// Copyright 2013 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// Created by postproc-cld2 4.0 on 2013-07-15 14:43:59
// From command line:
//  --cld2 --cc --just_read_raw --quad --standard --minchars=2 --mincount=2
//  --max_items_per_langscript=6000 --flatmap --rr_alloc --freq_alloc
//  --boostcloseweakerpercent=00 --indirectbits=16 --thresh=224 --v25
//  --kentries=256 --tablename=QuadChrome0715 --remap=xxx-Latn=>ut-Latn
//  sh-Latn=>hr-Latn sh-Cyrl=>sr-Cyrl    nn-Latn=>no-Latn mo-Cyrl=>ro-Cyrl
//    --include=af-Latn ar-Arab be-Cyrl bg-Cyrl ca-Latn cs-Latn cy-Latn
//  da-Latn de-Latn el-Grek en-Latn es-Latn et-Latn fa-Arab fi-Latn fr-Latn
//    ga-Latn gd-Latn hi-Deva hr-Latn hu-Latn id-Latn is-Latn it-Latn
//  iw-Hebr    ja-Hani ko-Hani lg-Latn lt-Latn lv-Latn mk-Cyrl ms-Latn
//  nl-Latn no-Latn    pl-Latn pt-Latn ro-Latn ro-Cyrl ru-Cyrl rw-Latn
//  sh-Cyrl sh-Latn sk-Latn sl-Latn sr-Cyrl    sv-Latn sw-Latn th-Thai
//  tl-Latn tr-Latn uk-Cyrl vi-Latn yi-Hebr    zh-Hani zh-TW    sq-Latn
//  az-Latn eu-Latn bn-Beng gl-Latn ht-Latn mt-Latn sr-Latn ur-Arab
//  bh-Deva mr-Deva ne-Deva lg-Latn rw-Latn gd-Latn    ut-Latn ut-Deva
//  ceb-Latn blu-Latn jw-Latn  --ko_english --force_to_lang_soft
//  --nosoft_cram2 --nomsidlevel --shapeflatprob --langpriorpercent=10
//  --skipnuc --noshapeforcetop --noshapeeventop --noshapesteep2
//  --langcounts --writebin --list_items=120 --max_langs_per_item=3
//  i18n/encodings/cld2/prob_data/vetted_quad_prob_20130527.utf8
//
#include "cld2tablesummary.h"
namespace CLD2 {

// For this build date, looking up 'qpdbmrmxyzptlkuuddlrlrbas' gives WELSH
static const uint32 kQuadChrome0715BuildDate = 20130715;    // yyyymmdd


// Of 367242 offered items into 262144 table entries:
// 240494 filled (65%), 651 merged (0%), 126097 dropped (34%)

// Nil-grams: 19 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE
//     SYRIAC LIMBU ORIYA INUKTITUT

// Uni-grams: 4 languages
//     Japanese Korean Chinese ChineseT

// Words/Quads: 60 languages in range ENGLISH..HMONG:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     BULGARIAN CROATIAN SERBIAN IRISH GALICIAN TAGALOG TURKISH
//     UKRAINIAN HINDI MACEDONIAN BENGALI INDONESIAN MALAY WELSH
//     NEPALI ALBANIAN BELARUSIAN JAVANESE URDU BIHARI ARABIC CATALAN
//     BASQUE SCOTS_GAELIC SWAHILI SLOVENIAN MARATHI MALTESE
//     VIETNAMESE SLOVAK AZERBAIJANI PERSIAN YIDDISH AFRIKAANS
//     HAITIAN_CREOLE KINYARWANDA GANDA CEBUANO HMONG

//  ENGLISH 3815
//  DANISH 3854
//  DUTCH 3771
//  FINNISH 3867
//  FRENCH 3835
//  GERMAN 3777
//  HEBREW 3805
//  ITALIAN 2773
//  NORWEGIAN 3850
//  POLISH 3862
//  PORTUGUESE 3860
//  RUSSIAN 3879
//  SPANISH 3326
//  SWEDISH 3930
//  CZECH 7715
//  ICELANDIC 3812
//  LATVIAN 3877
//  LITHUANIAN 3819
//  ROMANIAN 7682
//  HUNGARIAN 3832
//  ESTONIAN 3794
//  BULGARIAN 3872
//  CROATIAN 7685
//  SERBIAN 6930
//  IRISH 3849
//  GALICIAN 3667
//  TAGALOG 2941
//  TURKISH 3799
//  UKRAINIAN 3818
//  HINDI 7683
//  MACEDONIAN 3811
//  BENGALI 3837
//  INDONESIAN 3487
//  MALAY 2284
//  WELSH 3758
//  NEPALI 3775
//  ALBANIAN 3905
//  BELARUSIAN 3853
//  JAVANESE 3800
//  URDU 3843
//  BIHARI 4148
//  ARABIC 3810
//  CATALAN 3767
//  BASQUE 3800
//  SCOTS_GAELIC 3839
//  SWAHILI 3798
//  SLOVENIAN 3851
//  MARATHI 3786
//  MALTESE 3796
//  VIETNAMESE 3847
//  SLOVAK 3843
//  AZERBAIJANI 3914
//  PERSIAN 3817
//  YIDDISH 3828
//  AFRIKAANS 3797
//  HAITIAN_CREOLE 3796
//  KINYARWANDA 3760
//  GANDA 3823
//  CEBUANO 2513
//  HMONG 2280



// Recognized language-script combinations [62]:
static const char* const kQuadChrome0715RecognizedLangScripts =
  "af-Latn ar-Arab az-Latn be-Cyrl bg-Cyrl bh-Deva blu-Latn bn-Beng "
  "ca-Latn ceb-Latn cs-Latn cy-Latn da-Latn de-Latn en-Latn es-Latn "
  "et-Latn eu-Latn fa-Arab fi-Latn fr-Latn ga-Latn gd-Latn gl-Latn "
  "hi-Deva hr-Latn ht-Latn hu-Latn id-Latn is-Latn it-Latn iw-Hebr "
  "jw-Latn lg-Latn lt-Latn lv-Latn mk-Cyrl mr-Deva ms-Latn mt-Latn "
  "ne-Deva nl-Latn no-Latn pl-Latn pt-Latn ro-Cyrl ro-Latn ru-Cyrl "
  "rw-Latn sk-Latn sl-Latn sq-Latn sr-Cyrl sr-Latn sv-Latn sw-Latn "
  "tl-Latn tr-Latn uk-Cyrl ur-Arab vi-Latn yi-Hebr ";

static const uint32 kQuadChrome0715Size = 65536;    // Bucket count
static const uint32 kQuadChrome0715KeyMask = 0xffff0000;    // Mask hash key

static const IndirectProbBucket4 kQuadChrome0715[kQuadChrome0715Size] = {
  // hash_indirect[4], tokens[4] in UTF-8
   {{0xe9da0002,0x7c2e0003,0x65630004,0x394a0005}},	// [000] вка_, ssbr, kenh, _pcbs_,
   {{0x20070006,0xbddb0007,0x63bb0008,0x27ed0009}},	//   _kuni_, stèr, hiun, _ahen_,
   {{0xddc4000a,0x6563000b,0x02e2000c,0xbddb000d}},	//   _križ, denh, _पर्न, ptèr,
   {{0x63bb000e,0x2007000f,0x6e240010,0xeb9a0011}},	//   jiun, _muni_, _kwib, _рим_,
   {{0x20070012,0x63a90013,0x27ed0014,0x63bb0015}},	//   _luni_, dhen, _dhen_, diun,
   {{0x65630016,0x64430017,0x6fdd0018,0x24510019}},	//   genh, funi, léct, _bơm_,
   {{0x6443001a,0x24510019,0x26cd001b,0x2007001c}},	//   guni, _cơm_, _exeo_, _nuni_,
   {{0x63bb001d,0x63a9001e,0xf743001f,0x6fdd0020}},	//   giun, ghen, _месо, néct,
   {{0x36670021,0x65630022,0x21270023,0x69dc0024}},	//   _като_, benh, _benh_, _kkre,
   {{0x20070025,0x0f1f0026,0x65630009,0x6f040027}},	//   _buni_, पर्स_, cenh, _agic,
   {{0x2b9c0028,0x75280029,0x63bb002a,0x6aad002b}},	//   _tích_, _iedz, biun, zzaf,
   {{0x63a9002c,0x63bb002d,0x4ea7002e,0x2007002f}},	//   chen, ciun, арга, _duni_,
   {{0x75280030,0x6d470031,0x69c50032,0xc6080033}},	//   _kedz, tgja, ynhe, রীরা_,
   {{0x6e240034,0x75280035,0x20070036,0x71730037}},	//   _dwib, _jedz, _funi_, _وهنا,
   {{0x75280038,0x212c0014,0x6d470039,0xddc4003a}},	//   _medz, madh_, rgja, _friž,
   {{0x212c003b,0x69c5003c,0xddc4003d,0x6d47003e}},	//   ladh_, wnhe, _griž, sgja,
   {{0x6b8d003f,0x64430040,0xafb80041,0x69d70042}},	// [010] rjag, zuni, _خطوط_, toxe,
   {{0x63bb0043,0x212c003b,0x7ac40044,0x27ed0045}},	//   ziun, nadh_, істе, _shen_,
   {{0x69d70046,0x65630047,0x27ed0048,0x69c50049}},	//   roxe, venh, _phen_, rnhe,
   {{0x212c004a,0xa804004b,0xc7c4004c,0x6443004d}},	//   hadh_, ізіл, осчи, vuni,
   {{0x7528004e,0xd6ab004f,0x672b0050,0x69d70051}},	//   _bedz, خدام_, ragj, poxe,
   {{0x27ed0052,0x64430053,0x26df0054,0x672b0055}},	//   _when_, tuni, _vyuo_, sagj,
   {{0x27ed0056,0x65630057,0x212c0058,0x63bb0043}},	//   _then_, renh, dadh_, tiun,
   {{0x65630059,0x6443005a,0x7e6d005b,0xb385005c}},	//   senh, runi, _osap, слил,
   {{0x63a9005d,0x6443005e,0x63bb005f,0x212c0037}},	//   rhen, suni, riun, fadh_,
   {{0x64430060,0x212c003b,0x63bb0061,0x20070062}},	//   puni, gadh_, siun, _puni_,
   {{0xddc40063,0x63bb0064,0x7e6d0065,0x15ed0066}},	//   _priž, piun, _asap, _चीयर_,
   {{0xedb20067,0x66010068,0x7f4d0069,0x06ae0033}},	//   ुच्छ, _hilk, _ccaq, _ছুটি,
   {{0x6601006a,0x212c006b,0x7e6d006c,0x6729006d}},	//   _kilk, badh_, _csap, _meej,
   {{0x212c006e,0x6729006f,0xb2760070,0x00000000}},	//   cadh_, _leej, _לענג_, --,
   {{0x10150071,0xfce60072,0xdca30073,0x7e6d0074}},	//   _ابتد, сово, пари, _esap,
   {{0x69dc0075,0xee3f0076,0x67290077,0x66010078}},	//   _skre, brý_, _neej, _lilk,
   {{0x6d410079,0xddc4007a,0x6e24007b,0x00000000}},	// [020] ólac, _kriż, _uwib, --,
   {{0x46db007c,0x6601007d,0x31a9007e,0x7995007f}},	//   _बड़ह, _nilk, _fúze_, _cozw,
   {{0x75280080,0xdceb0009,0x4d7b0070,0xd7ef0081}},	//   _redz, _ćiće, _ערטע, зу_,
   {{0xbb860082,0x06d10083,0xa3e70084,0xf7460085}},	//   _الحي, ়েছি, _मील_, седо,
   {{0x65940086,0x66010087,0xe9440088,0x16340089}},	//   жалу, _bilk, _ورسی, целя,
   {{0xdb16008a,0x69dc008b,0x6609008c,0xdb0d008d}},	//   ábær, _ukre, _duek, lnað,
   {{0x6601008e,0xe644008f,0xb8960037,0x44250090}},	//   _dilk, ğlığ, _الزع, _cwl_,
   {{0x52140091,0xe6440092,0xdb0d0093,0xddc40024}},	//   одит, şlığ, nnað, _ariż,
   {{0x212c0094,0x6fc80095,0x59bf0096,0x00000000}},	//   tadh_, rıcl, ्वचर, --,
   {{0x20090009,0xddcd0097,0x44250098,0x26f60099}},	//   _čair_, _krať, _fwl_, ेशीर_,
   {{0x212c003b,0x1bf8009a,0xdb0d0093,0x6729009b}},	//   radh_, ंगाल_, knað, _yeej,
   {{0x212c009c,0x7f9f0031,0x00000000,0x00000000}},	//   sadh_, _këqi, --, --,
   {{0x212c009d,0xeabf009e,0xddc4009f,0x27fc00a0}},	//   padh_, _ceùl_, _friż, ívny_,
   {{0xa2c500a1,0xddc4009f,0x9f4900a2,0x98b800a3}},	//   ापर्, _griż, _thaï_, _ları_,
   {{0x7995006a,0x63b9001e,0x5ba700a4,0x31bb00a5}},	//   _rozw, _ymwn, браз, _תזונ,
   {{0xdb0d0093,0x2d8c00a6,0x00000000,0x00000000}},	//   gnað, öder_, --, --,
   {{0x7995004e,0x7e6d00a7,0x681500a8,0x74df00a9}},	// [030] _pozw, _usap, _işdə, _पुनः,
   {{0x5a3400aa,0x672900ab,0xaa7b00ac,0x00000000}},	//   янут, _seej, _ozýv, --,
   {{0xe71900ad,0xa3ca0026,0x98b800ae,0x9b9500af}},	//   ليات_, ोवा_, _barı_, _динц,
   {{0x660100b0,0xe00b00b1,0xd3660088,0x00000000}},	//   _silk, _संसद_, _غه_, --,
   {{0xd24600b2,0x660100b3,0xf1d800b4,0xe77800b5}},	//   _تن_, _pilk, डवान, صلوں_,
   {{0xcfcf0083,0x441500b6,0x00000000,0x00000000}},	//   রতিন, офит, --, --,
   {{0x660100b7,0x5fd900b8,0x672900b9,0xddc4009f}},	//   _vilk, णकाल, _teej, _rriż,
   {{0x36d500ba,0x660100bb,0xe3b100bc,0x57a400af}},	//   _добр, _wilk, برت_, _ешуа,
   {{0x660100bd,0x660900be,0xb5fd005f,0xddc4009f}},	//   _tilk, _uuek, _apše, _priż,
   {{0xd19900af,0x00000000,0x00000000,0x00000000}},	//   ртич_, --, --, --,
   {{0xe2a800bf,0xfbd900c0,0x98b800c1,0x00000000}},	//   لاین_, भकाम, _yarı_, --,
   {{0x14d600c2,0x225900c3,0x63b90027,0x00000000}},	//   _וועל_, _виды_, _umwn, --,
   {{0xc8e600c4,0xddc400c5,0x00000000,0x00000000}},	//   _कर्म_, _asiš, --, --,
   {{0xa0a500c6,0x853c00c7,0x00000000,0x00000000}},	//   _малд, _alėj, --, --,
   {{0x09c400c8,0x3b9600c9,0x8b9600ca,0xdb0d0093}},	//   ্তমা, ојат, орач, tnað,
   {{0x7c3a00cb,0xc05200a5,0xe8e000cc,0x00000000}},	//   štro, _חזה_, liệu_, --,
   {{0xdb0d0093,0x7c2900cd,0x00000000,0x00000000}},	// [040] rnað, ćera, --, --,
   {{0xbd4600ce,0xed5a00cf,0x98b800d0,0x2b5800d1}},	//   _بندي, _тоо_, _sarı_, _گیرد_,
   {{0xc8ca00d2,0x00000000,0x00000000,0x00000000}},	//   جوان_, --, --, --,
   {{0x81c10033,0x00000000,0x00000000,0x00000000}},	//   ূতি_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a3002d,0xddcd00ac,0x00000000,0x00000000}},	//   мичи, _trať, --, --,
   {{0x07a600d3,0x00000000,0x00000000,0x00000000}},	//   _давн, --, --, --,
   {{0x81e70083,0xd32600d4,0xaa7b00d5,0x68b700a5}},	//   _মূল_, цьки, _vzýv, _וללא_,
   {{0x672200d6,0xdcfe0029,0x9f400098,0x2c1100ab}},	//   mboj, _kopē, _fhiú_, _दूनू_,
   {{0x2a6200d7,0xd25700d8,0x27e600d9,0xdb230079}},	//   _mpkb_, іцы_, llon_, árúc,
   {{0x201800da,0x26100019,0xdb06006c,0x6ac600db}},	//   ëri_, _hào_, _elké, लपुर,
   {{0x28bd00dc,0x27e600dd,0x75ed00de,0x09a700df}},	//   ्पति, nlon_, púzc, _गत्य,
   {{0xd250004f,0xa2d600d1,0x230900e0,0x201800e1}},	//   _أنت_, _بيشت, _اتمي_, ūri_,
   {{0x261000e2,0x00000000,0x00000000,0x00000000}},	//   _mào_, --, --, --,
   {{0x27e600e3,0x26100019,0x2ca500e4,0x6f1600e5}},	//   klon_, _lào_, áld_, _ffyc,
   {{0x27e600e6,0x2a6200e7,0x764200ce,0x201e004b}},	//   jlon_, _bpkb_, kroy, mpti_,
   {{0x261000e8,0x291c0095,0x27e600e9,0xdc3c00ea}},	// [050] _nào_, ıvan_, dlon_, kšķe,
   {{0xceb20070,0x7e7f0069,0x764200eb,0xdcfe00ec}},	//   _ניי_, _irqp, droy, _copē,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26100019,0x27e600e9,0x201e00c7,0x00000000}},	//   _bào_, glon_, ipti_, --,
   {{0xff7c0070,0x26100023,0x79a700ed,0x31a900ee}},	//   יטאמ, _cào_, _дрве, _lúza_,
   {{0x5a3400ef,0x996400f0,0xbafa00a5,0x9f4000f1}},	//   _інст, _отсл, _להרש, _dhiù_,
   {{0x27e600f2,0x057400f3,0xdce500f4,0x00000000}},	//   blon_, باند, _dahć, --,
   {{0xd90e00f5,0x764200f6,0x9f40009e,0x00000000}},	//   _لیے_, broy, _fhiù_, --,
   {{0x764200f7,0x35b5002d,0x261000e2,0x78b800f4}},	//   croy, _ебар, _gào_, ćavš,
   {{0xd6c600f8,0x661b00f9,0x14190037,0x00000000}},	//   _عملی, _ituk, _هيئة_, --,
   {{0x3cdb00fa,0x00000000,0x00000000,0x00000000}},	//   _खुले_, --, --, --,
   {{0x6d4100fb,0xe3b300fc,0x00000000,0x00000000}},	//   ólan, _غرض_, --, --,
   {{0x26100023,0xb2c700fd,0xdd1100fe,0x705200ff}},	//   _xào_, _بغاو, _hýři, ونیا,
   {{0xdd9200bf,0x427a0100,0x64430101,0x672200cd}},	//   روز_, _לאנג, orni, zboj,
   {{0xa0a50102,0x661b0103,0x0c790104,0x00000000}},	//   _хайд, _ltuk, осты_, --,
   {{0x5f760105,0x64430106,0xbebb0031,0x3c180107}},	//   _رابر, irni, mbën, _nčve_,
   {{0xeb970108,0xa9a60109,0x661b010a,0x4a46010b}},	// [060] чит_, пиад, _ntuk, янав,
   {{0x2d96010c,0x7e64010d,0x26100023,0xfa490037}},	//   _хрис, _ipip, _rào_, تشفى_,
   {{0xfce6010e,0x661b010f,0x6d5c0110,0x261000e2}},	//   _хоно, _atuk, mfra, _sào_,
   {{0x2d9a00a5,0x76420111,0xe7370112,0xa2dc0099}},	//   _hope_, troy, зец_, _पडल्,
   {{0x67220029,0x64430113,0xd90d00fd,0xf99100fd}},	//   rboj, erni, ایہ_, ربے_,
   {{0x6d4e0114,0x261000e8,0x6d5c0115,0x27e60116}},	//   ngba, _vào_, nfra, slon_,
   {{0x27e60117,0x290a0118,0x661b0119,0x29180044}},	//   plon_, _igba_, _etuk, _ifra_,
   {{0x69de011a,0x7642011b,0x7e64011c,0xa857011d}},	//   lope, proy, _opip, _מילה_,
   {{0x321f011e,0x41e600d8,0x04fe0033,0x00000000}},	//   gpuy_, зіна, ুরের_, --,
   {{0x69de011f,0x6d4e0120,0x56370070,0x64430121}},	//   nope, jgba, _מאמע_, brni,
   {{0xf9930122,0x6d5c0123,0xe8df0019,0x64430124}},	//   תרת_, dfra, _trục_, crni,
   {{0xd36f0125,0x69de0126,0xd9b90127,0xbddb0118}},	//   _مهم_, hope, _आष्ट, grèn,
   {{0x6d5c0128,0x644a0129,0xe3b300c2,0x69de012a}},	//   ffra, lufi, _אױף_, kope,
   {{0x72eb012b,0x2d9a012c,0x00000000,0x00000000}},	//   _פֿאַ, _cope_, --, --,
   {{0xd5c800e8,0x6458012d,0x7c29012e,0x515b00a5}},	//   yền_, ntvi, ćero, _הכוו,
   {{0x7e64012f,0x6d4e0130,0xa3be0066,0xc17800c7}},	//   _fpip, agba, ुचि_, ldė_,
   {{0xb9990131,0xdb0d0132,0xdcfd00a8,0x6d5c0110}},	// [070] овах_, nhaé, ızıs, bfra,
   {{0x5c070133,0x64430134,0x64580135,0xc178010b}},	//   _няма, yrni, ktvi, ndė_,
   {{0x3ea60080,0x661b0136,0xa3be0099,0x75ed00ac}},	//   _ļoti_, _stuk, ुचा_, fúzn,
   {{0x6443008b,0x2d9a0065,0xdc360070,0x64580137}},	//   vrni, _zope_, _קארט_, dtvi,
   {{0x7bdf0138,0x69de0139,0x7bcd013a,0x3f8900ee}},	//   moqu, bope, mnau, _mnau_,
   {{0x6458008c,0xddd60097,0x3f9b013b,0x00000000}},	//   ftvi, _kryš, _loqu_, --,
   {{0x6458013c,0x6443013d,0xbddb00a2,0x7bcd013e}},	//   gtvi, urni, yrèn, onau,
   {{0x7bcd013f,0x64430140,0x260a0141,0x22150142}},	//   nnau, rrni, ादशी_, мфор,
   {{0x6d5c001e,0xd24e0079,0x661b0143,0x42540144}},	//   yfra, لني_, _utuk, нтэт,
   {{0x23c30107,0x10a50145,0x6d410146,0x644a007b}},	//   _bèjè_, дион, ólal, bufi,
   {{0x54550002,0x2d9a0147,0x00000000,0x00000000}},	//   _цвет, _rope_, --, --,
   {{0xd24e0148,0x20180149,0x69de002f,0xe291014a}},	//   دنی_, íria_, zope, _لذت_,
   {{0x6d5c014b,0x69de0054,0x7bdf014c,0x2d9a0147}},	//   tfra, yope, doqu, _pope_,
   {{0x90c5014d,0x7ae6014e,0x3f89014f,0xdce500a0}},	//   _обле, _rykt, _enau_, _dohľ,
   {{0xfce30150,0x6d5c0151,0x7bdf0152,0x1d070153}},	//   воро, rfra, foqu, дери_,
   {{0x7bcd0154,0x764b0155,0x8ffa00d1,0x7c220156}},	//   gnau, kugy, _برتر_, _čord,
   {{0x69de0157,0x2d9a0158,0x3207007b,0x00000000}},	// [080] tope, _tope_, _kiny_, --,
   {{0x764b0159,0x7bcd0051,0x320f0118,0xddd6007e}},	//   dugy, anau, _mugy_, _fryš,
   {{0xeb9a0012,0x8b26015a,0x69de015b,0x2ade0096}},	//   _дин_, _одне, rope, _कुरु_,
   {{0xfaa6004b,0x46ea015c,0x69de015d,0x7bdf015e}},	//   _жамо, оден_, sope, coqu,
   {{0x69de015f,0xe6770160,0x00000000,0x00000000}},	//   pope, _aţâţ, --, --,
   {{0x64580161,0x28d90162,0x644a0163,0x00000000}},	//   ttvi, _बुकि, tufi, --,
   {{0xd90d0164,0x00000000,0x00000000,0x00000000}},	//   _ایم_, --, --, --,
   {{0x02a60165,0xc2740166,0x28bd0167,0x320f0168}},	//   дром, елиј, ्परि, _bugy_,
   {{0x64580169,0x6aa4016a,0xba9b016b,0x65af008c}},	//   stvi, nyif, ַסטי, _søhe,
   {{0xb5aa004f,0x2fc0016c,0xd25000fd,0x00000000}},	//   _بارك_, _amig_, پنگ_, --,
   {{0x26ee007c,0x3207016d,0x799c016e,0xc17800c7}},	//   _जरुर_, _diny_, _morw, rdė_,
   {{0xdce5016f,0x2d9e0170,0x33830171,0x73360172}},	//   _pohľ, öten_, _аушв, _آرائ,
   {{0x799c0173,0xa3e70174,0x7bdf0175,0x69cb00b5}},	//   _oorw, _मीट_, voqu, égek,
   {{0x290700d8,0x32070176,0x442c0177,0x62820178}},	//   žnai_, _giny_, _kwd_, _iroo,
   {{0x7bdf0179,0x00000000,0x00000000,0x00000000}},	//   toqu, --, --, --,
   {{0x62820006,0x26ee017a,0x6608017b,0x764b0159}},	//   _kroo, _जरूर_, _lidk, yugy,
   {{0x7bcd017c,0x799c017d,0xdee7017e,0xa3d6017f}},	// [090] rnau, _borw, _تأثي, _सदन_,
   {{0xf9930180,0x6e2d0010,0x7bdf0181,0xdb0d00f7}},	//   خبر_, _iwab, soqu, chaî,
   {{0x20090182,0x7bdf0183,0x23b10184,0xddcd005f}},	//   _kiai_, poqu, _háje_, _kraž,
   {{0xa6350185,0x6e2d0186,0x68e70187,0x764b0188}},	//   енді, _kwab, _vyjd, tugy,
   {{0x62820189,0x799c00a5,0x2009018a,0x68e70067}},	//   _nroo, _forw, _miai_, _wyjd,
   {{0x6b9d018b,0x6e2d018c,0xba43010b,0x799c00e9}},	//   _hosg, _mwab, žįst, _gorw,
   {{0x6282018d,0x6e2d018e,0x7659001e,0x69c5018f}},	//   _aroo, _lwab, stwy, mihe,
   {{0xe2990036,0x6f0d0190,0x62820191,0xe64b00a8}},	//   заи_, _ngac, _broo, şdığ,
   {{0x02050192,0x09c40033,0x62820147,0x00000000}},	//   нзин, ্তরা, _croo, --,
   {{0x62820136,0x6b9d0193,0x6f0d0010,0x69c50194}},	//   _droo, _losg, _agac, nihe,
   {{0x6e2d0195,0x62820196,0x320700ac,0xddcd0197}},	//   _awab, _eroo, _viny_, _braž,
   {{0x6e2d0198,0x69c50199,0x6b9d002a,0x6282019a}},	//   _bwab, hihe, _nosg, _froo,
   {{0xee37019b,0x6282019c,0x69c5019d,0x6145019e}},	//   ння_, _groo, kihe, _зела,
   {{0x236d019f,0x4cc10033,0x6f0d0176,0x7c2201a0}},	//   leej_, _শুধু, _egac, _čorb,
   {{0x61e101a1,0x69c501a2,0x6b9d01a3,0x61d600a5}},	//   moll, dihe, _bosg, _אוסף_,
   {{0x63a901a4,0x200901a5,0xddcd00d8,0x6b9d01a6}},	//   nken, _giai_, _graž, _cosg,
   {{0x6b63005f,0x799c01a7,0x6e2d01a8,0x6b9d009e}},	// [0a0] ыкта, _porw, _gwab, _dosg,
   {{0x236d01a9,0x61e101aa,0x63a901ab,0x69c501ac}},	//   heej_, noll, hken, gihe,
   {{0x63a901ad,0x799c01ae,0x6b9d01a6,0x574601af}},	//   kken, _vorw, _fosg, енеб,
   {{0x61e101b0,0x63a901b1,0x1bba01b2,0x224d01a3}},	//   holl, jken, _راجع_, kuek_,
   {{0x61e101b3,0x63a901b4,0x9980010b,0x69c501b5}},	//   koll, dken, usių_, bihe,
   {{0x63a901b6,0x224d01b7,0x00000000,0x00000000}},	//   eken, duek_, --, --,
   {{0x186701b8,0x61e101b9,0x316c01ba,0x63a90051}},	//   _пари_, doll, vedz_, fken,
   {{0x645c00ab,0x628201bb,0x6f0900f4,0x00000000}},	//   _ärim, _proo, žeci, --,
   {{0xd2570043,0x6d41008d,0x224d0065,0x660801bc}},	//   нцэ_, ólak, guek_, _tidk,
   {{0xbddb01bd,0x61e101be,0x6e2d0010,0x628201bf}},	//   trèm, goll, _rwab, _vroo,
   {{0xddcd01c0,0x6e2d01c1,0x200900d7,0x316c00ea}},	//   _praž, _swab, _piai_, redz_,
   {{0x645a01c2,0x63a901c3,0xd469004f,0x657a01c4}},	//   _iqti, cken, _تحكم_, _hath,
   {{0x657a01c5,0xddcd01c6,0x61e101c7,0x71a601c8}},	//   _kath, _vraž, boll, _падз,
   {{0x61e101c9,0xd12f01ca,0x657a01cb,0x40940037}},	//   coll, _همه_, _jath, _للتر,
   {{0xddcd01cc,0x6b9d01cd,0x657a01ce,0x628001cf}},	//   _traž, _posg, _math, lvmo,
   {{0x657a0014,0x6e2d01d0,0xddcd00d5,0x09bb01d1}},	//   _lath, _twab, _uraž, ोच्य,
   {{0x245a01d2,0x3df501d3,0x6b9d01d4,0x6e2d01d5}},	// [0b0] hëm_, _изис, _vosg, _uwab,
   {{0xdb0d004f,0x3eb301d6,0x63a901d7,0xc4b00035}},	//   mhaí, ıntı_, zken, जनाओ,
   {{0x69c501d8,0x63a901d9,0x6b9d01da,0x00000000}},	//   rihe, yken, _tosg, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe6180044,0x8b9a0122,0x8a1801db,0x657a01dc}},	//   еді_, _חברת, _пояс_, _bath,
   {{0x61e101dd,0x657a01de,0x1a6801df,0x659401e0}},	//   xoll, _cath, _سیمی_, лачу,
   {{0x657a01e1,0x61e101e2,0x63a901e3,0x69d501e4}},	//   _dath, voll, tken, _ijze,
   {{0xc17801c8,0x657a01e5,0x68e301ae,0x224d01d7}},	//   klės_, _eath, ündu, tuek_,
   {{0x61e101e6,0x853c010b,0xddcd007a,0x00000000}},	//   toll, _plėt, _braż, --,
   {{0x63a901e7,0x9264004f,0x236d01e8,0x777b01d7}},	//   sken, اديم, seej_, _haux,
   {{0x63a901e9,0x00000000,0x00000000,0x00000000}},	//   pken, --, --, --,
   {{0x61e101ea,0x00000000,0x00000000,0x00000000}},	//   soll, --, --, --,
   {{0x61e101eb,0x657a01ec,0xddcd007a,0x224d01ed}},	//   poll, _yath, _fraż, quek_,
   {{0x614501ee,0xdb0d01ef,0x7e7600d5,0x777b00e2}},	//   _река, diañ, _vsyp, _laux,
   {{0xb02400e8,0xfce601f0,0x1fb601f1,0x2b3a00af}},	//   _trườ, тово, _аспр, дязэ_,
   {{0xf4130083,0x69d501f2,0x8e4a0037,0xdb0d0079}},	//   _সবার_, _ajze, _قلبك_, bhaí,
   {{0xc33201f3,0x245a01f4,0xdcfe00ea,0xb5fd013a}},	// [0c0] יון_, zëm_, _kopī, _apšm,
   {{0x2d9501f5,0xe9d701f6,0xa92300af,0x9f4001f7}},	//   _брюс, вку_, идул, _thió_,
   {{0x657a01f8,0x2fd70088,0x777b01f9,0x00000000}},	//   _rath, _سوید_, _baux, --,
   {{0x657a01fa,0x7bda000d,0xb09a0070,0xe3b801fb}},	//   _sath, étud, ויער, _atın_,
   {{0x657a01fc,0xeb9701fd,0x00000000,0x00000000}},	//   _path, _рия_, --, --,
   {{0x245a01d2,0x7c3a01fe,0x645c00ab,0xceb3016b}},	//   tëm_, štru, _ärik, סיג_,
   {{0x629d01ff,0xd4670200,0x657a0201,0x00000000}},	//   äson, вије_, _vath, --,
   {{0x07a30202,0x245a0055,0x657a0203,0xc7a30204}},	//   _касн, rëm_, _wath, _киск,
   {{0x657a0205,0xa6650206,0x245a0031,0x7c290207}},	//   _tath, _مطلو, sëm_, ćeri,
   {{0x657a004f,0x601e0029,0x00000000,0x00000000}},	//   _uath, _līme, --, --,
   {{0x9f350208,0x8f350209,0x255a0107,0x00000000}},	//   лені, ленц, _vņlč_, --,
   {{0xdb0d004f,0xddcd0035,0x67f800b8,0x1fa7020a}},	//   thaí, _wraż, bíje, трог,
   {{0x7c22020b,0x386a0009,0xecdb0067,0x798e0107}},	//   _čora, _lpbr_, _मुजफ, _onbw,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d6020c,0xa3c6020d,0xc1f70070,0x3ead020e}},	//   _सदा_, _उगा_, _שמוץ_, šet_,
   {{0x644a0037,0x7d0800b5,0x23b1007e,0x00000000}},	//   irfi, _sérü, _kája_, --,
   {{0x777b020f,0xaa5c0210,0x6284010b,0x23b100fe}},	// [0d0] _raux, метi, _šioj, _jája_,
   {{0x23b101ba,0x39580211,0x4c950212,0x00000000}},	//   _mája_, _ccrs_, _биос, --,
   {{0x2907013c,0x443e0213,0x98140037,0x4cc10033}},	//   äna_, _nvt_, لبنا, _শুরু,
   {{0xc8640214,0x9b95002d,0xdb0d01ed,0x00000000}},	//   ртфи, _симц, piañ, --,
   {{0x4993006c,0x75ed0215,0x7bda000d,0x9f44000d}},	//   _پیار, lúzi, étue, ômé_,
   {{0x6d550216,0x601e00ea,0xbebb0031,0x27310023}},	//   ngza, _zīme, rbëh, ạn_,
   {{0xe89400c3,0x69d80099,0x2a790207,0x00000000}},	//   _карь, _मदती, _hssb_, --,
   {{0x58d40217,0x2907010b,0x00000000,0x00000000}},	//   _тост, žnas_, --, --,
   {{0x443e0218,0x644a0219,0x36d50043,0xdb06008c}},	//   _evt_, arfi, _соар, _elkæ,
   {{0xdb040037,0x05b7021a,0x443e0044,0x6d550051}},	//   thiú, _अतिब, _fvt_, jgza,
   {{0xcea900c2,0x8fa6021b,0x443e021c,0x00000000}},	//   _צי_, гане, _gvt_, --,
   {{0x261900e2,0xdb0f00a2,0x6563021d,0x3c18021e}},	//   _kèo_, _ulcè, lfnh, _sčvo_,
   {{0x2bc60141,0xe1ee021f,0xe28e0210,0x00000000}},	//   रोफा, _гг_, _уа_, --,
   {{0xd00e0220,0x237d0221,0x26190019,0x5fc600ab}},	//   _کلي_, _hawj_, _mèo_, _लगवल,
   {{0x225f0222,0x00000000,0x00000000,0x00000000}},	//   ltuk_, --, --, --,
   {{0xc0520052,0x6d550223,0x00000000,0x00000000}},	//   _הזה_, agza, --, --,
   {{0x225f0224,0x261900e2,0xdd040225,0x00000000}},	// [0e0] ntuk_, _nèo_, ırıs, --,
   {{0x237d01e8,0x6e2401d6,0x8d560226,0x00000000}},	//   _lawj_, _itib, _стич, --,
   {{0xdca60227,0x39580183,0x601e0228,0x3136016b}},	//   _сани, _vcrs_, _tīme, רנעם_,
   {{0x237d0221,0x261900e2,0x225f0229,0xfaff0055}},	//   _nawj_, _bèo_, ktuk_, _ibën_,
   {{0x569400af,0x443e022a,0x96e7022b,0xe5a6022c}},	//   ралт, _svt_, льша_, лиди,
   {{0x443e022d,0x281600d1,0x2a60022e,0x6e24002f}},	//   _pvt_, _موسس, mtib_, _mtib,
   {{0xdd3200a8,0x00000000,0x00000000,0x00000000}},	//   zəşt, --, --, --,
   {{0x6d55022f,0x7f440031,0x644a0230,0x722a0231}},	//   zgza, _ndiq, rrfi, нцов_,
   {{0x6e240232,0x27e60233,0x237d006d,0x85560071}},	//   _ntib, moon_, _dawj_, _مخاط,
   {{0x27e60234,0xd6cf0041,0x104a0235,0x463b0070}},	//   loon_, _عقل_, нями_, _נעבע,
   {{0x6e240236,0xb6030237,0x5f950043,0x2a6000be}},	//   _atib, íšen, аинт, htib_,
   {{0x27e60238,0x2a600239,0x2366023a,0x00000000}},	//   noon_, ktib_, _uboj_, --,
   {{0x6e2400d5,0x6234002d,0xcae300b4,0x44ce013b}},	//   _ctib, _телу, _कुंड_, _hə_,
   {{0x63a2007c,0x27e6023b,0x7bc6023c,0x00000000}},	//   _hoon, hoon_, _amku, --,
   {{0x63a2007c,0x27e6023d,0x6e240095,0x2a6b01da}},	//   _koon, koon_, _etib, _spcb_,
   {{0x764b016e,0x63a2023e,0x44ce00a8,0x27e6023f}},	//   yrgy, _joon, _mə_, joon_,
   {{0x27e6010d,0x38c9006c,0x44ce00a8,0x65af008c}},	// [0f0] doon_, ھائی_, _lə_, _bøhl,
   {{0x2bc60240,0x63a20241,0x7e6d0242,0x26180243}},	//   रोबा, _loon, _ipap, _पढ़ी_,
   {{0x44ce01c2,0x27e60244,0x6d450245,0xa2cb0246}},	//   _nə_, foon_, _idha, _तेन्,
   {{0x63a20247,0xbddb0248,0x68ee0249,0x4427024a}},	//   _noon, ssèd, _dybd, vpn_,
   {{0x69cb00b5,0x6e240183,0xbb3a024b,0x00000000}},	//   éges, _xtib, _שעשי, --,
   {{0xce3800a5,0x9f420187,0x3a2900d7,0x7e6d024c}},	//   נאות_, roké_, mpap_, _mpap,
   {{0x63a2024d,0x27e600d7,0x9f42024e,0x6d45024f}},	//   _boon, boon_, soké_, _mdha,
   {{0x44ce0250,0x225f00b5,0xc2450251,0x261900e2}},	//   _də_, ttuk_, аник, _tèo_,
   {{0x63a200b9,0x6d450252,0xa3d60253,0x7e6d0159}},	//   _doon, _odha, _सदर_, _npap,
   {{0xb5fd0254,0x7aef00d7,0x6d4500f8,0x44270255}},	//   _opši, _myct, _ndha, ppn_,
   {{0x225f0256,0x7e6d0257,0x237d006f,0xe1f6002d}},	//   stuk_, _apap, _tawj_, ргэ_,
   {{0x6d450258,0xe7b50066,0x8e860259,0xc49a025a}},	//   _adha, ंसिप, агме, _בשעת,
   {{0x7c25025b,0x7aef00d7,0x69c7025c,0x7f440055}},	//   _athr, _nyct, _omje, _vdiq,
   {{0x63a2025d,0x7bc600d7,0x27e60223,0x44ce00a8}},	//   _zoon, _smku, zoon_, _yə_,
   {{0x63a2025e,0x27e60107,0x417400d1,0x30790070}},	//   _yoon, yoon_, _دانس, _יאַנ,
   {{0x63a200cc,0x4b26010b,0x00000000,0x00000000}},	//   _xoon, рмав, --, --,
   {{0x4425025f,0x6a83002d,0x3f92010d,0x98b10260}},	// [100] _ltl_, олта, _inyu_, _dezč_,
   {{0x27e60261,0x2a600262,0x644100b8,0xd9460263}},	//   woon_, rtib_, _ovli, режи,
   {{0x27e60264,0xb6070029,0xe73a0265,0xa3e50266}},	//   toon_, _mašī, вее_, पका_,
   {{0xb6cb006c,0xd62a0267,0xc6a60268,0xbebb0031}},	//   ھانے_, воде_, ирли, rbëv,
   {{0x27e60269,0x6441026a,0x8884026b,0x00000000}},	//   roon_, _avli, _گیان, --,
   {{0xbebb01d2,0x27e6026c,0x224d026d,0x4425026e}},	//   mbët, soon_, drek_, _btl_,
   {{0x63a2026f,0x27e60270,0xb7960200,0x00000000}},	//   _poon, poon_, _краћ, --,
   {{0x44ce0271,0x32660272,0x660301e8,0x7bd60273}},	//   _və_, атов, amnk, nnyu,
   {{0x644100d0,0xe57a0274,0x00000000,0x00000000}},	//   _evli, _иза_, --, --,
   {{0x63a20261,0x2ade007c,0x2bc60275,0x44ce013b}},	//   _woon, _कुछु_, रोता, _tə_,
   {{0x63a20276,0x66e200fe,0x6d45008c,0x09f70277}},	//   _toon, _díků, _rdha, שמים_,
   {{0xc4770122,0x224d0278,0x3f800279,0x4fc70012}},	//   _כתבו_, brek_, _caiu_, рсоа,
   {{0x4425027a,0xef1f027b,0x7c25009e,0x224d027c}},	//   _ztl_, rcü_, _sthr, crek_,
   {{0xdb0d0279,0x4425027d,0x3f82027e,0x3f920103}},	//   lhaç, _ytl_, adku_, _enyu_,
   {{0x8bc7027f,0xab950274,0xd1380067,0xddc40139}},	//   асад, бављ, ając_, _spiţ,
   {{0x69c70280,0x5b150281,0x61e80282,0xdb0d0132}},	//   _smje, смат, lodl, nhaç,
   {{0x2bc600a1,0x7e6d0283,0x2fc90284,0x6d41008a}},	// [110] रोधा, _upap, _imag_, ólas,
   {{0x6d450245,0x28870200,0x00000000,0x00000000}},	//   _udha, ићев, --, --,
   {{0x2fc9023a,0xcd7600a5,0x4dda00a5,0x00000000}},	//   _kmag_, _העתק_, _תחתו, --,
   {{0x44250285,0xd3660286,0x61e8024e,0xc60f0287}},	//   _rtl_, _عه_, hodl, ाद्य_,
   {{0x7bcd00d8,0x2d81007c,0x61e80288,0x5a440144}},	//   miau, _kahe_, kodl, _мэра,
   {{0x69c70289,0x2d83028a,0x7bcd00d8,0x4425028b}},	//   _umje, ndje_, liau, _ptl_,
   {{0xf773028c,0x2d8100b9,0x2d830223,0xaa8600d5}},	//   _وار_, _mahe_, idje_, rkýž,
   {{0x224d028d,0x7bcd028e,0x2d81007c,0xe3b1028f}},	//   trek_, niau, _lahe_, ثرت_,
   {{0x27ed0290,0x6aad01d5,0x1309002d,0x00000000}},	//   _iken_, nyaf, ыний_, --,
   {{0x224d0291,0xddc40292,0x61e80293,0x3f800294}},	//   rrek_, _opiš, godl, _saiu_,
   {{0x600a0267,0x7bcd0295,0x44250103,0x27ed0296}},	//   лном_, kiau, _utl_, _kken_,
   {{0x25a50297,0xdb0d0279,0x224d0298,0x2d830223}},	//   _holl_, chaç, prek_, edje_,
   {{0x4ac70299,0x2169029a,0x25a5029b,0x7bcd029c}},	//   _रेलव, _били_, _koll_, diau,
   {{0x2d83029d,0x63bb029e,0x4126029f,0x2fc902a0}},	//   gdje_, lhun, _лошо_, _emag_,
   {{0x601e013a,0x27ed02a1,0x705500b5,0x628b022f}},	//   _tīma, _oken_, _انعا, _hrgo,
   {{0x7bcd00d8,0x25a500be,0x2d8302a2,0x6d410093}},	//   giau, _loll_, adje_, ólar,
   {{0xdb0f0132,0x3946010b,0x63bb02a3,0xe9da02a4}},	// [120] _alcâ, йнаг, ihun, гка_,
   {{0x645c02a5,0x25a502a6,0x0d8300c3,0x628b02a7}},	//   _årig, _noll_, _ельн, _mrgo,
   {{0x6c860082,0x27ff02a8,0x7bcd010b,0x63bb02a9}},	//   _الجم, _bhun_, biau, khun,
   {{0x27ff02aa,0x7bcd02ab,0x628b02ac,0x2bfb00e7}},	//   _chun_, ciau, _orgo, ्षणं_,
   {{0x63bb00f8,0x6b840176,0x95ca02ad,0x25a502ae}},	//   dhun, mdig, лука_, _boll_,
   {{0x6b8402af,0x27ed02b0,0x27ff01d7,0x63bb02b1}},	//   ldig, _eken_, _ehun_, ehun,
   {{0x628b01d3,0x31cd00c8,0x61e802b2,0x6d5e01ed}},	//   _argo, রকাশ, vodl, _mcpa,
   {{0x63bb02b3,0x78a101f7,0x291500c1,0xe81d02b4}},	//   ghun, _àlva, ğdaş_, _बंता_,
   {{0x1a9a02b5,0xd130004f,0x6b8402b6,0x25a502b7}},	//   ריִע, ومة_, idig, _foll_,
   {{0x361b02b8,0x25a500e9,0x2fc902b9,0x154302ba}},	//   _עובד, _goll_, _smag_, _неум,
   {{0x2ed1021a,0x63bb0079,0x61e80282,0x9f9902bb}},	//   सप्त, bhun, rodl, авну_,
   {{0x63bb02bc,0xf8b30122,0x753a02bd,0x03a30009}},	//   chun, פשר_, _hetz, _нихо,
   {{0x6b8402be,0xddc401ba,0x7bcd00c7,0x20000211}},	//   ddig, _spiš, viau, _dhii_,
   {{0x753a02bf,0x6b8402c0,0x0dc802c1,0x645c018d}},	//   _jetz, edig, буси_, _äris,
   {{0x7bcd02c2,0x2d8302c3,0x753a0110,0x2d8100be}},	//   tiau, rdje_, _metz, _vahe_,
   {{0x753a02bf,0x69dc02c4,0x6b8402c5,0xddc402c6}},	//   _letz, _ajre, gdig, _vpiš,
   {{0x7bcd01c8,0x6e3602c7,0x0dcb02c8,0x2d81018d}},	// [130] riau, _gwyb, _буни_, _tahe_,
   {{0x753a02c9,0x213e00f1,0x6b8402ca,0x7bcd010b}},	//   _netz, nath_, adig, siau,
   {{0xddc40254,0x27ff0019,0x6aad012f,0x8af000a8}},	//   _upiš, _phun_, syaf, lgəl,
   {{0x25a502c9,0x64c302cb,0x6b8400f6,0xd5b800ec}},	//   _soll_, _वेगळ, cdig, _alā_,
   {{0xb5fd02cc,0x25a502cd,0x1c1f0299,0x959902ce}},	//   _opšt, _poll_, _मंडल_, итку_,
   {{0x7afd02cf,0x3c1802d0,0x59dd02d1,0x00000000}},	//   _izst, _sčvi_, _मदिर, --,
   {{0x63bb02d2,0x25a501ae,0x27ff02d3,0x799501ae}},	//   thun, _voll_, _thun_, _inzw,
   {{0xdcfc02d4,0x753a0051,0xb22502d5,0x422502d6}},	//   ndrā, _eetz, омил, одив,
   {{0x59dd0066,0x248c02d7,0x25a502d8,0x00000000}},	//   _मदार, _erdm_, _toll_, --,
   {{0x63bb02d9,0x628b025c,0xdb1d0093,0x6b8400ae}},	//   shun, _vrgo, _umsæ, zdig,
   {{0xc95202da,0x6b8402db,0x63bb02dc,0x00e200d8}},	//   ומי_, ydig, phun, джэн,
   {{0x628b02dd,0xe3b302de,0x661b0086,0x644302df}},	//   _trgo, _عرض_, _kuuk, msni,
   {{0x614502e0,0x333f02e1,0x6443013c,0x661b00ab}},	//   _дела, maux_, lsni, _juuk,
   {{0x661b02e2,0x00000000,0x00000000,0x00000000}},	//   _muuk, --, --, --,
   {{0x8fa602e3,0x1dbb02e4,0x644302e5,0xdb0f0176}},	//   _маке, _उतरत, nsni, _alcà,
   {{0x333f0248,0x6b8402e6,0xbebb01f4,0x26360035}},	//   naux_, udig, rbër, yło_,
   {{0x49ca0200,0x37cf0033,0xba2902e7,0x00000000}},	// [140] алан_, িকার, مسلم_, --,
   {{0x644302e8,0x23b80118,0x00000000,0x00000000}},	//   ksni, _méja_, --, --,
   {{0x2d9500d8,0xdb0601f4,0x3e6400c3,0xa2cb01c0}},	//   _хрыс, _kokë, löt_, _तेस्,
   {{0x753a02c9,0xbddb02e9,0xddc400d5,0x661b02ea}},	//   _setz, nsèn, _sviň, _buuk,
   {{0x6d5c02eb,0x25e6009a,0x2b4002ec,0x667602ed}},	//   ogra, टवली_, maic_, تدار,
   {{0x27380028,0x6593005f,0xc7b900b5,0xdb0402ee}},	//   ẩn_, дашу, _elő_, rkiä,
   {{0xe73a02ef,0x2636004e,0x291802f0,0x6d5c02f1}},	//   _веб_, sło_, _igra_, igra,
   {{0x66e602f2,0x938a02f3,0x661b02f4,0x2b400037}},	//   _доба, рска_, _fuuk, naic_,
   {{0xbddb01f7,0x00000000,0x00000000,0x00000000}},	//   krèp, --, --, --,
   {{0x23b800f7,0x201a0118,0x00000000,0x00000000}},	//   _déja_, _épik_, --, --,
   {{0x213e02f5,0x6d5c02f6,0xdfd10037,0x333f00a2}},	//   rath_, dgra, فيد_, baux_,
   {{0xa2cb02cb,0x333f0248,0x442e02f7,0x645802f8}},	//   _तेव्, caux_, mpf_, muvi,
   {{0xdefb00c7,0x645802f9,0xdcfe02fa,0x229402fb}},	//   рын_, luvi, _dapč, _хиля,
   {{0x6d5c02fc,0x29180282,0xdce5013a,0xe2a902fd}},	//   ggra, _ngra_, _abhā, _دامن_,
   {{0xe0d402b5,0x5ba702fe,0x645802ff,0x602100ea}},	//   _מײַ_, ораз, nuvi, _tēma,
   {{0x6d5c0082,0xc053011d,0xdb0f0300,0x2d9e0301}},	//   agra, _חזק_, _alcá, öter_,
   {{0x2bbc0302,0x201c007c,0x6d5c02d7,0x64580303}},	// [150] _ईतरा, _huvi_, bgra, huvi,
   {{0x64430304,0x64580086,0x6d5c0305,0xbddb0176}},	//   ysni, kuvi, cgra, crèp,
   {{0x333f00f7,0xe7190037,0x7d7a00a5,0xf8b10105}},	//   yaux_, ميات_, _הנתו, رکس_,
   {{0x6c7a02b5,0x5c7a02b5,0x661b005b,0x64580306}},	//   _פארפ, _פארה, _puuk, duvi,
   {{0x333f02e1,0x7afd0029,0xcb9a0122,0x64430159}},	//   vaux_, _uzst, _הסרט, wsni,
   {{0x64430307,0x201c0279,0x3d190035,0xdb0401ef}},	//   tsni, _ouvi_, _दलों_, chiñ,
   {{0x333f0248,0x22460260,0x23b100d5,0x64580308}},	//   taux_, _avok_, _háji_, guvi,
   {{0x64430309,0x6d5c030a,0x3a39028b,0x661b030b}},	//   rsni, zgra, _kwsp_, _tuuk,
   {{0x6443030c,0x333f0248,0xd54b0088,0x224600d5}},	//   ssni, raux_, _نجام_, _cvok_,
   {{0x644301c8,0x6578027d,0x201c030d,0x332600ee}},	//   psni, cevh, _buvi_, _efox_,
   {{0x645c007c,0x333f00f7,0xc9520070,0x64580139}},	//   _ärip, paux_, עמט_, cuvi,
   {{0xbebb01f4,0xb4fa00a5,0x6d5c00e5,0x3e64030e}},	//   rcën, _הפעי, wgra, töt_,
   {{0xcaea030f,0x3fc900f8,0x00000000,0x00000000}},	//   _झुंड_, تگوی_, --, --,
   {{0xda1f0299,0x6d5c0310,0x00000000,0x00000000}},	//   _बढ़त_, ugra, --, --,
   {{0x9f920311,0xdb0601f4,0x31560070,0x2246008b}},	//   lší_, _tokë, _זיצן_, _zvok_,
   {{0x6561011e,0x9f420097,0x3a2b0312,0x00000000}},	//   _lclh, boká_, _btcp_, --,
   {{0x6e46004f,0x6d5c0313,0x9f920314,0x2b400315}},	// [160] _عندم, pgra, nší_, raic_,
   {{0x2b400316,0x00000000,0x00000000,0x00000000}},	//   saic_, --, --, --,
   {{0x9d1b0317,0x2b400318,0x00000000,0x00000000}},	//   _לויט, paic_, --, --,
   {{0xdc9b0319,0x6a86031a,0x6b5a00af,0xab65013a}},	//   _היטל, _елма, _ушор_, _ceļā,
   {{0x9f92031b,0x394100d7,0x656d0124,0x7f8d016b}},	//   jší_, bahs_, đahn, ינאַ,
   {{0x6458031c,0x8afb0122,0x9f92031d,0x00000000}},	//   tuvi, _להכי, dší_, --,
   {{0x69ce031e,0x80d000c8,0xdd570070,0x98b8023a}},	//   _imbe, _সুন্, לבסט_, _kerč_,
   {{0x6458031f,0xdb06027a,0x7d070320,0x00000000}},	//   ruvi, _pokè, léré, --,
   {{0x6b860321,0x64580322,0x201c0323,0x98b10160}},	//   _makg, suvi, _suvi_, _teză_,
   {{0x7d0700f7,0x00000000,0x00000000,0x00000000}},	//   néré, --, --, --,
   {{0x26150324,0xf99300a5,0x00000000,0x00000000}},	//   _फूटी_, גרת_, --, --,
   {{0x09b90325,0x602801c0,0x78fb02b5,0x333d0024}},	//   _इत्य, _něme, מפיו, _gewx_,
   {{0x69ce0326,0x9f4b02d7,0x9f590079,0x5f94027a}},	//   _ombe, nocé_, omsú_, хият,
   {{0x9f420187,0x127b016b,0x442c0327,0x62820328}},	//   roká_, _לאדע, _ktd_, _isoo,
   {{0x9f42024e,0x7d0700f7,0x6b860329,0x00000000}},	//   soká_, déré, _bakg, --,
   {{0x442c032a,0x69ce032b,0x00000000,0x00000000}},	//   _mtd_, _ambe, --, --,
   {{0x442c032c,0xdcf200ea,0x6b86032d,0x7d07000d}},	// [170] _ltd_, īgāk, _dakg, féré,
   {{0xceb202b5,0x6e2d032e,0x64480124,0x7d0700a2}},	//   _סיי_, _itab, _ovdi, géré,
   {{0xd7fb032f,0xa3be0035,0xf1b30070,0x442c00cc}},	//   буд_, ीफा_, עסע_, _ntd_,
   {{0x69ce0330,0x256f00d0,0x62820331,0x68f50097}},	//   _embe, zılı_, _osoo, _vyzd,
   {{0xd2460332,0x442c0333,0x644802c6,0x256f01d6}},	//   _جن_, _atd_, _avdi, yılı_,
   {{0xcb120052,0x79e7006c,0x9f920334,0x68f500a0}},	//   _שלך_, _روزہ_, vší_, _tyzd,
   {{0x62820335,0xa5060336,0x442c0337,0x24090338}},	//   _asoo, меша_, _ctd_, онки_,
   {{0x442c01e0,0x9f9201c0,0xc2e60083,0x6e2d001c}},	//   _dtd_, tší_, খেছি_, _otab,
   {{0x6e2d0232,0x2a690339,0xd76600b5,0x67290069}},	//   _ntab, ntab_, _تنقی, _ifej,
   {{0x9f92033a,0xab5b033b,0x442c033c,0x00000000}},	//   rší_, _flüg, _ftd_, --,
   {{0xd3710082,0x6e2d033d,0x256f033e,0x6282018e}},	//   _لها_, _atab, rılı_, _esoo,
   {{0x2a69033f,0x9f92033a,0x67290024,0x7987021e}},	//   ktab_, pší_, _jfej, _lajw,
   {{0x6e2d009e,0xee370340,0xc61f0033,0x63ab0341}},	//   _ctab, мня_, নীরা_, _iogn,
   {{0x7987006a,0x6e2d0037,0x6b860342,0x63ab0343}},	//   _najw, _dtab, _sakg, _hogn,
   {{0x6e2d0344,0x98ba013a,0x2c8700b8,0x6b860345}},	//   _etab, kapā_, vídá_, _pakg,
   {{0xeb970346,0x67290024,0x31b20160,0x00000000}},	//   мис_, _nfej, _râzi_, --,
   {{0x63ab0347,0xf1e100b4,0x63a6022a,0x7d070348}},	// [180] _mogn, _पदान, ökni, téré,
   {{0x63ab0349,0x00000000,0x00000000,0x00000000}},	//   _logn, --, --, --,
   {{0x7649000d,0x2d9a0183,0x98b8034a,0xe786034b}},	//   _avey, _inpe_, _terč_, дуло,
   {{0x2a69034c,0xb7be0033,0x442c034d,0x63ab0298}},	//   btab_, েক্ট, _rtd_, _nogn,
   {{0x4cd300c8,0x442c034e,0x7d07000d,0x473301e0}},	//   _দুপু, _std_, péré, тніс,
   {{0x69ce034f,0x63ab009e,0x00000000,0x00000000}},	//   _umbe, _aogn, --, --,
   {{0x63ab0350,0x76490107,0xb8f30033,0x442c021d}},	//   _bogn, _evey, _হু_, _qtd_,
   {{0x63ab0351,0x00000000,0x00000000,0x00000000}},	//   _cogn, --, --, --,
   {{0x9f550093,0x05660352,0x63ab0353,0xe7bd0354}},	//   ófíl_, _ован, _dogn, ्फरप,
   {{0x26c602d7,0x60280355,0xea9b016b,0x00000000}},	//   mzoo_, _němc, קסיש, --,
   {{0x39570052,0x63ab0356,0x195700a5,0x2c1a021a}},	//   ושים_, _fogn, וביל_, _मंगू_,
   {{0xe29a01c8,0x62820189,0x26c6006d,0x63ab0036}},	//   _мае_, _tsoo, ozoo_, _gogn,
   {{0xdde20124,0x25ac00fe,0x00000000,0x00000000}},	//   _šušk, _kodl_, --, --,
   {{0xe0cf0357,0x63ab0358,0x00000000,0x00000000}},	//   ازی_, _zogn, --, --,
   {{0xdb06006c,0x79870260,0x00000000,0x00000000}},	//   _elkü, _rajw, --, --,
   {{0x3eae0031,0x2d9a0359,0x2cac01ff,0x6e2d018e}},	//   ëjtë_, _enpe_, ädda_, _ttab,
   {{0x6e2d035a,0x26c601e8,0x27ef035b,0xdd95010b}},	// [190] _utab, jzoo_, vogn_, _запы,
   {{0x2a69035c,0x00000000,0x00000000,0x00000000}},	//   rtab_, --, --, --,
   {{0x2a690006,0x22510035,0x917b00e2,0x00000000}},	//   stab_, ązki_, _hệ_, --,
   {{0x2a690359,0x25ac0176,0xaad0035d,0x00000000}},	//   ptab_, _aodl_, _सेवक, --,
   {{0xcb36035e,0x7987035f,0x1fc10083,0x63ab0360}},	//   _ראשי_, _tajw, _উদাস, _rogn,
   {{0x63ab0361,0xd7c900e0,0x65940362,0x00000000}},	//   _sogn, _کوره_, качу, --,
   {{0x63ab0363,0x00000000,0x00000000,0x00000000}},	//   _pogn, --, --, --,
   {{0x26c601e8,0x00000000,0x00000000,0x00000000}},	//   bzoo_, --, --, --,
   {{0xd24e017e,0x645c0364,0x63ab01b4,0x7bdf00f6}},	//   مني_, _årin, _vogn, inqu,
   {{0x63ab0051,0xe5070365,0x00000000,0x00000000}},	//   _wogn, _قباي, --, --,
   {{0x67240366,0x63ab0367,0xe0d600af,0x00000000}},	//   žije, _togn, евэ_, --,
   {{0x8fa60368,0xd9cc0253,0x93bc0160,0x00000000}},	//   хаме, _ाष्ट, _stăv, --,
   {{0xe2990369,0xf1a801cb,0x00000000,0x00000000}},	//   _хал_, سایه_, --, --,
   {{0x92c1036a,0xdd92036b,0xc0e5036c,0x7bdf036d}},	//   ığın, دوس_, _полк, enqu,
   {{0xfce3036e,0xddcd002d,0x61e600b5,0xeb9a036f}},	//   горо, _spaţ, ékle, пив_,
   {{0xa2d40302,0x7a160260,0x00000000,0x00000000}},	//   _बेड्, _pņto, --, --,
   {{0xf41202b5,0xdbdd008d,0x39560370,0x6e930037}},	// [1a0] רפן_, ráðs, ењет, _مليا,
   {{0xac860370,0x6f040371,0x26c6006d,0xdcfe00af}},	//   _згол, _izic, vzoo_, _capă,
   {{0xc17200a5,0xa81a0372,0x2fc001ed,0x68e700f6}},	//   רחב_, ستار_, _klig_, _cxjd,
   {{0xfaa60373,0xe6660374,0x00000000,0x00000000}},	//   _замо, етко, --, --,
   {{0x98ac0095,0x7bd600e0,0x25ac0375,0x00000000}},	//   ğlıq_, miyu, _podl_, --,
   {{0xe5a30376,0x98ac0095,0x7bd60088,0x2fc00176}},	//   личи, şlıq_, liyu, _llig_,
   {{0x26c6006d,0x6c7a016b,0x00000000,0x00000000}},	//   szoo_, לאַפ, --, --,
   {{0x7bd60371,0x00000000,0x00000000,0x00000000}},	//   niyu, --, --, --,
   {{0x66e30377,0x6f040371,0x00000000,0x00000000}},	//   _бота, _nzic, --, --,
   {{0xb5ca0332,0xbbad0378,0x64a60379,0xef1f037a}},	//   _عوام_, _टक्क, _паза, rdüm_,
   {{0xdb12008a,0x9f35004b,0x6f04037b,0x3f890176}},	//   _ágæt, кені, _azic, _paau_,
   {{0x09dd01d1,0x00000000,0x00000000,0x00000000}},	//   _मद्य, --, --, --,
   {{0x661a037c,0x644a037d,0xddcd004b,0x2c1a021a}},	//   _kitk, lsfi, _apaš, _मंजू_,
   {{0x9f4b01c0,0x661a037e,0x443e0088,0x2fc0008c}},	//   mocí_, _jitk, _kwt_, _elig_,
   {{0x661a037f,0xf1a90088,0xb3a40380,0x6f040381}},	//   _mitk, _تانه_, _खचाख, _ezic,
   {{0x7bdf0382,0x7bc40383,0x7b6400af,0xd138010b}},	//   unqu, ghiu, лтуе, lbą_,
   {{0x66d3006c,0x9f4b00de,0x6d5a0079,0x5b150384}},	// [1b0] _műkö, nocí_, ótac, тмат,
   {{0x661a0385,0xd8e70044,0x317e033b,0x00000000}},	//   _nitk, нцеп, netz_, --,
   {{0x20090028,0x6d470386,0xa3c00387,0x201b00a2}},	//   _khai_, maja, ँसा_, _épis_,
   {{0x6d470388,0x2009006d,0x7bc40389,0x661a009e}},	//   laja, _jhai_, chiu, _aitk,
   {{0x661a038a,0x6b9d02c9,0x6b8d038b,0x644a01ef}},	//   _bitk, _insg, mdag, esfi,
   {{0xb90700c8,0x6d47038c,0x6b8d038d,0x661a00ec}},	//   _পর_, naja, ldag, _citk,
   {{0xab5b02c9,0x644a038e,0x80d00033,0x443e038f}},	//   _glüc, gsfi, _সুস্, _cwt_,
   {{0xe2990390,0x69d70391,0x6d4702c6,0x443e0298}},	//   даи_, lixe, haja, _dwt_,
   {{0xdb0f0392,0x661a0393,0x443e00d5,0x64580328}},	//   _alcú, _fitk, _ewt_, arvi,
   {{0x6d470394,0x27fd00e9,0x2fc0009e,0x93bc0395}},	//   jaja, llwn_, _slig_, _stăt,
   {{0x2fc001a9,0x6d470396,0xf9920397,0x6b8d0398}},	//   _plig_, daja, ברי_, kdag,
   {{0x20090399,0x6b8d02a2,0x69d701b7,0x00000000}},	//   _chai_, jdag, hixe, --,
   {{0x63a9039a,0x93b60052,0x6b8d039b,0xddcd0254}},	//   mjen, _שלנו_, ddag, _spaš,
   {{0x63a9039c,0x6d47039d,0x7bd60010,0xfce6039e}},	//   ljen, gaja, wiyu, вого,
   {{0xdc670369,0x69d7039f,0x22510035,0x7bd60371}},	//   кард_, dixe, ązku_, tiyu,
   {{0x63a903a0,0x63bb03a1,0x6b8d03a2,0xa00a0037}},	//   njen, nkun, gdag, _تقبل_,
   {{0x6d470083,0x4b2300d4,0x63bb03a3,0x6f0403a4}},	// [1c0] baja, рмув, ikun, _uzic,
   {{0x6d4703a5,0x63a903a6,0x91d40084,0x765900e9}},	//   caja, hjen, योपै, drwy,
   {{0x63bb03a7,0x661a03a8,0x63a903a9,0x00000000}},	//   kkun, _ritk, kjen, --,
   {{0x6e240054,0x661a03aa,0x63bb03ab,0xe73a0009}},	//   _kuib, _sitk, jkun, фед_,
   {{0x63a903ac,0x661a03ad,0x76590297,0x63bb03ae}},	//   djen, _pitk, grwy, dkun,
   {{0x69c503af,0x645803b0,0xd49a03b1,0x9866006c}},	//   chhe, trvi, дри_, _لیئے_,
   {{0x18a303b2,0x98a30369,0x2cb8009e,0x63bb03b3}},	//   _карм, _кире, nyrd_, fkun,
   {{0x63a903b4,0x63bb03b5,0x61e103b6,0x6d4703b7}},	//   gjen, gkun, enll, zaja,
   {{0xfbd30052,0x20090297,0x661a03b8,0x6d47002f}},	//   יתה_, _rhai_, _titk, yaja,
   {{0xa3f5000c,0x661a0136,0x6b8d00fd,0x200903b9}},	//   ější_, _uitk, zdag, _shai_,
   {{0x6d4703ba,0x63a903bb,0xd13800d8,0x6b8d03bc}},	//   vaja, bjen, rbą_, ydag,
   {{0x63a903bd,0x317e01ae,0x63bb02c9,0x225f03be}},	//   cjen, setz_, ckun, buuk_,
   {{0x6d4703bf,0x6e2403c0,0x6b8d03c1,0x00000000}},	//   taja, _cuib, vdag, --,
   {{0x6e24006b,0x69d703c2,0xbf9b0345,0x00000000}},	//   _duib, xixe, dlêe, --,
   {{0x6d4703c3,0x6b8d03c4,0x80a303c5,0x4fc703c6}},	//   raja, tdag, _نمون, _аспа,
   {{0x5f7703c7,0x6d4703c8,0x20090054,0x8bc4004b}},	//   _شاعر, saja, _uhai_, асуд,
   {{0x6d4703c9,0xf96b03ca,0x2a6000d7,0x6e2400f6}},	// [1d0] paja, дрей_, guib_, _guib,
   {{0x63bb03cb,0x6b8d03cc,0x63a9035f,0x68fc03cd}},	//   zkun, sdag, zjen, _byrd,
   {{0x3eb903ce,0x63bb0282,0x69d703cf,0xa2d4035d}},	//   lyst_, ykun, rixe, _बेस्,
   {{0x7659001e,0x69c50031,0xe115016b,0x321c03d0}},	//   trwy, shhe, אַנז_, _livy_,
   {{0x6d4503d1,0x63a903d2,0xe78403d3,0x61e100e9}},	//   _keha, vjen, рухо, ynll,
   {{0xa93403d4,0x6d4503d5,0xa50903d6,0xe61801e0}},	//   _верш, _jeha, нела_, вді_,
   {{0x7afd03d7,0x63a903d8,0x63bb03d9,0x765900e9}},	//   _hyst, tjen, tkun, srwy,
   {{0x7c2503da,0x6d45026b,0x7afd03db,0x93bc00af}},	//   _muhr, _leha, _kyst, _stăr,
   {{0x63a903dc,0x63bb03dd,0x59b703de,0x7afd008c}},	//   rjen, rkun, _आकार, _jyst,
   {{0x63bb03df,0x004700b5,0x6d4503e0,0x63a903e1}},	//   skun, نیتي_, _neha, sjen,
   {{0x1c1f03e2,0x63a903e3,0x7afd03e4,0x046703e5}},	//   _मंगल_, pjen, _lyst, _штам,
   {{0xdb0f03e6,0x44250043,0xc43a02b8,0xdb0603e7}},	//   _você, _iul_, _נתני, _ilkö,
   {{0x442503e8,0x6d4503e9,0x7afd03ea,0x69d50120}},	//   _hul_, _beha, _nyst, _omze,
   {{0x442503eb,0x614503e6,0x4ed501e0,0x425203ec}},	//   _kul_, _сека, рюют, _انور,
   {{0x442503ed,0x30790070,0x00000000,0x00000000}},	//   _jul_, _טאַנ, --, --,
   {{0x7afd03ee,0x44250006,0x69d50160,0x7dd40095}},	//   _byst, _mul_, _amze, _müsə,
   {{0x7afd03ef,0xdcfc024e,0x442503f0,0x6fc601ef}},	// [1e0] _cyst, merč, _lul_, _cóce,
   {{0x6d4502c0,0x7afd03f1,0x3f8203f2,0x442503f3}},	//   _geha, _dyst, leku_, _oul_,
   {{0xdb06024e,0x7afd03f4,0x31ba02b5,0xdcf800b5}},	//   _doká, _eyst, עזענ, _شہرت_,
   {{0x6d450291,0x224d01d6,0x46ea03f5,0x3f8203f6}},	//   _zeha, ksek_, нден_, neku_,
   {{0x7f3b02b5,0x7c25028b,0x7afd00e9,0x68fc00e9}},	//   גענו, _zuhr, _gyst, _wyrd,
   {{0x442503f7,0x659403f8,0x3861012f,0xd5b10019}},	//   _bul_, раку, buhr_, _có_,
   {{0x442503f9,0xd46703fa,0xe56f03fb,0x888403fc}},	//   _cul_, гије_, سطو_, _خیان,
   {{0x44250082,0x3f8203fd,0x539803fe,0x93b4002d}},	//   _dul_, jeku_, твия_, рбиц,
   {{0x798e03ff,0xbebb0031,0x6441003c,0x44250400}},	//   _kabw, ncët, _ewli, _eul_,
   {{0x44250401,0x60210029,0xc05a0402,0xdb0f0310}},	//   _ful_, _lēmu, нім_, _docè,
   {{0x44250403,0x798e0404,0x09f700a5,0xdfd10405}},	//   _gul_, _mabw, רמים_, قيد_,
   {{0x6d450406,0x7c25033b,0xddc40024,0x98b8010b}},	//   _seha, _ruhr, _epiż, _gerą_,
   {{0x44250407,0x6d45011c,0x7c250408,0xb5fd0409}},	//   _zul_, _peha, _suhr, _apšy,
   {{0xbb1b0248,0x798e018c,0x7afd040a,0xeb9f01e0}},	//   _maît, _nabw, _ryst, _snø_,
   {{0x6d450060,0x3ebf040b,0x3f82040c,0x48bf0033}},	//   _veha, šut_, beku_, _আশ্র,
   {{0xc4c4040d,0x7afd0086,0x246e0095,0x798e0103}},	//   _ہے_, _pyst, _cəmi_, _aabw,
   {{0x6d45007c,0x2d85000d,0x798e018c,0xdb0600ac}},	// [1f0] _teha, ôles_, _babw, _poká,
   {{0x7afd040e,0xdcf500ea,0x00000000,0x00000000}},	//   _vyst, udzē, --, --,
   {{0x7afd006a,0x2d830232,0xdb06040f,0xd7c800f8}},	//   _wyst, meje_, _voká, گونه_,
   {{0x2d830410,0x31e100a1,0x7afd0411,0xe719004f}},	//   leje_, _पद्ध, _tyst, نيات_,
   {{0x44250412,0xd7c80413,0x98aa00ea,0xa2d400df}},	//   _sul_, دونه_, ējām_, _बेल्,
   {{0x44250095,0x2d830414,0x2d910415,0xf4830416}},	//   _pul_, neje_, ndze_, ماعی,
   {{0x44250417,0x00000000,0x00000000,0x00000000}},	//   _qul_, --, --, --,
   {{0x44250244,0xdb1d0093,0xbb1b000d,0x2d830418}},	//   _vul_, _umsó, _faît, heje_,
   {{0x6b8f0419,0x3f82041a,0x290c004f,0x798e041b}},	//   _macg, veku_, _údar_, _yabw,
   {{0x2d83041c,0x4425041d,0x224d041e,0x41b502fb}},	//   jeje_, _tul_, rsek_, рсит,
   {{0x3f8202f6,0x2d83041f,0x66ca00b5,0x224d0420}},	//   teku_, deje_, _töké, ssek_,
   {{0xe0d602fb,0x52d90421,0x00000000,0x00000000}},	//   рвю_, _имею_, --, --,
   {{0x2bc900be,0x00000000,0x00000000,0x00000000}},	//   रसना, --, --, --,
   {{0x628b0090,0x3f820422,0x6cc6005f,0x2d8301d5}},	//   _isgo, seku_, айга, geje_,
   {{0x8c460268,0xdd0e027d,0x3f820207,0x93bc0139}},	//   ребе, _dışa, peku_, _ouăl,
   {{0xc0520122,0x798e0008,0xb7b00033,0x00000000}},	//   _וזה_, _sabw, _কষ্ট, --,
   {{0xeab70423,0x09c10083,0x39460424,0x2d830425}},	// [200] айт_, োচনা, инаг, beje_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca60426,0x798e0103,0xc8ca0427,0xdb0401ed}},	//   _тани, _vabw, خوان_, rkiñ,
   {{0x628b00e9,0x798e0428,0x00000000,0x00000000}},	//   _osgo, _wabw, --, --,
   {{0xb8fd0429,0x23a902e4,0x6724042a,0x6b840093}},	//   _ते_, कानद, žijo, meig,
   {{0x6b84042b,0xb866042c,0x00000000,0x00000000}},	//   leig, _پاسو, --, --,
   {{0x26c0042d,0x92e200c8,0x292701ba,0x628b0176}},	//   šio_, _ধরে_, ávať_, _asgo,
   {{0x6b84042e,0x0fc10083,0x290a042f,0x87f900af}},	//   neig, _উদ্ধ, _izba_, _бэут_,
   {{0xa3c70299,0x27e60430,0xc1a60431,0xe61a0432}},	//   _उतर_, mnon_, ајни, _ада_,
   {{0xda160433,0xddd6005f,0x629900e5,0x00000000}},	//   थगित_, _asyž, _drwo, --,
   {{0x628b0434,0xc953011d,0x2d830435,0x5f9500af}},	//   _esgo, חמת_, veje_, бинт,
   {{0x27e60436,0xa3d20437,0x78a1008d,0x00000000}},	//   nnon_, होश_, _álve, --,
   {{0x63a20438,0x91e60439,0x2d83043a,0x5f940133}},	//   _inon, _коде, teje_, цият,
   {{0x7bc603ad,0xa3d2043b,0x63a201ba,0xdcfe00ee}},	//   _alku, होर_, _hnon, _dopľ,
   {{0x2d83043c,0xf2e80033,0x705400b2,0x63a20107}},	//   reje_, _পরিণ, _انبا, _knon,
   {{0x628b02c7,0xe45702b5,0x248c012f,0x2ba403e6}},	//   _ysgo, יילט_, _msdm_, ојув,
   {{0x27e6043d,0x2905043e,0x2d8300d5,0x2b1a021a}},	// [210] dnon_, _šla_, peje_, _मृदु_,
   {{0x3947043f,0x780f0440,0x2d830031,0x00000000}},	//   úns_, िष्क_, qeje_, --,
   {{0x6b8400ea,0x63a20441,0x6d5700a8,0xbef8042c}},	//   beig, _onon, _idxa, _مریض_,
   {{0x27e60442,0x20140443,0xdc9a0070,0x7d0800be}},	//   gnon_, _èxit_, _עירל, üdse,
   {{0xc9870043,0xb7bd0160,0x00000000,0x00000000}},	//   _куви, _niţe, --, --,
   {{0x63a20444,0x7c94042c,0x6833009f,0xdcfe00b8}},	//   _anon, _اشیا, _aħde, _napě,
   {{0x057400d1,0x27e6011e,0x97a70265,0x79850159}},	//   تاند, bnon_, _крал, mehw,
   {{0xab5b00ab,0xdcfc00ea,0xc24501e0,0x69c700cd}},	//   _olüm, nerā, бник, _hlje,
   {{0xe730006c,0x77050118,0xe1f90445,0xdd2c00d8}},	//   _آصف_, _اژان, лги_, vėži,
   {{0x6b840446,0x63a20447,0x7dc200ee,0x00000000}},	//   zeig, _enon, _rôso, --,
   {{0x69c7003a,0xf076006c,0x7dc201ba,0xab5b0448}},	//   _mlje, میوں_, _dôsl, _alüm,
   {{0x7dc2016f,0x6d5701dd,0x63a200ee,0x9f420097}},	//   _pôso, _adxa, _gnon, boký_,
   {{0x6fc60037,0x69c70449,0xdcfc00ea,0x6b84003e}},	//   _cóca, _olje, derā, veig,
   {{0x6b84044a,0xb6da0070,0x6feb0067,0xa2c4021a}},	//   weig, אַלט, ręca, िनर्,
   {{0x6b84044b,0x7d090355,0x27e6044c,0xacea01fd}},	//   teig, řesn, ynon_, умва_,
   {{0xdcfe00a0,0x6fc60079,0x00000000,0x00000000}},	//   _topľ, _fóca, --, --,
   {{0x69c7044d,0x6b84044e,0x7f3b0070,0x27e60124}},	// [220] _blje, reig, _געפו, vnon_,
   {{0x6b84044f,0x5d86004f,0x3f920118,0x7e660450}},	//   seig, _الدل, _hayu_, mukp,
   {{0x6d4e0451,0x3f920452,0x6fc60453,0x291c0454}},	//   maba, _kayu_, _zóca, äva_,
   {{0x6d4e0455,0x7bc6023a,0x00000000,0x00000000}},	//   laba, _ulku, --, --,
   {{0x3f92030d,0xa3ab0456,0x7e660159,0xdd070457}},	//   _mayu_, खान_, nukp, _köşk,
   {{0x6d4e0458,0x225f0459,0x27e6045a,0x3f92045b}},	//   naba, druk_, snon_, _layu_,
   {{0x2bbf045c,0x69de045d,0xef1f045e,0x6d4e0042}},	//   _एकमा, mipe, ndür_, iaba,
   {{0x69de045f,0x6d4e0460,0xa8570122,0xa3d20461}},	//   lipe, haba, _לילה_, हों_,
   {{0x6d4e0462,0x7dcb0463,0xaade00a1,0xe64303e6}},	//   kaba, _hüse, _नेमक, _нетп,
   {{0x6d4e0464,0x8c000083,0x69de0465,0x9f420187}},	//   jaba, ্দিন_, nipe, roký_,
   {{0x64a30466,0x6d4e0467,0x9f420187,0x672d0121}},	//   _нафа, daba, soký_, žaje,
   {{0x69de002d,0x63a20468,0x225f0469,0x443c01ef}},	//   hipe, _unon, bruk_, mpv_,
   {{0x3f92046a,0x394a046b,0x2bbf046c,0x06bc0033}},	//   _dayu_, _oebs_, _एकबा, _আইডি,
   {{0x6d4e046d,0x7de703d0,0x30a6046e,0xea010023}},	//   gaba, сімд, _грив, _đắp_,
   {{0x61fa0176,0x69de046f,0x2a6000ab,0x6ae1022e}},	//   motl, dipe, erib_, पप्र,
   {{0x69c70470,0x61fa0471,0xa3ab00ab,0x6fc6002a}},	//   _slje, lotl, खाय_, _tóca,
   {{0x6d4e0472,0x69c70254,0x8d8700af,0x59d900d8}},	// [230] baba, _plje, _лунд, адаў_,
   {{0x6d4e0473,0x61fa0474,0x6f0d0475,0x7f4f027a}},	//   caba, notl, _izac, lacq,
   {{0x2fc90476,0x61e80477,0x69c70478,0x6d41027b}},	//   _klag_, indl, _vlje, ılad,
   {{0x1da7009a,0x61fa0479,0x7f4f0036,0x2d9301ed}},	//   खावत, hotl, nacq, _haxe_,
   {{0x7bdf047a,0x7bcd047b,0x61fa03e0,0x00000000}},	//   miqu, mhau, kotl, --,
   {{0x7bdf047c,0x69c7047d,0x69de047e,0x61e80009}},	//   liqu, _ulje, cipe, jndl,
   {{0xddcc00d8,0x99650355,0x00000000,0x00000000}},	//   _žiūr, _kůži_, --, --,
   {{0x7bdf047f,0xe3b90480,0x6d4e0481,0x7bcd0482}},	//   niqu, рби_, zaba, nhau,
   {{0x6603016f,0x6d4e0483,0x27ff0484,0x7dcb00a8}},	//   plnk, yaba, _ikun_, _müsb,
   {{0x6d4e0485,0x2fc90486,0x7bdf00f7,0x3f920487}},	//   xaba, _alag_, hiqu, _sayu_,
   {{0x2fc90488,0x6d4e0489,0x3f92048a,0xe10900af}},	//   _blag_, vaba, _payu_, ренд_,
   {{0x6d4e048b,0x27ff048c,0x69de048d,0x225f01cb}},	//   waba, _jkun_, zipe, pruk_,
   {{0x7bdf048e,0x61fa048f,0xf8a60099,0x2d930490}},	//   diqu, botl, _गप्प, _baxe_,
   {{0x61fa01da,0xdb0f01ef,0x3f920118,0x27ed0207}},	//   cotl, _cocí, _wayu_, _ljen_,
   {{0x6d4e0491,0x7bdf0492,0x2b4b00d7,0xcfaa0493}},	//   raba, fiqu, _becc_, _ناظم_,
   {{0x6d4e0494,0x7bdf0495,0x27ed0496,0x6d41003e}},	//   saba, giqu, _njen_, ðlar,
   {{0xe9da0497,0x6d4e0498,0xed5a0499,0x2d93049a}},	// [240] ака_, paba, _коп_, _faxe_,
   {{0x6d4e013b,0x27ff049b,0x27ed0118,0x84e9049c}},	//   qaba, _akun_, _ajen_, टपाट_,
   {{0x088a00af,0x7bcd049d,0x69de049e,0xe8f7049f}},	//   рбей_, bhau, ripe, олф_,
   {{0x394a04a0,0xeb9a04a1,0x7bcd04a2,0x290301f4}},	//   _webs_, _тим_, chau, _dyja_,
   {{0x61fa0381,0x363304a3,0x2bbf00b8,0x00000000}},	//   yotl, وروس, _एकता, --,
   {{0x69de01d2,0x27ed04a4,0x3a230051,0xfc4b0355}},	//   qipe, _ejen_, _gijp_, říž_,
   {{0x69dc004f,0xab5b02b1,0x60280355,0x4ade00ab}},	//   _imre, _blüh, _těmi, _नेतव,
   {{0x78a104a5,0xa3ba004f,0x6b9604a6,0x27ed04a7}},	//   _álva, شاعر_, ndyg, _gjen_,
   {{0xa3db030f,0x61fa04a8,0x6f0404a9,0xaabc04aa}},	//   _डगर_, totl, _nyic, ोनिक,
   {{0x61e801ae,0x00000000,0x00000000,0x00000000}},	//   undl, --, --, --,
   {{0xeb070299,0x2fc904ab,0xdb0f04ac,0x399b0070}},	//   _शर्त_, _plag_, _rocí, בייד,
   {{0x932500bf,0x32050122,0x7bdf0248,0xea010019}},	//   _فرهن, ally_, xiqu, _đập_,
   {{0x7bcd04ad,0x7bdf04ae,0x6b96001e,0x69dc04af}},	//   vhau, viqu, ddyg, _omre,
   {{0x442c0478,0x72e902b5,0x7f4f0036,0x20000103}},	//   _kud_, _פֿײַ, sacq, _ekii_,
   {{0x7bdf04b0,0x442c002d,0x7bcd04b1,0x3a230223}},	//   tiqu, _jud_, thau, _rijp_,
   {{0x5a3504b2,0x69dc04b3,0x3ea60009,0x7bcd04b4}},	//   знат, _amre, _šote_, uhau,
   {{0x7bdf04b5,0x7bcd04b6,0x442c04b7,0x2d9304b8}},	// [250] riqu, rhau, _lud_, _taxe_,
   {{0x7bdf04b9,0x7bcd04ba,0x442c0136,0x6833007a}},	//   siqu, shau, _oud_, _aħda,
   {{0x6e2d01e8,0x7bdf04bb,0x20ca04bc,0x442c04bd}},	//   _huab, piqu, ानिध, _nud_,
   {{0x6e2d04be,0x69dc0225,0x62820118,0x00000000}},	//   _kuab, _emre, _opoo, --,
   {{0x27ed00da,0xf7700180,0xd6db04bf,0x442c04c0}},	//   _vjen_, ضان_, јте_, _aud_,
   {{0x442c04c1,0x6e2d04c2,0x20ca04aa,0xdcf50228}},	//   _bud_, _muab, ानाध, jdzī,
   {{0x27ff048c,0xddcd04c3,0xd838004b,0xc44700b5}},	//   _tkun_, _opaž, _мэт_, زیشن_,
   {{0x442c04c4,0x69c504c5,0x6fc601ef,0x799504c6}},	//   _dud_, lkhe, _cócl, _hazw,
   {{0x79950371,0x644804c7,0x442c04c8,0x67290371}},	//   _kazw, _ewdi, _eud_, _igej,
   {{0x442c004f,0x69c504c9,0xdb0601ba,0x5bb80266}},	//   _fud_, nkhe, _pokú, _इक्व,
   {{0x442c04ca,0x2a690189,0x6e2d009e,0x7bc4010b}},	//   _gud_, huab_, _auab, ykiu,
   {{0x7649018e,0x60330139,0x6e2d026e,0x00000000}},	//   _kwey, _căma, _buab, --,
   {{0x6e2d04cb,0x46bd04cc,0xd1bb04cd,0x6729034d}},	//   _cuab, ्निह, _پاشا_, _mgej,
   {{0x7995006a,0x69c504ce,0x6e2d022e,0x442c011e}},	//   _nazw, jkhe, _duab, _yud_,
   {{0x61e104cf,0xdca300ca,0x7649001c,0xc18300fd}},	//   mill, нари, _lwey, _فیکٹ,
   {{0x61e104d0,0x69dc04d1,0x672900f8,0x60d600a5}},	//   lill, _smre, _ngej, _מוצא_,
   {{0x61e104d2,0x3c1900d8,0x49ca02c4,0x27fd04d3}},	// [260] oill, іўся_, блан_, down_,
   {{0x6d4104d4,0x63b90069,0xa96a0037,0x61e104d5}},	//   ılac, _lown, إمام_, nill,
   {{0x7649034d,0x799502b1,0x2d8a0176,0x00000000}},	//   _awey, _dazw, mebe_, --,
   {{0x442c04d6,0x3ea00009,0x2d9804d7,0x764901a8}},	//   _rud_, _krit_, ldre_, _bwey,
   {{0x61e104d8,0xc6150083,0x2a690221,0x659404d9}},	//   kill, াদনা_, cuab_, далу,
   {{0x2d9804da,0x61e104db,0x67290009,0x442c04dc}},	//   ndre_, jill, _egej, _pud_,
   {{0x628204dd,0xf74604de,0xb4c6000c,0x7c2604df}},	//   _spoo, _нево, उने_, _kikr,
   {{0x7dcb01c2,0x9f590248,0x442c04e0,0x2d8a04e1}},	//   _müsa, posé_, _vud_, hebe_,
   {{0x63b904e2,0x61e104e3,0xe3af0037,0xf1aa0286}},	//   _down, fill, ارى_, ماده_,
   {{0x442c04e4,0xa63b011d,0x2d8a0124,0xdcf500ea}},	//   _tud_, _לגמר, jebe_, udzī,
   {{0xdcf50080,0x442c04e5,0x03260217,0x60330160}},	//   rdzī, _uud_, _еден, _păma,
   {{0x61e104e6,0x7c260069,0x00000000,0x00000000}},	//   aill, _nikr, --, --,
   {{0x71a604e7,0x1ee704e8,0x539b00a5,0x23a904e9}},	//   _надз, سوسی_, _ליאו, कारद,
   {{0x61e104ea,0x57b904eb,0x442604ec,0x3ea004ed}},	//   cill, _आव्ह, _hio_, _drit_,
   {{0x3ea004ee,0x48dc04ef,0x7c2604f0,0x717b00a5}},	//   _erit_, _गेलो_, _bikr, _הנוס,
   {{0xcf27004f,0x2d980382,0x6e2d04f1,0x3ea004f2}},	//   _عربي, adre_, _tuab, _frit_,
   {{0x442604f3,0x3ea004f4,0x2d8a04f5,0x7c2604f6}},	// [270] _mio_, _grit_, bebe_, _dikr,
   {{0x2d8a03e6,0xfbd000b5,0x6ff200ec,0x764904f7}},	//   cebe_, پتہ_, māca, _rwey,
   {{0x7c2604f8,0x2a69006f,0x2d810211,0x00000000}},	//   _fikr, suab_, _ibhe_, --,
   {{0x61e104f9,0x442604fa,0xc794010b,0x7c2604fb}},	//   zill, _nio_, ершы, _gikr,
   {{0x63b904fc,0x920c0324,0x61e104fd,0xcb9a00a5}},	//   _rown, हताज_, yill, _וסרט,
   {{0xd1260082,0x7c2604fe,0x06f400f8,0x601f04ff}},	//   _لم_, _zikr, رسنج, _dūmi,
   {{0x44260500,0xdb0602d0,0x6fc60079,0x3f8b0501}},	//   _bio_, _ankè, _sócm, kecu_,
   {{0x44260502,0x3f8b022f,0x2d8a0503,0x291102a7}},	//   _cio_, jecu_, zebe_, _izza_,
   {{0x61e10504,0x44260505,0x24890168,0x3f8b0506}},	//   till, _dio_, ňam_, decu_,
   {{0x61e10507,0x3ea00031,0x629b010b,0x7dd00508}},	//   uill, _rrit_, rvuo, _käse,
   {{0x61e10509,0x7dd003ad,0x4426050a,0x63b9050b}},	//   rill, _jäse, _fio_, _town,
   {{0x61e1050c,0x4426050d,0x60c1008c,0xdee6050e}},	//   sill, _gio_, rylm, доми,
   {{0x7dd0013c,0x2d8a050f,0x6fc601dd,0x9f420055}},	//   _läse, tebe_, _hóck, likë_,
   {{0x61e10510,0x44260511,0x7c260512,0xb4f90070}},	//   qill, _zio_, _sikr, ַפּי,
   {{0x2d980513,0x3b960370,0x2d8a0010,0x44260260}},	//   rdre_, мјат, rebe_, _yio_,
   {{0x6ff60514,0xea010019,0x2d8a0515,0x7dcb013b}},	//   _تستط, _đạp_, sebe_, _vüsa,
   {{0x7c2602d0,0x3b0701d3,0x29110516,0xfbdf0517}},	// [280] _vikr, дето_, _azza_, _नगरम,
   {{0x7c26022e,0xc9860037,0x00000000,0x00000000}},	//   _wikr, بشري, --, --,
   {{0x8cb50518,0x7c2601c8,0xdb0f0519,0x19b9051a}},	//   _उपयो, _tikr, _vocá, чуть_,
   {{0x6aa90009,0x672d011c,0xb0b60070,0xf0b6016b}},	//   _šefe, žajn, ופעס_, ולער_,
   {{0x4426051b,0xdb0f0138,0x2911030d,0x12e80033}},	//   _rio_, _tocá, _ezza_, _পর্দ,
   {{0x4426000e,0xe5a3002d,0xb7bd0139,0x60330139}},	//   _sio_, кичи, _fiţo, _nămo,
   {{0x69ce051c,0xd497021f,0x52b8051d,0xe5a30200}},	//   _ilbe, дры_, ेन्स, тији,
   {{0x29180067,0x00000000,0x00000000,0x00000000}},	//   ągać_, --, --, --,
   {{0x8cb5051e,0x4426051f,0xdb0d003e,0x3f8b0520}},	//   _उपभो, _vio_, nkað, vecu_,
   {{0x7c3e0521,0xe29f008a,0x76420522,0x7dd00523}},	//   _otpr, æða_, mpoy, _läsb,
   {{0x44260524,0xf9930122,0xd36f0132,0x00000000}},	//   _tio_, דרת_, _ич_, --,
   {{0x443e0332,0x72c60525,0xdb0d0093,0x3ea60009}},	//   _itt_, _обез, kkað, _šota_,
   {{0x441b00c2,0x69ce0526,0x64580527,0xa3ab0084}},	//   _וואס, _olbe, lsvi, खार_,
   {{0x7ae90280,0x3f8b0528,0x443e0529,0x7c3e0036}},	//   _žeto, secu_, _ktt_, _btpr,
   {{0xc04f0210,0xc178010b,0x245a02d4,0xac19052a}},	//   _ші_, snės_, nīm_, зову_,
   {{0x7dd00282,0x5bc90099,0x645804d5,0x00000000}},	//   _räse, रसेव, isvi, --,
   {{0x6feb006a,0xbbbf052b,0x9f4201f4,0xda15052c}},	// [290] jęci, _एकीक, zikë_, едањ,
   {{0x443e052d,0x6277011d,0xc5f30033,0x00000000}},	//   _ott_, וגמא_, _চীনা_, --,
   {{0x443e052e,0x645e00ac,0xab5b033b,0xa3c0052f}},	//   _ntt_, ápil, _blüt, ुसा_,
   {{0x6d550530,0x69ce0531,0x64580532,0x7dd001ff}},	//   laza, _elbe, dsvi, _väse,
   {{0x443e0533,0x6fc6004f,0x645a02a7,0xb9060534}},	//   _att_, _dóch, _avti, _बे_,
   {{0x6d550535,0x443e0536,0x9f4200da,0xdcee010b}},	//   naza, _btt_, tikë_, gebė,
   {{0x26c90537,0xa3ab009a,0x64580538,0x443e0539}},	//   šao_, खाल_, gsvi, _ctt_,
   {{0x6d55053a,0x443e053b,0x9f4201f4,0xabcc0070}},	//   haza, _dtt_, rikë_, ַציִ,
   {{0x443e053c,0x644e0484,0x6016053d,0x6458053e}},	//   _ett_, _ħbie, náme, asvi,
   {{0xf1b1004f,0x443e0036,0x6b8d053f,0x765b007b}},	//   اءة_, _ftt_, heag, _ivuy,
   {{0x6d550540,0x14740079,0x672400b8,0x6b8d0541}},	//   daza, _لانج, žijt, keag,
   {{0x649a0122,0x64430542,0x00000000,0x00000000}},	//   _מסעד, mpni, --, --,
   {{0xe1ee01d3,0x7124006c,0x6d41037a,0x3f9e00b8}},	//   _бг_, ٹریل, ılan, ětu_,
   {{0x7bcf0543,0x6d550544,0x68330024,0x200b030a}},	//   _alcu, gaza, _aħdm, alci_,
   {{0xb0420028,0xafe60545,0x6b8d0211,0xdb860212}},	//   _trưở, _покл, feag, нгви,
   {{0x6b8d008c,0x00000000,0x00000000,0x00000000}},	//   geag, --, --, --,
   {{0xada60546,0x6d550547,0x20020548,0x00000000}},	// [2a0] _запл, baza, moki_, --,
   {{0xdb0d00fb,0x64580549,0x6d55054a,0x2002054b}},	//   rkað, ysvi, caza, loki_,
   {{0x7dcb00d0,0xdb0d008d,0x6b8d054c,0x2d9a0176}},	//   _müsl, skað, beag, _iape_,
   {{0x48c30083,0x6016054d,0x2ca5054e,0x2d9a054f}},	//   ্পূর, lámb, ælde_, _hape_,
   {{0x2d9a0550,0x443e0551,0x64580552,0x00000000}},	//   _kape_, _stt_, wsvi, --,
   {{0x20020553,0x63ab0554,0x64580555,0xab5b01ae}},	//   hoki_, _angn, tsvi, _flüs,
   {{0x2d9a0556,0x200201d7,0xa3ab00ab,0xc7b0006c}},	//   _mape_, koki_, खां_, _پڑا_,
   {{0x64580557,0x443e0558,0x9f5900de,0x2d9a0559}},	//   rsvi, _vtt_, tosí_, _lape_,
   {{0x6d55055a,0x6458055b,0x443e055c,0x9f4201cb}},	//   yaza, ssvi, _wtt_, ciké_,
   {{0x27e6055d,0x2d9a055e,0x6b8d01d7,0x6724055f}},	//   lion_, _nape_, zeag, žijs,
   {{0xc0570560,0x6d550561,0x443e00ea,0x20020562}},	//   нія_, vaza, _utt_, foki_,
   {{0x27e60563,0x6d550564,0x6b8d01a3,0x25be023a}},	//   nion_, waza, xeag, _hotl_,
   {{0x6d550565,0x15e40066,0x2d9a0566,0xf8ad0099}},	//   taza, _कगार_, _bape_, _टप्प,
   {{0xa19302c4,0x2bc90567,0x7d030568,0x5bc90569}},	//   _башч, रस्थ, _ønsk, रस्व,
   {{0x26ec056a,0x27e6056b,0x2002056c,0x6b8d056d}},	//   जपुर_, kion_, boki_, teag,
   {{0x27e6021e,0x6d5a056e,0x6d55056f,0xfc300037}},	//   jion_, ótar, saza, صحف_,
   {{0x27e60570,0x6b8d0571,0x49750572,0x99670573}},	// [2b0] dion_, reag, клас, етел,
   {{0x60160574,0x6b8d0575,0xab5b0576,0xd9fa0577}},	//   ráme, seag, _plüs, ्तगत_,
   {{0x4ddc0122,0x6fc603e6,0x27e6001e,0x7dd0033b}},	//   _מחזו, _sóci, fion_, _wäsc,
   {{0x27e60578,0x765900e9,0x7dc2021d,0xb8d900ab}},	//   gion_, tswy, _fôss, _अऊ_,
   {{0x7e7d0579,0x9f4b0453,0x05be021a,0x3f9b0024}},	//   ntsp, locó_, ्संब, _maqu_,
   {{0xd5bb057a,0x7e7d057b,0xeabf00e2,0xa2cf057c}},	//   ясе_, itsp, _ngùi_, धनस्,
   {{0x02c9057c,0x27e6001e,0xd90f03fc,0x52c9057c}},	//   िन्न, bion_, _ایا_, िन्स,
   {{0x27e6057d,0x6443057e,0x7e7d057f,0x7dcb027d}},	//   cion_, rpni, ktsp, _süsl,
   {{0x7dd0022a,0xa2830580,0x0ee00581,0x2a690582}},	//   _läsa, ایتو, _पेंड, nrab_,
   {{0x64430583,0x7e7d0584,0x00000000,0x00000000}},	//   ppni, dtsp, --, --,
   {{0x66030585,0x20020586,0xf076006c,0x7dd0017b}},	//   monk, toki_, نیوں_, _näsa,
   {{0xb4bf0587,0x7e7d0588,0x64410260,0x2d9a0589}},	//   ुनी_, ftsp, _itli, _sape_,
   {{0x2002058a,0x29c40523,0xbddb0176,0x00000000}},	//   roki_, _köat_, rpèn, --,
   {{0x27e6058b,0x212e0051,0xd65600a5,0x00000000}},	//   zion_, _ggfh_, כישת_, --,
   {{0x2d9a058c,0x7e7d058d,0x2002058e,0x1d07058f}},	//   _vape_, atsp, poki_, вери_,
   {{0x27e602e1,0x66030590,0x601601ef,0x2d9a023c}},	//   xion_, honk, sámb, _wape_,
   {{0xf1b50591,0x27e602ee,0x7e7d0223,0x501b00a5}},	// [2c0] _अचान, vion_, ctsp, _קופו,
   {{0xd9460592,0xdcfc0029,0x261600ab,0x24920067}},	//   тежи, ndrī, _पीढी_, łymi_,
   {{0x27e60593,0x8e3a0594,0x66030595,0xdb060035}},	//   tion_, _عسکر_, donk, _pokó,
   {{0x46ea0009,0x00000000,0x00000000,0x00000000}},	//   мден_, --, --, --,
   {{0x27e60596,0xa3ab0299,0x64410597,0x66030598}},	//   rion_, खाई_, _atli, fonk,
   {{0x27e60599,0x6603059a,0xd943059b,0xd64500b5}},	//   sion_, gonk, _вери, ائنٹ,
   {{0x27e6059c,0x65610036,0x09e3059d,0xe7f40099}},	//   pion_, _ddlh, _торн, ेकदा_,
   {{0x799c059e,0xdb1d0118,0xc27403e6,0x7bd6055c}},	//   _harw, _bosè, глиј, nhyu,
   {{0x6441059f,0x877b02b5,0x660305a0,0x762605a1}},	//   _etli, _קאמי, bonk, _амаз,
   {{0xbbbf05a2,0x2fc00211,0xf1a605a3,0x799c01cb}},	//   _एक्क, _aoig_, трин, _jarw,
   {{0x799c05a4,0x2fc00392,0x2fd205a5,0xc60e05a6}},	//   _marw, _boig_, _blyg_, ितीय_,
   {{0x7e7d05a7,0x9f4b00de,0x2fc00284,0x6d41033e}},	//   ttsp, vocó_, _coig_, ılam,
   {{0xdbdc0093,0x00000000,0x00000000,0x00000000}},	//   _ráðn, --, --, --,
   {{0x2d850187,0xdd11024e,0x799c05a8,0x00000000}},	//   ýle_, _výži, _narw, --,
   {{0xf41402b5,0x61e805a9,0x2fd2013c,0x7e7d05aa}},	//   ָפּ_, midl, _flyg_, stsp,
   {{0x3ec701c8,0x2a690279,0xef6701d3,0x2fc00392}},	//   _асоб, trab_, _ръко, _goig_,
   {{0x20090118,0x799c05ab,0x5b1505ac,0x660305ad}},	// [2d0] _ikai_, _barw, умат, yonk,
   {{0x799c05ae,0xdd910098,0x2a6905af,0xc27b011d}},	//   _carw, _اود_, rrab_, ורמי,
   {{0x2d910010,0x48c30083,0x7bd60118,0x660305b0}},	//   meze_, ্প্র, bhyu, vonk,
   {{0x2d9105b1,0x4cdc0033,0x7bd600d7,0x61e805b2}},	//   leze_, _মুকু, chyu, hidl,
   {{0xd2460332,0x660305b3,0x799c00e9,0x6b9d01a6}},	//   _دن_, tonk, _farw, _iasg,
   {{0x2d9105b4,0x799c00d1,0x09ad0083,0xca7a0070}},	//   neze_, _garw, _গতকা, _אנשט,
   {{0x660305b5,0x6b9d05b6,0xb4bf05b7,0x61e80097}},	//   ronk, _kasg, ुने_, didl,
   {{0x2d9105b8,0x799c007b,0x7d08018d,0xe2b90200}},	//   heze_, _zarw, üdsi, ећој_,
   {{0x2fc00443,0x6b9d05b9,0x2d9105ba,0x660305bb}},	//   _roig_, _masg, keze_, ponk,
   {{0x61e801a2,0xe57305bc,0x2d9105bd,0x6b9d05be}},	//   gidl, _خطر_, jeze_, _lasg,
   {{0x80ad02e4,0x7bcd0086,0x437501b2,0x6f0d05bf}},	//   टमें, kkau, _مهار, _ayac,
   {{0x527505c0,0x7bcd006d,0x6f0d01d5,0xbb1b000d}},	//   _буку, jkau, _byac, _abîm,
   {{0x6f0d0010,0xe81a0067,0x61e805c1,0x60330395}},	//   _cyac, _फीफा_, bidl, _mămi,
   {{0x409505c2,0x63bb05c3,0x2d910232,0x200901ed}},	//   _брит, ljun, geze_, _ekai_,
   {{0x8fa605c4,0x6f0d00de,0x320500b5,0x6b9d05c5}},	//   _байе, _eyac, moly_, _basg,
   {{0x63bb05c6,0xeb9705c7,0x6b9d001e,0x7bcd05c8}},	//   njun, лис_, _casg, gkau,
   {{0xc332035e,0x601605c9,0x799c05ca,0x6b9d0090}},	// [2e0] מון_, cáma, _parw, _dasg,
   {{0x7bd60232,0x629905cb,0xfd4a00d4,0x6b9d0341}},	//   shyu, _mswo, _язок_, _easg,
   {{0x63bb0093,0x6b9d05cc,0x00000000,0x00000000}},	//   kjun, _fasg, --, --,
   {{0x61e805cd,0x799c05ce,0x6b9d00e9,0x60330395}},	//   zidl, _warw, _gasg, _cămi,
   {{0x6b840009,0x63bb05cf,0x799c05d0,0x320505d1}},	//   mfig, djun, _tarw, koly_,
   {{0xd49a05d2,0x7dd000a0,0x00000000,0x00000000}},	//   ери_, _mäso, --, --,
   {{0x61e805d3,0x395a05d4,0x62990051,0x6aa40036}},	//   vidl, maps_, _aswo, lvif,
   {{0x2d9105d5,0x6b8405d6,0x291800d7,0x395a05d7}},	//   zeze_, nfig, _izra_, laps_,
   {{0xd130004f,0xdb1d00f7,0x46a305d8,0xdb0f000d}},	//   يمة_, _posé, _латв, _ancê,
   {{0x7a7b016b,0x6f0d04fb,0xda7b016b,0x60330160}},	//   עריס, _ryac, עניר, _zămi,
   {{0x2d9105d9,0x63bb0024,0x61e805da,0x62990107}},	//   veze_, bjun, ridl, _eswo,
   {{0x09c100a1,0x2d9105db,0x5faf05dc,0x61e805dd}},	//   _शक्य, weze_, टाइल, sidl,
   {{0x3205040f,0x2d9105de,0x6b9d05df,0x61e805e0}},	//   boly_, teze_, _rasg, pidl,
   {{0x7dcb0006,0x232705e1,0x6aa905e2,0x6f0d05e3}},	//   _küsi, _сочи_, _šefo, _vyac,
   {{0x2d9105e4,0xa1570122,0x6b9d05e5,0xd13f0035}},	//   reze_, _גבוה_, _pasg, łącz_,
   {{0x2d9105e6,0x261605e7,0x672d0121,0x6b8400fd}},	//   seze_, _पीसी_, žaji, gfig,
   {{0x995505e8,0x7bcd05e9,0xf96b05ea,0x2d910160}},	// [2f0] икац, rkau, ерей_, peze_,
   {{0x7bcd05eb,0x6b9d05ec,0x62800051,0x995400af}},	//   skau, _wasg, itmo, йкуц,
   {{0x6b9d0014,0x3ea905ed,0x63bb05ee,0x84e3021a}},	//   _tasg, _hrat_, yjun, _केंट_,
   {{0x3ea905ef,0x6b9d0037,0x290f0228,0x6d5705f0}},	//   _krat_, _uasg, āga_, _hexa,
   {{0x291805f1,0x6d5701a3,0x395a0176,0x60330160}},	//   _ezra_, _kexa, baps_, _vămi,
   {{0x4ade00b4,0x5e5802b5,0xb5fd00b8,0xe5a502c8}},	//   _नेटव, ריגע_, _ovše, рики,
   {{0xdb06006c,0x23d505f2,0x6d5700a8,0x63bb05f3}},	//   _inká, ицир, _mexa, tjun,
   {{0xea0100e8,0x626505f4,0x3ea905f5,0xd2650382}},	//   _đẹp_, авиа, _orat_, акий,
   {{0x320505f6,0xd7f8010b,0xe3b6057a,0x00000000}},	//   toly_, _сур_, рбы_, --,
   {{0xbbd205f7,0x5bd205f8,0x98a105f9,0xa3d900b4}},	//   _सत्क, _सत्व, lahı_, डोज_,
   {{0xf9920122,0x7dd0013c,0x6ff20029,0x320505fa}},	//   חרי_, _säso, lāci, roly_,
   {{0x3ea905fb,0xf1d905fc,0x7c2f0211,0x543a0070}},	//   _brat_, योजन, _nicr, _סענא,
   {{0x320505fd,0x6ff20029,0x628005fe,0x442f05ff}},	//   poly_, nāci, ctmo, _iig_,
   {{0xc5f20070,0x7c2f026e,0x00000000,0x00000000}},	//   ַדן_, _aicr, --, --,
   {{0x3ea90600,0xa3cc000c,0x442f0601,0x2d9e01ba}},	//   _erat_, _रकम_, _kig_, ľte_,
   {{0x442f0602,0x0b460603,0x6ff20029,0x2d9e053d}},	//   _jig_, рнан, kāci, žte_,
   {{0x442f0604,0x3ea90605,0x7c2f01cb,0x3e7f00af}},	// [300] _mig_, _grat_, _dicr, cît_,
   {{0x442f0606,0xe9d70607,0x6ff20228,0x7c2f0211}},	//   _lig_, аку_, dāci, _eicr,
   {{0x442f0608,0xd9100609,0x6fcd00a2,0x2bbf060a}},	//   _oig_, سیر_, _bûch, _एकचा,
   {{0x7afd0069,0x69d5060b,0x225f0008,0xcc3b0070}},	//   _fxst, _elze, ksuk_, _שעכט,
   {{0x7c24060c,0x7ae9011c,0xeb9702fb,0x6ff200ea}},	//   mmir, _žetv, _тия_, gāci,
   {{0x6d5c060d,0x442f060e,0x7c240095,0x7dcb007c}},	//   nara, _aig_, lmir, _püsi,
   {{0x442f060f,0x601d02e1,0x3958012f,0xdb0f00e0}},	//   _big_, léme, _iers_, _ancè,
   {{0x938a0610,0x442f0611,0x80a90026,0x2b400612}},	//   тска_, _cig_, टिने, ncic_,
   {{0x442f0613,0x6d5c03d0,0x3c3c05ee,0x05160083}},	//   _dig_, kara, _lív_, াশের_,
   {{0x6d5c0614,0x442f0615,0x60330395,0x3958008c}},	//   jara, _eig_, _lămu, _jers_,
   {{0x39580616,0x442f0617,0x3ea90618,0xdfd10037}},	//   _mers_, _fig_, _srat_, كيد_,
   {{0x6d570619,0x3ea9061a,0x6fc6061b,0x395801f7}},	//   _sexa, _prat_, _sócr, _lers_,
   {{0xdefb061c,0x6d5c061d,0x7c2f0382,0xdb1d0036}},	//   тын_, fara, _ricr, _così,
   {{0x6d5c061e,0x442f061f,0x3ea90620,0x7c2f0297}},	//   gara, _zig_, _vrat_, _sicr,
   {{0x442f006f,0x6ff20080,0x6d570621,0x61ef00f7}},	//   _yig_, zāci, _vexa, ècle,
   {{0x7c2401a2,0x6d4e0069,0x69d500d5,0x3ea90622}},	//   gmir, abba, _slze, _trat_,
   {{0x6d5c0623,0x69d501c0,0x8d870009,0x6d570624}},	// [310] bara, _plze, _кунд, _texa,
   {{0xe29f00fb,0xc17801c8,0x44240159,0x7f5d0625}},	//   æði_, ngė_, hmm_, lasq,
   {{0x3958027d,0x7c2f0176,0xf7730079,0x9f4200ac}},	//   _ders_, _ticr, قاش_, liká_,
   {{0x39580626,0x22460627,0x6ff20029,0x7c240628}},	//   _eers_, _otok_, tāci, cmir,
   {{0x9f420187,0x601600b5,0x395800a2,0x442f0629}},	//   niká_, zámo, _fers_, _rig_,
   {{0x442f062a,0x6ff20080,0x3958062b,0xd877042c}},	//   _sig_, rāci, _gers_, _پاسب,
   {{0xe3b1004f,0x601601ef,0x442f062c,0x98aa009f}},	//   كرة_, xámo, _pig_, _rebħ_,
   {{0x6d5c062d,0x442f01e8,0xb7bd0395,0x3a390282}},	//   zara, _qig_, _piţu, _kusp_,
   {{0x442f062e,0x36d401e0,0xa56701cb,0xdcfe00ea}},	//   _vig_, _дотр, _ندان, _papī,
   {{0x7c240029,0x6d5c062f,0xdb1d0097,0xf1b10630}},	//   zmir, xara, _nosí, जाइन,
   {{0x442f0631,0x2ed0018d,0x1bf90632,0x225f00b5}},	//   _tig_, हन्त, ्काल_, ssuk_,
   {{0xcdc90052,0x6d5c0633,0xdb0f0634,0x672d00cd}},	//   _אך_, wara, _encé, žaju,
   {{0x6d5c0635,0x539a00a5,0xdb24045e,0x2b400207}},	//   tara, _תינו, üsün, vcic_,
   {{0x32b80037,0x6139016b,0x60160042,0x7dd00421}},	//   _خدمة_, _גײַס, pámo, _täsm,
   {{0x6d5c0636,0xc8850095,0x7c240637,0x8c460279}},	//   rara, naşı_, tmir, себе,
   {{0x9f82008a,0x2b590638,0x2a600639,0x7dd003a6}},	//   _góð_, _cesc_, tsib_, _käsk,
   {{0x7c24063a,0x2b40063b,0xdb1d063c,0x0936063d}},	// [320] rmir, rcic_, _fosí, مراج,
   {{0x7dd0063e,0x2a60063f,0x601d0640,0x3a3100fe}},	//   _mäsk, rsib_, réme, _cizp_,
   {{0x39580641,0xfbd20642,0x2a600643,0x601d00f7}},	//   _vers_, _فتح_, ssib_, séme,
   {{0xc8850644,0x9f4b0031,0x7f440069,0x395800e5}},	//   daşı_, vicë_, _jfiq, _wers_,
   {{0xe5c60645,0x39580646,0xe77500a8,0xada90647}},	//   йско, _ters_, zıçı, _صدیق_,
   {{0x6b96008e,0x7e6402a7,0x00000000,0x00000000}},	//   leyg, _mvip, --, --,
   {{0x7bc60648,0xe9d701e0,0x66d100b5,0x00000000}},	//   _koku, _укр_, tókö, --,
   {{0x6b960649,0x7e6403d0,0x7bc6064a,0x2b590176}},	//   neyg, _ovip, _joku, _xesc_,
   {{0x7ae9064b,0x7bc60486,0x60290035,0x7dcb064c}},	//   _þett, _moku, _uśmi, _küst,
   {{0x7bc6064d,0x104a0352,0x6d5a0093,0x644a03d0}},	//   _loku, лями_, ðtal, ppfi,
   {{0xe452064e,0x7dcb064f,0x672d0650,0x9f4b0453}},	//   _رضا_, _xüsu, žajt, licé_,
   {{0x7bc60651,0x94260652,0xb4d40653,0x660a0207}},	//   _noku, _умее, हनी_, lofk,
   {{0xdb1d0654,0x2246043d,0x601d0118,0x00000000}},	//   _posí, _utok_, témb, --,
   {{0x270700e8,0x63a20655,0x2b590279,0xe9df0300}},	//   ống_, _haon, _sesc_, _atún_,
   {{0x7bc60656,0x7f5d0036,0x7a29010b,0x3a39021d}},	//   _boku, pasq, _užti, _susp_,
   {{0x1b020033,0xdb1d0183,0x7dd00282,0x660a0298}},	//   লেছে_, _rosâ, _läsh, hofk,
   {{0x63a20657,0x200b0658,0x394100f7,0x7dcb0659}},	// [330] _maon, moci_, tchs_, _büst,
   {{0x2ba9065a,0x200b065b,0x63a2065c,0x39410110}},	//   _चोरा, loci_, _laon, uchs_,
   {{0x3941065d,0x7dcb065e,0x9982004b,0x00000000}},	//   rchs_, _düst, _aukų_, --,
   {{0x61c5065f,0x63a20054,0x200b0660,0x39410110}},	//   _लक्ष, _naon, noci_, schs_,
   {{0x25ed02cb,0x4ae401c8,0xb5fd024e,0x961d021e}},	//   _अगदी_, _еўра, _avša, _opņt,
   {{0x7bc60661,0xdcfc0029,0x3e5c0070,0x96280037}},	//   _zoku, cerē, נדוס, مكنك_,
   {{0x7bc60662,0x200b0663,0x67d50664,0xdb0601ff}},	//   _yoku, koci_, _дову, _enkä,
   {{0xc2450665,0x69c70666,0x7dcb0508,0x63a20667}},	//   оник, _hoje, _küss, _caon,
   {{0x69c70668,0x64480669,0x63a2066a,0x85b9066b}},	//   _koje, _etdi, _daon, _клас_,
   {{0x7dcb02c9,0xd24e00f8,0x69c700d7,0x7dd0013c}},	//   _müss, کنی_, _joje, _väsk,
   {{0x69c7066c,0xcea90397,0x7e64008a,0x645e00a0}},	//   _moje, _שי_, _svip, špir,
   {{0x6d450244,0x200b0443,0x246500ea,0xd00a066d}},	//   _afha, goci_, mēm_, реме_,
   {{0xa29400ef,0xd9fb00a1,0x6d450341,0x246500ea}},	//   _наці, ्वात_, _bfha, lēm_,
   {{0x7dd0066e,0x4129066f,0x7bc60670,0xed570671}},	//   _käsi, _коло_, _soku, жор_,
   {{0x7bc60672,0x7dcb0673,0x8c430674,0x63a20675}},	//   _poku, _rüst, десе, _yaon,
   {{0xb06803c5,0x7dcb007c,0x200b0676,0x3d1a00ab}},	//   _اصول_, _süst, coci_, _धरीं_,
   {{0x69c702f6,0x7dcb00ab,0xed360677,0x19c60678}},	// [340] _boje, _püst, _мэнэ, обам,
   {{0x7bc60679,0x3ea002e9,0x7dcb01ae,0x69c7067a}},	//   _woku, _isit_, _düss, _coje,
   {{0x69c7067b,0x7bc6067c,0x601d067d,0x5faf0099}},	//   _doje, _toku, léma, _जोडल,
   {{0x2d98067e,0x510c00c2,0x224d067f,0x7dcb02b1}},	//   lere_, נהאַ, kpek_, _wüst,
   {{0xd5ba03ad,0x69c70009,0x63a20680,0x601d00f7}},	//   иск_, _foje, _raon, néma,
   {{0x2d980681,0x6448012f,0x69c70682,0xe4520037}},	//   nere_, _ptdi, _goje, وضع_,
   {{0xb4d40683,0x601d0684,0x63a20036,0x2d980685}},	//   हने_, héma, _paon, iere_,
   {{0x2d980686,0x32660072,0x9faf01c0,0x6aa9030a}},	//   here_, отов, tří_, _šefi,
   {{0x2d980687,0xdb1d006c,0x00000000,0x00000000}},	//   kere_, _kosá, --, --,
   {{0x2d980688,0x63a20054,0xcb1300a5,0x3f80010b}},	//   jere_, _waon, ולח_, _aciu_,
   {{0x2d980689,0x63a20269,0x200b042a,0x246500ea}},	//   dere_, _taon, toci_, cēm_,
   {{0xdb1d01ef,0x00000000,0x00000000,0x00000000}},	//   _losá, --, --, --,
   {{0x2d98068a,0x200b068b,0x00000000,0x00000000}},	//   fere_, roci_, --, --,
   {{0x2d98068c,0xddcf002d,0x61ea00af,0xdb1d068d}},	//   gere_, ducţ, _umfl, _nosá,
   {{0xa1770052,0xfbd30082,0xc05a0044,0x69c7068e}},	//   _ועוד_, وتر_, _тіл_, _roje,
   {{0x69c7068f,0xdb1d0176,0x7dcb00be,0x320c0147}},	//   _soje, _posà, _püss, lody_,
   {{0x69c70690,0x2d980232,0x3f990691,0xdb1d00d5}},	// [350] _poje, bere_, mesu_, _bosá,
   {{0x2d980692,0x3f990693,0xdb1d0079,0xdb0f0176}},	//   cere_, lesu_, _cosá, _socó,
   {{0x76490694,0x69c7024e,0x2d81009e,0xdb1d00b8}},	//   _stey, _voje, _iche_, _dosá,
   {{0x320c0076,0x3f990695,0x69c7004e,0x4c9a02b8}},	//   hody_, nesu_, _woje, _פברו,
   {{0x320c0067,0x00000000,0x00000000,0x00000000}},	//   kody_, --, --, --,
   {{0x27ef024b,0x24650029,0x69de0696,0x85e801e0}},	//   sign_, tēm_, chpe, одів_,
   {{0xf7730697,0x2d81023c,0xd5ae0698,0x00000000}},	//   _يار_, _mche_, طفي_, --,
   {{0x3cfc0100,0x61fa0699,0x2d980010,0x3f99003a}},	//   ילונ, entl, zere_, jesu_,
   {{0x37da0070,0x27ed069a,0x2d810036,0x2d9801e0}},	//   _פֿלע, _imen_, _oche_, yere_,
   {{0x2d980051,0x320c0035,0x6d48027b,0x224d01ed}},	//   xere_, gody_, ıdak, rpek_,
   {{0x2d98069b,0x6016069c,0x224d069d,0x2fc90211}},	//   vere_, lámi, spek_, _boag_,
   {{0x2d98069e,0xd8d60122,0x25a500a5,0x224d00b5}},	//   were_, פורט_, _hall_, ppek_,
   {{0x25a5069f,0x320c06a0,0x02a700af,0x27ed0107}},	//   _kall_, body_, _фрем, _mmen_,
   {{0x6b8f0168,0x27ff0024,0x7bcb008d,0x7dd001ff}},	//   _abcg, _ljun_, ögun, _läsv,
   {{0x2d9806a1,0x27ed06a2,0xdb1d06a3,0x25a5024b}},	//   rere_, _omen_, _rosá, _mall_,
   {{0x2d9806a4,0x4a4606a5,0x9e6606a6,0x27ed010d}},	//   sere_, знав, _евид, _nmen_,
   {{0x2d9806a7,0x6d4106a8,0xe9da06a9,0xdb1d0187}},	// [360] pere_, ılar, бка_, _posá,
   {{0xdb0406aa,0x27ff06ab,0x8af000a8,0x25a506ac}},	//   ndié, _ajun_, vbəd, _nall_,
   {{0x6d5e0029,0x6d3b00a5,0xdb1d00d5,0x63760457}},	//   _iepa, _לתינ, _vosá, nünü,
   {{0xf1ba0019,0x69de0031,0x25a500e5,0x7bdf02b1}},	//   _nhơn_, shpe, _aall_, chqu,
   {{0x6d5e06ad,0xb4e40066,0x25a506ae,0x27ff007a}},	//   _kepa, _पेड़_, _ball_, _djun_,
   {{0x6d5e00a1,0x7c3e06af,0x25a506b0,0x3f9901d7}},	//   _jepa, _kupr, _call_, zesu_,
   {{0x25a50133,0x320c033a,0x3f9906b1,0x7ae406b2}},	//   _dall_, vody_, yesu_, lzit,
   {{0x6d5e06b3,0x320c0035,0x25a500ab,0x7bd606b4}},	//   _lepa, wody_, _eall_, nkyu,
   {{0x320c04aa,0x25a506b5,0xdb0400f7,0x3f99023a}},	//   tody_, _fall_, udiè, vesu_,
   {{0x64a606b6,0x6d5e06b7,0x200301cc,0x672003fd}},	//   _наза, _nepa, čkim_, _izmj,
   {{0x9316006c,0x320c05d1,0xef1f06b8,0x63760448}},	//   _کوشش, rody_, rfüm_, günü,
   {{0x672002e4,0x2d810110,0x443e06b9,0x27ed055c}},	//   _बराक_, _sche_, _iut_, _xmen_,
   {{0x6d5e06ba,0xb80d06bb,0xe80d06bc,0x7c3e0248}},	//   _bepa, िकतम_, िकता_, _aupr,
   {{0x6d5e0388,0x443e06bd,0x224b01ba,0x3f9900e9}},	//   _cepa, _kut_, ícke_, sesu_,
   {{0x7c3e0043,0x9f4b0355,0x443e00b5,0x3f9906be}},	//   _cupr, licí_, _jut_, pesu_,
   {{0x443e06bf,0x69dc06c0,0xd1170317,0x6d5e0159}},	//   _mut_, _alre, _מקוה_, _eepa,
   {{0x443e06c1,0x5a3506c2,0x25ed0461,0x69dc009e}},	// [370] _lut_, днат, _अगली_, _blre,
   {{0x443e01f3,0x6d5e06c3,0x2ca1022e,0x7bdf06c4}},	//   _out_, _gepa, _tshd_, shqu,
   {{0x25a506c5,0x69dc0211,0x7c670427,0x443e06c6}},	//   _rall_, _dlre, _عادل, _nut_,
   {{0x69dc00b5,0x601601ef,0x00000000,0x00000000}},	//   _elre, támi, --, --,
   {{0xf7700206,0x443e06bc,0x637600d0,0x25a506c7}},	//   طان_, _aut_, zünü, _pall_,
   {{0x443e01f3,0x601606c8,0xf65006c9,0x6d470035}},	//   _but_, rámi, ائن_, ncja,
   {{0x25a50443,0x443e00a5,0x64a202fb,0x601d02d7}},	//   _vall_, _cut_, ваща, jémo,
   {{0x443e0291,0x741506ca,0x7dd006cb,0x601d01dd}},	//   _dut_, بوعا, _häst, démo,
   {{0x644906cc,0x91e506cd,0x443e00f7,0x6d470067}},	//   _žlič, допе, _eut_, kcja,
   {{0x443e06ce,0x5ef101c0,0xdb0402b1,0x63760448}},	//   _fut_, ँछन्_, heiß, tünü,
   {{0x656306cf,0x7bdd06d0,0x443e06d1,0x7ae4027a}},	//   manh, _olsu, _gut_, zzit,
   {{0x5ec600c8,0x7dd006d2,0x637606d3,0x7bcb0093}},	//   _লেগে, _läst, rünü, ögul,
   {{0x6d5e06d4,0x7c3e06d5,0x8af0013b,0x2e2402b1}},	//   _pepa, _supr, naət, höfe_,
   {{0x63a906d6,0x7dd006d7,0x518706d8,0x2be006d9}},	//   lden, _näst, _худа, नसभा,
   {{0x628906da,0x601d002a,0x6b8d06db,0x443e01f7}},	//   lteo, cémo, ffag, _xut_,
   {{0x63a906dc,0x7ae401d7,0x673b06dd,0x656306de}},	//   nden, tzit, _nguj, hanh,
   {{0x7dd006d7,0x6d5e06df,0x628906e0,0x63a906e1}},	// [380] _bäst, _tepa, nteo, iden,
   {{0x7ae406e2,0x673b06e3,0x62890037,0x22590097}},	//   rzit, _aguj, iteo, ásky_,
   {{0x59c40026,0xdb0f0392,0x0c2606e4,0xab670228}},	//   लॉगर, _encà, _омон, _beļģ,
   {{0x63a906e5,0x443e06e6,0x3eb206e7,0x6fde0026}},	//   jden, _rut_, _kryt_, मसिं,
   {{0x443e0297,0x7dd0013c,0x656306e8,0x63a906e9}},	//   _sut_, _fäst, fanh, dden,
   {{0x7dd006ea,0x63a906eb,0x443e06ec,0xa2ac0026}},	//   _gäst, eden, _put_, जिस्,
   {{0x443e012f,0x7dd006ed,0x7845010b,0xf77206ee}},	//   _qut_, _häss, _tėva, _لاء_,
   {{0x443e06ef,0x600800c1,0x63a906f0,0x00000000}},	//   _vut_, nımd, gden, --,
   {{0xa80206d3,0x291806f1,0x656306f2,0x443e06f3}},	//   ğıda, _hyra_, banh, _wut_,
   {{0x443e06f4,0x63a906f5,0x7dd006f6,0x601d05c9}},	//   _tut_, aden, _mäss, témo,
   {{0x7dd002c9,0x443e007c,0xf1a301f1,0x201902c4}},	//   _läss, _uut_, трын, tlsi_,
   {{0x291806f7,0x601d06f8,0x3eb20185,0x764006f9}},	//   _myra_, rémo, _bryt_, _kumy,
   {{0x442606fa,0x7dd006fb,0x628906fc,0xa30800b5}},	//   _iho_, _näss, cteo, _عرصے_,
   {{0x442606fd,0x02ca06fe,0x764006ff,0xdb0402b1}},	//   _hho_, िहीन, _mumy, weiß,
   {{0x44260700,0x6d470701,0x2bbb0037,0x9e3400af}},	//   _kho_, rcja, يارة_, терч,
   {{0xdb0601cb,0x00000000,0x00000000,0x00000000}},	//   _kakè, --, --, --,
   {{0x656302b3,0x69c50069,0xa3d6030f,0x6b8d0702}},	// [390] yanh, tjhe, _हवन_, rfag,
   {{0x44260703,0x63a90704,0x49740705,0x7e7d03a6}},	//   _lho_, zden, клус, musp,
   {{0x7dd0022a,0x44260706,0x63a90707,0x65630708}},	//   _väst, _oho_, yden, vanh,
   {{0x44260709,0xdb0f01dd,0xddcd0097,0x291801bc}},	//   _nho_, _encá, _staň, _dyra_,
   {{0x7c2d0533,0x200301cc,0x7dd0070a,0x656306f2}},	//   mmar, čkih_, _täst, tanh,
   {{0x4426070b,0x2918022a,0x00000000,0x00000000}},	//   _aho_, _fyra_, --, --,
   {{0x4426004a,0x6563070c,0xfc4601ba,0x63a9070d}},	//   _bho_, ranh, žíva_, tden,
   {{0x4426070e,0x7c2d070f,0x65630710,0x62890711}},	//   _cho_, nmar, sanh, tteo,
   {{0x66f30712,0x65630370,0x2a690713,0xe7840714}},	//   _अधिक_, panh, nsab_, _шуро,
   {{0x62890715,0x60080716,0x7e7d00ab,0xdb060260}},	//   rteo, zımd, dusp, _dakè,
   {{0x62890717,0x7c2d0718,0xdb0601f4,0x44260719}},	//   steo, kmar, _pakë, _fho_,
   {{0x64410012,0x7c2d071a,0x6561071b,0x2a6900ab}},	//   _iuli, jmar, _helh, ksab_,
   {{0x442d071c,0x644100a7,0x81d5071d,0x6561071e}},	//   mme_, _huli, _подх, _kelh,
   {{0x644104be,0x7c26071f,0x270e0019,0xfbdf06f2}},	//   _kuli, _shkr, ộng_, _alê_,
   {{0x656100c9,0x64410720,0xfce60721,0xa3b40722}},	//   _melh, _juli, хово, _छोड_,
   {{0x442d0723,0x64410724,0x44260725,0xf06202fb}},	//   nme_, _muli, _xho_, _скъп,
   {{0x291e0537,0x160f0726,0xe9da014d,0x442d0727}},	// [3a0] _šta_, िवार_, пка_, ime_,
   {{0x442d0728,0x7c2d0729,0xdb0601c0,0x644103bc}},	//   hme_, amar, _jaké, _ouli,
   {{0x442d072a,0x6441072b,0x7c2d072c,0x2b4b00fe}},	//   kme_, _nuli, bmar, _ffcc_,
   {{0x442d072d,0x7dd003ad,0x3f82072e,0x2a69006d}},	//   jme_, _täss, ngku_, bsab_,
   {{0x4426072f,0x00000000,0x00000000,0x00000000}},	//   _rho_, --, --, --,
   {{0x64410730,0x442600ec,0x442d0731,0x991600d8}},	//   _buli, _sho_, eme_, _зьбі,
   {{0x64410732,0xd4970733,0xdcfc0029,0x7e7d0734}},	//   _culi, еры_, derī, zusp,
   {{0x442601a9,0x69ce0291,0x442d0735,0xdb0602d0}},	//   _qho_, _hobe, gme_, _pakè,
   {{0x65610332,0x69ce0736,0x64410737,0xf5ea00af}},	//   _felh, _kobe, _euli, _емал_,
   {{0x44260052,0x64410069,0x442d0738,0xf1ba0019}},	//   _who_, _fuli, ame_, _thơm_,
   {{0x44260739,0x6441073a,0xdfd10125,0x69ce073b}},	//   _tho_, _guli, ليد_, _mobe,
   {{0x7e7d073c,0x04db0122,0x442d073d,0xa2e6073e}},	//   tusp, _מקבל, cme_, _поед,
   {{0x0cc9073f,0x64410740,0x7c2d0282,0xa3d5007c}},	//   रह्म, _zuli, vmar, _सकत_,
   {{0x69ce0741,0x2d850742,0x7c2d0743,0x7afb011c}},	//   _nobe, üle_, wmar, _žuto,
   {{0x7e7d0744,0x64410745,0xac190746,0x00000000}},	//   susp, _xuli, дову_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f490453,0x7f4d0024,0x9f4b00be,0x00000000}},	// [3b0] ñequ, _ifaq, öjõu_, --,
   {{0x69ce0747,0x9f590079,0x5b1400af,0x7e6d0065}},	//   _cobe, insí_, умут, _ivap,
   {{0xd3660118,0x69ce0748,0x2a690183,0xe3c30225}},	//   _په_, _dobe, ssab_, ngıç_,
   {{0x2d830044,0x7e6d0749,0x65610355,0x7f4d0024}},	//   lgje_, _kvap, _selh, _jfaq,
   {{0xe7e200b1,0x65610355,0x4b7a0070,0x85b800f8}},	//   _खतरा_, _pelh, _קאשו, کانس_,
   {{0x69ce074a,0x6441074b,0x888200b5,0x2d83074c}},	//   _gobe, _puli, _چیلن, ngje_,
   {{0x442d074d,0x6561074e,0x644100a8,0xb4db074f}},	//   tme_, _velh, _quli, डने_,
   {{0x7bcf0012,0x69ce0750,0x7e6d02c4,0x64410751}},	//   _jocu, _zobe, _ovap, _vuli,
   {{0x130902ce,0x9f4201f4,0x69d8006c,0x65610752}},	//   ьний_, shkë_, öveg, _telh,
   {{0x7bcf0012,0x64410753,0xfe7f0176,0xb6350754}},	//   _locu, _tuli, duï_, _شفاع,
   {{0xf8e10755,0x64410756,0xdb1d004f,0xd37100ce}},	//   पनिय, _uuli, _cosú, _نها_,
   {{0x2d830051,0x13a700f8,0x00000000,0x00000000}},	//   egje_, _سنتی_, --, --,
   {{0x69c406bc,0x3f8c0035,0xdb0601ba,0x15e5049c}},	//   रामी, ędu_, _také, _कतार_,
   {{0x827602b5,0x7e6d011c,0x63ab0093,0x9f4b0132}},	//   _יענע_, _dvap, _hagn, ricá_,
   {{0xa3d50035,0xa0a50757,0x4094010b,0x00000000}},	//   _सका_, _райд, _брыт, --,
   {{0x69ce0042,0xeb97002d,0xd00f004f,0x7bcf0758}},	//   _sobe, кис_, _ولو_, _cocu,
   {{0x69ce0759,0xd946075a,0xe7f70026,0x00000000}},	// [3c0] _pobe, вези, ूचना_, --,
   {{0xdb0d008a,0x63ab075b,0x7dd00282,0x00000000}},	//   rjað, _lagn, _gäsp, --,
   {{0x1d0a075c,0x69ce075d,0x00000000,0x00000000}},	//   _цени_, _vobe, --, --,
   {{0x63ab075e,0x69ce075f,0x27e00037,0x6ec60380}},	//   _nagn, _wobe, óin_, ामपु,
   {{0xe7f30035,0xe7370760,0x34da0761,0x23c5021a}},	//   _आगरा_, вец_, बन्द, वानद,
   {{0xa61300d8,0x5573002d,0x6b840762,0x00000000}},	//   аміч, агшт, lgig, --,
   {{0x63ab01d3,0x629902e9,0x04630763,0x442a00af}},	//   _bagn, _apwo, атым, мцим_,
   {{0x63ab0764,0x00000000,0x00000000,0x00000000}},	//   _cagn, --, --, --,
   {{0x63ab0765,0x41e600d8,0x99830409,0x6f090067}},	//   _dagn, віна, _gijų_, żecz,
   {{0xdb1d0766,0xf1ba0023,0x63ab0767,0x27e60768}},	//   _posú, _khơi_, _eagn, lhon_,
   {{0x601d0769,0xb97b0122,0x63ab0093,0xdb06033b}},	//   lémi, וניי, _fagn, _ankü,
   {{0x63ab076a,0x7ec900da,0x27e602b3,0x14d7076b}},	//   _gagn, _nëpë, nhon_, _שואל_,
   {{0xd250004f,0xd33600d8,0xf8bf04aa,0x601d076c}},	//   _انت_, _рэжы, _एप्प, némi,
   {{0x63a0076d,0x63ab076e,0x6280076f,0x7bcf0139}},	//   lemn, _zagn, mumo, _socu,
   {{0xa3d60591,0x7bcf0770,0x62800771,0x2d830772}},	//   _हवा_, _pocu, lumo, rgje_,
   {{0x6008027d,0x3ed50773,0x00000000,0x00000000}},	//   rımc, _مقبر, --, --,
   {{0x628001a2,0x27e60774,0x41a90775,0x00000000}},	// [3d0] numo, dhon_, _कसमस, --,
   {{0x601d0776,0x9f4001f7,0x3ea9067f,0x3f8901da}},	//   démi, _aliè_, _isat_, _hcau_,
   {{0xf1ba00e8,0x62800777,0xf77500d4,0x7bcf0778}},	//   _chơi_, humo, гулю, _tocu,
   {{0xf0930779,0x63a0077a,0x1a650332,0x6280077b}},	//   ינע_, jemn, _میری_, kumo,
   {{0x63ab077c,0x62800029,0x600804d4,0x7c3d00ab}},	//   _ragn, jumo, nıma, _iisr,
   {{0x63ab077d,0x27e6010d,0x2e240093,0x00000000}},	//   _sagn, ahon_, höfn_, --,
   {{0x63ab077e,0x20020035,0x478b0274,0x25ac077f}},	//   _pagn, ynki_, _осам_, _dadl_,
   {{0x27e60780,0x3f8901e8,0x25be0176,0x7c3d0781}},	//   chon_, _ncau_, _entl_, _jisr,
   {{0x63ab0782,0x67d4002d,0x601d0783,0x628004ff}},	//   _vagn, _тоту, cémi, gumo,
   {{0x10a50665,0xdb040784,0xddc40009,0xb0ae0785}},	//   гион, ndiá, _oviš, टिंग,
   {{0x54550786,0x63ab0787,0x69c402cb,0x228b02ce}},	//   _свет, _tagn, राती, søk_,
   {{0x62800788,0x92b50789,0xdb0d00be,0x7c3d007a}},	//   bumo, _محتا, ljaõ, _nisr,
   {{0xf1a80088,0x3ea9078a,0x62c70079,0x00000000}},	//   رایه_, _csat_, _جزاك, --,
   {{0x27e6078b,0x7c3d009e,0xc33200a5,0x3ea9008c}},	//   zhon_, _aisr, _הוד_, _dsat_,
   {{0xfce3078c,0x7c3d046a,0xd1b8006c,0x3ea9078d}},	//   боро, _bisr, _جانا_, _esat_,
   {{0xfaa6078e,0x81bc00ea,0xd0120037,0x1ee80088}},	//   лабо, smēt, _دلع_, _لوبی_,
   {{0xfe7200d2,0x6b84078f,0xdb060359,0x2fc00790}},	// [3e0] _ادب_, rgig, _ankò, _inig_,
   {{0x63a00791,0xf1ba0023,0x7a2200a0,0x69c4052b}},	//   zemn, _phơi_, rôto, राधी,
   {{0x27e60792,0x81bc0080,0xddc4023a,0x443d0793}},	//   thon_, slēg, _gviš, _oiw_,
   {{0x6d4e02c4,0x4b5502fb,0xdb1d0107,0x6e3e018d}},	//   lcba, _върт, _onsè, _hipb,
   {{0xcc3b02b5,0xdb06021e,0x6e3e008c,0x27e60794}},	//   _רעכט, _enkò, _kipb, rhon_,
   {{0xe9df004f,0x27e601f4,0x601d0795,0xb86602ed}},	//   _dtús_, shon_, rémi, _مارو,
   {{0xe0c70796,0x63a00797,0xdb1d02d0,0x601d000d}},	//   _از_, temn, _ansè, sémi,
   {{0xc2740798,0xb27406a6,0x75240355,0xedd101c0}},	//   алиј, алиш, řizo, _सक्छ,
   {{0x248e01a2,0x060a0799,0x443d02d0,0x6d5c079a}},	//   stfm_, _знак_, _diw_, kbra,
   {{0x6280079b,0x63a0079c,0x27e4028b,0xf1a6079d}},	//   rumo, semn, _hlmn_, урин,
   {{0x43860164,0x6280079e,0xb97b0070,0xdb1d021e}},	//   _ملاق, sumo, ענטי, _ensè,
   {{0x273a0092,0x9f5901f4,0x752800ea,0x6d5c079f}},	//   _günü_, misë_, _izdz, ebra,
   {{0x9f5901f4,0x98b8007a,0x741301cb,0x244a00e2}},	//   lisë_, _ferħ_, _اونا, _hùm_,
   {{0x2fc007a0,0xf1aa05f5,0x6d5c07a1,0x6008045e}},	//   _enig_, _ساته_, gbra, rıma,
   {{0x9f5900da,0xfaff00da,0xdb1d07a2,0xa2ac07a3}},	//   nisë_, _ndër_, _insé, जिक्,
   {{0x6d5c0608,0x3b5503e6,0x81bc0029,0x61fa07a4}},	//   abra, ркар, slēd, litl,
   {{0x6d5c01d3,0x9f49027d,0x3ea90392,0x661a0107}},	// [3f0] bbra, _amaç_, _usat_, _oktk,
   {{0x6d5c009e,0xdcfc0029,0x9f590031,0x61fa07a5}},	//   cbra, sgrā, kisë_, nitl,
   {{0xa3d50006,0xdb0407a6,0x9f5901f4,0xf9880037}},	//   _सकल_, rdiá, jisë_, انمي_,
   {{0x9f590031,0x61fa0225,0xa80200c1,0x69c807a7}},	//   disë_, hitl, şına, _òden,
   {{0xd90f07a8,0xe6110580,0x61fa027b,0x2246021e}},	//   _کیا_, يشت_, kitl, _nuok_,
   {{0x443d02d0,0xf98907a9,0x9f590031,0xaaa802fb}},	//   _siw_, _جنسي_, fisë_, _съюз_,
   {{0x7aed07aa,0x244a07ab,0x61fa07ac,0x7e7d033b}},	//   lzat, _cùm_, ditl, hrsp,
   {{0x7bcd07ad,0x2246011e,0x244a0019,0x6d5c07ae}},	//   njau, _buok_, _dùm_, zbra,
   {{0x7aed07af,0x11e507b0,0x59c90026,0x6d5c07b1}},	//   nzat, ижим, रापर, ybra,
   {{0x437500bf,0x846701d3,0x6d5c021d,0x20b5010b}},	//   _چهار, _бъде, xbra, аёмс,
   {{0x53c50026,0x9f5900da,0xe5c407b2,0x23c507b3}},	//   वादश, cisë_, _усто, वादद,
   {{0x6d5c0211,0x229507b4,0xb4b107b5,0xdb1d02d7}},	//   wbra, _видя, टटी_, _ensé,
   {{0x6d5c07b6,0x61fa05f9,0x5f19018d,0xceb4013b}},	//   tbra, bitl, _युद्_, _azər_,
   {{0xdb040132,0x601d0298,0x7aed07b7,0x00000000}},	//   ldiç, dému, dzat, --,
   {{0x6d5c07b8,0xdc6702ee,0xdca6066d,0x6f0d07b9}},	//   rbra, иард_, шави, _exac,
   {{0xdb040370,0x35c707ba,0x2fc00297,0x78ba01ba}},	//   ndiç, लाड़, _unig_, _štvo,

   {{0x896604bf,0xbea607bb,0x31670359,0x9f590031}},	// [400] икаж, _тапк, _kenz_, zisë_,
   {{0x69260409,0x27e4009e,0x48b602fb,0x00000000}},	//   амза, _slmn_, ищет, --,
   {{0x3205024b,0xac0a07bc,0x98740355,0x69de07bd}},	//   inly_, _анна_, _týče_, rkpe,
   {{0x244a0014,0x31670408,0x7e6404fb,0x9f590031}},	//   _rùm_, _lenz_, _kwip, visë_,
   {{0xe5c607be,0x61fa07bf,0x7aed0067,0xdcfe07c0}},	//   иско, yitl, czat, _napĺ,
   {{0xd49a07c1,0x5d7a00c2,0x672900ea,0x9f590031}},	//   ври_, דאַק, _dzej, tisë_,
   {{0x53e607c2,0x83f807c3,0x61fa07c4,0x67290103}},	//   ициа, лекс_, vitl, _ezej,
   {{0x9f5901d2,0x7afb011c,0x00000000,0x00000000}},	//   risë_, _žuti, --, --,
   {{0x9f5900da,0x316707c5,0x61fa07c6,0x66e307c7}},	//   sisë_, _benz_, titl, _дота,
   {{0x9f5907c8,0x244a00e2,0x00000000,0x00000000}},	//   pisë_, _tùm_, --, --,
   {{0x7aed07c9,0x9f5907ca,0x661807cb,0x00000000}},	//   zzat, lisé_, movk, --,
   {{0x661807cc,0x61fa07cd,0x656807ce,0x7aed07cf}},	//   lovk, sitl, _hedh, yzat,
   {{0x61fa07d0,0x9f5907d1,0x644807d2,0x656800d1}},	//   pitl, nisé_, _hudi, _kedh,
   {{0x644807d3,0x65680118,0x661805ed,0x7e6407d4}},	//   _kudi, _jedh, novk, _dwip,
   {{0x656807d5,0x31570122,0x7b670086,0x644807d6}},	//   _medh, _דיון_, итае, _judi,
   {{0x81e800c8,0x7aed07d7,0x644807d8,0x6008008f}},	//   _যদি_, tzat, _mudi, nıml,
   {{0x6e950514,0x644807d9,0x7bcd03ad,0x5e95004f}},	// [410] _الخا, _ludi, rjau, _الخط,
   {{0x201907da,0x7bcd07db,0x7aed07dc,0xa802033e}},	//   losi_, sjau, rzat, şıla,
   {{0x6618024e,0x6d4507dd,0x6008027d,0x3a33011e}},	//   dovk, _igha, kıml, rmxp_,
   {{0x201907de,0xb8ff07df,0x6568030d,0x00000000}},	//   nosi_, _तथ_, _aedh, --,
   {{0xef1f0644,0x656800f8,0x600800a8,0x00000000}},	//   zgün_, _bedh, dıml, --,
   {{0x644807e0,0xc9840185,0xbb3a0122,0x2019001e}},	//   _budi, _муси, _תעשי, hosi_,
   {{0x201907e1,0x644807e2,0x6d4507e3,0x656800e0}},	//   kosi_, _cudi, _mgha, _dedh,
   {{0xd77407e4,0x316707e5,0x201907e6,0xdce707e7}},	//   _واقع, _senz_, josi_, jajč,
   {{0x65680657,0x201907e8,0x69d507e9,0xdb040132}},	//   _fedh, dosi_, _koze, rdiç,
   {{0x69d507ea,0x6d45001e,0x27fd001e,0xbbd40325}},	//   _joze, _ngha, liwn_, _धक्क,
   {{0x273300e8,0x69d507eb,0x7e640602,0x64480053}},	//   _ảnh_, _moze, _swip, _gudi,
   {{0x6d4507ec,0xdb0607ed,0xfaff053e,0xef1f033e}},	//   _agha, _laká, _reën_, rgün_,
   {{0x69d50176,0xfaff053e,0x6d450024,0x6008013b}},	//   _ooze, _seën_, _bgha, sımo,
   {{0xc5f200c2,0x644807ee,0x9f590086,0x2be001c0}},	//   ִדן_, _yudi, ensä_, नस्थ,
   {{0xdcf701c2,0x764107ef,0x644807f0,0x20190195}},	//   _baxı, _mily, _xudi, bosi_,
   {{0x6618024e,0x776907f1,0x201907f2,0x2d8c0067}},	//   zovk, _neex, cosi_, żde_,
   {{0x69d507f3,0x6d450069,0xef1f07f4,0x4a4303e6}},	// [420] _boze, _fgha, ngül_, знув,
   {{0x3ea0010d,0xe9d707f5,0x9f59000d,0xa96a07f6}},	//   _ipit_, бку_, visé_, امام_,
   {{0x442f07f7,0xb86507f8,0xdb1d002a,0x6008037a}},	//   _ohg_, قانو, _bosó, yıml,
   {{0x644807f9,0x46ea07fa,0x9f59000d,0x76490138}},	//   _rudi, лден_, tisé_, _buey,
   {{0x6448011c,0x764107fb,0x661807fc,0xa6fa0037}},	//   _sudi, _bily, tovk, دعاء_,
   {{0x644807fd,0x7c2407fe,0x9f5902e1,0x442f010d}},	//   _pudi, llir, risé_, _ahg_,
   {{0xdcf701c2,0xd4670202,0x661807ff,0x7641001e}},	//   _yaxı, бије_, rovk, _dily,
   {{0xdb060076,0x32540800,0x77690801,0x938a05ac}},	//   _zaká, овир, _geex, уска_,
   {{0x20190802,0x6008033e,0x316c022e,0xaac80803}},	//   vosi_, rıml, tadz_, रमिक,
   {{0xc05a0804,0x64480805,0x7641001e,0x442f0159}},	//   лім_, _tudi, _gily, _ehg_,
   {{0x64480806,0x20190807,0x59c90808,0x3ea00809}},	//   _uudi, tosi_, रातर, _apit_,
   {{0x1ac800b8,0x7c24080a,0x00000000,0x00000000}},	//   रमाथ, jlir, --, --,
   {{0x2019080b,0x2d98080c,0x8af000a8,0x00000000}},	//   rosi_, ffre_, ncəd, --,
   {{0xddcd004e,0x6d48011c,0x2019080d,0x10f900b5}},	//   _stał, ždan, sosi_, ابیں_,
   {{0x69d5080e,0x7c24080f,0xd12f0810,0x9cc8010b}},	//   _roze, flir, _хх_, быта_,
   {{0x68e1007c,0x69d50811,0xdb0f0453,0x9b590812}},	//   _üldi, _soze, _hacé, риат_,
   {{0x69d50813,0xdd91004f,0x4424007c,0x77690814}},	// [430] _poze, _قوة_, ilm_, _reex,
   {{0x4424013c,0x6d45002f,0xceb4016b,0x00000000}},	//   hlm_, _ugha, _זיץ_, --,
   {{0x7c240815,0xdb1d0816,0x69d50817,0xdcf700a8}},	//   blir, _insí, _voze, _taxı,
   {{0x76410818,0x76b90819,0x764902d7,0x64420305}},	//   _sily, илер_, _puey, _nioi,
   {{0xdb2300f8,0x7641081a,0xdce50116,0x9a84081b}},	//   _روسی, _pily, _mehč, _нурл,
   {{0x27fd001e,0x442f081c,0x4efc011d,0xa2cc06fe}},	//   siwn_, _shg_, נהגו, तमन्,
   {{0x3623006c,0x628001bf,0x00000000,0x00000000}},	//   _ہورہ, ermo, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6442081d,0x7641008c,0x00000000,0x00000000}},	//   _dioi, _tily, --, --,
   {{0xe1f9081e,0xfaff053e,0xdb0f021d,0xef1f0448}},	//   рго_, _reël_, _cacé, rgül_,
   {{0x3ea0081f,0x600a0820,0xa06903fa,0x62800211}},	//   _spit_, ином_, јама_, armo,
   {{0xd9a60821,0x64420822,0x3ea0012f,0x7a30017b}},	//   _ऑस्ट, _gioi, _ppit_, mäte,
   {{0xdb0f01dd,0x11d50823,0x8db601e0,0x00000000}},	//   _facé, _мікр, осві, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9d430009,0x00000000,0x00000000,0x00000000}},	//   дерд, --, --, --,
   {{0xdb0d0037,0xdb1d0824,0xfaff0298,0x00000000}},	//   adaí, _ensí, _teël_, --,
   {{0x533600c2,0xeab70036,0x7c360282,0x3ea00612}},	// [440] ַנען_, ойт_, rmyr, _upit_,
   {{0xa2cc0825,0xa6ca05f5,0xa2b10826,0x7a300827}},	//   _तपस्, یوال_, _अनन्, käte,
   {{0x7c240828,0xeb9a002d,0xa17a0070,0xb17a0070}},	//   plir, _кин_, שטעט, שטער,
   {{0xb09a0070,0xdb040079,0x7a300421,0x00000000}},	//   ייער, idiú, däte, --,
   {{0x7bc60829,0xdce700ea,0x00000000,0x00000000}},	//   _inku, majā, --, --,
   {{0x78af00c3,0xdce70228,0xfa67082a,0x00000000}},	//   äivä, lajā, _фарк_, --,
   {{0x37e600d4,0xdb0f002a,0xa6d80033,0x2be1021a}},	//   _довг, _racé, _দেশট, _नवमा,
   {{0x68e3082b,0x7dd000c3,0xdce70228,0x00000000}},	//   ønde, _väsy, najā, --,
   {{0x7762082c,0xc1a6052c,0xdceb082d,0x628003d0}},	//   mbox, ојни, _čiče, urmo,
   {{0x77620523,0x68e900b8,0x2be10035,0x64a6082e}},	//   lbox, _ředi, _नवभा, _маза,
   {{0x7bc6082f,0xc9530122,0xdce700ea,0x3d1a0099}},	//   _onku, ומת_, kajā, _मुले_,
   {{0x645a0095,0x80ab0026,0x68310830,0x6d4800f4}},	//   _itti, _जनरे, rådg, ždal,
   {{0xf7730122,0x11d30118,0x37bc0831,0x00000000}},	//   וקר_, ستید, _অকার, --,
   {{0x7bc60832,0x00000000,0x00000000,0x00000000}},	//   _anku, --, --, --,
   {{0xf1a90833,0xdb6b0834,0xdb0d0079,0x9b6b0279}},	//   _دانه_, ирал_, rdaí, ишаа_,
   {{0x3eb00086,0x3d1a00a1,0xf1e0021a,0x00000000}},	//   ältä_, _मुळे_, _पकडन, --,
   {{0x161a0835,0x2aab0836,0x776202d7,0x00000000}},	// [450] धवार_, штво_, dbox, --,
   {{0x645a0837,0x7bc60273,0x9998023a,0x657a00cc}},	//   _otti, _enku, _pirš_, _ndth,
   {{0x6d550035,0x00000000,0x00000000,0x00000000}},	//   mcza, --, --, --,
   {{0x27e900b5,0x9998010b,0x80380070,0x6d550067}},	//   óan_, _virš_, ַנגע_, lcza,
   {{0x645a0838,0x68e301b4,0xc21a0066,0x41bc012f}},	//   _atti, øndb, नकाब_, ्ञास,
   {{0x7a3001ae,0x6b8d0839,0x00000000,0x00000000}},	//   täte, lgag, --, --,
   {{0x69cd0099,0x00000000,0x00000000,0x00000000}},	//   साठी, --, --, --,
   {{0xf773083a,0x7a30083b,0x59c901d1,0x6aad023c}},	//   _زار_, räte, रावर, owaf,
   {{0x645a083c,0xdb0f0300,0x69c70009,0xc7b2011d}},	//   _etti, _incó, _knje, _אבן_,
   {{0x200b0067,0x765b083d,0x95c8083e,0x00000000}},	//   enci_, _ituy, _муха_, --,
   {{0x6d55004e,0xc617083f,0x69c70478,0x00000000}},	//   dcza, दकीय_, _mnje, --,
   {{0xdb040079,0x21e90168,0x6d550067,0x00000000}},	//   rdiú, _dúha_, ecza, --,
   {{0x63a90840,0xa3b4007c,0x33f40841,0xe1ee0842}},	//   meen, _छोट_, _تسلس, _зг_,
   {{0x63a90843,0xed570573,0x225f06d4,0x725a00a5}},	//   leen, зор_, mpuk_, _הכספ,
   {{0xdce700ea,0x8af000a8,0x800b00b5,0xa3cf00b4}},	//   tajā, hbət, _گروہ_, शाप_,
   {{0x69c70844,0x24510076,0x60dc0845,0x63a90846}},	//   _anje, _mám_, ärme, neen,
   {{0xfaa30847,0x765b0848,0x20020849,0xca86002d}},	// [460] нато, _ntuy, miki_, ягай,
   {{0x2002084a,0x14bd084b,0x63a90086,0x4efb00a5}},	//   liki_, ्माण, heen, _להפו,
   {{0x2451084c,0x69c7084d,0x63a9084e,0xf1d00023}},	//   _nám_, _dnje, keen, _hạch_,
   {{0x2002084f,0x69c70850,0x63a90851,0x7bc6007b}},	//   niki_, _enje, jeen, _unku,
   {{0x77620852,0xa3cf0084,0x63a90853,0xdb0601ff}},	//   rbox, शान_, deen, _bakå,
   {{0xf1d001a5,0xdb0f0391,0x9f590187,0x69c7003a}},	//   _mạch_, _encó, visí_, _gnje,
   {{0x245101a5,0x18a30854,0x247700af,0x765b0855}},	//   _cám_, _парм, găm_, _etuy,
   {{0x63a90856,0x24510857,0x20020858,0xa6d30033}},	//   geen, _dám_, jiki_, _দেওয়,
   {{0x36670859,0x2002085a,0x6d550035,0xdce500ea}},	//   _нато_, diki_, ycza, _mehā,
   {{0x683102df,0xe56100ee,0x00000000,0x00000000}},	//   råde, _päťč, --, --,
   {{0x80df00c8,0x63a9085b,0x2002085c,0x92cc0083}},	//   _ফেব্, been, fiki_, রনে_,
   {{0xf1d001a5,0x27e6085d,0x63a90139,0x2002085e}},	//   _bạch_, nkon_, ceen, giki_,
   {{0xf19400c3,0x00000000,0x00000000,0x00000000}},	//   _жиль, --, --, --,
   {{0xdb0f01f7,0x7a2b0225,0x27e6085f,0x00000000}},	//   _oncò, gütl, hkon_, --,
   {{0x20020860,0x24510019,0x6d550035,0x00000000}},	//   biki_, _xám_, rcza, --,
   {{0x69c7025c,0x27e60861,0x1bd40862,0x6b8d0863}},	//   _snje, jkon_, нося, ugag,
   {{0xf1d00019,0x27e600d5,0x00000000,0x00000000}},	// [470] _gạch_, dkon_, --, --,
   {{0x8af00095,0x2fc901e8,0x20b00864,0x321e0865}},	//   vbət, _hnag_, _जनाध, noty_,
   {{0x63a90866,0x4ddc00a5,0x67d50867,0x5c74002d}},	//   yeen, _לחזו, можу, _плэт,
   {{0xdb0f0033,0x321e0865,0x2a60006d,0x27e60008}},	//   _hací, hoty_, bpib_, gkon_,
   {{0x2451024e,0x9f4b0453,0x63a90868,0xdb0f0791}},	//   _sám_, licó_, veen, _kací,
   {{0x63a90869,0x2002086a,0x27e6029c,0x247700af}},	//   ween, ziki_, akon_, tăm_,
   {{0x63a9086b,0x5884086c,0x9f4b0453,0xdb0f0138}},	//   teen, _пыта, nicó_, _mací,
   {{0x2451086d,0x7a30086e,0xf8b200a5,0x247700af}},	//   _vám_, mäta, _בשל_, răm_,
   {{0x20020274,0x27ff05ca,0x765b0010,0x63a9086f}},	//   viki_, _imun_, _utuy, reen,
   {{0x81bc0080,0x13060086,0x68e1007c,0x63a90870}},	//   blēm, ьный_, _ülds, seen,
   {{0x66030871,0x20020872,0xf1d001a5,0x2fc901da}},	//   mink, tiki_, _sạch_, _bnag_,
   {{0x66030873,0x9f4b0831,0x2fc90874,0x351a0070}},	//   link, dicó_, _cnag_, _ווענ,
   {{0x20020875,0x62890876,0x8af001c2,0xddcd0877}},	//   riki_, queo, hbər, _svaš,
   {{0x66030878,0xc3320122,0x20020879,0x9f4b0831}},	//   nink, _סוג_, siki_, ficó_,
   {{0x27ed087a,0x8016087b,0x81bc0029,0x2002087c}},	//   _olen_, _офиц, klēj, piki_,
   {{0x6603087d,0x2d8401d6,0x22470523,0xbf9b0183}},	//   hink, şme_, _hink_, liên,
   {{0x6603087e,0xdb0f0391,0x78a900cb,0x2247087f}},	// [480] kink, _fací, _ćeva, _kink_,
   {{0xceb40669,0x66030880,0x27ff028b,0x27ed0881}},	//   _isə_, jink, _amun_, _alen_,
   {{0x66030882,0x16c60803,0x2fc9028b,0x27e60883}},	//   dink, लम्ब, _ynag_, tkon_,
   {{0xbf9b0023,0xfbdf0023,0x2b4b0176,0x9f4b027a}},	//   hiên, _hiên_, _ggcc_, licò_,
   {{0x27e60884,0xfbdf0019,0x8af000a8,0xdb1d01b4}},	//   rkon_, _kiên_, rbəs, _ansæ,
   {{0x27e60885,0x66030886,0x27ff01b7,0xdb0f0160}},	//   skon_, gink, _emun_, _facâ,
   {{0xbf9b03e6,0xc9270369,0xdcfe01d6,0x64a303fa}},	//   diên, _жорж_, _kapı, ваја,
   {{0xfbdf00e8,0x69dc0887,0x24800888,0xbf9b00f7}},	//   _liên_, _hore, čim_, nnêt,
   {{0x51860889,0x12be0033,0x22470051,0x23270274}},	//   муна, েন্দ, _bink_, моћи_,
   {{0xfbdf01a5,0x70c9045c,0x6603088a,0x69dc088b}},	//   _niên_, िमूल, cink, _jore,
   {{0x69dc088c,0x22470626,0x9f4b027a,0x321e088d}},	//   _more, _dink_, dicò_, roty_,
   {{0xe363088e,0x69dc088f,0xd011017e,0xa2a90354}},	//   _акци, _lore, الح_, _जैक्,
   {{0x3f8506d0,0xe81f0567,0xfbdf01a5,0xdb0f0890}},	//   ğlu_, यकता_, _biên_, _pací,
   {{0xbf9b0370,0x69dc0044,0x9f4b0453,0xdb060168}},	//   ciên, _nore, ticó_, _fakú,
   {{0x62860891,0xdb0f0020,0xdce70035,0x26c20355}},	//   škod, _vací, kają, _škol_,
   {{0x66030892,0xdb0d0370,0x22470893,0x1bb80037}},	//   zink, ndaç, _zink_, واقع_,
   {{0x66030894,0x63a20895,0x5a350896,0xdce7004e}},	// [490] yink, _mbon, енат, dają,
   {{0x69dc0897,0x7e6d0054,0xddc400cb,0x5887005f}},	//   _core, _iwap, _zviž, дыда,
   {{0x66030898,0x69dc0899,0x27ed089a,0x63a2089b}},	//   vink, _dore, _plen_, _obon,
   {{0x6603089c,0xdd0d004e,0x7e6d089d,0xdce70035}},	//   wink, półp, _kwap, gają,
   {{0x660301c8,0xf77005bc,0x3669089e,0x7af6004e}},	//   tink, شان_, чало_, czyt,
   {{0x69dc089f,0x7e6d08a0,0xfbdf00e2,0x00000000}},	//   _gore, _mwap, _xiên_, --,
   {{0xdcfe08a1,0x7bdd0306,0x764808a2,0x660308a3}},	//   _yapı, _kosu, _didy, rink,
   {{0x660308a4,0x7bdd0853,0xdb0601ba,0x69dc08a5}},	//   sink, _josu, _rakú, _zore,
   {{0x7bdd02b3,0xc24508a6,0x69c400b4,0x69dc08a7}},	//   _mosu, нник, राची, _yore,
   {{0x69dc0510,0xdb1d01ff,0x7bdd08a8,0xddc400ac}},	//   _xore, _insä, _losu, _sviž,
   {{0xbf9b0370,0x2000022e,0x91d00033,0x22470223}},	//   riên, _pmii_, িসংখ, _vink_,
   {{0x6e2502c2,0x34bd08a9,0x7bdd08aa,0x7e6d08ab}},	//   _akhb, ्मीद, _nosu, _bwap,
   {{0x22470176,0x63bb08ac,0x63b9016e,0x626401e0}},	//   _tink_, mdun, _iawn, _авіа,
   {{0x63bb08ad,0xf1d001a5,0x6fb20026,0x63b9003c}},	//   ldun, _hạnh_, _जसवं, _hawn,
   {{0xdca308ae,0xfbdf00e8,0x320508af,0x3d1a08b0}},	//   лари, _viên_, mily_, _मुखे_,
   {{0x63bb08b1,0xc4d200c2,0x7bdd08b2,0xdcfe00a8}},	//   ndun, נגן_, _cosu, _qapı,
   {{0x69dc08b3,0xc4bd00b4,0xfbdf0028,0x2ecb0387}},	// [4a0] _pore, ्मुख, _tiên_, ामृत,
   {{0xf1d001a5,0x81e10083,0x7ae4007b,0xdce70035}},	//   _lạnh_, নোর_, ryit, wają,
   {{0x69dc08b4,0xdcfe0716,0xc6d601cb,0xdce70035}},	//   _vore, _tapı, کتات, tają,
   {{0x764801a2,0x629b010b,0x672908b5,0x69dc08b6}},	//   _sidy, ktuo, _byej, _wore,
   {{0x69dc08b7,0x63bb08b8,0xdce70035,0x7c26009f}},	//   _tore, ddun, rają, _ikkr,
   {{0xb9060083,0x629b0430,0x7a300168,0xd5c70066}},	//   _বই_, dtuo, mäto, लागज,
   {{0x06d80083,0x764808b9,0x7bdd08ba,0xf7720037}},	//   _দেখি, _vidy, _yosu, _ماء_,
   {{0xf1d001a5,0x63bb0008,0x326608bb,0xd3700037}},	//   _cạnh_, gdun, нтов, جهة_,
   {{0x63b908bc,0x32050187,0x76480260,0x75280035}},	//   _dawn, fily_, _tidy, _wydz,
   {{0xa2b1035d,0x75280035,0x26c40065,0x7e6d0027}},	//   _अनर्, _tydz, _irmo_, _rwap,
   {{0xeb0d0084,0x68150035,0x63b90024,0x63bb0069}},	//   _सख्त_, ląda, _fawn, bdun,
   {{0x63a208bd,0x20d500c7,0x26c4023a,0x7e6d0107}},	//   _ubon, džią_, _krmo_, _pwap,
   {{0x32050076,0x91e608be,0x629b08bf,0x2d8508c0}},	//   bily_, _поде, ctuo, óleo_,
   {{0x92f2037a,0x7bdd08c1,0x00000000,0x00000000}},	//   ığım, _sosu, --, --,
   {{0x7bdd08c2,0xe5710070,0x63b908c3,0x442608c4}},	//   _posu, יַן_, _yawn, _kko_,
   {{0x7e6d08c5,0x4426023a,0x00000000,0x00000000}},	//   _twap, _jko_, --, --,
   {{0x16200066,0x7e6d08c6,0x442608c7,0xe9870274}},	// [4b0] मकार_, _uwap, _mko_, ећен,
   {{0x9999010b,0xafdb08c8,0x3ea90118,0x00000000}},	//   _rusų_, smød, _ipat_, --,
   {{0x44260202,0xd7c80118,0x78ba016f,0xa77508c9}},	//   _oko_, کونه_, _štvr, влеч,
   {{0x44260010,0x248e012f,0xfbdf0023,0x6b67000d}},	//   _nko_, dufm_, _kiêm_, _dégâ,
   {{0x7c2d08ca,0x212b0019,0x63b9007a,0x69c108cb}},	//   mlar, ́ch_, _rawn, _óleo,
   {{0x442608cc,0x7c2d08cd,0xe5a508ce,0xd12608cf}},	//   _ako_, llar, тики, _نم_,
   {{0x320508d0,0x34bd08d1,0xfbdf0019,0x66e700ea}},	//   vily_, ्मेद, _liêm_, _sīkā,
   {{0x7c2d08d2,0xd6d80083,0x629b08d3,0xe795006c}},	//   nlar, _দেওয, ttuo, _جاسک,
   {{0x63bb06a2,0x7c2d01d7,0x442608d4,0xfbdf0019}},	//   rdun, ilar, _dko_, _niêm_,
   {{0x3d1a006a,0x7c2d04d4,0x629b08d5,0x442608d6}},	//   _मुझे_, hlar, rtuo, _eko_,
   {{0x7c2d08d7,0x629b08d8,0xc95202b8,0x63b90024}},	//   klar, stuo, ימי_, _tawn,
   {{0x7c2d0723,0xdee608d9,0x629b0409,0x320500a5}},	//   jlar, воми, ptuo, sily_,
   {{0x443f08da,0x7c2d06d0,0x442d08db,0x20b00803}},	//   mmu_, dlar, mle_, _जनअध,
   {{0x644b08dc,0x3ea908dd,0x7c2d08de,0x62890079}},	//   _higi, _dpat_, elar, mreo,
   {{0x683808df,0x442d08e0,0x644b08e1,0x7c2d08e2}},	//   líde, ole_, _kigi, flar,
   {{0x2d8108e3,0x7c2d08e4,0xb7bc00c8,0x442d08e5}},	//   _edhe_, glar, _অক্ট, nle_,
   {{0x442d08e6,0xdb0f004f,0x201908e7,0x443f08e8}},	// [4c0] ile_, _pacá, érie_, imu_,
   {{0x644b08e9,0x442d08ea,0x443f08eb,0x00000000}},	//   _ligi, hle_, hmu_, --,
   {{0x7c2d08ec,0x443f08ed,0x442d08ee,0x7db500d8}},	//   blar, kmu_, kle_, _ёсьц,
   {{0x443f08ef,0x442d08f0,0x186708f1,0x7c2d08f2}},	//   jmu_, jle_, таци_, clar,
   {{0x442d000c,0x443f009f,0x6d5c0211,0x969601d3}},	//   dle_, dmu_, ocra, треш,
   {{0x442d08f3,0x442608f4,0x628908f5,0x443f08f6}},	//   ele_, _sko_, dreo, emu_,
   {{0x69ce08f7,0x644b0010,0x442d08f8,0xeb9f00d4}},	//   _inbe, _bigi, fle_, _kjøp_,
   {{0x68e308f9,0x7c2408fa,0xe4e300d4,0x644b0405}},	//   ände, noir, рішн, _cigi,
   {{0x1dc2021a,0x26c400be,0x00000000,0x00000000}},	//   शयात, _urmo_, --, --,
   {{0x442d08fb,0x7c2d08fc,0x644b08fd,0x443f01a8}},	//   ale_, zlar, _eigi, amu_,
   {{0x442d08fe,0x442608ff,0x7c2d0900,0xf9930122}},	//   ble_, _tko_, ylar, ברת_,
   {{0x4426070b,0x442d08fe,0x644b0901,0x62890037}},	//   _uko_, cle_, _gigi, breo,
   {{0x44240902,0x69ce0903,0x7c240904,0x7c2d0905}},	//   mom_, _onbe, doir, vlar,
   {{0x827700c2,0x644b0906,0x24580019,0xfbdf0019}},	//   _יעדע_, _zigi, _kém_, _viêm_,
   {{0x7c2d06a8,0x2bc40907,0x644b0908,0x7c24004f}},	//   tlar, _लोहा, _yigi, foir,
   {{0x69ce0909,0x0a6b052c,0xfbdf0023,0x7c2d0139}},	//   _anbe, држи_, _tiêm_, ular,
   {{0x7c2d090a,0x3b5406cd,0x3ea902b3,0x6d5c090b}},	// [4d0] rlar, ркур, _upat_, bcra,
   {{0x4424090c,0x7c2d090d,0x442d090e,0x00000000}},	//   hom_, slar, zle_, --,
   {{0x442d090f,0x44240910,0xf7730911,0x7c2d06d3}},	//   yle_, kom_, لاش_, plar,
   {{0x44240912,0x7c2d0669,0x69ce0913,0xb8db0914}},	//   jom_, qlar, _enbe, _अन_,
   {{0x442d0915,0xc178010b,0x644b0916,0x00000000}},	//   vle_, nkės_, _rigi, --,
   {{0x68380917,0x442d0918,0x69d8006c,0xdb0600b8}},	//   víde, wle_, övet, _jaký,
   {{0xd90f0919,0x442d091a,0x644b091b,0x443f091c}},	//   _بیا_, tle_, _pigi, tmu_,
   {{0x4424011c,0x6289091d,0x442d091e,0x443f091f}},	//   gom_, treo, ule_, umu_,
   {{0x442d0920,0x11d9004f,0x32d400d8,0x395102a7}},	//   rle_, فوظة_, ацэс, _kgzs_,
   {{0x442d0921,0x62890922,0xe0d90923,0x644b0924}},	//   sle_, rreo, ево_, _wigi,
   {{0x442d0925,0x44240926,0x3395006c,0x644b0927}},	//   ple_, bom_, _ملاز, _tigi,
   {{0x44240928,0x644b08c7,0x6838002a,0x00000000}},	//   com_, _uigi, píde, --,
   {{0x7c240248,0x3f9e0035,0x00000000,0x00000000}},	//   voir, ętu_, --, --,
   {{0x7bcf0929,0xdb04092a,0x645c0183,0x86350070}},	//   _ancu, leiç, _éric, טאָג_,
   {{0x7c2402e1,0x201900f7,0x0c79037c,0xa0a50812}},	//   toir, éric_, ксты_, _сайд,
   {{0xf0920122,0x6d5c092b,0x00000000,0x00000000}},	//   _הנה_, scra, --, --,
   {{0x7c24092c,0x00000000,0x00000000,0x00000000}},	// [4e0] roir, --, --, --,
   {{0x7bcf00c8,0x7c24092d,0x7a2b00ab,0x00000000}},	//   _encu, soir, kütu, --,
   {{0xdb04092e,0x2fd700d1,0x7c24000d,0x6fd80099}},	//   rdiñ, _شوید_, poir, यापू,
   {{0x27e000fb,0x61e005fc,0x78800076,0x4424092f}},	//   ðin_, _पक्ष, _návš, xom_,
   {{0x44240912,0x4a75086c,0x2bd10930,0xfbd10931}},	//   vom_, _выст, हारा, हारम,
   {{0x69ce02c9,0x442402b3,0x00000000,0x00000000}},	//   _unbe, wom_, --, --,
   {{0xa3cf021a,0xdb040279,0x356903d0,0xb4ce018d}},	//   शां_, feiç, трін_, शमे_,
   {{0x3a2a0932,0xd90d00d1,0x7e640933,0xf74607e5}},	//   _hkbp_, _تیم_, _otip, _бебо,
   {{0x81bc0029,0x644001a2,0x75d301cb,0x65960934}},	//   klēt, rmmi, _گيلا, _مجار,
   {{0x44240935,0x683800b8,0x245800a0,0xdd1f07c0}},	//   som_, bídc, _tém_, _líši,
   {{0x44240936,0x6ad102e4,0xf9930122,0x7e640937}},	//   pom_, _सप्र, זרת_, _atip,
   {{0xde5900d8,0x7e7d0938,0x1e1d0939,0xd36f017e}},	//   камі_, tssp, पक्ष_, _فهم_,
   {{0xbb1b0139,0x81e30033,0x00000000,0x00000000}},	//   _adîn, _নগর_, --, --,
   {{0xdb070332,0x7e7d093a,0xdb0600b5,0x52830037}},	//   ámít, rssp, _lakó, _الوك,
   {{0x7e640051,0x403505ac,0x9f520107,0x9998005f}},	//   _etip, _кекс, _olyè_, _birž_,
   {{0xf1d206bb,0xdb0600d0,0x7a2b033b,0x7a3001ba}},	//   तावन, _fakü, hütt, bätk,
   {{0x200b093b,0x4975093c,0xdb0601ba,0x7b640432}},	// [4f0] mici_, илас, _taký, стсе,
   {{0x200b093d,0xdd9101ca,0xd91b00c3,0x7e7b0009}},	//   lici_, _بود_, нье_, šups,
   {{0xd7e7093e,0x6d48093f,0x1a6505f5,0x00000000}},	//   лідо, ždar, _چیری_, --,
   {{0x200b0940,0x69d80941,0xf3f100e2,0x00000000}},	//   nici_, över, _mục_, --,
   {{0x7c3a00f7,0xdb1d0031,0xb5fd010b,0xdae600b5}},	//   ître, _masë, _atša, _پہلو_,
   {{0x48770206,0x7bd700d8,0x200b0942,0xdb0e0093}},	//   _مدرس, šbuč, hici_, _þjál,
   {{0xdb1d01b4,0x200b0943,0x25b60079,0x00000000}},	//   _ansø, kici_, شهيد_, --,
   {{0x200b0944,0x73e50945,0x69c90253,0x28e200ab}},	//   jici_, роиз, _होती, पहरि,
   {{0x200b0946,0x22150947,0x45d500af,0x00000000}},	//   dici_, ифор, _коас, --,
   {{0xe1250948,0x02050949,0x9f590036,0x7a3000c3}},	//   импи, рзон, misù_, vätk,
   {{0x200b094a,0xdb0602d0,0x7e64094b,0x6838094c}},	//   fici_, _jakò, _stip, lída,
   {{0x200b0676,0x7643094d,0xdb060359,0xf3f100e2}},	//   gici_, lmny, _makò, _dục_,
   {{0x3263006c,0xdb0602d0,0x2d9a01ef,0x326700ed}},	//   _انتہ, _lakò, _pcpe_, _стев,
   {{0x7e64024e,0x3f8c00a8,0x00000000,0x00000000}},	//   _vtip, şdu_, --, --,
   {{0x443d006f,0x7643022e,0x61e3094e,0x00000000}},	//   _khw_, imny, _ionl, --,
   {{0x61e3006c,0xab66094f,0x200b0950,0x7845010b}},	//   _honl, рвал, cici_, _tėvy,
   {{0x395600c9,0x7e64025c,0x61e3021e,0x7a2b006c}},	// [500] ањет, _utip, _konl, yütt,
   {{0x2fc001f7,0x61e30118,0xdb060260,0xdb1d0951}},	//   _haig_, _jonl, _bakò, _masè,
   {{0x61e30952,0x2cba002a,0x443d0051,0xdb1d0260}},	//   _monl, _uspd_, _ohw_, _lasè,
   {{0xb8ce0953,0x443d0297,0xe6660954,0x2d9802e9}},	//   _कह_, _nhw_, атко, lgre_,
   {{0xb86600b5,0x2fc00955,0xddd6024e,0x660a0034}},	//   _چارو, _maig_, _zvyš, tifk,
   {{0x200b0956,0xb8660957,0x2d980958,0x2fc00959}},	//   zici_, _نارو, ngre_, _laig_,
   {{0x660a095a,0x200b027d,0x3ea00024,0x7a300421}},	//   rifk, yici_, _lqit_, jäti,
   {{0xe8d70122,0x443d095b,0x7643006d,0x25a9011c}},	//   _דולר_, _chw_, amny, đala_,
   {{0x9f49027d,0x78af011c,0x443d095c,0x683801ef}},	//   _ilaç_, čivš, _dhw_, cída,
   {{0x95c7095d,0xc05a01c8,0x61e3095e,0x31600207}},	//   _клуб_, кім_, _conl, _đizs_,
   {{0x3a370397,0x61e3095f,0x3957011d,0xe97b0070}},	//   שרים_, _donl, ישים_, כניש,
   {{0x2fc0006d,0xf42700af,0x00000000,0x00000000}},	//   _caig_, _кохл_, --, --,
   {{0x200b0960,0x2fc00961,0x00000000,0x00000000}},	//   rici_, _daig_, --, --,
   {{0x200b0962,0x62800523,0x628201bf,0x2d8500a2}},	//   sici_, msmo, _ivoo, ûle_,
   {{0x52b60963,0x02b60964,0x6e270965,0x200b0966}},	//   _अनुस, _अनुन, rojb, pici_,
   {{0x3b550209,0xd0f700a5,0x2fc00176,0x61e302a2}},	//   скар, _כמות_, _gaig_, _zonl,
   {{0xa3a80967,0x62800968,0xdb1d0118,0x7d1e0282}},	// [510] ख्य_, nsmo, _kasé, _exps,
   {{0x99670969,0xf993096a,0x683800b8,0x628001ed}},	//   ртал, تبر_, vída, ismo,
   {{0x2fc001e8,0xdb1d096b,0xb9c40037,0x00000000}},	//   _yaig_, _masé, تقلي, --,
   {{0x2a69018d,0x62820207,0x00000000,0x00000000}},	//   ppab_, _ovoo, --, --,
   {{0x6fd800a1,0x27e400af,0xf9930037,0x26c901ef}},	//   यातू, _domn_, _وبس_, íao_,
   {{0x7aed096c,0x6280096d,0xa2b70355,0x00000000}},	//   myat, dsmo, ्टस्, --,
   {{0xfc3f0028,0x7aed096e,0x26c200f4,0x61e30069}},	//   _khí_, lyat, _škot_, _ronl,
   {{0x2489096f,0x81c30083,0xe3b90970,0x61e30971}},	//   čam_, _একই_, уби_, _sonl,
   {{0x7aed0452,0xdb1d0972,0xfc3f004f,0x61e30300}},	//   nyat, _basé, _mhí_, _ponl,
   {{0x6282082d,0x20090973,0x7a300974,0x61fa00a5}},	//   _dvoo, _amai_, täti, ghtl,
   {{0x628003bc,0x61e303f4,0x443d02b1,0x62820207}},	//   asmo, _vonl, _thw_, _evoo,
   {{0xfc3f0019,0xfbdf0023,0x7a300975,0x00000000}},	//   _nhí_, _kiêu_, räti, --,
   {{0x2fc00955,0x0cd00162,0x62800069,0x7a300086}},	//   _vaig_, हम्म, csmo, säti,
   {{0x61fa0976,0x7aed0977,0xfc3f0033,0xfbdf0023}},	//   chtl, dyat, _ahí_, _miêu_,
   {{0x40950514,0xfc3f0514,0x2fc001e8,0xfbdf0019}},	//   _العر, _bhí_, _taig_, _liêu_,
   {{0xfc3f0028,0x3ce5022a,0x7ff60609,0x79870359}},	//   _chí_, älva_, _دستا, _adjw,
   {{0x68e30301,0x7aed00fd,0x44c700e2,0x27e4009e}},	// [520] ändn, gyat, _lđ_, _romn_,
   {{0xc3320052,0x27e400af,0xdb04000d,0xddcd0097}},	//   לון_, _somn_, nfié, _zvaž,
   {{0xe93a015a,0x44c70023,0xb17a0070,0x9f490176}},	//   учај_, _nđ_, רטער, _plaç_,
   {{0x62800978,0x7aed0979,0x8b96097a,0x00000000}},	//   ysmo, byat, _уроч, --,
   {{0x7aed007b,0x673b0035,0x683800b8,0x00000000}},	//   cyat, _czuj, bídn, --,
   {{0x99d603c7,0xd49a097b,0x44c700e2,0x600f0359}},	//   _اتحا, гри_, _bđ_, _kòmè,
   {{0x320c0260,0x44c70019,0x758901e0,0xdb1d000d}},	//   vidy_, _cđ_, рсів_, _rasé,
   {{0xc7a3097c,0x6280097d,0x6286010b,0x07a303d0}},	//   _ниск, tsmo, škom, _насн,
   {{0x6d430097,0x320c097e,0xdb1d0118,0x00000000}},	//   _únav, tidy_, _pasé, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20190370,0x44c700e2,0x3fd9002d,0x546a0279}},	//   ério_, _gđ_, амнэ_, _саем_,
   {{0x7aed01c2,0xf53700a5,0xdb0f0042,0x657a00e5}},	//   yyat, _פנאי_, _vacú, _heth,
   {{0x657a00d1,0x733600bf,0x8336097f,0x74c00355}},	//   _keth, _ارائ, _اراض, विकृ,
   {{0x329b02da,0x645a0980,0x657a0981,0x7aed0982}},	//   _עבוד, _kuti, _jeth, vyat,
   {{0xfc3f0028,0x657a0983,0xf1a900bf,0x645a0984}},	//   _phí_, _meth, _خانه_, _juti,
   {{0x645a0985,0x657a0986,0x317e01ae,0x7aed0987}},	//   _muti, _leth, latz_, tyat,
   {{0x645a0988,0x1a5b004f,0xed4e00b5,0x00000000}},	// [530] _luti, اشرة_, ٹھی_, --,
   {{0x645a02e1,0x317e0989,0x9f4b0355,0x657a098a}},	//   _outi, natz_, nkcí_, _neth,
   {{0xe8e0098b,0x2bc402cb,0xfbdf0023,0x3178004e}},	//   ười_, _लोका, _siêu_, órzy_,
   {{0x317e098c,0x657a098d,0x473503e6,0x00000000}},	//   hatz_, _aeth, онес, --,
   {{0x657a098e,0x6aa4098f,0x3f89002f,0x6286010b}},	//   _beth, ctif, _mdau_, škoj,
   {{0x645a0990,0x25a9044d,0x657a00d1,0x2bd106fe}},	//   _buti, đalo_, _ceth, हाका,
   {{0x69d50991,0x645a002d,0x8ccc0992,0x44290019}},	//   _inze, _cuti, हियो, _ưa_,
   {{0xfbdf0028,0x69c50993,0x657a0051,0x61f80223}},	//   _tiêu_, ldhe, _eeth, _alvl,
   {{0xe1f90994,0x6fdd02cb,0xdb1d0995,0x657a0996}},	//   иги_, यानं, _insó, _feth,
   {{0x69c50997,0x657a0998,0x00850036,0x44c700e2}},	//   ndhe, _geth, олоо, _tđ_,
   {{0xf99202da,0x69c5004a,0x645a0999,0x7a300086}},	//   ורי_, idhe, _guti, mätt,
   {{0x7a30099a,0x777b0248,0x81bc00ea,0x26cd02d7}},	//   lätt, _jeux, slēp, _kreo_,
   {{0xeef501c8,0x3f89001e,0x645a099b,0x69d5099c}},	//   пярэ, _ddau_, _zuti, _onze,
   {{0x317e034d,0x201901d1,0x442f0118,0x2d9e099d}},	//   catz_, ansi_, _hkg_, üte_,
   {{0x69c5099e,0x68e3033b,0xd1b8099f,0x271509a0}},	//   ddhe, ändl, _دانا_, तपुर_,
   {{0x69d502bf,0xa2cd00b8,0x6aa409a1,0x63a909a2}},	//   _anze, तिप्, ttif, nfen,
   {{0xb4b609a3,0x261a017a,0x7bc409a4,0xfaa309a5}},	// [540] _छन्_, _बदली_, rdiu, мато,
   {{0x69c509a6,0x8eb3006c,0xe9d709a7,0x99630097}},	//   gdhe, _کمیش, оку_, _píšu_,
   {{0x02b609a8,0xd910006c,0x7a300421,0x20dc00a0}},	//   _अन्न, ریر_, dätt, pšiť_,
   {{0x657a00f8,0x69c509a9,0x69d509aa,0x65630019}},	//   _seth, adhe, _enze, ecnh,
   {{0x26cd09ab,0x645a00d8,0x777b0248,0x657a09ac}},	//   _creo_, _suti, _deux, _peth,
   {{0x63a909ad,0x7c3609ae,0x7641016e,0x7aeb09af}},	//   efen, llyr, _chly, ägte,
   {{0x63a909b0,0x5fca09b1,0x6fca0325,0x5fdd084b}},	//   ffen, ियाल, ियां, यामल,
   {{0x657a09b2,0x63a9001e,0x26cd002a,0xdb1d0392}},	//   _weth, gfen, _freo_, _insò,
   {{0x657a09b3,0x26cd011e,0x7a300523,0x23a609b4}},	//   _teth, _greo_, bätt, क्षद,
   {{0x914a09b5,0x645a09b6,0x154600af,0x238c00c7}},	//   ична_, _tuti, _дезм, dėjų_,
   {{0x645a03ad,0x425400d1,0x317e09b7,0x1dde09b8}},	//   _uuti, _کنتر, ratz_, मानत,
   {{0x317e01ae,0xddc40160,0x765b0103,0x00000000}},	//   satz_, _puiş, _yuuy, --,
   {{0x41e600d8,0x00000000,0x00000000,0x00000000}},	//   _міка, --, --, --,
   {{0x81f809b9,0x3f84008d,0x386a0183,0x00000000}},	//   _دفتر_, ómur_, _otbr_, --,
   {{0x271c01a5,0x644209ba,0x71260037,0x00000000}},	//   ỉnh_, _khoi, _برشل, --,
   {{0x3958013a,0xdfd10079,0x929d0067,0x00000000}},	//   _agrs_, _أية_, szłe, --,
   {{0x34b7051d,0x644209bb,0x8af000a8,0xdb1d0260}},	// [550] _आन्द, _mhoi, dcəs, _ansò,
   {{0x78a500fb,0x25ef0380,0x59d201d1,0x683800ac}},	//   tthv, _अवधी_, सागर, sídl,
   {{0x69c509bc,0x290701da,0x26cd011c,0x9f400093}},	//   rdhe, àna_, _sreo_, _hlið_,
   {{0x26cd0009,0x78a509bd,0x76410031,0x69c50031}},	//   _preo_, rthv, _shly, sdhe,
   {{0x2bc40302,0x7c2d0074,0x7bda0122,0x7a300974}},	//   _लोटा, moar, _הקרו, tätt,
   {{0x7c2d09be,0x26cd0043,0x29070037,0x1dde021a}},	//   loar, _vreo_, únas_, मायत,
   {{0x7a3009bf,0x644202a8,0x6ab90095,0xdb1d05ed}},	//   rätt, _bhoi, şafı, _masí,
   {{0x7a3009bf,0x57b409c0,0x644209c1,0x7c2d06a2}},	//   sätt, _обст, _choi, noar,
   {{0xd5bb09c2,0x644209c3,0x63a909c4,0x7c2d01a3}},	//   _все_, _dhoi, rfen, ioar,
   {{0x7c2d09c5,0xdb0d09c6,0x00000000,0x00000000}},	//   hoar, ndañ, --, --,
   {{0xf9920779,0x6442003b,0x7c2d0291,0x3eb209c7}},	//   ערט_, _fhoi, koar, _spyt_,
   {{0xb4d70567,0xa3bb03c5,0x644209bb,0x7f85006c}},	//   ामी_, _خاطر_, _ghoi, ولپن,
   {{0x7c2d09c8,0x644909c9,0xdb1d09ca,0x317c023a}},	//   doar, mmei, _basí, _fevz_,
   {{0x644909cb,0xdb1d007e,0xfce609cc,0x8b080067}},	//   lmei, _casí, пого, nięż,
   {{0xe6b80240,0x7c2d09cd,0x1fb609ce,0x7c3a00a2}},	//   _इन्ज, foar, _еспр, îtro,
   {{0x644909cf,0x1e8609d0,0x7c2d09d1,0x00000000}},	//   nmei, _елим, goar, --,
   {{0x3f8209d2,0xdcfc0506,0x00000000,0x00000000}},	// [560] maku_, marč, --, --,
   {{0x3f820614,0x644909d3,0x442d09d4,0x386a0069}},	//   laku_, hmei, hoe_, _ptbr_,
   {{0x53bd0378,0x9f5900de,0xb3bd01d1,0x644909d5}},	//   ्याश, cisó_, ्याख, kmei,
   {{0x3f8209d6,0x7a3001ae,0xdb1d00b8,0x7c2d0171}},	//   naku_, täts, _zasí, coar,
   {{0x442d09d7,0x5fdd00a1,0x644909d8,0x2907008d}},	//   doe_, यातल, dmei, únar_,
   {{0x7bc609d9,0x644209c3,0xe5340572,0x3f8209da}},	//   _haku, _shoi, мель, haku_,
   {{0x7bc609db,0x6442066a,0x3f8209dc,0x6449095a}},	//   _kaku, _phoi, kaku_, fmei,
   {{0x293702b5,0x7bc609dd,0x00000000,0x00000000}},	//   _זאלן_, _jaku, --, --,
   {{0x7bc609de,0xdb0d0093,0x64a000f4,0x00000000}},	//   _maku, ndað, dšiš, --,
   {{0x7bc609df,0x7c2d09e0,0x6e2e09e1,0x644209e2}},	//   _laku, zoar, jobb, _whoi,
   {{0x644209e3,0x5f9509e4,0x6e2e09e5,0x442d09e6}},	//   _thoi, минт, dobb, boe_,
   {{0x7c2d06a2,0x3f8209e7,0x04db00a5,0xab5b01f7}},	//   xoar, gaku_, _לקבל, _caül,
   {{0x7c2d002d,0x63a209e8,0xdb0d0279,0xdb1d00a0}},	//   voar, _icon, meaç, _pasí,
   {{0x91e309e9,0x611409ea,0x7bc6010d,0x9f590079}},	//   _поче, _одлу, _aaku, mhsí_,
   {{0x7c2d09eb,0x7bc609ec,0x3f8209ed,0x7d2406e4}},	//   toar, _baku, baku_, ефте,
   {{0x7bc609ee,0x61ea09ef,0x2c0d0099,0x3f8209f0}},	//   _caku, _hofl, _सगळं_, caku_,
   {{0x4a5509f1,0x7c2d06a2,0x7bc609f2,0xb3a90033}},	// [570] дкас, roar, _daku, _খোঁজ,
   {{0x7c2d09f3,0x6838000c,0x7e6d09f4,0x5a3403fa}},	//   soar, bídk, _itap, енут,
   {{0x7bc609f5,0x2d8309f6,0x41ae0967,0x7c2d09f7}},	//   _faku, maje_, ज्यस, poar,
   {{0x27e9064b,0x2d9c06d7,0x2d8309f8,0x6568028b}},	//   ðan_, _över_, laje_, _afdh,
   {{0x6fa509f9,0x442d02c4,0x7e69002d,0xe69b0067}},	//   _कानू, voe_, _împă, _żołą,
   {{0x7bc609fa,0x2d8309fb,0xdcfc02a7,0x7e6d08c7}},	//   _zaku, naje_, zarč, _mtap,
   {{0x7bc606f9,0x442d09fc,0x644909fd,0x7e6d028b}},	//   _yaku, toe_, tmei, _ltap,
   {{0x69c709fe,0x7e6d09ff,0x2d830a00,0x9cd8024b}},	//   _haje, _otap, haje_, לווה_,
   {{0x69c70a01,0x64490a02,0x442d095e,0xdcfc0a03}},	//   _kaje, rmei, roe_, varč,
   {{0xa8790070,0x3f820a04,0x69c70a05,0x442d0a06}},	//   ֿאָר, waku_, _jaje, soe_,
   {{0x3f820118,0x9327006c,0x63a20a07,0x7e6d0a08}},	//   taku_, _کران, _fcon, _atap,
   {{0x69c700bf,0x63a20037,0x68380355,0xa2cd06bc}},	//   _laje, _gcon, vídk, तिद्,
   {{0x63bb023c,0xb5fd0a09,0x00000000,0x00000000}},	//   meun, _atši, --, --,
   {{0x7bc60a0a,0x69c70a0b,0x3f820a0c,0x2d830a0d}},	//   _saku, _naje, saku_, gaje_,
   {{0xed570272,0x7bc60a0e,0x3f820a0f,0x6e2e0a10}},	//   дор_, _paku, paku_, robb,
   {{0x6e2e0a11,0x8c4306e4,0xaac902b4,0x00000000}},	//   sobb, весе, रिंक, --,
   {{0x69c70a12,0x7bc60a13,0x2d830a14,0xc222006c}},	// [580] _baje, _vaku, baje_, _سکیو,
   {{0x7bc60a15,0x7c290a16,0x68380279,0x69c70a17}},	//   _waku, čera, mídi, _caje,
   {{0xb4d707b5,0x69c70a18,0x1c460a19,0x00000000}},	//   ामो_, _daje, _оном, --,
   {{0x63bb0a1a,0x00000000,0x00000000,0x00000000}},	//   jeun, --, --, --,
   {{0xa3e1035d,0x63bb0a1b,0x69c70a1c,0x6b840a1d}},	//   दान_, deun, _faje, maig,
   {{0x6b84066a,0x69c70a1e,0x63a20a1f,0x00000000}},	//   laig, _gaje, _scon, --,
   {{0x628f0a20,0x61ea0a21,0xe9a30a22,0xdb0f00f6}},	//   ácon, _rofl, _шарп, _abcè,
   {{0x69c70a23,0x6b840a24,0x2d830a25,0xd9430a26}},	//   _zaje, naig, zaje_, _реси,
   {{0x752d00d0,0x2d830a27,0xdb1d00ac,0x69c70a28}},	//   ğaza, yaje_, _kasá, _yaje,
   {{0x27e60a29,0x6b840a2a,0x24f60a2b,0x683801ef}},	//   ljon_, haig, _очер, dídi,
   {{0xdb1d024e,0x2d830a2c,0x6b840a2d,0x7e6d0a2e}},	//   _masá, vaje_, kaig, _stap,
   {{0x68e30a2f,0x83fc044d,0x63bb01ef,0x2d830a30}},	//   ändi, _buđe, ceun, waje_,
   {{0x2d830a31,0x6b840a32,0xfe6e00b5,0xe46a0093}},	//   taje_, daig, یگی_, blöð_,
   {{0x02bc0026,0x61ac0033,0xdb1d0097,0x26c4021d}},	//   ्टीन, _কোরআ, _nasá, _msmo_,
   {{0x2d830a33,0x6b840037,0x7c84002d,0x3f800211}},	//   raje_, faig, куте, _feiu_,
   {{0x2d830a34,0xa3e10324,0xa008004f,0x69c70a35}},	//   saje_, दाय_, _يقول_, _saje,
   {{0x69c70a36,0x7e6d0a37,0x2d830a38,0x68380a39}},	// [590] _paje, _utap, paje_, cídi,
   {{0x2fc90a3a,0x1e14002d,0xb5fd0207,0xdb1d0a3b}},	//   _haag_, _амья, _kuše, _casá,
   {{0x6b8400d8,0x61e7013c,0x69c70a3c,0x26c401a3}},	//   baig, öjli, _vaje, _asmo_,
   {{0x69c70a3d,0x6b840a3e,0x2fc9053e,0x27e60a3f}},	//   _waje, caig, _jaag_, gjon_,
   {{0xb4d70a40,0xdb1d0a41,0xd7c80a42,0x2fc90a43}},	//   ाम्_, _ansö, بونه_, _maag_,
   {{0xa2cd0a44,0x7a2b01ae,0x2fc902e6,0x69c708c7}},	//   तिस्, hütz, _laag_, _uaje,
   {{0x63bb0a45,0x2d8100ab,0x97a70a46,0x6fa500a1}},	//   teun, _mehe_, _орал, _काढू,
   {{0x2d810a47,0x321e0355,0xee3f01ba,0x75fd0260}},	//   _lehe_, enty_, dtým_, _dèza,
   {{0xc6a4087b,0x63bb0a48,0xb06500c3,0x17f80037}},	//   _архи, reun, kyää, _غرفة_,
   {{0xddc401cc,0x63bb0a49,0xdb040a4a,0xb5fd0a4b}},	//   _otiš, seun, nfiá, _buše,
   {{0x83fc0254,0xdcfc013a,0x27ff02a7,0x00000000}},	//   _suđe, karā, _klun_, --,
   {{0xb5fd0a4c,0x2fc901e8,0x6838002a,0x27ed0328}},	//   _duše, _caag_, tídi, _joen_,
   {{0x2fc90a4d,0x79850a4e,0x2d8101a3,0x25f500b4}},	//   _daag_, kahw, _behe_, ्सपी_,
   {{0x68380a4f,0x27ff001e,0x20020a50,0x11d90037}},	//   rídi, _llun_, shki_, _روعة_,
   {{0x6b840a51,0xc5f200c2,0x64590a52,0x7c290a53}},	//   taig, נדל_, _kiwi, čern,
   {{0x68380a54,0x64590118,0x83fc011c,0x27ed0a55}},	//   pídi, _jiwi, _tuđe, _noen_,
   {{0x64590a56,0x6b840a57,0x499600af,0xda650286}},	// [5a0] _miwi, raig, ешет, نالي,
   {{0x6b84009c,0x2d8101ae,0x27ff0a58,0x62890037}},	//   saig, _gehe_, _alun_, iseo,
   {{0x6d5e02b3,0x7d7b00a5,0xdb1d00b5,0x6b840a59}},	//   _igpa, _מניו, _vasá, paig,
   {{0x1dde052f,0x25a500e5,0x64590a5a,0x27ff00e5}},	//   मावत, _acll_, _niwi, _clun_,
   {{0x27ed019c,0x6d5e012f,0x79850010,0x27e60a5b}},	//   _doen_, _kgpa, bahw, rjon_,
   {{0x27e60a55,0x25a50176,0x2d810065,0x3e6600e2}},	//   sjon_, _ccll_, _xehe_, _môt_,
   {{0xd9430a5c,0x69dc0a5d,0x8cd30a5e,0x6d5e010d}},	//   _бери, _inre, डियो, _mgpa,
   {{0xb5fd01a0,0xb4b00006,0x27ff05b9,0x64590a5f}},	//   _ruše, _ओही_, _glun_, _ciwi,
   {{0x7ae4043f,0xa2cd035d,0x64590a60,0xaac901c0}},	//   nxit, तिष्, _diwi, रिएक,
   {{0xb5fd0a61,0x44ce004e,0x171b0070,0x2fc90a62}},	//   _puše, _tę_, _זומע, _saag_,
   {{0x7a2b02c9,0x200001da,0x2d810a63,0x98b300cd}},	//   tütz, _blii_, _rehe_, čeće_,
   {{0x2d8101ae,0x20000211,0x64590090,0x00000000}},	//   _sehe_, _clii_, _giwi, --,
   {{0x69dc03c4,0xddc40a16,0xdcfc02d4,0x20000211}},	//   _onre, _stiš, varā, _dlii_,
   {{0xa2cd0a64,0x62860a65,0xb5fd0a66,0x80d0021a}},	//   तिर्, škos, _tuše, धिदे,
   {{0x2fc9006d,0x765a0a67,0x9c47021f,0xd24d05f5}},	//   _taag_, _mity, ехал, _بچي_,
   {{0x69dc0a68,0x7c290a69,0xd7cf007c,0xc178010b}},	//   _anre, čero, _सोंच, lbė_,
   {{0x3b550a6a,0x5a3506c2,0x2d810a6b,0xa3e105f7}},	// [5b0] ткар, внат, _tehe_, दात_,
   {{0x27ed0a6c,0x765a0088,0x61fa0a6d,0xb4b0007c}},	//   _soen_, _nity, nktl, _ओहू_,
   {{0x79850a6e,0xdcfc00ea,0xe61100b5,0x27ed0a6f}},	//   rahw, parā, یشت_, _poen_,
   {{0x69dc0a70,0x87e40a71,0x2000009e,0xe7190037}},	//   _enre, люче, _xlii_, ويات_,
   {{0xf7700a72,0x7bdd0a73,0x765a0a74,0x00000000}},	//   صان_, _insu, _bity, --,
   {{0x0c7400bf,0x6aad002f,0x248c0168,0x27e000ea}},	//   _جدید, mtaf, _bvdm_, ķina_,
   {{0xdb04008a,0x27ed0a75,0x765a00f8,0x6aad0a76}},	//   leið, _toen_, _dity, ltaf,
   {{0xc447006c,0x7bcd0a77,0x27ff07d4,0x1958021f}},	//   ریشن_, ndau, _ulun_, _часы_,
   {{0x24800a78,0x3863012f,0x7c3a0248,0x6459002f}},	//   ćima_, _hujr_, îtri, _viwi,
   {{0x62890a79,0x645900bf,0x765a0a7a,0x7bdd0430}},	//   rseo, _wiwi, _gity, _lnsu,
   {{0x7bdd0a7b,0x34940a7c,0x62890a7d,0x67290069}},	//   _onsu, _бахр, sseo, _hxej,
   {{0xdb040093,0xb4bd00ab,0x6289018d,0x00000000}},	//   keið, इबी_, pseo, --,
   {{0x6d450a7e,0x764800c3,0x62860207,0x00000000}},	//   _azha, _yhdy, škor, --,
   {{0x7bdd0a7f,0x51870a80,0x7af60421,0x00000000}},	//   _ansu, _чуда, vyyt, --,
   {{0x6e3c00e5,0x15f40a5e,0x75fd0260,0x6aad0a81}},	//   rlrb, _अवसर_, _lèzo, etaf,
   {{0x3e660a82,0x7ae401d7,0x7bcd043d,0x9f060088}},	//   _tôt_, txit, gdau, _لوبو,
   {{0xdfd20332,0x6d4500d7,0xa9a6081b,0x00000000}},	// [5c0] _ميں_, _ezha, киад, --,
   {{0xfe9b02b8,0xafdb0185,0x7bdd0a83,0x6d5e011e}},	//   _קיימ, smøt, _ensu, _ugpa,
   {{0x83fc025c,0x7e640086,0x7af600c3,0xeb9f08c8}},	//   _luđa, _huip, syyt, _blød_,
   {{0xdb04003e,0x7e640a84,0x660100ab,0x765a02d0}},	//   beið, _kuip, _allk, _sity,
   {{0x765a0a85,0x77910a86,0xc17800d8,0xc7a30a87}},	//   _pity, صیلا, ybė_, ричк,
   {{0x68380279,0x69dc0a88,0x9633010b,0x00000000}},	//   vídu, _unre, аніц, --,
   {{0x38630118,0x7e640a89,0xeb9f0a8a,0x765a0a8b}},	//   _gujr_, _luip, _flød_, _vity,
   {{0x83fc0009,0xeb9f0a8c,0x59e001d1,0x656a0098}},	//   _buđa, _glød_, नावर, scfh,
   {{0x2a660079,0x765a030d,0x00000000,0x00000000}},	//   íobh_, _tity, --, --,
   {{0x320500a5,0x765a021e,0x00000000,0x00000000}},	//   ghly_, _uity, --, --,
   {{0xa99b02b5,0x68380279,0x61fa0a8d,0xbb1b00af}},	//   וביר, sídu, rktl, _neîn,
   {{0xc05801c8,0x66180a8e,0xeb9f0a8a,0x00000000}},	//   кія_, livk, _kløe_, --,
   {{0x442600f8,0xa29400d8,0x7e640118,0x00000000}},	//   _ijo_, _салі, _cuip, --,
   {{0x273101a5,0x32050a8f,0xdb040093,0xb5fd0506}},	//   ỡng_, chly_, veið, _kuša,
   {{0x4426071f,0xab9502bb,0xb4b0052f,0xe6bf0a90}},	//   _kjo_, ливі, _ओहो_, _एन्ज,
   {{0x6aad0a91,0x2cba0160,0xb5fd0a92,0xa4b700a5}},	//   ttaf, _dppd_, _muša, כללה_,
   {{0xab840a93,0x20190a94,0x7e640a95,0x44260282}},	// [5d0] руск, misi_, _guip, _mjo_,
   {{0xdb040093,0xb5fd0009,0x7bcd0a96,0x661808b7}},	//   reið, _ouša, sdau, jivk,
   {{0x6aad0a97,0x44260a98,0x9964021d,0x67d503e6}},	//   staf, _ojo_, ртул, ложу,
   {{0x7bdd0a99,0x20190a9a,0xc79400d8,0xba77017e}},	//   _unsu, nisi_, аршы, _لاست,
   {{0x4b7a02da,0xa3e1017a,0xdb1d0523,0x3a840104}},	//   _ראשו, दास_, _baså, _высв,
   {{0xd1260a9b,0x4426071f,0xa2b8051d,0x2019000e}},	//   _هم_, _ajo_, ्बन्, hisi_,
   {{0x2baa0355,0x20190a9c,0x442606f2,0xb4bd00ab}},	//   ङ्का, kisi_, _bjo_, इबे_,
   {{0x20190a9d,0x957c005f,0x6e350065,0x00000000}},	//   jisi_, _anąd, hozb, --,
   {{0x20190a9e,0xe3b6021f,0x44260260,0x55a500b5}},	//   disi_, убы_, _djo_, _مجاہ,
   {{0x44260010,0xa3e104bc,0x6e3500cd,0x60e90a9f}},	//   _ejo_, दाह_, jozb, емом_,
   {{0x20190aa0,0x7c2903ab,0xb5fd0009,0x7e6409a9}},	//   fisi_, čerj, _guša, _suip,
   {{0xc50c0070,0x20190aa1,0xbb1b00af,0x7e64026e}},	//   _קלאָ, gisi_, _reîn, _puip,
   {{0x443f0aa2,0xd24e00f8,0x7e6400f6,0x2cba00d7}},	//   mlu_, تنی_, _quip, _sppd_,
   {{0x443f0aa3,0x831a02b5,0xdca60281,0x2292004f}},	//   llu_, _אונז, лаги, _الوس,
   {{0x20190aa4,0x443f018d,0x00000000,0x00000000}},	//   bisi_, olu_, --, --,
   {{0x443f0aa5,0x20190aa6,0x3ec900c3,0x68380138}},	//   nlu_, cisi_, ättä_, hídr,
   {{0x2baa0355,0xfbaa0355,0x443f0aa7,0x8eb300f8}},	// [5e0] ङ्गा, ङ्गम, ilu_, _هميش,
   {{0x443f0aa8,0xd8390107,0x7a30033b,0x00000000}},	//   hlu_, _akō_, lätz, --,
   {{0x443f0aa9,0xb8650aaa,0x3ea20aab,0xad5a0210}},	//   klu_, لانو, lukt_, _ярих_,
   {{0x443f0aac,0x2bab0aad,0x2d8a0273,0x2a69006d}},	//   jlu_, _छाया, labe_, bqab_,
   {{0x443f0aae,0x60060aaf,0xb5fd0ab0,0xa3d70826}},	//   dlu_, _góme, _suša, ायन_,
   {{0x45d40ab1,0x7a3001ae,0x7c24002d,0x443f0ab2}},	//   рокс, hätz, lnir, elu_,
   {{0x20190ab3,0x443f0ab4,0x5faa00a1,0x7c240ab5}},	//   yisi_, flu_, _काढल, onir,
   {{0x69ce0ab6,0x7c240ab7,0x68e30ab8,0x2d8a0ab9}},	//   _habe, nnir, ånde, habe_,
   {{0x69ce0aba,0x20190abb,0x6b8602c4,0x2d8a0abc}},	//   _kabe, visi_, _mekg, kabe_,
   {{0x69ce06a2,0x32b7004f,0x20190abd,0x443f0abe}},	//   _jabe, ادية_, wisi_, alu_,
   {{0x20190abf,0x44260ac0,0x03140722,0x69ce0ac1}},	//   tisi_, _tjo_, _तेरह_, _mabe,
   {{0x443f0ac2,0x69ce0ac3,0x7c240254,0x9f490093}},	//   clu_, _labe, jnir, _blað_,
   {{0xa3e10ac4,0x20190ac5,0x4ea7002d,0x80ca0033}},	//   दार_, risi_, ырна, িমধ্,
   {{0x20190ac6,0xd250004f,0x64400ac7,0x2fcd0254}},	//   sisi_, _بنت_, llmi, žeg_,
   {{0x021700a5,0x2a69006d,0xafdb01b4,0x6b860298}},	//   _תחום_, wqab_, rløb, _bekg,
   {{0xfbdf0028,0x69a70006,0x69ce08c8,0x6b750009}},	//   _thêm_, _चाही, _aabe, рлау,
   {{0x3f8b0ac8,0x2d8a0ac9,0x6b860051,0x7c28000d}},	// [5f0] macu_, babe_, _dekg, édra,
   {{0x69ce0aca,0x3b540acb,0x5fd900dc,0x443f0acc}},	//   _cabe, скур, _बोतल, zlu_,
   {{0x69ce0acd,0x443f0ace,0x7a300421,0x00000000}},	//   _dabe, ylu_, näty, --,
   {{0x8d7400d1,0x600602d7,0x443f00a8,0x6c7a016b}},	//   _پایا, _tóme, xlu_, _שארפ,
   {{0x66e50acf,0xb5fd00fe,0x443f0ad0,0x00000000}},	//   рола, _dušn, vlu_, --,
   {{0x69ce0ad1,0x64400479,0x7bcf0371,0x00000000}},	//   _gabe, elmi, _hacu, --,
   {{0x62820ad2,0x7bcf0ad3,0x3dd70083,0x2aaf0095}},	//   _awoo, _kacu, _সকাল, lüb_,
   {{0x443f0ad4,0x2d8a0ad5,0x6282073a,0x3f8b00cd}},	//   ulu_, zabe_, _bwoo, jacu_,
   {{0x443f0ad6,0x02050431,0x491900a1,0x69ce018c}},	//   rlu_, изин, _येतो_, _yabe,
   {{0x443f0ad7,0x7bcf0ad8,0xd24e0ad9,0xbb1b0139}},	//   slu_, _lacu, وني_, _neîm,
   {{0x443f0ada,0x61450adb,0x7bcf0adc,0xd00a0274}},	//   plu_, рена, _oacu, вене_,
   {{0xdcfe00ea,0x7bcf0add,0x2004003e,0xc059010b}},	//   _nepā, _nacu, ómi_, ліў_,
   {{0x91e50ade,0xf38c0070,0x44d500ec,0x2d8a0adf}},	//   _воле, _טראָ, _hā_, tabe_,
   {{0x44d50ae0,0x21660009,0x7a3002c9,0xee370ae1}},	//   _kā_, _киши_, sätz, иня_,
   {{0x2d8a02c6,0x44d50029,0x69ce0ae2,0x7bcf0ae3}},	//   rabe_, _jā_, _rabe, _bacu,
   {{0x69ce0ae4,0x44d500ec,0x31c500b4,0x7bcf0ae5}},	//   _sabe, _mā_, _वसुध, _cacu,
   {{0xfaa60ae6,0xcb00004e,0x70530ae7,0x69ce0ae8}},	// [600] разо, लैंड_, _بنيا, _pabe,
   {{0x69ce0484,0x2d960ae9,0x7bcf0aea,0x0b590aeb}},	//   _qabe, _трис, _eacu, урсы_,
   {{0x44d5013a,0xfce60aec,0x44c700b5,0x7bcf0aed}},	//   _nā_, _тоно, _nő_, _facu,
   {{0x69ce0aee,0xfaa60aef,0x7bcf0af0,0xf0b60070}},	//   _wabe, _камо, _gacu, ילער_,
   {{0x6abd00ee,0x6716073f,0x00000000,0x00000000}},	//   _gpsf, _देशक_, --, --,
   {{0xa61302ce,0xb5fd0af1,0x7bcf0af2,0x3f8b0af3}},	//   оміч, _dušo, _zacu, zacu_,
   {{0xa3e100b4,0x291e013c,0x7bcf007b,0x64aa00a8}},	//   दां_, _äta_, _yacu, _rəis,
   {{0x07a30af4,0x00000000,0x00000000,0x00000000}},	//   _масн, --, --, --,
   {{0xe5a60af5,0x41e600d8,0x521400c3,0xa3200af6}},	//   _визи, аіна, йдит, मपेज_,
   {{0x44c7006c,0x83fc00cd,0x3f8b04fb,0xd257002d}},	//   _fő_, _tuđo, wacu_, ицэ_,
   {{0x7e760af7,0xf99300a5,0x64c60af8,0x69d90070}},	//   _atyp, חרת_, _خيال, אַרו,
   {{0xa3e10096,0xa3d70af9,0xb5fc007a,0xa2b80afa}},	//   दाः_, ायण_, _diġe, ्बद्,
   {{0x69a70775,0xc7b30122,0x3f8b0afb,0x7bc407f2}},	//   _चाली, חבר_, racu_, deiu,
   {{0x272301a5,0x82330af8,0x6aa40afc,0x3f8b0207}},	//   ằng_, _وروا, duif, sacu_,
   {{0x40940514,0x6adf0437,0x4c9400c3,0x3f8b012f}},	//   _البر, नम्र, жисс, pacu_,
   {{0x95fe0083,0x3ced0254,0xb5fc035f,0x41a600be}},	//   ্চিম_, ćev_, _jiġb, _खाँस,
   {{0x99670afd,0xa3d7017f,0x671600ab,0xddcd003c}},	// [610] ател, ायत_, _देलक_, _kważ,
   {{0x2aaf00a8,0x7bcf0afe,0x2b8500cc,0x00000000}},	//   rüb_, _wacu, ặc_, --,
   {{0x7bcf0aff,0xc7c70b00,0x00000000,0x00000000}},	//   _tacu, исди, --, --,
   {{0x44d502d4,0x7bc400af,0x5f0a0033,0x60060260}},	//   _rā_, ceiu, রপরও_, _kóma,
   {{0xa3ea035d,0x6b8d0b01,0xd6d9004e,0x44d5013a}},	//   मान_, maag, _była_, _sā_,
   {{0x44d5013a,0x6b8d0b02,0x39b7007e,0xb8cd0033}},	//   _pā_, laag, _děsí_, _কন_,
   {{0x69c50b03,0xcd9800a5,0x18a4010b,0x00000000}},	//   mehe, בדות_, _маём, --,
   {{0x6b8d0b04,0x44d502d4,0x69c50b05,0x53c90820}},	//   naag, _vā_, lehe, угим_,
   {{0x60060b06,0x659500af,0x00000000,0x00000000}},	//   _nóma, _газу, --, --,
   {{0x44d50ae0,0xa2050b07,0x6b8d0b08,0x69c500d4}},	//   _tā_, спод, haag, nehe,
   {{0x3f890b09,0x6b8d0b0a,0x629d0187,0x7e760067}},	//   _beau_, kaag, ásob, _styp,
   {{0x69c50b0b,0xdb040b0c,0x3f890160,0xdcfe0139}},	//   hehe, rfiú, _ceau_, _lepă,
   {{0x6b8d0b0d,0x69c50b0e,0xaac60084,0xe1ee002d}},	//   daag, kehe, _रैंक, _ег_,
   {{0x63a90b0f,0x60060093,0x69c501f4,0x3f9e01d6}},	//   lgen, _dóma, jehe, ştu_,
   {{0x61e30b10,0x61fc0b11,0xeb9a0b12,0x63a90b13}},	//   _innl, örle, лив_, ogen,
   {{0x63a90b14,0x6b8d0b15,0x78a50b16,0xa3ea022e}},	//   ngen, gaag, duhv, माय_,
   {{0x63a90b17,0xfe720037,0x7bc40160,0x60060b18}},	// [620] igen, _عدة_, reiu, _góma,
   {{0x69c50b19,0x443d033b,0x20020421,0xb5fd0b1a}},	//   gehe, _lkw_, lkki_, _bušm,
   {{0xa3d70755,0x395c013c,0x26cd00de,0xdcfe002d}},	//   ाया_, ävs_, _aseo_, _depă,
   {{0x20020086,0x63a90b1b,0xb5fd00cd,0x07a60272}},	//   nkki_, jgen, _dušm, садн,
   {{0xadec0b1c,0x69c50b1d,0x6aa40176,0xb4e007df}},	//   ञापन_, behe, quif, दम्_,
   {{0x63a90b1e,0x25db0864,0xb8660a42,0x386d00d5}},	//   egen, _गोदी_, _هارو, _červ_,
   {{0x63a90b1f,0x7c290187,0x7d7b0070,0x18a3010b}},	//   fgen, červ, אנצו, _нарм,
   {{0x63a90b20,0x83fc003a,0x6815004e,0x3a3a013c}},	//   ggen, _tuđm, ządz, lopp_,
   {{0x443d0345,0xfbd300a5,0x00000000,0x00000000}},	//   _dkw_, לתה_, --, --,
   {{0x63a90b21,0xddcd0009,0xd9cf0033,0x60060b22}},	//   agen, _otaš, রাথম, _róma,
   {{0x3f890248,0x6b8d0b23,0x66080b24,0x00000000}},	//   _peau_, yaag, _ildk, --,
   {{0x82a60b25,0x3a3a01ff,0x61e30044,0xc4d300a5}},	//   _гадж, hopp_, _ennl, _מגע_,
   {{0x3f89000d,0x69c50b26,0xddcd0b27,0x00000000}},	//   _veau_, yehe, _ataš, --,
   {{0xddcd004e,0x6b8d0b28,0xa1580b29,0x3878009e}},	//   _uważ, waag, _калу_, _otrr_,
   {{0x6b8d0273,0x69c50b2a,0x00000000,0x00000000}},	//   taag, vehe, --, --,
   {{0x321e0b2b,0x69c50b2c,0x27e40159,0x60060b2d}},	//   lity_, wehe, _nnmn_, _tóma,
   {{0x6b8d0b2e,0x69c502c9,0xfaff01f4,0x15fa0761}},	// [630] raag, tehe, _afër_, ्सार_,
   {{0x321e0b2f,0xddab0b30,0x6b8d0b31,0x59e0018d}},	//   nity_, _стил_, saag, नागर,
   {{0x094b0b32,0x69c50b33,0x6b8d0b34,0x237f0067}},	//   учаи_, rehe, paag, ybuj_,
   {{0x69c502bf,0xb8f10b35,0xad1a0122,0x2679002d}},	//   sehe, _वन_, _כותר, аскэ_,
   {{0x63a90b36,0x8f9c076b,0x69c505f5,0x00000000}},	//   vgen, רידי, pehe, --,
   {{0x2009001e,0x601602c4,0x443d0345,0xb5fd0116}},	//   _llai_, ršmi, _skw_, _tušm,
   {{0x63a90b37,0x443d0b38,0x20020093,0x321e06a0}},	//   tgen, _pkw_, ykki_, dity_,
   {{0x5fd90b39,0x66830332,0xdb0d0033,0x07350b3a}},	//   _बोलल, _فیصل, leañ, _дебю,
   {{0x23290b3b,0x66f4002d,0x320700ac,0x42090200}},	//   ропи_, _епту, _plny_, инио_,
   {{0xb5fd01cc,0x63a90b3c,0x20090b3d,0x312500c3}},	//   _mušk, sgen, _alai_, ждог,
   {{0xafdb0b3e,0x32070097,0xd12e00b5,0x20090b3f}},	//   rløn, _vlny_, ہمی_, _blai_,
   {{0xa3ea0b40,0xb4d508b6,0xafdb0b41,0x443d0b42}},	//   माण_, िटी_, sløn, _ukw_,
   {{0xe2da0332,0x20020086,0xb5fd02a7,0x00000000}},	//   _پانچ_, rkki_, _nušk, --,
   {{0x27380028,0x321e0b2b,0x27e000ea,0xfc3f0168}},	//   ứng_, city_, ķini_, _akí_,
   {{0xed5a0652,0xdbc7008a,0x3e6f018d,0x00000000}},	//   ров_, töðu, _eüt_, --,
   {{0xc4d2011d,0x1c46093e,0xb5fd0b43,0x20090090}},	//   וגל_, інам, _bušk, _glai_,
   {{0xa3ea00a1,0x3a3a0b44,0x00000000,0x00000000}},	// [640] मात_, topp_, --, --,
   {{0xb5fd01a0,0xa2a104e9,0xc18c0070,0x00000000}},	//   _dušk, _खिन्, ָטאָ, --,
   {{0xd6d9006a,0x6e3c0b45,0x00000000,0x00000000}},	//   _było_, morb, --, --,
   {{0x321e0187,0x386d00ac,0x8c460043,0x00000000}},	//   zity_, _čert_, _феме, --,
   {{0x628600b8,0x00000000,0x00000000,0x00000000}},	//   škoz, --, --, --,
   {{0xd49a0b46,0x2ba80b47,0x321e0b48,0x5d7a016b}},	//   ари_, गलवा, xity_, באַק,
   {{0x25a00723,0x321e0b49,0x1db20b4a,0xd5ad006c}},	//   ğil_, vity_, _जानत, اہم_,
   {{0x25a0027d,0xaa7b00b8,0x6e3c026e,0x321e0067}},	//   şil_, _frýd, horb, wity_,
   {{0x24890254,0x6e3c0b4b,0x6ab60035,0x1dca0099}},	//   ćama_, korb, ntyf, ाजात,
   {{0xdb1d0168,0x00000000,0x00000000,0x00000000}},	//   _nasý, --, --, --,
   {{0x321e0052,0x60060b4c,0x104b0086,0xa3ea0b4d}},	//   rity_, _cómo, иями_, माद_,
   {{0xf1ae018d,0xdb210187,0x321e0b4e,0x320c0b4f}},	//   ज्जन, _štíh, sity_, shdy_,
   {{0x6e3c0b50,0x185b016b,0x00000000,0x00000000}},	//   forb, יכטע, --, --,
   {{0xf2870332,0x6e3c0b51,0x00000000,0x00000000}},	//   _بھٹو_, gorb, --, --,
   {{0x48c50b52,0x2009012f,0x00000000,0x00000000}},	//   _এপ্র, _tlai_, --, --,
   {{0x7aed0b53,0x83fc0009,0x7bd6011e,0x61f80185}},	//   txat, _buđi, gdyu, _hovl,
   {{0xf96b004c,0x7f4d00a8,0x6e3c0b4b,0x00000000}},	// [650] арей_, _uzaq, borb, --,
   {{0x527b00c2,0xa2b20b54,0x38640160,0x91ed07b5}},	//   ינמא, _आमन्, _aimr_, जायज_,
   {{0x2d910b55,0x2d8301f4,0x81bc00ea,0x603200ea}},	//   maze_, mbje_, tnēj, sāme,
   {{0x2d910b56,0x61f8082b,0x7c290187,0x80c40083}},	//   laze_, _lovl, čers, ষিপ্,
   {{0xeb760070,0x4dff046c,0xb5fc007a,0x00000000}},	//   _מערץ_, _ईकाई_, _siġa, --,
   {{0xe61801e0,0x61f800f4,0x2d9105ad,0xb5fd00f4}},	//   оді_, _novl, naze_, _kuši,
   {{0x7e6d022e,0xf50500d8,0x92aa0033,0xf8b4002d}},	//   _luap, язко, খবো_, _обрэ,
   {{0x25db0b57,0xfbdf0023,0x2d9104fb,0x3ea20b58}},	//   _गोरी_, _thêu_, haze_, yrkt_,
   {{0x69d50b59,0x600602d7,0x26d902d7,0x29ff0067}},	//   _kaze, _sómo, _éso_, ałań_,
   {{0x69d50b5a,0xddc40254,0x11d5004f,0x2d910b5b}},	//   _jaze, _stiž, ستخد, jaze_,
   {{0x69d50b5c,0x6d450221,0x61f80b5d,0xb5fd0b5e}},	//   _maze, _nyha, _dovl, _nuši,
   {{0x69d50b5f,0x7e6d00d7,0x6e3c033b,0xdbf7021a}},	//   _laze, _buap, worb, ीसोड_,
   {{0x63bb0b60,0xa2e50b61,0xdb1d0138,0x932702fd}},	//   mfun, _холд, _masó, _بران,
   {{0x2d8c0b62,0x63bb0b63,0x7e6d022e,0xb5fd012e}},	//   úde_, lfun, _duap, _buši,
   {{0xe16600bf,0x61420b64,0x59df073f,0x63bb0b65}},	//   _عضوی, _пеша, _नफ़र, ofun,
   {{0xc4d20779,0xbc630b66,0xb5fd0b67,0x80b10083}},	//   עגן_, евск, _duši, _জনপ্,
   {{0x7e6d0b68,0x2fc00269,0x2d910b69,0x63bb0b6a}},	// [660] _guap, _ibig_, baze_, ifun,
   {{0xa3e20066,0x4a430b6b,0x25db00b1,0x6ab60035}},	//   _फोन_, енув, _गोली_, rtyf,
   {{0x38b50b6c,0xdb1d0b6d,0x63bb0b6e,0xb5fd012e}},	//   går_, _basó, kfun, _guši,
   {{0xde6d01a5,0xdb1d0b6f,0x83fc0254,0x63bb0b70}},	//   _hươn, _obsè, _tuđi, jfun,
   {{0x69d500c9,0x6b840b71,0x6d4000d0,0xa3ea0b72}},	//   _faze, mbig, şmad, मास_,
   {{0x69d50b73,0x6b840b74,0x281604cd,0x442f0b75}},	//   _gaze, lbig, _کورس, _ajg_,
   {{0xdb0f02e1,0xa3d7012f,0xdb1d0310,0x63bb0b76}},	//   _accè, ायं_, _absè, ffun,
   {{0xde6d01a5,0x6b840b77,0x69d5003d,0x02a60b78}},	//   _lươn, nbig, _zaze, пром,
   {{0x61f80b79,0xa3e10b7a,0x81d50083,0x93c8006c}},	//   _povl, दाज_, হান_, ماکہ_,
   {{0xdb0d03e6,0x7e6d009e,0x6faa05e7,0xde6d0023}},	//   sfaç, _ruap, _काउं, _nươn,
   {{0x6aa40b7b,0x7e6d0b7c,0x7336006c,0xd250006c}},	//   hrif, _suap, _کرائ, ٹنگ_,
   {{0xe45a0b7d,0x2ee0001e,0xdb1d002a,0xe7ef021a}},	//   _уже_, _brif_, _xasó, छाया_,
   {{0xf2060021,0xb5fd0b7e,0x2ee00036,0xe2da00b5}},	//   _няко, _suši, _crif_, _دباؤ_,
   {{0xb5fd0b7f,0xde6d0019,0x9c8301ba,0x6aa40b80}},	//   _puši, _cươn, účov, drif,
   {{0xde6d0028,0x69d50b81,0xc1bb0122,0x00000000}},	//   _dươn, _raze, _המוש, --,
   {{0x6aa40297,0x6b8400a7,0xdfd10b82,0x69d50b83}},	//   frif, gbig, _شيخ_, _saze,
   {{0x6aa40b84,0x8f9c0122,0x2ee00b85,0x69d50b86}},	// [670] grif, _היחי, _grif_, _paze,
   {{0x38b50b87,0xde6d01a5,0xb5fd003d,0x62800b88}},	//   tår_, _gươn, _tuši, ipmo,
   {{0x29070b89,0x6b84013c,0x798e021e,0xe3c7010b}},	//   ána_, bbig, _debw, ščių_,
   {{0x29070484,0x69d50054,0x764100d8,0x38b50830}},	//   ġna_, _waze, _skly, rår_,
   {{0x29070888,0x7c2d0b8a,0xdb1d0b8b,0x603200ea}},	//   šna_, mnar, _obsé, nāma,
   {{0xde6d0019,0x68e100b5,0x7c2d0b8c,0xb9c50b8d}},	//   _xươn, _áldo, lnar, _تقسي,
   {{0x2489044d,0xd7fb00af,0x00000000,0x00000000}},	//   ćamo_, _луа_, --, --,
   {{0x7c2d0b8e,0xdb0f0b8f,0x67d40b90,0x603200ec}},	//   nnar, _accé, _посу, kāma,
   {{0x63bb0b91,0x7c2d0b92,0x7c28002a,0x00000000}},	//   rfun, inar, édri, --,
   {{0x3eab0b93,0xb5fd04d9,0x644201d7,0x7c2d0b94}},	//   duct_, _aušv, _ekoi, hnar,
   {{0xc60902e4,0x63bb0b95,0x7c2d0b96,0xa3ea0354}},	//   वसीय_, pfun, knar, माश_,
   {{0x2ee00297,0x81b50083,0xe3b0004f,0xde6d0019}},	//   _prif_, _চোখ_, _مره_, _sươn,
   {{0xe28e0b97,0xa3ea0066,0x443f0b98,0x7c2d02c6}},	//   _ша_, मार_, mou_, dnar,
   {{0x64490b99,0x442d0b9a,0x7c2d0b9b,0x6b9d0044}},	//   llei, lne_, enar, _adsg,
   {{0x442d0021,0xe1f0028c,0x3eb904ce,0xde6d01a5}},	//   one_, _حسن_, atst_, _vươn,
   {{0x64490151,0x7c2d0b9c,0x443f0b9d,0xa3b1018d}},	//   nlei, gnar, nou_, ञ्च_,
   {{0x442d0b9e,0xde6d0028,0x443f0b9f,0x64490ba0}},	// [680] ine_, _tươn, iou_, ilei,
   {{0x6aa40ba1,0x443f0ba2,0x6b840036,0x2b8c0028}},	//   rrif, hou_, sbig, ếc_,
   {{0x443f0ba3,0x442d0ba4,0x851c0299,0x64490ba5}},	//   kou_, kne_, _भेंट_, klei,
   {{0x442d0ba6,0x798e0136,0x443f0ba7,0xc3140033}},	//   jne_, _webw, jou_, াপতি_,
   {{0x442d0ba8,0x443f0ba9,0xb86502fd,0x7c240baa}},	//   dne_, dou_, رامو, miir,
   {{0x442d0bab,0x64490bac,0x44ce0355,0x443f0345}},	//   ene_, elei, _př_, eou_,
   {{0x1dc00bad,0x443f0bae,0xa3ea0808,0x3e7401ff}},	//   श्यत, fou_, माल_, _lät_,
   {{0x442d0baf,0xe73a0009,0x443f0bb0,0x64490bb1}},	//   gne_, _деб_, gou_, glei,
   {{0x3e7401ff,0x00000000,0x00000000,0x00000000}},	//   _nät_, --, --, --,
   {{0x442d0bb2,0x7c240bb3,0x7c2d0124,0x64490421}},	//   ane_, hiir, znar, alei,
   {{0x85060bb4,0x442d0bb5,0x443f0bb6,0x64490bb7}},	//   _توان, bne_, bou_, blei,
   {{0x442d0bb8,0x443f0bb9,0x603202d4,0x7c240103}},	//   cne_, cou_, tāma, jiir,
   {{0x64400bba,0x7c2d0bbb,0x628b01ef,0xdefb0bbc}},	//   momi, vnar, _gwgo, цын_,
   {{0x64400bbd,0x60320029,0xddc40228,0x60060098}},	//   lomi, rāma, _puiš, _lómh,
   {{0x7c2401a8,0x61ea0bbe,0x7c2d0bbf,0x6032013a}},	//   fiir, _infl, tnar, sāma,
   {{0x2bdf06bc,0x7c2d0bc0,0xfc3006c9,0x80c40033}},	//   _पोशा, unar, لحق_, ষিদ্,
   {{0xa3b60bc1,0x4424009e,0xcd0400b8,0x8fa40274}},	// [690] _जान_, iim_, vněž_, _рање,
   {{0x442d042f,0x443f0bc2,0x7c2d0bc3,0x644000cd}},	//   zne_, zou_, snar, homi,
   {{0x442d0bc4,0x644000ab,0xf77300f3,0xb5fd0bc5}},	//   yne_, komi, ناش_, _mušt,
   {{0x44240bc6,0x27e90bc7,0x443f0bc8,0x6440010b}},	//   jim_, ñan_, xou_, jomi,
   {{0x442d0bc9,0x443f0bca,0x7bcd00f7,0x644903bc}},	//   vne_, vou_, meau, vlei,
   {{0x442d006a,0x443f0359,0x7bcd00a2,0xb5fd0124}},	//   wne_, wou_, leau, _nušt,
   {{0x443f0bcb,0x442d0bcc,0x60060082,0x64490bcd}},	//   tou_, tne_, _fómh, tlei,
   {{0x442d0043,0x64400bce,0xf1d70266,0x61ea0bcf}},	//   une_, gomi, _भोजन, _anfl,
   {{0x442d0bd0,0x64490bd1,0x63a60bd2,0x96350272}},	//   rne_, rlei, ókna, _знац,
   {{0x442d0936,0x443f0bd3,0xe1f1004f,0x442404e6}},	//   sne_, sou_, اسة_, aim_,
   {{0x44240bd4,0x64400bd5,0x443f0bd6,0x60260bd7}},	//   bim_, bomi, pou_, една,
   {{0x64400bd8,0x44240bd9,0xa3ea021a,0xa3b60bda}},	//   comi, cim_, माः_, _जाय_,
   {{0x7bcd0bdb,0x7c240bdc,0x2ac300ea,0x4f070036}},	//   deau, viir, nībā_, енян_,
   {{0xa3d70bdd,0xb5fd0bde,0xdd920bdf,0x2d9e00f7}},	//   ायक_, _gušt, طور_, ûte_,
   {{0x1b1d00c8,0x7c240be0,0xa3b6073f,0xd00a03fa}},	//   _ভুলে_, tiir, _जाम_, _неке_,
   {{0x2c75029e,0x00000000,0x00000000,0x00000000}},	//   _dåd_, --, --, --,
   {{0x7c24018e,0xf41202b5,0x60060be1,0x1f6601e0}},	// [6a0] riir, אפן_, _nómi, _яким,
   {{0x44240be2,0x7c240be3,0xe9d70be4,0x5fc101c0}},	//   zim_, siir, нку_, ष्ठल,
   {{0x44240be5,0x7c240be6,0x7bcd0be7,0x1bea0be8}},	//   yim_, piir, beau, _едни_,
   {{0x44240be9,0xc5fa0825,0x95fa04bc,0x59ac0380}},	//   xim_, ्स्य_, ्स्ट_, _चाकर,
   {{0x44240496,0x6440061c,0x60060b4c,0x00000000}},	//   vim_, vomi, _cómi, --,
   {{0x44240bea,0x6b960159,0x6006003e,0x2ba8021a}},	//   wim_, layg, _dómi, गलका,
   {{0x7c2f004f,0x04660beb,0xb5fd0097,0x00000000}},	//   _áirí, нтим, _rušt, --,
   {{0xb5fd0bec,0xccf30bed,0xd4670202,0x64400036}},	//   _sušt, רכה_, није_, uomi,
   {{0x44240bee,0xb5fd0a78,0x2ac30029,0x00000000}},	//   rim_, _pušt, cībā_, --,
   {{0x64400bef,0x00000000,0x00000000,0x00000000}},	//   somi, --, --, --,
   {{0x44240bf0,0x64400bf1,0x2a6a0036,0x64a30bf2}},	//   pim_, pomi, _mibb_, _баха,
   {{0x929d004e,0x2c750bf3,0x44240bf4,0xdfd10bf5}},	//   syła, _råd_, qim_, جيح_,
   {{0x7bcd0bf6,0x1acf0026,0xdcfc02d4,0x6b960bf7}},	//   veau, _सैंथ, karē, dayg,
   {{0x61ea0107,0xaa7b008d,0x00000000,0x00000000}},	//   _unfl, _brýn, --, --,
   {{0x7bcd0bf8,0x71f700b5,0x00000000,0x00000000}},	//   teau, _سروس_, --, --,
   {{0x59c60026,0x7c8403e6,0x99d70088,0x00000000}},	//   _रॉबर, ѓусе, کترا, --,
   {{0x7bcd0bf9,0x7b740037,0xab380bfa,0x23c20067}},	// [6b0] reau, اطفا, епту_, व्यद,
   {{0x7bcd0bfb,0x13d90033,0x49d80bfc,0x00000000}},	//   seau, থায়, ндую_, --,
   {{0x7bcd0bfd,0x5d550bfe,0x48ab0bff,0x00000000}},	//   peau, _шкот, ятам_, --,
   {{0xfbab03ad,0xa2a104bc,0x629d00b5,0x200b00b8}},	//   _этой_, _खिल्, ások, nkci_,
   {{0x79a70798,0x6aad027a,0xc66b0421,0x00000000}},	//   _прве, quaf, чшее_, --,
   {{0xd5490c00,0x60060300,0x2ac300ea,0xb5fd00c7}},	//   мпле_, _vómi, rībā_, _aušr,
   {{0xda34021f,0x2d930132,0x2ac300ea,0x70af0387}},	//   _серы, _mexe_, sībā_, _झमेल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c100a9,0x961d0228,0x00000000,0x00000000}},	//   र्थी, _atņe, --, --,
   {{0x85b80c01,0x2d9301f7,0x27ff0260,0x00000000}},	//   _плус_, _nexe_, _houn_, --,
   {{0x76430c02,0x27ff0260,0x00000000,0x00000000}},	//   mony, _koun_, --, --,
   {{0x27ff0107,0x69c10c03,0x00000000,0x00000000}},	//   _joun_, र्ती, --, --,
   {{0xa3b60c04,0x27ff0c05,0x20190031,0x764308c7}},	//   _जात_, _moun_, ëria_, oony,
   {{0xed5a0c06,0x76430c07,0x27ff00fe,0x00000000}},	//   дог_, nony, _loun_, --,
   {{0xdcfc0029,0x629b010b,0x27ed0c08,0xef1f0457}},	//   varē, lsuo, _onen_, lbül_,
   {{0x27ff0c09,0x7ae90c0a,0x76430c0b,0xa3ea00dc}},	//   _noun_, _šeta, hony, माए_,
   {{0xee3a0c0c,0xe9da0c0d,0xab270c0e,0x76430c0f}},	// [6c0] _они_, мка_, вота_, kony,
   {{0x27ed0031,0x20000118,0x7d0700d5,0x48e60200}},	//   _anen_, _hoii_, byjs, козв,
   {{0x2d980c10,0x76430c11,0x27ff0107,0x940c00a8}},	//   mare_, dony, _boun_, _evdə_,
   {{0x2d980c12,0x629b0c13,0x661d010b,0xe72a027a}},	//   lare_, ksuo, _įska, моед_,
   {{0x2a6a00a8,0x27ff01ed,0x00000000,0x00000000}},	//   _tibb_, _doun_, --, --,
   {{0x2d9803d0,0xc8aa04bc,0xe5340c14,0x00000000}},	//   nare_, _चटपट, лель, --,
   {{0x69dc0065,0xb5fc035f,0x00000000,0x00000000}},	//   _iare, _jiġi, --, --,
   {{0x2d980c15,0x64590c16,0x69dc0c17,0x38bc0c18}},	//   hare_, _chwi, _hare, mír_,
   {{0x51860409,0x69dc0c19,0x2d980c1a,0x76430c1b}},	//   куна, _kare, kare_, bony,
   {{0x69dc0c1c,0x2d980c1d,0x69de0c1e,0x76430067}},	//   _jare, jare_, ndpe, cony,
   {{0x27ff0c1f,0x2d980c20,0x98c50c21,0x6d5a07c0}},	//   _youn_, dare_, čuće_, ýtal,
   {{0x69dc0c22,0x2d930c23,0x03260923,0x249e0176}},	//   _lare, _sexe_, _иден, _ivtm_,
   {{0x63a20c24,0x2d980c25,0x69dc00af,0xdcf50029}},	//   _idon, fare_, _oare, pazī,
   {{0x69dc02dd,0x2d980533,0xc0aa0357,0xa3ea00be}},	//   _nare, gare_, _قابل_, माक_,
   {{0x20d30c26,0x6d400c27,0xdd940c28,0x7ae60c29}},	//   _نتيج, şman, расы, _arkt,
   {{0x76430c2a,0xec340c2b,0xb5fc035f,0x69dc0c2c}},	//   zony, ансь, _diġi, _aare,
   {{0x69dc0c2d,0x2d980c2e,0x81d500c8,0x76430c2f}},	// [6d0] _bare, bare_, হার_, yony,
   {{0x2d980c30,0x69dc0c31,0x6006008d,0x6282021d}},	//   care_, _care, _dómu, _mtoo,
   {{0x69dc0c32,0x9967081b,0x63a20c33,0x7ae60044}},	//   _dare, ттал, _odon, _erkt,
   {{0x63a20c34,0x69dc0c35,0x764301a8,0xac1900d4}},	//   _ndon, _eare, wony, _чому_,
   {{0xf7700c36,0x501c0c37,0xe5a5083e,0x6282006f}},	//   زان_, וואו, гили, _ntoo,
   {{0x63a20c38,0x69dc0c39,0x6272004e,0x7bdd0c3a}},	//   _adon, _gare, _młod, _hasu,
   {{0x7bdd0c3b,0x25a90092,0x5e5802b5,0x62820c3c}},	//   _kasu, ğal_, דיגע_, _atoo,
   {{0x69dc0c3d,0x2d980012,0xa3ea0c3e,0x27ed0c3f}},	//   _zare, zare_, माग_, _unen_,
   {{0x7bdd0c40,0x69dc0c41,0x224700d7,0x2d980c42}},	//   _masu, _yare, _pknk_, yare_,
   {{0x386d0c43,0x611301c2,0x63a201d7,0x2d980c44}},	//   _hier_, lələ, _edon, xare_,
   {{0x2d980c45,0x62820103,0x629b0c46,0x69c70031}},	//   vare_, _etoo, ssuo, _mbje,
   {{0x7bdd0c47,0x66010c48,0x3f9902f6,0x611300a8}},	//   _nasu, _holk, gasu_, nələ,
   {{0x2d980c49,0x386d0c4a,0x7ae90254,0x20550144}},	//   tare_, _mier_, _šetn, ртэр,
   {{0x61130095,0xddcd0c4b,0x51870c4c,0x386d0c4d}},	//   hələ, _etaž, _руда, _lier_,
   {{0x2d980c4e,0x7bdd0c4f,0x611301c2,0x69dc0c50}},	//   rare_, _basu, kələ, _rare,
   {{0x69dc0c51,0x2d980c52,0x44e30723,0x600602d7}},	//   _sare, sare_, _mı_, _pómu,
   {{0x79950c1f,0x2d980c53,0x61130095,0x7bdd0118}},	// [6e0] _bezw, pare_, dələ, _dasu,
   {{0x7bdd0312,0x69dc0c54,0x2d980031,0x3ea00160}},	//   _easu, _qare, qare_, _ivit_,
   {{0x386d0c55,0x69de0c56,0x61130095,0x778608f1}},	//   _bier_, rdpe, fələ, глез,
   {{0xe73a03ad,0xb8dc0c57,0x765a01d2,0x69dc0c58}},	//   нее_, _आम_, _shty, _ware,
   {{0x69dc0c59,0x386d03c4,0x63a2009e,0xc7a30c5a}},	//   _tare, _dier_, _rdon, сичк,
   {{0x7ae40c5b,0x386d0c5c,0x69dc009e,0x38bc0c5d}},	//   mvit, _eier_, _uare, pír_,
   {{0x386d0c5e,0x7ae40c5f,0x3f9900e7,0x7bdd0b69}},	//   _fier_, lvit, yasu_, _yasu,
   {{0x611301c2,0x386d0035,0x8d5b0070,0x28030355}},	//   cələ, _gier_, עכקי, ěrná_,
   {{0xe737081b,0x66010c60,0x22450c61,0x7ae40c62}},	//   _бет_, _folk, folk_, nvit,
   {{0xddcd0c63,0xa3b60006,0x66010c64,0x40860c65}},	//   _staž, _जाव_, _golk, лумб,
   {{0x7c260c66,0x59c60c67,0x3f9900ab,0x3ea00260}},	//   _omkr, र्यर, tasu_, _avit_,
   {{0x660100d7,0x7ae40c68,0x63a20c69,0x7e760b88}},	//   _zolk, kvit, _udon, _buyp,
   {{0x44260c6a,0x7bdd072e,0x6d4006d3,0x3ea00124}},	//   _imo_, _rasu, şmal, _cvit_,
   {{0x7bdd0c6b,0x44260189,0x273101a5,0x44e3027d}},	//   _sasu, _hmo_, ạng_, _yı_,
   {{0x3ea00c6c,0x7bdd0c6d,0xdb0d004f,0x317b0319}},	//   _evit_, _pasu, rgaí, _ארומ,
   {{0x60060093,0xddcd0c6e,0x4426023c,0x7bdd0c6f}},	//   _dóms, _utaž, _jmo_, _qasu,
   {{0x7bdd0c70,0xafdb0c71,0x611300a8,0xdcfc00c7}},	// [6f0] _vasu, sløs, vələ, karė,
   {{0x7bdd0c72,0xe29f0093,0xdb16008d,0x442603d0}},	//   _wasu, áði_, reyð, _lmo_,
   {{0x7bdd0006,0x61130095,0x7ae40c73,0x636b00a8}},	//   _tasu, tələ, avit, _könü,
   {{0x20da0129,0x2ee90a4e,0xe84b0c74,0x66010c75}},	//   mšić_, _kraf_, رجان_, _solk,
   {{0x386d02c0,0x6b8d0c76,0x66010c77,0x61130095}},	//   _vier_, mbag, _polk, rələ,
   {{0x386d0223,0x6b8d0c78,0x611301c2,0x66010510}},	//   _wier_, lbag, sələ, _qolk,
   {{0x66010c79,0x19580bbc,0x224503bc,0xf8c907b5}},	//   _volk, _бары_, volk_, _रहिय,
   {{0x66010c7a,0x61130095,0x69c50c7b,0x22450c7c}},	//   _wolk, qələ, lfhe, wolk_,
   {{0x2bc702cb,0x66010c7d,0xa3b60324,0x21f501e0}},	//   ऱ्या, _tolk, _जार_, аїнс,
   {{0x032200d8,0x2fc90159,0x20da011c,0x42250c7e}},	//   ідэн, _abag_, kšić_, рдов,
   {{0x7ae40528,0x3ea00c7f,0x2ee9016e,0x6aad0098}},	//   zvit, _svit_, _araf_, hraf,
   {{0xa4fa02b5,0x6aad0c80,0x504600af,0x2ee900e9}},	//   _בלעט, kraf, ремб, _braf_,
   {{0x636b06d3,0x1f56021f,0xc7d600a5,0x60320228}},	//   _dönü, ртнё, בורי_, nāmi,
   {{0x91fc0ae0,0x62890c81,0x6aad0c82,0x2ee90c83}},	//   rmāc, mpeo, draf, _draf_,
   {{0x3b960c84,0xa3ea009a,0x7c2600e7,0x2ee90c85}},	//   ијат, माच_, _pmkr, _eraf_,
   {{0xe8e001a5,0x6b8d0c86,0x636b027d,0xafdb0c71}},	//   _hiệp_, gbag, _gönü, slør,
   {{0x7bc405f5,0xa3d6045c,0x6da60c87,0xada60c88}},	// [700] rfiu, ाजत_, _кипа, _капл,
   {{0x7ae40c89,0xac7600f8,0x6006008d,0x00000000}},	//   rvit, _پادش, _tóms, --,
   {{0x68460c8a,0xdb0d0187,0xa3b60534,0x7ae40c8b}},	//   анжа, čkác, _जाल_, svit,
   {{0xbc7b0052,0x3ead0c8c,0x6aad008c,0xebe60c8d}},	//   _שנכת, šete_, braf, _томп,
   {{0x6032013a,0x2bdf0099,0x2c7c0c8e,0x9f400312}},	//   gāmi, _पोटा, _híd_, _aniú_,
   {{0x44260c8f,0x7aeb01b4,0xe4a60c90,0x25a50090}},	//   _smo_, ægte, арио, _cdll_,
   {{0xd4970c91,0x44260c92,0x18a30c93,0x98a30c94}},	//   ары_, _pmo_, _марм, _мире,
   {{0xa6860859,0x7c36001e,0xf2c60c95,0xddcd0035}},	//   _влад, nnyr, асон, _staż,
   {{0x20190031,0x00000000,0x00000000,0x00000000}},	//   ërim_, --, --, --,
   {{0x44260c96,0x387801f4,0x1db20c97,0x64a60c98}},	//   _wmo_, _kurr_, _जागत, _важа,
   {{0x80270180,0xe8e00023,0xe3ba0be8,0x6b8d0159}},	//   لرحم, _diệp_, _абе_, ybag,
   {{0x7c3b0c99,0x59c6021a,0x2ee900af,0x4426023c}},	//   čurk, र्तर, _praf_, _umo_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x71260088,0x6aad0036,0x6f1d02b1,0xa3b600be}},	//   _پرتل, vraf, rzsc, _जाँ_,
   {{0x6b8d0c9a,0xac190274,0x245100e2,0xdde100fd}},	//   tbag, гову_, _sơmi_, ítői,
   {{0x6aad0c9b,0xa3b60084,0x20da0124,0x2ee90c9c}},	//   traf, जलि_, ršić_, _traf_,
   {{0x6b8d0406,0xda780c9d,0x00000000,0x00000000}},	// [710] rbag, аях_, --, --,
   {{0xd9990c9e,0x3da70c9f,0xa3c80026,0x38780ca0}},	//   انات_, _триб, _लॉस_, _burr_,
   {{0x69c50079,0x290700af,0xf0930070,0xa3b60ca1}},	//   rfhe, âna_, ַנס_, जला_,
   {{0x6aad0ca2,0x628901a2,0x24850848,0x00000000}},	//   praf, ypeo, _rtlm_, --,
   {{0x7c2d0ca3,0x6aad00a8,0xfaff0031,0x00000000}},	//   miar, qraf, _egër_, --,
   {{0x929d004e,0x70b60266,0x38780069,0x4aac0ca4}},	//   syłk, _अमूल, _furr_, _चितव,
   {{0x610a00a8,0xd90f0987,0x7c2d0065,0x00000000}},	//   nəld, _تیا_, oiar, --,
   {{0xf77f0092,0xa95400d4,0x7c2d0ca5,0x00000000}},	//   _üç_, _єкті, niar, --,
   {{0xa3d60299,0xa71503fa,0x26cd002f,0xa3c800ab}},	//   ाज़_, _удаљ, _upeo_, _लउर_,
   {{0xe1f90ca6,0x7c2d0ca7,0xe6130ca8,0x69ca0380}},	//   уго_, hiar, _بشر_, स्पी,
   {{0x7c2d06a2,0x7c360ca9,0xd24e00d1,0x62720035}},	//   kiar, ynyr, رچه_, _płoc,
   {{0x60060caa,0x9f060037,0xc50c0070,0x644b0159}},	//   _cómp, موجو, _שלאָ, _ukgi,
   {{0x7c2d0cab,0x91e50cac,0x201e01c8,0x5285004f}},	//   diar, _голе, ėti_, _التك,
   {{0x442d0cad,0x64490cae,0x62720035,0xe29f0093}},	//   lie_, loei, _włoc, áðu_,
   {{0x69ca00dc,0x7c2d01b7,0x442d0caf,0x0c7900c3}},	//   स्फी, fiar, oie_, исты_,
   {{0x442d0cb0,0x7c2d0cb1,0xb5fc035f,0x75fd0107}},	//   nie_, giar, _jiġr, _vèzy,
   {{0x63a60cb2,0x7c36010b,0x442d0cb3,0x00000000}},	// [720] ókni, rnyr, iie_, --,
   {{0x442d0cb4,0x38780211,0x64490223,0xc3010033}},	//   hie_, _purr_, hoei, এনপি_,
   {{0x8c460cb5,0x442d0cb6,0x7c2d0cb7,0x1d0a02c4}},	//   _гене, kie_, biar, _сени_,
   {{0x442d0cb8,0x2d9a08dd,0x6e2e0cb9,0xa3b600ab}},	//   jie_, _hepe_, libb, _जाइ_,
   {{0x3ea20cba,0xdcfc0029,0xddc400ea,0xf62a01e0}},	//   nskt_, karī, _muiž, ліки_,
   {{0x6e2e0484,0x27e00cbb,0x9e7b0070,0x19fa00af}},	//   nibb, žin_, אנספ, _сэмь_,
   {{0x442d0cbc,0xdcfc0080,0x344a0183,0x2d9a0118}},	//   fie_, darī, лчин_, _mepe_,
   {{0x442d0cbd,0x2d9a0cbe,0x6e2e00d7,0x64490015}},	//   gie_, _lepe_, hibb, goei,
   {{0x3866013c,0x600601ef,0x6e2e0103,0x610a00a8}},	//   mmor_, _rómp, kibb, zəld,
   {{0x7c2d0cbf,0x442d0cc0,0x7c3b0cc1,0x7ae90cc2}},	//   ziar, aie_, čuri, _šetk,
   {{0x442d0cc3,0xa1580cc4,0xa3b60cc5,0x69ca09b1}},	//   bie_, рану_, _जाऊ_, स्यी,
   {{0x442d0cc6,0xe29a0cc7,0x7c2d0cc8,0x395700a5}},	//   cie_, _бад_, xiar, משים_,
   {{0x7c2d0cc9,0x799e0cca,0x6e2e0ccb,0x2d9a0118}},	//   viar, kapw, fibb, _bepe_,
   {{0xdb0d03e6,0x6e2e0cb9,0x2d9a0814,0x7c2d0067}},	//   lgaç, gibb, _cepe_, wiar,
   {{0x7c2d0ccc,0x386600d7,0x2d9a0ccd,0x00000000}},	//   tiar, kmor_, _depe_, --,
   {{0x388101c8,0xdb0d0cce,0x00000000,0x00000000}},	//   _nėra_, ngaç, --, --,
   {{0x7c2d0291,0xa3b60ccf,0x99990cd0,0xda670cd1}},	// [730] riar, _जाई_, икат_, مائي,
   {{0x442d0cd2,0x6fb50357,0x7c2d0cd3,0xff180122}},	//   zie_, _امکا, siar, _לקחת_,
   {{0x442d0cd4,0x9f520359,0x3c59002d,0x764a0051}},	//   yie_, _anyè_, _винэ_, dofy,
   {{0x28ba046c,0x6449002a,0x442d0cd5,0x81be0831}},	//   _उमरि, xoei, xie_, ঁজি_,
   {{0x442d0cd6,0xc98701ee,0xb6c70421,0x09ce0033}},	//   vie_, _губи, ссей, রয়া,
   {{0x442d0cd7,0xd9fd00c0,0x2d83004e,0x853c00d8}},	//   wie_, _उचित_, ncje_, _idėj,
   {{0x442d0cd8,0x00000000,0x00000000,0x00000000}},	//   tie_, --, --, --,
   {{0x3ea20cd9,0x52a90cda,0x69d70cdb,0x00000000}},	//   yskt_, авим_, lexe, --,
   {{0x2d83004e,0x644909a6,0x59c60a64,0x130600c3}},	//   kcje_, roei, र्वर, жный_,
   {{0x442d0cdc,0x69d70cdd,0x9f49021d,0x91fc013a}},	//   sie_, nexe, _joaõ_, smān,
   {{0x442d0cde,0x2d9a081b,0x7bd60cdf,0xdbc600be}},	//   pie_, _repe_, yeyu, mööd,
   {{0xa3b60953,0xa2b202cb,0x2d9a023a,0xe29f0093}},	//   _जाए_, _आमच्, _sepe_, áðs_,
   {{0x2d9a0ce0,0xe2990336,0x6d580355,0xa3e200b4}},	//   _pepe_, _тал_, _úvaz, _फोट_,
   {{0x63bb0ce1,0x71250987,0x3ea20ce2,0x00000000}},	//   lgun, _ورغل, rskt_, --,
   {{0xc5f20122,0xfce30ce3,0x69d70ce4,0x3866016e}},	//   ודם_, моро, dexe, ymor_,
   {{0x63bb0ce5,0x3ead040b,0x320700ac,0x6e2e073a}},	//   ngun, šeta_, _hony_, sibb,
   {{0x61e30ce6,0x81dc0083,0x32070ce7,0x799e08dd}},	// [740] _kanl, ডার_, _kony_, tapw,
   {{0x63bb0ce8,0x20020ce9,0x00000000,0x00000000}},	//   hgun, ljki_, --, --,
   {{0x5fc10cea,0xa3e90ceb,0x61e30cec,0x00000000}},	//   ष्कल, मया_, _manl, --,
   {{0xb8f20755,0x46ea0ced,0x61e30cee,0x6d5e0cef}},	//   _वह_, иден_, _lanl, _izpa,
   {{0x38660cf0,0x70b600dc,0x4e0e08b6,0xe66601f0}},	//   rmor_, _अम्ल, _हवाई_, отко,
   {{0xb0a90cf1,0x61e30cf2,0x63bb0cf3,0x6aa4002f}},	//   _किंग, _nanl, egun, msif,
   {{0xf8b000b5,0x9f4500b8,0x443d0051,0xa3d60387}},	//   _سکا_, ělé_, _bjw_, ाजल_,
   {{0x2fc00189,0x61e30136,0x799c0cf4,0x02a601f0}},	//   _ncig_, _aanl, _herw, ором,
   {{0x61e30cf5,0x2d830035,0x75d60833,0x32070096}},	//   _banl, ycje_, _ويرا, _bony_,
   {{0x61e30cf6,0x3218006a,0x320701f7,0xd25a0166}},	//   _canl, óry_, _cony_, јци_,
   {{0x61e30cf7,0x63bb06a2,0xb97b02b8,0x799c053e}},	//   _danl, bgun, יניי, _merw,
   {{0x69ca09b8,0x68e3054e,0x27e60cf8,0x660800ac}},	//   स्ती, ændi, ndon_, _hodk,
   {{0x91e60cf9,0x7336006c,0x32070168,0x799c0cfa}},	//   _моде, _برائ, _fony_, _oerw,
   {{0x63a00cfb,0x61e3001e,0xd34400bf,0x799c0035}},	//   lamn, _ganl, _ویژه_, _nerw,
   {{0x27e6011e,0x2cb80cfc,0x64b800b4,0x66080cfd}},	//   kdon_, gurd_, _इमोश, _modk,
   {{0x27e40533,0xe3ac0033,0x63a00cfe,0x27e60987}},	//   _namn_, ক্রব, namn, jdon_,
   {{0x799c0cff,0xa3cc0d00,0x0dcb06e4,0x69d70391}},	// [750] _berw, श्य_, _куни_, texe,
   {{0x3eb90d01,0xaaac0437,0x63a00d02,0x61e3013b}},	//   must_, _चिरक, hamn, _xanl,
   {{0x25fe02e4,0x3eb90d03,0x799c0d04,0x69d70485}},	//   लानी_, lust_, _derw, rexe,
   {{0xa3b60907,0x69ce0d05,0x69d70d06,0x27e60107}},	//   _जाग_, _ebbe, sexe, gdon_,
   {{0xd6db0d07,0x799c0d08,0xd7c80934,0x2009012f}},	//   рте_, _ferw, تونه_, _moai_,
   {{0x95cb0036,0x62720035,0x20090023,0xd5b10037}},	//   руда_, _słon, _loai_, رفع_,
   {{0x1c0f0953,0x32070107,0x91fc0029,0x27e40d09}},	//   _सवाल_, _rony_, rmāl, _famn_,
   {{0x61e30d0a,0xd7c900bf,0x3eb9007c,0xe2990d0b}},	//   _sanl, _دوره_, kust_, баи_,
   {{0x63bb0d0c,0x61e30d0d,0x6608008c,0x799c030d}},	//   rgun, _panl, _fodk, _yerw,
   {{0x321e0d0e,0x2ea806bb,0x3eb90d01,0x66080c60}},	//   ghty_, _कटौत, dust_, _godk,
   {{0x61e30d0f,0x610a00a8,0x33750d10,0xd87400b5}},	//   _vanl, vəlc, _егер, _راہب,
   {{0x22800c1f,0x63a0022e,0x6b9d01ef,0x54370416}},	//   _fòk_, camn, _nesg, _برطر,
   {{0x61e30d11,0xe8030d12,0x320705f0,0x2f560d13}},	//   _tanl, _रचना_, _tony_, ятос,
   {{0x321e0d14,0xfc3f02d7,0x91e50d15,0x273800e2}},	//   chty_, _ají_, _хоке, ẩng_,
   {{0x27e60d16,0xed5a0d17,0xd3470088,0xdbd9008a}},	//   ydon_, сов_, _دیکه_, tæðu,
   {{0x799c006a,0x6aa40d18,0x3eb90d19,0x6b9d0d1a}},	//   _serw, tsif, bust_, _cesg,
   {{0x0b430d1b,0x799c0d1c,0x6b840d1d,0xdbd900fb}},	// [760] ентн, _perw, rcig, ræðu,
   {{0x6aa40d1e,0xa3ab0d1f,0x09e30144,0x6b840d20}},	//   rsif, कृत_, ноун, scig,
   {{0x799c0d21,0x1b040083,0x6aa40d22,0x63ab02a7}},	//   _verw, _রেখে_, ssif, _odgn,
   {{0xdcf5004e,0x799c0d23,0x27e60d24,0x79850d25}},	//   jczę, _werw, udon_, achw,
   {{0x799c0d26,0x660805d1,0x15fa00dc,0x27e60d27}},	//   _terw, _podk, _एचआर_, rdon_,
   {{0x98a605a1,0xd49a0d28,0x26c60086,0x6aa20009}},	//   _ниге, бри_, rtoo_, šofs,
   {{0x26c60d29,0x628b00e9,0x27e6011e,0x25fe0d2a}},	//   stoo_, _atgo, pdon_, लाबी_,
   {{0xa3b60299,0xa2d3000c,0xb6030029,0x046301f1}},	//   _जाओ_, _बैङ्, īšan, нтым,
   {{0x2bce02cb,0x27f7000c,0x18670044,0xd70700af}},	//   ह्या, šení_, _хати_, _енте_,
   {{0xe8e001a5,0x59cf0d2b,0x3eb9007c,0x63a00093}},	//   _nhịp_, स्पर, vust_, samn,
   {{0x3eb90120,0x69c10d2c,0x00000000,0x00000000}},	//   wust_, र्टी, --, --,
   {{0x3eb90006,0x5ed60033,0x2bce0b35,0x8fa40166}},	//   tust_, দিনে, ह्मा, наџе,
   {{0x6b9d0d2d,0x24490987,0x798500e9,0x7a200523}},	//   _resg, _بجلي_, ychw, _götg,
   {{0x99ce00c8,0x6b9d0d2e,0x3eb90d2f,0x00000000}},	//   রযুক, _sesg, rust_, --,
   {{0x61f802e6,0x3eb9007c,0x248c027a,0xddde00fd}},	//   _invl, sust_, _jtdm_, _cipő,
   {{0x5c740d30,0x3eb90d31,0xb15700a5,0x25fe01c0}},	//   елст, pust_, _מסוג_, लाडी_,
   {{0x3a75034b,0x3eb90d32,0x00000000,0x00000000}},	// [770] длар, qust_, --, --,
   {{0xdce70723,0x9967002d,0xa3cc0722,0xdcf50035}},	//   sajı, птел, श्त_, zczę,
   {{0x3ea9008e,0x02d90311,0x79850d33,0x201900c7}},	//   _hvat_, _भन्न, rchw, ūriu_,
   {{0x798502c9,0x69c10d34,0x69c8027d,0x00000000}},	//   schw, र्जी, _öden, --,
   {{0x601f00da,0x61f80d35,0x00000000,0x00000000}},	//   _këmb, _onvl, --, --,
   {{0x8afa00a5,0x00000000,0x00000000,0x00000000}},	//   _והשי, --, --, --,
   {{0x20f001f2,0x7aed09e8,0x8ca6073f,0x00000000}},	//   nđić_, lvat, _छिछो, --,
   {{0xfcaa0779,0x3ea90d36,0x61f8021e,0x657a03bc}},	//   קיפּ, _ovat_, _anvl, _egth,
   {{0x7aed0d37,0x00000000,0x00000000,0x00000000}},	//   nvat, --, --, --,
   {{0xf0a90217,0xbebb0055,0x00000000,0x00000000}},	//   окол_, tzën, --, --,
   {{0x7aed0d38,0x6d45006d,0xa06a0d39,0x349402fb}},	//   hvat, _nxha, жана_, _захр,
   {{0xe4d4006c,0x00000000,0x00000000,0x00000000}},	//   _ستمب, --, --, --,
   {{0x7aed00f4,0x3ea90207,0x628b0d3a,0x6d450c6f}},	//   jvat, _cvat_, _utgo, _axha,
   {{0x7a20006c,0x59cf05a6,0x7aed0d3b,0x6d570282}},	//   _köte, स्मर, dvat, _byxa,
   {{0x442f0553,0x4252006c,0x7aed00a0,0x7bcd0d3c}},	//   _kmg_, _جنور, evat, ffau,
   {{0x7a20022a,0xc1720122,0x201901f4,0x09a60099}},	//   _möte, _בחו_, ërit_, खण्य,
   {{0xfaa30d3d,0x7aed0d3e,0x6d450d3f,0x2eff02b1}},	// [780] като, gvat, _exha, äuft_,
   {{0x442f02c4,0xe9d70d40,0x601f01f4,0x00000000}},	//   _lmg_, мку_, _vëme, --,
   {{0x41cf0d41,0xf1cf00e7,0x3ea9022f,0x7aed081b}},	//   त्यस, त्यन, _zvat_, avat,
   {{0x6d4006d0,0x9f400d42,0x6a860009,0xb9060d43}},	//   şmas, _unió_, _олма, _भन_,
   {{0xc7a30d44,0xa3c8004e,0xd6d00609,0x7aed0d45}},	//   тичк, _लॉग_, اقت_, cvat,
   {{0x7a2001ff,0x3eaf01b4,0x6b96038d,0xe8df00e2}},	//   _böte, _ægte_, lbyg, _luộc_,
   {{0xa5c40067,0xf8d2018d,0x00000000,0x00000000}},	//   _राठौ, _सहिय, --, --,
   {{0xd4670274,0x6b9600d4,0x00000000,0x00000000}},	//   мије_, nbyg, --, --,
   {{0x42740d46,0x07a30009,0x86c60d47,0x39580282}},	//   нгис, _шатн, _زيان, _hyrs_,
   {{0x61e800e5,0xf8d208b6,0xdb1500f7,0x3ea90207}},	//   uddl, _सहाय, ébéc, _rvat_,
   {{0xd1300514,0x7a20022a,0x7aed0254,0xe8df01a5}},	//   امج_, _göte, zvat, _buộc_,
   {{0xe8df0028,0x7aed024e,0x4de7046c,0x00000000}},	//   _cuộc_, yvat, _छोड़े_, --,
   {{0xd6d9004e,0x6b960d48,0x2ef200e9,0x00000000}},	//   _były_, dbyg, _cryf_, --,
   {{0x7aed03c1,0x6ab603bc,0x2ef203bc,0xa3d60437}},	//   vvat, dryf, _dryf_, ाजक_,
   {{0xfe2400c3,0x1bd502fb,0x645c00ea,0x34dc021a}},	//   тьян, новя, _īrij, _मनोद,
   {{0x91ca0355,0x21b7006c,0x20f00009,0x7aed0d49}},	//   त्रै, _ٹھیک_, rđić_, tvat,
   {{0x2ef20d4a,0x201900e1,0xc054024b,0x00000000}},	// [790] _gryf_, ūris_, _בזק_, --,
   {{0x6d450d4b,0xe9d30037,0xc95b010b,0x00000000}},	//   _txha, ضغط_, оўе_, --,
   {{0x7aed0d4c,0x5884021f,0x5c7500cf,0x3958099e}},	//   svat, выча, _плот, _cyrs_,
   {{0x20190d4d,0xda090118,0x3958008c,0x00000000}},	//   nksi_, _کيسه_, _dyrs_, --,
   {{0x442f022e,0x201900c3,0x59c70d4e,0x97350d4f}},	//   _rmg_, iksi_, _लापर, رکرا,
   {{0x68e30d50,0x644200c3,0x649902c4,0x39580d51}},	//   ænds, _ajoi, птир_, _fyrs_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe73900e9,0x58d40746,0xc2fa0033,0x00000000}},	//   _ddŵr_, _шост, েননি_, --,
   {{0x7c3a03e6,0xf6b500b5,0x9f9d008a,0x95cb0d52}},	//   étri, _سماج, væði_, _мужа_,
   {{0x5694027a,0x20190086,0x7a20033b,0x41050aec}},	//   _рафт, eksi_, _töte, езов,
   {{0x6e3501a0,0x00000000,0x00000000,0x00000000}},	//   dizb, --, --, --,
   {{0xcdc90052,0x80a0006a,0x59cf0d53,0x3cf90066}},	//   _לך_, _खबरे, स्तर, _उपजे_,
   {{0xef1703ad,0x9f9d008a,0x93240312,0x00000000}},	//   емя_, ræði_, _لرون, --,
   {{0xfce60d54,0x91e20183,0xc6920070,0x201900c3}},	//   ного, _боше, ראם_, aksi_,
   {{0xa3cc0d55,0x81c80083,0x9d430009,0x621a0319}},	//   श्व_, _লোক_, герд, _מוסק,
   {{0x443f0d56,0x0eaa00af,0xfbdf0298,0x853c005f}},	//   nnu_, _екий_, _skêr_, _idėt,
   {{0x34dc00c0,0x6b960d57,0x443f0d58,0xbdfa00b2}},	// [7a0] _मन्द, rbyg, inu_, _فردا_,
   {{0x443f0d59,0x8e9700a5,0x6b960d5a,0x6d40013b}},	//   hnu_, _רדיו_, sbyg, şmaq,
   {{0x2d980d5b,0x69c801d6,0xf1c205fc,0xd7fa0043}},	//   mbre_, _ödem, _शासन, зул_,
   {{0x443f0d5c,0x41cf00a1,0x7afb02f6,0xf1cf007e}},	//   jnu_, त्तस, _šute, त्तन,
   {{0x443f0d5d,0xc879033e,0x645b01bf,0x00000000}},	//   dnu_, _diş_, dlui, --,
   {{0x443f0d5e,0x2d980d5f,0x857400b5,0x9f400176}},	//   enu_, nbre_, نگائ, _maià_,
   {{0x1dd20d60,0x645b0d61,0x443f0d62,0x5fc600a1}},	//   द्यत, flui, fnu_, _वाढल,
   {{0x66e60d63,0x443f0b79,0x25fe00a1,0x6b7b016b}},	//   _поба, gnu_, लाही_, ּרינ,
   {{0xe7d506d3,0x00000000,0x00000000,0x00000000}},	//   lığı, --, --, --,
   {{0x443f002d,0x9fd00083,0x69de0d64,0x1fa90355}},	//   anu_, িযোগ, nepe, कण्ड,
   {{0x443f0d5c,0x7c24005d,0x3a370122,0x610a00a8}},	//   bnu_, khir, תרים_, cəll,
   {{0x645b0d65,0x443f0d66,0x69de0d67,0x351b00a5}},	//   clui, cnu_, hepe, _מובנ,
   {{0x7c240d68,0x69de0d69,0x20190d6a,0x4ea7010b}},	//   dhir, kepe, rksi_, эрна,
   {{0xa3cc0bc1,0x932500b5,0x69de0d6b,0x127b0070}},	//   श्र_, _جرمن, jepe, _זאגע,
   {{0x63a20d6c,0x69de0d6d,0x62820118,0xc0e30d6e}},	//   _keon, depe, _huoo, _бојк,
   {{0xe7d50d6f,0x61ea0d70,0x63a200cc,0x7c240d71}},	//   dığı, _hafl, _jeon, ghir,
   {{0xf1a40084,0x61ea0093,0xc87f00d0,0x9f4001f7}},	// [7b0] _खजान, _kafl, ışma_, _gaià_,
   {{0x443f0d5c,0x69de0d72,0x5a340d73,0x7c240054}},	//   znu_, gepe, гнут, ahir,
   {{0x443f0297,0x7c2400f1,0x7ae603d0,0xdb1600fd}},	//   ynu_, bhir, _eskt, rgyá,
   {{0x7c240d74,0x61ea0d75,0x610a00a8,0x28d200ab}},	//   chir, _lafl, vəll, _सहरि,
   {{0x44240082,0x443f011c,0x69de09a6,0x66e50409}},	//   dhm_, vnu_, bepe, тола,
   {{0x27e901cc,0xe6180185,0x69de0d76,0xcfea0083}},	//   žan_, нді_, cepe, গায়_,
   {{0x443f0d77,0x645b053e,0x6e200031,0x3eb902b1}},	//   tnu_, tlui, ëmbi, hrst_,
   {{0x7bdf0183,0x443f0d78,0x00000000,0x00000000}},	//   nequ, unu_, --, --,
   {{0x443f0d79,0xd7c800e0,0x63a20d7a,0x645b0d7b}},	//   rnu_, _سوله_, _deon, rlui,
   {{0xd24e0ad9,0x645b0d26,0x443f0d7c,0x7bdf0d7d}},	//   يني_, slui, snu_, hequ,
   {{0x443f0d7e,0x61ea00e9,0x25fe00ab,0x59c609b1}},	//   pnu_, _dafl, लारी_, र्टर,
   {{0x9f400176,0x69de0d7f,0x7a20017b,0x6d5a018d}},	//   _paià_, zepe, _möta, ütam,
   {{0x69c70c21,0x7bdf0d80,0x69de0d81,0x69d50168}},	//   _ocje, dequ, yepe, _obze,
   {{0xdd920d82,0x61ea0d83,0x00000000,0x00000000}},	//   شور_, _gafl, --, --,
   {{0xed570b46,0x7c24000e,0x27310019,0xada30d84}},	//   вор_, thir, ạnh_, расл,
   {{0x60d60d85,0x1c430043,0x8c4303e6,0x63a20042}},	//   _יוצא_, ансм, аесе, _xeon,
   {{0xeab10332,0xc1e5083f,0x7c24099e,0x00000000}},	// [7c0] یعے_, _कसाब_, rhir, --,
   {{0x7c240d86,0x61ea01b7,0xceb9000c,0x68f5024e}},	//   shir, _xafl, áře_, _brzd,
   {{0x69de0d87,0x291c0d88,0x00000000,0x00000000}},	//   repe, áva_, --, --,
   {{0x69de0d89,0xe73a0d8a,0x3ea002d0,0x7ae6010d}},	//   sepe, мее_, _kwit_, _tskt,
   {{0x63a20d8b,0x6272004e,0xa6fa0037,0x69de0d8c}},	//   _reon, _głow, بعاء_, pepe,
   {{0xaa460d8d,0x4a750086,0x63a20d8e,0x7ae4035a}},	//   _регл, _быст, _seon, mwit,
   {{0x98a306cd,0x7a20013c,0x7ae403bc,0xdb040d8f}},	//   _висе, _göta, lwit, rgiõ,
   {{0x61ea0297,0xa7850082,0x7bc40d90,0x44f10024}},	//   _safl, _مشكو, ngiu, _dġ_,
   {{0x59cf0d91,0x268a00b5,0x7c230043,0x7ae40d92}},	//   स्वर, _آخري_, _înre, nwit,
   {{0x610a0095,0x63a20453,0x3f800183,0x61ea0024}},	//   səlm, _weon, _agiu_, _qafl,
   {{0x85060d93,0x9f4e024e,0x3ea00d94,0x63a200d7}},	//   _جوان, čným_, _awit_, _teon,
   {{0xc9530052,0x7ae40d95,0x7d0301f7,0x628f002a}},	//   ימת_, kwit, _ànsi, ícoc,
   {{0x05c90d96,0x61ea0d97,0x00000000,0x00000000}},	//   _रामब, _tafl, --, --,
   {{0xf7730bed,0x6e9400c3,0x7bc40d98,0x00000000}},	//   יקר_, риру, egiu, --,
   {{0x6272006a,0x7bdf0d99,0x1dd209b1,0x7ae40110}},	//   _słow, tequ, द्धत, ewit,
   {{0x7bc401d3,0xd10f0d00,0xa17700a5,0x217700a5}},	//   ggiu, ाहरण_, _בעוד_, _בתור_,
   {{0x41cf007e,0xf1cf0355,0xdb1d0260,0x3c5800af}},	// [7d0] त्वस, त्वन, _absò, титэ_,
   {{0x7bdf0d9a,0x200b0bc6,0x2ee900e9,0xf7f400d1}},	//   sequ, ljci_, _isaf_, یسند,
   {{0x386f0069,0x7bdf0d9b,0x2d810371,0x6d4105ee}},	//   tmgr_, pequ, _ighe_, úlad,
   {{0x787a01c0,0x200b0169,0xc8640d9c,0x7ae40d9d}},	//   _důvo, njci_, атчи, bwit,
   {{0x81d200e2,0x00000000,0x00000000,0x00000000}},	//   _rồng, --, --, --,
   {{0x69c7012e,0x6b8d0036,0x26360035,0xc9870d9e}},	//   _ucje, lcag, słon_, _шуми,
   {{0x6aad0d9f,0xd5ae0a42,0x00000000,0x00000000}},	//   lsaf, سفي_, --, --,
   {{0x2fc9006d,0x69c50da0,0xd4660da1,0x32cb02ce}},	//   _ncag_, lghe, лище_, tøy_,
   {{0x2bd500a1,0x6aad0da2,0x27ff01ed,0x65950da3}},	//   ड्या, nsaf, _inun_, _базу,
   {{0x2d810028,0x27ed0da4,0x95d80421,0xc5fb0698}},	//   _nghe_, _haen_, _идут_, _تعرض_,
   {{0xe4cb0357,0x69c50094,0x2ee90da5,0x27ed0159}},	//   _زبان_, ighe, _asaf_, _kaen_,
   {{0xf3f0004f,0x27ed0da6,0x24850036,0x25a506c6}},	//   _وأن_, _jaen_, _iulm_, _hell_,
   {{0x25a50da7,0x27ed001e,0x63a90da8,0x645901d5}},	//   _kell_, _maen_, maen, _ikwi,
   {{0x63a90da9,0x6aad0a8a,0x25a5055c,0x27ed0daa}},	//   laen, dsaf, _jell_, _laen_,
   {{0x61e10dab,0x27ff0dac,0x03e60083,0xdcee04d4}},	//   mell, _onun_, কারী_, tabı,
   {{0x41cf0a90,0x7afb0129,0x61e10dad,0x63a90dae}},	//   त्रस, _šuta, lell, naen,
   {{0xab660daf,0x7643046a,0x6459023c,0x3ea000e0}},	// [7e0] увал, knny, _mkwi, _uwit_,
   {{0x25a50133,0x787a01c0,0xdcee04d4,0x27ed0a8a}},	//   _nell_, _půvo, sabı, _aaen_,
   {{0x60c10db0,0x61e102fb,0x610a0095,0x63a90db1}},	//   nulm, iell, vəlk, kaen,
   {{0x6b8d0db2,0x61e10db3,0x27ed0db4,0xe4f9012f}},	//   ccag, hell, _caen_, ्मनि_,
   {{0x61e10db5,0x6d5e0db6,0x63a9016e,0x25a50db7}},	//   kell, _hypa, daen, _bell_,
   {{0x7e7e0484,0x25a50db8,0x61e10db9,0xa8a600b5}},	//   _jipp, _cell_, jell, _مصرو,
   {{0x61e10dba,0x25a50dbb,0x63a90dbc,0x83fd006c}},	//   dell, _dell_, faen, klőd,
   {{0x3a3a0dbd,0x7643005d,0x4422006c,0x61e10086}},	//   lipp_, anny, ók_, eell,
   {{0x61e10dbe,0x610a0095,0x57460dbf,0xe3af0dc0}},	//   fell, məli, _снаб, سري_,
   {{0x61e10dc1,0xf1c601c0,0x64590dc2,0x2000002d}},	//   gell, _část_, _ekwi, _anii_,
   {{0x63a90dc3,0x20120b13,0x00000000,0x00000000}},	//   baen, _boyi_, --, --,
   {{0x0eeb0086,0x7e7e01e0,0x25a50dc4,0x610a013b}},	//   ньги_, _aipp, _zell_, nəli,
   {{0xe2960370,0x6aa30437,0x6fc60785,0x6d5e0be2}},	//   _среќ, _ओबेर, _वारं, _aypa,
   {{0x61e10dc5,0x7e7e0dc6,0x2fc9021d,0x25a501f7}},	//   cell, _cipp, _wcag_, _xell_,
   {{0x7e7e0dc7,0x23b800ab,0x00000000,0x00000000}},	//   _dipp, _इयाद, --, --,
   {{0x60df006c,0x7e7e02a7,0x6d5e0055,0x00000000}},	//   őzmé, _eipp, _dypa, --,
   {{0x5a350dc8,0x765a0d32,0x7e7e0dc9,0x76430dca}},	// [7f0] анат, _okty, _fipp, ynny,
   {{0x27ed01dd,0x6b8d027a,0x6aad0dcb,0x321e0035}},	//   _saen_, scag, rsaf, nkty_,
   {{0xa3e50299,0x69c50dcc,0x6aad0dcd,0x63a908c7}},	//   _फसल_, rghe, ssaf, yaen,
   {{0x765a0dce,0x61e10dcf,0x67d50dd0,0x6272004e}},	//   _akty, zell, роду, _złot,
   {{0x25a503b6,0x61e10dd1,0x60c10644,0x63a9018d}},	//   _pell_, yell, zulm, vaen,
   {{0xf7700dd2,0x60c10644,0x7643022e,0x672b01f4}},	//   سان_, yulm, unny, rzgj,
   {{0x63a90dd3,0x25a50dd4,0x61e10dd5,0x76430dd6}},	//   taen, _vell_, vell, rnny,
   {{0x25a50052,0x61e10dd7,0xb6c900b5,0x321e0067}},	//   _well_, well, _لائے_, ekty_,
   {{0x61e10dd8,0xcb1202b5,0x25a50122,0x74120c74}},	//   tell, ַלט_, _tell_, تويا,
   {{0x60c10dd9,0x63a90dda,0xdb0d0ddb,0x22150ddc}},	//   tulm, saen, ngañ, рфир,
   {{0xc5fa02b5,0xb5fa02b5,0x386d0107,0x69ca00b4}},	//   _שפעט, _שלעכ, _kher_, स्टी,
   {{0x61e10ddd,0x43750dde,0x60c106d0,0x64590010}},	//   sell, _култ, rulm, _ukwi,
   {{0xe7d70302,0x7afb025c,0x7e7e0ddf,0xeac00083}},	//   ण्यप, _šutn, _pipp, _উন্ম,
   {{0x51870de0,0x387f0034,0x6da302f3,0x60c100b9}},	//   _суда, _liur_, жира, pulm,
   {{0xed5a0de1,0xe8160302,0xdca60de2,0x6286024e}},	//   тов_, _थकला_, раби, íkov,
   {{0x1e860de3,0x20000de4,0x6d5e0333,0x387f009e}},	//   _клим, _unii_, _vypa, _niur_,

   {{0x7e7e0de5,0x6272004e,0x6d5e004e,0xdee60de6}},	// [800] _tipp, _głos, _wypa, _топи,
   {{0x6d41004f,0x3ead003c,0x3c3f00c3,0x64950069}},	//   úlac, ġett_, tävä_, _iġif,
   {{0x6fd30026,0x6e3c0de7,0xa3e50067,0x610a013b}},	//   ध्वं, mirb, _फसं_, təli,
   {{0x386d02e1,0xd7f9005f,0x1dd20de8,0x387f0160}},	//   _cher_, луі_, द्रत, _ciur_,
   {{0x66f40de9,0x386d0dea,0x387f009e,0xc6a3051a}},	//   сплу, _dher_, _diur_, орщи,
   {{0xfaa30deb,0x386d02c9,0xdb060031,0xc8960dec}},	//   _фаро, _eher_, _lekë, _врањ,
   {{0xd9430ded,0x386d0069,0x00000000,0x00000000}},	//   _дери, _fher_, --, --,
   {{0x6a6b033b,0x387f0036,0x986a00af,0xe8df00e2}},	//   rüfe, _giur_, _рибб_, _guốc_,
   {{0xf5ea0dee,0xdb0d0093,0x00000000,0x00000000}},	//   _имал_, ngað, --, --,
   {{0xd4d600d8,0x387f01a3,0x00000000,0x00000000}},	//   _відэ, _ziur_, --, --,
   {{0x6e3c0def,0x741600f8,0x765800ac,0x00000000}},	//   dirb, _پوشا, movy, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22940514,0x44260df0,0x3294004f,0xd0420095}},	//   _التس, _ilo_, _التأ, ntlə,
   {{0x4426006f,0x7c26030d,0x765800ac,0x00000000}},	//   _hlo_, _alkr, novy, --,
   {{0x442603ad,0x2ba70798,0x6272004e,0xe7d70bad}},	//   _klo_, ијав, _włos, ण्डप,
   {{0xf21c0299,0x717b0122,0x5bb80086,0xd04200a8}},	//   _पकड़_, _בנוס, ился_, ktlə,
   {{0xb06600ab,0xaed50274,0x442608c7,0xe9870274}},	// [810] svää, _уопш, _mlo_, аћен,
   {{0x44260df1,0x7ac40dba,0x7c260523,0xeb9f0a8a}},	//   _llo_, юссе, _elkr, _snød_,
   {{0xda78071d,0x44260df2,0x4f580df3,0x98b9081b}},	//   рят_, _olo_, _مجید_, улет_,
   {{0xd12600f5,0xe8df00e8,0x44260df4,0x00000000}},	//   _ہم_, _quốc_, _nlo_, --,
   {{0x6eaa0243,0xba770088,0x610a013b,0x6f1d00d5}},	//   जीपु, _ناست, məlu, nysc,
   {{0x44260df5,0x386d0159,0xcb12011d,0xe5a20df6}},	//   _alo_, _wher_, _צלם_, пиши,
   {{0x4426008b,0x95c80009,0x29070df7,0x81ac0033}},	//   _blo_, руча_, ånad_, গলা_,
   {{0x43690df8,0x44260df9,0x5fc60026,0x13e9081b}},	//   лайн_, _clo_, _वाइल, умий_,
   {{0xd8380409,0x44260c1f,0x00000000,0x00000000}},	//   _тэр_, _dlo_, --, --,
   {{0x44260dfa,0x00000000,0x00000000,0x00000000}},	//   _elo_, --, --, --,
   {{0x7afb0124,0x1b1b0033,0x6d40045e,0x786a00ac}},	//   _šutl, _নেমে_, şmaz, lýva,
   {{0x44260dfb,0xdee60dfc,0x9f4200ac,0x6e3c02b1}},	//   _glo_, боми, leké_, wirb,
   {{0x2bcb0067,0x6e3c0dfd,0x00000000,0x00000000}},	//   िलना, tirb, --, --,
   {{0xe29c02b5,0x44260a18,0x7d1c0dfe,0x51950037}},	//   _ישׂר, _zlo_, tyrs, _الغذ,
   {{0x82340dff,0x1d1902ce,0xdca302c8,0x6e3c0093}},	//   _برنا, ають_, заси, rirb,
   {{0x61b700a1,0x3b860b5e,0x65610e00,0x6f1d0e01}},	//   _आयुष, слаг, _mylh, bysc,
   {{0xe9da0e02,0xc0530122,0x62720035,0x3b070be8}},	// [820] лка_, _מזה_, _kłop, бето_,
   {{0xdb0d008d,0x7dea0421,0x00000000,0x00000000}},	//   rgað, _смог_, --, --,
   {{0xd23a02b5,0xe80400a1,0x00000000,0x00000000}},	//   נגעל, ळाला_, --, --,
   {{0xa2aa0066,0x3ebf0506,0x20f70139,0x64950069}},	//   _फ़िल्, šute_, _măi_, _mġid,
   {{0x2907013c,0x00000000,0x00000000,0x00000000}},	//   änar_, --, --, --,
   {{0x44260e03,0xd0420095,0x644b0176,0xcff10033}},	//   _slo_, rtlə, _ajgi, টায়_,
   {{0xd0420095,0x26190e04,0x6f1d004e,0xd49700d8}},	//   stlə, _बकरी_, zysc, бры_,
   {{0xb2b80e05,0x786a0e06,0x2905012e,0x941800c3}},	//   алиф_, býva, _šlag_, ржит_,
   {{0x59cf051e,0x6a7001ff,0x44260051,0xd37700af}},	//   स्कर, räff, _vlo_, йчь_,
   {{0x6d4006d3,0x20f70395,0xf2380279,0x09e60831}},	//   şmay, _băi_, рпош_, নাকা,
   {{0x69dc0e07,0x44260254,0x20f70395,0xc0aa0079}},	//   _mbre, _tlo_, _căi_, داخل_,
   {{0x4386004f,0x69d80963,0x44260e08,0x44200019}},	//   _الإق, न्ती, _ulo_, _ôi_,
   {{0x69dc0e09,0x00000000,0x00000000,0x00000000}},	//   _obre, --, --, --,
   {{0xdd940409,0x44f80019,0x13ad0033,0x25fe00b4}},	//   зары, _kĩ_, _গায়, लाटी_,
   {{0x786a0334,0xe6a50026,0x2d910035,0xb4250035}},	//   zýva, _ऑब्ज, rcze_, łżeń,
   {{0xa3cc021a,0x27e6012f,0x44f80023,0x69ce00cc}},	//   श्च_, jeon_, _mĩ_, _acbe,
   {{0x7b670e0a,0x69dc0024,0x64950024,0x68fc0c6f}},	// [830] стве, _bbre, _iġie, _arrd,
   {{0x69dc0e0b,0x00000000,0x00000000,0x00000000}},	//   _cbre, --, --, --,
   {{0xdd920919,0xa3e8018d,0x4e940088,0x7c230395}},	//   _توپ_, मजा_, _وشیر, _înro,
   {{0x7c670e0c,0x69dc0e0d,0x7aee00c3,0x7d1a0e0e}},	//   _داخل, _ebre, äntä, ätse,
   {{0x7c2d0e0f,0xdcf5045e,0x65610088,0x6495009f}},	//   mhar, mazı, _sylh, _mġie,
   {{0x7afd02ee,0x69d800c0,0x786a0097,0x7aef021d}},	//   _irst, न्दी, rýva, _isct,
   {{0x240907bc,0x1ddb07df,0xafdb08c8,0x7afd0791}},	//   инки_, म्यत, rnøj, _hrst,
   {{0x7afd0902,0x7c2d0e10,0x601f00da,0x44f80019}},	//   _krst, nhar, _fëmi, _dĩ_,
   {{0xc7b9006c,0x7afb022f,0x20f700af,0x00000000}},	//   _idő_, _šutj, _săi_, --,
   {{0x1ddb0e11,0x80cd0033,0xdcf501fb,0x20f70395}},	//   म्मत, ়বস্, hazı, _păi_,
   {{0x7bcf0e12,0x71690036,0x629b0421,0x00000000}},	//   _occu, ранг_, spuo, --,
   {{0xe8e000e2,0x20f70160,0xe8df00cc,0x00000000}},	//   _chộp_, _văi_, _chỉa_, --,
   {{0x7c2d0a12,0x442d006e,0x6d410e13,0xc7d600a5}},	//   dhar, mhe_, úlan, חורי_,
   {{0x443f0e14,0x442d0370,0x7bcf0e15,0x628b0e16}},	//   liu_, lhe_, _accu, _iugo,
   {{0x7afd007c,0x628308dd,0x64950024,0x64490e17}},	//   _arst, _iino, _fġie, onei,
   {{0x443f0e18,0x62830e19,0x7c2d0e1a,0x64490e1b}},	//   niu_, _hino, ghar, nnei,
   {{0x628b0e1c,0xda050e1d,0x63ab0332,0x64490e1e}},	// [840] _jugo, रांत_, _megn, inei,
   {{0x63ab0e1f,0x442d0e20,0x628300b8,0x64490e21}},	//   _legn, hhe_, _jino, hnei,
   {{0x7afd0938,0x7c2d0e22,0x443f01c8,0x78a7006d}},	//   _erst, bhar, kiu_, _cwjv,
   {{0x62830e23,0x7c2d0e24,0x442d0051,0x60da0070}},	//   _lino, char, jhe_, יקענ,
   {{0x442d0e25,0x443f0e26,0x44f80028,0x27e60e27}},	//   dhe_, diu_, _sĩ_, reon_,
   {{0x62830e28,0x7c24007c,0x27e60e29,0x8c1f0033}},	//   _nino, lkir, seon_, নোদন_,
   {{0x7a2001ae,0x628b00ea,0x443f00a0,0x291c00ab}},	//   _nöti, _augo, fiu_, ävad_,
   {{0x442d0e2a,0x443f0e2b,0x628b0e2c,0x62830086}},	//   ghe_, giu_, _bugo, _aino,
   {{0x63ab0e2d,0x7c2401a8,0x628b0124,0x2bcb0d1f}},	//   _degn, ikir, _cugo, िलता,
   {{0x38660e2e,0x628b0e2f,0x64490e30,0x7afb0e31}},	//   llor_, _dugo, anei, _šutk,
   {{0x93540332,0x443f0e32,0xf9930052,0x442d0094}},	//   _کراچ, biu_, ורת_, bhe_,
   {{0x443f0e33,0x63ab0e34,0x64490211,0x7c2402c4}},	//   ciu_, _gegn, cnei, jkir,
   {{0x62830e35,0xc7b30052,0x64400e36,0xe1ef01ca}},	//   _fino, ובר_, mimi, رسی_,
   {{0x7c2d01a2,0x62830e37,0x64400e38,0x63ab008c}},	//   whar, _gino, limi, _zegn,
   {{0x7c2d0e39,0xfe6e0e3a,0x61e8071b,0x7c240024}},	//   thar, دگي_, medl, fkir,
   {{0x59dd0e3b,0x628b022e,0x62830e3c,0x386601f2}},	//   न्नर, _yugo, _zino, jlor_,
   {{0xdceb06d3,0x8d870466,0xdcf505f9,0x628b01ef}},	// [850] ınız, _мунд, razı, _xugo,
   {{0x7afd0e3d,0x7c2d0e3e,0x61e80e3f,0x442d00da}},	//   _vrst, shar, nedl, zhe_,
   {{0x64400e40,0x3ea9012f,0xf8b10416,0x58d40036}},	//   kimi, _hwat_, عکس_, дохт,
   {{0xdce50028,0x443f0e41,0x7afd0e42,0x64400e43}},	//   _nghĩ, xiu_, _trst, jimi,
   {{0x443f0e44,0x63ab0e45,0x660501d3,0xe8e00019}},	//   viu_, _regn, зпла, _khớp_,
   {{0x63ab0133,0x61e80e46,0x628b0e47,0x656500ab}},	//   _segn, jedl, _rugo, ühho,
   {{0x442d0e48,0x443f0e49,0x628b0e4a,0x64400e4b}},	//   the_, tiu_, _sugo, fimi,
   {{0x64400e4c,0x7bcd0e4d,0x628b0cca,0x7aed0e4e}},	//   gimi, ngau, _pugo, owat,
   {{0x63ab00fb,0x443f0e4f,0x62830e50,0x442d0e51}},	//   _vegn, riu_, _pino, rhe_,
   {{0x442d0e52,0x443f0e53,0x63ab0e54,0x64400079}},	//   she_, siu_, _wegn, aimi,
   {{0x442d0e55,0x64400e56,0x63ab0b20,0x443f0e57}},	//   phe_, bimi, _tegn, piu_,
   {{0x644000c8,0x7aed0273,0x628b0e58,0x3ea902e9}},	//   cimi, kwat, _tugo, _bwat_,
   {{0x62830e59,0x6299004e,0x628b0159,0x61e80009}},	//   _tino, _utwo, _uugo, bedl,
   {{0x7aed0e5a,0x3ea902e9,0xe8020084,0xe8e00023}},	//   dwat, _dwat_, _रोना_, _chớp_,
   {{0x7aed0e5b,0x32070035,0x38660e5c,0x7c240e5d}},	//   ewat, _inny_, ylor_, tkir,
   {{0x5fc600a1,0xdddc0187,0x3ebf0e5e,0x7bcd081b}},	//   _वाटल, zorň, šuta_, ggau,
   {{0x7c240e5f,0x6e460e60,0x70db0e61,0x6fa20e62}},	// [860] rkir, _неиз, _बहुल, _क्यू,
   {{0x64400e63,0x7c2408d8,0x4efb02b5,0x1efb0070}},	//   zimi, skir, _פליג, _פליע,
   {{0x64400e64,0xae1b02b5,0xa3ae018d,0xfaff0031}},	//   yimi, _הויכ, करम_, _erë_,
   {{0x7aed0e65,0x00000000,0x00000000,0x00000000}},	//   bwat, --, --, --,
   {{0x64400e66,0x38660e67,0xa2bd0e68,0xb86600b5}},	//   vimi, rlor_, _शिष्, _ہارو,
   {{0x28c90026,0x16030354,0x00000000,0x00000000}},	//   ांशि, लागर_, --, --,
   {{0x443d0e69,0x61e80e6a,0xb8660e6b,0x64400b73}},	//   _bmw_, vedl, _فارو, timi,
   {{0x7afb003a,0x329803e6,0x60c80e6c,0x443d0345}},	//   _šuti, овиќ_, vudm, _cmw_,
   {{0x443d00d5,0x787a00fe,0x61e80e6d,0x00000000}},	//   _dmw_, _důvt, tedl, --,
   {{0x64400e6e,0x80c00e6f,0x248c0a4e,0xf8e007b5}},	//   simi, _विदे, _tudm_, _नहाय,
   {{0x859b0122,0x64400e70,0x64a30e71,0x6608054e}},	//   _השבו, pimi, _заха, _indk,
   {{0x7aed006a,0x35d20243,0x64400e72,0xa3e30d2a}},	//   ywat, _साड़, qimi, _पॉप_,
   {{0x661a0e73,0x82fa02fd,0xaa7b00ee,0x00000000}},	//   _kotk, _دراز_, _osýp, --,
   {{0x661a03ad,0xe3b00416,0x00000000,0x00000000}},	//   _jotk, _سرچ_, --, --,
   {{0x61db0bed,0x601f00da,0x7bcd005f,0x7aed0e74}},	//   _הקוד, _sëmu, tgau, wwat,
   {{0x7bcd00c7,0x00000000,0x00000000,0x00000000}},	//   ugau, --, --, --,
   {{0x3b540e75,0xa3de0835,0x35d20299,0x601f01f4}},	// [870] ектр, द्य_, _साढ़, _dëmt,
   {{0x24860082,0x91fc0080,0x7c870043,0x661a0e76}},	//   _liom_, klām, _нуме, _notk,
   {{0x7aed0e77,0xf9880037,0x9f5200a2,0x41d4007e}},	//   swat, أنمي_, _rayé_, _दानस,
   {{0xa2bd0ac4,0xa3de060a,0x66080e78,0x6fad021a}},	//   _शिल्, द्म_, _andk, चरिं,
   {{0xd6db0e79,0x2366006d,0x661a0e7a,0x9f5200f7}},	//   сте_, _nyoj_, _botk, _payé_,
   {{0x95cb0e7b,0x661a023a,0x59c70066,0x00000000}},	//   суда_, _cotk, _लाटर, --,
   {{0x661a0e7c,0x2486007e,0x80db073f,0xd5b8013a}},	//   _dotk, _biom_, _बहें, _alās_,
   {{0x3e6400b5,0x00000000,0x00000000,0x00000000}},	//   lött_, --, --, --,
   {{0x661a0e7d,0xe1f200b5,0x00000000,0x00000000}},	//   _fotk, چسپ_, --, --,
   {{0x200901b7,0x80d901e0,0x7a20008d,0x00000000}},	//   _anai_, оєму_, _fötu, --,
   {{0x443d027a,0x2486027a,0x7a200093,0xb7bd00af}},	//   _tmw_, _fiom_, _götu, _alţi,
   {{0x59dd06d9,0x76430e7e,0xa3ae0e7f,0x46d10066}},	//   न्तर, liny, करण_, _समाह,
   {{0xd09201c2,0x7a200e80,0xdb0600de,0x9f5f008d}},	//   _müəy, _kött, _pekí, ðuð_,
   {{0xfce600d4,0x1e83010b,0x3e6400b5,0x7a2000b5}},	//   мого, клям, jött_, _jött,
   {{0x91fc0029,0x41b200ce,0x7a200e81,0x3e6400b5}},	//   klāj, _شمير, _mött, dött_,
   {{0x601f0031,0x7a200e82,0x00000000,0x00000000}},	//   _dëms, _lött, --, --,
   {{0x76430e83,0xdd8f0332,0xcb670e84,0x13e00033}},	// [880] kiny, اوہ_, дате_, _মোড়,
   {{0x76430e85,0xda050026,0x6722002f,0x3e6400b5}},	//   jiny, रागत_, vyoj, gött_,
   {{0x76430e86,0x661a0e87,0x6ab60282,0x00000000}},	//   diny, _rotk, ssyf, --,
   {{0x3b0a0e88,0x50c5018d,0x27e005ee,0x80c000be}},	//   _демо_, _विनष, ýin_, _विसे,
   {{0x76430e89,0x24860e8a,0x00000000,0x00000000}},	//   finy, _riom_, --, --,
   {{0xd49a0e8b,0x59dd051d,0x9d45006c,0x2d980e8c}},	//   ори_, न्दर, _آئین, ncre_,
   {{0xf9830e8d,0x661a0e8e,0x7a20017b,0x00000000}},	//   _агро, _votk, _dött, --,
   {{0x764300d7,0xa80301d3,0xb7fb0afa,0x00000000}},	//   ainy, _изсл, _एफएम_, --,
   {{0x20090e8f,0x7a2001ff,0x76430e90,0xe3af0098}},	//   _rnai_, _fött, biny, جرى_,
   {{0x7a20064c,0x20090036,0x7643007b,0x00000000}},	//   _gött, _snai_, ciny, --,
   {{0x24860211,0x00000000,0x00000000,0x00000000}},	//   _tiom_, --, --, --,
   {{0x3e640332,0x53460340,0xdb0f021d,0x00000000}},	//   zött_, _охла, _decê, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69de0051,0x00000000,0x00000000,0x00000000}},	//   jfpe, --, --, --,
   {{0xdb0600d5,0x463b016b,0x00000000,0x00000000}},	//   _odkó, קעלע, --, --,
   {{0x76430e91,0x61f80e92,0x20090e93,0x69de0223}},	//   ziny, _havl, _unai_, efpe,
   {{0x76430e94,0x3a750947,0x0c840409,0x3e6400b5}},	// [890] yiny, елар, тырм, tött_,
   {{0x61f80a78,0x61fa082b,0x00000000,0x00000000}},	//   _javl, ndtl, --, --,
   {{0xa3ae0ccf,0x76430e95,0x64dd0e96,0x7a200301}},	//   करा_, viny, _महेश, _rött,
   {{0x2c2702ce,0x61f80e97,0xfc3f00b8,0x6d570024}},	//   _цьог, _lavl, _umí_, _ixxa,
   {{0x76430e98,0x6b9a00a5,0x00000000,0x00000000}},	//   tiny, _משרד, --, --,
   {{0xf7700357,0x321c0bca,0x7643012f,0x249e055c}},	//   جام_, _novy_, uiny, _bttm_,
   {{0x76430e99,0x9f4e0355,0x00000000,0x00000000}},	//   riny, čném_, --, --,
   {{0x76430e9a,0xc7c400af,0x26c60207,0x9f4b021d}},	//   siny, _асфи, broo_, recê_,
   {{0xa3de0e9b,0x76430e9c,0x25f7045c,0xddde0e9d}},	//   द्ध_, piny, _एसपी_, _lipš,
   {{0x80c0074f,0x61f80e9e,0xf5270e9f,0xaac70bdd}},	//   _विशे, _cavl, _офен, _लिनक,
   {{0xa06a0ea0,0xe0460ea1,0x64450ea2,0x321c0051}},	//   зана_, енни, éhis, _dovy_,
   {{0x44f10a93,0xdb06016f,0xb4fa00a5,0x80c00ea3}},	//   _iš_, _leká, _מפעי, _विरे,
   {{0xc2c803c7,0xd12e0164,0x442f01ef,0x93270ca8}},	//   _قبول_, لمی_, _ilg_, _تران,
   {{0x2d8c035b,0x7c2f0282,0x61f8093a,0x00000000}},	//   øde_, _alcr, _gavl, --,
   {{0xdb0400c8,0xb4ad0006,0x32d902e9,0x1d070ea4}},	//   mbié, _कबो_, lèy_, нери_,
   {{0x44f10187,0x59dd0569,0x3c2e00a0,0x00000000}},	//   _mš_, न्सर, _býva_, --,
   {{0x442f0ea5,0x2903003c,0x77690282,0x00000000}},	// [8a0] _mlg_, _arja_, _nyex, --,
   {{0x44f10528,0x7c2f0176,0x4a4303e6,0x2d9a0183}},	//   _oš_, _elcr, гнув, _ufpe_,
   {{0x4c860ea6,0xd8260ea7,0xdb06040f,0x6f0400d5}},	//   _плов, нджи, _deká, _hric,
   {{0x6f040ea8,0x69d50ea9,0xa01b0eaa,0xdc9b0070}},	//   _kric, _ecze, rmög, _מיטל,
   {{0xdcfc0669,0x44f101c8,0xa01b033b,0xdb0600d5}},	//   marı, _aš_, smög, _feká,
   {{0xdcfc0eab,0x80c00026,0xceb30317,0x6f0400e0}},	//   ları, _विले, ריג_, _mric,
   {{0xdb1d0107,0x6e200055,0x442f0553,0x20d801ef}},	//   _adsè, ëmby, _blg_, xéi_,
   {{0x6f040012,0x61f80eac,0xdcfc00c1,0x442f0098}},	//   _oric, _savl, narı, _clg_,
   {{0x5334002d,0x44f100f4,0x99610228,0x00000000}},	//   тепт, _eš_, _cīņa_, --,
   {{0xdb0f0176,0x2d8c0bca,0x442f0ead,0xdb0400a2}},	//   _decè, ždej_, _elg_, rbiè,
   {{0x40350607,0xdcfc01d6,0x6f040eae,0x3a370122}},	//   венс, karı, _aric, גרים_,
   {{0x6f040eaf,0x00000000,0x00000000,0x00000000}},	//   _bric, --, --, --,
   {{0x44f1024e,0x61f80eb0,0x6d4805c9,0x93460eb1}},	//   _zš_, _tavl, údan, _янде,
   {{0x6f04013c,0xbe8800c3,0x00000000,0x00000000}},	//   _dric, ессе_, --, --,
   {{0xf1b302b8,0xcfb00083,0x2d850eb2,0xdb040183}},	//   _עסק_, _কারন, äle_, caiú,
   {{0x6f040eb3,0x3ea00484,0xac1803fa,0x656500be}},	//   _fric, _ftit_, носу_, ühhi,
   {{0x06e800c8,0x6c540eb4,0xf9c70eb5,0x6f040eb6}},	// [8b0] পিডি, укту, ещен, _gric,
   {{0x60c80223,0x00000000,0x00000000,0x00000000}},	//   ordm, --, --, --,
   {{0x628a0eb7,0xdcfc045e,0x98b9002d,0x00000000}},	//   _mifo, barı, флет_, --,
   {{0x69d5004e,0x9964002d,0x628a0eb8,0xdcfc00a8}},	//   _wcze, утул, _lifo, carı,
   {{0xe8df01a5,0x44f100ac,0x80380070,0x799c001e}},	//   _thỏa_, _sš_, ענדע_, _ffrw,
   {{0x69d5004e,0xb5c20eb9,0x442f023a,0x628a0064}},	//   _ucze, айшл, _slg_, _nifo,
   {{0x442f0eba,0x00000000,0x00000000,0x00000000}},	//   _plg_, --, --, --,
   {{0x13090ebb,0xd138004e,0x32d902d0,0x44f10097}},	//   дний_, dzą_, tèy_, _vš_,
   {{0x628a013c,0x27ef008c,0x35f50ebc,0x95d903e6}},	//   _bifo, megn_, _ипар, _одат_,
   {{0xdcfc0463,0x32d902e9,0x628a09c8,0x644201d7}},	//   zarı, rèy_, _cifo, _emoi,
   {{0xa2bd0ebd,0xf9920122,0x628a0044,0xdcfc00d0}},	//   _शिक्, ירי_, _difo, yarı,
   {{0x6f040ebe,0xdcfc0095,0x3ea00ebf,0x22450a8a}},	//   _pric, xarı, _ptit_, silk_,
   {{0x63a90ec0,0x539a0bed,0xdcfc00d0,0x26cf0ec1}},	//   mben, _חינו, varı, nugo_,
   {{0x63a90ec2,0x6fa202e4,0x628a0371,0x78780ec3}},	//   lben, _क्रू, _gifo, míve,
   {{0xdcfc0ec4,0xd1380035,0xd7b30ec5,0x78780ec6}},	//   tarı, czą_, ुणाच, líve,
   {{0x218800c2,0x51840131,0x31560070,0x26cf0ec7}},	//   _אָפּ, _суча, _שיקן_, kugo_,
   {{0x78780370,0x27fd0297,0xa3c40084,0xdcfc04d4}},	// [8c0] níve, ddwn_, ौलत_, rarı,
   {{0xdcfc01d6,0x26cf0ec8,0x00000000,0x00000000}},	//   sarı, dugo_, --, --,
   {{0xd7fa0ec9,0x28c90380,0xdcfc00c1,0xee3700af}},	//   дул_, ांगि, parı, _рнэ_,
   {{0x26cf0054,0x63a90eca,0x00000000,0x00000000}},	//   fugo_, jben, --, --,
   {{0x63a9068b,0xfaa60dec,0x00000000,0x00000000}},	//   dben, _јаго, --, --,
   {{0x63a901ae,0x787800b8,0x6442009e,0x00000000}},	//   eben, díve, _smoi, --,
   {{0xd9460ecb,0x628a046f,0xdb0f0ecc,0xaa430ecd}},	//   _реви, _rifo, _recé, _терл,
   {{0x13f40036,0x7c360297,0xa5070202,0xd7060ece}},	//   узия, nhyr, ђења_, _изби,
   {{0x26dd004e,0xa6860ecf,0x97ea0095,0xe0ae0083}},	//   ctwo_, _алад, ışdı, _কমেন,
   {{0x620601e0,0x00000000,0x00000000,0x00000000}},	//   тчиз, --, --, --,
   {{0x1be20141,0xc4c50c26,0x64570138,0x6d480138}},	//   खभाल_, _متنو, éxic, údal,
   {{0x74130088,0x14d7011d,0x78780132,0xd1380035}},	//   _پوها, _יובל_, bíve, rzą_,
   {{0xd138004e,0x628a0ed0,0x78780183,0xdd3a0139}},	//   szą_, _tifo, cíve, _păşe,
   {{0xa3de04aa,0x5bcb00b4,0x00000000,0x00000000}},	//   द्र_, िल्व, --, --,
   {{0xa2f200dc,0x69c80225,0x00000000,0x00000000}},	//   _अनुज_, _ödey, --, --,
   {{0xc61f0ed1,0xdb0f00af,0x00000000,0x00000000}},	//   _भव्य_, _decî, --, --,
   {{0x06d70083,0x9f520176,0xeb0d01c0,0x00000000}},	// [8d0] _দৈনি, _gayà_, समेत_, --,
   {{0x63a9029d,0x26cf0010,0xbdf500ed,0x5a340ed2}},	//   zben, vugo_, _спој, анут,
   {{0x63a90ed3,0x27ef082b,0x00000000,0x00000000}},	//   yben, tegn_, --, --,
   {{0xdb060ed4,0x00000000,0x00000000,0x00000000}},	//   _bekä, --, --, --,
   {{0x27ef0075,0x7c2d0ed5,0x78780132,0x26cf0207}},	//   regn_, mkar, xíve, uugo_,
   {{0xd774004f,0x26cf0ed6,0xbb3a0070,0x78780183}},	//   جامع, rugo_, _טערי, víve,
   {{0xd4690ed7,0x26dd0035,0x245a00ea,0xa3ae022e}},	//   нике_, stwo_, zīme_, करं_,
   {{0x78780ed8,0x63a90ed9,0xc6a7002d,0xa3e300b4}},	//   tíve, uben, _аржи, _पॉश_,
   {{0x63a90eda,0x7c2d0edb,0xc7b20122,0x6ae10033}},	//   rben, ikar, _לבן_, নিকো,
   {{0x63a90edc,0x96f80d82,0x7c2d0edd,0x00000000}},	//   sben, _جعفر_, hkar, --,
   {{0x7c2d0ede,0x78780279,0x9f4e00b8,0x69d80035}},	//   kkar, síve, čním_, न्टी,
   {{0xd5df0edf,0xddd501c0,0xdb0a0187,0x7c2d0ee0}},	//   प्रज, mozř, šnéh, jkar,
   {{0x91e50ee1,0x442d0ee2,0x7c2d0ee3,0x644901ef}},	//   _боле, mke_, dkar, miei,
   {{0xdd920082,0xf7760070,0xd5b1055c,0x00000000}},	//   صور_, טערי_, _bói_, --,
   {{0x442d0ee4,0x7c360ee5,0x09b20083,0xed570ee6}},	//   oke_, thyr, _চালা, гор_,
   {{0x7c2d0ee7,0xaca9006c,0x09cc0099,0x8c430652}},	//   gkar, کھیے_, ाल्य, бесе,
   {{0x9b93004f,0x442d0ee8,0x7c360ee9,0xed1700b5}},	// [8e0] إلكت, ike_, rhyr, نہیں_,
   {{0xe9d7051b,0x9a6a0eea,0x3b830eeb,0x442d0eec}},	//   лку_, رمال_, слуг, hke_,
   {{0x442d0eed,0x7c2d00a8,0x8c460eee,0xf4be0033}},	//   kke_, bkar, _бене, _আহ্ব,
   {{0x442d0eef,0x7c2d0ef0,0xa3e302e4,0x3eb20b88}},	//   jke_, ckar, _पॉल_, _kwyt_,
   {{0x442d0ef1,0xd7070421,0x00000000,0x00000000}},	//   dke_, лнце_, --, --,
   {{0x442d0903,0x38c80ef2,0x9f5b0031,0x00000000}},	//   eke_, _لاری_, _saqë_, --,
   {{0x6449001e,0x7af600e9,0x04660ef3,0x629d0138}},	//   fiei, lwyt, лтим, íson,
   {{0x25f0004e,0x7bd6043d,0x442d0ef4,0xd46703fa}},	//   _इसकी_, ngyu, gke_, лије_,
   {{0xa6ca0ef5,0xd5d6006c,0x3866081f,0x05d6004f}},	//   _سوال_, _متاث, moor_, _مزاج,
   {{0xd6cf0c9e,0xe29f00fb,0x7c2d0291,0x442d0ef6}},	//   _رقم_, íða_, zkar, ake_,
   {{0xf5930082,0xa1580de0,0x05560ef7,0x09de0033}},	//   _المج, тану_, _стая, ড়পা,
   {{0x442d0ef8,0x764a02e9,0x557700c2,0x38660173}},	//   cke_, lify, _געבן_, noor_,
   {{0x80c00433,0x09cc0083,0x7c2d0ef9,0xbf0f0efa}},	//   _विके, র্যা, vkar, ामेन_,
   {{0xe80b0299,0x38660173,0x764a0efb,0x7c2d0efc}},	//   _सोना_, hoor_, nify, wkar,
   {{0x16d10efd,0x7c2d0efe,0x25f70066,0x28c900b4}},	//   _सम्ब, tkar, _एससी_, ांछि,
   {{0x09cc0083,0xa3e70eff,0x38660b88,0xd175010b}},	//   র্মা, म्प_, joor_, _тычы,
   {{0x38660f00,0x3c58002d,0x00000000,0x00000000}},	// [8f0] door_, уитэ_, --, --,
   {{0x7c2d0f01,0x6d410f02,0x442d0f03,0xdfd1006c}},	//   skar, úlas, zke_, _ايک_,
   {{0x764a02d0,0x442d0f04,0x09cc0033,0x38660298}},	//   dify, yke_, র্ভা, foor_,
   {{0x386603bc,0x00000000,0x00000000,0x00000000}},	//   goor_, --, --, --,
   {{0x442d0f05,0x2ba5022e,0x64490952,0x6f1b033b}},	//   vke_, गुणा, viei, äuch,
   {{0x80aa0b52,0x09cc00c8,0xa3e7045c,0xc9870369}},	//   _কিন্, র্বা, म्न_, _буби,
   {{0x442d0bcc,0x3d080f06,0x386601bf,0x84590382}},	//   tke_, हिये_, boor_, крит_,
   {{0x442d0f07,0x6a6b033b,0x14250f08,0x91fc0228}},	//   uke_, rüfu, рдим, klās,
   {{0xe80b0f09,0x64490f0a,0x7cec00b5,0x7a32008c}},	//   _सोया_, riei, _körö, _mætn,
   {{0x442d0f0b,0x3d080302,0x27ff0328,0xdb0f0097}},	//   ske_, हिमे_, _haun_, _necí,
   {{0xc32300c8,0x442d0f0c,0x787800de,0x69dd0f0d}},	//   _বেশি_, pke_, líva, _पानी,
   {{0xdb0f03e6,0x27ff0f0e,0x5f060210,0x6495005f}},	//   _mecâ, _jaun_, азма, _ašig,
   {{0x92b70082,0x63bb0f0f,0x27ff0f10,0x248f01ef}},	//   _إحصا, maun, _maun_, _iigm_,
   {{0x40950cb5,0xed5a0202,0x63bb0f11,0x27ff0f12}},	//   _крит, вог_, laun, _laun_,
   {{0x61420f13,0xdb0f0f14,0x629b0176,0x32f60067}},	//   _меша, _decí, lquo, _zły_,
   {{0x63bb0f15,0x229b0345,0x27ff0065,0x00000000}},	//   naun, _kêk_, _naun_, --,
   {{0xe9da0f16,0xa3e705f8,0xeb970043,0x38660120}},	// [900] кка_, म्य_, риу_, voor_,
   {{0x63bb043d,0x7af6001e,0x787800b8,0x20000088}},	//   haun, rwyt, díva, _haii_,
   {{0x41dd0f17,0x63bb0f18,0x26190632,0xf1dd08b6}},	//   _मानस, kaun, पानी_, _मानन,
   {{0xdb0f0043,0x63bb0029,0xa3e7000c,0x20020f19}},	//   _decâ, jaun, म्म_, ndki_,
   {{0x27ff0f1a,0x38660626,0x764a0f1b,0x63bb0f1c}},	//   _daun_, roor_, tify, daun,
   {{0x7cec00b5,0x69dd052f,0xb8dc0831,0x00000000}},	//   _görö, _पायी, _আম_, --,
   {{0x01bb0b52,0x764a0f1d,0x38660f1e,0x26df0f1f}},	//   ংলাদ, rify, poor_, _equo_,
   {{0x27ff0f20,0x63bb0f21,0x290a0118,0x00000000}},	//   _gaun_, gaun, _irba_, --,
   {{0xd3770f22,0x6459012f,0x46a30f23,0x07a30f24}},	//   ичь_, _djwi, _матв, _фаун,
   {{0x20120f25,0xdb0401ef,0x27ff0110,0x00000000}},	//   _anyi_, laió, _zaun_, --,
   {{0x7bc60f26,0x20000160,0x9f4b02d7,0x64a30f27}},	//   _odku, _baii_, recí_, _даха,
   {{0x78a100b5,0x27e600e9,0x920200ea,0x20000395}},	//   _élve, nfon_, _šāda, _caii_,
   {{0x200500b8,0x629b00f6,0x44f800e2,0xa85700a5}},	//   ěli_, cquo, _hũ_, שיכה_,
   {{0x2005006a,0x290a012f,0x20120cdf,0xf1dd0f06}},	//   śli_, _orba_, _enyi_, _मायन,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8f470f28,0x1dd30084,0x44f80019,0x705500d1}},	//   _вход, _ताकत, _mũ_, _دنبا,
   {{0x290a01c8,0x207c02b5,0x905c0122,0x44f80019}},	// [910] _arba_, _באהא, _שכחת, _lũ_,
   {{0x39a70f29,0x63bb01b7,0x7a380f2a,0x27ff0f2b}},	//   ршав, zaun, апур_, _saun_,
   {{0x27ff0f2c,0x7cec00b5,0x69dd0099,0x9f40021d}},	//   _paun_, _vörö, _पाठी, _ibiá_,
   {{0xdd1c00b8,0xd7c80698,0x629b00f6,0x78780f2d}},	//   _nářa, لومه_, yquo, tíva,
   {{0xd6db0f2e,0xe5a509d0,0x290a0f2f,0x8c1a0122}},	//   тте_, били, _erba_, _עושי,
   {{0xd6ce0098,0x63a20f30,0x7afd0f31,0x69dc0079}},	//   رقى_, _afon, _isst, _gcre,
   {{0x27ff00bf,0x44f801a5,0x290a0f32,0x63bb0f33}},	//   _taun_, _cũ_, _grba_, taun,
   {{0xed580122,0x80c00967,0x6d480037,0x61ea02b1}},	//   יבור_, _विजे, údai, _abfl,
   {{0x63bb0f34,0x386d0f35,0x86980f36,0xdb060f37}},	//   raun, _iker_, _вкус_, _sekú,
   {{0x629b02e1,0xe4e702ce,0xdb0f0310,0x63a20f38}},	//   rquo, _відн, _mecà, _efon,
   {{0x92d700c8,0x26190f39,0x63bb0f3a,0x63a2001e}},	//   াবে_, पाठी_, paun, _ffon,
   {{0x66010f3b,0x44e10f3c,0x6e25009e,0xaac70f3d}},	//   _halk, mó_, _aohb, _लिंक,
   {{0x69c70f3e,0x44e10f3f,0x539a00a5,0x7afd03d0}},	//   _odje, ló_, _עיסו, _nsst,
   {{0x69c701d2,0x6da30d28,0x66010086,0xada3027a}},	//   _ndje, зира, _jalk, зарл,
   {{0x2d8c01ff,0x44e10f40,0x80ce0066,0x386d01a3}},	//   äde_, nó_, _थिये, _oker_,
   {{0x69dc0f41,0x62990f42,0x7aef0f43,0xbea60e9f}},	//   _scre, _kuwo, _bpct, _лаик,
   {{0x290a0f44,0xa3df0299,0x63b9001e,0x6299012f}},	// [920] _srba_, _तान_, _mewn, _juwo,
   {{0xbf9b0370,0x69dd00a1,0xdb0f01f7,0x386d08d7}},	//   ndên, _पाणी, _decà, _aker_,
   {{0x31ba00c2,0x93f900a1,0x44e10f45,0x629900d7}},	//   רזענ, ्याच_, jó_, _luwo,
   {{0x387f0f46,0x44e10f47,0xe73a03ad,0x44f80019}},	//   _chur_, dó_, лее_, _rũ_,
   {{0x27e60f48,0x387f0f49,0x629900e0,0x00000000}},	//   rfon_, _dhur_, _nuwo, --,
   {{0x7ae40f4a,0xfaa30f4b,0x386d0f4c,0xceb30317}},	//   mtit, _харо, _eker_, ליד_,
   {{0x44e10f4d,0x96c4004e,0x7c260f4e,0x7ae40f4f}},	//   gó_, _रिकॉ, _kokr, ltit,
   {{0x44f80028,0x69c70f50,0x62990f51,0x7c260f52}},	//   _vũ_, _zdje, _buwo, _jokr,
   {{0x8c1b0052,0x66010f53,0x82380421,0x326601d3}},	//   רופי, _falk, изис_, йтов,
   {{0x41dd02cb,0x66010f54,0x44e10f55,0x8afb02b5}},	//   _माणस, _galk, bó_, נהיי,
   {{0x04960082,0x44e10033,0xdb0f0f56,0x7ae40421}},	//   _الصح, có_, _mecá, htit,
   {{0x6e2501d6,0x7ae40f57,0x7c260044,0x787801ba}},	//   _sohb, ktit, _nokr, zívn,
   {{0x447b00c2,0xdb1d0097,0x6299001c,0xdb0401ed}},	//   _ענדע, _odsá, _guwo, kaiñ,
   {{0x7ae40f58,0x63b90035,0x2b400f59,0xbc9503e6}},	//   dtit, _zewn, dzic_, жавј,
   {{0x44260f5a,0x90a606ca,0x7c260f5b,0x7ae40223}},	//   _koo_, _احتم, _bokr, etit,
   {{0x44260f5c,0x7c260f5d,0x7ae40160,0x7a200f5e}},	//   _joo_, _cokr, ftit, _götz,
   {{0x44260189,0x2fc90f5f,0x44e10332,0x78780038}},	// [930] _moo_, _idag_, zó_, tívn,
   {{0x44260f60,0x386d0f61,0x98b80463,0x44e10831}},	//   _loo_, _sker_, _ayrı_, yó_,
   {{0x7ae40036,0xda780f62,0xdb0f0f63,0x6f0d0187}},	//   atit, сят_, _decá, _hrac,
   {{0x44260f64,0x6f0d0f65,0x44e10f40,0x66010f66}},	//   _noo_, _krac, vó_, _salk,
   {{0x66010f67,0xf6e70f68,0xe61000b5,0xd36600bc}},	//   _palk, сцен, کشن_, _آه_,
   {{0x44e100f5,0x69c70f69,0xd1260bdf,0x6f0d0f6a}},	//   tó_, _udje, _قم_, _mrac,
   {{0x63b9006a,0x66010f6b,0xe3b1004f,0x5e580070}},	//   _pewn, _valk, ورة_, זיגע_,
   {{0x44e10f6c,0xf4290f6d,0x64950009,0x66010f6e}},	//   ró_, роил_, _ašic, _walk,
   {{0xe81602cb,0x44e10f6f,0x66010f70,0x68e50f71}},	//   णारा_, só_, _talk, lthd,
   {{0x2fc900fd,0x63b90035,0x44e10f72,0x317c0124}},	//   _adag_, _wewn, pó_, _bzvz_,
   {{0x6f0d0f73,0x3ea90043,0x0ef40026,0x7a3b00f7}},	//   _arac, _atat_, ेट्स_, _gîte,
   {{0xa06a010c,0x68e500e9,0x44c500ea,0x44260147}},	//   рама_, ithd, mē_, _goo_,
   {{0x44c50029,0x644b009f,0x6f0d0f74,0x6495035f}},	//   lē_, _imgi, _crac, _eġit,
   {{0x7ae40523,0x44260f75,0x64a300f4,0x00000000}},	//   vtit, _zoo_, _gđic, --,
   {{0x44260f76,0x8c0100c8,0x27ed02bf,0x3ea90f77}},	//   _yoo_, _একজন_, _oben_, _etat_,
   {{0x6a7002c9,0x4426006d,0xeb970f78,0x27ed01ed}},	//   häft, _xoo_, жит_, _nben_,
   {{0x6f0d0f79,0x7ae40453,0x3b0706c2,0x3a260f7a}},	// [940] _grac, utit, оето_, омаг,
   {{0x7ae40f7b,0x78780f7c,0x27ed008c,0x3205024b}},	//   rtit, tívo, _aben_, ndly_,
   {{0x7ae40f7d,0xe8fa0f7e,0x644b0f7f,0xe81600a1}},	//   stit, рле_, _omgi, णाला_,
   {{0x7ae40f80,0xdb24006c,0xb6c800b5,0x44c500ea}},	//   ptit, _فوجی, ماتے_, dē_,
   {{0x44260f81,0xaac701c0,0xdb0401ed,0x00000000}},	//   _roo_, _लिएक, paiñ, --,
   {{0x27ed0f82,0x3af902b5,0xa3e702b4,0x644b0008}},	//   _eben_, _פּרע, म्स_, _amgi,
   {{0x44260f83,0xd4970733,0xd0b100a8,0x00000000}},	//   _poo_, оры_, _təəs, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44260f84,0x69da0225,0x2fc9008c,0x00000000}},	//   _voo_, _ötes, _rdag_, --,
   {{0x81d20083,0x23dc012f,0x44260f85,0x6f0d0031}},	//   হ্ন_, _यावद, _woo_, _rrac,
   {{0x4a7b00c2,0x44260122,0xfbca0967,0x649500b8}},	//   שריב, _too_, िणाम, _všic,
   {{0x6f0d0f86,0x403400c3,0x35e0073f,0x00000000}},	//   _prac, деюс, _नाड़, --,
   {{0xa3df01d1,0x2fc90345,0xa3e3021a,0x00000000}},	//   _तात_, _vdag_, _पॉट_, --,
   {{0xdef801c8,0x64950207,0x00000000,0x00000000}},	//   цыю_, _ušic, --, --,
   {{0xdd9400c7,0x6f0d0f87,0x6ce400d4,0x40350f88}},	//   дары, _wrac, міте, _некс,
   {{0x6f0d0f89,0xafdb0c71,0x26110f8a,0x69dd0099}},	//   _trac, riøs, _धोनी_, _पाही,
   {{0x6f0d0f8b,0x97ea033e,0x44c500ea,0x5a350f8c}},	// [950] _urac, ışlı, zē_, пнат,
   {{0x78a300fd,0xd042013b,0x00000000,0x00000000}},	//   ínvo, drlə, --, --,
   {{0x6aad0036,0x7a32008c,0x64950168,0xa3da00be}},	//   spaf, _mæth, _ošia, ़ला_,
   {{0xdb1f01f4,0x68e50f8d,0xa8020225,0x9cd6076b}},	//   naqë, rthd, _çılg, _צורה_,
   {{0x8c1a0122,0x00000000,0x00000000,0x00000000}},	//   _הורי, --, --, --,
   {{0x386600f4,0x00000000,0x00000000,0x00000000}},	//   čora_, --, --, --,
   {{0x6a700f8e,0x25ec007c,0x19580f8f,0x7af901fb}},	//   räft, _आउरी_, _дары_, şatı,
   {{0x44390f90,0x26190f91,0x57f40166,0xf99200a5}},	//   ós_, पाही_, _опст, _טרם_,
   {{0xf7490082,0x051b0033,0x44c500ea,0x45d50043}},	//   _الذي_, তনের_, sē_, _ноас,
   {{0x363700bf,0xc2420f92,0xd5b100e2,0x32050f93}},	//   _بررس, еньк, _góp_, udly_,
   {{0x21690500,0x3205024b,0x86220647,0xdb1f0055}},	//   сини_, rdly_, _سکول, faqë,
   {{0x293602b5,0x3e76008d,0x00000000,0x00000000}},	//   פארן_, mæti_, --, --,
   {{0x20040038,0xb4bb0380,0x3e76008d,0x00000000}},	//   ľmi_, _अबु_, læti_, --,
   {{0x3d080930,0x161e00b4,0x00000000,0x00000000}},	//   हिले_, पायर_, --, --,
   {{0xc6920122,0x91ba00a5,0xed5200b5,0x20560f94}},	//   תאם_, _המצי, رپر_, _нтир,
   {{0x443f0f95,0x4ac70722,0xaac70066,0x645b0f96}},	//   nhu_, _लिखव, _लिखक, nnui,
   {{0x6b630f97,0xe0850f98,0x998306fe,0x00000000}},	// [960] екта, _تجوي, _bojů_, --,
   {{0xd042013b,0x499a0f99,0x00000000,0x00000000}},	//   vrlə, стая_, --, --,
   {{0x443f0f9a,0x290e0093,0xd88a00b5,0xa96a0079}},	//   khu_, ífa_, مپئن_, حمام_,
   {{0xfc32004f,0xdb040120,0x26110b4d,0x7a32008d}},	//   _أحد_, ncië, _धोबी_, _mæti,
   {{0xfbd30052,0x443f0f9b,0x628300d5,0xf3f900af}},	//   _אתר_, dhu_, _ohno, deţ_,
   {{0xe8df0028,0xdb0f0279,0x4b7b00a5,0x7c2401a0}},	//   _giữa_, _secç, _לאכו, ljir,
   {{0x9f590298,0x00000000,0x00000000,0x00000000}},	//   gesê_, --, --, --,
   {{0x7c240010,0x443f003c,0xb3c60f9c,0x43940f9d}},	//   njir, ghu_, रृंख, майс,
   {{0xdb06006c,0x00000000,0x00000000,0x00000000}},	//   _nekü, --, --, --,
   {{0x6283006b,0x443f034d,0x31340f9e,0x61f300d5}},	//   _chno, ahu_, деор, _čelí,
   {{0xf1dd0084,0x26190f9f,0x443f0fa0,0x00000000}},	//   _मारन, पारी_, bhu_, --,
   {{0x443f0fa1,0xc4860733,0x39570122,0xe1ef006c}},	//   chu_, _элек, לשים_, پسی_,
   {{0x69dd00b4,0x26c600b9,0xee870421,0x7a320a8a}},	//   _पाली, nsoo_, зыво, _tæth,
   {{0xd2500fa2,0x6ece0f8a,0x628300f1,0x6ca705e8}},	//   _جنت_, _तिरु, _ghno, зраж,
   {{0x61fa0fa3,0xa1570fa4,0xe9ff0019,0xf27b011d}},	//   metl, _нашу_, _ngạc_, _הרגש,
   {{0x61fa0fa5,0x31c601c0,0x415b00a5,0x7c240055}},	//   letl, bízí_, _לדוג, gjir,
   {{0xdb040248,0xa3df00a1,0x7b1800af,0xdb06033b}},	// [970] nciè, _तास_, потр_, _gekü,
   {{0x61fa0fa6,0x443f00ec,0xe29f008d,0x7c24002f}},	//   netl, zhu_, íði_, ajir,
   {{0xb4bb0437,0x6ca40fa7,0x7c380138,0xa3bc007c}},	//   _अबे_, _пряж, ñará, अरा_,
   {{0xf77000d1,0x61fa0fa8,0xdb0d0138,0x9f590031}},	//   گام_, hetl, lbaí, jesë_,
   {{0x26190fa9,0x61fa0723,0x6440004f,0xdb060faa}},	//   पाली_, ketl, dhmi, _dekó,
   {{0x61fa0280,0xf7700fab,0x60da046a,0xa3df0066}},	//   jetl, دام_, kutm, _ताह_,
   {{0x443f0fac,0x61fa0fad,0x00000000,0x00000000}},	//   thu_, detl, --, --,
   {{0xc9520122,0xdb1d01f4,0x6283078b,0x7bdf0fae}},	//   _סמן_, _nesë, _shno, ngqu,
   {{0x36d40faf,0x443f0fb0,0x130600c3,0x61fa027d}},	//   _потр, rhu_, дный_, fetl,
   {{0x443f0fb1,0xa3df0864,0x645b002d,0x68e1013c}},	//   shu_, _ताव_, snui, _älds,
   {{0xa2cf0d2a,0x3de30083,0x443f0fb2,0xdb1d0031}},	//   _दिव्, য়াল, phu_, _besë,
   {{0xcdc90052,0x64400fb3,0x261100ab,0x831900b5}},	//   _כך_, chmi, _धोती_, _وقار_,
   {{0xdb060c1f,0x43740166,0x09d50083,0xdb0401e4}},	//   _lekò, _пушт, স্যা, rcië,
   {{0x29110160,0x00000000,0x00000000,0x00000000}},	//   _orza_, --, --, --,
   {{0x6da30fb4,0x1d0707c3,0x64850079,0xa2d90ac4}},	//   тиса, мери_, róif, फूर्,
   {{0x32070fb5,0x6e210093,0xdb1d0fb6,0x41dd00b4}},	//   _hany_, ölbr, _gesë, _माँस,
   {{0x7c240fb7,0x29030fb8,0xfaff00ea,0x29110088}},	// [980] rjir, _asja_, šīnu_, _arza_,
   {{0x6f040fb9,0x7c360fba,0x320700ac,0x2911011c}},	//   _isic, skyr, _jany_, _brza_,
   {{0xeb9a0e0a,0x32070052,0x8c460fbb,0xae1b02b5}},	//   _мин_, _many_, _жене, _וויכ,
   {{0x32070176,0x3ea00fbc,0x9f5902e9,0x61fa0fbd}},	//   _lany_, _kuit_, fesè_, zetl,
   {{0x41dd0808,0x61fa0fbe,0x15fc00b4,0x00000000}},	//   _मांस, yetl, _एसआर_, --,
   {{0x6f040054,0x28db0fbf,0x2fc001a6,0x443d00e9}},	//   _msic, मूहि, _leig_, _alw_,
   {{0x5e5700c2,0x61fa0fc0,0x64400fc1,0x9f5901f4}},	//   ויסע_, vetl, thmi, tesë_,
   {{0x7bc40fc2,0xdb1d0118,0x672d0031,0x3d0f018d}},	//   naiu, _besè, ënjë, डिते_,
   {{0xa3df0fc3,0x3ea002e1,0x61fa0fc4,0x68e1022a}},	//   _तार_, _nuit_, tetl, _äldr,
   {{0xa6830fc5,0x644001f4,0x2fc00176,0xdb1d0fc6}},	//   _алуд, shmi, _aeig_, _desè,
   {{0x61fa0fc7,0xae220722,0x443d0183,0x661a009f}},	//   retl, मानन_, _flw_, _intk,
   {{0x61fa0fc8,0x68e1022a,0xf9930122,0x3ea00fc9}},	//   setl, _ålde, כרת_, _buit_,
   {{0x61fa0fca,0x69ce01ba,0x3ea00fcb,0xdb0d00a8}},	//   petl, _odbe, _cuit_, çkün,
   {{0x3ea00fcc,0x32070107,0x00000000,0x00000000}},	//   _duit_, _gany_, --, --,
   {{0xd30800e8,0x24860221,0x2bd00fcd,0x6f040036}},	//   _hệ_, _khom_, तृभा, _esic,
   {{0x3ea00fce,0xdb0602e9,0x69ce01a2,0xd3080019}},	//   _fuit_, _rekò, _adbe, _kệ_,
   {{0x661a03c4,0xae0c0fcf,0x7a320093,0xb4bb0387}},	// [990] _ontk, िएशन_, _lætu, _अब्_,
   {{0x200903bc,0x62980069,0xdb060107,0x00000000}},	//   _haai_, _jivo, _pekò, --,
   {{0xd30801a5,0xa3df0fd0,0x386f0009,0x62980987}},	//   _lệ_, _ताल_, togr_, _mivo,
   {{0xa2cf0fd1,0xec3500c2,0x315702b5,0x62980fd2}},	//   _दिल्, _נאָר_, ויבן_, _livo,
   {{0x66080fd3,0x20090fd4,0x00000000,0x00000000}},	//   _badk, _maai_, --, --,
   {{0x62980fd5,0x2ca1012f,0x660800d5,0x2009053e}},	//   _nivo, _kuhd_, _cadk, _laai_,
   {{0x660800ee,0x6d470484,0x69c50fd6,0x9f5902e9}},	//   _dadk, nzja, mahe, sesè_,
   {{0xcd9802da,0x24860fd7,0x69c50fd8,0x2ca1028b}},	//   ודות_, _chom_, lahe, _muhd_,
   {{0x32070176,0x443d0fd9,0xfe0f0fd0,0xf7730fda}},	//   _pany_, _vlw_, ायास_, _شار_,
   {{0x3ea00fdb,0x66080fdc,0xfc3f0176,0x649500c7}},	//   _ruit_, _gadk, _llí_, _išim,
   {{0x09d500c8,0xdb1d07a6,0x2009053e,0xd00a0fdd}},	//   স্থা, _desé, _baai_, пене_,
   {{0x7a3200fb,0x7878024e,0x69c50fde,0x23600187}},	//   _hætt, tívi, hahe, _žije_,
   {{0x20090173,0x63a90fdf,0x64850fe0,0x2fc00443}},	//   _daai_, mcen, róid, _veig_,
   {{0x09d500c8,0xfc3f043f,0x3ea00443,0xe29f0093}},	//   স্তা, _alí_, _vuit_, íðu_,
   {{0x75f30463,0x69c50fe1,0x7a32008a,0x63a90fe2}},	//   mızı, dahe, _mætt, ocen,
   {{0x62980fe3,0x63a90fe4,0x98a700b8,0x3ea00fe5}},	//   _zivo, ncen, šně_, _tuit_,
   {{0xfc3f004f,0xf1d30035,0x1e960b90,0x764300d7}},	// [9a0] _dlí_, _दयान, _прор, khny,
   {{0x19b901c8,0x69c50fe6,0xd9460fe7,0x75f300d0}},	//   дуць_, gahe, нези, nızı,
   {{0xa3df0099,0x660800ac,0x7bc400d7,0xba3b0fe8}},	//   तला_, _radk, paiu, _suïc,
   {{0xc18c02b5,0x59e20026,0x63a903e0,0xe78601e0}},	//   קטאָ, _पावर, jcen, нуло,
   {{0xe7370fe9,0x69c50fea,0x26dd0feb,0x660803bc}},	//   нец_, bahe, guwo_, _padk,
   {{0x63a90fec,0x69ce01b4,0x69c500cc,0xfc3f00ac}},	//   ecen, _udbe, cahe, _zlí_,
   {{0x62980fed,0x2486006f,0xdb1d002a,0x649500f4}},	//   _rivo, _phom_, _resé, _išij,
   {{0x62980fee,0x76430fef,0xdb0f002a,0x63a90a8a}},	//   _sivo, ahny, _recú, gcen,
   {{0xa01b008a,0x885700a5,0xdb08000d,0x2009053e}},	//   llög, _נשמע_, élèv, _raai_,
   {{0xd3080028,0x63a90ff0,0x20090b0d,0x2486024b}},	//   _vệ_, acen, _saai_, _whom_,
   {{0xa3e80e04,0x63a90ff1,0xb7bd002d,0x20090ff2}},	//   _बाप_, bcen, _soţi, _paai_,
   {{0x23660d4b,0xd30801a5,0x63a9027a,0x44cc01c0}},	//   _txoj_, _tệ_, ccen, mě_,
   {{0x62980ff3,0x69c50ff4,0x998300ee,0x00000000}},	//   _tivo, yahe, _mojš_, --,
   {{0x61460248,0xfc3f0037,0x2009053e,0x657a0ff5}},	//   _célé, _slí_, _waai_, _kyth,
   {{0x69c50006,0x44cc01c0,0xbd680ff6,0x614600f7}},	//   vahe, ně_, ерте_, _délé,
   {{0x9f5200de,0x3f15034b,0x69c50ff7,0xb17b011d}},	//   _cayó_, _адис, wahe, _מטור,
   {{0x69c50ff8,0x3a75021d,0x657a016e,0x614600fd}},	// [9b0] tahe, влар, _lyth, _félé,
   {{0xddc70129,0x99670ff9,0xbbeb00bf,0x61460118}},	//   bojš, нтел, _کردم_, _gélé,
   {{0x7a3205ee,0x69c50ffa,0xe61f01a5,0x996704d9}},	//   _rætt, rahe, _đô_, хтал,
   {{0xb9090ac4,0x7a320ffb,0x44cc000c,0x69c50ffc}},	//   _मम_, _sætt, dě_, sahe,
   {{0xd90f00f5,0xab840ffd,0x00000000,0x00000000}},	//   _گیا_, _бурк, --, --,
   {{0x7aed006c,0x657a0ffe,0x6495031d,0xa3b30fff}},	//   mtat, _byth, _všim, जुन_,
   {{0xd90f00f5,0x657a00e5,0xd4691000,0x00000000}},	//   _دیا_, _cyth, мике_, --,
   {{0x6d581001,0x64950009,0x7aed027a,0x00000000}},	//   _žvak, _išik, otat, --,
   {{0x657a008e,0x7a3208c8,0x64951002,0x7c2f1003}},	//   _eyth, _tætt, _ušim, _mocr,
   {{0x7aed1004,0x7c2f1005,0x248d0edf,0x44cc0355}},	//   itat, _locr, smem_, bě_,
   {{0x7aed01f4,0xa06a1006,0x63a9017b,0x76411007}},	//   htat, дана_, pcen, _illy,
   {{0x614600a2,0x7c2f0118,0x75f31008,0x00000000}},	//   _sélé, _nocr, sızı, --,
   {{0xe28e1009,0x09cc0033,0x00000000,0x00000000}},	//   _ва_, র্টা, --, --,
   {{0xc0a801ca,0x82d6100a,0x7aed100b,0x64950207}},	//   بایل_, _יונג_, dtat, _ošik,
   {{0x1fb6100c,0x7aed09f3,0x217502b5,0xdca60814}},	//   _испр, etat, _בײַם_, таби,
   {{0x442f100d,0xe8df0019,0x7aed100e,0xbc630212}},	//   _jog_, _nhựa_, ftat, авск,
   {{0x442f100f,0x61461010,0x7aed1011,0x160104bc}},	// [9c0] _mog_, _télé, gtat, लजार_,
   {{0x442f0122,0x4a431012,0xd5e0045c,0xa01b01ff}},	//   _log_, анув, _नाइज, smöt,
   {{0x2dd902b5,0x4dd902b5,0x442f0136,0x7769002a}},	//   _אַרב, _אַרױ, _oog_, _axex,
   {{0x44cc000c,0x76411013,0x657a00f7,0x6f160d14}},	//   vě_, _ally, _ryth, _kryc,
   {{0x7aed1014,0xb8651015,0x657a1016,0x4af900af}},	//   ctat, دالو, _syth, _пэря_,
   {{0x09cc0083,0x44cc01c0,0x64950506,0x442f0211}},	//   র্জা, tě_, _ušij, _aog_,
   {{0x442f1017,0x046608f1,0x7769002a,0x7f4a00a8}},	//   _bog_, ктим, _exex, _əfqa,
   {{0x442f0189,0x6f160176,0x7a320a8a,0x00000000}},	//   _cog_, _oryc, _tæts, --,
   {{0x657a0297,0x42740132,0x65c61018,0x442f00a5}},	//   _wyth, лгис, _абза, _dog_,
   {{0x44cc0355,0x442f1019,0x657a03d0,0x00000000}},	//   pě_, _eog_, _tyth, --,
   {{0x442f006c,0x7aed101a,0x320a01ba,0x3a3700a5}},	//   _fog_, ztat, ľby_, דרים_,
   {{0x320a086d,0x7658000e,0xe53702b5,0x6f16101b}},	//   žby_, livy, _שטאט_, _bryc,
   {{0x6442101c,0xdb0d101d,0xdd3b0139,0x6f160090}},	//   _iloi, mbaç, _băşt, _cryc,
   {{0x442f01a9,0x7c2f101e,0x6f16101f,0xdd3b0139}},	//   _zog_, _socr, _dryc, _căşt,
   {{0x442f1020,0x16df00c0,0x6442012f,0x7c2f00c5}},	//   _yog_, _नम्ब, _kloi, _pocr,
   {{0x7aed1021,0x3d0800a1,0x46d21022,0x09cb0099}},	//   ttat, हिजे_, _सिंह, ाण्य,
   {{0x5b151023,0x7aed002d,0xc4c400b5,0x4c9400c3}},	// [9d0] ымат, utat, _ڈے_, ритс,
   {{0x7aed1024,0x1db7021a,0x3eda0070,0x9f590138}},	//   rtat, _अभित, _אַטא, nesí_,
   {{0x7aed1025,0xda7807b0,0xdd911026,0x6f161027}},	//   stat, тят_, _دود_, _zryc,
   {{0x7aed1028,0xdb1d01ef,0x00000000,0x00000000}},	//   ptat, _hesí, --, --,
   {{0x442f1029,0x442101a5,0xdcfe00ea,0x00000000}},	//   _rog_, _đh_, _izpā, --,
   {{0x644203ad,0x69dd02cb,0x6d5800d8,0x442f102a}},	//   _aloi, _पाटी, _žvai, _sog_,
   {{0x442f102b,0x6442102c,0xdb1d0138,0xb7bd00af}},	//   _pog_, _bloi, _mesí, _soţu,
   {{0x442f0221,0x6442102d,0x13090263,0xe80b0461}},	//   _qog_, _cloi, ений_, _सोचा_,
   {{0x628a0082,0x97ea01d6,0x442f102e,0x26cd011c}},	//   _bhfo, ıştı, _vog_, _uveo_,
   {{0x42250439,0xa3df04bc,0x442f102f,0xa3e800b4}},	//   удов, _ताक_, _wog_, _बाथ_,
   {{0x442f1030,0xa2cf0f39,0xa2d80066,0x56940183}},	//   _tog_, _दिक्, _मिथ्, _тафт,
   {{0x64421031,0x6f161032,0x68fb00f4,0x00000000}},	//   _gloi, _pryc, _ćudl, --,
   {{0xa3e81033,0x63bb1034,0x60da01e4,0xba3b1035}},	//   _बात_, mbun, artm, _ruïn,
   {{0xa2d80127,0xfce61036,0x63bb1037,0x7e7501a3}},	//   _मित्, лого, lbun, gozp,
   {{0xdb1d00b8,0x9d430d46,0x27200067,0x00000000}},	//   _desí, берд, _मप्र_, --,
   {{0x6e3c1038,0x6f161039,0x2a78008b,0x409500d8}},	//   skrb, _tryc, _skrb_, _крыт,
   {{0x63bb02c9,0xc0530122,0x3a310097,0x3b86005f}},	// [9e0] ibun, _לזה_, _bozp_, улаг,
   {{0x200200d1,0x01d50033,0x00000000,0x00000000}},	//   leki_, ত্রদ, --, --,
   {{0x291e103a,0x46c600b4,0x38cb103b,0x00000000}},	//   _štab_, रीनह, فانی_, --,
   {{0x2002103c,0x6495007a,0xdb1d021d,0x8176016b}},	//   neki_, _eġiz, _desâ, אגעס_,
   {{0xa2cf0325,0x601b00c3,0x00000000,0x00000000}},	//   _दिग्, _hämä, --, --,
   {{0x644204e6,0x7bc601f4,0x2002103d,0xa5f8103e}},	//   _sloi, _heku, heki_, теку_,
   {{0xa3e8103f,0x7bc60464,0x6442002d,0x765802d0}},	//   _बाद_, _keku, _ploi, rivy,
   {{0x76581040,0xb50902e4,0x63bb1041,0x20021042}},	//   sivy, विजय_, gbun, jeki_,
   {{0x38550021,0xc1ea01c8,0x200201d6,0x05240083}},	//   _търс, ньне_, deki_, বনের_,
   {{0x7bc61043,0x64a600d4,0x27e61044,0x69c8018d}},	//   _leku, _бажа, lgon_, _õded,
   {{0xdb1d0279,0x601b0328,0x00000000,0x00000000}},	//   _resí, _nämä, --, --,
   {{0x7bc61045,0x27e61046,0x20021047,0x6485063d}},	//   _neku, ngon_, geki_, lóin,
   {{0xa85700a5,0x63a21048,0x27e600e2,0x00000000}},	//   ריכה_, _igon, igon_, --,
   {{0x539b0100,0x291801a6,0xc6940070,0xdb1d0279}},	//   _ניגו, _orra_, יאָ_, _lesã,
   {{0xdb1d01dd,0x7bc601e9,0x7e750e7d,0x20021049}},	//   _vesí, _beku, rozp, beki_,
   {{0x200201d6,0x6aa60db6,0xade904aa,0x7a32008c}},	//   ceki_, _bukf, ञ्जन_, _sætp,
   {{0x2918006c,0x63a20054,0x7bc6104a,0xba550836}},	// [9f0] _arra_, _mgon, _deku, авај,
   {{0x05e0018d,0x2b4b00e2,0x00000000,0x00000000}},	//   _नागब, _đhcđ_, --, --,
   {{0x6485104b,0x63bb0067,0x3eb90228,0x63a2104c}},	//   dóin, ybun, lpst_, _ogon,
   {{0x7bc60a81,0x63a2104d,0x68fc022e,0x27e601cb}},	//   _geku, _ngon, _dprd, ggon_,
   {{0x2918104e,0x7c2d104f,0x68fc00fe,0x61f808b7}},	//   _erra_, mjar, _eprd, _obvl,
   {{0x63a21050,0x20021051,0xd00e0083,0xe7361052}},	//   _agon, zeki_, ষায়_, реш_,
   {{0x7bc60095,0xce380122,0x63a20159,0x63bb01bf}},	//   _yeku, ראות_, _bgon, tbun,
   {{0x7afd011e,0xd3f9010b,0x00000000,0x00000000}},	//   _kpst, тэкі_, --, --,
   {{0x63bb0408,0x69c70858,0xc2451053,0xa3b407b5}},	//   rbun, _keje, иник, झड़_,
   {{0x69c71054,0xdb041055,0x63a206a2,0xab5b0176}},	//   _jeje, nciá, _egon, _reül,
   {{0x21691056,0x7c2d1057,0xafdb01b4,0x69c71058}},	//   тини_, kjar, dkøb, _meje,
   {{0x7afd1059,0x6603105a,0x69c7105b,0x2056105c}},	//   _opst, lenk, _leje, ртор,
   {{0x387e105d,0x443f0e7d,0x7c2d105e,0x442d105f}},	//   _être_, mku_, djar, mje_,
   {{0x442d0fd5,0x64491060,0x443f1061,0x69c701c0}},	//   lje_, lhei, lku_, _neje,
   {{0x7afd0080,0x7c2d0093,0xdd921062,0x64a30009}},	//   _apst, fjar, زور_, _eđiv,
   {{0x442d02dd,0x443f0a4e,0x64491063,0x44f101a5}},	//   nje_, nku_, nhei, _mơ_,
   {{0x69c70332,0x207b02b5,0x443f1064,0x68fc012e}},	// [a00] _beje, _באקא, iku_, _sprd,
   {{0xba231065,0x442d1066,0x601b03ad,0x443f1067}},	//   одук, hje_, _tämä, hku_,
   {{0x442d0044,0x443f1068,0x7bc61069,0x64490626}},	//   kje_, kku_, _teku, khei,
   {{0x1ae60d36,0x443f011c,0xf09302b5,0x64490120}},	//   _комм, jku_, ַנג_, jhei,
   {{0x442d106a,0x443f0f86,0x27e6106b,0x6449106c}},	//   dje_, dku_, rgon_, dhei,
   {{0x6603106d,0x443f0029,0x442d004e,0x44f10023}},	//   genk, eku_, eje_, _bơ_,
   {{0x44f100e8,0x443f0393,0x7ae4106e,0x6449004f}},	//   _cơ_, fku_, luit, fhei,
   {{0x442d106f,0x64491070,0x62810033,0x443f1071}},	//   gje_, ghei, ello, gku_,
   {{0x66031072,0x23380086,0xdc370070,0x32661073}},	//   benk, уппы_, שאפט_, итов,
   {{0x442d1074,0xe617002d,0xe5a3002d,0x660300d5}},	//   aje_, _кду_, _дифи, cenk,
   {{0x443f0736,0x85060148,0x442d008b,0x644900f1}},	//   bku_, _خوان, bje_, bhei,
   {{0x442d0755,0x443f1075,0x38661076,0x64491077}},	//   cje_, cku_, nnor_, chei,
   {{0x7c2d0024,0x38660159,0x7ae41078,0x62810031}},	//   vjar, inor_, juit, bllo,
   {{0x7ae41079,0x30a6107a,0x66fa0228,0x6e950ef3}},	//   duit, _крив, mākā, сигу,
   {{0x8bc7107b,0x7c2d107c,0x69c7107d,0x44f10023}},	//   исад, tjar, _reje, _xơ_,
   {{0xe5170bc1,0x69c7107e,0x6603107f,0x64401080}},	//   थिति_, _seje, zenk, nkmi,
   {{0x7ae41081,0x7c2d1082,0xdb0f1083,0x66031084}},	// [a10] guit, rjar, _recó, yenk,
   {{0x442d1085,0x443f1086,0x7c2d1087,0x656d00a8}},	//   zje_, zku_, sjar, şahi,
   {{0x69c71088,0x442d00d8,0x64490173,0x9f4b0132}},	//   _veje, yje_, yhei, pecó_,
   {{0x3ea90464,0x7ae41089,0x38660382,0x6603018e}},	//   _kuat_, buit, gnor_, wenk,
   {{0x443f0097,0x66030aeb,0x44f100e8,0x442d108a}},	//   vku_, tenk, _sơ_, vje_,
   {{0x3ea9108b,0x64a50c88,0xba4500b5,0x2fc90719}},	//   _muat_, бака, _انسٹ, _leag_,
   {{0x442d108c,0x6449108d,0x3ea90043,0x38660009}},	//   tje_, thei, _luat_, bnor_,
   {{0xa2d8046c,0x6603108e,0x442d00d8,0x443f108f}},	//   _मिश्, senk, uje_, uku_,
   {{0x64491090,0xa3e81033,0x66030882,0x3ea90176}},	//   rhei, _बार_, penk, _nuat_,
   {{0x442d1091,0xa2d80953,0x64491092,0x44f10019}},	//   sje_, _मिर्, shei, _tơ_,
   {{0x2fc91093,0x442d1094,0x3f861095,0x846701d3}},	//   _beag_, pje_, _šou_, _къде,
   {{0x3ea91096,0x64401097,0x442d01f4,0x00000000}},	//   _buat_, ckmi, qje_, --,
   {{0x02a70ff6,0x1474004f,0x9e660037,0x6f0d026b}},	//   _трем, _بالج, ماسن, _csac,
   {{0xa3b3009a,0x3866002a,0x6d4e033b,0xed5a1098}},	//   जुर_, znor_, tzba, гог_,
   {{0x50b51099,0x386601a2,0x27ed109a,0xc2120122}},	//   _услу, ynor_, _ocen_, _זהו_,
   {{0x7ae4109b,0xb603053d,0x68e5011e,0xdb0f01f7}},	//   tuit, _hráč, duhd, _recò,
   {{0xab270e8b,0x6fbe0026,0x9ce80033,0xb6030097}},	// [a20] бота_, _व्यू, খবেন_, _kráč,
   {{0x27ed109c,0x78a0109d,0x239b00c7,0x3205109e}},	//   _acen_, _simv, mąjį_, nely_,
   {{0x7ae4109f,0xa3e800b1,0xb60300ac,0x645902a2}},	//   suit, _बाल_, _mráč, _omwi,
   {{0xa2d8000c,0x320500b5,0x2012021e,0x317a016b}},	//   _मिल्, hely_, _jayi_, ארעמ,
   {{0x386610a0,0x78bb0f44,0x201210a1,0x320500a5}},	//   rnor_, _čuve, _mayi_, kely_,
   {{0x3205007e,0x645910a2,0xdb1d08c8,0x27ed0055}},	//   jely_, _amwi, _besæ, _ecen_,
   {{0x78a00019,0x186a0274,0x320510a3,0xaa4710a4}},	//   _timv, _бави_, dely_, _упра_,
   {{0xe8e001a5,0x66fa00ea,0xa2b40923,0xfbdf016e}},	//   _chụp_, tākā, обич, _llên_,
   {{0x6440008a,0x661100c3,0x32050f00,0x00000000}},	//   rkmi, ökkä, fely_, --,
   {{0x6440007c,0x66fa00ea,0xc50a0fab,0xd6cf0037}},	//   skmi, rākā, _متصل_, _أقل_,
   {{0x53160148,0x20121034,0x09d50033,0xb60300d5}},	//   _گذار, _bayi_, স্কা, _dráč,
   {{0x6f0d06bc,0x3ea90118,0xfe7f01f7,0xa2e6010b}},	//   _psac, _puat_, duïa_, _годд,
   {{0x32050355,0x3ea900cc,0x28af0354,0x649510a5}},	//   bely_, _quat_, _जूनि, _všit,
   {{0x6d1410a6,0xfbdf099e,0x320510a7,0x00000000}},	//   डिंग_, _clên_, cely_, --,
   {{0x64a30506,0x60b404cd,0x20120027,0x463b016b}},	//   _uđit, _بمبئ, _fayi_, נעלע,
   {{0x0ca8014d,0x649500ac,0xb7bd0160,0x00000000}},	//   стри_, _ušit, _onţa, --,
   {{0x6a350274,0x765a026a,0x09d20831,0x2baa021a}},	// [a30] онађ, _omty, ালনা, _कलरा,
   {{0x27ed10a8,0x6aad0031,0xfe7f0176,0xfbdf099e}},	//   _scen_, rqaf, buïa_, _glên_,
   {{0x20120088,0xa3e80d2a,0x27ed008c,0x00000000}},	//   _yayi_, बला_, _pcen_, --,
   {{0xac1910a9,0xb90110aa,0xf99010ab,0xc0b200e2}},	//   _тому_, _दि_, ربل_, _sưởi_,
   {{0xd6db10ac,0xb06600c3,0x68e500c3,0x1dbf05f7}},	//   уте_, ltää, suhd, ्रपत,
   {{0xf77010ad,0x1a94010b,0x00000000,0x00000000}},	//   ران_, _наяў, --, --,
   {{0x32050122,0x91fc0029,0xb0660086,0x27ed0036}},	//   vely_, rnāl, ntää, _tcen_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x320510ae,0x201210af,0x52a610b0,0xe7330d93}},	//   tely_, _rayi_, овым_, _عصر_,
   {{0xa2bf0324,0x229200ce,0x201210b1,0x225e01ed}},	//   लीग्, وليس, _sayi_, gitk_,
   {{0x69d80370,0x386d108a,0x320500a5,0x7d0202c4}},	//   óvei, _kjer_, rely_, _ćoso,
   {{0xdb1d03ad,0x64590010,0x60dc10b2,0xef1a0421}},	//   _kesä, _umwi, árma, амм_,
   {{0x6e370069,0x32050187,0x2d8510b3,0x44f30183}},	//   _boxb, pely_, ülen_, lã_,
   {{0xdca610b4,0xe8df00cc,0xa01b10b5,0x15ed021a}},	//   жави, _chừa_, llöl, च्चर_,
   {{0xdfd2006c,0x2d8c02df,0x201210b6,0x6da30610}},	//   _ہيں_, åde_, _tayi_, дира,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7ff10b7,0xd0420095,0xa09b016b,0x49ca10b8}},	// [a40] ोजना_, xslə, _דיקט, илан_,
   {{0x25fb00c0,0x387f10b9,0x5e57004f,0x386d06dd}},	//   ल्मी_, _akur_, _وليس_, _ajer_,
   {{0x291c10ba,0xda1b0084,0x57a60763,0xe7aa10bb}},	//   íva_, _नफरत_, ошла, авел_,
   {{0xdb1d0ef0,0xa3e800b4,0xfe7f01f7,0x25b4022e}},	//   _besä, _बाइ_, nuïn_, ुर्ण,
   {{0x7c2610bc,0x386d00e0,0x00000000,0x00000000}},	//   _inkr, _djer_, --, --,
   {{0x386d01b4,0x963300d8,0xc4da0274,0x6b8b10bd}},	//   _ejer_, мніц, ађи_, ügge,
   {{0x3af40282,0x344a10be,0x867500d8,0xdb070093}},	//   läp_, ичин_, чыцц, élög,
   {{0x9cd70122,0x386d0044,0x7e7c10bf,0x66e60f88}},	//   קופה_, _gjer_, horp, _моба,
   {{0x213e001e,0xdb1d10c0,0x7e7c10c1,0x166601d3}},	//   wyth_, _gesä, korp, _двам,
   {{0x7af601c8,0x51860036,0xb06600c3,0x44f3021d}},	//   ityt, жума, ytää, bã_,
   {{0x7c2610c2,0x6e3710c3,0x7e7c01bf,0x00000000}},	//   _onkr, _roxb, dorp, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdefb00c7,0x09d50083,0x7e7c10c4,0x442610c5}},	//   шын_, স্টা, forp, _ino_,
   {{0x442610c6,0x3f850080,0x7e7c0065,0xb06600c3}},	//   _hno_, ālu_, gorp, ttää,
   {{0xa3de00e7,0x25b900a8,0x91bb00a5,0x00000000}},	//   _तया_, _əsl_, _דמוי, --,
   {{0xa3b300b4,0x8cdc0127,0x1bbb0079,0x00000000}},	//   _ज्ञ_, _फिरो, شارع_, --,
   {{0xe8df01a5,0x442610c7,0xb0660086,0xdce70644}},	// [a50] _thừa_, _mno_, stää, ğlıd,
   {{0x09e30083,0x7c2602c6,0x7e7c0720,0x539b00a5}},	//   ন্না, _enkr, corp, שימו,
   {{0x442610c8,0x386d10c9,0x3a3803c4,0x99910355}},	//   _ono_, _pjer_, _dorp_, _vozů_,
   {{0x442601a8,0x3a380211,0xdb1d0421,0x00000000}},	//   _nno_, _eorp_, _pesä, --,
   {{0x2b520035,0x58bb00fd,0xab840d6e,0x00000000}},	//   czyc_, _چارج_, _журк, --,
   {{0x442610ca,0xd126004f,0x3a380051,0x44f30183}},	//   _ano_, _كم_, _gorp_, tã_,
   {{0xe5a2021d,0x386d0055,0x442610cb,0x044510cc}},	//   ниши, _tjer_, _bno_, зейн,
   {{0x387f10cd,0x4426009e,0x44f30132,0x290302a7}},	//   _ukur_, _cno_, rã_, _ipja_,
   {{0x27ff10ce,0x6ed70066,0x28af0387,0x00000000}},	//   _ibun_, _बिगु, _जूति, --,
   {{0x442610cf,0x64aa007e,0x00000000,0x00000000}},	//   _eno_, _břid, --, --,
   {{0x7e7c10d0,0xf8cb046c,0x00000000,0x00000000}},	//   vorp, ाठिय, --, --,
   {{0x44d70043,0xe8df0019,0xbbaa04cc,0x5baa00b4}},	//   mă_, _chứa_, _कलेक, _कलेव,
   {{0x7d1e10d1,0x644b10d2,0x44d70012,0x09e30083}},	//   _srps, _ilgi, lă_, ন্যা,
   {{0x629d01c0,0x2911012f,0x00000000,0x00000000}},	//   ůsob, _osza_, --, --,
   {{0x44d70012,0x4426001e,0x00000000,0x00000000}},	//   nă_, _yno_, --, --,
   {{0x09e30083,0x7e7c10d3,0xc7a500fd,0x00000000}},	//   ন্মা, sorp, _لڑ_, --,
   {{0xeb9710d4,0x78bb0a78,0xe9da10d5,0x7af610d6}},	// [a60] зит_, _čuva, йка_, utyt,
   {{0x3af4017b,0x6f040176,0x00000000,0x00000000}},	//   räp_, _ipic, --, --,
   {{0xe8fa10d7,0x7af610d8,0x644b10d9,0x44d700af}},	//   сле_, styt, _olgi, jă_,
   {{0xfaa610da,0xa3ea0246,0x44d7002d,0xafdb10db}},	//   _намо, _टाइप_, dă_, lhør,
   {{0xdd8f0118,0xf74310dc,0x3a3810dd,0x00000000}},	//   _لوی_, нецо, _torp_, --,
   {{0x644b10de,0x44260523,0x27ff0118,0x7ae410df}},	//   _algi, _sno_, _ebun_, mrit,
   {{0x44260159,0x44d7002d,0x7ae410e0,0x69ce035f}},	//   _pno_, gă_, lrit, _iebe,
   {{0xb6030080,0x68e30f56,0x6f040a69,0x69ce10e1}},	//   ēšan, ánde, _opic, _hebe,
   {{0x69ce0464,0x7ae410e2,0x66e310e3,0x442610e4}},	//   _kebe, nrit, _пота, _vno_,
   {{0x69ce10e5,0x64aa000c,0x644b10e6,0x200010e7}},	//   _jebe, _přid, _elgi, _abii_,
   {{0x44d70012,0x7ae402c9,0x55bb0122,0x442610e8}},	//   că_, hrit, _המבו, _tno_,
   {{0x442610e9,0x69ce10ea,0x7d1c10eb,0x69dc03d0}},	//   _uno_, _lebe, dvrs, _ldre,
   {{0x69dc10ec,0xddc502c4,0xa85700a5,0x69ce0118}},	//   _odre, _ajhš, ליטה_, _oebe,
   {{0xbeed0e1d,0x69ce10ed,0x8cb10378,0x626610ee}},	//   _जमीन_, _nebe, _आंदो, _عاشق,
   {{0x6f0410ef,0x7ae40006,0xd7cc00a1,0x09e30033}},	//   _epic, erit, ाराच, ন্ডা,
   {{0x7ae410f0,0x69ce01d7,0xdb0d10f1,0x3cfe07b5}},	//   frit, _aebe, scaí, _लहरे_,
   {{0x69ce10f2,0x44d70012,0x6fc30534,0x91fc00ea}},	// [a70] _bebe, ză_, _व्यं, ciāc,
   {{0x19ab03e6,0x200b10f3,0x69ce10f4,0x00000000}},	//   стап_, leci_, _cebe, --,
   {{0x69ce10f5,0x394710f6,0xdb1d10f7,0x7ae410f8}},	//   _debe, áns_, _jesú, arit,
   {{0xa3e8017a,0x44d7002d,0x9cd600a5,0x200b10f9}},	//   _बाग_, vă_, _קורה_, neci_,
   {{0x69ce10fa,0x7bdd0176,0x00000000,0x00000000}},	//   _febe, _idsu, --, --,
   {{0x69ce10fb,0x1dbf0864,0x44d70012,0xcb12011d}},	//   _gebe, ्रित, tă_, _שלם_,
   {{0x7bcf0464,0x78a2024e,0xdb1d01ba,0x00000000}},	//   _kecu, ňova, _nesú, --,
   {{0x200b0c21,0x44d70012,0x69ce10fc,0x27ff012f}},	//   jeci_, ră_, _zebe, _ubun_,
   {{0x44d70043,0x1dbf00a1,0x7bcf09ba,0x200b10fd}},	//   să_, ्रात, _mecu, deci_,
   {{0xe0d910fe,0x44d7002d,0x69ce013b,0xbbaa0af9}},	//   ово_, pă_, _xebe, _कल्क,
   {{0x69c501a6,0x7ae401ba,0x200b10ff,0x00000000}},	//   ibhe, zrit, feci_, --,
   {{0x7bcf002d,0xdb1d0176,0x7ae400c3,0x6aa702a2}},	//   _necu, _desú, yrit, _lijf,
   {{0xdb040098,0x998300c7,0x00000000,0x00000000}},	//   sciú, _kojų_, --, --,
   {{0x09e30083,0x7ae41100,0x01650214,0x6f0400d5}},	//   ন্তা, vrit, _окло, _vpic,
   {{0x7bcf1101,0xbea31102,0x69ce1103,0x7d05008c}},	//   _becu, тарк, _rebe, _cphs,
   {{0x69ce1104,0xd9f00006,0xdd8f07f6,0x7bcf0395}},	//   _sebe, _चाहत_, شوق_, _cecu,
   {{0x78ae1105,0x7bcf09ce,0xfeba03fc,0x7bc4004b}},	// [a80] _subv, _decu, _بابت_, rbiu,
   {{0x7ae41106,0xe8df01a5,0x6aa70120,0xff5f0248}},	//   rrit, _chữa_, _cijf, raît_,
   {{0x69ce1107,0xfbc61108,0x2d961109,0xdb1d01dd}},	//   _vebe, _обно, _юрис, _xesú,
   {{0xab2a110a,0x313600c2,0xa3c302e4,0x7ae4110b}},	//   _дома_, ונעם_, ्रफ_, prit,
   {{0x09e30083,0x69ce110c,0xe737110d,0x6283110e}},	//   ন্ধা, _tebe, мец_, _okno,
   {{0x659400af,0x69dc110f,0x200b1110,0x66840088}},	//   налу, _udre, zeci_, ریال,
   {{0xdb060b3e,0x69350355,0x00000000,0x00000000}},	//   _afkø, _přeš, --, --,
   {{0x64aa00b8,0xdb1d1111,0x09e30033,0xd7060274}},	//   _přib, _resú, ন্দা, _озби,
   {{0x41e61112,0x200b0160,0x25fb007c,0x64aa0355}},	//   міна, veci_, ल्ही_, _břic,
   {{0xd25000bf,0xd626017e,0x63ab0159,0xf5e7002d}},	//   اند_, _تعري, _eggn, _омул_,
   {{0x200b1113,0xa01b00c3,0x629a0282,0x63b90090}},	//   teci_, llöi, rmto, _ffwn,
   {{0xc32a004f,0xa3e8051d,0xd5b100e2,0x00000000}},	//   _وكان_, _बाट_, _tác_, --,
   {{0xa2d80299,0x7bcf1114,0x200b1115,0x41bf035d}},	//   _मिट्, _recu, reci_, _श्वस,
   {{0x200b05e2,0x7bcf1116,0x00000000,0x00000000}},	//   seci_, _secu, --, --,
   {{0x38b7048c,0x320c1117,0x6d550036,0x3a2d1118}},	//   _oħra_, medy_, uzza, _đep_,
   {{0xa3c31119,0x28d8111a,0x00000000,0x00000000}},	//   ्रय_, _डिजि, --, --,
   {{0x7bcf0029,0x7b670166,0xa3b3111b,0xfe6e00fd}},	// [a90] _vecu, фтве, जुट_, شگی_,
   {{0x1600021a,0x00000000,0x00000000,0x00000000}},	//   ल्मर_, --, --, --,
   {{0xa3c305f7,0x69c5111c,0x1bd5111d,0x7bcf0395}},	//   ्रम_, rbhe, _поня, _tecu,
   {{0x2aad023a,0x6aa70223,0x00000000,0x00000000}},	//   _ažbe_, _wijf, --, --,
   {{0x7d020b16,0x320c016f,0xa3e8111e,0x7c3d111f}},	//   _ćosi, kedy_, _बाज_, _iosr,
   {{0x2451033a,0x7aed1120,0x46e000ab,0x00000000}},	//   _máme_, muat, _निरह, --,
   {{0x7aed1121,0x7c3d1122,0x2451063c,0x00000000}},	//   luat, _kosr, _láme_, --,
   {{0xdb1d1123,0xe7f9000c,0xe8cb00a1,0x00000000}},	//   _besø, _एउटा_, ाठीच, --,
   {{0x64aa00b8,0x7c3d1124,0x25a900d1,0x3f89034d}},	//   _přic, _mosr, _فضای_, _nyau_,
   {{0x291e010b,0x320c0147,0x00000000,0x00000000}},	//   _štai_, gedy_, --, --,
   {{0x7aed1125,0x7c3d0345,0x00000000,0x00000000}},	//   huat, _oosr, --, --,
   {{0x7aed0f1a,0x1b060033,0x78a9005f,0x4375027a}},	//   kuat, রিতে_, _jiev, _пулт,
   {{0xe80102cb,0x7aed0831,0x23291126,0x6449033b}},	//   ळ्या_, juat, _холи_, mkei,
   {{0x443d0052,0x78a91127,0x644900c3,0x7aed1128}},	//   _how_, _liev, lkei, duat,
   {{0x7c961129,0x443d112a,0xda02112b,0x7c3d0223}},	//   ерац, _kow_, र्फत_, _bosr,
   {{0x7aed0657,0x628101d7,0x78a9112c,0x6449112d}},	//   fuat, lolo, _niev, nkei,
   {{0xfe720332,0x3b070133,0x7aed112e,0xadee00a1}},	// [aa0] _مدد_, нето_, guat, _जाऊन_,
   {{0x6281112f,0x443d0122,0x9b93004f,0x64491130}},	//   nolo, _low_, الكت, hkei,
   {{0x64491131,0xd94300af,0xeabf0211,0x64850079}},	//   kkei, лефи, _crùb_, nóis,
   {{0x443d0052,0x7aed1132,0x38600014,0x78a900a0}},	//   _now_, buat, òir_, _ciev,
   {{0x78a91133,0x7aed1134,0x91fc0029,0x3f89006d}},	//   _diev, cuat, onāt, _xyau_,
   {{0x25fb0fd1,0x62811135,0x443d1136,0x00000000}},	//   ल्ली_, jolo, _aow_, --,
   {{0x291e008d,0x7c3d02c2,0x3eb20b88,0x443d062c}},	//   _éta_, _yosr, _luyt_, _bow_,
   {{0x644902bf,0x18a3081b,0x98a310ac,0x78a9011e}},	//   gkei, _басм, _бисе, _giev,
   {{0x62811137,0x0edc0243,0x68e101ff,0x57cc00a9}},	//   folo, _बिगड, _åldr, ारीह,
   {{0x62811138,0x7bd61139,0x78a9005f,0x24510168}},	//   golo, hayu, _ziev, _ráme_,
   {{0x7bd6113a,0x320c07c0,0x00000000,0x00000000}},	//   kayu, redy_, --, --,
   {{0x44fa071f,0xa3c30355,0xd2500105,0x64490110}},	//   më_, ्रण_, انگ_, ckei,
   {{0x661a113b,0x44fa00da,0xc43b0122,0x320c113c}},	//   _katk, lë_, _מתאי, pedy_,
   {{0x661a03ad,0x7c3d05ca,0x3866113d,0x443d0051}},	//   _jatk, _sosr, hior_, _zow_,
   {{0x44fa071f,0x661a113e,0x7c3d02dd,0xfd10006c}},	//   në_, _matk, _posr, یجہ_,
   {{0x7bd6113f,0x661a1140,0x24860069,0xdc88002d}},	//   gayu, _latk, _jkom_, есул_,
   {{0x44fa01f4,0x38660051,0x78a91141,0xeab30037}},	// [ab0] hë_, dior_, _riev, اعر_,
   {{0x78a90080,0x44fa00da,0xda781142,0x7aed1143}},	//   _siev, kë_, нях_, ruat,
   {{0xdd911144,0x78a90ae0,0x44fa01d2,0x7aed0f1a}},	//   _خود_, _piev, jë_, suat,
   {{0x6485004f,0x7aed0453,0x44fa0031,0x7e670051}},	//   hóir, puat, dë_, lijp,
   {{0x44fa053e,0x62811145,0xdb0700c3,0x443d024b}},	//   eë_, yolo, ämäs, _row_,
   {{0x443d1146,0x62811147,0xa50900c9,0xcf940070}},	//   _sow_, xolo, дека_, נטס_,
   {{0x443d1148,0x6485004f,0x44fa00da,0x69d70282}},	//   _pow_, dóir, gë_, maxe,
   {{0x38661149,0x6281114a,0xed640097,0x00000000}},	//   cior_, wolo, loží_, --,
   {{0x6449114b,0x661a01f4,0xf7730037,0x248600e0}},	//   rkei, _fatk, _صار_, _dkom_,
   {{0x69d7043f,0x6485004f,0x6449114c,0x07080088}},	//   naxe, góir, skei, _سيمي_,
   {{0x201b046a,0x7bd601a2,0xa3c30380,0x44fa0031}},	//   _baqi_, yayu, ्रद_, cë_,
   {{0x2004114d,0xa3d2114e,0x6281114f,0x3f6a1150}},	//   ými_, वरण_, solo, димо_,
   {{0x62811151,0x249f1152,0x661a1008,0x60da1153}},	//   polo, mmum_, _yatk, astm,
   {{0x248d1154,0x63bb01d3,0xfce600aa,0x9f6100b5}},	//   llem_, lcun, кого, ását_,
   {{0x7bd61155,0xfc3f0392,0xfd79027a,0x8d631156}},	//   tayu, _boí_, естъ_, авре,
   {{0x63bb1157,0x3ce500b5,0x2cab0051,0x960e00b4}},	//   ncun, álva_, _cicd_, _िस्ट_,
   {{0xdca31158,0xcb671159,0xa3d202e4,0x44fa01f4}},	// [ac0] рати, вате_, वरत_, zë_,
   {{0x7bd603be,0xbea60112,0x6fa70461,0x248d115a}},	//   sayu, _шапк, _गणतं, hlem_,
   {{0xa3c300e7,0x661a0086,0x7bd6115b,0x249f1051}},	//   ्रा_, _ratk, payu, kmum_,
   {{0x5ee90066,0x44fa01f4,0xb90a115c,0x248d0009}},	//   _जिम्_, vë_, _मि_, jlem_,
   {{0x3866115d,0x248d115e,0x69ca008a,0x2ca000ab}},	//   rior_, dlem_, ðfes, mmid_,
   {{0x44fa071f,0x2486115f,0x2ca000be,0xe7370274}},	//   të_, _skom_, lmid_, тељ_,
   {{0x81d70083,0x386601ff,0x64aa007e,0x00000000}},	//   িলা_, pior_, _dřin, --,
   {{0x44fa071f,0x29181160,0x661a1161,0x4394005f}},	//   rë_, _isra_, _watk, лайс,
   {{0x44fa071f,0x661a1162,0x6d47004e,0x6485004f}},	//   së_, _tatk, zyja, tóir,
   {{0x91fc0080,0xae041163,0xd05d0095,0x60c41164}},	//   ciāl, श्मन_, əyəc, _čimb,
   {{0xb6a300af,0x6485004f,0x67221165,0x44fa0031}},	//   _тифл, róir, lvoj, që_,
   {{0xdb041166,0x64850037,0x60da1167,0x855400b5}},	//   nció, sóir, rstm, _لیڈر_,
   {{0xf09f0310,0x73361168,0xdb040300,0x657a009e}},	//   rmà_, _جرائ, ició, _hxth,
   {{0x52d70122,0x2ca000ab,0xc6940070,0x33260168}},	//   _יודע_, emid_, טאָ_, _irox_,
   {{0x4fc71169,0xdb04006c,0x2918021d,0x201b0c6f}},	//   _испа, kció, _nsra_, _taqi_,
   {{0x09cb0fcf,0x57cc0761,0x30a400d8,0x3f8500a8}},	//   िर्य, ारोह, _крыв, ğlub_,
   {{0x69d7116a,0x3a75116b,0x6e450037,0x245100fe}},	// [ad0] taxe, глар, _منظم, _jáma_,
   {{0x68e3116c,0x6722116d,0x99d51062,0x2ca0116e}},	//   ándo, dvoj, اقات, amid_,
   {{0x69d7116f,0xa3d208b0,0x248d0edf,0x8af000a8}},	//   raxe, वरा_, ylem_, lzəl,
   {{0x69d70391,0x69ca008a,0xa01b00a6,0x00000000}},	//   saxe, ðfer, mlös, --,
   {{0x7c2f1170,0xa3c3045c,0x64aa01c0,0xa01b1171}},	//   _incr, ्रस_, _přin, llös,
   {{0xe29a00e8,0xdb0409ab,0x45191172,0xf3f900af}},	//   _như_, ació, еция_, miţi_,
   {{0xa8a70d46,0x91fc0080,0xa01b1173,0x58d41174}},	//   _арак, riāl, nlös, _вост,
   {{0xdb041175,0x69d51176,0x33260024,0x00000000}},	//   cció, _heze, _brox_, --,
   {{0x248d1177,0x69d5006c,0xf3f900af,0xa3e401c0}},	//   rlem_, _keze, niţi_, _भएर_,
   {{0x69d51178,0x63bb1179,0xa3c305f7,0x24510097}},	//   _jeze, scun, ्रह_, _dáma_,
   {{0x10a6117a,0x69d5117b,0x248d117c,0xe0d600af}},	//   лион, _meze, plem_, лвэ_,
   {{0xcea90779,0x69d50a75,0xf99202b8,0xdd410103}},	//   _זי_, _leze, מרי_, _eŋŋe,
   {{0x442f0796,0xe28e117d,0x26df02c4,0x16000084}},	//   _ing_, _га_, _jvuo_, ल्वर_,
   {{0xa01b01ae,0x7c2f117e,0x00000000,0x00000000}},	//   flös, _ancr, --, --,
   {{0x6722117f,0x1d071180,0xed5a1181,0x2d8c054e}},	//   zvoj, лери_, хов_, æde_,
   {{0x09cd0083,0xfe7f0310,0xaab500b4,0x63ad021d}},	//   _লাগা, duïu_, _अंशक, _ºand,
   {{0x69d51182,0x2ca000be,0x705301b2,0x442f1183}},	// [ae0] _beze, rmid_, _دنيا, _mng_,
   {{0x442f00a7,0x57cc012f,0x2ca01184,0x00000000}},	//   _lng_, ार्ह, smid_, --,
   {{0x442f0b04,0x69d51185,0x9d460fc5,0xdb1d1186}},	//   _ong_, _deze, _сенд, _besó,
   {{0x442f1187,0x3e6d00d5,0x00000000,0x00000000}},	//   _nng_, ržte_, --, --,
   {{0xdb040caa,0xdb1d02d7,0x69d50183,0x764100fd}},	//   rció, _desó, _feze, _boly,
   {{0x442f1188,0x69d51189,0x6722118a,0x20d1118b}},	//   _ang_, _geze, rvoj, kši_,
   {{0xdb0409ab,0x6722118c,0x20d1108a,0x442f118d}},	//   pció, svoj, jši_, _bng_,
   {{0x69d501d7,0x44de003c,0x3326118e,0x6d5c00ec}},	//   _zeze, rċ_, _prox_, izra,
   {{0x76410332,0x32540043,0x78a2118f,0x69d51190}},	//   _foly, ивир, mmov, _yeze,
   {{0x78a20936,0x76410297,0xda140035,0xdb040042}},	//   lmov, _goly, ड़ित_, nciñ,
   {{0xd48f1191,0x2d8c0035,0x6244009e,0x741300d1}},	//   _гр_, żdej_, _bòor, _گونا,
   {{0xd0e506bc,0x78a20300,0x442f08dd,0xb4c20a64}},	//   _किरण_, nmov, _gng_, ्ठी_,
   {{0xe29a0028,0xdd250029,0x9f5902d7,0x75280168}},	//   _thư_, dīša, vesó_, _hrdz,
   {{0x98bc01c0,0x64421192,0x78a20725,0xa01b1193}},	//   ávě_, _hooi, hmov, tlös,
   {{0x442f02c7,0x78a202c6,0x644202a2,0xeabf01da}},	//   _yng_, kmov, _kooi, _crùn_,
   {{0x78a200cd,0xa01b1173,0x78b502c4,0xda020066}},	//   jmov, rlös, _ruzv, र्सत_,
   {{0xa01b0ed4,0x64420244,0x909810ad,0x69d501d7}},	// [af0] slös, _mooi, _حضور_, _peze,
   {{0xdb1d0310,0xf3f9002d,0xa01b01ff,0x9f40033b}},	//   _besò, riţi_, plös, _heiß_,
   {{0x69d51194,0x9851004e,0x39151195,0x76410a2d}},	//   _veze, nąć_, рмер, _roly,
   {{0x64420d26,0x69d51196,0x76411197,0xc9050d12}},	//   _nooi, _weze, _soly, _रहीम_,
   {{0x7bda1198,0x442f00ee,0xf6e71199,0x1707042c}},	//   _בקרו, _rng_, уцен, افتی_,
   {{0x7aed119a,0x7bcd119b,0x6d480508,0x78a200ac}},	//   mrat, lbau, ädag, amov,
   {{0xe3b10514,0x7a4100b8,0x7641119c,0x64420051}},	//   يرة_, _vítě, _voly, _booi,
   {{0x20d101cc,0x7bcd119d,0x7aed119e,0x130900d4}},	//   vši_, nbau, orat, вний_,
   {{0x6442053e,0x7aed119f,0x442f11a0,0x764111a1}},	//   _dooi, nrat, _vng_, _toly,
   {{0x248001cc,0x6aae01e8,0xdd250029,0x7aed11a2}},	//   čima_, _xibf, zīša, irat,
   {{0x290111a3,0x27e00093,0x7aed0168,0xdddc011c}},	//   ntha_, ðing_, hrat, jorš,
   {{0x442f11a4,0x672911a5,0x20d111a6,0x644201e4}},	//   _ung_, _krej, rši_, _gooi,
   {{0x99980116,0x00000000,0x00000000,0x00000000}},	//   _morš_, --, --, --,
   {{0x21a50009,0x20d1030a,0x78a20097,0x8cb10035}},	//   _килм, pši_, zmov, _आंखो,
   {{0xada61109,0xdb1200fb,0x7aed016f,0x6da611a7}},	//   равл, _ágús, erat, рива,
   {{0x3b00007a,0x6729112c,0x7bcd11a8,0x32050a8a}},	//   ttiq_, _orej, gbau, lfly_,
   {{0x7aed11a9,0x2d850ab6,0xfe7f0443,0xdd2500ea}},	// [b00] grat, üler_, tuït_, rīša,
   {{0x09e611aa,0x8d7600fd,0x00000000,0x00000000}},	//   рожн, _ناجا, --, --,
   {{0x2901004f,0xe8fa11ab,0x7aed0382,0xaa7b01c0}},	//   gtha_, тле_, arat, _svýc,
   {{0x672911ac,0x64aa0355,0x00000000,0x00000000}},	//   _brej, _přim, --, --,
   {{0x78a2024e,0x2bd30378,0x29010094,0x644211ad}},	//   rmov, तररा, atha_, _rooi,
   {{0x6729071f,0x29010079,0x644211ae,0x245800a2}},	//   _drej, btha_, _sooi, _méme_,
   {{0xa3c300e7,0x25080164,0xb4c200b4,0x29010037}},	//   ्रं_, ارتی_, ्ठे_, ctha_,
   {{0x672911af,0x32050f00,0x249d0090,0x00000000}},	//   _frej, efly_, _chwm_, --,
   {{0x672911b0,0xd1ca11b1,0xa2b300c3,0x32050312}},	//   _grej, кунд_, обыч, ffly_,
   {{0x166311b2,0x6f0d01da,0x64aa007e,0x00000000}},	//   _двум, _rpac, _křik, --,
   {{0x7aed00ee,0x6f0d11b3,0x672901ba,0x91a90023}},	//   zrat, _spac, _zrej, _đã_,
   {{0xa3c31140,0x7aed11b4,0xdd30007e,0x00000000}},	//   ्रः_, yrat, _běžt, --,
   {{0xfe7f0392,0x00000000,0x00000000,0x00000000}},	//   duïr_, --, --, --,
   {{0x7aed0ba8,0x9f4002c9,0x2d8401d6,0x69d8008a}},	//   vrat, _weiß_, ğmen_, ðvel,
   {{0x7aed0024,0x25fb11b5,0x228b0185,0xb7bd0139}},	//   wrat, ल्टी_, røkt_, _haţe,
   {{0x7aed11b6,0x00000000,0x00000000,0x00000000}},	//   trat, --, --, --,
   {{0x7bcd11b7,0x6f0d0452,0x64aa01c0,0x7aed11b8}},	// [b10] rbau, _upac, _přij, urat,
   {{0xe9ab09b9,0x6288001e,0xab8411b9,0x7aed11ba}},	//   ندان_, nodo, цуск, rrat,
   {{0x628801ef,0x672902c4,0x7aed11bb,0x39470395}},	//   iodo, _srej, srat, âns_,
   {{0x62880252,0x672911bc,0x7aed11bd,0x290111be}},	//   hodo, _prej, prat, rtha_,
   {{0x290111bf,0x07090698,0xfe04021a,0xf77011c0}},	//   stha_, ايتي_, श्वस_, واه_,
   {{0xb60711c1,0xdd280029,0x6288012f,0x29010037}},	//   рядк, lēša, jodo, ptha_,
   {{0x628811c2,0xd46911c3,0xa3d2012f,0x48ab005f}},	//   dodo, лике_, वरं_, _атам_,
   {{0x672911c4,0xdd280029,0x00000000,0x00000000}},	//   _trej, nēša, --, --,
   {{0x6288001e,0x672902c6,0x9f4404d4,0xd5b100cc}},	//   fodo, _urej, ümü_, _lái_,
   {{0x8b5800a5,0x00000000,0x00000000,0x00000000}},	//   ייחס_, --, --, --,
   {{0xf5950082,0x0086036c,0x00000000,0x00000000}},	//   _الاج, йлоо, --, --,
   {{0x205611c5,0x237d0221,0x7ae211c6,0xb7bd0160}},	//   стор, _txwj_, šoti, _faţe,
   {{0x628811c7,0x443f11c8,0x645b04e6,0xdd2800ea}},	//   bodo, mju_, mhui, dēša,
   {{0xb6cc0644,0x741300b5,0x645b11c9,0x00000000}},	//   _şükü, _دوچا, lhui, --,
   {{0xed5711ca,0x443f00d8,0xdd9205bc,0xafdb11cb}},	//   бор_, oju_, سور_, rkør,
   {{0x645b0120,0x78a311cc,0x245800a0,0xd5b10023}},	//   nhui, ïnvl, _téme_, _cái_,
   {{0x8c4311cd,0xbbb80099,0x09e6002d,0x645b0298}},	// [b20] чете, _अलीक, йоан, ihui,
   {{0x443f007c,0x64aa00b8,0xe9d711ce,0xda6511cf}},	//   hju_, _přik, йку_, يالي,
   {{0x645b0fdb,0x443f008d,0x090611d0,0x08fa0ae7}},	//   khui, kju_, спен, طراب_,
   {{0x443f11d1,0xb8eb006c,0xdd2800ea,0xc7a600af}},	//   jju_, ابلے_, cēša, биек,
   {{0x443f11d2,0xf3ff0083,0x645b11d3,0x7c2411d4}},	//   dju_, ্যার_, dhui, mdir,
   {{0x7c2411d5,0x443f11d6,0x89f500d8,0x645b0130}},	//   ldir, eju_, _мясц, ehui,
   {{0x628811d7,0x69de11d8,0x645b11d9,0x6d4e11da}},	//   vodo, mape, fhui, nyba,
   {{0x7c2411db,0x24800528,0x6288004e,0xa3a900b1}},	//   ndir, čimo_, wodo, _गृह_,
   {{0x35fa036b,0x98a300af,0x00000000,0x00000000}},	//   _مراد_, _хите, --, --,
   {{0x69de11dc,0x443f11dd,0xdd2800ea,0x00000000}},	//   nape, aju_, zēša, --,
   {{0x628811de,0x443f11df,0x7c24037a,0x00000000}},	//   rodo, bju_, kdir, --,
   {{0x628811e0,0x69de11e1,0x645b11e2,0x443f11e3}},	//   sodo, hape, chui, cju_,
   {{0x69de11e4,0x628811e5,0x7c2411e6,0x09e30083}},	//   kape, podo, ddir, ন্টা,
   {{0x3dd900c8,0xdce501ba,0x5eb80033,0x69de11e7}},	//   _তাহল, _vzhľ, _অবশে, jape,
   {{0x69de11e8,0x64aa000c,0xd12f0aeb,0x260008a9}},	//   dape, _přih, _эх_, _रानी_,
   {{0x7c2411e9,0x60c700b8,0xa17700a5,0x00000000}},	//   gdir, íjme, _לעוד_, --,
   {{0xdd280029,0x7d1e011e,0xeabf0023,0xf3fa0033}},	// [b30] rēša, _esps, _trùm_, _আসার_,
   {{0x443f0484,0x7b74004f,0x69de11ea,0x00000000}},	//   zju_, أطفا, gape, --,
   {{0x78bb0207,0x6d4e0027,0x00000000,0x00000000}},	//   _čuvs, cyba, --, --,
   {{0x19a811eb,0xaae20380,0x987c0355,0x00000000}},	//   ступ_, _पिचक, bíč_, --,
   {{0xe73911ec,0x443f11ed,0x4424012f,0x69de11ee}},	//   рел_, vju_, ddm_, bape,
   {{0xdb1d06d7,0x7bdf11ef,0x1b060033,0x69de11f0}},	//   _besö, laqu, রিখে_, cape,
   {{0xf53200c9,0x443f11f1,0x8459002d,0x645b11f2}},	//   дејќ, tju_, ирит_, thui,
   {{0x7bdf11f3,0x94790274,0x443f0e3c,0x00000000}},	//   naqu, јску_, uju_, --,
   {{0x443f11f4,0x645b02e6,0x727900af,0xa5f90274}},	//   rju_, rhui, исос_, _везу_,
   {{0x443f11f5,0x645b11f6,0xdd1c0187,0x7c2411f7}},	//   sju_, shui, váže, zdir,
   {{0x443f11f8,0x932702fd,0x7c2401fb,0xda0b021a}},	//   pju_, _گران, ydir, स्यत_,
   {{0x69de11f9,0x1faa031a,0xbbb804bc,0x00000000}},	//   zape, икни_, _अलेक, --,
   {{0x7bdf11fa,0x9327042c,0x7c2411fb,0x64590024}},	//   daqu, _دران, vdir, _ilwi,
   {{0xda0b0084,0x6d4e11fc,0xa3c30d34,0xdd1c031d}},	//   स्मत_, tyba, ्रक_, ráže,
   {{0xa3bd02cb,0x69de11fd,0x7bdf0031,0x7c240510}},	//   _आला_, vape, faqu, tdir,
   {{0x69de11fe,0x22470051,0x6d4e11ff,0x7c241200}},	//   wape, _honk_, ryba, udir,
   {{0xe9da1199,0x7c241201,0xf41202da,0x200501c2}},	// [b40] ика_, rdir, ופן_, əli_,
   {{0x2247053e,0x7c241202,0xee0a00af,0x49960d6e}},	//   _jonk_, sdir, _теол_, ошет,
   {{0x69de1203,0x6da60525,0x8c461204,0xdd0f01d6}},	//   rape, _фина, _дене, mışt,
   {{0xdd0f01d6,0x7c2400a8,0x9f480023,0x394701ff}},	//   lışt, qdir, _điêu_, änsa_,
   {{0xcfbc0033,0x64aa0355,0xfaa61205,0x60c402a7}},	//   _অজান, _křiv, _мамо, _čimm,
   {{0x7ae40037,0x64590069,0xdd0f0225,0xf4ea0421}},	//   msit, _alwi, nışt, афий_,
   {{0xd90d0164,0x7ae41206,0x81cf0083,0x69dc1207}},	//   _میل_, lsit, ষণা_, _iere,
   {{0x7bc41208,0x7ae41209,0x245800fe,0x4adf021a}},	//   nciu, osit, _béma_, _पौडव,
   {{0x69dc042c,0x7ae4120a,0x22470159,0x7bc4010b}},	//   _kere, nsit, _bonk_, iciu,
   {{0x69dc120b,0x7ae4120c,0x24510037,0x4424012f}},	//   _jere, isit, _lámh_, sdm_,
   {{0x69dc120d,0xd2570a93,0x224702e9,0x7bdf120e}},	//   _mere, іць_, _donk_, yaqu,
   {{0x69dc120f,0xe0cf064e,0x7bdf014c,0x66181210}},	//   _lere, کزی_, xaqu, levk,
   {{0x69dc008c,0x7ae400f4,0x78bc03c1,0x20050067}},	//   _oere, jsit, _lurv, ęli_,
   {{0x248901ba,0x76480359,0x5bd302b4,0xbbd30b35}},	//   čame_, _jody, तर्व, तर्क,
   {{0x7bdf0248,0x16d702e4,0x7ae41211,0xec6b1212}},	//   taqu, _डब्ब, esit, арак_,
   {{0x69dc01d3,0x67200c21,0x3ced068b,0xa0680836}},	//   _aere, _osmj, čev_, _маја_,
   {{0x20191213,0x7bdf1214,0x7ae4010d,0xb60601ba}},	// [b50] mesi_, raqu, gsit, _kráľ,
   {{0x20191215,0x66180bde,0x69dc1216,0x7bc4027a}},	//   lesi_, jevk, _cere, aciu,
   {{0x69dc1217,0x7bdf0300,0xfe7000bc,0x48151218}},	//   _dere, paqu, _جدي_, змес,
   {{0x765a1219,0x2019121a,0x7ae4121b,0xb17b02b5}},	//   _alty, nesi_, bsit, סטאר,
   {{0x2ca90e89,0x69dc121c,0x27e0008a,0xf770042c}},	//   mmad_, _fere, ðina_, پان_,
   {{0x69dc121d,0x7bdd121e,0x2019121f,0x2ca900ab}},	//   _gere, _hesu, hesi_, lmad_,
   {{0x69c51220,0x7bdd1221,0x6e250024,0x20191222}},	//   mche, _kesu, _mahb, kesi_,
   {{0x7bdd1223,0x69c50b84,0x20191224,0x68e31225}},	//   _jesu, lche, jesi_, ándu,
   {{0x2bdc0302,0x69dc1226,0x76d500ad,0x20191227}},	//   बरता, _yere, _رياض, desi_,
   {{0x7bdd1228,0x69c51229,0x69dc122a,0x09af0083}},	//   _lesu, nche, _xere, _চ্যা,
   {{0x69c5122b,0x2019122c,0x387f02c4,0x69d80093}},	//   iche, fesi_, _kjur_, ðvei,
   {{0x2458122d,0x7bdd122e,0x2019122f,0x7ae41230}},	//   _téma_, _nesu, gesi_, ysit,
   {{0x24511231,0x64aa00b8,0x248d012f,0x91cc0b35}},	//   _námi_, _přiv, moem_, _द्वै,
   {{0x69c51232,0x6e25009e,0x248d01bf,0x2ca900be}},	//   jche, _cahb, loem_, emad_,
   {{0x61e103ad,0x69dc1233,0x7bdd1234,0x6abd02c9}},	//   mall, _rere, _besu, _ausf,
   {{0x7ae41235,0x61e11236,0x20191237,0x8c431238}},	//   tsit, lall, cesi_, несе,
   {{0x7bdd054e,0x7bc4006c,0x78bc1239,0x2d9e0187}},	// [b60] _desu, rciu, _surv, ťte_,
   {{0x7bc4123a,0x61e1123b,0x78bc123c,0x386d123d}},	//   sciu, nall, _purv, _amer_,
   {{0x7ae4123e,0x764800d8,0xda020d91,0x7bdd123f}},	//   ssit, _rody, र्गत_, _fesu,
   {{0x61e11240,0x69dc1241,0x7bdd1242,0x7ae41243}},	//   hall, _were, _gesu, psit,
   {{0x61e1052a,0x387f013c,0x69c51244,0x76481245}},	//   kall, _djur_, bche, _pody,
   {{0x78bc1246,0x61e11247,0x7bdd0103,0x69c501d3}},	//   _turv, jall, _zesu, cche,
   {{0x20c100e8,0x7bdd1248,0x20191249,0xfaa3124a}},	//   _nói_, _yesu, yesi_, _чаро,
   {{0x066601df,0x7bdd0042,0x6d4100c3,0x32c00107}},	//   _کارپ, _xesu, älai, _pòy_,
   {{0x6618124b,0x61e1124c,0x6720124d,0x00000000}},	//   pevk, fall, _usmj, --,
   {{0x61e1124e,0x2019124f,0x20c10019,0x3f850225}},	//   gall, wesi_, _bói_, şluk_,
   {{0x6e251250,0x20191251,0xcfe10083,0x60cd011c}},	//   _rahb, tesi_, _ভাবন, _čamc,
   {{0xe3a70332,0xb6060187,0x3dd90033,0x20c10132}},	//   _کشمی, _dráž, _তাইল, _dói_,
   {{0x61e11252,0x20191253,0xaa7b00b8,0x00000000}},	//   ball, resi_, _svým, --,
   {{0x44260657,0x7bdd124f,0x61e10122,0x8ca20026}},	//   _hao_, _sesu, call, _कीबो,
   {{0x44261254,0x20c101a5,0x7bdd1255,0x20191256}},	//   _kao_, _gói_, _pesu, pesi_,
   {{0x7c261257,0x44261258,0x20190031,0x3a380160}},	//   _cakr, _jao_, qesi_, _anrp_,
   {{0xd6d70b52,0x44260430,0x69c51259,0x2ca9125a}},	// [b70] _সম্প, _mao_, tche, rmad_,
   {{0x4426125b,0x27e000fb,0x69c5125c,0x386d125d}},	//   _lao_, ðinn_, uche, _smer_,
   {{0x69c50599,0x29190ca8,0x7bdd125e,0xfaa80037}},	//   rche, تقاد_, _tesu, أهلي_,
   {{0x69c5125f,0x44261260,0xd12604cd,0x7bdd00e7}},	//   sche, _nao_, _یم_, _uesu,
   {{0x69c51261,0x61e1045e,0x79950067,0x00000000}},	//   pche, yall, _wyzw, --,
   {{0x7c26088d,0x61e11262,0xf1ba0023,0x660d00cd}},	//   _zakr, xall, _ngơ_, đako,
   {{0x61e11263,0x44260028,0x7c3a0079,0x00000000}},	//   vall, _bao_, _úcrá, --,
   {{0x442600e8,0x61e11264,0x2458000d,0x20c11265}},	//   _cao_, wall, _démo_, _rói_,
   {{0x44261266,0x27ed1267,0x20c10019,0x3b0900a8}},	//   _dao_, _iden_, _sói_, ntaq_,
   {{0x81bc00ea,0x25a00355,0x44261268,0x00000000}},	//   ldēj, řila_, _eao_, --,
   {{0x26cd1269,0x61e1126a,0x64aa00b8,0x3555126b}},	//   _hteo_, rall, _přit, _تناز,
   {{0x61e1126c,0xd36e00bf,0x20e700cd,0x387d016e}},	//   sall, اهی_, rđi_, nnwr_,
   {{0x61e1126d,0xe28e126e,0x7c26126f,0x00000000}},	//   pall, _аа_, _rakr, --,
   {{0x44260657,0x6da604b2,0x13e20083,0x61e10be2}},	//   _zao_, дига, _যায়, qall,
   {{0x44260657,0x7c261270,0x644b01ef,0x27ed0523}},	//   _yao_, _pakr, _kogi, _oden_,
   {{0x44260023,0x8af000a8,0x27ed027d,0x26cd00cd}},	//   _xao_, yyəd, _nden_, _oteo_,
   {{0x1e860948,0x644b1271,0xeb971272,0x7c260185}},	// [b80] _олим, _mogi, дит_, _vakr,
   {{0x7c260054,0x63bc0355,0xcf9300a5,0x00000000}},	//   _wakr, ěrni, _בטח_, --,
   {{0x7c261273,0xa80601c8,0x26cd0159,0xa3bd00a1}},	//   _takr, дзел, _ateo_, _आलं_,
   {{0x644b1274,0xd7ef0037,0x27ed008c,0x00000000}},	//   _nogi, لكم_, _cden_, --,
   {{0x44260028,0x47360037,0xdb1d08c8,0x245100fe}},	//   _rao_, براز, _afsæ, _jámu_,
   {{0x44261275,0x27ed1276,0xdd1d0333,0xd0270033}},	//   _sao_, _eden_, lášt, যায়_,
   {{0x44261277,0x644b1278,0x245100ee,0x00000000}},	//   _pao_, _bogi, _lámu_, --,
   {{0xe9a31279,0x644b127a,0xfc3f00e2,0x7af60067}},	//   _расп, _cogi, _khía_, oryt,
   {{0x4426127b,0x84ea0c57,0xd7030382,0xd5cf0d60}},	//   _vao_, _टिकट_, _изти, _स्वज,
   {{0x44260657,0x64aa01c0,0x24890254,0x65790037}},	//   _wao_, _přis, čama_, ábhá,
   {{0xd48f0012,0x4426127c,0x09f70052,0xb42300fd}},	//   _ар_, _tao_, ומים_, رٹیو,
   {{0xdbd6127d,0x644b00e5,0x44260176,0x00000000}},	//   _jääd, _gogi, _uao_, --,
   {{0xfe730125,0x00000000,0x00000000,0x00000000}},	//   ندس_, --, --, --,
   {{0x245100d5,0x63a2127e,0x6a600282,0x00000000}},	//   _dámu_, _izon, _löfb, --,
   {{0xdd9401c8,0x2d850381,0xdc140448,0x00000000}},	//   вары, çle_, _ağız, --,
   {{0x7af601f4,0xaa7b0187,0x7bd60298,0x00000000}},	//   fryt, _zvýh, gbyu, --,
   {{0x5a3502fb,0x5b150677,0xf09400a5,0x7af6127f}},	// [b90] ннат, эмат, _בנק_, gryt,
   {{0x3b090024,0x00000000,0x00000000,0x00000000}},	//   rtaq_, --, --, --,
   {{0x80e00033,0x3b091280,0x00000000,0x00000000}},	//   পূর্, staq_, --, --,
   {{0x7af61281,0xc19b00a5,0x00000000,0x00000000}},	//   bryt, חשבי, --, --,
   {{0x6d5500b5,0xa3c21282,0x629a0009,0x387d016e}},	//   lyza, ंशन_, klto, rnwr_,
   {{0xe5a51283,0x629a0051,0x00000000,0x00000000}},	//   нили, jlto, --, --,
   {{0x63a20332,0x644b1284,0x04b51285,0x4adb021a}},	//   _azon, _pogi, нсия, मीरव,
   {{0x03251286,0x27ed0022,0x63a2035f,0xc3250432}},	//   един, _uden_, _bzon, емик,
   {{0xe6100e3a,0x64aa00b8,0x200c00b5,0x662800c3}},	//   _چشم_, _přir, ődik_, öskä,
   {{0x63a21287,0x64b100ea,0x60c701ba,0x00000000}},	//   _dzon, _jāiz, íjmo, --,
   {{0x9f4201cb,0x644b1288,0x63a21289,0x00000000}},	//   maké_, _togi, _ezon, --,
   {{0xe7300332,0x2cb90211,0x2004128a,0x00000000}},	//   _حصہ_, _nisd_, ümi_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cb90211,0x60c40116,0x00000000,0x00000000}},	//   _aisd_, _čimv, --, --,
   {{0x40960525,0xdd92128b,0x9f420118,0x00000000}},	//   _прит, اوز_, iaké_, --,
   {{0xfc3f01a5,0x6aa80246,0x9f4200d1,0x7af60f31}},	//   _phía_, कग्र, haké_, tryt,
   {{0x9f4201ca,0x7bd6010d,0xc2cc016b,0x00000000}},	// [ba0] kaké_, rbyu, ַמאָ, --,
   {{0x9f42024e,0xcfb70122,0xdbd60086,0x7af6128c}},	//   jaké_, _אלפי_, _sääd, rryt,
   {{0x69a5021a,0x8d76128d,0xdbd61130,0x9f4201cb}},	//   _करणी, _سادا, _pääd, daké_,
   {{0x27e0128e,0x2002128f,0xe3a7036b,0xfc3f00e2}},	//   úin_, ngki_, _مر_, _thía_,
   {{0x81d60033,0x9f4201cb,0x00000000,0x00000000}},	//   িণত_, faké_, --, --,
   {{0x9f4201cb,0x00000000,0x00000000,0x00000000}},	//   gaké_, --, --, --,
   {{0xa9a30009,0xe9a30036,0x6593005f,0x22990118}},	//   _бирд, _барп, лашу, cèki_,
   {{0x62830009,0x25a000b8,0x3eba1290,0x69a51291}},	//   _ajno, řilo_, _lipt_, _करती,
   {{0x087702b5,0x68fe005f,0xb5fc007a,0x27e61292}},	//   _נעמט_, lupd, _alġe, maon_,
   {{0x325405c2,0x27e61293,0x3eba0051,0x9f4200e0}},	//   твор, laon_, _nipt_, caké_,
   {{0xf0e71294,0xd5a40a44,0x2d9a03d0,0x00000000}},	//   ньяк_, _ओरिज, _nype_, --,
   {{0x27e61295,0x62830009,0x25a1033b,0x20b4010b}},	//   naon_, _ejno, ühle_, лёўс,
   {{0xf1d100b8,0x3ce30099,0x2cb90027,0x63a2007b}},	//   _द्वन, टीने_, _risd_, _uzon,
   {{0x27e6043d,0xfc3f0019,0x6d550035,0x611400d8}},	//   haon_, _chín_, tyza, _адку,
   {{0x321e0e7d,0x27e61296,0x7e751297,0x00000000}},	//   mety_, kaon_, rizp, --,
   {{0x6d55004e,0x321e1298,0xc5e60033,0x00000000}},	//   ryza, lety_, নলিপ, --,
   {{0x200c0095,0x00000000,0x00000000,0x00000000}},	// [bb0] ədi_, --, --, --,
   {{0x321e1299,0x06cf0831,0x00000000,0x00000000}},	//   nety_, _রিলি, --, --,
   {{0xa3e00722,0xa3c2129a,0xfe7f0176,0x00000000}},	//   थरा_, ्डा_, duïx_, --,
   {{0x99980009,0xab5b0183,0x69d8008d,0x80a70067}},	//   _forž_, _agüe, ðver, _टीमे,
   {{0x321e024e,0x7c2d129b,0x58b8004f,0x99980009}},	//   kety_, mdar, رامج_, _gorž_,
   {{0x7c2d129c,0xe73607e5,0xf1b2022e,0x00000000}},	//   ldar, теш_, ुखान, --,
   {{0x64aa000c,0x27e6129d,0x60cd02c4,0xc984129e}},	//   _přip, baon_, _čamo, _бути,
   {{0x2489129f,0x3d190067,0x00000000,0x00000000}},	//   čamo_, _पहने_, --, --,
   {{0x9f4200d1,0x321e0122,0xd5bb0546,0x130600c3}},	//   paké_, fety_, _есе_, вный_,
   {{0xa77412a0,0x7c2d12a1,0x78aa00a0,0x68e108c8}},	//   _случ, hdar, čovň, _ælds,
   {{0x320b004e,0x216912a2,0x7c2d12a3,0x33260044}},	//   ęcy_, фини_, kdar, _esox_,
   {{0x7c2d12a4,0x2056081b,0x2bd30099,0x00000000}},	//   jdar, ттор, धुमा, --,
   {{0xf8b200c2,0x7c2d12a5,0x442d08d7,0xe81300a1}},	//   ישט_, ddar, mde_, ण्या_,
   {{0x7c3d03d0,0x2d9a0b88,0x00000000,0x00000000}},	//   _ansr, _pype_, --, --,
   {{0x1d0705c7,0x442d12a6,0x67220035,0xfc3f01ef}},	//   кери_, ode_, zwoj, _chío_,
   {{0x7c2d0dc3,0x61e312a7,0x644912a8,0x645b00c3}},	//   gdar, _henl, njei, nkui,
   {{0xc0530122,0xe9d2026e,0x628112a9,0x61e300cc}},	// [bc0] _כזה_, لغا_, onlo, _kenl,
   {{0x442d0086,0x7c2d12aa,0x628100d4,0x7c3d0a8a}},	//   hde_, adar, nnlo, _ensr,
   {{0x27e60d0d,0x442d053d,0x7c2d12ab,0xbf9b0279}},	//   taon_, kde_, bdar, ngên,
   {{0x442d12ac,0x38600082,0x321e12ad,0x61e30159}},	//   jde_, óir_, zety_, _lenl,
   {{0x442d12ae,0xe1e70148,0x2ee002e9,0xf11e051d}},	//   dde_, _پس_, _jwif_, _बन्द_,
   {{0x442d12af,0x27e61296,0x443d0051,0x645b0b88}},	//   ede_, saon_, _anw_, ekui,
   {{0x442d12b0,0x321e00d5,0x29180009,0xa80612b1}},	//   fde_, vety_, _upra_, _извл,
   {{0x442d12b2,0x78bb0139,0x6abb002a,0x443d00f6}},	//   gde_, _giuv, _éufr, _cnw_,
   {{0xd70712b3,0x68e1054e,0x799c001e,0x61e312b4}},	//   _инте_, _ældr, _hyrw, _benl,
   {{0x442d12b5,0x386600c9,0x7c2d12b6,0x443d0297}},	//   ade_, lhor_, zdar, _enw_,
   {{0x26c412b7,0x442d0249,0x321e12b8,0x7c2d0381}},	//   _humo_, bde_, rety_, ydar,
   {{0xf993035e,0x386603e6,0x68e312b9,0x61e312ba}},	//   ירת_, nhor_, ândi, _eenl,
   {{0x321e1298,0x61e3021e,0x69ce0093,0x7c2d12bb}},	//   pety_, _fenl, _ofbe, vdar,
   {{0xdce50038,0x61e312bc,0x27e4002d,0x26c4011e}},	//   _vyhľ, _genl, _lemn_, _mumo_,
   {{0xac1912bd,0x61e812be,0x7c2d12bf,0xa3e60084}},	//   нову_, madl, tdar, _बजा_,
   {{0xfbd30148,0x7c2d12c0,0x69ce0a75,0x660d022f}},	//   شتر_, udar, _afbe, đaki,
   {{0x386612c1,0x200901ef,0x00000000,0x00000000}},	// [bd0] dhor_, _icai_, --, --,
   {{0x442d12c2,0xf09f12c3,0x61e812c4,0x7c2d12c5}},	//   zde_, llà_, nadl, sdar,
   {{0x442d12c6,0x9f4e006c,0xb7bd0160,0xdbd100be}},	//   yde_, önöm_, _haţi, _küüd,
   {{0x248603fd,0x61e80008,0x7c3d12c7,0x26c4022f}},	//   _njom_, hadl, _unsr, _bumo_,
   {{0x442d070f,0x61e812c8,0x6abc03d0,0xdbd100ab}},	//   vde_, kadl, _firf, _müüd,
   {{0x442d12c9,0x7aed12ca,0x6a60008d,0x00000000}},	//   wde_, msat, _höfn, --,
   {{0x260900a1,0x442d12cb,0x26c401f7,0x27e40107}},	//   _साठी_, tde_, _eumo_, _femn_,
   {{0x628104e2,0x61e312cc,0x290112cd,0x26c412ce}},	//   wnlo, _senl, muha_, _fumo_,
   {{0x7aed12cf,0x387c00f7,0x645b12d0,0x3e66000d}},	//   nsat, èvre_, rkui, _hôte_,
   {{0x442d12d1,0xb7bd0043,0x645b12d2,0x61e80211}},	//   sde_, _naţi, skui, gadl,
   {{0x61e312d3,0x442d12d4,0x2901121e,0x26c412d5}},	//   _venl, pde_, nuha_, _zumo_,
   {{0x44e101c8,0xbf9b03e6,0x83350ca8,0x349403c6}},	//   mų_, rgên, _مرتض, _кахр,
   {{0x27e005ee,0x44e100d8,0xa3c20b35,0x09ca0033}},	//   ðini_, lų_, ्डर_, ষরতা,
   {{0x249f12d6,0x290112d7,0x7aed12d8,0x3f9e0029}},	//   llum_, kuha_, dsat, ātu_,
   {{0x44e101c8,0x7aed12d9,0xf09f0176,0x10f5010b}},	//   nų_, esat, blà_, _сяля,
   {{0xc00612da,0x290112db,0xa3e60299,0x6b9d016e}},	//   _спик, duha_, _बड़ा_, _bysg,
   {{0xfc3f0076,0xcb6712dc,0x7aed12dd,0x7fe912de}},	// [be0] _dní_, гате_, gsat, _شريف_,
   {{0xfeba064e,0x44e101c8,0x6b9d0297,0x26c40279}},	//   _ثابت_, kų_, _dysg, _rumo_,
   {{0x44e101c8,0x386612df,0x7aed12e0,0x3e660248}},	//   jų_, thor_, asat, _côte_,
   {{0x8c460b32,0x6abc12e1,0x44e1010b,0x7aed12e2}},	//   _семе, _wirf, dų_, bsat,
   {{0x09e800c8,0x7aed00fd,0xe73712e3,0x6b9d016e}},	//   _পাঠা, csat, лец_, _gysg,
   {{0x290112e4,0x2ca012e5,0x38660c6f,0x00000000}},	//   buha_, llid_, shor_, --,
   {{0x61e812e6,0x44e100d8,0x2ca0018d,0xa3c212e7}},	//   vadl, gų_, olid_, ्डल_,
   {{0x26090bc1,0x249f0093,0x545412e8,0x61e802b3}},	//   _साथी_, glum_, рвит, wadl,
   {{0x61e812e9,0x18670274,0x41e612ea,0x2ca0018d}},	//   tadl, _сати_, ліна, ilid_,
   {{0x471b0100,0xdbd1007c,0x44e1010b,0x171b0070}},	//   _אומג, _süüd, bų_, _אומע,
   {{0x3de212eb,0x2ca0007c,0x249f0118,0xdbd100ab}},	//   _বাংল, klid_, blum_, _püüd,
   {{0x7aed05ee,0xfc3f01a5,0x442012ec,0x61e812ed}},	//   ysat, _phím_, _úi_, sadl,
   {{0x543b00c2,0x61e80e6a,0x087702b5,0xf09f12ee}},	//   _רעדא, padl, רעכט_, rlà_,
   {{0x2ca012ef,0x6a60008d,0x00000000,0x00000000}},	//   elid_, _söfn, --, --,
   {{0xf09f0392,0x00000000,0x00000000,0x00000000}},	//   plà_, --, --, --,
   {{0x7aed12f0,0x2ca0007c,0x6b9d001e,0x00000000}},	//   tsat, glid_, _pysg, --,
   {{0x3a750de2,0x0ca800c3,0xb7bd0160,0x7aed0a63}},	// [bf0] алар, утри_, _taţi, usat,
   {{0x7aed03d0,0x290112f1,0x7ed4004f,0x2ca000be}},	//   rsat, tuha_, _ازيا, alid_,
   {{0x7aed12f2,0xc98412f3,0x47d512f4,0x667500d1}},	//   ssat, буци, ليار, یدتر,
   {{0x7aed12f5,0x290112f6,0x2ca012f7,0x2c2702ce}},	//   psat, ruha_, clid_, _сьог,
   {{0xf74512f8,0x290101a2,0x26000af6,0xd6db02fb}},	//   рело, suha_, _राखी_, хте_,
   {{0xa2c30e1d,0x44e101c8,0x09df0083,0x290112f9}},	//   रदस्, tų_, _ঢাকা, puha_,
   {{0x58d412fa,0xa8a712fb,0x249f12fc,0xdb1d0a8a}},	//   _гост, _брак, tlum_, _afsø,
   {{0x99840082,0x44e100d8,0x60c408b7,0x3ce80324}},	//   _الفو, rų_, _čimp, _जबसे_,
   {{0x76b9027a,0x09e80083,0xc8641012,0xd2650036}},	//   _алар_, _পাতা, _утри, икий,
   {{0x7c2f0af5,0xaa7b0187,0x249f0093,0x425512fd}},	//   _lacr, _zvýr, slum_, ртит,
   {{0xa06a12fe,0xc4f800ad,0xd6680312,0x249f027d}},	//   вана_, _معنا_, _حملو_, plum_,
   {{0xb4c10fd1,0x54a70e6b,0xcea902b8,0x7c2f01a0}},	//   ंदी_, _صحاف, _חי_, _nacr,
   {{0x442f12ff,0x00000000,0x00000000,0x00000000}},	//   _iag_, --, --, --,
   {{0x442f1300,0x3ebe07ed,0xa2d21301,0x00000000}},	//   _hag_, ött_, _بيوت, --,
   {{0x442f1302,0xfce61303,0x94ee013b,0xc27a0277}},	//   _kag_, робо, _bəə_, _שרצי,
   {{0x442f1304,0xbc6312a0,0xa3ac0e1d,0x2fdf008d}},	//   _jag_, овск, _गरम_, ðugt_,

   {{0x76411305,0xb4c102e4,0x91fc0029,0x6b850037}},	// [c00] _only, ंदु_, bkād, مشكل,
   {{0xe9d71306,0x442f1307,0x7ea0022a,0x4a431308}},	//   ику_, _lag_, köpi, онув,
   {{0x9d460970,0xa9261309,0x442f046d,0xdca607bc}},	//   _тенд, рдел, _oag_, _вани,
   {{0x442f130a,0x4907007c,0x6d5c130b,0x00000000}},	//   _nag_, _हमरो_, myra, --,
   {{0x7c24130c,0xd70710ac,0x28130af8,0x00000000}},	//   meir, инце_, تونس, --,
   {{0x7c24130d,0xb4c10785,0x80db0083,0x7c2f00cb}},	//   leir, ंदू_, _ভিন্, _zacr,
   {{0x3947022a,0xa3c1012f,0x442f130e,0x2bd307b5}},	//   änst_, ःखं_, _bag_, धुवा,
   {{0x7c24130f,0x442f1310,0x8af00095,0x2c6700be}},	//   neir, _cag_, yyəl, _tõde_,
   {{0x27e0008a,0xd5b10023,0x6d5c00e9,0x78a21311}},	//   ðinu_, _máy_, hyra, mlov,
   {{0x80ca0ca1,0x442f1312,0x7c241313,0x59aa0785}},	//   _संदे, _eag_, heir, _करार,
   {{0x3a370052,0x442f1314,0x51861315,0x6d5c0031}},	//   ברים_, _fag_, рупа, jyra,
   {{0x78a21316,0x7c241317,0x6d5c108c,0x1b1d0033}},	//   nlov, jeir, dyra, নিতে_,
   {{0x7c241318,0x44241319,0x236d004e,0x78a20187}},	//   deir, mem_, czej_, ilov,
   {{0x7c2f131a,0x442f131b,0xa2c3131c,0x78a20187}},	//   _sacr, _zag_, रदर्, hlov,
   {{0x442f131d,0x7c240297,0x78a200ac,0x6d5c131e}},	//   _yag_, feir, klov, gyra,
   {{0x4424131f,0x7c241320,0x245801ba,0x78a21321}},	//   nem_, geir, _tému_, jlov,
   {{0x78a2024e,0x44241322,0x80ca018d,0xf9c7111d}},	// [c10] dlov, iem_, _सूते, ащен,
   {{0x44241323,0x753a01b7,0x00000000,0x00000000}},	//   hem_, _ortz, --, --,
   {{0x44241324,0x7c240bc8,0x26000026,0x7c2f1325}},	//   kem_, beir, _राजी_, _tacr,
   {{0x7c241326,0x00000000,0x00000000,0x00000000}},	//   ceir, --, --, --,
   {{0x442f1327,0x753a01d7,0xfe701328,0x7d1e02a7}},	//   _rag_, _artz, _ردی_, _zpps,
   {{0x64420514,0x442f1329,0x00000000,0x00000000}},	//   _anoi, _sag_, --, --,
   {{0x442f132a,0xb4c100a1,0x4424132b,0x9608010b}},	//   _pag_, ंदे_, fem_, рэча_,
   {{0x4424132c,0x442f01e8,0xe3e9132d,0xe894010b}},	//   gem_, _qag_, اکان_, _дась,
   {{0x442f132e,0xe2990714,0xdbf40083,0x753a06a2}},	//   _vag_, лаи_, ঙ্কস_, _ertz,
   {{0x442f132f,0x7c2403e6,0x9f42031d,0x673b01b7}},	//   _wag_, zeir, jaká_, _iruj,
   {{0x442f1330,0x44241331,0x236d004e,0x291306a2}},	//   _tag_, bem_, szej_, ntxa_,
   {{0x44241332,0x442f1333,0x7c240bc8,0x673b0031}},	//   cem_, _uag_, xeir, _kruj,
   {{0x43741334,0x7c241335,0x7e7c1336,0x6d5c00e9}},	//   _мушт, veir, tirp, wyra,
   {{0xda03009a,0x6d5c1337,0x1d0a1338,0x78a21339}},	//   _लागत_, tyra, леги_, zlov,
   {{0x7c240bb0,0x78a2133a,0x3ce300b8,0x00000000}},	//   teir, ylov, टीले_, --,
   {{0x3fe6052c,0x673b0103,0x00000000,0x00000000}},	//   _ужив, _oruj, --, --,
   {{0x7c24133b,0x387d001e,0x64aa00b8,0x00000000}},	// [c20] reir, diwr_, _přiz, --,
   {{0x7c24133c,0x09e80083,0x00000000,0x00000000}},	//   seir, _পাহা, --, --,
   {{0x7d1e133d,0x78a20d5c,0x4424133e,0xed5a12e3}},	//   _upps, tlov, yem_, _сон_,
   {{0x4424133f,0x673b1340,0x16050006,0xb4c1052f}},	//   xem_, _bruj, _राउर_, ंदो_,
   {{0x44241341,0x78a21342,0x7bc6011e,0x673b0453}},	//   vem_, rlov, _igku, _cruj,
   {{0x78a20a0b,0x4424004e,0xd9460368,0x13e00b35}},	//   slov, wem_, _леги, नर्भ,
   {{0x26091343,0x7bc6011e,0x9ac3003c,0x00000000}},	//   _सारी_, _kgku, ċċes, --,
   {{0x44241344,0xddc500fe,0x00000000,0x00000000}},	//   uem_, _dohř, --, --,
   {{0xe73703ad,0x673b1345,0x53341346,0x66e31347}},	//   _лет_, _gruj, цепт, _нота,
   {{0x44241348,0x3d190755,0x6f061349,0x929d0067}},	//   sem_, _पहले_, dukc, tuła,
   {{0x4424134a,0x3a370122,0x1a9b02b5,0x753a01a3}},	//   pem_, זרים_, רייע, _urtz,
   {{0x5edd0083,0xc95300a5,0x9f4b000d,0x44240031}},	//   _বিবে, למת_, lacé_, qem_,
   {{0xa3bc134b,0xafdb03d0,0x987b016b,0xa3ac01c0}},	//   _आणि_, fjør, ראכט, _गरि_,
   {{0x63a2134c,0xafdb01e0,0x9f4001f7,0x92a40067}},	//   _iyon, gjør, _deià_, ółdz,
   {{0x865b134d,0xdd3a00af,0x00000000,0x00000000}},	//   נדלי, văţa, --, --,
   {{0x63a20273,0x4fc7002d,0x3a3100ee,0x00000000}},	//   _kyon, _уска, _sazp_, --,
   {{0xafdb082b,0x6288134e,0x26090914,0x61ea0093}},	// [c30] bjør, ondo, _साली_, _kefl,
   {{0x80db0083,0xa9c7005f,0xe9ab00f8,0x00000000}},	//   _ভিত্, ссак, هدان_, --,
   {{0x63a2134f,0x99d40079,0x628801bf,0x09e80033}},	//   _lyon, ستلا, indo, _পাশা,
   {{0x629a1350,0xf7700a86,0x27e91351,0x6e271352}},	//   hoto, کام_, úan_, lejb,
   {{0x387d00e9,0x65c51353,0xd9e80033,0x9f4b00a2}},	//   riwr_, обла, _পারম, facé_,
   {{0xe6180210,0x34b305e7,0xddc50355,0x62880223}},	//   йді_, ुद्द, _pohř, jndo,
   {{0x63a2018e,0xdffb0066,0x69c702ce,0x00000000}},	//   _ayon, ्लाद_, _igje, --,
   {{0x673b1354,0x63a209d6,0xe4591355,0x06d80083}},	//   _truj, _byon, ржи_, _সিরি,
   {{0x60ca01ae,0x27ef008d,0x63a201d5,0x6e2700ac}},	//   _aufm, magn_, _cyon, kejb,
   {{0x629a1356,0x63a2021e,0x60d80176,0x7d070055}},	//   goto, _dyon, _btvm, kujs,
   {{0x60261357,0x63a21358,0xdddc010b,0x00000000}},	//   одна, _eyon, sirū, --,
   {{0x27ef0f20,0x628807e5,0x504603fa,0xe45f00ab}},	//   nagn_, ando, цемб, ööd_,
   {{0x63a201a8,0x00000000,0x00000000,0x00000000}},	//   _gyon, --, --, --,
   {{0x6f061359,0x2bbf0930,0xfbbf112b,0x61ea135a}},	//   rukc, ्शना, ्शनम, _gefl,
   {{0xed570390,0x2c6700be,0x09e80033,0x8c7a02fb}},	//   оор_, _sõda_, _পালা, ащат_,
   {{0x69c700da,0x69d501e4,0xc5f30033,0x8c43135b}},	//   _agje, _afze, চ্চা_, месе,
   {{0x2ea700b5,0x20e700b5,0x00000000,0x00000000}},	// [c40] _ڈپٹی_, lői_, --, --,
   {{0x752100d5,0x89f5010b,0x00000000,0x00000000}},	//   _oplz, зяцц, --, --,
   {{0x38cb0a86,0x2901012f,0x60c4135c,0xc7c60a80}},	//   لانی_, grha_, _kiim, осли,
   {{0xdca6135d,0x69da0fd1,0x629a0054,0x186a0370}},	//   _фами, _प्री, zoto, јади_,
   {{0x41c9114e,0xf1c9135e,0x629a000e,0xc5f30083}},	//   रशास, रशान, yoto, চ্ছা_,
   {{0x473302ce,0x7c3603c1,0x60c4135f,0x63a204c6}},	//   ьніс, ldyr, _liim, _ryon,
   {{0x629a05ed,0x00000000,0x00000000,0x00000000}},	//   voto, --, --, --,
   {{0x69c701d2,0x7c361360,0x60c41361,0x6d4e01f7}},	//   _zgje, ndyr, _niim, ixba,
   {{0x629a00a7,0x2451007e,0x00000000,0x00000000}},	//   toto, _jámy_, --, --,
   {{0xd25a1362,0x62880183,0x245100ac,0x60c400f6}},	//   рци_, undo, _mámy_, _aiim,
   {{0x6288038d,0xfc3f00e2,0x5bb70099,0x00000000}},	//   rndo, _khít_, _अण्व, --,
   {{0x63a20159,0x7ea001ff,0x629a1363,0x6a60008d}},	//   _tyon, köps, soto, _döfi,
   {{0x60c40ce8,0x629a1364,0x63a2011e,0x628f000d}},	//   _diim, poto, _uyon, écoc,
   {{0x5edd0083,0xf8ca018d,0x271e00ec,0x69da1365}},	//   _বিদে, िदाय, mānā_, _प्ली,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c40008,0x00000000,0x00000000,0x00000000}},	//   _giim, --, --, --,
   {{0x3f8c01c2,0x27ef1366,0x00000000,0x00000000}},	// [c50] şdur_, vagn_, --, --,
   {{0x3cfe1367,0x24510097,0x0b8801e0,0xea0000e2}},	//   štva_, _dámy_, істи_, _đản_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8f3065a,0xa3dc021a,0x2901012f,0xfc3f0023}},	//   _हं_, तुम_, rrha_, _chít_,
   {{0x49070035,0x87270037,0x69c70044,0xf72b00af}},	//   _हमको_, تعام, _tgje, рцей_,
   {{0xb9010033,0xd6291368,0x69c70185,0x00000000}},	//   _দি_, соке_, _ugje, --,
   {{0x22491369,0x2fc90159,0xb06600c3,0x00000000}},	//   _đak_, _ogag_, nsää, --,
   {{0x2fc90008,0x26c901ef,0x00000000,0x00000000}},	//   _ngag_, íaos_, --, --,
   {{0xeda8000c,0x3b09022e,0x66f4136a,0x60c4136b}},	//   _गर्छ, nuaq_, _опту, _riim,
   {{0x27ed02e6,0xcb120397,0x2fc90260,0x20e700b5}},	//   _heen_, עלי_, _agag_, tői_,
   {{0xa0a6136c,0x60c400ab,0x27ed0f00,0x2d840225}},	//   занд, _piim, _keen_, şmez_,
   {{0x26c50657,0xc4d20122,0x248902d7,0x27ed0051}},	//   _hilo_, _נגד_, _ñam_, _jeen_,
   {{0x60c4136d,0x27ed136e,0x00000000,0x00000000}},	//   _viim, _meen_, --, --,
   {{0x27ed136f,0xd35602b8,0x64591370,0x6fec0033}},	//   _leen_, _מיני_, _howi, কলেও_,
   {{0x64591371,0x2fcd0627,0x60c402e2,0x7c360d51}},	//   _kowi, žega_, _tiim, tdyr,
   {{0x62811372,0x27ed02a2,0xd0fa0070,0xa2c300e7}},	//   lilo, _neen_, _פּור, रदक्,
   {{0x64590067,0x2d85000d,0x201204fb,0x26c50065}},	// [c60] _mowi, ûler_, _icyi_, _oilo_,
   {{0x62810012,0xee3700af,0x6a600282,0x00000000}},	//   nilo, _ень_, _löfv, --,
   {{0x27ed0052,0x2f16054e,0x7c3603d0,0x3e5b024b}},	//   _been_, læg_, pdyr, _הדיס,
   {{0x62811373,0xc18c02b5,0x64591374,0x00000000}},	//   hilo, סטאָ, _nowi, --,
   {{0x62811375,0x26c51376,0xb8f30084,0x163403fe}},	//   kilo, _bilo_, _हू_, деля,
   {{0x6b89064b,0x98ac04d4,0x26c5022f,0x62811377}},	//   _þega, ılır_, _cilo_, jilo,
   {{0x349401c8,0x62811378,0x64591379,0x26c5137a}},	//   макр, dilo, _bowi, _dilo_,
   {{0x27ed137b,0xc955010b,0x18a3137c,0x00000000}},	//   _geen_, _ўтры, _засм, --,
   {{0x26c5137d,0x6459004e,0x3866137e,0x00000000}},	//   _filo_, _dowi, mkor_, --,
   {{0xa3dc02e4,0x628100af,0x25a51281,0x26c500e0}},	//   _त्र_, gilo, _fyll_, _gilo_,
   {{0x7648137f,0xfc3f0037,0xecbe02b4,0x2ee90359}},	//   _indy, _mhír_, ्दाफ, _swaf_,
   {{0xa3e608a9,0x38661380,0x7af600c3,0x7e7e02ee}},	//   _बजट_, nkor_, ksyt, _ampp,
   {{0x6a6000fb,0x5334029f,0xd04200a8,0x765a1381}},	//   _höfu, _целт, nqlə, _koty,
   {{0x6281002d,0x644700ea,0x64591136,0x00000000}},	//   cilo, ējie, _zowi, --,
   {{0x38661382,0x765a1383,0xe80d0084,0x645901cb}},	//   kkor_, _moty, _हाला_, _yowi,
   {{0xea000023,0x9f4b0e06,0x765a1384,0x4fc71385}},	//   _đạn_, lací_, _loty, _эска,
   {{0x27ed03bc,0x5a351386,0xb0660086,0x38661387}},	// [c70] _reen_, мнат, ssää, dkor_,
   {{0x32d20019,0x27ed0122,0x765a1388,0x9f4b0355}},	//   _mây_, _seen_, _noty, nací_,
   {{0x80a40148,0x26c5011e,0x32d20023,0x6dc30024}},	//   _زمین, _rilo_, _lây_, _qċaċ,
   {{0x38661389,0x6281138a,0x26c5138b,0x2c0900d1}},	//   gkor_, zilo, _silo_, _بعدی_,
   {{0xcc560d85,0x27ed0223,0x26c5138c,0x9f4b00b8}},	//   _חברי_, _veen_, _pilo_, kací_,
   {{0xe5a5135d,0x2ca9138d,0x6459138e,0x27ed138f}},	//   мили, llad_, _sowi, _ween_,
   {{0x64590755,0x765a12ad,0x62811390,0x27ed1391}},	//   _powi, _doty, vilo, _teen_,
   {{0x3866022a,0x61e40200,0x32d201a5,0x76481392}},	//   ckor_, _đila, _bây_, _endy,
   {{0x62811393,0x32d20028,0x2ca9001e,0x26c51394}},	//   tilo, _cây_, ilad_, _tilo_,
   {{0x32d201a5,0x2ca91395,0x00000000,0x00000000}},	//   _dây_, hlad_, --, --,
   {{0x628109eb,0x2ca91396,0x356b0384,0xd5671397}},	//   rilo, klad_, _уран_, _этап,
   {{0x62811398,0x62790187,0x1de60b54,0xd59a00a5}},	//   silo, jňov, कर्ष_, _ובעל,
   {{0x32d201a5,0x62790187,0x248d1399,0xd3d80037}},	//   _gây_, dňov, mnem_, _ربنا_,
   {{0x5edd00c8,0x7cd500d8,0x248d139a,0x249f139b}},	//   _বিশে, _sąra, lnem_, loum_,
   {{0x248d01f7,0x6da30896,0x2ca907df,0x386d139c}},	//   onem_, вира, flad_, _oler_,
   {{0x3cfe139d,0x248d139e,0x2ca9139f,0x4e1f13a0}},	//   štvo_, nnem_, glad_, म्बई_,
   {{0x32d20028,0xa5a400c0,0xdca313a1,0x3ced0254}},	// [c80] _xây_, _चुनौ, тати, ćeva_,
   {{0x2bde0d00,0x248d13a2,0x386d01f7,0x7af60035}},	//   _फ्रा, hnem_, _aler_, rsyt,
   {{0x248d13a3,0x2ca913a4,0x386d13a5,0x9f4200a0}},	//   knem_, blad_, _bler_, jakú_,
   {{0x20d301a5,0x315602b5,0x249f00d7,0x9f4b00b8}},	//   _mãi_, ויען_, joum_, zací_,
   {{0x248d13a6,0x20d30019,0x386613a7,0xfc3f0079}},	//   dnem_, _lãi_, rkor_, _thír_,
   {{0x386613a8,0xa3c10f8a,0xd04200a8,0x00000000}},	//   skor_, ंधन_, rqlə, --,
   {{0x386d06d7,0xceb300c2,0x9f4b031b,0x656300e9}},	//   _fler_, דיג_, vací_, gynh,
   {{0x248d13a9,0x38b50307,0x628f000d,0x68430f88}},	//   gnem_, gård_, écon, _инса,
   {{0x27e613aa,0xd626004f,0x41c913ab,0x3a3813ac}},	//   mbon_, _يعطي, रशंस, _karp_,
   {{0x20d30019,0x518613ad,0x27e601d7,0x2ca013ae}},	//   _bãi_, дума, lbon_, hoid_,
   {{0x2ca0012f,0x20d30023,0x248d13af,0x9f4b00b8}},	//   koid_, _cãi_, bnem_, rací_,
   {{0x27e613b0,0x32d20028,0x248d13b1,0x2bde111a}},	//   nbon_, _tây_, cnem_, _फ्ला,
   {{0x80ca009a,0x44fa00ea,0x6279031d,0x200500c1}},	//   _संके, lī_, vňov, ğli_,
   {{0x2ca9016e,0x200504d4,0x8d6b0370,0x91f2046c}},	//   wlad_, şli_, ојба_, _आजिज_,
   {{0x44fa0228,0x62790bca,0x20d300cc,0x27e60223}},	//   nī_, tňov, _gãi_, kbon_,
   {{0x8af00669,0xfc3f0023,0xa3b50066,0x2ca00553}},	//   yyət, _chíp_, छेक_, goid_,
   {{0x7b180086,0x29180484,0x2d9e13b2,0x2ca913b3}},	// [c90] мотр_, _aqra_, üter_, rlad_,
   {{0xd5a400f5,0x248d13b4,0x2ca0009e,0x62790097}},	//   _نہ_, znem_, aoid_, sňov,
   {{0x62790187,0x249f13b5,0x386d13b6,0x00000000}},	//   pňov, youm_, _pler_, --,
   {{0x59df111b,0x00000000,0x00000000,0x00000000}},	//   _प्रर, --, --, --,
   {{0xf62511ca,0x7c2d13b7,0x248d02c6,0x38b5013c}},	//   едло, mear, vnem_, vård_,
   {{0xb0cf09b1,0x8cb90534,0xe61000a8,0xb05b13b8}},	//   _संलग, ्दको, rüşə, lmäd,
   {{0xe5a200d4,0x248d13b9,0x64a513ba,0x27e610a7}},	//   лиши, tnem_, нака, bbon_,
   {{0x7c2d13bb,0x387f1034,0x20d30023,0x27e600e2}},	//   near, _umur_, _rãi_, cbon_,
   {{0x248d13bc,0x249f0282,0x27ff008c,0x00000000}},	//   rnem_, roum_, _idun_, --,
   {{0x7c2d009c,0x248d13bd,0x00000000,0x00000000}},	//   hear, snem_, --, --,
   {{0x248d13be,0x7c2d01a3,0x00861159,0x2c0f08b0}},	//   pnem_, kear, елно, िलां_,
   {{0x20d30023,0x7c2d13bf,0x38be00fe,0x00000000}},	//   _vãi_, jear, _fůru_, --,
   {{0x7c2d13c0,0x270d00a1,0xf8b2016b,0x00000000}},	//   dear, _समोर_, טשט_, --,
   {{0x442d13c1,0x82350220,0x00000000,0x00000000}},	//   lee_, _سرتا, --, --,
   {{0x261713c2,0x8af00095,0x7c2d13c3,0x27ff10b1}},	//   _नानी_, yyəs, fear, _odun_,
   {{0x442d13c4,0x7c2d13c5,0xdca600b6,0x3a380381}},	//   nee_, gear, хаби, _sarp_,
   {{0x2ca013c6,0xdb1c00a8,0xac0700d8,0xab2713c7}},	// [ca0] roid_, _özüm, энта_, нота_,
   {{0x442d13c8,0x27ff13c9,0x7f44009e,0x00000000}},	//   hee_, _adun_, _iriq, --,
   {{0x442d13ca,0x7c2d13cb,0x644b13cc,0x27e00c22}},	//   kee_, bear, _ongi, ñino_,
   {{0x7c2d13cd,0xb05b0553,0x6e2e13ce,0x00000000}},	//   cear, rmäg, lebb, --,
   {{0xdd8f13cf,0x3a3800d8,0x7d0e13d0,0xb5fc0024}},	//   _نوی_, _tarp_, lubs, _joġg,
   {{0x644b13d1,0x7ae413d2,0x44fa0228,0xe45f00c3}},	//   _angi, mpit, tī_, öön_,
   {{0x7ae413d3,0x2b4013d4,0x69dc13d5,0x7d0e13d6}},	//   lpit, lvic_, _ifre, nubs,
   {{0x442d0626,0x7ae40054,0x6e2e13d7,0x44fa0228}},	//   gee_, opit, hebb, rī_,
   {{0x7ae413d8,0x760a00af,0x96ba0841,0x00000000}},	//   npit, _неаг_, _فائز_, --,
   {{0x644b13d9,0xda100632,0x7c2d06a2,0x75d60037}},	//   _engi, ालित_, zear, _أيضا,
   {{0xd48f0de3,0x7f440183,0x7c2d108c,0x06d80831}},	//   _бр_, _ariq, year, _সিটি,
   {{0x442d13da,0x7f4413db,0x7c2d01a3,0xf99300a5}},	//   cee_, _briq, xear, טרת_,
   {{0x69dc09ab,0x7c2d13dc,0x7f4413dd,0x00000000}},	//   _ofre, vear, _criq, --,
   {{0x7c2d0069,0x6e2e00b5,0x78a2018d,0xa3dc13de}},	//   wear, gebb, hoov, तुर_,
   {{0x30a713df,0x7c2d13e0,0xdd9400c7,0x3ced011c}},	//   _прив, tear, гары, ćevo_,
   {{0x69dc13e1,0xa01b01ff,0x00000000,0x00000000}},	//   _afre, rnös, --, --,
   {{0x7c2d13e2,0xddc501ba,0x7ae41292,0x7a3900af}},	// [cb0] rear, _dlhš, gpit, мпар_,
   {{0x7c2d13e3,0x442d13e4,0x6f0f0036,0x6f1d02b1}},	//   sear, zee_, mucc, mtsc,
   {{0x6f0f13e5,0x7c2d13e6,0x6f1d033b,0x442d13e7}},	//   lucc, pear, ltsc, yee_,
   {{0x442d13e8,0xdddc00d8,0x69dc0107,0x6d4513e9}},	//   xee_, mirš, _efre, _irha,
   {{0xd3660118,0x6f1d13ea,0x442d13eb,0x6f0f027a}},	//   _ئه_, ntsc, vee_, nucc,
   {{0x442d13ec,0x6d4a004f,0x6f1d033b,0x79e700fd}},	//   wee_, _áfac, itsc, _سورہ_,
   {{0x442d13ed,0x6f1d13ee,0x644b13ef,0xc44700b5}},	//   tee_, htsc, _pngi, ٹیشن_,
   {{0x6d4500ee,0x00000000,0x00000000,0x00000000}},	//   _mrha, --, --, --,
   {{0x2ba713f0,0x36d502ce,0x442d13f1,0x9f4b0453}},	//   _कुमा, _розр, ree_, yacá_,
   {{0x6f0f13f2,0x442d13f3,0xcb1402b5,0x6d450225}},	//   ducc, see_, אלץ_, _orha,
   {{0x442d13f4,0x2000046a,0x6d4501e8,0xd00a13f5}},	//   pee_, _pdii_, _nrha, мене_,
   {{0x6e2e001c,0x644b13f6,0x6f1d10c0,0x261701d1}},	//   webb, _ungi, ftsc, _नाडी_,
   {{0x6d4513f7,0x547a00a5,0x6e2e030d,0xa3a80099}},	//   _arha, _קטנו, tebb, _खुप_,
   {{0xdee313f8,0x00000000,0x00000000,0x00000000}},	//   рори, --, --, --,
   {{0x6e2e0133,0x6da613f9,0x7afd13fa,0x6f1d0120}},	//   rebb, тива, _avst, atsc,
   {{0x7f44007a,0x69dc13fb,0x6e2e13fc,0x7ae40107}},	//   _triq, _sfre, sebb, tpit,
   {{0x7d0e13fd,0x6b6313fe,0x6d4502c9,0x6f1d0051}},	// [cc0] subs, акта, _erha, ctsc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3a8009a,0x7afd02c4,0x1bea0421,0x63ab13ff}},	//   _खुन_, _evst, _одни_, _lygn,
   {{0xe7861400,0x66e61401,0xa3c10026,0x7ae41402}},	//   куло, вода, ंधा_, ppit,
   {{0x628300a0,0x00000000,0x00000000,0x00000000}},	//   _omno, --, --, --,
   {{0xb7d20083,0x20ee00b8,0x78a200ab,0x09e308ce}},	//   ারেট, yři_, soov, _ворн,
   {{0x6f0f0036,0x91fc00ea,0x00000000,0x00000000}},	//   zucc, skāk, --, --,
   {{0x63ab0c61,0x62830cd4,0x394708c8,0x7434002d}},	//   _bygn, _amno, ænse_, униф,
   {{0x872501b2,0xa7a71403,0x36c600c7,0xc7b000fd}},	//   _معلم, _акта_, _абаг, _اڑا_,
   {{0x63ab013c,0x6fec0033,0xf4870088,0x00000000}},	//   _dygn, _কাগজ_, _یانی, --,
   {{0x60f800d8,0x26171404,0x7c261405,0x00000000}},	//   эння_, _नाती_, _obkr, --,
   {{0x6f0f027a,0xdddc1406,0x6f1d10c0,0x64a3010b}},	//   tucc, virš, ttsc, _каха,
   {{0x44261407,0xd36f0c74,0x6f1d033b,0x2d9a01ed}},	//   _ibo_, _وهم_, utsc, _axpe_,
   {{0x6f0f1408,0x6f1d02bf,0x2c75054e,0x9f5202d0}},	//   rucc, rtsc, _måde_, _meyè_,
   {{0x26cc1409,0x2bc50380,0x6f1d140a,0x4426140b}},	//   _mido_, लेना, stsc, _kbo_,
   {{0x26cc140c,0x6f1d033b,0x6d4500ac,0x628303e0}},	//   _lido_, ptsc, _vrha, _zmno,
   {{0x201e0669,0x09bd01c0,0x4426140d,0x26cc00de}},	// [cd0] əti_, ्ख्य, _mbo_, _oido_,
   {{0x9967140e,0x6288140f,0x26cc1410,0x2ba700a1}},	//   ктел, nido, _nido_, _कुणा,
   {{0x67291411,0x7ac41412,0x49a4015a,0x60cd1413}},	//   _spej, рсте, ајца, _kiam,
   {{0x2c750bf3,0x2458016f,0x44260223,0x9f520107}},	//   _både_, _témy_, _nbo_, _beyè_,
   {{0x60cd1414,0x2617009a,0xb8fa0e04,0xef1f033e}},	//   _miam, _नादी_, _डू_, ntü_,
   {{0x44261415,0x60cd1416,0x98b306d0,0xa3ac00a1}},	//   _abo_, _liam, ıdır_, _गरज_,
   {{0x62881417,0x7c3d1418,0x63ab0035,0x44261419}},	//   dido, _kasr, _sygn, _bbo_,
   {{0x60cd141a,0x26cc01dd,0x9f520260,0x00000000}},	//   _niam, _eido_, _feyè_, --,
   {{0x26cc141b,0x7c3d141c,0x42c9141d,0x2c750b3e}},	//   _fido_, _masr, нгин_, _gåde_,
   {{0x6288141e,0x78a2141f,0x44261420,0xe3b61023}},	//   gido, čove, _ebo_, ыбы_,
   {{0x78bb006d,0x60cd0107,0x64150037,0x1a9c016b}},	//   _khuv, _biam, _مواط, ויזע,
   {{0x7c3d1421,0xdee61422,0x60cd01a6,0x2056002d}},	//   _nasr, ломи, _ciam, утор,
   {{0x62881423,0x443f1424,0x60cd1425,0xb4c10067}},	//   bido, mdu_, _diam, ूदी_,
   {{0x443f1426,0x62881423,0x7c26022e,0x6283011c}},	//   ldu_, cido, _sbkr, _umno,
   {{0x443d1427,0x443f00d8,0x7c960889,0x60cd1428}},	//   _kaw_, odu_, грац, _fiam,
   {{0x60cd1429,0x7c3d0211,0x41df142a,0x443d142b}},	//   _giam, _casr, पुरस, _jaw_,
   {{0x4bd9142c,0x3eba01a5,0x443d001e,0x443f142d}},	// [ce0] ться_, _thpt_, _maw_, idu_,
   {{0x443d0122,0x443f142e,0xfaaa00d1,0x78a9005f}},	//   _law_, hdu_, رهاي_, _akev,
   {{0x9f52142f,0x26cc0359,0x09060810,0x443f00d7}},	//   _seyè_, _rido_, упен, kdu_,
   {{0x26cc1430,0x386000fb,0x443f1431,0x78bb1432}},	//   _sido_, ðir_, jdu_, _chuv,
   {{0x443f1433,0x26cc1434,0x7c241435,0x38cb00e0}},	//   ddu_, _pido_, mfir, رامی_,
   {{0x0f370052,0x443f1436,0x62880391,0x7c241437}},	//   טרנט_, edu_, xido, lfir,
   {{0x62881438,0x443d1439,0xaad8143a,0x00000000}},	//   vido, _baw_, _भूतक, --,
   {{0x443d006f,0xdd0401c8,0x7c24143b,0x2fcd022f}},	//   _caw_, ūrėt, nfir, žegi_,
   {{0x62881423,0x443d143c,0xb274015a,0x60cd009c}},	//   tido, _daw_, илиш, _riam,
   {{0x60cd143d,0x7c240526,0x443f00e9,0x7d01143e}},	//   _siam, hfir, adu_, álsk,
   {{0x60cd143f,0x75d312de,0x443f007a,0x1da40f06}},	//   _piam, _ايما, bdu_, _खुलत,
   {{0xf5370052,0x62881440,0x60cd00d7,0x443d0fde}},	//   _תנאי_, sido, _qiam, _gaw_,
   {{0x9f590055,0x00000000,0x00000000,0x00000000}},	//   masë_, --, --, --,
   {{0x64401441,0x6e3e1442,0xef1f0381,0x35a9073f}},	//   ldmi, _capb, rtü_, _चुड़,
   {{0x60cd1443,0x61fa01c2,0x7c241444,0x7c3d1445}},	//   _tiam, matl, ffir, _pasr,
   {{0x61fa1446,0x64401447,0x443d006d,0xaed50279}},	//   latl, ndmi, _xaw_, _коиш,
   {{0x3b5503fa,0x50b80071,0x999000cb,0x6e9500d4}},	// [cf0] шкар, _حدود_, _čaša_, _випу,
   {{0x443f1061,0x61fa1448,0x78bb028b,0xda780f92}},	//   zdu_, natl, _shuv, лях_,
   {{0x39471449,0x443f144a,0x628f00f7,0x999800fe}},	//   íns_, ydu_, écoi, _darů_,
   {{0x2617134b,0x61fa0acc,0x62980009,0x443f00a8}},	//   _नाही_, hatl, _ljvo, xdu_,
   {{0xe739144b,0x443f144c,0x61fa144d,0x07a50798}},	//   тел_, vdu_, katl, јалн,
   {{0xa509144e,0x61fa023a,0x443d00a5,0x00000000}},	//   века_, jatl, _saw_, --,
   {{0x61fa144f,0x443d1080,0x3e7400ab,0x78bb00cc}},	//   datl, _paw_, _jäta_, _thuv,
   {{0x443f1450,0xc6060083,0x3e7401ff,0xfbb91451}},	//   udu_, ল্লা_, _mäta_, _आराम,
   {{0x443f1452,0xfc3f064b,0xe456004b,0xa3a80c57}},	//   rdu_, _maí_, ржы_, _खुद_,
   {{0xc6a71453,0x61fa006c,0x64401454,0x673b0009}},	//   _срби, gatl, admi, _isuj,
   {{0x443d1455,0x7c240093,0xfba7046c,0x09d30387}},	//   _taw_, yfir, _कुसम, _तलैय,
   {{0x62980009,0x443f035f,0x44f300af,0x10a61456}},	//   _ejvo, qdu_, mţ_, римн,
   {{0x61fa05f9,0x6e3e0345,0x00000000,0x00000000}},	//   batl, _papb, --, --,
   {{0x200c0095,0xfcaa05f5,0x673b034d,0x00000000}},	//   şdi_, چارو_, _msuj, --,
   {{0x82340088,0x44f300af,0x8d631457,0xa3dc0930}},	//   _درنا, nţ_, овре, तुक_,
   {{0xb05b1458,0x61e40009,0xfc3f1459,0x673b00cd}},	//   lmän, _đili, _caí_, _osuj,
   {{0xfc3f0279,0x63880228,0x673b073a,0x00000000}},	// [d00] _daí_, cīnī, _nsuj, --,
   {{0xa3e5145a,0x7c24145b,0x7bdf07e5,0xab27145c}},	//   बुत_, sfir, acqu, рофа_,
   {{0xd00f07e4,0x19b900d8,0x7c2401d5,0x673b145d}},	//   _علی_, гуць_, pfir, _asuj,
   {{0x8c460431,0x61fa145e,0x2ba70387,0xa01b0421}},	//   _теме, zatl, _कुवा, tiöi,
   {{0x61fa06d3,0x27e90083,0xbb4300d4,0xeb97145f}},	//   yatl, ñana_, _деяк, _вия_,
   {{0x3cfe0496,0x2913002a,0xbb4303e6,0x24860b88}},	//   štvu_, buxa_, _ќерк, _smom_,
   {{0x26170299,0xd49a1460,0x5e57016b,0x00000000}},	//   _नारी_, кри_, ייסע_, --,
   {{0x98a300d4,0x18671461,0x2c750523,0x00000000}},	//   _дисе, _каси_, _kåda_, --,
   {{0x61fa1462,0xc17800d8,0x3ced011c,0x66e31463}},	//   tatl, ybės_, ćevi_, _мота,
   {{0x09ca0083,0x67221464,0x44240107,0x00000000}},	//   _ল্যা, mtoj, sfm_, --,
   {{0x61fa1465,0x705500b2,0x272002d0,0x67221466}},	//   ratl, مندا, lòn_, ltoj,
   {{0x672200d8,0x2486040b,0x61fa1465,0x44320023}},	//   otoj, _umom_, satl, _úy_,
   {{0x67221467,0x61fa1468,0xfc3f021d,0x00000000}},	//   ntoj, patl, _raí_, --,
   {{0xea0000e8,0x61fa00a8,0x7ae9027d,0xfc3f0132}},	//   _đến_, qatl, _çeti, _saí_,
   {{0xb2bb0122,0xbd680012,0x25fe04bc,0x67221469}},	//   _שמור, арте_, _रजनी_, htoj,
   {{0x6722146a,0x2c75022a,0xdb0f0138,0x5c74146b}},	//   ktoj, _båda_, _azcá, олст,
   {{0x3a7502c4,0x672201f4,0xa9e70037,0x00000000}},	// [d10] блар, jtoj, لثان, --,
   {{0x61f80009,0x6d43146c,0x00000000,0x00000000}},	//   _jevl, _šnau, --, --,
   {{0xdd91146d,0x2ba7000c,0x06e60033,0x61f8146e}},	//   _روح_, _कुरा, _নিষি, _mevl,
   {{0x315700c2,0x20191221,0x272002d0,0x672201f4}},	//   ייבן_, ngsi_, fòn_, ftoj,
   {{0xf7450e88,0xd838005f,0x25b2013b,0x00000000}},	//   село, рэх_, əyli_, --,
   {{0x2ca9146f,0x78a20076,0xbb3a02b5,0x291301ef}},	//   load_, čova, _געשי, puxa_,
   {{0xfbdb009a,0x28f81470,0xd5490088,0x499301cb}},	//   _भलाम, _весь_, البو_, _بیار,
   {{0x673b1471,0x29010054,0x6722006d,0x4adb00ab}},	//   _tsuj, msha_, btoj, _बढाव,
   {{0x29010c6f,0x61f81472,0x9f590118,0x00000000}},	//   lsha_, _bevl, basé_, --,
   {{0x425505d2,0x38bc004f,0x290108c7,0x61f8023a}},	//   стит, ríre_, osha_, _cevl,
   {{0x61f81473,0xa06a1474,0xb05b1475,0x00000000}},	//   _devl, гана_, rmän, --,
   {{0xf99200a5,0x29011476,0xb05b1477,0x00000000}},	//   לרי_, isha_, smän, --,
   {{0x248d0ae0,0x76411478,0x889a0317,0x6fa50067}},	//   miem_, _kaly, רברי, _गुआं,
   {{0x29010118,0x248d0029,0x61f80b0d,0xb05b00c3}},	//   ksha_, liem_, _gevl, lmäl,
   {{0x76411479,0xfce6147a,0x01c50033,0x916800e2}},	//   _maly, собо, _শ্রদ, _tức_,
   {{0x248d147b,0x672200d8,0xb05b013c,0x00000000}},	//   niem_, ytoj, nmäl, --,
   {{0x29010159,0xf1bf00b8,0xd5b10023,0x29070009}},	// [d20] esha_, řád_, _lý_, šnal_,
   {{0x6f040a78,0x248d147c,0x29010031,0xb05b147d}},	//   _ivic, hiem_, fsha_, hmäl,
   {{0xfe370052,0x248d147e,0xdca609cc,0xbd46147f}},	//   _פרטי_, kiem_, _гани, _انجي,
   {{0x248d0ae0,0xd7f70009,0x91fc0029,0x69d51480}},	//   jiem_, буш_, nkār, _egze,
   {{0x501b0bed,0x248d0080,0x76411481,0x67221482}},	//   רונו, diem_, _baly, utoj,
   {{0x67221483,0x1ae3001f,0x7c361484,0x00000000}},	//   rtoj, _хорм, leyr, --,
   {{0x67220690,0x76410a93,0x9f591485,0x6f0400fe}},	//   stoj, _daly, rasé_, _lvic,
   {{0x248d1486,0x672200da,0xb1760019,0x2bc50a44}},	//   giem_, ptoj, _ngượ, लेवा,
   {{0xa3a80953,0x00000000,0x00000000,0x00000000}},	//   _खुश_, --, --, --,
   {{0x76411487,0xda7b0070,0x066500f8,0x00000000}},	//   _galy, ָנטר, _والپ, --,
   {{0xd0110bdf,0x248d1488,0x69c100ac,0x959a002d}},	//   ولد_, biem_, _úlet, _стау_,
   {{0x248d1489,0x76410103,0x00000000,0x00000000}},	//   ciem_, _zaly, --, --,
   {{0x5f9402fb,0x6f04148a,0x3e970037,0x9f4001ed}},	//   зият, _cvic, مؤسس, _beiñ_,
   {{0xfbbe00dc,0x29010159,0x64420315,0x2bbe00e7}},	//   ्धनम, ysha_, _haoi, ्धना,
   {{0x90e605bc,0x628a02d7,0x7c360093,0x6e3500f4}},	//   _استن, _imfo, feyr, rezb,
   {{0x7f950409,0x00000000,0x00000000,0x00000000}},	//   _майх, --, --, --,
   {{0x6442148b,0x5eb80083,0xd9f9075a,0x9b950421}},	// [d30] _maoi, _ইংরে, инац_, циац,
   {{0x7f4d0095,0x2901148c,0x644209c3,0x248d148d}},	//   _iraq, tsha_, _laoi, ziem_,
   {{0x6f0401f4,0x27e9148e,0xa01b008d,0xdb060097}},	//   _zvic, ñano_, rhöf, _vyká,
   {{0x6d400080,0x764100e0,0xdb0f0248,0x6442148f}},	//   āmat, _saly, _lycé, _naoi,
   {{0x248d1490,0xa3a80299,0x764100d8,0x29011491}},	//   viem_, _खुल_, _paly, ssha_,
   {{0xf1c8051e,0x248d004e,0x00000000,0x00000000}},	//   रधान, wiem_, --, --,
   {{0x248d0080,0x9f40008a,0x76411492,0xf5560037}},	//   tiem_, _leið_, _valy, قلوب_,
   {{0x13091493,0x644202a8,0x7b08008a,0x2b4900cd}},	//   аний_, _caoi, _ástæ, ovac_,
   {{0x6442003b,0x76411494,0x248d1490,0x7aed1495}},	//   _daoi, _taly, riem_, npat,
   {{0x248d0029,0x7aed1496,0x20090054,0x2f100093}},	//   siem_, ipat, _adai_, _lögð_,
   {{0x6442006e,0x7f4d1497,0x645d01ae,0x6d5c0069}},	//   _faoi, _araq, ösis, xxra,
   {{0x43750fbb,0x644209bb,0xf485006c,0x9fca0265}},	//   _мулт, _gaoi, _بائی, игна_,
   {{0xaad8009a,0xe28e00d8,0x7f4d1498,0x083a0070}},	//   _भूंक, _жа_, _craq, בערל,
   {{0x7f4d027a,0x7aed0af9,0x91fc0228,0xc5f9016b}},	//   _draq, dpat, skār, יפֿט,
   {{0xa3c102e4,0xa01b00a6,0x9d431499,0x00000000}},	//   ंधक_, giös, мерд, --,
   {{0x7f4d149a,0x6f040260,0x00000000,0x00000000}},	//   _fraq, _tvic, --, --,
   {{0x7aed149b,0x7c36008a,0x8eba002d,0x6f040176}},	// [d40] gpat, reyr, _вынт_, _uvic,
   {{0xf2210324,0xf992149c,0xa2da0067,0x25a00225}},	//   _माफ़_, وبا_, नदत्, şili_,
   {{0x64970029,0xed5a13c7,0x6ee50919,0x05a907b5}},	//   rģij, _тон_, _وسیل, _चुलब,
   {{0x7aed149d,0xcfad0033,0xd7ef0037,0xae2000ab}},	//   bpat, _গণতন, نكم_, _बाडन_,
   {{0xa6ca02c4,0x644200f1,0x8af0013b,0x00000000}},	//   алда_, _raoi, yyəy, --,
   {{0x6442009c,0x6b63010b,0x00000000,0x00000000}},	//   _saoi, _ўкра, --, --,
   {{0xd8390107,0x385a149e,0x6923031a,0x92e60033}},	//   _djōb_, _краю_, _омра, _বটে_,
   {{0xa3e50d4e,0xe81405a6,0x00000000,0x00000000}},	//   बुल_, _डाटा_, --, --,
   {{0x533400af,0x00000000,0x00000000,0x00000000}},	//   чепт, --, --, --,
   {{0x3f82042f,0x026a00d4,0x00000000,0x00000000}},	//   dzku_, рший_, --, --,
   {{0x2ee9149f,0x3a370122,0x644214a0,0x8cd60067}},	//   _staf_, חרים_, _taoi, _मंगो,
   {{0x232a14a1,0x7aed005f,0xb05b0421,0x00000000}},	//   _води_, ypat, mmäk, --,
   {{0xe29a0202,0xb05b0421,0xe7ca06fe,0x00000000}},	//   _кад_, lmäk, िधिप, --,
   {{0x29070332,0x63a201ed,0x9f5b0055,0x00000000}},	//   ának_, _ixon, _heqë_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa01b14a2,0x7f4d14a3,0xe57102b5,0x69d8010b}},	//   riös, _traq, ײַל_, žvel,
   {{0x3a750009,0xda67026e,0x9f5b0031,0x6d4801ff}},	// [d50] плар, يائي, _meqë_, ådar,
   {{0x68e30391,0x00000000,0x00000000,0x00000000}},	//   índo, --, --, --,
   {{0x05a902e4,0x629a00c3,0xa3ca00a1,0x7aed14a4}},	//   _चुंब, into, ळेत_, spat,
   {{0x7aed14a5,0x6d5814a6,0x7c590079,0x38be06fe}},	//   ppat, _švag, _الحر_, _kůry_,
   {{0xfc5a00a5,0x00000000,0x00000000,0x00000000}},	//   _הכרמ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d830035,0x26c7080a,0x00000000,0x00000000}},	//   nzje_, rmno_, --, --,
   {{0x629a14a7,0x00000000,0x00000000,0x00000000}},	//   ento, --, --, --,
   {{0xf77308cf,0x3834093e,0x00000000,0x00000000}},	//   _غار_, _інфр, --, --,
   {{0x629a008c,0xaabd112b,0x2bbe06fe,0xb05b0a48}},	//   gnto, ्गिक, ्धता, lmäh,
   {{0x27e002dd,0x85050a86,0x63a214a8,0x91fc0029}},	//   žine_, _روشن, _exon, rkāp,
   {{0x8fa614a9,0x55ba00a5,0x61ee00a8,0xb05b02b1}},	//   заме, _המעו, ıbla, nmäh,
   {{0xc3190083,0x442f14aa,0x09b801c0,0x52750009}},	//   _তৈরি_, _ibg_, _अर्य, _нуку,
   {{0x68e901a0,0x442f0282,0x00000000,0x00000000}},	//   _čedn, _hbg_, --, --,
   {{0x670214ab,0xdd9214ac,0xddc507c0,0x00000000}},	//   _रौनक_, رور_, _jahň, --,
   {{0x442f025c,0xaf060525,0x00000000,0x00000000}},	//   _jbg_, _епил, --, --,
   {{0x3aeb0332,0x200214ad,0x60c414ae,0x207b0070}},	// [d60] مبلی_, maki_, _ihim, _לאקא,
   {{0x200214af,0x442f0009,0xdb060035,0xa6e90023}},	//   laki_, _lbg_, _szkó, _khươ,
   {{0xceb314b0,0x4ddb00a5,0x442f0183,0x8d760934}},	//   _איז_, _לחיו, _obg_, _رادا,
   {{0x38cb03c5,0xdca611d0,0xda1e00ab,0x442f14b1}},	//   مانی_, _хами, _पावत_, _nbg_,
   {{0x629a0090,0xfbb900b4,0x60c414b2,0x00000000}},	//   ynto, _आरएम, _mhim, --,
   {{0x200214b3,0xd6d900d4,0x6b840009,0x81bc0831}},	//   haki_, іті_, mzig, _অলস_,
   {{0xe9a314b4,0x442f14b5,0x00000000,0x00000000}},	//   _зарп, _bbg_, --, --,
   {{0x399b0122,0x200214b6,0x2bc30066,0x291a08dd}},	//   _הילד, jaki_, _शरमा, mupa_,
   {{0x20020723,0x291a14b7,0x6b8414b8,0x98a3002d}},	//   daki_, lupa_, nzig, _чите,
   {{0x2a6a14b9,0xb05b03ad,0x877b0397,0x629a14ba}},	//   _jobb_, mmäi, _האמי, unto,
   {{0x2bb90567,0xa6e90028,0x249700bf,0x60c40118}},	//   _आर्थ, _chươ, _کنند_, _bhim,
   {{0x27e614bb,0x60c414bc,0x442f017b,0xfbbe142a}},	//   ncon_, _chim, _gbg_, ्धाम,
   {{0x60c400da,0x6b8404ce,0x291a010d,0xeaae0009}},	//   _dhim, jzig, hupa_, koй_,
   {{0x291a14bd,0xd35700a5,0xf1e00835,0x00000000}},	//   kupa_, _מידי_, _नलिन, --,
   {{0x200214be,0x27e600d7,0x68e914bf,0x78a20506}},	//   baki_, kcon_, _čedo, čovj,
   {{0x30a401c8,0x60c414c0,0x60d60225,0x00000000}},	//   _прыв, _ghim, _giym, --,
   {{0x3f9e01d6,0x7c2f14c1,0x00000000,0x00000000}},	// [d70] ştur_, _vbcr, --, --,
   {{0x291a002f,0x6d410093,0x1ab4002d,0x00000000}},	//   fupa_, ælas, ебуя, --,
   {{0x290701c0,0x27e60bf0,0x291a010d,0x8cd60067}},	//   éna_, fcon_, gupa_, _मंचो,
   {{0x3869064b,0x6a73033e,0x00000000,0x00000000}},	//   ðar_, _sıfı, --, --,
   {{0x7c2d14c2,0x649700af,0xf72b010b,0x28d9021a}},	//   mfar, nţie, сцей_, _बंकि,
   {{0x200214c3,0x442f14c4,0x7c2d14c5,0x00000000}},	//   zaki_, _sbg_, lfar, --,
   {{0xa93414c6,0x200214c7,0x291a14c8,0xe1ab073f}},	//   _перш, yaki_, cupa_, _घुंघ,
   {{0x7c2d14c9,0x20020132,0x00000000,0x00000000}},	//   nfar, xaki_, --, --,
   {{0x20020a2c,0x7c2d14ca,0x00000000,0x00000000}},	//   vaki_, ifar, --, --,
   {{0xa6e90028,0x60c414cb,0x200214cc,0x00000000}},	//   _phươ, _shim, waki_, --,
   {{0x660314cd,0x200214ce,0x27ff008c,0x60c400cc}},	//   mank, taki_, _keun_, _phim,
   {{0x660314cf,0x60d601c2,0x205614d0,0x27ff00f6}},	//   lank, _qiym, фтор, _jeun_,
   {{0x64490297,0x200214d1,0x645914d2,0x7c2d14d3}},	//   mdei, raki_, _inwi, dfar,
   {{0x200214d4,0x442d02bf,0xa6e900e8,0x660314d5}},	//   saki_, lfe_, _thươ, nank,
   {{0x200214d6,0x60c414d7,0x2a6a14d8,0xed35002d}},	//   paki_, _thim, _robb_, нэтэ,
   {{0x644914d9,0x442d14da,0x6b8414db,0x39940006}},	//   ndei, nfe_, tzig, _तs_,
   {{0x06e30083,0x3e7400ab,0x6d4105ee,0x6497002d}},	// [d80] নীতি, _läti_, ælar, cţie,
   {{0xe9d2026e,0x291a14dc,0x628100e2,0x22470069}},	//   نغا_, tupa_, nhlo, _jank_,
   {{0x660314dd,0x7e7e022e,0x2ee014de,0x224702d0}},	//   dank, _ilpp, _ভবিষ, _mank_,
   {{0x291a14df,0x22470173,0x7d1c14e0,0x39430009}},	//   rupa_, _lank_, murs, _dsjs_,
   {{0x44e302d7,0x073a0789,0x2ee014e1,0x64490090}},	//   _añ_, تساب_, _juif_, ddei,
   {{0x6e3c14e2,0x26c505b9,0x660314e3,0x44fa00ec}},	//   nerb, _chlo_, gank, tū_,
   {{0x442d14e4,0x69dc0bb0,0x26c500d7,0x64490051}},	//   ffe_, _igre, _dhlo_, fdei,
   {{0x3ae4022a,0x6e3c14e5,0x27ff00cc,0x6f0900f4}},	//   _köp_, herb, _geun_, šeci,
   {{0x6e3c14e6,0x224700a5,0x7ae20079,0xb5fc007a}},	//   kerb, _bank_, íoth, _loġi,
   {{0x6e3c0009,0x442d14e7,0x64490015,0x290a0345}},	//   jerb, afe_, adei, _kvba_,
   {{0x224714e8,0x7c2d001e,0x765a14e9,0x018a00c3}},	//   _dank_, yfar, _inty, ющий_,
   {{0x7d1c14ea,0x1c1d14eb,0x386614ec,0x73c60f98}},	//   durs, _फाइल_, njor_, _قيام,
   {{0x69dc14ed,0x6e3c14ee,0x22470009,0x764814ef}},	//   _ogre, ferb, _fank_, _kady,
   {{0x628114f0,0x6e3c14f1,0x69dc14f2,0x224714f3}},	//   chlo, gerb, _ngre, _gank_,
   {{0xc3480019,0xf1aa00d1,0x764814f4,0x7d1c14f5}},	//   _hổ_, _باشه_, _mady, gurs,
   {{0x660314f6,0x69dc14f7,0x6e3c0036,0x2ee00051}},	//   zank, _agre, aerb, _fuif_,
   {{0x3ec714f8,0x4abd0355,0x7c2d14f9,0x765a0b88}},	// [d90] _особ, ्गलव, rfar, _onty,
   {{0x27ff0173,0x68fc001e,0xadf3020d,0x764801cb}},	//   _seun_, _bwrd, _अभिन_, _nady,
   {{0x6f1d14fa,0x481514fb,0x6449001e,0x6e2514fc}},	//   lusc, емес, ydei, _ichb,
   {{0x6d4514fd,0xb8e70299,0x765a14fe,0x660314ff}},	//   _isha, _उठ_, _anty, wank,
   {{0x7648129d,0xc3480019,0x7bdd02b3,0x569512ea}},	//   _bady, _nổ_, _igsu, надт,
   {{0x68fc00e9,0x6459009e,0x00000000,0x00000000}},	//   _fwrd, _snwi, --, --,
   {{0x76481500,0x224700a5,0x68fc00e9,0x27ff0223}},	//   _dady, _rank_, _gwrd, _teun_,
   {{0x93451501,0x61ea1502,0xc34801a5,0x6d45000e}},	//   ение, _affl, _bổ_, _msha,
   {{0x64490434,0xc3480028,0x442d1503,0x66031504}},	//   rdei, _cổ_, rfe_, pank,
   {{0x2729116c,0x66031505,0x764802d0,0x64491506}},	//   mún_, qank, _gady, sdei,
   {{0x6d451507,0x27290037,0x22470160,0x442d1508}},	//   _nsha, lún_, _vank_, pfe_,
   {{0x6e3c02c9,0x386d0453,0xf09f0176,0x6f1d0036}},	//   werb, _joer_, gnà_, fusc,
   {{0x66011509,0x6d4508bd,0x249f008d,0x386d150a}},	//   _kelk, _asha, mnum_, _moer_,
   {{0x7d1c150b,0x6601150c,0x249f0093,0x386d03bc}},	//   turs, _jelk, lnum_, _loer_,
   {{0x387f0d6f,0x320501ba,0x6da3150d,0xed57150e}},	//   _olur_, maly_, гира, нор_,
   {{0x249f00fb,0x6e3c150f,0x6601006c,0x386d1510}},	//   nnum_, serb, _lelk, _noer_,
   {{0x6d4501d5,0x249f0093,0xc3480019,0x69dc1511}},	// [da0] _esha, inum_, _xổ_, _pgre,
   {{0x6d4500da,0x387f1512,0x32051513,0x66011514}},	//   _fsha, _alur_, naly_, _nelk,
   {{0x76481515,0x386d1516,0x249f008a,0xdb060a8a}},	//   _rady, _boer_, knum_, _lykø,
   {{0x76480dc3,0x3ae4008e,0xd7061517,0x32051518}},	//   _sady, _töp_, езди, haly_,
   {{0x272909ab,0x61360332,0x66011519,0x3205151a}},	//   gún_, _külö, _belk, kaly_,
   {{0x6601114d,0xc3480023,0x3205151b,0x69dc0210}},	//   _celk, _rổ_, jaly_, _ugre,
   {{0xc34801a5,0x2ca000ab,0xfaa3151c,0x249f008a}},	//   _sổ_, onid_, _саро, fnum_,
   {{0x249f008a,0x5454151d,0x660100ab,0x2ca000ab}},	//   gnum_, твит, _eelk, nnid_,
   {{0x7648151e,0x6601006c,0xc7a30674,0xfe200084}},	//   _tady, _felk, _битк, _बांस_,
   {{0x2c7c1111,0x2ca00079,0x00000000,0x00000000}},	//   _oído_, hnid_, --, --,
   {{0xb05b022a,0xbbbe018d,0x2b9101ba,0x5a170070}},	//   nläg, ्धुक, môcť_, עקטן_,
   {{0xc3480028,0x6f1d038e,0xbebb01f4,0x399b0070}},	//   _tổ_, tusc, ntëv, לייד,
   {{0x4426151f,0x32051520,0xb05b01ae,0x2c7c02d7}},	//   _ico_, baly_, hläg, _aído_,
   {{0x6f1d1521,0xa01b033b,0x7c261522,0xb05b017b}},	//   rusc, chön, _ackr, kläg,
   {{0xac951523,0x00000000,0x00000000,0x00000000}},	//   вавш, --, --, --,
   {{0x6f1d1524,0xdcb801d3,0x9404013b,0x00000000}},	//   pusc, ещу_, timə_, --,
   {{0x64970043,0x00d800b5,0x44260088,0x92de0033}},	// [db0] nţia, _ثبوت_, _mco_, _তবু_,
   {{0x6d450d4b,0x3b091525,0x24840159,0x6f0d00ee}},	//   _tsha, rsaq_, hhmm_, _ivac,
   {{0x3b09007a,0x6d451526,0x44261527,0x387f1528}},	//   ssaq_, _usha, _oco_, _plur_,
   {{0x442601a9,0x66010086,0x672b0044,0x27291529}},	//   _nco_, _selk, ttgj, tún_,
   {{0xf745152a,0x386d152b,0x66010086,0xb05b152c}},	//   тело, _voer_, _pelk, lmäs,
   {{0x2729152d,0xe9d300f8,0x69351108,0x386d0345}},	//   rún_, _مغز_, _ингу, _woer_,
   {{0x6601152e,0x3205152f,0x386d053e,0x249f0093}},	//   _velk, valy_, _toer_, tnum_,
   {{0x660106ba,0x58d40374,0x3e7402b1,0x387f0031}},	//   _welk, _бост, _hätt_, _ulur_,
   {{0x249f008a,0x32051530,0xd8420355,0x44261531}},	//   rnum_, taly_, áčů_, _dco_,
   {{0x44261532,0x249f1533,0x00000000,0x00000000}},	//   _eco_, snum_, --, --,
   {{0x32051534,0xb05b1535,0x249f0093,0x4e1b00ab}},	//   raly_, kläd, pnum_, _बाड़े_,
   {{0x32051536,0x3e74022a,0x339213cf,0xdee60f6d}},	//   saly_, _lätt_, الیز, коми,
   {{0x443f1537,0x10a31538,0x320500ac,0x6f0d00d5}},	//   meu_, риян, paly_, _cvac,
   {{0x443f1539,0x644b153a,0x6da60f94,0x332d153b}},	//   leu_, _hagi, вига, mtex_,
   {{0x6f0d153c,0x644b0c02,0x27ed02b1,0x817403fc}},	//   _evac, _kagi, _ofen_, _منوچ,
   {{0x443f153d,0x7f86004f,0x6f960037,0x7cdc009e}},	//   neu_, _للبن, _للعض, _cōra,
   {{0x644b153e,0x443f0310,0x7c2b0014,0xb05b153f}},	// [dc0] _magi, ieu_, ògra, rmät,
   {{0x644b1540,0xaa7b0093,0x443f1541,0x9c8502d4}},	//   _lagi, _stýr, heu_, _ančā,
   {{0x6f0d0cc1,0xaa4302ee,0x00000000,0x00000000}},	//   _zvac, рехл, --, --,
   {{0x644b1542,0x63a4008a,0xb05b1543,0x7f5601f4}},	//   _nagi, _þing, rläg, _kryq,
   {{0x443f1544,0x27e01545,0xb05b01ff,0xbebb0031}},	//   deu_, žino_, släg, rtëv,
   {{0x7c24010b,0xddc50c99,0x7bc602c6,0xbebb01f4}},	//   lgir, _hohš, _izku, stëv,
   {{0x92de0b52,0x644b1546,0xc5d500c8,0x443f1547}},	//   _তবে_, _bagi, _স্বপ, feu_,
   {{0x7c241548,0x443f1549,0x38c80148,0x644b027a}},	//   ngir, geu_, _سازی_, _cagi,
   {{0x644b154a,0xf2c6154b,0x66e6126e,0xb05b01ff}},	//   _dagi, ксон, _роза, kmär,
   {{0x78a2154c,0x6f0d022f,0x644b154d,0x649700af}},	//   lnov, _rvac, _eagi, rţia,
   {{0x443f154e,0x6f0d154f,0x6d581550,0x518609a5}},	//   beu_, _svac, _švan, тупа,
   {{0x04460500,0x443f1551,0x78a21552,0x61f500d0}},	//   _једн, ceu_, nnov, ızla,
   {{0x78a200ac,0x6440027d,0x00000000,0x00000000}},	//   inov, memi, --, --,
   {{0x64970043,0x644b1553,0xd13001cb,0x4ea40409}},	//   nţin, _zagi, _همت_, арса,
   {{0x3e7406d7,0x644b0a74,0x7bc601a3,0xac2703e6}},	//   _rätt_, _yagi, _azku, кфак,
   {{0x78a21554,0x64401555,0x3e7406d7,0x6abd1556}},	//   jnov, nemi, _sätt_, ्ग्र,
   {{0x4ea7082a,0x5a3507c1,0xbebb0031,0xb05b01ff}},	// [dd0] _арна, лнат, ftët, smäs,
   {{0x64401557,0x443f0043,0xf8cb0355,0xdce70035}},	//   hemi, zeu_, िष्प, zyję,
   {{0x39151558,0x7bc601d7,0x443f1559,0x6440155a}},	//   умер, _ezku, yeu_, kemi,
   {{0x78a2155b,0x443f0443,0x6440155c,0x648701a3}},	//   gnov, xeu_, jemi, _iñig,
   {{0x644b1530,0x443f155d,0x291a027a,0xd366017e}},	//   _ragi, veu_, arpa_, _اه_,
   {{0x644b155e,0xe5a5155f,0x332d0024,0x00000000}},	//   _sagi, лили, vtex_, --,
   {{0x644b1560,0x443f1561,0x78a20334,0x64401562}},	//   _pagi, teu_, bnov, femi,
   {{0x64401563,0x69c70169,0x332d0484,0x78a21564}},	//   gemi, _izje, ttex_, cnov,
   {{0x443f1565,0x67d4002d,0x91e51566,0xbebb0055}},	//   reu_, _воту, лопе, ntës,
   {{0x443f1567,0x644b1568,0xb6340754,0xd2a600af}},	//   seu_, _wagi, _نعمت, лкые_,
   {{0x644b1569,0x443f156a,0xab5b0332,0xe4e702ce}},	//   _tagi, peu_, _szül, _різн,
   {{0xa3550041,0xbebb0031,0xc879156b,0x644b023c}},	//   _مختص, ktës, _fişe_, _uagi,
   {{0xbebb00da,0x6d5700a8,0x6d4101fb,0x99750067}},	//   jtës, _arxa, çlan, nęła_,
   {{0x78a20169,0xdee3156c,0x539a0319,0x00000000}},	//   znov, сори, _אינו, --,
   {{0x5bbe0ac4,0x6497002d,0x7c24156d,0x78a2156e}},	//   ्ध्व, nţio, tgir, ynov,
   {{0xb05b007c,0xdd8f0037,0xbebb0031,0xa3d700b4}},	//   smär, سوق_, ftës, _ाणा_,
   {{0x78a2156f,0xb05b013c,0x69c7009f,0x2c7503d0}},	// [de0] vnov, pmär, _azje, _rådt_,
   {{0x7c241570,0x64401571,0x2d9e00a2,0x8af0013b}},	//   sgir, zemi, ûtes_, vvəd,
   {{0x64401572,0x7c240392,0x673b1573,0xdce80029}},	//   yemi, pgir, _apuj, ēlēt,
   {{0xe3a701ca,0xd70a1574,0x78a21575,0x644001ed}},	//   _هر_, енде_, unov, xemi,
   {{0xb8eb0e04,0x2bba0037,0x7bc61576,0x00000000}},	//   _री_, _ساحة_, _uzku, --,
   {{0x78a21577,0x09e31578,0x00000000,0x00000000}},	//   snov, _горн, --, --,
   {{0x64400723,0xafdb0c61,0x2bbe1579,0x649700af}},	//   temi, ndør, ्धका, rţin,
   {{0x62830861,0x6497002d,0x78a20187,0x00000000}},	//   _alno, sţin, čovs, --,
   {{0xb5fc0069,0x6d580eac,0x7ae60069,0xf20610a4}},	//   _anġe, _šval, _jukt, ляно,
   {{0x6722010b,0x86c60037,0x64400d19,0x00000000}},	//   muoj, _صيان, semi, --,
   {{0x6440157a,0x27e9068b,0x7ae6157b,0x6497002d}},	//   pemi, žane_, _lukt, cţio,
   {{0xf99302b8,0x6497002d,0x660a008c,0x9f590079}},	//   מרת_, nţil, lafk, masú_,
   {{0x672200d8,0x26de157c,0xf4870416,0x7ae6002f}},	//   nuoj, _kito_, _حالی, _nukt,
   {{0x0cbf157d,0x81d41283,0x660a046a,0xb05b01ae}},	//   ्ष्म, _колх, nafk, fläc,
   {{0x629a157e,0x7ae6157f,0xc27b0070,0x6ca71580}},	//   mito, _aukt, _ארגי, граж,
   {{0x7ae61581,0x26de1582,0x1f751583,0x44ea0019}},	//   _bukt, _lito_, _влия, _mù_,
   {{0x200b1584,0x26de0bc8,0x660a1585,0x60cd1586}},	// [df0] maci_, _oito_, kafk, _iham,
   {{0x44ea1010,0x200b1587,0x26de0269,0x7ae61588}},	//   _où_, laci_, _nito_, _dukt,
   {{0x60cd1589,0x81b60083,0xbebb0031,0x2aa8052a}},	//   _kham, চের_, stës, утто_,
   {{0x200b0d5c,0x8934004f,0x629a158a,0x394a008c}},	//   naci_, إعلا, hito, _dsbs_,
   {{0x629a158b,0x6722010b,0x60cd158c,0x26de158d}},	//   kito, guoj, _mham, _bito_,
   {{0x629a158e,0x44ea0019,0x870400c3,0x26de158f}},	//   jito, _bù_, сяце, _cito_,
   {{0x26de0269,0x44ea1590,0x200b00b8,0x6f1d01ae}},	//   _dito_, _cù_, kaci_, hrsc,
   {{0x200b0936,0x44ea01a5,0x67221591,0x628800c3}},	//   jaci_, _dù_, buoj, ehdo,
   {{0x200b1592,0x6b8d1593,0x26de1594,0x6283024e}},	//   daci_, nzag, _fito_, _plno,
   {{0x65951595,0x68e700da,0x60cd1596,0x26de043c}},	//   _казу, _kujd, _aham, _gito_,
   {{0x76431597,0x6f1d1598,0x4254010b,0x200b1599}},	//   meny, ersc, стыт, faci_,
   {{0x60cd159a,0x200b159b,0x26de08c7,0x7523159c}},	//   _cham, gaci_, _zito_, munz,
   {{0x60cd159d,0xe1ee159e,0xdee6159f,0x22490ebc}},	//   _dham, _мг_, роги, _апли_,
   {{0x628815a0,0x78a9003a,0x764301a8,0x29030051}},	//   chdo, _ljev, neny, _owja_,
   {{0x752315a1,0x78bb09d6,0x200b0a78,0x672200d8}},	//   nunz, _okuv, baci_, zuoj,
   {{0x200b15a2,0x60cd15a3,0x764315a4,0x3ceb00ac}},	//   caci_, _gham, heny, _živí_,
   {{0x764315a5,0x4e1a0086,0xbebb01f4,0x752301d5}},	// [e00] keny, _июня_, rtër, hunz,
   {{0x75230010,0x78a90009,0x2b590a69,0xef1f00b5}},	//   kunz, _ajev, _drsc_, zzük_,
   {{0x2bb80299,0x26de15a6,0xfe3702b5,0x3eb815a7}},	//   _आडवा, _rito_, _דריי_, mort_,
   {{0x26de0133,0x628801d2,0x629a15a8,0x313602b5}},	//   _sito_, zhdo, zito, ינעם_,
   {{0x78a915a9,0x26de15aa,0x87030a2b,0x6497002d}},	//   _djev, _pito_, ояще, rţil,
   {{0x752315ab,0x200b00b8,0x672200d8,0x629a0300}},	//   funz, zaci_, ruoj, xito,
   {{0x629a0690,0x660a15ac,0x3218004e,0x6d5815ad}},	//   vito, rafk, órym_, _švaj,
   {{0x7c3605ee,0x26de0054,0x98a615ae,0x6b9b01f2}},	//   nfyr, _wito_, _тибе, _žugi,
   {{0x629a15af,0x26de15b0,0x60cd15b1,0x320715b2}},	//   tito, _tito_, _rham, _beny_,
   {{0x320715b3,0x60cd15b4,0xab5b0332,0x44ea0019}},	//   _ceny_, _sham, _szük, _tù_,
   {{0x200b15b5,0x68e0037a,0x60cd15b6,0x6b8d027a}},	//   taci_, _kimd, _pham, zzag,
   {{0x859b0122,0x629a15b7,0x6f0401d5,0x757b0070}},	//   _בשבו, sito, _bwic, _שטאפ,
   {{0x200b15b8,0x3eb81229,0xfa110033,0x68e0009f}},	//   raci_, fort_, স্টল_, _mimd,
   {{0x6f1d15b9,0x6608023a,0x61e30103,0x00000000}},	//   rrsc, _jedk, _ggnl, --,
   {{0xa3ea0429,0x60cd15ba,0x200b15bb,0x320c15bc}},	//   _मला_, _tham, paci_, mady_,
   {{0x320c15bd,0x60cd0af0,0x3d180084,0x6b8d01d7}},	//   lady_, _uham, _फिरे_, tzag,
   {{0x24860221,0xa3ca00a1,0x764315be,0xc8790160}},	// [e10] _mlom_, ळेच_, yeny, _nişa_,
   {{0x78a903fd,0x78bb15bf,0x628601f4,0x248601f7}},	//   _sjev, _skuv, ëkoh, _llom_,
   {{0x78a9029d,0x996715c0,0xbebb00da,0x6f0415c1}},	//   _pjev, штал, rrëd, _zwic,
   {{0x320c15c2,0x764315c3,0x660801ed,0x254700fd}},	//   hady_, weny, _aedk, _ről_,
   {{0x78a9025c,0xa01b033b,0x66080298,0x62980fdb}},	//   _vjev, rhöh, _bedk, _omvo,
   {{0x752315c4,0x7bda0122,0x24860d35,0xa01b02b1}},	//   tunz, _תקשו, _alom_, shöh,
   {{0x32070260,0x248615c5,0x764315c6,0x2bdb0099}},	//   _reny_, _blom_, reny, _मृता,
   {{0x764315c7,0x629815c8,0x78bb0010,0x68e000d8}},	//   seny, _amvo, _ukuv, _gimd,
   {{0x752315c9,0x7aed007a,0x764315ca,0x648702d7}},	//   sunz, nqat, peny, _añic,
   {{0xf674004f,0x75230010,0x68e00298,0x320c00ac}},	//   _والخ, punz, _zimd, gady_,
   {{0x555500e0,0xd00a15cb,0xb80b007c,0x248603d0}},	//   _دپار, лене_, _हजाम_, _flom_,
   {{0x3eb802c9,0xb7bd0043,0x200900af,0x00000000}},	//   wort_, _acţi, _ceai_, --,
   {{0x320705f5,0xd12e0148,0x3eb815cc,0x42d500d4}},	//   _teny_, ومی_, tort_, _ліку,
   {{0x201e15cd,0x248615ce,0x2009009e,0xddde0160}},	//   şti_, _zlom_, _eeai_, _copş,
   {{0xb05b017b,0x2d7e011c,0x3eb815cf,0x80f50037}},	//   mlän, _oćeš_, rort_, _استض,
   {{0x27e002dd,0xb05b15d0,0x3eb815d1,0x6f0415d2}},	//   žini_, llän, sort_, _twic,
   {{0x3eb815d3,0x7c3615d4,0xcb6715d5,0x68e015d6}},	// [e20] port_, rfyr, бате_, _rimd,
   {{0xb05b00a6,0x62810fbc,0xa96a12fd,0x34d30066}},	//   nlän, nklo, лиза_, दगुद,
   {{0x6608008b,0xb05b1173,0xfeba00fd,0x62810345}},	//   _redk, ilän, _لاگت_, iklo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68fb0528,0xb05b0ef0,0x00000000,0x00000000}},	//   _čude, klän, --, --,
   {{0xfd650028,0x628102c4,0x248600cd,0x00000000}},	//   _nguồ, jklo, _slom_, --,
   {{0x99860514,0x27e915d7,0x320c15d8,0x5d7a0070}},	//   _الأو, žana_, vady_, טאַק,
   {{0x62810345,0x00000000,0x00000000,0x00000000}},	//   eklo, --, --, --,
   {{0xc44500d1,0x778603fa,0xf3ef0037,0xd20a0409}},	//   زیون_, _улаз, رأي_, лэнд_,
   {{0x326615d9,0x2732002d,0xb05b1173,0xe5a60192}},	//   стив, mân_, glän, _лизи,
   {{0x27320d11,0x320c12ad,0xe3b200b5,0xd25700d8}},	//   lân_, rady_, _کرا_, сцы_,
   {{0x320c15da,0x629d00f7,0x62810345,0x00000000}},	//   sady_, ésor, aklo, --,
   {{0x320c15db,0xdb0f021d,0x937a15dc,0x00000000}},	//   pady_, _excê, _حصار_, --,
   {{0xacf915dd,0xddde0260,0x00000000,0x00000000}},	//   ингу_, _enpō, --, --,
   {{0x403515de,0x273200e9,0x20090160,0x00000000}},	//   _дейс, hân_, _teai_, --,
   {{0xa0a400c9,0xd011042c,0xce3300d1,0xef1f0225}},	//   _најд, _کلک_, _کودک, prü_,
   {{0x3a7515df,0x1eab00f3,0xf09f0310,0x7f4d15e0}},	// [e30] олар, _مادي_, mià_, _usaq,
   {{0x9e0715e1,0xf09f0443,0x99670036,0x2eb407df}},	//   _учил, lià_, йтел, ंकृत,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50c906bc,0xb0c904e9,0xf09f0392,0x00000000}},	//   रतिष, रतिग, nià_, --,
   {{0xf1050fd1,0x7aed0024,0x628115e2,0xb05b02ee}},	//   _शब्द_, qqat, yklo, ylän,
   {{0x451915e3,0x2ca915e4,0xfdfb021a,0x00000000}},	//   ация_, lnad_, ्रिस_, --,
   {{0x2ca9026e,0x00000000,0x00000000,0x00000000}},	//   onad_, --, --, --,
   {{0x2ca9007c,0x52b3012f,0x833903e6,0xf1c30355}},	//   nnad_, ुत्स, ачот_, _liší_,
   {{0xb05b0ef0,0x2d8c0300,0x649700af,0xf09f0392}},	//   tlän, údez_, nţii, dià_,
   {{0xe29903fa,0x2ca9001e,0x7c2f0345,0x00000000}},	//   рао_, hnad_, _lccr, --,
   {{0xb05b15e5,0xc66800c9,0xe04609c0,0x628115e6}},	//   rlän, _уште_, онни, rklo,
   {{0x628115e7,0x61fc04d4,0xb05b15e8,0x7e6500cc}},	//   sklo, ırla, slän, _anhp,
   {{0xb05b15e9,0x7e770282,0x443d0103,0x00000000}},	//   plän, _boxp, _ibw_, --,
   {{0x7c2f15ea,0x2eb4004e,0x0eba15eb,0x3f8c0035}},	//   _accr, ंकेत, румы_, ądu_,
   {{0x1d0a0214,0xe7fc01c0,0x00000000,0x00000000}},	//   реби_, उँमा_, --, --,
   {{0x90c315de,0x9f5202e9,0x248d15ec,0x2ca915ed}},	//   _обще, _deyò_, nhem_, gnad_,
   {{0xdca30279,0x8af70095,0x2d910036,0x443d0345}},	// [e40] фати, _şəra, azze_, _mbw_,
   {{0xa01b15ee,0x443d15ef,0x2ca915f0,0x6f1600ee}},	//   nkön, _lbw_, anad_, _ivyc,
   {{0x443d0273,0x02b60070,0xdb0601ff,0x57ea083e}},	//   _obw_, קלעך_, _nykö, адем_,
   {{0x442f01ef,0xab2a15f1,0x6d5e005f,0x00000000}},	//   _ncg_, _кома_, _irpa, --,
   {{0x05260083,0x6497002d,0x248d15f2,0xa01b15f3}},	//   _মনের_, cţii, dhem_, kkön,
   {{0x057615f4,0x63a400d8,0x442f0211,0x6d5e15f5}},	//   قاعد, _žino, _acg_, _krpa,
   {{0x442f030d,0x00000000,0x00000000,0x00000000}},	//   _bcg_, --, --, --,
   {{0x69ce15f6,0x442f0211,0x443d15f7,0x684300af}},	//   _izbe, _ccg_, _cbw_, _онса,
   {{0x684301c8,0x926a0dbf,0xe3af006c,0xd7ef0037}},	//   _інфа, арна_, ہری_, _شكل_,
   {{0xa5f703fa,0x2ca00553,0x443d0345,0xd25015f8}},	//   _међу_, hiid_, _ebw_, رنج_,
   {{0xdb0f15f9,0x67220009,0xe3af02fd,0x00000000}},	//   _excè, lroj, فری_, --,
   {{0x248d15fa,0x27e00254,0xb4e6143a,0x490c0246}},	//   chem_, žinu_, पदी_, डीयो_,
   {{0x2ca00103,0x672215fb,0xb4c806bc,0xf09f0310}},	//   diid_, nroj, ोगी_, rià_,
   {{0x62631052,0x9f520260,0x00000000,0x00000000}},	//   _овча, _peyò_, --, --,
   {{0x2d8505d3,0x66cd016f,0xb05b1535,0x628a15fc}},	//   ále_, núka, lläm, _ilfo,
   {{0xbca50037,0x6fd30b7a,0x672215fd,0x6d5e0207}},	//   أمري, _सरपं, kroj, _drpa,
   {{0x7de715fe,0x2d850ce9,0x6d5e15ff,0x2a781600}},	// [e50] _мінд, šle_, _erpa, _borb_,
   {{0x249f02c2,0x67221601,0x2a781602,0xc5e400b5}},	//   zium_, droj, _corb_, _لۓ_,
   {{0x248d1603,0xdcef00ea,0x6aae0a8a,0x00000000}},	//   yhem_, ēdēt, _djbf, --,
   {{0x63ad008a,0x25fd1604,0x228907c0,0x00000000}},	//   _þang, रुनी_, _múka_, --,
   {{0x69ce1605,0xae1f00b1,0x2289148a,0x27e901a0}},	//   _ezbe, _बयान_, _lúka_, žano_,
   {{0x7bda0122,0x442f1606,0x249f0098,0x00000000}},	//   _לקרו, _scg_, wium_, --,
   {{0x070b0026,0xa8a71607,0x20020067,0x67220176}},	//   _सौरव_, _драк, ybki_, aroj,
   {{0x628a1608,0x6722011c,0xddc700a0,0x00000000}},	//   _alfo, broj, rejň, --,
   {{0x7c2d1609,0x248d160a,0x443d0051,0xf5590647}},	//   igar, rhem_, _vbw_, _گلاب_,
   {{0x248d00da,0xa5670bf5,0x7c2d001e,0xc879027d}},	//   shem_, _ودان, hgar, _hoş_,
   {{0x63ad160b,0x648e009e,0xe1f600af,0xe3b00088}},	//   _žand, _bùid, ягэ_, _یره_,
   {{0x2eb609a8,0x628a006c,0xdb0f0815,0x443d01d5}},	//   ृत्त, _elfo, _excé, _ubw_,
   {{0xe28e0b46,0x44f100c9,0x6d5e029d,0xc8790395}},	//   _за_, _há_, _srpa, _moş_,
   {{0x442d160c,0x7c2d160d,0x6449160e,0x228900ee}},	//   lge_, egar, leei, _fúka_,
   {{0x44f1160f,0x2ca001ed,0x672202c4,0x648e0211}},	//   _já_, tiid_, zroj, _fùid,
   {{0x7c2d1610,0xb5fc007a,0xeb9a0009,0x768f0185}},	//   ggar, _anġl, биб_, _høyd,
   {{0x44f11611,0x442d1612,0x20d2004f,0xfbd1006c}},	// [e60] _lá_, ige_, ráid_, ہتے_,
   {{0x7c2d01a6,0x20d20037,0x6d5e1554,0x09b00831}},	//   agar, sáid_, _trpa, _করবা,
   {{0x44f11613,0xd7fa1614,0x7c2d00ac,0xc879037a}},	//   _ná_, бул_, bgar, _boş_,
   {{0x67221615,0xc8791616,0x9f5902d7,0xb05b02ee}},	//   troj, _coş_, casó_, yläm,
   {{0x442d0052,0x27e003ad,0x6d5c053e,0xf0930070}},	//   dge_, äin_, lvra, ענד_,
   {{0x44f11617,0xa96a0610,0x67221618,0x442d1619}},	//   _bá_, _лига_, rroj, ege_,
   {{0xd943161a,0x44f1161b,0x6d5c0a75,0x9c8303ab}},	//   _пери, _cá_, nvra, ščev,
   {{0x44f1161c,0x442d161d,0x26c70528,0xb4c802b4}},	//   _dá_, gge_, alno_, ोगे_,
   {{0x768f03d0,0x00000000,0x00000000,0x00000000}},	//   _bøyd, --, --, --,
   {{0x44f1161e,0xaabe09b1,0x442d161f,0x7c2d1620}},	//   _fá_, ्तिक, age_, zgar,
   {{0x44f10082,0x7c2d1621,0x04461622,0x768f0044}},	//   _gá_, ygar, _нежн, _døyd,
   {{0x6d5c0345,0x78a203ee,0xc87900a8,0x63ad1623}},	//   dvra, niov, _xoş_, _žane,
   {{0x4abe0567,0xaabe0afa,0xb05b00c3,0x44f100d5}},	//   ्ताव, ्ताक, lläk, _zá_,
   {{0x68fc00ea,0x44f102d7,0x2ee5033b,0x00000000}},	//   _otrd, _yá_, ölf_, --,
   {{0x291c006c,0xd23b0122,0xdb1d01c0,0x44f10019}},	//   ával_, _הגול, _vysí, _xá_,
   {{0x7c2d1624,0xd13800c7,0x3e740168,0x3f820118}},	//   ugar, mtą_, _mäty_, byku_,
   {{0x7c2d1625,0x78a211fa,0x64970043,0x2918027a}},	// [e70] rgar, diov, cţiu, _avra_,
   {{0x7c2d0291,0x442d1626,0x6ce700d4,0xd1381627}},	//   sgar, zge_, _німе, otą_,
   {{0x442d11cb,0xd13800d8,0x9f591628,0x00000000}},	//   yge_, ntą_, pasó_, --,
   {{0x44f11629,0x78a2162a,0x6d450132,0xd138010b}},	//   _rá_, giov, _ipha, itą_,
   {{0xb8f4162b,0x44f100fb,0x2d8301c8,0x00000000}},	//   _सी_, _sá_, lyje_, --,
   {{0x44f1162c,0xd13800d8,0x61ea0118,0x00000000}},	//   _pá_, ktą_, _ngfl, --,
   {{0x442d162d,0x2d8300d8,0xe61001b2,0x3f82162e}},	//   tge_, nyje_, اشه_, zyku_,
   {{0x44f1162f,0x442d1630,0x78a20237,0x29011631}},	//   _vá_, uge_, ciov, mpha_,
   {{0x6d45012f,0x44f10023,0x6d5c00cd,0x26c70097}},	//   _lpha, _wá_, zvra, plno_,
   {{0x44f102aa,0x6d451632,0x442d01a6,0x7d1a0334}},	//   _tá_, _opha, sge_, átsk,
   {{0x6d450221,0xbebb0031,0x7ae71633,0x00000000}},	//   _npha, trën, _mijt, --,
   {{0xbe250083,0x8fa600af,0xa06a0274,0x7afd00be}},	//   ম্মদ_, даме, цама_, _otst,
   {{0x6fde00b4,0x7afd0298,0x3ea31634,0xdd9200fd}},	//   _नृशं, _ntst, fijt_, ھور_,
   {{0x68fb1635,0xdd9202fd,0x6d5c1636,0x768f0044}},	//   _čudn, پور_, tvra, _føye,
   {{0xdee31637,0x8db50044,0x7afd1638,0xed5713a1}},	//   тори, есті, _atst, мор_,
   {{0x69da03e6,0x6d5c1639,0x291c00a0,0x27e901a0}},	//   _útei, rvra, ávam_, žanj_,
   {{0x60c4163a,0x68fc02a7,0x7ae7163b,0x6abe163c}},	// [e80] _ikim, _strd, _bijt, topf,
   {{0x68ee0107,0x7bc6163d,0xab5b00b5,0x9a6a00fd}},	//   _pubd, _vyku, _gyüm, غمال_,
   {{0xceb300c2,0xbebb01f4,0x6abe02b1,0x994a0c26}},	//   _ביז_, ytëz, ropf, تلال_,
   {{0x672b163e,0x7aef0160,0xb4b700b8,0x00000000}},	//   fugj, _fuct, चको_, --,
   {{0x78a2163f,0x7afd0051,0x7bc6027d,0x60c408c7}},	//   riov, _gtst, _uyku, _mkim,
   {{0xd1381640,0xa9260d6e,0x3e740168,0x00000000}},	//   ytą_, _одгл, _päty_, --,
   {{0x98a61641,0x250700b5,0x764a016e,0x60c4001c}},	//   _живе, ورٹی_, refy, _okim,
   {{0x7ae70223,0x60c41642,0x3d110387,0x399b024b}},	//   _zijt, _nkim, _तबसे_, _וילד,
   {{0x6b841643,0x98a305ac,0xb05b01ff,0x00000000}},	//   nyig, _рите, släk, --,
   {{0x60c41644,0x3254093e,0xa01b02b1,0x32050b88}},	//   _akim, хвор, rköm, gbly_,
   {{0xb05b0421,0x60f81645,0x6b8404fb,0x40351646}},	//   lläi, яння_, hyig, ненс,
   {{0xd1381647,0x60d6001e,0x42ce0033,0x2d8300c7}},	//   rtą_, _chym, রদেশ, vyje_,
   {{0xd1381648,0x00000000,0x00000000,0x00000000}},	//   stą_, --, --, --,
   {{0x2bd51649,0x60c4164a,0x2d8300d8,0xd13800c7}},	//   _दरबा, _ekim, tyje_, ptą_,
   {{0x7aef0602,0x68fb0169,0x6d58164b,0x7ae701e4}},	//   _suct, _čudo, _švar, _rijt,
   {{0x96140083,0x2d83010b,0x7ae70051,0x8f35002d}},	//   সলিম_, ryje_, _sijt, _зеиц,
   {{0x3f4f0484,0x7ebf00b8,0x92c20033,0x7ae70c8c}},	// [e90] _użu_, tápě, ্দী_, _pijt,
   {{0x2d8300d8,0x6f0d0010,0x2fc90159,0xdddc011c}},	//   pyje_, _iwac, _iyag_, skrš,
   {{0xdc0300d5,0x00000000,0x00000000,0x00000000}},	//   lčík, --, --, --,
   {{0xc87906d0,0x38690f56,0x80d10083,0x69c70187}},	//   _kişi_, ñar_, _সূত্, _vyje,
   {{0x7afd053c,0x59d4164c,0x6b84007b,0xfc3f00b5}},	//   _utst, _थरथर, cyig, _amíg_,
   {{0x2901055c,0x0555164d,0xaa450086,0x6f0d164e}},	//   ppha_, етия, ävää_, _mwac,
   {{0xaabe06d9,0xa2c200ab,0x4abe164f,0x00000000}},	//   ्तरक, रकन्, ्तरव, --,
   {{0xa3ba0bda,0xf992011d,0x00000000,0x00000000}},	//   _आँख_, _ערן_, --, --,
   {{0x27ed1650,0x6442009e,0xdc0300d5,0x60d61651}},	//   _igen_, _dboi, jčík, _rhym,
   {{0x68e91652,0x00000000,0x00000000,0x00000000}},	//   _hied, --, --, --,
   {{0x68e9006a,0x32051653,0x21691654,0x2bcc060a}},	//   _kied, rbly_, чини_, _ार्थ,
   {{0x6f0d01d5,0x22800260,0x037b03fc,0x62881655}},	//   _bwac, _bòks_, _وحشت_, akdo,
   {{0x68e91656,0xe8100380,0x6f0d0103,0x443f023c}},	//   _mied, ारता_, _cwac, mfu_,
   {{0x523900c2,0x443f1657,0x68e90b3c,0x64590487}},	//   _זײַנ, lfu_, _lied, _hawi,
   {{0xfaff01d2,0x64591658,0x7bcb01ae,0x27ed0120}},	//   _atë_, _kawi, ügun, _ogen_,
   {{0x68e91659,0x60c4000e,0x63a401c8,0x6459165a}},	//   _nied, _ukim, _žini, _jawi,
   {{0x6d410723,0x64590054,0x443f0054,0x00000000}},	// [ea0] çlar, _mawi, ifu_, --,
   {{0x27ed1034,0x6459165b,0x00000000,0x00000000}},	//   _agen_, _lawi, --, --,
   {{0x68e9165c,0xd7fa002d,0x35c40084,0xdb1d0bca}},	//   _bied, пул_, _लुढ़, _vysá,
   {{0x7e7e165d,0x6459004e,0xb5fc035f,0xa29f02b4}},	//   _hopp, _nawi, _inġi, गोत्,
   {{0x7e7e165e,0xd7070384,0x175400c3,0xe7c00033}},	//   _kopp, енче_, твля, েশ্য,
   {{0x27ed165f,0x443f05db,0x6459067f,0x68e90345}},	//   _egen_, efu_, _aawi, _eied,
   {{0x80d100c8,0x443f1660,0x7e7e1661,0x6abe1662}},	//   _সংস্, ffu_, _mopp, ्तीर,
   {{0xd4971663,0x7e7e1664,0x645900e0,0x68e91665}},	//   ерь_, _lopp, _cawi, _gied,
   {{0x64591666,0x82a61667,0x7e7e1668,0x00000000}},	//   _dawi, ешне, _oopp, --,
   {{0x68e91669,0x443f166a,0x6f0d01d5,0x3d1100ab}},	//   _zied, afu_, _rwac, _तबले_,
   {{0x13ea00af,0x64420211,0xc5690079,0x00000000}},	//   _емей_, _tboi, _يحمل_, --,
   {{0x64590269,0x6abe166b,0x765a081b,0x92c20033}},	//   _gawi, ्तुर, _haty, ্দে_,
   {{0x765a166c,0x768f03d0,0x6d5800f4,0x00000000}},	//   _katy, _høya, _švap, --,
   {{0x6459004e,0xa6e70023,0x7e7e0dbb,0x2bdb012f}},	//   _zawi, _nhữ, _copp, _मृगा,
   {{0x7e7e166d,0x765a166e,0xa2af143a,0x20d20037}},	//   _dopp, _maty, ुवर्, máin_,
   {{0x765a166f,0x27e90bc6,0x20d20079,0x645900ee}},	//   _laty, žani_, láin_, _xawi,
   {{0x68e91670,0xfaf30a72,0x6abe0026,0x5a350f8c}},	// [eb0] _ried, اثر_, ्तूर, кнат,
   {{0x765a1671,0x68e91672,0x20d20037,0x645b00af}},	//   _naty, _sied, náin_, zdui,
   {{0x68e91673,0x394712c3,0x7cd900af,0x48151583}},	//   _pied, ïns_, _омор_, вмес,
   {{0x20d20514,0xe0df02e9,0x26c50187,0x7e7e1674}},	//   háin_, nmò_, _sklo_, _zopp,
   {{0x68e91675,0x765a0186,0x20d90037,0xe7391676}},	//   _vied, _baty, méid_, фел_,
   {{0x68e91677,0x645901ca,0x945d004e,0x20d90037}},	//   _wied, _sawi, końc, léid_,
   {{0x68e90d36,0x645914d6,0x443f1678,0x20d20037}},	//   _tied, _pawi, tfu_, dáin_,
   {{0x27ed01b4,0x20d90079,0xa564026e,0x672400cd}},	//   _ugen_, néid_, ادون, šija,
   {{0xe2990424,0x645b1679,0x443f167a,0x23db073f}},	//   дап_, rdui, rfu_, मेंद,
   {{0x09e50083,0x6459000e,0x20d20037,0x387f00a5}},	//   _প্যা, _wawi, gáin_, _hour_,
   {{0x81c90b52,0x20120c05,0x443f0010,0x6459167b}},	//   লেন_, _peyi_, pfu_, _tawi,
   {{0x387f1010,0x7e7e167c,0x10a6167d,0xa3ba167e}},	//   _jour_, _sopp, тимн, _आँच_,
   {{0xa4d402ce,0x087602b5,0x047800b5,0x80d10033}},	//   _соці, דערט_, _سلوک_, _সংশ্,
   {{0x9f9e0370,0x387f0260,0xe0df027a,0x20d2104b}},	//   _ação_, _lour_, amò_, cáin_,
   {{0x71640037,0x00000000,0x00000000,0x00000000}},	//   _مايك, --, --, --,
   {{0x09b00083,0xeaed0edf,0x1f6602ee,0x3ceb021d}},	//   _করলা, जदूत_, _аким, _cicv_,
   {{0x7e7e167f,0xf41200c2,0xfce306cd,0x69d51680}},	// [ec0] _topp, יפן_, рото, _azze,
   {{0x386d1681,0x0d861682,0x3ceb0027,0xdee6167d}},	//   _aner_, _алон, _eicv_, _шопи,
   {{0x386d0118,0x649500d5,0x387f0160,0xceb90355}},	//   _bner_, _káid, _bour_, éře_,
   {{0x765a1683,0x387f0248,0x20d90079,0x00000000}},	//   _saty, _cour_, céid_, --,
   {{0x765a00d8,0x69d5006c,0x929d0035,0xb8f91604}},	//   _paty, _ezze, zpła, _ठी_,
   {{0x6f020723,0x6495004f,0xb05b153f,0x386d0168}},	//   _çocu, _láid, llät, _ener_,
   {{0xc60b0083,0x387f0122,0x64b3002d,0xfaa3151c}},	//   _রাখা_, _four_, răin, _таро,
   {{0xd90d00e0,0xb4cc0099,0x00000000,0x00000000}},	//   _ریه_, ळते_, --, --,
   {{0x20d20037,0x765a1684,0xd2500037,0xdc0300ac}},	//   táin_, _taty, منة_, nčák,
   {{0x7c2900ea,0x69da00ac,0x00000000,0x00000000}},	//   _ķerm, _útes, --, --,
   {{0x387f01f3,0x63ad00fb,0x20d21685,0xe1341686}},	//   _your_, _þann, ráin_, ынны,
   {{0x20d20082,0x63a401c8,0x2ebd0fcf,0x44f80176}},	//   sáin_, _žinu, ोत्त, _ié_,
   {{0xe0df07e5,0x20d20079,0x00000000,0x00000000}},	//   rmò_, máil_, --, --,
   {{0x6fe900ea,0x44f81687,0x20d20079,0x2fcd0067}},	//   _rīcī, _ké_, láil_, żego_,
   {{0x44f81688,0x3f8d00f4,0x3ead0207,0x00000000}},	//   _jé_, šeu_, đet_, --,
   {{0x44f80514,0x273b00e8,0x80d10033,0x20d20079}},	//   _mé_, yên_, _সূর্, náil_,
   {{0x44f81689,0x6618168a,0x30840698,0x00000000}},	// [ed0] _lé_, kavk, _خليف, --,
   {{0x20d20082,0x44f80037,0x7e5500d4,0xb05b033b}},	//   háil_, _oé_, _своє, rläu,
   {{0x387f168b,0x44f8168c,0x6618024e,0x2bd50591}},	//   _pour_, _né_, davk, _दरवा,
   {{0xdb1d00c3,0x05b60067,0xb4cc0099,0x00000000}},	//   _pysä, _अख़ब, ळतो_, --,
   {{0xfeb801ca,0x9cd6168d,0x20d2004f,0x23660221}},	//   _سایت_, _תורה_, dáil_, _nroj_,
   {{0x2ca902c7,0x44f8168e,0x2019168f,0x25570095}},	//   liad_, _bé_, hasi_, _hələ_,
   {{0x20191690,0x44f80082,0x387f1691,0x64a51692}},	//   kasi_, _cé_, _tour_, лака,
   {{0x23660537,0x20d20082,0x2ca90297,0x44f80571}},	//   _broj_, gáil_, niad_, _dé_,
   {{0x20191693,0x69da1694,0x6618011c,0x648e009e}},	//   dasi_, _úter, bavk, _tùin,
   {{0x44f81695,0x20190043,0x2ca900e9,0x00000000}},	//   _fé_, easi_, hiad_, --,
   {{0x20190657,0x44f80098,0xa29f00dc,0xe43500b5}},	//   fasi_, _gé_, गोष्, _مفاد,
   {{0x20191696,0x20d2004f,0x672b0031,0x27e900cd}},	//   gasi_, cáil_, orgj, žanu_,
   {{0x32450dc8,0x2ca902c7,0x44f803e6,0x14b200b4}},	//   _белг, diad_, _zé_, ुकरण,
   {{0xed5a0202,0x248d01c0,0xf2070352,0x44f81697}},	//   ног_, lkem_, _рядо, _yé_,
   {{0x2ca9001e,0x20191698,0x2b4b0176,0x5cf500af}},	//   fiad_, basi_, _apcc_, ияту,
   {{0x6abe0311,0x2ca90297,0x7d1c1699,0x39580132}},	//   ्त्र, giad_, rsrs, _rsrs_,
   {{0x7c2b169a,0xab6615eb,0xeb970f08,0xab27020a}},	// [ee0] ógra, ывал, гит_, лота_,
   {{0x248d0006,0x394a012f,0x68f5169b,0xb8650105}},	//   hkem_, _ppbs_, _buzd, یانو,
   {{0xb05b01ae,0x648e009e,0x2ca900e9,0xdca60ea0}},	//   plät, _bùil, biad_, _бани,
   {{0xb05b169c,0x44f8169d,0x648e0211,0x2ca9016e}},	//   llär, _ré_, _cùil, ciad_,
   {{0x44f8169e,0x6618030a,0x248d00b8,0xc60b0033}},	//   _sé_, tavk, dkem_, _রাজা_,
   {{0x44f8169f,0x4ab80569,0x201900ae,0xaab816a0}},	//   _pé_, _आदिव, zasi_, _आदिक,
   {{0x20190ec4,0x20d20082,0x2b4016a1,0x68f50207}},	//   yasi_, táil_, ltic_, _guzd,
   {{0x44f801a5,0x6f0416a2,0x768f0044,0x2b4016a3}},	//   _vé_, _otic, _høyl, otic_,
   {{0x20d20082,0x363616a4,0xb05b02c9,0xe80a02cb}},	//   ráil_, _مراس, klär, _ह्या_,
   {{0x44f816a5,0x68e216a6,0x20d2004f,0x201916a7}},	//   _té_, lmod, sáil_, wasi_,
   {{0x326300d8,0x7aee0036,0x44f80183,0x20d20098}},	//   стыв, _mibt, _ué_, páil_,
   {{0x68e216a8,0x7aee0069,0x6f1d16a9,0x248d16aa}},	//   nmod, _libt, tssc, ckem_,
   {{0xb4c00953,0x236601f4,0xb4c200a1,0x6f0402d7}},	//   ंकी_, _uroj_, ृती_, _ctic,
   {{0x201916ab,0x25630723,0x2ca904fc,0x3eaa033b}},	//   sasi_, _yıl_, wiad_, gibt_,
   {{0x6f0416ac,0xdd940409,0x2ca900e9,0x69ce038d}},	//   _etic, бары, tiad_, _nybe,
   {{0xb05b16ad,0x81ab0033,0xd1380035,0x20191505}},	//   rläs, _খরচ_, rząd_, qasi_,
   {{0x2ca90297,0x68f516ae,0xb5fc0069,0xb05b038e}},	// [ef0] riad_, _suzd, _gaġg, släs,
   {{0x69ce0626,0x2ca9001e,0x8f9c02b5,0xdb1d0168}},	//   _bybe, siad_, _ריזי, _kysú,
   {{0x81e60033,0xb9b502e7,0x2ca916af,0x2b4011f0}},	//   যুর_, جماع, piad_, atic_,
   {{0x21370070,0x764816b0,0x68e216b1,0x69ce08c8}},	//   רטאל_, _abdy, gmod, _dybe,
   {{0x2b4016b2,0x656816b3,0xdc3600c2,0x648e009e}},	//   ctic_, _ardh, _דארט_, _cùim,
   {{0x7aee01ae,0x83fd00b5,0x8af000a8,0xab6600ea}},	//   _gibt, zdőd, rvət, _daļē,
   {{0xd618004f,0x248d16b4,0x291c00b8,0x648e009e}},	//   اتها_, tkem_, ávat_, _tùil,
   {{0x03250896,0x7f4d16b5,0xc48516b6,0x68e2013a}},	//   адин, _opaq, рлик, cmod,
   {{0x656800da,0xc6140083,0x248d16b7,0x527516b8}},	//   _erdh, _সারা_, rkem_, ауну,
   {{0x248d16b9,0x648700de,0x78ab16ba,0x7ea90009}},	//   skem_, _añit, ligv, džpo,
   {{0x26c716bb,0xe0da16bc,0x394116bd,0x6f0416be}},	//   mono_, кво_, nths_, _stic,
   {{0x6f040496,0x6e250014,0x26c716bf,0x4f960336}},	//   _ptic, _adhb, lono_, аргу,
   {{0xe28e16c0,0xa3e916c1,0x7d050037,0xa85600a5}},	//   _да_, _मणि_, _aths, בירה_,
   {{0x91e50faf,0x26c716c2,0x539a00a5,0x60c600d7}},	//   _коле, nono_, _בינו, sokm,
   {{0xb05b0523,0xa2c20d91,0x26c707e5,0x68e216c3}},	//   rlär, रकर्, iono_, ymod,
   {{0x7aee16c4,0xb05b0ef0,0x628316c5,0x26c716c6}},	//   _sibt, slär, _hono, hono_,
   {{0x6f0403fa,0x628316c7,0x26c716c8,0xb05b16c9}},	// [f00] _utic, _kono, kono_, plär,
   {{0x2b4016ca,0x26c700d8,0x68e20051,0x628316cb}},	//   rtic_, jono_, wmod, _jono,
   {{0x2b4016cc,0x26c716cd,0xd83a0409,0x20d903e6}},	//   stic_, dono_, вэл_, léia_,
   {{0x69ce0076,0xb5fc0024,0xddde0260,0xa01b16ce}},	//   _vybe, _maġe, _rapň, lkör,
   {{0x26c716cf,0xbebb00da,0x77690176,0x20d90132}},	//   fono_, rrëv, _crex, néia_,
   {{0x68e2038d,0x628316d0,0x69ce01a7,0x00000000}},	//   smod, _nono, _tybe, --,
   {{0x68e216d1,0xa01b01ff,0x768f0044,0xd5af11c0}},	//   pmod, ljöe, _gøym, وفه_,
   {{0xd7061583,0x776901ed,0x64b2111a,0xb4c00f06}},	//   _взаи, _frex, ुकेश, ंके_,
   {{0x628316d2,0xa2c216d3,0xf74900d1,0x26c716d4}},	//   _bono, रकल्, _مجله_, bono_,
   {{0x628316d5,0x2bde009a,0x26c716d6,0xe5a6059d}},	//   _cono, _मरना, cono_, _кизи,
   {{0x628316d7,0xd48f16d8,0x99f70122,0x7c2616d9}},	//   _dono, _др_, יזיה_, _odkr,
   {{0xdcee00d8,0x75d300d1,0x672d02f6,0xb97b00a5}},	//   mybė, _بيما, šaje, דנטי,
   {{0x628316da,0xe3b203c7,0xbfa813df,0xdcee00c7}},	//   _fono, _برا_, атре_, lybė,
   {{0x628316db,0x6b5d008c,0xef1f0225,0x4426007e}},	//   _gono, _lægå, rsü_, _hdo_,
   {{0x442616dc,0xdcee010b,0x6ca7010b,0xeca70d6e}},	//   _kdo_, nybė, араж, ајан,
   {{0x80d10083,0x26c716dd,0x30150132,0x628316de}},	//   _সংক্, zono_, _удир, _zono,
   {{0x26c707ee,0x394116df,0x60cd16e0,0x6d48027d}},	// [f10] yono_, wths_, _ikam, çdar,
   {{0x996700f0,0x44260183,0x3b0900a8,0xdcee010b}},	//   ител, _ldo_, rpaq_, kybė,
   {{0xd3660796,0x26c701d3,0x44260e9d,0x161a0035}},	//   _که_, vono_, _odo_, _नज़र_,
   {{0xa3cc0066,0x44260054,0x776901dd,0x649c0037}},	//   _शुभ_, _ndo_, _prex, _héif,
   {{0x26c716e1,0xcc76011d,0x60cd002f,0xdb1d008c}},	//   tono_, _הערה_, _mkam, _nysø,
   {{0xc98716e2,0x2bb402e4,0x442616e3,0x60cd0069}},	//   _куби, ंपरा, _ado_, _lkam,
   {{0x09e50b52,0x60cd024e,0x99850082,0x26c716e4}},	//   _প্রা, _okam, _الزو, rono_,
   {{0x442600da,0xa8a41112,0x26c716e5,0xe57016e6}},	//   _cdo_, _друк, sono_, بطه_,
   {{0x26c716e7,0x6b8d16e8,0x442616e9,0x78a916ea}},	//   pono_, nyag, _ddo_, _imev,
   {{0x60cd15c4,0x442603cb,0x80d10083,0xafdb0c61}},	//   _akam, _edo_, _সংগ্, rføl,
   {{0x62830031,0x2c170067,0x442602d7,0xb5a716eb}},	//   _vono, तरां_, _fdo_, _трай,
   {{0x656e0514,0x160b12e7,0x628316ec,0x20d90132}},	//   _ábha, _स्तर_, _wono, téia_,
   {{0x232916ed,0x80d10083,0x443d012f,0xafdb01b4}},	//   _соли_, _সংখ্, _icw_, lføj,
   {{0x629a16ee,0x60cd00d7,0x20d90132,0xb05b01ff}},	//   chto, _ekam, réia_, släp,
   {{0x69a70299,0x753c01ae,0x7c9616ef,0xa01b16f0}},	//   _टेली, _ärzt, брац, rkör,
   {{0x20d90132,0xa92401ba,0xa01b16f1,0xdca3083e}},	//   péia_, _úžit, skör, паси,
   {{0xc9f6004f,0x09e50033,0x5f4600fd,0x00000000}},	// [f20] مساع, _প্লা, _انخل, --,
   {{0xe8100bdd,0x78101343,0x78a9002f,0x2bac00a1}},	//   ार्थ_, ार्क_, _amev, _घेणा,
   {{0x81c90b52,0x443d16f2,0x00000000,0x00000000}},	//   লের_, _ocw_, --, --,
   {{0x6d5e16f3,0xa01b022a,0x443d006d,0x38cb01cb}},	//   _ispa, nköp, _ncw_, هانی_,
   {{0x649c0098,0x78bb16f4,0x6b8d007b,0x00000000}},	//   _héig, _djuv, cyag, --,
   {{0xdcee01c8,0xa01b0086,0x44260031,0xb4c207df}},	//   tybė, hköp, _sdo_, ृत्_,
   {{0xdcfc010b,0x2bac0099,0x26de0051,0xeae416f5}},	//   tyrę, _घेता, _vhto_, कगीत_,
   {{0x69dc03ba,0x442616f6,0x629d0055,0x00000000}},	//   _izre, _qdo_, ëson, --,
   {{0x649c004f,0x57fb0317,0xa3e30026,0xd6d20d93}},	//   _léig, _תלמו, फेल_, _فقر_,
   {{0x60cd16f7,0x6d5e16f8,0x3218016f,0xe7b300b5}},	//   _skam, _ospa, úry_, _عملد,
   {{0x80c5009a,0x672200ea,0x4426021d,0x38cb00b5}},	//   रवले, lsoj, _tdo_, _شاہی_,
   {{0x557700c2,0x661a1246,0x629a00da,0x442616f9}},	//   _לעבן_, _hetk, shto, _udo_,
   {{0x6d5e16fa,0x7e2b00d8,0xeaae0009,0xe819046c}},	//   _aspa, ліва_, kiй_, दरता_,
   {{0x24860221,0xa19412a2,0x0dcb16fb,0x20020a8a}},	//   _hoom_, _малч, губи_, acki_,
   {{0x248601a9,0x321e16fc,0x661a030a,0xdd94004b}},	//   _koom_, maty_, _metk, пары,
   {{0x6d5e16fd,0x60cd16fe,0x6b8d16ff,0x661a1700}},	//   _dspa, _ukam, tyag, _letk,
   {{0x6d5e1701,0xfbd30bdf,0x2486055c,0x3cfa1702}},	// [f30] _espa, ستر_, _moom_, _eupv_,
   {{0x661a029d,0xbebb01f4,0x6b8d007b,0x321e0067}},	//   _netk, rrës, ryag, naty_,
   {{0x2bd50722,0x6f160035,0x290701f4,0x69dc00fe}},	//   _दरका, _zwyc, ëna_, _czre,
   {{0x24860221,0x321e00d5,0x290700ea,0x66cd003e}},	//   _noom_, haty_, īna_, júkr,
   {{0xf1cf0299,0x321e0035,0x661a1703,0x649c0079}},	//   _सुनन, katy_, _betk, _méid,
   {{0xda7b00d8,0x661a1321,0x64950079,0x7bdd1704}},	//   _сям_, _cetk, _cáin, _izsu,
   {{0x24861705,0x78bb15ed,0x7d0200a0,0x321e00d5}},	//   _boom_, _tjuv, _čosk, daty_,
   {{0x62981706,0x25fd0907,0x6722006d,0x649c0312}},	//   _alvo, रुजी_, bsoj, _néid,
   {{0x64950037,0x254e00a8,0x20d90098,0x443d00cc}},	//   _fáin, _cəlb_, téin_, _vcw_,
   {{0x81bd0033,0x321e0067,0x52a900c3,0x31250d54}},	//   _আরব_, gaty_, рвом_, одог,
   {{0x2486006f,0x649c0312,0x6f160067,0x00000000}},	//   _foom_, _béid, _swyc, --,
   {{0x649c004f,0x6d5e012f,0x090e0033,0xf8c900b4}},	//   _réig, _rspa, _হিমু_, िकिय,
   {{0x661a1707,0x649c0341,0x2d850301,0xa01b1708}},	//   _yetk, _déid, älen_, rköp,
   {{0x24861709,0x2169170a,0x6449170b,0xfc3f0310}},	//   _zoom_, _вики_, lfei, _ací_,
   {{0x649c0514,0xf8c9170c,0xed5a01e0,0x71a5081b}},	//   _féid, िकाय, шов_, _файз,
   {{0x6449170d,0x2fc001e8,0x2486006d,0x20d90079}},	//   nfei, _txig_, _xoom_, néil_,
   {{0x6d5e004e,0xbb43170e,0x00000000,0x00000000}},	// [f40] _wspa, метк, --, --,
   {{0x649c004f,0x20d90098,0x00000000,0x00000000}},	//   _téig, héil_, --, --,
   {{0x661a170f,0x6d5e1710,0xf1cf05f8,0xa01b01ff}},	//   _retk, _uspa, _सुमन, ljöa,
   {{0x50ca006a,0x20ca0632,0x661a0761,0x67220421}},	//   रविष, रविध, _setk, tsoj,
   {{0x661a02f6,0x24861711,0x20d90037,0xe8e000e2}},	//   _petk, _room_, déil_, hiệt_,
   {{0x24861712,0x6b8b01ff,0x67221713,0x649c0183}},	//   _soom_, ägge, rsoj, _méie,
   {{0xd49a1714,0x24860639,0x69dc00ea,0x321e0097}},	//   ири_, _poom_, _uzre, vaty_,
   {{0xb1980019,0x734a002d,0x672d1715,0x20d90098}},	//   _ngưỡ, ачов_, šaja, géil_,
   {{0x61ef0095,0x68fc1716,0x649c0037,0x160b0518}},	//   əklə, _hurd, _réid, _स्वर_,
   {{0x68fc1717,0x3866053e,0x649c0098,0x386400fe}},	//   _kurd, ldor_, _séid, _hamr_,
   {{0x321e027e,0x24861718,0xe45a02ce,0x3b001719}},	//   raty_, _toom_, _вже_, hqiq_,
   {{0x68fc171a,0x7658171b,0x92ca0083,0x6d5c00e9}},	//   _murd, levy, লগে_, dwra,
   {{0x61010029,0x3866171c,0x9757016b,0x00000000}},	//   _vēla, idor_, ֿילו_, --,
   {{0x81c90083,0x76580054,0x3326021d,0xbbb40099}},	//   লেই_, nevy, _ivox_, ंपैक,
   {{0xbd68171d,0x009500af,0x6d5c00e5,0x68fc171e}},	//   орте_, _никэ, gwra, _nurd,
   {{0x90c40798,0x00000000,0x00000000,0x00000000}},	//   _обје, --, --, --,
   {{0x1eab004f,0x7bc10035,0x3866171f,0x68fc01ed}},	// [f50] _نادي_, _ślub, ddor_, _aurd,
   {{0x1b040083,0x68fc08cd,0x768f0044,0x2918099e}},	//   _লিখে_, _burd, _høyv, _bwra_,
   {{0x68fc009e,0xad2700d1,0x644900e9,0x20d90079}},	//   _curd, _برخو, yfei, héim_,
   {{0xe8f80560,0x6495004f,0x68fc033e,0x386603d0}},	//   ілі_, _cáil, _durd, gdor_,
   {{0xb9020380,0xcb4400c9,0x64950037,0x0c2400d8}},	//   _नी_, _охри, _dáil, _імён,
   {{0x7afd1720,0x38661721,0x8afa0122,0x9662081b}},	//   _iust, ador_, _להשי, екше,
   {{0xceb400c2,0x6495004f,0x8557064e,0x7afd1722}},	//   ויס_, _fáil, تیار_, _hust,
   {{0x7afd1723,0x7af506a2,0x81c20033,0xe29a055c}},	//   _kust, _hizt, ্ধা_, _alư_,
   {{0x64491724,0xe3b1004f,0x68fc1725,0x00000000}},	//   rfei, عرب_, _zurd, --,
   {{0xe29903fa,0x64491726,0x68fc00c1,0x6d5c1727}},	//   сао_, sfei, _yurd, ywra,
   {{0x68fc0391,0xc22205f5,0x76b20035,0x321c00ee}},	//   _xurd, رکوو, słyc, _devy_,
   {{0x7af50065,0x7b0900a0,0x69d50055,0x00000000}},	//   _lizt, _kľud, _myze, --,
   {{0x7afd01c8,0x3f8f003c,0xbf9b0279,0x00000000}},	//   _nust, _żgur_, scên, --,
   {{0x386600f4,0x91fc0228,0x00000000,0x00000000}},	//   zdor_, ndāl, --, --,
   {{0x7c961728,0x6495004f,0xe7eb1729,0xfce6172a}},	//   прац, _láim, जेता_, зово,
   {{0x249f0370,0xf09f009e,0xa3e200ab,0x6d5c172b}},	//   nhum_, chà_, _धरम_, rwra,
   {{0x7af5172c,0x7afd172d,0x649c0312,0xf1cf018d}},	// [f60] _bizt, _cust, _héic, _सुतन,
   {{0x5cf600af,0x7afd172e,0x64950098,0x00000000}},	//   _няму, _dust, _sáil, --,
   {{0x7afd01d7,0x249f012f,0x68fc00a8,0x7af501ed}},	//   _eust, khum_, _qurd, _dizt,
   {{0x7afd172f,0x68fc1730,0x20d21731,0x69d51732}},	//   _fust, _vurd, máis_, _dyze,
   {{0x68fc0446,0x38661733,0x672d0506,0xe7370012}},	//   _wurd, rdor_, šajn, зеч_,
   {{0x68fc1734,0x386600d7,0x2d8701f7,0x648e009e}},	//   _turd, sdor_, _ànec_, _lùit,
   {{0x7afd1735,0x64950037,0x321c1736,0xddc70067}},	//   _zust, _táil, _revy_, dejś,
   {{0x2ca0067f,0x7afd1737,0x7de7006c,0xf7461738}},	//   nhid_, _yust, lésé, _небо,
   {{0x7afd043f,0x00000000,0x00000000,0x00000000}},	//   _xust, --, --, --,
   {{0xcb1300a5,0x2cbf00f4,0x6d47008d,0x7de700fd}},	//   עלת_, čudi_, ytja, nésé,
   {{0x403508ae,0x648e0284,0x59be052b,0x20d202d7}},	//   менс, _bùit, ्थिर, jáis_,
   {{0x249f1739,0x7bc3002d,0x67240009,0x64a3010b}},	//   chum_, şnui, šiju, _паха,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afd173a,0x6d47173b,0xddde0009,0xfd130c74}},	//   _rust, ttja, _sopš, فجر_,
   {{0x7afd173c,0x71f70bdf,0x7de7006c,0x20d20453}},	//   _sust, _عروس_, désé, gáis_,
   {{0x6d47173d,0x628a017b,0x9f400065,0x15e100b4}},	//   rtja, _hofo, _egiñ_, गेटर_,
   {{0x6d47173e,0xc6220083,0x7af501d7,0x628a173f}},	// [f70] stja, _নানা_, _pizt, _kofo,
   {{0x7afd1740,0xbd0202d7,0x00000000,0x00000000}},	//   _vust, ñéca, --, --,
   {{0xb5fc0484,0x628a1741,0xc95904a3,0x96220033}},	//   _paġn, _mofo, تلاش_, নলাম_,
   {{0xddde0bec,0x2ca01742,0x20d20037,0x69d501ba}},	//   _uopš, chid_, láir_, _vyze,
   {{0xf7450171,0x7afd018d,0x00000000,0x00000000}},	//   фело, _uust, --, --,
   {{0x628a00ea,0x20d2004f,0x64420042,0x768f01e0}},	//   _nofo, náir_, _acoi, _nøyt,
   {{0x249f0090,0xa8a70009,0x00000000,0x00000000}},	//   thum_, _ерак, --, --,
   {{0x6495004f,0x9f6501ba,0x13091743,0xc21f0324}},	//   _táim, _štýl_, оний_, _मजहब_,
   {{0x249f1744,0x628a1745,0x6f0d0010,0x20d2002a}},	//   rhum_, _bofo, _ntac, záis_,
   {{0x200901ef,0x644212ee,0xaabf0e61,0xd0480095}},	//   _afai_, _ecoi, ्विक, əməy,
   {{0x648e01a6,0xbbba0066,0x610100ea,0x00000000}},	//   _cùis, _इश्क, _vēlo, --,
   {{0x6442004f,0x7de7006c,0x20d20453,0x648e01da}},	//   _gcoi, zésé, váis_, _dùis,
   {{0x628a0132,0x4abf1746,0xaabf022e,0x10a31747}},	//   _fofo, ्वाव, ्वाक, тиян,
   {{0x12fa0122,0x443f1748,0x83fd006c,0x6f0d0037}},	//   _והסב, lgu_, zdől, _dtac,
   {{0x2ca0004a,0x443f1749,0x768f0185,0x00000000}},	//   thid_, ogu_, _høys, --,
   {{0x443f174a,0x20d2004f,0x2ca0046a,0x672900de}},	//   ngu_, ráis_, uhid_, _ovej,
   {{0x7de70332,0x9f4400c3,0xaec6174b,0x443f174c}},	// [f80] tésé, ämä_, _обил, igu_,
   {{0x2ca0174d,0xed5a11d0,0x629d0031,0x6b8b01ff}},	//   shid_, _доо_, ësoh, ägga,
   {{0x443f0a4e,0x610800b8,0xd7fa0043,0x8e7b00a5}},	//   kgu_, _těle, оул_, _וניה,
   {{0x648e01da,0x00000000,0x00000000,0x00000000}},	//   _lùir, --, --, --,
   {{0x7c24174e,0x768f03d0,0x921d00be,0x00000000}},	//   mair, _nøys, फराज_, --,
   {{0x7c24174f,0x64420082,0x443f1750,0x245801a5}},	//   lair, _scoi, egu_, _ẩm_,
   {{0x26ce1751,0xa01b008a,0x645b1752,0xd826052c}},	//   rofo_, fjöl, feui, _одви,
   {{0x7c241753,0x628a1754,0x26ce1755,0x443f1756}},	//   nair, _sofo, sofo_, ggu_,
   {{0x64420023,0x648e0284,0x628a1757,0x00000000}},	//   _vcoi, _bùir, _pofo, --,
   {{0x7c241758,0x628a0024,0x443f0409,0x648e0284}},	//   hair, _qofo, agu_, _cùir,
   {{0x3a371759,0x7c24175a,0x60cf002d,0x6f0d175b}},	//   ורים_, kair, tocm, _stac,
   {{0x78a2175c,0xe7f50066,0x645b175d,0x9f350210}},	//   nhov, ुँचा_, ceui, немі,
   {{0x7c24175e,0x23e200df,0x648e009e,0xb4ca175f}},	//   dair, _परिद, _fùir, लकी_,
   {{0x44241760,0x78a20553,0x768f00d4,0x00000000}},	//   lam_, hhov, _høyr, --,
   {{0x20c71761,0x7c241762,0x78a21763,0xa2cb0067}},	//   _осиг, fair, khov, सकर्,
   {{0x7c24066a,0xa3e204bc,0x64401764,0xfaff0031}},	//   gair, _धरा_, ngmi, _orët_,
   {{0x44241765,0x3b550144,0x6f0d1766,0xba2b104b}},	// [f90] iam_, экар, _utac, قسام_,
   {{0x44241767,0x81c90083,0x443f1768,0xe7d20084}},	//   ham_, লেও_, zgu_, _तड़प,
   {{0x44241769,0x6729176a,0x443f176b,0x3835176c}},	//   kam_, _svej, ygu_, енер,
   {{0x4424176d,0x7c24176e,0xe8c900a1,0x672d0b67}},	//   jam_, cair, िकेच, šajm,
   {{0xfe7000b5,0x00000000,0x00000000,0x00000000}},	//   _صدی_, --, --, --,
   {{0x4519176f,0x81c90033,0x443f0090,0xa01b00b5}},	//   пция_, লেট_, wgu_, gköz,
   {{0x44241770,0xddde0035,0x645b00f7,0x00000000}},	//   fam_, _zapł, teui, --,
   {{0x44241771,0x78a2086d,0xfdf80122,0x443f1772}},	//   gam_, chov, וצות_, ugu_,
   {{0x254e0095,0x645b1773,0x610100ea,0x00000000}},	//   _həll_, reui, _vēlm, --,
   {{0x443f0297,0x2d1f0324,0x236d01b4,0x57780079}},	//   sgu_, _बबूल_, rvej_, _تصفح_,
   {{0x236d01b4,0xa06a15c0,0x00000000,0x00000000}},	//   svej_, пана_, --, --,
   {{0x3cf9012f,0xd11b00b4,0x20050067,0x768f03d0}},	//   _nisv_, भीषण_, ślin_, _tøys,
   {{0x442f1774,0x41cf0246,0x7c2400ea,0x9f4c04d4}},	//   _idg_, _सुरस, vair, _ölüm_,
   {{0x78a2024e,0x7c241775,0xa3b80037,0xade400ab}},	//   zhov, wair, _تامر_, _गरदन_,
   {{0x7c241776,0x649c0312,0x69c700da,0x57dc08b0}},	//   tair, _méin, _nxje, _बर्ह,
   {{0x649c004f,0xa01b006c,0x23ce000c,0xda660118}},	//   _léin, zköz, _हुँद, کاري,
   {{0x7c241777,0x69cb027d,0xfa3600d2,0x60c40024}},	// [fa0] rair, şgel, فراد, _ijim,
   {{0x7c241778,0x4a430dee,0xd00f00f8,0xfaff0c6f}},	//   sair, лнув, _پلی_, _arës_,
   {{0x44241779,0x442f177a,0xf2960070,0x7c24177b}},	//   yam_, _odg_, עכער_, pair,
   {{0xafdb177c,0x4424177d,0xaca800b5,0xb05b033b}},	//   mfør, xam_, _کھڑے_, mnäc,
   {{0xe80f0084,0x78a2177e,0xa01b006c,0xaabf00b4}},	//   ाड़ा_, rhov, tköz, ्वशक,
   {{0x4424177f,0x78a21780,0xfaff0055,0x6101013a}},	//   wam_, shov, _erës_, _cēlk,
   {{0xb7bd002d,0x78a2013c,0x4abf021a,0xafdb1781}},	//   _reţe, phov, ्वरव, nfør,
   {{0x60c40496,0xb4ca1782,0x2a6a0024,0x18671783}},	//   _njim, लके_, _habb_, _паси_,
   {{0x64400006,0xe7370896,0x442f01f7,0x98a31784}},	//   rgmi, _пет_, _ddg_, _сите,
   {{0x44241785,0x649c0098,0x60d600ee,0x442f1786}},	//   sam_, _géin, _akym, _edg_,
   {{0xa2a600b4,0x648e009e,0x610800fe,0x3cf308b0}},	//   टोग्, _fùip, _běla, ंगमे_,
   {{0x395800e7,0xafdb10db,0x44241787,0x2a6a0d3e}},	//   _mprs_, dfør, qam_, _labb_,
   {{0x610801c0,0x2d8c1788,0x4477016b,0xb5fc009f}},	//   _děla, äden_, _רעדל_, _raġj,
   {{0x62340043,0xd36f00f8,0x60c4005f,0x00000000}},	//   _реку, _دهه_, _ejim, --,
   {{0xafdb082b,0x7c2f0027,0x00000000,0x00000000}},	//   gfør, _pdcr, --, --,
   {{0x11db0122,0x213e1789,0x225e011e,0x60c4178a}},	//   _מחוב, muth_, letk_, _gjim,
   {{0x213e14d8,0x6fb901e0,0x6ad90033,0x00000000}},	// [fb0] luth_, _ігор_, _ভূগো, --,
   {{0x629a178b,0x60dd038d,0xa9c70171,0x2ebe178c}},	//   nkto, llsm, нсек, ोवृत,
   {{0x649c178d,0xb8120033,0x2bd1018d,0x200b0036}},	//   _réin, _হয়ত_, _थुरा, occi_,
   {{0xb4ca0311,0x4c95095d,0x893407f8,0x00000000}},	//   लको_, _римс, اعلا, --,
   {{0x649c0037,0x442f007b,0x36690226,0x00000000}},	//   _péin, _rdg_, дало_, --,
   {{0x38690528,0x442f009e,0x368b083e,0x6e270e5e}},	//   žar_, _sdg_, ясен_, najb,
   {{0x6abf07b3,0x442f0fce,0x64a5178e,0x1958037c}},	//   ्वीर, _pdg_, кака, _пары_,
   {{0x29110065,0xd1381627,0xdce500f4,0x25ba178f}},	//   _itza_, drą_, _drhć, úpla_,
   {{0x3a230009,0xc48202ee,0x2a6a02ee,0x29031790}},	//   _kejp_, рлык, _yabb_, _huja_,
   {{0x2903000e,0x60d61791,0x649c0079,0xb92800e2}},	//   _kuja_, _skym, _héil, _nhuệ_,
   {{0xa0a61792,0x442f0176,0x10a600d4,0x6e271793}},	//   ванд, _tdg_, винн, dajb,
   {{0x92c30083,0x442f1794,0x29031795,0x4096136c}},	//   ্ষে_, _udg_, _muja_, трот,
   {{0x29030c06,0x6f6300d8,0x68fb0015,0x68e91796}},	//   _luja_, авяз, _miud, _mhed,
   {{0x76431201,0xed5a1797,0x68fb010b,0x200b027a}},	//   ngny, мог_, _liud, acci_,
   {{0x63a91798,0x29031799,0x59d0073f,0x60c40107}},	//   lzen, _nuja_, _तुंर, _tjim,
   {{0xafdb03db,0x6fb60037,0x27ff179a,0x649c0098}},	//   rfør, _لمعا, _ngun_, _néil,
   {{0x63a9179b,0xafdb11cb,0x2a6a0024,0xab27179c}},	// [fc0] nzen, sfør, _pabb_, кота_,
   {{0x63a913ee,0x68e9179d,0x68fb0069,0x27ff0118}},	//   izen, _ahed, _aiud, _agun_,
   {{0x6cc606d8,0x68e9009e,0x29030279,0x68fb010b}},	//   _айна, _bhed, _cuja_, _biud,
   {{0x68fb179e,0x649c0037,0x6f04002f,0x779400d1}},	//   _ciud, _céil, _kuic, هیزا,
   {{0x6d4e179f,0x649c0037,0x68e917a0,0x2d9800b5}},	//   ltba, _déil, _dhed, lyre_,
   {{0x63a917a1,0x27ff03cb,0x6d4e0345,0x6f040098}},	//   dzen, _egun_, otba, _muic,
   {{0x649c004f,0x2d9817a2,0x684617a3,0xb5fc035f}},	//   _féil, nyre_, _инва, _jaġi,
   {{0x68fb01d3,0x68e917a4,0x7afc17a5,0x3eb817a6}},	//   _giud, _ghed, _hirt, hirt_,
   {{0x69dc17a7,0x6f040160,0x6d4e17a8,0x44f71301}},	//   _hyre, _nuic, htba, خروج_,
   {{0x7afc007a,0xd13817a9,0x6d4e0532,0x61080355}},	//   _jirt, trą_, ktba, _děln,
   {{0x2d980031,0x63a901ed,0x6d4e0051,0x7afc08a3}},	//   jyre_, azen, jtba, _mirt,
   {{0x6f04004f,0x69dc17aa,0x213e006b,0x2366006d}},	//   _buic, _myre, ruth_, _tsoj_,
   {{0x63a90755,0x7afc09c3,0x6d4e17ab,0x6f040069}},	//   czen, _oirt, etba, _cuic,
   {{0x6f0417ac,0xf77300a5,0x6d4e06c6,0x00000000}},	//   _duic, בקש_, ftba, --,
   {{0x6fd30035,0xb5fc035f,0x69dc17ad,0x5c07021f}},	//   _धुरं, _baġi, _nyre, вяза,
   {{0x7afc0082,0x3eb80094,0x672d00ea,0x2fc9006d}},	//   _airt, airt_, šaji, _txag_,
   {{0x649c004f,0x7afc17ae,0x68e9001e,0x6f0417af}},	// [fd0] _réil, _birt, _rhed, _guic,
   {{0x68e917b0,0x290317b1,0x64950037,0x69dc17b2}},	//   _shed, _puja_, _háit, _byre,
   {{0xdd95081b,0x69dc17b3,0x63a917b4,0x68e9016e}},	//   _саны, _cyre, zzen, _phed,
   {{0x69dc17b5,0xf8d100c8,0x7afc05b9,0x20d917b6}},	//   _dyre, িষ্ঠ, _eirt, méis_,
   {{0xab8417b7,0x649c0037,0x68fb17b8,0x610100ea}},	//   _курк, _céim, _viud, _vēli,
   {{0xf77000d2,0x64950082,0x4aa700c0,0x0dba006c}},	//   غان_, _láit, _गतिव, _آئیں_,
   {{0x68e917b9,0x20d917ba,0x6fd50026,0xb8120033}},	//   _thed, néis_, _युसू, _হযরত_,
   {{0x2005004e,0x63a917bb,0x764800d7,0x7bdd01ba}},	//   ślij_, tzen, _ecdy, _kysu,
   {{0xe89400c3,0x69dc0055,0x659306fe,0x61080355}},	//   _тать, _zyre, _běhá, _bělo,
   {{0x63a917bc,0x454517bd,0x6f04009e,0x386d0312}},	//   rzen, _منطق, _ruic, _haer_,
   {{0x63a917be,0x386d0553,0x20d902d7,0x6d4e0282}},	//   szen, _kaer_, jéis_, xtba,
   {{0x20d917bf,0x237506c9,0x71a2010b,0x386d03d0}},	//   déis_, _ماتح, саюз, _jaer_,
   {{0x6f0417c0,0x386d0032,0x6e25013b,0xd12e00e0}},	//   _quic, _maer_, _behb, يمی_,
   {{0x2d9803b4,0x386d053e,0x6d4e17c1,0x332d0479}},	//   tyre_, _laer_, ttba, msex_,
   {{0xed5709eb,0x09be00c8,0x6da317c2,0x2d9e0237}},	//   лор_, _অর্থ, бира, áte_,
   {{0x6f0417c3,0x09e20033,0x7d0500e0,0x7bdd00e5}},	//   _tuic, _বললা, _duhs, _bysu,
   {{0x2d9e17c4,0x09be0931,0x7afc17c5,0x3eb801f4}},	// [fe0] šte_, ्थ्य, _pirt, pirt_,
   {{0x649c004f,0x20d917c6,0x0e6617c7,0x0d8617c8}},	//   _réim, béis_, _скон, _блон,
   {{0x386d0526,0x20d900de,0xddde00ea,0x649c0079}},	//   _baer_, céis_, _sapņ, _séim,
   {{0x7afc17c9,0x386d17ca,0x20d90037,0x64950037}},	//   _wirt, _caer_, léir_, _máis,
   {{0x7afc17cb,0x386d00e5,0x2b400176,0x69dc17cc}},	//   _tirt, _daer_, quic_, _wyre,
   {{0x356a141d,0xe94400f8,0x7afc0037,0x20d9004f}},	//   ерин_, _پرسی, _uirt, néir_,
   {{0x2aa40332,0x64950082,0x7c2607d4,0x776901ef}},	//   _több_, _náis, _kekr, _esex,
   {{0x386d016e,0xa01b17cd,0xb97b076b,0x297b016b}},	//   _gaer_, ljöv, _אנלי, _אטלא,
   {{0x6495004f,0x5c370070,0xae0400b4,0x7c2617ce}},	//   _ráit, ארפן_, लशान_, _mekr,
   {{0x59b80162,0x4154107a,0x7c2617cf,0x326617d0}},	//   _आधार, авос, _lekr, утив,
   {{0x6e2501d6,0xdd120095,0xba570070,0x5bc1046c}},	//   _rehb, _rüşv, נסטו_, _एश्व,
   {{0x7c2617d1,0x629d01f4,0x7d05027d,0x00000000}},	//   _nekr, ësor, _ruhs, --,
   {{0xe29a17d2,0xe0df027a,0x61080355,0x91fc00ea}},	//   _пад_, rlò_, _tělo, edāt,
   {{0x20d917d3,0x4ea705d8,0x44260019,0x7bdd0035}},	//   téis_, урма, _heo_, _rysu,
   {{0x7c260e45,0x442617d4,0x254e00a8,0x6e2517d5}},	//   _bekr, _keo_, _bəli_, _vehb,
   {{0x6495004f,0x20d917d6,0x44260506,0x3ce001cf}},	//   _háir, réis_, _jeo_, gliv_,
   {{0x7c2617d7,0x442617d8,0x20d917d9,0x2d8c01cf}},	// [ff0] _dekr, _meo_, séis_, øder_,
   {{0x442617da,0x20d917db,0x39a717dc,0x7bdd0097}},	//   _leo_, péis_, лшев, _vysu,
   {{0x64950037,0x7c260024,0x386d01f7,0xb5fc0024}},	//   _máir, _fekr, _paer_, _kaġu,
   {{0x4426004a,0x7c260136,0xddde01c0,0xb4c0000c}},	//   _neo_, _gekr, _např, ूको_,
   {{0xd3660796,0xddd701c2,0x2ca9004f,0x00000000}},	//   _به_, _yaxş, mhad_, --,
   {{0xd1260037,0x2ca90024,0x4426010d,0x9a8702a4}},	//   _وم_, lhad_, _aeo_, _сумл,
   {{0x442617dd,0x1ddb021a,0x00000000,0x00000000}},	//   _beo_, _मुमत, --, --,
   {{0xf1cf167e,0x44260f00,0xa4230831,0x00000000}},	//   _सुगन, _ceo_, ফল্য_, --,
   {{0x442617de,0xd05d0095,0x730500ed,0x64950079}},	//   _deo_, _üzər, јпоз, _báir,
   {{0x64950037,0xe29903fa,0x332d081c,0x7eab02b1}},	//   _páis, тао_, rsex_, _hüpf,
   {{0x008617df,0x44261725,0x91e517e0,0x067a0317}},	//   ално, _feo_, роне, _שנעל,
   {{0x2c150785,0x672d011c,0x00000000,0x00000000}},	//   _फ्लू_, šaju, --, --,
   {{0x81bd00c8,0x249f011e,0x20d90079,0x6459007b}},	//   _আরও_, mkum_, téir_, _ibwi,
   {{0xe29614a9,0x03a20036,0x249f05ee,0x64950037}},	//   _ваш_, _фишо, lkum_, _gáir,
   {{0x20d9004f,0x44260159,0x8cb617e1,0x3ce010fa}},	//   réir_, _yeo_, асач, tliv_,
   {{0x248d0496,0x44260391,0x2ca917e2,0x64ba0484}},	//   njem_, _xeo_, ghad_, nċip,

   {{0x3b0717e3,0x249f17e4,0x3b86005f,0x20d90079}},	// [1000] ието_, ikum_, шлаг, péir_,
   {{0x3ce00307,0x249f05f9,0x248d08c8,0x3f8f021d}},	//   sliv_, hkum_, hjem_, _àgua_,
   {{0x249f17e5,0x7c2601d6,0xb4f70d1f,0x186a11cd}},	//   kkum_, _tekr, ुदाय_, кажи_,
   {{0x315600c2,0x6d5e035f,0x2ca90014,0x248d0484}},	//   ייען_, _ippa, chad_, jjem_,
   {{0x248d17e6,0x91fc0029,0x00000000,0x00000000}},	//   djem_, ndār, --, --,
   {{0x442617e7,0x645917e8,0xfaa6075c,0x249f0051}},	//   _seo_, _abwi, _таго, ekum_,
   {{0x442617e9,0x26c000f4,0x8af0013b,0xfc3f07c0}},	//   _peo_, đio_, ttəf, _ulíc_,
   {{0xd7660332,0x248d0031,0x61130160,0xd4970421}},	//   _پارٹ, gjem_, _măld, иры_,
   {{0x64950082,0x442617ea,0xf2c60009,0xb5fc003c}},	//   _páir, _veo_, исон, _raġu,
   {{0x6d5e17eb,0x68e217ec,0x248d0207,0xd25701e0}},	//   _oppa, llod, ajem_, ацю_,
   {{0x442617ed,0x672d17ee,0x64a617ef,0x6913007a}},	//   _teo_, šajt, _кажа, _għed,
   {{0x644b011e,0x249f17f0,0xd83f053d,0xd13000b5}},	//   _gcgi, ckum_, _účtu_, _ہمت_,
   {{0x64950082,0x6d5e0dc5,0x58f70070,0x00000000}},	//   _táir, _appa, ימטע_, --,
   {{0xd0650095,0x539b00a5,0x3ea500b5,0x6101013a}},	//   _əsər, _בידו, ólt_, _cēls,
   {{0xdd980009,0x2ca901a6,0x3cf317f1,0x611300af}},	//   ашт_, thad_, ंगले_, _căld,
   {{0x76b20035,0xbd440037,0x00000000,0x00000000}},	//   pływ, تنفي, --, --,
   {{0x90a70493,0x2ca917f2,0x5a3502fb,0xb6030097}},	// [1010] _محکم, rhad_, йнат, áško,
   {{0xda780086,0x2ca917f3,0x657a17f4,0x249f0355}},	//   иях_, shad_, _orth, zkum_,
   {{0xceb2012b,0x83fd006c,0x249f17f5,0x7b090168}},	//   _זיי_, ndőr, ykum_, _kľuk,
   {{0x68e217f6,0x0a5505f5,0x00000000,0x00000000}},	//   glod, _گھرج, --, --,
   {{0x7c2d17f7,0xfc3f002a,0x291a0714,0x6d4105ee}},	//   maar, _glía_, appa_, álaf,
   {{0x7c2d0276,0x7b3d0139,0x00000000,0x00000000}},	//   laar, _căuş, --, --,
   {{0x63721505,0x248d008b,0x6d9e035f,0xd57517f8}},	//   yınç, tjem_, _għaġ, суль,
   {{0x58d417f9,0x7c2d17fa,0xc4850d6e,0x64950079}},	//   _дост, naar, слик, _cáip,
   {{0xf7730148,0x248d17fb,0x657a001e,0x249f0093}},	//   _باز_, rjem_, _erth, rkum_,
   {{0x249f17fc,0xd5bb00af,0x248d0a66,0x777b01ed}},	//   skum_, _исе_, sjem_, _irux,
   {{0x7c2d17fd,0x6f1617fe,0xfa98016b,0x00000000}},	//   kaar, _styc, ידזש_, --,
   {{0x64590232,0x7c2d17ff,0x777b0282,0x00000000}},	//   _ubwi, jaar, _krux, --,
   {{0x442d1800,0x7c2d1801,0xe28e0043,0xf45608cf}},	//   mae_, daar, _еа_, _طلوع_,
   {{0x442d1802,0x64491803,0xd8390107,0xc7d61804}},	//   lae_, lgei, _blōk_, מורי_,
   {{0x7c2d1805,0x6da30ece,0xf1cf112b,0xada31102}},	//   faar, пира, _सुचन, парл,
   {{0x7c2d1806,0x442d1807,0xdd8f0e6b,0x00000000}},	//   gaar, nae_, روق_, --,
   {{0x09b500c8,0xbebb00da,0x7e9a0a72,0x00000000}},	// [1020] _জুলা, rsër, _منظر_, --,
   {{0xe3a70332,0x442d1808,0x2ca000c4,0xe7db0387}},	//   _ہر_, hae_, skid_, _बड़प,
   {{0x9e7b02b5,0x7c2d11c9,0x6d5e1809,0x442d04be}},	//   _ענטפ, baar, _uppa, kae_,
   {{0x6c86180a,0x6e2e180b,0x442d0088,0xe3a7083a}},	//   _الحم, labb, jae_, _فر_,
   {{0x628311cc,0x777b01ef,0xddd50355,0xb8d00387}},	//   _onno, _crux, dezř, _ओत_,
   {{0x68e2180c,0xcd290ef5,0x5693059d,0x6e2e180d}},	//   slod, _حسین_, зашт, nabb,
   {{0x2b400815,0x64950037,0xb9960037,0x00000000}},	//   lric_, _páip, _الزب, --,
   {{0x6283180e,0x6e2e180f,0x290a011e,0x5fc800a9}},	//   _anno, habb, _iuba_, रपाल,
   {{0xdc9b00c2,0x213e0297,0x78a20187,0x657a001e}},	//   טיקל, wrth_, mkov, _wrth,
   {{0x290a1810,0x78a21811,0x6e2e1812,0x7c2d030d}},	//   _kuba_, lkov, jabb, zaar,
   {{0x290a0006,0x442d0269,0xd48f1813,0x867b0122}},	//   _juba_, bae_, _ер_, _תרבו,
   {{0x442d1814,0x6283018e,0x7d1c0097,0x290a1815}},	//   cae_, _enno, dprs, _muba_,
   {{0x7c2d1816,0x2bd80992,0x43941817,0x6e2e1818}},	//   vaar, _भुला, _фалс, fabb,
   {{0x29181819,0x7c2d0a45,0xa01b0093,0xe33700a5}},	//   _otra_, waar, gjör, _פרופ_,
   {{0x7c2d181a,0x8af00095,0x6ca700d4,0x2a710009}},	//   taar, ktəb, браж, _razb_,
   {{0x2b40053f,0xfc3f008d,0x00000000,0x00000000}},	//   fric_, _elín_, --, --,
   {{0x7c2d181b,0x78a2024e,0x2918099e,0x6e2e003c}},	// [1030] raar, dkov, _atra_, babb,
   {{0x7c2d181c,0xff50004f,0x290a181d,0x442d034d}},	//   saar, _أخي_, _buba_, zae_,
   {{0x290a181e,0x2918181f,0x78a21550,0x6d410079}},	//   _cuba_, _ctra_, fkov, álad,
   {{0x6d470805,0xec6b07b0,0xfc3f00b8,0x26cc023a}},	//   muja, _срок_, _zlín_, _ajdo_,
   {{0x6d5503cb,0x442d023c,0x60cd08c7,0x290a1820}},	//   ltza, vae_, _mjam, _euba_,
   {{0x442d0858,0x29071821,0x78a20168,0x2bc601c0}},	//   wae_, ínas_, akov, लपरा,
   {{0x6d5503cb,0x290a1822,0x78a20187,0x6d471823}},	//   ntza, _guba_, bkov, nuja,
   {{0x78a21824,0x67d50185,0x6d5506a2,0x60cd1825}},	//   ckov, _добу, itza, _njam,
   {{0x442d1826,0x98680332,0x290a1827,0x6d4711e7}},	//   rae_, _دینے_, _zuba_, huja,
   {{0xadf9045c,0x27ed01d7,0x64491828,0x60cd1829}},	//   ंधान_, _izen_, sgei, _ajam,
   {{0x208a02fb,0x6f1d0051,0x61130395,0x71b50421}},	//   айни_, epsc, _sălb, ющих,
   {{0x25d60779,0x6d47016f,0x3eba022e,0x6abe0371}},	//   _ווען_, duja, _smpt_, zipf,
   {{0x6e2e035f,0x60cd182a,0x78a9182b,0x61130139}},	//   tabb, _djam, _mlev, _bălc,
   {{0x78a9182c,0x6283182d,0x78a20187,0x224e0009}},	//   _llev, _unno, zkov, _gcfk_,
   {{0x6e2e182e,0x78a9066e,0xde0302ce,0x7c96182f}},	//   rabb, _olev, дпри, орац,
   {{0x290a1830,0x6e2e00b5,0x2b401831,0x8b260c46}},	//   _ruba_, sabb, tric_, ждае,
   {{0x78a200ac,0x6d5506a2,0x7eab01d6,0x765c008a}},	// [1040] vkov, atza, _süpe, _öryg,
   {{0x6d471832,0x2b400024,0x78a91833,0x61e30093}},	//   buja, rric_, _alev, _kynl,
   {{0x78a90022,0x656101e8,0x2d78011c,0xe96a150d}},	//   _blev, _nplh, _uče_, раел_,
   {{0x290a0010,0x80370070,0x13e10033,0xbb1b099e}},	//   _vuba_, ַנצע_, মেয়, _brîd,
   {{0x8af000a8,0x61e30b3e,0x236f034d,0x00000000}},	//   rtəb, _lynl, _nsgj_, --,
   {{0x78a21834,0x649c004f,0x7b091835,0x290a1836}},	//   skov, _léit, _džud, _tuba_,
   {{0x98a61837,0x27ed1838,0x78a91839,0xb8660427}},	//   _диве, _ezen_, _flev, _وارو,
   {{0x78a901f7,0xd91b011d,0x00000000,0x00000000}},	//   _glev, _כולל, --, --,
   {{0xccf30bed,0x316e00ee,0x00000000,0x00000000}},	//   וכה_, _ssfz_, --, --,
   {{0x60cd183a,0x78a906fe,0xc178010b,0x2904034d}},	//   _sjam, _zlev, tvė_, _hima_,
   {{0x61e302c7,0x290408c7,0x649c0079,0x52aa0387}},	//   _cynl, _kima_, _béit, _छतीस,
   {{0x7413183b,0x29040116,0x61130160,0x61e3099e}},	//   _قوما, _jima_, _sălc, _dynl,
   {{0x2486183c,0x78fb025a,0x649c183d,0x00000000}},	//   _inom_, יפטו, _déit, --,
   {{0x26dc05e2,0x6d47183e,0x00000000,0x00000000}},	//   novo_, tuja, --, --,
   {{0x61e3001e,0x361b0070,0xdcbb01d3,0x00000000}},	//   _gynl, שולד, аща_, --,
   {{0x5b15183f,0x290402c6,0x6d550291,0x62981840}},	//   змат, _nima_, rtza, _hovo,
   {{0x248603fd,0x62981841,0x63a00bca,0x6d551167}},	// [1050] _mnom_, _kovo, nymn, stza,
   {{0x62981842,0x78a901c0,0x6d471843,0x60dd1844}},	//   _jovo, _slev, puja, losm,
   {{0x29041845,0x24860254,0x26dc1846,0x89d9004f}},	//   _bima_, _onom_, dovo_, حوار_,
   {{0xf7710082,0x62980081,0x2904031a,0x6f0d000e}},	//   فات_, _lovo, _cima_, _kuac,
   {{0x7c220b4c,0x78a90355,0x0a6b0274,0x61130160}},	//   ñore, _vlev, _крви_, _măla,
   {{0xd6db1847,0x26dc1848,0x2486027c,0x6f0d1849}},	//   ште_, govo_, _anom_, _muac,
   {{0x6f0d009c,0x29040207,0x170500b5,0xa95401e0}},	//   _luac, _fima_, _کہتی_, _окрі,
   {{0x78bb0010,0x27ed01d7,0x2009184a,0x2904184b}},	//   _umuv, _tzen_, _ngai_, _gima_,
   {{0x6f0d0082,0x649c004f,0xf770006c,0x62981499}},	//   _nuac, _réit, _لال_, _bovo,
   {{0xd2a90086,0x6298184c,0x649c184d,0x248600f8}},	//   ское_, _covo, _béis, _enom_,
   {{0x6298184e,0x2b4902d7,0x6729009f,0x61130395}},	//   _dovo, huac_, _hwej, _băla,
   {{0x92cb0083,0x6f0d184f,0x61130139,0x649c0098}},	//   লতে_, _buac, _căla, _déis,
   {{0x61fe0076,0x6f0d1850,0x7ea200f7,0xb7bd0139}},	//   _úpln, _cuac, _hôpi, _beţi,
   {{0x62981851,0x523902b5,0x59bd052f,0xe3b00609}},	//   _govo, _הײַנ, ्पार, _جرم_,
   {{0xf3f9002d,0xb7bd002d,0x649c183d,0x610800fe}},	//   deţi_, _deţi, _géis, _bělu,
   {{0x649c004f,0x6ab40066,0x26dc1852,0x236d0035}},	//   _héir, ंफ्र, zovo_, owej_,
   {{0x6b631853,0x7b090409,0x69c30042,0x00000000}},	// [1060] нкта, _ažub, únen, --,
   {{0x6d410082,0x29041854,0xf3f900af,0x2cab00e0}},	//   álac, _sima_, geţi_, _elcd_,
   {{0xfe9b02b5,0x5e9b00a5,0x29041855,0x7e9b00a5}},	//   _היימ, _הביק, _pima_, _הסיו,
   {{0x649c0082,0xa2bb1856,0x7b090693,0x67291857}},	//   _léir, षोत्, _džub, _bwej,
   {{0x7c241642,0x26dc1851,0x66e61858,0x7eab018d}},	//   mbir, tovo_, пода, _hüpa,
   {{0x7c241859,0xb6030187,0xf3f9002d,0xd65e005f}},	//   lbir, _otáč, ceţi_, _мiнд,
   {{0x7d06185a,0x2904185b,0x24860009,0x6298185c}},	//   _kiks, _tima_, _pnom_, _rovo,
   {{0x7c24185d,0x649c0341,0x629802a7,0x7d06003c}},	//   nbir, _réis, _sovo, _jiks,
   {{0x629815d8,0x7d06185e,0x26dc02c4,0xe646185f}},	//   _povo, _miks, povo_, _неап,
   {{0x7d061860,0x649c1861,0x0bb700a5,0x2cfa111a}},	//   _liks, _céir, פלים_, ्दुल_,
   {{0x7c241862,0xb7bd00af,0x649c0098,0x6f0d1863}},	//   kbir, _reţi, _déir, _suac,
   {{0x7d061864,0x75d30037,0x2486043d,0x629802b1}},	//   _niks, _ثيما, _unom_, _wovo,
   {{0x7c241865,0x6298008b,0x6f0d1866,0xdfdb02fb}},	//   dbir, _tovo, _quac, сън_,
   {{0xd24f004f,0xdb23006c,0x7c241867,0xb60300ee}},	//   _منه_, ہوری, ebir, _ftáč,
   {{0xa2d90803,0x7d061868,0x51860368,0x3f80005f}},	//   नकर्, _biks, _хула, _eriu_,
   {{0x4424012f,0x6f0d1869,0x2a7f0225,0x00000000}},	//   nbm_, _tuac, _şub_, --,
   {{0x2d8c186a,0x7d06186b,0xddde00a8,0xf3f90043}},	// [1070] äder_, _diks, _tapş, teţi_,
   {{0xa577012e,0xed4e00b5,0x7c24018e,0x0dcb186c}},	//   ščić, دھی_, abir, _гуми_,
   {{0x7c24186d,0xa907186e,0x00000000,0x00000000}},	//   bbir, سبان, --, --,
   {{0xe9f801e0,0x00000000,0x00000000,0x00000000}},	//   їнці_, --, --, --,
   {{0x3b640021,0x6913007a,0x00000000,0x00000000}},	//   _първ, _għen, --, --,
   {{0x644700d8,0x4519186f,0x3ce901e9,0x00000000}},	//   ėjim, оция_, llav_, --,
   {{0x2d571870,0x7e771871,0x67240029,0x7c2f1872}},	//   nçe_, _maxp, ģija, _kecr,
   {{0xc95200a5,0x8af000a8,0x2d81023a,0x031900e0}},	//   _שמן_, ntən, _mrhe_, يتخت_,
   {{0x2d5701d6,0x645b009e,0x649c0079,0xfc3f00fe}},	//   hçe_, rfui, _péir, _alík_,
   {{0x2d57027d,0x3ce900d5,0x99910116,0x957c0067}},	//   kçe_, hlav_, _zdzš_, _cząs,
   {{0x3ce902d0,0x904600bf,0xa06a1873,0x9f49021d}},	//   klav_, ونده, оана_, _dzaí_,
   {{0xcea914b0,0x7c2f1874,0x7c24013b,0x3f800c6f}},	//   _די_, _necr, xbir, _priu_,
   {{0x7d061875,0x442f00ee,0x610800fe,0xe2a800e0}},	//   _riks, _ieg_, _běls, زاین_,
   {{0x7d061876,0x442f1877,0xc332025a,0xa1c501e0}},	//   _siks, _heg_, _יוד_, _облд,
   {{0xfce61878,0x69d5021d,0x8af0013b,0x00000000}},	//   дово, _nxze, ftən, --,
   {{0x442f1879,0x3ce9177a,0x3cf80035,0x7c2f187a}},	//   _jeg_, glav_, ंगें_, _cecr,
   {{0x442f187b,0x7c24187c,0x7c2f187d,0x46dd111a}},	// [1080] _meg_, rbir, _decr, यवाह,
   {{0x7d06187e,0x4a4303e6,0x7c24187f,0xda660037}},	//   _wiks, кнув, sbir, باري,
   {{0x7d061880,0xa96a1168,0x3ce901ed,0x00000000}},	//   _tiks, تمام_, blav_, --,
   {{0x442f02e9,0x3ce90314,0x7c2f1881,0x53ad00dc}},	//   _neg_, clav_, _gecr, टनाश,
   {{0xd7f70132,0x69d502b1,0x291c004b,0x00000000}},	//   муш_, _exze, ūva_, --,
   {{0x442f0006,0x64d60907,0x7c2f0103,0x00000000}},	//   _aeg_, डक्श, _zecr, --,
   {{0x442f1882,0x98560009,0xafdb0c71,0x443d0024}},	//   _beg_, _оташ, ngør, _bdw_,
   {{0x442f006f,0xb8660118,0xb05b1883,0x9855010b}},	//   _ceg_, _تاسو, nnät, _птуш,
   {{0x442f0a55,0xfc3f0093,0x443d0090,0x2a780069}},	//   _deg_, _slík_, _ddw_, _karb_,
   {{0x3958006d,0x67220409,0x00000000,0x00000000}},	//   _kqrs_, mpoj, --, --,
   {{0xa3de065a,0x67220080,0x443d00de,0x442f1884}},	//   _दुर_, lpoj, _fdw_, _feg_,
   {{0x3cfa004e,0x442f1885,0x3cf80035,0x14170037}},	//   ्दों_, _geg_, ंगों_, _قيمة_,
   {{0xceeb1629,0x7c2f047e,0x5f9402fb,0x26ce07e5}},	//   قرآن_, _recr, вият, onfo_,
   {{0x7c2f1886,0x442f0120,0x2d570225,0x00000000}},	//   _secr, _zeg_, tçe_, --,
   {{0x26ce1887,0x9d181888,0xafdb01b4,0x443d00e9}},	//   info_, дост_, ggør, _ydw_,
   {{0x2cb2001e,0x9f5500d4,0x2d571889,0x6aae0055}},	//   ghyd_, _звич, rçe_, _albf,
   {{0x7c22188a,0x7c2f0228,0x7e770f00,0x00000000}},	// [1090] ñora, _vecr, _taxp, --,
   {{0xe9ab0698,0x7d1e0051,0x672200d5,0x8af0013b}},	//   يدان_, _ftps, dpoj, stən,
   {{0x7c2f01d6,0x7b090009,0x2a78188b,0x3d250107}},	//   _tecr, _džua, _darb_, _dèwò_,
   {{0x2cb20297,0x628a011e,0x201900b5,0x2a78009e}},	//   chyd_, _lnfo, ncsi_, _earb_,
   {{0x442f188c,0x628a0069,0xb8d70299,0x23660221}},	//   _reg_, _onfo, _छत_, _npoj_,
   {{0x442f0a55,0x649c0079,0xddd500fd,0x9967188d}},	//   _seg_, _séip, lező, _отбл,
   {{0x26c90254,0x442f188e,0x00000000,0x00000000}},	//   đao_, _peg_, --, --,
   {{0x628a188f,0x2ca91890,0x00000000,0x00000000}},	//   _anfo, nkad_, --, --,
   {{0x442f1891,0x130502c4,0xe3b10037,0x29110027}},	//   _veg_, нзим, طرة_, _huza_,
   {{0x442f1892,0x291101d5,0x5fda052f,0x31250210}},	//   _weg_, _kuza_, _युगल, ндог,
   {{0x442f1893,0x2ca91894,0x2f1401ff,0x5fc500b4}},	//   _teg_, kkad_, _säg_, _लेबल,
   {{0x8cc10324,0xb05b02ee,0x628a1895,0x442f1896}},	//   रोमो, siän, _enfo, _ueg_,
   {{0xc00000c8,0xe3ae1897,0x2ca91898,0xd9bd018d}},	//   ূর্ণ_, _сб_, dkad_, ्पुट,
   {{0x539a1899,0x2f14022a,0xafdb08c8,0x29110260}},	//   _מינו, _väg_, tgør, _ouza_,
   {{0x98a700b8,0x6d41023a,0xacf610b4,0xc8790160}},	//   éně_, šlan, ечај, _oaş_,
   {{0x2ca9010d,0xfce30fc5,0xc8790160,0x2a780160}},	//   gkad_, госо, _naş_, _sarb_,
   {{0x60d700a5,0x3a31189a,0xca860409,0x4aaa081b}},	// [10a0] _רופא_, _bezp_, нгай, пкан_,
   {{0x2911189b,0x60c6189c,0x69130024,0x00000000}},	//   _buza_, likm, _iħej, --,
   {{0xc8790669,0xdca6189d,0xb05b0523,0xc8660c94}},	//   _baş_, _зани, mnär, етли,
   {{0x60c60464,0x6d4e189e,0x2ca9013c,0x48be0033}},	//   nikm, muba, ckad_, ইক্র,
   {{0x6d4e189f,0xb05b18a0,0x7c360430,0xc879013b}},	//   luba, onär, mayr, _daş_,
   {{0xb05b16c9,0x26ce18a1,0x7c36013b,0x2f3b016b}},	//   nnär, unfo_, layr, לגנד,
   {{0x672203a5,0x291118a2,0x550600af,0x00000000}},	//   spoj, _guza_, нчиа, --,
   {{0x6d5c18a3,0xb05b02b1,0x09e318a4,0x67220421}},	//   itra, hnär, _сосн, ppoj,
   {{0x6d4e18a5,0x68e200ab,0x00000000,0x00000000}},	//   huba, mood, --, --,
   {{0x6d4e18a6,0x8af00095,0x68e218a7,0x95e800b5}},	//   kuba, xtəl, lood, _قبضہ_,
   {{0xc87906d3,0x6d5c18a8,0xe3af0148,0x6d4e0088}},	//   _yaş_, jtra, لری_, juba,
   {{0xe61f0028,0x68e218a9,0x6d5c18aa,0xd138010b}},	//   _đôi_, nood, dtra, rsą_,
   {{0xb4be1404,0xdefb00c3,0x6d5c0553,0x6d4e18ab}},	//   ुची_, зыв_, etra, euba,
   {{0x6d5c18ac,0x628a00a5,0xbb1b0139,0xb8160033}},	//   ftra, _unfo, _brîn, ারিত_,
   {{0x6d5c18ad,0x6d4e18ae,0x68e218af,0x6e3518b0}},	//   gtra, guba, kood, razb,
   {{0x614303fa,0x8af00095,0xdef8003c,0x68e200be}},	//   _сећа, stəl, ċċa_, jood,
   {{0x29110c0a,0x6d5c0ca9,0x2ca918b1,0x3d11018d}},	// [10b0] _suza_, atra, rkad_, _दूरे_,
   {{0x2ca918b2,0xbb1b0160,0x8af0013b,0x29110207}},	//   skad_, _frîn, qtəl, _puza_,
   {{0xd5df0302,0x7c3618b3,0xc98418b4,0x67200118}},	//   _पुंज, bayr, луци, _atmj,
   {{0x61ea18b5,0xcd9600a5,0x7afe0b88,0x00000000}},	//   _myfl, _סדרת_, ampt, --,
   {{0x4c9a02b8,0xd7630220,0x00000000,0x00000000}},	//   _חברו, انتی, --, --,
   {{0x07a218b6,0xc66803fa,0xc7a20009,0xa3de01c0}},	//   рашн, ешће_, ришк, _दुइ_,
   {{0x68e201bf,0xc879027d,0x20e102b4,0x7ea200ee}},	//   bood, _taş_, नवाध, _kôpr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3de0084,0x6d4e18b7,0x6d5c18b8,0x67d418b9}},	//   _दुआ_, zuba, ztra, _боту,
   {{0x6d5c18ba,0x6d4e18bb,0x386f0124,0x8cc10067}},	//   ytra, yuba, legr_, रोतो,
   {{0x61ea02c7,0x26c718bc,0x60c618bd,0x3dc60033}},	//   _cyfl, mino_, tikm, _শুনল,
   {{0xf4850332,0x6d5c18be,0x2b490506,0x3cf90298}},	//   _جائی, vtra, krac_, _nhsv_,
   {{0x7fd603d0,0x6d5c18bf,0x3f8401c0,0x80ca0722}},	//   тіні, wtra, ímu_, ाचौं,
   {{0x6d5c18c0,0x6d4e18c1,0x60c618c2,0x2b490506}},	//   ttra, tuba, sikm, drac_,
   {{0x61ea0297,0xed5718c3,0xddc318c4,0x00000000}},	//   _gyfl, кор_, абри, --,
   {{0x6d4e18c5,0x26c718c6,0x6d5c18c7,0x8c430279}},	//   ruba, hino_, rtra, иесе,
   {{0x26c718c8,0x6d4e18c9,0x387d00e9,0x8af000a8}},	// [10c0] kino_, suba, ddwr_, stəm,
   {{0x26c718ca,0x7c3618cb,0x0f370070,0xbb1b0160}},	//   jino_, sayr, _שריט_, _trîn,
   {{0x26c718cc,0x68e200ab,0xa3de000c,0xfbd100b5}},	//   dino_, tood, _दुई_, لتے_,
   {{0xdca618cd,0xd30800e2,0x7641008c,0x26c701ef}},	//   _рами, _hệt_, _adly, eino_,
   {{0xdb0a0098,0x2c170067,0x60c4034d,0x00000000}},	//   únói, धुओं_, _mmim, --,
   {{0x26c718ce,0xb05b033b,0x68e218cf,0x00000000}},	//   gino_, hnäp, sood, --,
   {{0xceb30052,0xd3080019,0xd5af017e,0xd04800a8}},	//   שיו_, _mệt_, يفه_, şməy,
   {{0x98a318d0,0xb4be0b57,0x60c40159,0x982800fd}},	//   _кисе, ुचे_, _nmim, _سترہ_,
   {{0x26c718d1,0xf9f40033,0xd4670200,0x00000000}},	//   bino_, _জলিল_, тиње_, --,
   {{0x26c718d2,0x00000000,0x00000000,0x00000000}},	//   cino_, --, --, --,
   {{0x3a3700a5,0x403518d3,0xaa370070,0x78a0017b}},	//   כרים_, ленс, כטיק_, _komv,
   {{0x93461412,0x30a718d4,0x6abf045c,0x60c40031}},	//   _анде, тров, _एग्र, _cmim,
   {{0x2d8c0b6c,0x644218d5,0x2d9e18d6,0x7d0300d1}},	//   åden_, _idoi, äten_, _ènsi,
   {{0x41dd0e1d,0x60c418d7,0x61ea00d5,0x00000000}},	//   _नुकस, _emim, _tyfl, --,
   {{0x7b090df4,0xd3080019,0x2d850079,0x00000000}},	//   _džul, _dệt_, íle_, --,
   {{0xc0ab1328,0x2b4918d8,0x629a00cd,0x60d60031}},	//   _زابل_, trac_, ljto, _gjym,
   {{0x0bf518d9,0x59d50066,0x1be318da,0x3e1900af}},	// [10d0] упаю, _दशहर, _कुशल_, _попэ_,
   {{0x26c7002a,0xdd0300d0,0x629a0031,0x6d4818db}},	//   xino_, ırıc, njto, ádac,
   {{0x26c718dc,0x81e40083,0x6cd518dd,0x78a00223}},	//   vino_, পের_, _مقدا, _bomv,
   {{0x3cf601d1,0x26c704fb,0x78a018de,0x64420098}},	//   ्षणे_, wino_, _comv, _ndoi,
   {{0x3ea118df,0x7b0900c7,0x00000000,0x00000000}},	//   _koht_, _užuo, --, --,
   {{0x6442043f,0xfc3f00ee,0x00000000,0x00000000}},	//   _adoi, _elít_, --, --,
   {{0x26c718e0,0x00000000,0x00000000,0x00000000}},	//   rino_, --, --, --,
   {{0xf77300b5,0x00000000,0x00000000,0x00000000}},	//   _پار_, --, --, --,
   {{0x26c718e1,0xdce50080,0x68e9012f,0x130910be}},	//   pino_, _arhī, _iked, нний_,
   {{0xd7f818e2,0x6b6700ea,0x68fb030d,0x3ea102a7}},	//   _рус_, mīgā, _hhud, _noht_,
   {{0xa0a60763,0x245518dd,0x68fb00d7,0x27fa004e}},	//   ганд, _مناس, _khud, ępne_,
   {{0x5fc500ab,0x351a024b,0xd30800cc,0x00000000}},	//   _लेहल, _טוענ, _sệt_, --,
   {{0x7ae51246,0x27ed0107,0x68fb08c7,0x61130139}},	//   koht, _jyen_, _mhud, _măli,
   {{0x63a918e3,0x63bb08c7,0x7ae500c3,0x68fb009f}},	//   myen, mzun, joht, _lhud,
   {{0x27ed0c1f,0x8af00095,0x9256015a,0x270f051d}},	//   _lyen_, stək, _сајт_, ादुर_,
   {{0x60c418e4,0x27ed0453,0x7b0900f4,0x00000000}},	//   _umim, _oyen_, _džum, --,
   {{0x63bb18e5,0x8b2600d8,0xfc3f0176,0xf4120070}},	// [10e0] nzun, удзе, _alís_, מפן_,
   {{0xfeba00bf,0x290d0069,0x63bb18e6,0x68e918e7}},	//   _ساخت_, _aiea_, izun, _aked,
   {{0x6da618e8,0x27ed021e,0x68fb18e9,0x09f618ea}},	//   _сина, _ayen_, _bhud, учая,
   {{0xd7fa18eb,0x68fb18ec,0x7e7e18ed,0x27ed18ee}},	//   нул_, _chud, _happ, _byen_,
   {{0x7e7e18ef,0x68fb00e0,0x96ea18f0,0x7c9500d8}},	//   _kapp, _dhud, нька_, _трэц,
   {{0x7e7e003c,0xddc70e6a,0x6f1602d7,0xaf770070}},	//   _japp, lejš, _muyc, טענס_,
   {{0x7b090280,0x7e7e18f1,0x00000000,0x00000000}},	//   _ožuj, _mapp, --, --,
   {{0xddc718f2,0x7e7e18f3,0x3a3a0d3b,0x63bb02b1}},	//   nejš, _lapp, lapp_, fzun,
   {{0xa3de0c3e,0x63a918f4,0x6b8418f5,0xa3e700be}},	//   _दुख_, gyen, nvig, _मुद_,
   {{0x7e7e18f6,0x3a3a18f7,0xf12618f8,0x2258027d}},	//   _napp, napp_, льмо, ürk_,
   {{0x63a90298,0x6b8400be,0x00000000,0x00000000}},	//   ayen, hvig, --, --,
   {{0x7e7e0159,0x657a03d0,0x63a918f9,0xb3860698}},	//   _aapp, _isth, byen, _مجته,
   {{0x7e7e022e,0x7b090009,0xdb0418fa,0x3a3a18fb}},	//   _bapp, _džuj, nzió, kapp_,
   {{0x6b8418fc,0x7e7e18fd,0x6b890207,0x645903d0}},	//   dvig, _capp, _šego, _zcwi,
   {{0x7e7e18fe,0xccfb03fa,0x7eb000be,0x6b840051}},	//   _dapp, ећа_, _täpn, evig,
   {{0x61f815d7,0x00000000,0x00000000,0x00000000}},	//   _izvl, --, --, --,
   {{0x5a3518ff,0x7afc009e,0x68e9008c,0x00000000}},	// [10f0] инат, _bhrt, _rked, --,
   {{0x68e91900,0x7afc00d5,0x7e7e1901,0x6b6700ea}},	//   _sked, _chrt, _gapp, vīgā,
   {{0x4975034b,0x657a01e8,0x7afc0009,0x1ed81902}},	//   рлес, _nsth, _dhrt, _حبيب_,
   {{0xf7710206,0x27ed0107,0x00000000,0x00000000}},	//   قات_, _pyen_, --, --,
   {{0x7c2d1903,0x7e7e0159,0x69dc0176,0x4e1902b4}},	//   mbar, _yapp, _exre, _दलाई_,
   {{0x6b670029,0x63bb013b,0x61f800d5,0xe46305f9}},	//   rīgā, vzun, _ozvl, şmüş,
   {{0x7d0f006c,0x5e5802b5,0x7c2d009e,0x68fb1904}},	//   _kics, טיגע_, obar, _thud,
   {{0x63bb1905,0x93451906,0x63a91907,0x58d500d4}},	//   tzun, ание, tyen, _тобт,
   {{0x3f89006d,0xe2990009,0x7c2d1908,0x63bb1909}},	//   _nrau_, вап_, ibar, uzun,
   {{0x52a9190a,0x63a9190b,0x7c2d190c,0x387f01d7}},	//   твом_, ryen, hbar, _haur_,
   {{0x63a9190d,0x7c2d190e,0x7e7e190f,0x3f8901d7}},	//   syen, kbar, _rapp, _arau_,
   {{0x7c2d004e,0x3f891910,0xf8b507b5,0x859a00a5}},	//   jbar, _brau_, ंसिय, _בשעו,
   {{0x442d0c72,0x7e7e1911,0xddc71912,0x387f1913}},	//   mbe_, _papp, vejš, _maur_,
   {{0x442d1914,0x6b8407e5,0x387f1915,0x7b0900f4}},	//   lbe_, vvig, _laur_, _džuk,
   {{0x3f890043,0xddc71916,0x3c42006c,0x442d001c}},	//   _erau_, tejš, _lévő_, obe_,
   {{0x0c261917,0x442d0c1f,0x3f8902c9,0xed570370}},	//   рман, nbe_, _frau_, јот_,
   {{0x3f891918,0x7e7e1919,0xddc702c6,0x442d01ae}},	// [1100] _grau_, _tapp, rejš, ibe_,
   {{0x6281142b,0x00000000,0x00000000,0x00000000}},	//   ndlo, --, --, --,
   {{0x6e3c02df,0x7c2d191a,0x81e70083,0x02b60070}},	//   marb, bbar, _মৃত_, סלעך_,
   {{0x6e3c191b,0x442d191c,0x387f00ea,0x57a6081b}},	//   larb, jbe_, _caur_, ишла,
   {{0x442d03ab,0x387f0932,0xdddc006c,0xca76002d}},	//   dbe_, _daur_, merő, _кувы,
   {{0x7d04191d,0x442d01ae,0x6e3c191e,0x6b8b01b4}},	//   lmis, ebe_, narb, ægge,
   {{0xd943191f,0x385602fb,0x387f0139,0x00000000}},	//   _мери, _възс, _faur_, --,
   {{0x387f0291,0x29180168,0x6e3c1920,0x6d410037}},	//   _gaur_, _iura_, harb, álai,
   {{0x7d041921,0xb4d60084,0x29181922,0x38661923}},	//   imis, _सदी_, _hura_, mfor_,
   {{0x29181924,0xc5fd0083,0x7d04112d,0x6d411715}},	//   _kura_, ুড়া_, hmis, šlai,
   {{0x442d1925,0x6e3c1926,0xdb0401ed,0x00000000}},	//   bbe_, darb, nziñ, --,
   {{0x29181927,0xd5770122,0x62811928,0x38661929}},	//   _mura_, _כתבה_, adlo, nfor_,
   {{0x29180484,0x7d04007c,0x6e3c192a,0x6d48192b}},	//   _lura_, dmis, farb, ádan,
   {{0x6e3c192c,0x2bf00035,0x7d04192d,0x7c2d0223}},	//   garb, _आरजू_, emis, wbar,
   {{0x02fb0d85,0x7c2d192e,0x7d0f0987,0x29180510}},	//   _שלומ, tbar, _pics, _nura_,
   {{0xb035192f,0xc03504bf,0x7d041930,0x7c2d1931}},	//   _униш, _униј, gmis, ubar,
   {{0x29181932,0xfbc7020d,0x649c01dd,0x6d4e1933}},	// [1110] _aura_, _रेशम, _déix, arba,
   {{0x7c2d1934,0x442d1935,0x387f0118,0x7d040086}},	//   sbar, zbe_, _saur_, amis,
   {{0x29181936,0x442d1937,0x7d04024b,0x7c2d1938}},	//   _cura_, ybe_, bmis, pbar,
   {{0x386905ee,0x7c95004f,0x6d551939,0x620500a8}},	//   ýar_, _الحص, muza, ürlə,
   {{0x7bd801d6,0x442d193a,0x2918193b,0x3cf4193c}},	//   şvur, vbe_, _eura_, ंतरे_,
   {{0x2918193d,0x1fd90033,0x442d0260,0x69c30042}},	//   _fura_, _সরাস, wbe_, únes,
   {{0x6a220332,0x20d20038,0x2918193e,0x27fa0035}},	//   _رہنم, lšie_, _gura_, ępna_,
   {{0x442d01ae,0x6e3c193f,0x3a38003d,0x9dd800a5}},	//   ube_, zarb, _zerp_, יווק_,
   {{0x7c221111,0x6e3c027d,0x29181940,0x6d551941}},	//   ñori, yarb, _zura_, huza,
   {{0x7d041942,0x442d1943,0x6d551944,0xf42600ab}},	//   zmis, sbe_, kuza, ääri_,
   {{0x628111ad,0x7d040086,0xd29800d8,0x20d201ba}},	//   rdlo, ymis, ртыі_, hšie_,
   {{0x6d551945,0x2b400176,0x00000000,0x00000000}},	//   duza, ysic_, --, --,
   {{0x20d20038,0x6e3c1946,0xfbc700dc,0xd30800e2}},	//   jšie_, tarb, _रेलम, _tệp_,
   {{0x249f1947,0x6d551948,0x61130160,0x7e2310b4}},	//   ljum_, fuza, _bălt, здрж,
   {{0x7d040006,0x6e3c1949,0x6d55194a,0x6d4e194b}},	//   tmis, rarb, guza, urba,
   {{0x6e3c194c,0x3a38194d,0xceb40095,0x7d04194e}},	//   sarb, _serp_, _atət_, umis,
   {{0x7e7515b3,0x2918194f,0x6a1607f8,0xeb971950}},	// [1120] bezp, _sura_, مبار, бит_,
   {{0x3f8f0370,0x6d551951,0x61130139,0xb05b02b1}},	//   _água_, buza, _fălt, ghäf,
   {{0x5d86004f,0xd23a0070,0x249f0093,0x29180be2}},	//   _الجل, רגעל, kjum_, _qura_,
   {{0x29181952,0x3a3803bc,0x00000000,0x00000000}},	//   _vura_, _werp_, --, --,
   {{0x38661953,0x2918012f,0x3a38008c,0xdd8f0919}},	//   rfor_, _wura_, _terp_, _قوی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x05860036,0x249f008d,0x3866021d,0x00000000}},	//   сулм, fjum_, pfor_, --,
   {{0x249f0093,0xb05b02ee,0x00000000,0x00000000}},	//   gjum_, niät, --, --,
   {{0x644f002a,0x6d5504fb,0x00000000,0x00000000}},	//   ócia, zuza, --, --,
   {{0x25610332,0xe3af0cd1,0x28c40bdd,0x224701ed}},	//   ból_, عري_, लोरि, _cdnk_,
   {{0x76480297,0xf09f12c3,0x6a9b0070,0x25610079}},	//   _iddy, tjà_, אשינ, cól_,
   {{0x2bfa00b4,0x64a31954,0x00000000,0x00000000}},	//   ्धां_, _наха, --, --,
   {{0x33f616e6,0x2ca0012f,0xc7b40070,0x61130139}},	//   _اساس, djid_, קבֿ_, _sălt,
   {{0x20d2016f,0x6d551955,0x31341956,0x3d110066}},	//   všie_, tuza, _декр, _दूजे_,
   {{0x3b110069,0x00000000,0x00000000,0x00000000}},	//   _rizq_, --, --, --,
   {{0x6d551957,0x8cf51958,0x853b02b5,0x26ce1959}},	//   ruza, ізац, טגלי, hifo_,
   {{0x7b14195a,0x7648195b,0xab8701d3,0x5b14195c}},	// [1130] здух, _oddy, щувк, змут,
   {{0x705504e8,0x20d2016f,0x6d55195d,0x249f0035}},	//   _انکا, ršie_, puza, zjum_,
   {{0xceb20d85,0x69c8011c,0x2d870051,0x00000000}},	//   _חיי_, _žder, _éne_, --,
   {{0x76480297,0x20d2016f,0x515b0319,0x8af000a8}},	//   _addy, pšie_, רכאו, ftəs,
   {{0xf745195e,0x6561195f,0x75280228,0x00000000}},	//   цело, _sqlh, _atdz, --,
   {{0x25610332,0xf770017e,0x7f3c0070,0x79820035}},	//   tól_, عان_, נעוו, łowa,
   {{0x04590037,0x00000000,0x00000000,0x00000000}},	//   للغة_, --, --, --,
   {{0xc3251960,0x25610332,0x03250beb,0x7eab00ab}},	//   омик, ról_, один, _küps,
   {{0x249f008a,0x7b090009,0x60cf0124,0x36d5002d}},	//   rjum_, _džuv, dicm, _доар,
   {{0x68eb1961,0x02c502ce,0x42c91783,0x6913035f}},	//   logd, ійно, ргон_, _għer,
   {{0x21691962,0xe0da0545,0x2bd00433,0xd4e702ce}},	//   шини_, иво_, _सेना, _люди,
   {{0x237d0189,0xd00a01fd,0x60cf00a2,0x6729009f}},	//   _tswj_, иене_, gicm, _ktej,
   {{0x443f1963,0x03a51964,0xe9ff0023,0xe2991461}},	//   mau_, _фило, _trặc_, _вал_,
   {{0x443f1965,0x645b1966,0x67291967,0x6aa70009}},	//   lau_, lgui, _mtej, _nojf,
   {{0x2d8c1968,0x62830160,0xfc3f01ef,0xa1560274}},	//   íde_, _iano, _soía_, _дају_,
   {{0x443f1969,0x6283196a,0x645b196b,0x3f8600f4}},	//   nau_, _hano, ngui, _šouu_,
   {{0x628303c1,0xeab2006c,0x5aca196c,0x6d45196d}},	// [1140] _kano, وٹر_, алам_, _evha,
   {{0x386d0446,0x443f196e,0x2ca0124f,0xb4d6022e}},	//   _aber_, hau_, sjid_, _सद्_,
   {{0x443f196f,0xdca60b07,0x6d41006c,0x62831970}},	//   kau_, _дани, álat, _mano,
   {{0x186a1971,0x443f1972,0x2cb902c4,0xb05b0508}},	//   ради_, jau_, _glsd_, chäd,
   {{0x443f1973,0x27e01974,0x473301e0,0x645b0282}},	//   dau_, çin_, дніс, dgui,
   {{0x62831975,0x290606a2,0x56930009,0x27e0003c}},	//   _nano, smoa_, дашт, ħin_,
   {{0x443f001e,0x68eb0124,0xe1e71062,0x7c240036}},	//   fau_, bogd, _آس_, ocir,
   {{0x7c240169,0x443f0297,0x20050095,0x26ce01ed}},	//   ncir, gau_, əlif_, sifo_,
   {{0x62831976,0x8af000a8,0xa3e7073f,0x00000000}},	//   _bano, qtəs, _मुआ_, --,
   {{0x62830090,0x78a218d4,0x00000000,0x00000000}},	//   _cano, ljov, --, --,
   {{0x443f0d04,0xe29a00e8,0x69c11977,0x645b1978}},	//   bau_, _chưa_, _žlez, bgui,
   {{0x443f1979,0x78a20009,0xf48700e0,0x00000000}},	//   cau_, njov, _وانی, --,
   {{0x6283197a,0x6440197b,0x34d90070,0xe3b2197c}},	//   _fano, mami, _פֿעב, _ترا_,
   {{0x6283197d,0xfc3f02d7,0x7c26197e,0xfbdf099e}},	//   _gano, _coín_, _afkr, _ddêl_,
   {{0xeca704bf,0x9c8300b8,0x6440002f,0x4426197f}},	//   ојан, íčov, oami, _kfo_,
   {{0x4c9400c3,0x62831980,0x6aaa01ae,0x00000000}},	//   мисс, _zano, öffn, --,
   {{0x60cd1981,0xdfd10b82,0x628318f9,0xba2b0312}},	// [1150] _imam, _سيد_, _yano, لسام_,
   {{0x64401982,0x442401a5,0x443f1983,0x6d411984}},	//   hami, hcm_, zau_, álas,
   {{0xceb20779,0x64401985,0xe2a600fb,0x6729000c}},	//   _ניט_, kami, _áður_, _stej,
   {{0x5d7a02b5,0x64401986,0x443f0221,0x7c240036}},	//   _פארק, jami, xau_, ccir,
   {{0x64401987,0x443f00d8,0x7b641988,0x1be30067}},	//   dami, vau_, _отре, _कुचल_,
   {{0x8af001c2,0xcf580122,0x443f1989,0x644002d7}},	//   stər, קבות_, wau_, eami,
   {{0x443f198a,0x6283198b,0x60cd198c,0x645b198d}},	//   tau_, _rano, _omam, tgui,
   {{0x6440198e,0x628303ad,0x44260602,0xb4e5198f}},	//   gami, _sano, _cfo_, पके_,
   {{0x443f02c7,0x7c3d104e,0x20d201ba,0x44260282}},	//   rau_, _mesr, jšia_, _dfo_,
   {{0x6283008c,0x443f1990,0x78a90a45,0x60cd1991}},	//   _qano, sau_, _hoev, _amam,
   {{0x62831992,0x443f1993,0x64401994,0x78a91995}},	//   _vano, pau_, bami, _koev,
   {{0x7c3d02dd,0x64401996,0x62831997,0x4424002f}},	//   _nesr, cami, _wano, ccm_,
   {{0x62830269,0x7c24025c,0x78bb01c0,0xa29500d4}},	//   _tano, vcir, _mluv, _наді,
   {{0x78bb0033,0xe29a0019,0x2bef007c,0x60cd1998}},	//   _lluv, _thưa_, _आड़ू_, _emam,
   {{0x443d02d0,0xde031999,0x6da6199a,0x78bb0273}},	//   _kew_, епри, чива, _oluv,
   {{0xdca30346,0x61fc01d6,0x8b2600c3,0xc5f200a5}},	//   наси, ürle, здае, גדל_,
   {{0x7c24199b,0x7c3d199c,0x6d41003e,0xeb97199d}},	// [1160] rcir, _desr, álar, пит_,
   {{0x6440199e,0x09e60b46,0x7c24199f,0x443d19a0}},	//   zami, позн, scir, _lew_,
   {{0x64401815,0x6b8f01f2,0x78a20453,0x78a90051}},	//   yami, _ercg, tjov, _boev,
   {{0x443d01f3,0x644019a1,0x78a919a2,0x7eab00ab}},	//   _new_, xami, _coev, _hüpp,
   {{0x8af00095,0x644019a3,0xe70400e0,0x78a90051}},	//   stəq, vami, وستی, _doev,
   {{0xd9460d6e,0x442619a4,0xab270133,0x644019a5}},	//   _неги, _sfo_, _хора_, wami,
   {{0x644019a6,0xe7ec046c,0x00000000,0x00000000}},	//   tami, _छुरा_, --, --,
   {{0x89db0122,0x78bb00cd,0xe29a055c,0x00000000}},	//   _החלי, _gluv, _chưn_, --,
   {{0x644019a7,0xe73703ad,0x68e30300,0x7b0900ee}},	//   rami, _нет_, énde, _ižur,
   {{0x644019a8,0x442400d7,0xbebb0031,0x78a90051}},	//   sami, scm_, hpër, _zoev,
   {{0x644019a9,0x443d0122,0x705507a9,0x7d1e018d}},	//   pami, _few_, وندا, _nups,
   {{0x442619aa,0x443d19ab,0x69c100ab,0xdfd500d8}},	//   _ufo_, _gew_, _ülee, домы,
   {{0x395a023a,0xdcb10023,0x2d8c08c8,0x74130098}},	//   hups_, ểm_, æden_, _كوما,
   {{0x7bc419ac,0x7c3d19ad,0x00000000,0x00000000}},	//   dziu, _sesr, --, --,
   {{0xdd94010b,0x443d18ae,0x7eb000ab,0x945d0067}},	//   нары, _yew_, _näpu, cińs,
   {{0x60cd08dd,0x20d200a0,0x7d1e19ae,0x00000000}},	//   _umam, pšia_, _dups, --,
   {{0x2bc70518,0x5b1519af,0x9f5400d8,0xfbd319b0}},	// [1170] _रेखा, дмат, _звыч, رتر_,
   {{0x7b0910ec,0x2d810221,0x628819b1,0xf8b5021a}},	//   _ažur, _tshe_, nddo, ंस्प,
   {{0x60dd19b2,0x2d8c0c60,0x62880345,0xfc3000fd}},	//   onsm, ådet_, iddo, ئحہ_,
   {{0x6d471228,0x6b890009,0x31570070,0x2904009e}},	//   msja, _šegu, ליבן_, _chma_,
   {{0x2bc819b3,0x629802e6,0x7b090009,0x60dd19b4}},	//   _еуро_, _onvo, _džur, insm,
   {{0x443d003c,0x6b8d01d5,0x6d5519b5,0x00000000}},	//   _sew_, mvag, orza, --,
   {{0x78a90261,0x7c22025c,0x58d500d4,0x291c0355}},	//   _toev, žore, _жовт, ívat_,
   {{0xe3b919b6,0x6288016e,0x6d480079,0x6add00b4}},	//   жби_, eddo, ádai, _मदुर,
   {{0xf7700041,0x27ff06d3,0xa3e719b7,0x628819b8}},	//   _مال_, _uzun_, _मुख_, fddo,
   {{0x25e807ba,0xfc3f17bf,0x04fd0033,0x6d4719b9}},	//   _चुकी_, _leí_, ঁদের_, ksja,
   {{0x764319ba,0x69c519bb,0x6d550035,0x6d4700cd}},	//   many, nzhe, jrza, jsja,
   {{0x629819bc,0x764319bd,0x644b054e,0x6d5519be}},	//   _envo, lany, _udgi, drza,
   {{0x7d1e19bf,0x6d550067,0x996200fe,0x945d0067}},	//   _sups, erza, _díře_, sińs,
   {{0x764319c0,0xe2990043,0x60dd0051,0x7d1e005f}},	//   nany, _фак_, ansm, _pups,
   {{0x9fa019c1,0x00000000,0x00000000,0x00000000}},	//   _méér_, --, --, --,
   {{0xc106004f,0xa2d502b4,0x00000000,0x00000000}},	//   _توبي, यचक्, --, --,
   {{0x764319c2,0x09ab0083,0xcb6719c3,0x6d4700be}},	// [1180] kany, _গেলা, мате_, asja,
   {{0x0f5700a5,0x7bc40409,0xbebb0055,0x6d550288}},	//   _קיים_, rziu, spër, brza,
   {{0x673b00f8,0x5e9b00a5,0x6b8d0629,0x00000000}},	//   _awuj, _וביק, avag, --,
   {{0x6d5c19c4,0x395a19c5,0xeb9a136c,0x9f990345}},	//   mura, rups_, _дим_, _háár_,
   {{0x764319c6,0x6d5c0ce8,0x628802c7,0xb90613f0}},	//   fany, lura, yddo, _पद_,
   {{0x764319c7,0x395a19c8,0x07a303fa,0x7e7c19c9}},	//   gany, pups_, таљн, nerp,
   {{0x6d5c19ca,0xf9830086,0x00000000,0x00000000}},	//   nura, _игро, --, --,
   {{0x2ebb074f,0x7e7c19cb,0x7b0900cb,0x00000000}},	//   _उत्त, herp, _užur, --,
   {{0x764319cc,0xc4450118,0x20c20098,0x00000000}},	//   bany, ریون_, _móid_, --,
   {{0xd25000bf,0x76430232,0xeb9102b5,0x234800fd}},	//   دند_, cany, אָט_, _ہستی_,
   {{0x62880297,0x20d219cd,0xf1aa00f8,0x2486026e}},	//   rddo, ršin_, زاده_, _taom_,
   {{0x6d5c19ce,0x6720002f,0x04930037,0x9fa00223}},	//   dura, _kumj, _للمح, _zéér_,
   {{0xfc3f02d7,0x7e7c0b17,0x2d6802b1,0x9343031a}},	//   _reí_, ferp, eße_, _анче,
   {{0x6d5c000e,0x7e7c19cf,0x6298033b,0x826800b5}},	//   fura, gerp, _unvo, _رشتہ_,
   {{0x9f990298,0x00000000,0x00000000,0x00000000}},	//   _dáár_, --, --, --,
   {{0x6d4719d0,0x764319d1,0x20c20037,0x7c3619d2}},	//   rsja, zany, _cóid_, gbyr,
   {{0x764319d3,0x2d9e01ae,0x2d8c0909,0x3f8500ea}},	// [1190] yany, äter_, åder_, ālus_,
   {{0x6d5c19d4,0x9af5004f,0x7f5d0176,0x7e7c19d5}},	//   bura, ركات, musq, cerp,
   {{0x764319d6,0x6d5c19d7,0x6b8d19d8,0xc98419d9}},	//   vany, cura, svag, куци,
   {{0x764319da,0x2bd019db,0xe0df07e5,0x2bcb0274}},	//   wany, _सेवा, nnò_, _дуго_,
   {{0x7d0d19dc,0x764319dd,0xf3880019,0x291c02d7}},	//   mmas, tany, _nợ_, ívar_,
   {{0x7d0d19de,0xddde0b16,0x672002d4,0x00000000}},	//   lmas, _hapš, _dumj, --,
   {{0x764319df,0xddde005f,0x00000000,0x00000000}},	//   rany, _kapš, --, --,
   {{0x7d0d19e0,0x764319e1,0xb38519e2,0x9fa01472}},	//   nmas, sany, елил, _wéér_,
   {{0x764319e3,0x7d0d19e4,0x375500f8,0x2b4900f6}},	//   pany, imas, _سپاس, nsac_,
   {{0x130603ad,0x6d5c19e5,0x7d0d19e6,0x237f0035}},	//   нный_, yura, hmas, rwuj_,
   {{0xe4a7002d,0xd12e0e3a,0x6d5c01d7,0xe1f900d8}},	//   _ордо, یمی_, xura, яго_,
   {{0x764100f5,0xf99200c2,0x2ec8004e,0x3cfb0035}},	//   _hely, ארט_, रफ्त, ्षों_,
   {{0x764119e7,0x42cd0033,0x75210051,0xbebb0031}},	//   _kely, রকৌশ, _hulz, rqën,
   {{0x91e50f94,0x6d5c16a3,0x3ebe0093,0x75210103}},	//   _поле, tura, ótt_, _kulz,
   {{0x764119e8,0xc5f20070,0x7e7c0a8c,0x00000000}},	//   _mely, ָדן_, rerp, --,
   {{0x7d0d19e9,0x7e7c19ea,0x7f5d00f6,0x764119eb}},	//   gmas, serp, busq, _lely,
   {{0x245a01d6,0x6d5c19ec,0x6b8900cd,0x75210055}},	// [11a0] lümü_, sura, _šegr, _lulz,
   {{0x6d5c19ed,0xb05b19ee,0x7c3617ad,0x7d0d19ef}},	//   pura, nhän, sbyr, amas,
   {{0x8c4619f0,0xcee900d1,0x02b60070,0x6d5c19f1}},	//   _пене, _ترين_, עלעך_, qura,
   {{0x7eb0007c,0x224503b3,0x7d0d19f2,0x20d200cd}},	//   _täps, halk_, cmas, kšim_,
   {{0x68e319f3,0xa2b401c0,0x00000000,0x00000000}},	//   énda, ेसम्, --, --,
   {{0x09bf0033,0xc8e90066,0x764119f4,0x0cc30033}},	//   _আশরা, टकॉम_, _cely, ্কৃত,
   {{0xf38801a5,0xceb30122,0x7641016e,0x80a300b4}},	//   _sợ_, ריו_, _dely, गामे,
   {{0x75210453,0xd3a6051a,0x69c100be,0x6720034d}},	//   _dulz, ероп, _ülea, _tumj,
   {{0xb05b02b1,0x764119f5,0x20d219f6,0x00000000}},	//   fhän, _fely, ršil_, --,
   {{0xf38801a5,0x764119f7,0x7d0d00c1,0x6aae08c8}},	//   _vợ_, _gely, zmas, _jobf,
   {{0x6d1f007c,0xba570070,0x75210051,0xf48400b5}},	//   _मूंग_, עסטו_, _gulz, _لاشی,
   {{0x254c00b8,0x7d0d00a8,0x61f800ac,0x00000000}},	//   měl_, xmas, _vyvl, --,
   {{0xe29a19f8,0xb05b01ae,0x213c012f,0xe0df07e5}},	//   _над_, bhän, _wwvh_, rnò_,
   {{0x6710009a,0x64420341,0x245a0225,0x7f5d00f6}},	//   ाषिक_, _heoi, bümü_, rusq,
   {{0x7d0d19f9,0x20240098,0x00000000,0x00000000}},	//   tmas, íriú_, --, --,
   {{0xdc8819fa,0x7d0d19fb,0xccf803fa,0x628a016e}},	//   нсул_, umas, ећу_, _hafo,
   {{0x7d0d19fc,0x628a02d0,0x64420341,0x3c5800af}},	// [11b0] rmas, _kafo, _meoi, эитэ_,
   {{0x644219fd,0x00000000,0x00000000,0x00000000}},	//   _leoi, --, --, --,
   {{0x764119fe,0xd999004f,0xddde19ff,0x7d0d1a00}},	//   _rely, بنات_, _tapš, pmas,
   {{0x628a1a01,0x76411a02,0x48cf0083,0x64421a03}},	//   _lafo, _sely, িক্র, _neoi,
   {{0x81bc00ea,0x7eb01a04,0x245a0448,0x75210b17}},	//   ucēj, _käpp, zümü_, _sulz,
   {{0x69d502cb,0x628a0097,0xf653006c,0x75211a05}},	//   _येथी, _nafo, ائش_, _pulz,
   {{0x6442004f,0x764100c7,0x00000000,0x00000000}},	//   _beoi, _vely, --, --,
   {{0x64420037,0xe7d20ed1,0x69cc00a0,0x7eb01a06}},	//   _ceoi, _देवप, ôlež, _läpp,
   {{0x64421a07,0xe3b10037,0x1309051a,0x69d50099}},	//   _deoi, شرة_, мний_, _येती,
   {{0x628a001e,0x7eb00196,0xb6060097,0x20d20207}},	//   _cafo, _näpp, _stáž, ršim_,
   {{0x628a00e5,0x644211d9,0xb05b1788,0x22580067}},	//   _dafo, _feoi, rhän, órka_,
   {{0x64420608,0xe3b003c5,0x20d2030a,0x290f0159}},	//   _geoi, _گرم_, pšim_, nmga_,
   {{0xb05b022a,0x2ca900be,0x22451a08,0xe3ae1a09}},	//   mhäl, djad_, palk_, _тб_,
   {{0x7982004e,0x628a001e,0x248d05a6,0x00000000}},	//   łowi, _gafo, ldem_, --,
   {{0xbea3052c,0x200401ba,0x8af0013b,0xb05b02b1}},	//   шарк, ťmi_, frən, chäo,
   {{0x248d1a0a,0x1fb61a0b,0xa3e50f06,0x00000000}},	//   ndem_, _асор, _नशा_, --,
   {{0x248d1a0c,0x236d006f,0x2c070096,0x628a0371}},	// [11c0] idem_, ntej_, _शरणं_, _yafo,
   {{0x3ced0528,0x6d4801dd,0x3ce01a0d,0x6a1600ce}},	//   čeva_, ádas, sniv_, نبار,
   {{0xae570122,0x19b91a0e,0x69230210,0x41c1021a}},	//   _בסיס_, нуць_, амха, शनिस,
   {{0x38cb0df3,0x248d1a0f,0xd7fa0043,0x79950035}},	//   وانی_, jdem_, мул_, _drzw,
   {{0x6d5a010b,0x23d00035,0x248d1a10,0xe7d209b8}},	//   štad, _तेंद, ddem_, _देशप,
   {{0x248d003c,0x254c00b8,0x64421a11,0x7ccc013b}},	//   edem_, těl_, _seoi, rşru,
   {{0xe9a30889,0xa2c506fe,0x628a008d,0xa9a3081b}},	//   _карп, िसन्, _rafo, _кирд,
   {{0x628a0297,0x2a070439,0xb8660df3,0xa2d4022e}},	//   _safo, _респ_, _جاسو, योन्,
   {{0x2c6d006c,0xaa820093,0xd62a1a12,0x06860036}},	//   lódó_, _þýsk, _жозе_, _иган,
   {{0x68e21a13,0x00000000,0x00000000,0x00000000}},	//   lnod, --, --, --,
   {{0x64421a14,0x9f4f008d,0xe3af0647,0x00000000}},	//   _teoi, _ágú_, مری_, --,
   {{0x9f351a15,0x68e200e9,0xe3ba0267,0x6b8401d5}},	//   лемі, nnod, _обе_, kwig,
   {{0x35a80953,0x628a016e,0xe70300e2,0x09d60033}},	//   _कपड़, _tafo, _hướ, _তুমা,
   {{0x6b841a16,0x7a4800ea,0x11d313cf,0x00000000}},	//   dwig, nūtē, اتید, --,
   {{0x8c670183,0x2ca900ab,0x20d200cd,0x1df80104}},	//   ктад, tjad_, kših_, веры_,
   {{0x20d2008b,0x2d9c00ac,0x021700a5,0x00000000}},	//   jših_, _švec_, _בחום_, --,
   {{0x68e20076,0x3a7500c3,0x2ca91a17,0x31e200b4}},	// [11d0] dnod, ллар, rjad_, _पशुध,
   {{0x5a341a18,0x2ca900be,0x248d1a19,0x00000000}},	//   инут, sjad_, zdem_, --,
   {{0x68e30f56,0x68e20297,0xceb202b8,0x8af000a8}},	//   éndo, fnod, _היי_, mrəl,
   {{0x3f89046a,0x68e2016e,0x6b84007b,0xa215016b}},	//   _ksau_, gnod, bwig, אַנס_,
   {{0xe9ff0019,0xa2c5164f,0x20c20132,0x27e91a1a}},	//   _trắc_, िसम्, _jóia_, çan_,
   {{0x7d1d1a1b,0x7c2d1315,0xe70300cc,0xda34010b}},	//   _hiss, lcar, _bướ, _веры,
   {{0xc9841a1c,0x68e20097,0xb05b01ae,0x45191a1d}},	//   _кути, bnod, thäl, нция_,
   {{0x7c2d1a1e,0xdb1e0187,0x7d1d003c,0xc48500af}},	//   ncar, _švéd, _jiss, улик,
   {{0x7d1d1a1f,0x248d1a20,0xb05b01ae,0x7c2d00c7}},	//   _miss, rdem_, rhäl, icar,
   {{0x248d0a21,0x236d1a21,0x27e00037,0x66150097}},	//   sdem_, rtej_, úine_, _úzko,
   {{0x291e02e1,0x7d1d1a22,0x3f8900e5,0xa06a13ba}},	//   _état_, _oiss, _asau_, нана_,
   {{0x7c2d1a23,0xd5ba02b5,0x20c2021d,0x00000000}},	//   jcar, _אזעל, _bóia_, --,
   {{0xe28e1a24,0x442d0690,0x7c2d1a25,0x61ea0523}},	//   _ла_, mce_, dcar, _exfl,
   {{0x442d1a26,0x66f5004e,0x35d80066,0x64490079}},	//   lce_, ेतिक_, _भेड़, laei,
   {{0x62811a27,0x7d1d1a28,0x3f890e5b,0x68e2001e}},	//   melo, _biss, _esau_, ynod,
   {{0x442d1a29,0x62811a2a,0x7d1d1a2b,0x6b9b012e}},	//   nce_, lelo, _ciss, _šuga,
   {{0x7d1d1a2c,0x442f01ae,0x60c41a2d,0x20d21a2e}},	// [11e0] _diss, _mfg_, _ilim, vših_,
   {{0x62811a2f,0x7bc001c2,0xc3320122,0x442d1a30}},	//   nelo, _ümum, צוב_, hce_,
   {{0x2d961a31,0x442d000c,0x7d1d1a32,0x68e20c7c}},	//   _српс, kce_, _fiss, tnod,
   {{0x6846002d,0x5ca61a33,0x7c2d1a34,0x62811a35}},	//   унда, _симб, ccar, helo,
   {{0x442d1a36,0x62811a37,0x6d4e1a38,0xd7f718c3}},	//   dce_, kelo, lsba, луш_,
   {{0x56941a39,0x62811a3a,0x6d5c1a3b,0x60c41a3c}},	//   ракт, jelo, orra, _llim,
   {{0x62811a3d,0x6d4e1a3e,0x20d20121,0xf1a70037}},	//   delo, nsba, pših_, _اء_,
   {{0x442f1a3f,0x6f1e004e,0x6d4e0a8d,0x64491a40}},	//   _cfg_, _lipc, isba, gaei,
   {{0xb4e40ec5,0x62811a41,0x6d5c01ae,0x8af000a8}},	//   _नदी_, felo, hrra, hrəm,
   {{0x62810a45,0x26c701c0,0x3866001e,0x6d4e1a42}},	//   gelo, chno_, lgor_, ksba,
   {{0x442d01c0,0x645d0138,0x6d4e1a43,0x7c2d062c}},	//   bce_, ósic, jsba, ycar,
   {{0x38661a44,0x442d01d3,0x6d4e1a45,0x6d5c0031}},	//   ngor_, cce_, dsba, drra,
   {{0x7d1d1a46,0x8af00095,0x6d4e0e54,0x6d5c1a47}},	//   _riss, stəy, esba, erra,
   {{0x7d1d0ccf,0x7c2d1a48,0x62341a49,0x3866016e}},	//   _siss, wcar, _теку, hgor_,
   {{0x60c4003c,0x7c2d01e4,0x6d5c010d,0x6d4e1a4a}},	//   _flim, tcar, grra, gsba,
   {{0x60c41a4b,0x3f890221,0x3ced1a4c,0x7d1d1505}},	//   _glim, _tsau_, čevo_, _qiss,
   {{0x7d1d1a4d,0x6d5c1a4e,0xa01b038e,0x4bdb00f8}},	// [11f0] _viss, arra, rdös, ربرد_,
   {{0x7d1d1a4f,0x442d1a50,0x7c2d012c,0x2a6a0183}},	//   _wiss, zce_, scar, _ccbb_,
   {{0x7d1d1a51,0x7c2d1a52,0xda780c8a,0x6d4e1a53}},	//   _tiss, pcar, ыят_, csba,
   {{0xa2d40026,0x62811a54,0x69c1007c,0x4c951a55}},	//   योत्, zelo, _ülem, _тимс,
   {{0x442d0097,0x07a51a56,0x36691169,0x499300b5}},	//   vce_, ралн, вало_, _گیار,
   {{0x055502fb,0x38690701,0x62811a57,0x442d0035}},	//   атия, żar_, xelo, wce_,
   {{0x62811a58,0x49931328,0x442d0803,0x3eb30024}},	//   velo, _دیار, tce_, _moxt_,
   {{0xed64024e,0x62811a59,0x47351a5a,0x442d1a5b}},	//   leží_, welo, _внас, uce_,
   {{0x628100af,0x442d1a5c,0xe7300ca8,0x64491a5d}},	//   telo, rce_, _فصل_, raei,
   {{0x442d1a5e,0x60c41a5f,0x27ff0095,0xd7f80043}},	//   sce_, _slim, _iyun_, _сус_,
   {{0x442d1a60,0x62811a61,0x60c40395,0x2009022e}},	//   pce_, relo, _plim, _azai_,
   {{0x62811a62,0x656303e6,0x272b01b4,0x8af000a8}},	//   selo, munh, _køn_, stəx,
   {{0x68e901f4,0x7bcd1a63,0x6f1e1a64,0x20c20079}},	//   _mjed, jzau, _pipc, _fóin_,
   {{0xed5a0500,0x6d4e1a65,0x59b5018d,0x2009021d}},	//   ког_, tsba, ंहार, _dzai_,
   {{0x68fb1a66,0x272b035b,0x68e900ac,0x6d5c1a67}},	//   _okud, _løn_, _ojed, urra,
   {{0x27ff1a68,0x60c4000e,0x68e91a69,0x22471a6a}},	//   _oyun_, _ulim, _njed, _henk_,
   {{0x63bb1a6b,0x6d4e0a6d,0x26c50391,0x63a91a6c}},	// [1200] nyun, ssba, _ollo_, nxen,
   {{0xc87901c2,0x68e900de,0xed461a6d,0x63a90310}},	//   _abş_, _ajed, _кноп, ixen,
   {{0x27ff0dc3,0x21270392,0x68e900f4,0x80aa0067}},	//   _ayun_, _junh_, _bjed, टापे,
   {{0x290d01dd,0x26c501d3,0x7bcd0221,0xe73a1a6e}},	//   _chea_, _allo_, bzau, вед_,
   {{0x68e9025c,0x1867117a,0x290d1a6f,0x2d9a022f}},	//   _djed, рачи_, _dhea_, _hrpe_,
   {{0x2d9a0a18,0x68e90b3e,0x68fb1a70,0x22470118}},	//   _krpe_, _ejed, _ekud, _nenk_,
   {{0x65631a71,0x09e31499,0x20d200a0,0x27ed0051}},	//   gunh, _дорн, lšiu_, _exen_,
   {{0x26c50083,0xd4971a72,0xb4c00fc3,0x272b008c}},	//   _ello_, арь_, ँसे_, _føn_,
   {{0x63bb00b5,0x22471a73,0x80aa021a,0x00000000}},	//   gyun, _benk_, टाने, --,
   {{0x291f0043,0x68e90f86,0x9f4f000d,0xb273021f}},	//   _ziua_, _zjed, _âgé_, ольш,
   {{0x22470a75,0x2ef81a74,0xadf21a75,0x21631a76}},	//   _denk_, dorf_, _आँगन_, отяг,
   {{0x64a31a77,0x26dc07fc,0xddc50355,0x63bb007b}},	//   _маха, livo_, _schů, byun,
   {{0xdc2e0095,0x76481a78,0xa29400d8,0x20d200a0}},	//   _sığo, _kedy, _галі, jšiu_,
   {{0x7648004e,0x7b1001ae,0x22471a79,0x0ea700dc}},	//   _jedy, läuf, _genk_, खाधड,
   {{0xe3e800c8,0x76481a7a,0x2d9a1a7b,0x00000000}},	//   _পরিব, _medy, _crpe_, --,
   {{0x50d41a7c,0x7528046a,0x6ca41a7d,0xc05b00d4}},	//   _وزير, _mudz, оруж, _рік_,
   {{0x75281a7e,0x2bba0035,0x290d1901,0x68e91a7f}},	// [1210] _ludz, jącą_, _rhea_, _rjed,
   {{0x68e91a80,0x26dc1851,0x69c100ab,0x68fb0d51}},	//   _sjed, jivo_, _ülek, _skud,
   {{0x26dc03c9,0x2484003c,0x272b035b,0xc8ab01d3}},	//   divo_, kemm_, _søn_, къде_,
   {{0xf77102aa,0x00000000,0x00000000,0x00000000}},	//   كات_, --, --, --,
   {{0x2bde09a3,0x68e901f4,0x75280029,0x7648077f}},	//   _नेपा, _vjed, _audz, _bedy,
   {{0x65630008,0x75281a81,0xdc3c009f,0x00000000}},	//   tunh, _budz, _iġġo, --,
   {{0x68e9029d,0xa8a71a82,0x75281a83,0xdddc0506}},	//   _tjed, _крак, _cudz, zdrž,
   {{0x68e90a78,0x224702e9,0x15b8004b,0x60dd1a84}},	//   _ujed, _senk_, рышы_, jism,
   {{0x26dc19be,0x764800e5,0x00000000,0x00000000}},	//   bivo_, _fedy, --, --,
   {{0x68f9007a,0x63a90391,0x26dc0881,0x656306e4}},	//   lowd, rxen, civo_, punh,
   {{0x63bb121e,0x386d0124,0x63a901ef,0x75280409}},	//   syun, _kcer_, sxen, _gudz,
   {{0x67211a85,0x297a0100,0x397a0122,0x60dd1a86}},	//   _hilj, נטרא, נטרנ, gism,
   {{0x443f1903,0x80aa0026,0x6d45011e,0x22471a87}},	//   mbu_, टाबे, _awha, _tenk_,
   {{0x443f1a88,0x6d451a89,0x63a41a8a,0x7d1800fd}},	//   lbu_, _bwha, _šing, _évsz,
   {{0x2d95107a,0xdca60652,0x60dd1a8b,0xdc3c003c}},	//   ортс, бави, bism, _aġġo,
   {{0x386d00d7,0x443f1a8c,0x67211a8d,0x0c261a8e}},	//   _ncer_, nbu_, _lilj, сман,
   {{0x1d07150d,0x443f1a8f,0x63a4009e,0x00000000}},	// [1220] сети_, ibu_, _àint, --,
   {{0x443f0024,0x8e860037,0x2d9a00cd,0x9e661a90}},	//   hbu_, _الده, _trpe_, _увод,
   {{0x76480107,0x24840159,0xef170043,0x499a037c}},	//   _redy, yemm_, _ымь_, ытая_,
   {{0x443f1a91,0x75281a92,0x20d200a0,0x6729008c}},	//   jbu_, _rudz, pšiu_, _buej,
   {{0x7d041a93,0x67290176,0x31650c9c,0xc0530070}},	//   mlis, _cuej, hulz_, לזא_,
   {{0x7d041a94,0x67211851,0x88841a95,0xf1ca000c}},	//   llis, _cilj, _ژیان, ानमन,
   {{0x26dc1a96,0x67211a97,0x2d981a98,0x60dd1a99}},	//   rivo_, _dilj, nvre_, yism,
   {{0x7d041a9a,0x443f01c1,0x7648001e,0x2d9800f7}},	//   nlis, gbu_, _wedy, ivre_,
   {{0x26dc1a9b,0x7d041a9c,0x47c60370,0xf7430de6}},	//   pivo_, ilis, _убав, _нето,
   {{0x7d041a9d,0x60dd022e,0x66011a9e,0x415410be}},	//   hlis, wism, _fylk, овос,
   {{0x443f1a9f,0x8afb02b5,0x8af000a8,0x00000000}},	//   bbu_, רהיי, msəd, --,
   {{0x67210c6f,0x00000000,0x00000000,0x00000000}},	//   _zilj, --, --, --,
   {{0x44261aa0,0xe6c400fb,0x7d04016f,0x6d5a01ba}},	//   _igo_, _þjóð, dlis, átan,
   {{0xf1a61aa1,0x7d16016f,0x60dd1aa2,0x7d041aa3}},	//   _грин, emys, sism, elis,
   {{0x6d5a116d,0xa2c500b4,0x7d041aa4,0x60dd1aa5}},	//   štan, िसर्, flis, pism,
   {{0xd9041aa6,0x7d041aa7,0xa2d400b8,0x442602d7}},	//   _سی_, glis, योर्, _jgo_,
   {{0x2d8c054e,0x88bd0035,0x75220176,0xceeb01cb}},	// [1230] æder_, _liśc, _mioz, _مردن_,
   {{0x443f1aa8,0x2d9800a2,0x386d0176,0x31790067}},	//   zbu_, bvre_, _scer_, ńsze_,
   {{0x7d041aa9,0x443f0097,0x20d20009,0x6ab500e2}},	//   blis, ybu_, mšir_, _vozf,
   {{0x442619dd,0x67211aaa,0x77991aab,0x00000000}},	//   _ngo_, _silj, икер_, --,
   {{0xd3660833,0x67290033,0x443f024e,0x67211aac}},	//   _ته_, _quej, vbu_, _pilj,
   {{0xd1260079,0x3ce900af,0xe80f0035,0xe0df0036}},	//   _يم_, lnav_, ़ेगा_, hiò_,
   {{0x67211aad,0x44261aae,0xa2ac021a,0x5fe000b4}},	//   _vilj, _bgo_, जान्, _पेनल,
   {{0x44260312,0x00000000,0x00000000,0x00000000}},	//   _cgo_, --, --, --,
   {{0x443f1aaf,0x7b1001ae,0x42c91402,0xb05b033b}},	//   rbu_, bäud, игин_, nhäu,
   {{0x66010755,0x443f1ab0,0x7d161ab1,0xb60700ec}},	//   _tylk, sbu_, zmys, _apšū,
   {{0x008617a3,0xd04f013b,0x00000000,0x00000000}},	//   олно, licə, --, --,
   {{0x2eb41ab2,0xe0df0036,0xdddc0009,0xc9520317}},	//   ुस्त, giò_, jerš, ומט_,
   {{0xbebb01f4,0xfc4601ba,0xdddc0009,0x7d041ab3}},	//   jqës, šíka_, derš, vlis,
   {{0x61451ab4,0x644b01d5,0x25de046c,0x75221ab5}},	//   _дека, _hegi, _केडी_, _zioz,
   {{0x644b0406,0x7e230370,0x2d981ab6,0xdddc00f4}},	//   _kegi, ддрж, uvre_, ferš,
   {{0x0ce80083,0xdca30336,0xb05b1ab7,0xe0df1ab8}},	//   পত্ত, маси, lkän, ciò_,
   {{0x7d041ab9,0x644b1aba,0xeb970086,0x8b2602ce}},	// [1240] rlis, _megi, оит_, ідже,
   {{0x7d041abb,0xda66004f,0x7d160355,0x63a40098}},	//   slis, تاري, smys, _áine,
   {{0x6459004e,0x1d0a0ec9,0xe9da0274,0xdddc068f}},	//   _odwi, _вени_, јке_, berš,
   {{0x644b1abc,0x53c90ea3,0xb17a0070,0xe8fa0c9f}},	//   _negi, िनाश, יטער, шле_,
   {{0x7522021d,0x1634027a,0x442600f6,0xf76f1abd}},	//   _rioz, пеля, _rgo_, ناو_,
   {{0x8f9b1abe,0xe0df07e5,0xbf9b025a,0x00000000}},	//   ייני, ziò_, יינש, --,
   {{0x2bde00c0,0xb05b013c,0x4426029e,0xe5a30200}},	//   _नेता, dkän, _pgo_, дији,
   {{0x644b01a7,0x18670eb4,0x00000000,0x00000000}},	//   _cegi, _маси_, --, --,
   {{0x644b1abf,0xe0df0036,0x00000000,0x00000000}},	//   _degi, viò_, --, --,
   {{0x3ce00006,0x8af001c2,0x3ced0bc6,0x29061ac0}},	//   hiiv_, qsəd, čevi_, lloa_,
   {{0x27300028,0x644b1ac1,0x7522021d,0x00000000}},	//   _hàn_, _fegi, _tioz, --,
   {{0x6ab70567,0x44261ac2,0xbebb01f4,0x644b1ac3}},	//   _आक्र, _ugo_, yqës, _gegi,
   {{0x6d5a1ac4,0x69c1007c,0x290601ed,0x27300107}},	//   štal, _ülev, iloa_, _jàn_,
   {{0xdefb1ac5,0x27300028,0x20050080,0xf1aa0088}},	//   рым_, _màn_, āli_, _نابه_,
   {{0x27301ac6,0x62881ac7,0xc8bc0567,0x290601a3}},	//   _làn_, medo, ्घाट, kloa_,
   {{0x62881ac8,0xe9ab01cb,0x00000000,0x00000000}},	//   ledo, یدان_, --, --,
   {{0x60c01ac9,0x27300023,0x3ce900b9,0x00000000}},	// [1250] ömme, _nàn_, rnav_, --,
   {{0x77621aca,0x62881acb,0x3ce900ec,0x7f840105}},	//   drox, nedo, snav_, _کلین,
   {{0xdc3f024e,0x41ca0d1f,0xb05b02b1,0x7c3a0160}},	//   líčk, ानिस, shäu, _ştre,
   {{0xd04f01c2,0x27301acc,0xb17b0070,0x628803d0}},	//   ticə, _bàn_, שטאר, hedo,
   {{0xdc3f0187,0xf7451acd,0x6d55006c,0xdc360070}},	//   níčk, чело, lsza, _מארט_,
   {{0x644b1ace,0x62881acf,0xf1ca1ad0,0x27301ad1}},	//   _segi, jedo, ानान, _dàn_,
   {{0x62881ad2,0x6b8d0a75,0x6d551ad3,0x00000000}},	//   dedo, lwag, nsza, --,
   {{0xe7871ad4,0x62880207,0x28f801e0,0x00000000}},	//   _музо, eedo, _десь_, --,
   {{0x644b1ad5,0x6b8d1ad6,0xdc3f0187,0xf41f00c3}},	//   _vegi, nwag, jíčk, ää_,
   {{0x62881ad7,0x04fd0083,0x42551172,0x2cb9009e}},	//   gedo, ুদের_, чтит, _losd_,
   {{0x644b1ad8,0x6b8d1ad9,0xb05b1ab7,0x68eb00e2}},	//   _tegi, hwag, rkän, ongd,
   {{0x6b8d1815,0x69c100be,0xeb9f008c,0x00000000}},	//   kwag, _üleu, _orø_, --,
   {{0xd7bd0567,0x7643006d,0x2004008a,0xa3d300a1}},	//   ्निच, obny, æmi_, _हेच_,
   {{0x6d5a1ada,0x2cb90211,0x62881adb,0x539a0277}},	//   štam, _aosd_, cedo, _לינו,
   {{0x2d9e0076,0x7643046a,0x6da30610,0x6d55006c}},	//   íte_, ibny, нира, gsza,
   {{0x2cb90211,0xb05b0421,0xd7bd0099,0xdc3f00ac}},	//   _cosd_, nkäl, ्नाच, bíčk,
   {{0x673b0221,0x6b8d1adc,0x00000000,0x00000000}},	// [1260] _ntuj, gwag, --, --,
   {{0x0e660086,0x80aa0302,0x3f9218ad,0x387f1add}},	//   _экон, टावे, _isyu_, _abur_,
   {{0x273001a5,0x3ebb0122,0xdebb0122,0x98b000cd}},	//   _sàn_, _הציב, _המיל, šači_,
   {{0x186a1ade,0x77621adf,0x6b8d1ae0,0x779400b5}},	//   сади_, trox, bwag, ویزا,
   {{0xfc3f1ae1,0x6563033b,0x473301e0,0x6b8d04fb}},	//   _unía_, ernh, еніс, cwag,
   {{0x2b401ae2,0x62881ae3,0x996400b8,0x290600be}},	//   mpic_, xedo, může_, sloa_,
   {{0xeafa065a,0x9d000033,0x673b0421,0x00000000}},	//   ्तीत_, ্দীন_, _etuj, --,
   {{0x62880297,0x27300019,0xe9d70104,0x77621ae4}},	//   wedo, _tàn_, _экс_, prox,
   {{0x6563009e,0x00000000,0x00000000,0x00000000}},	//   arnh, --, --, --,
   {{0xb6c80332,0x7afe1ae5,0x68e21ae6,0x86ea0037}},	//   _بارے_, nopt, liod, _اعرف_,
   {{0x62881ae7,0x6d5a01cc,0x6b8d1ae8,0x69c100ab}},	//   redo, štaj, zwag, _ület,
   {{0xeafa1ae9,0x62881aea,0x7afe0088,0x68e204fc}},	//   ्तुत_, sedo, hopt, niod,
   {{0x14a90099,0xa4b700a5,0x3eba01f7,0x98a7011c}},	//   कारण, _מלאה_, _bopt_, šići_,
   {{0x628801d2,0x6d551aeb,0x3eba1aec,0x68e21aed}},	//   qedo, tsza, _copt_, hiod,
   {{0xf29702b8,0x200c00a8,0x3ebe1aee,0x68eb1aef}},	//   _זכור_, ədim_, ötta_, yngd,
   {{0x6d551af0,0x6b8d1af1,0xfbde00a1,0xf1ba0023}},	//   rsza, twag, _नेहम, _ngơi_,
   {{0x6d550332,0xa3be08b0,0x46be112b,0x60cd1af2}},	// [1270] ssza, ीनि_, ्साह, _ilam,
   {{0x60cd1af3,0x6b8d1af4,0xb05b033b,0x6d5507cf}},	//   _hlam, rwag, chär, psza,
   {{0x60cd1af5,0xc17800d8,0xb05b0328,0xceb2016b}},	//   _klam, ntė_, ykäl, _סיט_,
   {{0xa3be1af6,0x2ee30120,0xc178010b,0xa3cc198f}},	//   ीना_, lijf_, itė_, रना_,
   {{0x60cd00d1,0x3a38007b,0x28f800af,0x00000000}},	//   _mlam, _ffrp_, чець_, --,
   {{0x60cd00c8,0x7afe1af7,0x25de000c,0x255700af}},	//   _llam, copt, _केही_, tăl_,
   {{0xf65010ee,0x60cd027d,0xb05b00c3,0x00000000}},	//   ائه_, _olam, tkäl, --,
   {{0x68e20043,0xe89401c8,0x387f1af8,0x2ee30120}},	//   ciod, _пась, _ubur_, hijf_,
   {{0xb05b16c9,0xc17800c7,0xd702010b,0x673b037b}},	//   rkäl, etė_, _кiра, _utuj,
   {{0x78bb1af9,0x69c1007c,0x130600c3,0x78a907c0}},	//   _houv, _üles, мный_, _hnev,
   {{0x78bb1afa,0x78a90051,0x60cd1afb,0x3eba0c6f}},	//   _kouv, _knev, _blam, _ropt_,
   {{0xafe602ce,0xd00a03e6,0x6d5a1abc,0x555800d8}},	//   домл, жеме_, štak, _хаця_,
   {{0x78bb1afc,0x60cd1afd,0x92b50037,0x853c0409}},	//   _mouv, _dlam, _يحتا, _grėb,
   {{0x78bb1afe,0x60cd007c,0x68e201b7,0xbb1b0160}},	//   _louv, _elam, ziod, _spîn,
   {{0x78a91aff,0x99980009,0x60cd1b00,0xb05b1b01}},	//   _onev, _serž_, _flam, rhär,
   {{0x78bb1b02,0x7afe0260,0x2b401b03,0x2b59055c}},	//   _nouv, wopt, tpic_, _bvsc_,
   {{0xb05b01ae,0x7afe0223,0xa2d40bdd,0x2b590176}},	// [1280] phär, topt, योक्, _cvsc_,
   {{0x78a90160,0x273b00af,0x25de00ab,0x2b400510}},	//   _anev, _mână_, _कइली_, rpic_,
   {{0x2d9c006c,0x33270069,0x7afe1b04,0xfbd1006c}},	//   _éve_, _minx_, ropt, نتے_,
   {{0x52bc009a,0x78bb0248,0x7afe19b2,0x5883021f}},	//   _ोत्स, _couv, sopt, выша,
   {{0x78a9068b,0x78bb02d0,0x711b0070,0x7afe00fe}},	//   _dnev, _douv, קונפ, popt,
   {{0x68e21b05,0x78a91b06,0xc178010b,0x00000000}},	//   siod, _enev, ytė_, --,
   {{0xdddc00d5,0x00000000,0x00000000,0x00000000}},	//   berť, --, --, --,
   {{0x78bb1b07,0x6abc008a,0x78a90f32,0x00000000}},	//   _gouv, _horf, _gnev, --,
   {{0x66cf0a55,0x69c100be,0x60cd0284,0x25de021a}},	//   _søke, _üler, _rlam, _केरी_,
   {{0x60cd1b08,0xf7431b09,0x6abc0176,0xc17a01e0}},	//   _slam, _рефо, _jorf, оїм_,
   {{0xa2d4175f,0xa50a002d,0xb05b1193,0x00000000}},	//   योग्, _дежа_, skäm, --,
   {{0x22490c99,0xc178010b,0x30a71b0a,0xd4c60037}},	//   _đake_, rtė_, фров, _تغطي,
   {{0x351b02b5,0xc17800d8,0x60cd1b0b,0x60c001ff}},	//   _וואנ, stė_, _vlam, ömma,
   {{0x3207001e,0x213c0023,0x00000000,0x00000000}},	//   _fyny_, _ttvh_, --, --,
   {{0x63a21b0c,0x27fa004e,0x67281b0d,0x60cd1b0e}},	//   _hron, ępny_, _midj, _tlam,
   {{0x60cd1b0f,0x629a04c5,0x6ee90124,0x66080118}},	//   _ulam, ldto, džbe, _mydk,
   {{0x62981b10,0x5b1519c3,0x78bb1b11,0x63a200d1}},	// [1290] _kavo, емат, _rouv, _jron,
   {{0x78bb1b12,0x6abc001e,0x290408dd,0x7f4d007a}},	//   _souv, _corf, _akma_, _iwaq,
   {{0x78bb1b13,0x25de0429,0x78a9008b,0x6abc033b}},	//   _pouv, _केली_, _pnev, _dorf,
   {{0x62980021,0x7d090484,0x200916ec,0xa01b01ff}},	//   _lavo, ċess, _kyai_, pföd,
   {{0x6abc0568,0xd3660365,0x672802d0,0x61ca022e}},	//   _forf, _حه_, _bidj, ानुष,
   {{0x6abc0297,0x7f4d007a,0x629a0051,0x25fa00ab}},	//   _gorf, _mwaq, jdto, _ऊँखी_,
   {{0x63a21b14,0xd5b11b15,0x78bb1b16,0x00000000}},	//   _aron, افع_, _touv, --,
   {{0xe3b90de3,0x273b0043,0x2129028b,0xf77001df}},	//   зби_, _până_, _niah_, _چال_,
   {{0x03251b17,0x65930095,0x20091b18,0x69c51b19}},	//   ндин, _məhə, _nyai_, lyhe,
   {{0x63a200e0,0x62980382,0x7dee006c,0x3f4d1b1a}},	//   _dron, _cavo, nősé, džu_,
   {{0x62981b1b,0x057411cf,0x69c50557,0xda1f0026}},	//   _davo, _لاند, nyhe, बधित_,
   {{0xf9da02b5,0x629a1b1c,0x0ef80f8a,0x6593013b}},	//   פֿיל, adto, ंक्स_, _nəhə,
   {{0x63a21b1d,0x21291b1e,0x6f0500cc,0x00000000}},	//   _gron, _diah_, _bkhc, --,
   {{0x248d1b1f,0xe3b004e8,0x629800c7,0x00000000}},	//   leem_, _خرم_, _gavo, --,
   {{0x57bd06d9,0xdd921b20,0x2ee10a8a,0xa2ac07df}},	//   ्नुह, دوز_, _dmhf_, जार्,
   {{0x248d0626,0x659300a8,0x91fc00ea,0x2cab0160}},	//   neem_, _cəhə, rgāt, _cncd_,
   {{0xc4d202b5,0x6abc1725,0x2cab02d7,0x63a2013b}},	// [12a0] אגן_, _porf, _dncd_, _xron,
   {{0x248d006f,0x62980176,0x09c40033,0x00000000}},	//   heem_, _xavo, _এইবা, --,
   {{0xa84a004f,0x6abc1b21,0x91fc00ea,0x2cab0260}},	//   كلام_, _vorf, lgār, _fncd_,
   {{0x67281b22,0xab2a021d,0x2129055c,0xa2a1035d}},	//   _sidj, _нома_, _xiah_, _कोस्,
   {{0x66e60b00,0x248d1b23,0x6abc1b24,0x1c1c00fa}},	//   нода, deem_, _torf, पेशल_,
   {{0x69370009,0x3cff0124,0x6593013b,0x69c51b25}},	//   _ićen, čuve_, _zəhə, byhe,
   {{0x67281b26,0x248d006d,0x63a20088,0x69c11b27}},	//   _vidj, feem_, _sron, _ülep,
   {{0x62981b28,0x67280feb,0x692c0395,0x00000000}},	//   _savo, _widj, _eşec, --,
   {{0x62981b29,0xe3b207f6,0x63a20069,0x2ab60b3e}},	//   _pavo, ارع_, _qron, _sæby_,
   {{0x63a21b2a,0x00000000,0x00000000,0x00000000}},	//   _vron, --, --, --,
   {{0x2129028b,0x63a200a5,0x6298081b,0x629a1b2b}},	//   _piah_, _wron, _vavo, rdto,
   {{0x63a2098b,0x3cfa0035,0xdfd10098,0x00000000}},	//   _tron, ंवों_, ليج_, --,
   {{0x09dd09b8,0x62981b2c,0xbfa81663,0x63a21b2d}},	//   _मध्य, _tavo, нтре_, _uron,
   {{0x63ad082d,0x61eb006c,0xb3e90037,0x659300a8}},	//   _šang, állá, _تعمل_, _səhə,
   {{0xe29b02b5,0x69370009,0x51861023,0x00000000}},	//   _זשור, _aćen, _чула, --,
   {{0xb05b00c3,0x00000000,0x00000000,0x00000000}},	//   kkäi, --, --, --,
   {{0x7dee0332,0xe7e00992,0xaa671b2e,0x2d9e15ed}},	// [12b0] tősé, _खेला_, етек, åter_,
   {{0x69111b2f,0x69c50031,0x3a740328,0x257a0055}},	//   gåen, tyhe, ллур, kël_,
   {{0x69370009,0x1df900c3,0x7ae51b30,0x20c20183}},	//   _ećen, _цены_, riht, _góis_,
   {{0xf7711b31,0xa90700d2,0x69c51b32,0x248d01e8}},	//   لات_, ربان, ryhe, xeem_,
   {{0x7d0d1b33,0x57bd01c0,0x257a03bc,0x00000000}},	//   mlas, ्नेह, eël_, --,
   {{0x7d0d1b34,0x00000000,0x00000000,0x00000000}},	//   llas, --, --, --,
   {{0x6d5a039a,0x257a00da,0x1af41b35,0xa2a10808}},	//   štav, gël_, _спря, _कोष्,
   {{0x7d0d1b36,0xa3be01d1,0x00000000,0x00000000}},	//   nlas, ीनं_, --, --,
   {{0x3f890189,0x248d1b37,0x0735172a,0x8af000a8}},	//   _npau_, reem_, _резю, ksəl,
   {{0x7d0d0076,0x248d1b38,0xc3c8004f,0x257a0031}},	//   hlas, seem_, عظيم_, bël_,
   {{0x7d0d1b39,0x3de10083,0x3f89046a,0xa06a1b3a}},	//   klas, _মুসল, _apau_, мана_,
   {{0xa2a102b4,0x34950bfe,0xfc3f00ee,0xf99200a5}},	//   _कोर्, _јадр, _dník_, ברט_,
   {{0xe28e1b3b,0x7d0d1b3c,0x64491b3d,0x2d8c003c}},	//   _ка_, dlas, mbei, ħdem_,
   {{0x200c00ea,0x20c20037,0x64491b3e,0xa3da0026}},	//   ādi_, _cóir_, lbei, _डेट_,
   {{0x442f0159,0xfc3f00a0,0x6281003e,0x443d1b3f}},	//   _kgg_, _kníh_, mflo, _kfw_,
   {{0x64491b40,0x753c00b5,0x98b800ea,0x442f0282}},	//   nbei, _érze, _otrā_, _jgg_,
   {{0x1d0713a1,0x69111b41,0x64491b42,0x60dd0031}},	// [12c0] тети_, tåen, ibei, ërme,
   {{0x6281035f,0x4a431012,0x7d0d1b43,0x692c0139}},	//   nflo, инув, alas, _aşea,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7461b44,0x6d5c008c,0x442f0118,0x8af0013b}},	//   ведо, msra, _ngg_, msəm,
   {{0xd7ef0082,0x7d041b45,0xb865006c,0x2bc90026}},	//   يكم_, mois, طانو, _रथया,
   {{0x7d041b46,0xa2a11b47,0x6d5a016f,0x442f027a}},	//   lois, _कोल्, štau, _agg_,
   {{0x1ae31b48,0x6d5c038e,0x0573183b,0x442f102f}},	//   _торм, nsra, لايد, _bgg_,
   {{0x7d041b49,0x22490129,0x62811b4a,0x69c300c3}},	//   nois, _đaka_, eflo, änee,
   {{0x613e00ea,0x62811b4b,0x64a310b4,0x00000000}},	//   _mīle, fflo, рања, --,
   {{0x02a61a76,0x7d0d1b4c,0x6d5c1789,0x7d041b4d}},	//   трим, zlas, ksra, hois,
   {{0x7d0d1b4e,0xd48f1b4f,0x7d040086,0xf48400d1}},	//   ylas, _кр_, kois, _ماشی,
   {{0x6d5c13a4,0x04461b50,0x7d040421,0x6ee90207}},	//   dsra, _редн, jois, džba,
   {{0x7d041b51,0xfbdf0298,0x6d5c0298,0x00000000}},	//   dois, _leêr_, esra, --,
   {{0x7658000e,0xf1a61b52,0x00000000,0x00000000}},	//   navy, _арин, --, --,
   {{0x2fcd01cc,0x7d0d1b53,0x6d5c1b54,0x442f0044}},	//   šeg_, tlas, gsra, _ygg_,
   {{0x7d041b55,0x656a0037,0x48bd0083,0x8c3b033b}},	//   gois, irfh, _আগ্র, _maßg,
   {{0x7d0d1b56,0x20c2004f,0xe7bd0083,0x3f89012f}},	// [12d0] rlas, _tóir_, _অধ্য, _upau_,
   {{0x7d0d0fd8,0x765808c7,0xf09f0392,0x00000000}},	//   slas, javy, ldà_, --,
   {{0x6f02004f,0x7d041b57,0x765800c7,0x24860168}},	//   _íoca, bois, davy, _obom_,
   {{0x7d0d1505,0xf09f0176,0x658a00a8,0x48e10033}},	//   qlas, ndà_, _məhd, যক্র,
   {{0x973504e8,0x6d5a1b58,0x628100e9,0xf094016b}},	//   اکرا, štat, yflo, ינף_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb41899,0x443d0051,0x940d00a8,0x00000000}},	//   ייס_, _pfw_, ənən_, --,
   {{0x26190461,0x8a180421,0x00000000,0x00000000}},	//   येगी_, _росс_, --, --,
   {{0x64491b59,0x27e0004f,0x76580054,0xf79400d8}},	//   rbei, úint_, bavy, _катэ,
   {{0x3ce901a9,0x64491b5a,0xf09f0443,0x7d04023c}},	//   hiav_, sbei, edà_, zois,
   {{0x62811b5b,0xdc100324,0x7d04002f,0x69370124}},	//   rflo, _ार्ड_, yois, _oćem,
   {{0x62810093,0x20c20037,0x273900e2,0xe7b70099}},	//   sflo, _cóip_, _kèn_, _आपाप,
   {{0xe3b00286,0x273902e9,0x6e290095,0x7d041b5c}},	//   _وره_, _jèn_, əmbə, vois,
   {{0xe2961b5d,0x249d0189,0x249f1b5e,0x6d5c1b5f}},	//   _баш_, _hawm_, ldum_, tsra,
   {{0xa0a61b60,0x249d01a9,0x7d040086,0x691102df}},	//   _байд, _kawm_, tois, tåel,
   {{0x249f00fb,0x6d5c1b61,0x7242006c,0x7b1001ae}},	//   ndum_, rsra, _پھیل, räum,
   {{0x7d041b62,0xcb671b63,0x237f1b64,0x6d5c0110}},	// [12e0] rois, лате_, ntuj_, ssra,
   {{0x249d0d4b,0xda650082,0x6d5a0391,0x8f9b0397}},	//   _lawm_, لامي, átas, _טיפי,
   {{0x7d041b65,0xbebb0055,0x9a1600af,0x00000000}},	//   pois, yqëz, уфаш, --,
   {{0x237f1b66,0x249d006d,0x27391b67,0x28df00b4}},	//   ktuj_, _nawm_, _bèn_, पोलि,
   {{0x27e00014,0x76581b68,0x249f1b69,0x00000000}},	//   àin_, tavy, ddum_, --,
   {{0xb8cb1b6a,0x2ca0007c,0x3b0a0086,0x27391b6b}},	//   _को_, ldid_, _чего_, _dèn_,
   {{0x76581b6c,0x45d41172,0x2ca000be,0x00000000}},	//   ravy, ройс, odid_, --,
   {{0x2ca01b6d,0x249d006f,0x76581040,0x8af0013b}},	//   ndid_, _cawm_, savy, ksək,
   {{0xc67600f5,0xe6461b6e,0x249d01e8,0x66760071}},	//   _مطاب, _безп, _dawm_, _مدار,
   {{0x63ad024e,0x4b7b0070,0x5b7b0070,0x2d9a1b6f}},	//   _šanc, עטיג, עריא, _ospe_,
   {{0x249d006d,0xf0b51b70,0xdb060055,0x5ab7016b}},	//   _fawm_, айнь, _arkë, אליע_,
   {{0x249d006d,0x273900bf,0xa2b0018d,0x00000000}},	//   _gawm_, _yèn_, _अचक्, --,
   {{0xf09f12c3,0x9f350185,0x2d9a1b71,0x2ca01b72}},	//   rdà_, регі, _aspe_, ddid_,
   {{0x741300f3,0x11d60041,0x249d006d,0x539b0d85}},	//   _اوها, _متعد, _zawm_, _ניוו,
   {{0x7f441b73,0x56370070,0x249d006f,0xf1a301f1}},	//   _etiq, ראלע_, _yawm_, _грын,
   {{0x25ec00ab,0x00000000,0x00000000,0x00000000}},	//   _अइनी_, --, --, --,
   {{0x4a5505c2,0x5f950036,0xba5500ed,0x6d471b74}},	// [12f0] икас, _типт, ивај, spja,
   {{0xb05b01ae,0x3ce9006d,0x27391b75,0x658a00a8}},	//   rkäu, siav_, _rèn_, _məhb,
   {{0x6d5a1b76,0x249f0448,0x853c004b,0x80aa0761}},	//   štar, ydum_, _brėm, _जोडे,
   {{0x6d451b77,0x237f0035,0x2739021e,0x00000000}},	//   _itha, ytuj_, _pèn_, --,
   {{0x0a6b1b78,0x249d01e8,0xb05b00c3,0xa2d700b8}},	//   _први_, _rawm_, lkäs, यसम्,
   {{0x249d0221,0xe73602fb,0xb6a51b79,0x00000000}},	//   _sawm_, шеш_, рикл, --,
   {{0xa564004f,0xb05b1b7a,0xb9250037,0x7d1d00fe}},	//   مدين, nkäs, _نفسي, _khss,
   {{0x3860004f,0xdb060118,0x6d451b7b,0xe79503fc}},	//   óirt_, _arkè, _mtha, _پارک,
   {{0x249f008f,0x6d45011e,0x7d1d0118,0x69370207}},	//   rdum_, _ltha, _mhss, _oćek,
   {{0x6d451b7c,0x237f0035,0x68eb1b7d,0x6ee90207}},	//   _otha, rtuj_, ligd, džbo,
   {{0x249d01a9,0x6d4501e8,0x25b901b2,0x7f440176}},	//   _tawm_, _ntha, _جهاد_, _stiq,
   {{0x20560185,0x68eb0c7c,0x25de09b4,0x00000000}},	//   штор, nigd, _केटी_, --,
   {{0x6d451b7e,0x60dd01f4,0x443f1b7f,0x00000000}},	//   _atha, ërma, mcu_, --,
   {{0x443f1b80,0x7d1d0211,0x68eb0008,0x00000000}},	//   lcu_, _ahss, higd, --,
   {{0x5046027a,0xa01b006c,0xddc31b81,0x68eb1b82}},	//   _кейб, lföl, обри, kigd,
   {{0x1c461b83,0x6d450211,0x645b0110,0x98aa1b84}},	//   рнам, _dtha, naui, _kubą_,
   {{0x2ca000ab,0x68eb1b85,0xb05b0328,0x6f071b86}},	// [1300] rdid_, digd, rkät, bojc,
   {{0xc332011d,0x60c41b87,0xb05b00be,0xe9d2026e}},	//   קוב_, _hoim, skät, يغا_,
   {{0x2d9a1b88,0x60d603d0,0x00000000,0x00000000}},	//   _uspe_, _klym, --, --,
   {{0x270e00dc,0x443f1b76,0x200c0095,0x186a0183}},	//   ित्र_, jcu_, ədir_, тади_,
   {{0x443f0bcc,0x02b50066,0x25de04aa,0x3f8200ac}},	//   dcu_, _अचंभ, _केजी_, ntku_,
   {{0x658a01c2,0x236d1b89,0xb4c00d1f,0x316b0035}},	//   _rəhb, drej_, ुस्_, ńczy_,
   {{0x6d450211,0x00000000,0x00000000,0x00000000}},	//   _xtha, --, --, --,
   {{0x399b1899,0x63ad1b8a,0xe3e70033,0x798e0118}},	//   _בילד, _šana, _পড়ব, _ipbw,
   {{0xf7430b00,0xdb060118,0x764100e5,0x00000000}},	//   _мето, _arké, _ffly, --,
   {{0x78a21b8b,0x443f1b8c,0xdce70067,0x00000000}},	//   ldov, acu_, mują, --,
   {{0x3a3702da,0x6f071b8d,0xaa370070,0x60c40b6d}},	//   ירים_, vojc, יטיק_, _boim,
   {{0x60c409e3,0x645b0176,0xd4671b8e,0x69de01d7}},	//   _coim, caui, _вице_, izpe,
   {{0x77f41b8f,0x6d450024,0x60c41b90,0xdce70035}},	//   _अशोक_, _stha, _doim, nują,
   {{0x0eeb1303,0x644002c4,0xb05b0421,0x6ee900ac}},	//   тьми_, lcmi, tkäs, ržbo,
   {{0xeda400d4,0xdef801c8,0xd2f8006c,0x60d6008c}},	//   ошто, рыя_, _لکھا_, _flym,
   {{0xdce7004e,0x60d61b91,0xb05b147d,0x8af0013b}},	//   kują, _glym, rkäs, mrəy,
   {{0x78a207e5,0x6d5a00cd,0x69de01ed,0x00000000}},	// [1310] ddov, štap, ezpe, --,
   {{0x6e95004f,0xdce704a8,0x443f1b92,0x39a7059d}},	//   _الدا, dują, zcu_, ишев,
   {{0x6d451b93,0x2b491b94,0x78a00371,0x3ea10160}},	//   _utha, spac_, _bamv, _iaht_,
   {{0x78a00176,0xa3c70324,0x78a200d5,0x00000000}},	//   _camv, _उथल_, gdov, --,
   {{0x2d831b95,0x07a50382,0x36691b96,0xdce70067}},	//   ltje_, салн, гало_, gują,
   {{0x98bc00ea,0x236d0009,0x78a21b97,0x6d48003e}},	//   īvā_, vrej_, adov, ídag,
   {{0x2d831b98,0x645b1b99,0x443f1b9a,0x3ea100be}},	//   ntje_, taui, tcu_, _maht_,
   {{0xfdf8011d,0x66cf054e,0x443f00ea,0x2d8302a2}},	//   ימוש_, _køkk, ucu_, itje_,
   {{0x443f1b9b,0x60c4006e,0x68e91b9c,0x81e40083}},	//   rcu_, _roim, _imed, _ভুল_,
   {{0x443f0012,0x236d1b9d,0xa01b1b9e,0x60d6060b}},	//   scu_, rrej_, rföl, _slym,
   {{0x60d61b9f,0x2d831ba0,0xa0a61ba1,0x60c41ba2}},	//   _plym, jtje_, банд, _poim,
   {{0x236d02c6,0xfd1f0023,0xa01b01ff,0x2d830051}},	//   prej_, _nhì_, pföl, dtje_,
   {{0x26c506e2,0x60c403ad,0x2d8302a2,0xb05b1ba3}},	//   _kolo_, _voim, etje_, tkär,
   {{0x68fb15d7,0x78a20e6a,0x291f006d,0x66cf00d4}},	//   _ljud, zdov, _lhua_, _søkj,
   {{0x60c41ba4,0x645906b3,0x3f821431,0xdcfc1075}},	//   _toim, _kewi, stku_, strč,
   {{0xeb9a14d0,0x26c51ba5,0xb05b013c,0xfd1f0023}},	//   либ_, _lolo_, skär, _chì_,
   {{0x63bb043f,0x64591ba6,0x2d830120,0xfc3f08bf}},	// [1320] nxun, _mewi, atje_, _anís_,
   {{0x68fb1ba7,0x64591ba8,0xf4120100,0x78a01ba9}},	//   _ajud, _lewi, לפן_, _samv,
   {{0x272201a5,0xdb041baa,0x68fb013c,0xdce70035}},	//   _hưng_, nvié, _bjud, wują,
   {{0x64590297,0x291f1bab,0x63ab1bac,0xd7fa09eb}},	//   _newi, _chua_, _orgn, лул_,
   {{0x26c50038,0x78a20664,0x96ea1bad,0x68fb0981}},	//   _bolo_, rdov, лька_, _djud,
   {{0x26c51bae,0x68e91baf,0xdce70035,0x68fb030d}},	//   _colo_, _emed, rują, _ejud,
   {{0xb0c8009a,0x64590b37,0x6b841bb0,0x27220019}},	//   _लवंग, _bewi, ltig, _lưng_,
   {{0xd4971bb1,0xdce70035,0x26c50036,0x39470079}},	//   брь_, pują, _eolo_, ínse_,
   {{0x64590297,0x68e300da,0xd250004f,0x26c50160}},	//   _dewi, ënde, ونة_, _folo_,
   {{0x6b8401ae,0x26c51bb2,0x63ab085e,0x15e300ab}},	//   itig, _golo_, _drgn, _केकर_,
   {{0x6b841bb3,0xd9fa01c0,0x70550312,0x60dd0055}},	//   htig, ्थित_, يندا, ërmo,
   {{0x64590b19,0x2ed108b0,0x6b841bb4,0x212002d7}},	//   _gewi, हस्त, ktig, _chih_,
   {{0x765a01f4,0xdfd801d3,0x27220023,0x6b84023a}},	//   _kety, бър_, _cưng_, jtig,
   {{0x69370009,0xd9fa1bb5,0x27220023,0x8c000033}},	//   _ićev, ्थात_, _dưng_, ্ধান_,
   {{0x765a1bb6,0x6b8411cc,0x69180453,0xfd1f0023}},	//   _mety, etig, víen, _phì_,
   {{0x2d830a75,0x7afc0009,0x3ea10159,0x09df0033}},	//   rtje_, _ajrt, _waht_, _বুঝা,
   {{0x6b841bb7,0x2d831bb8,0x3ea1035f,0x753a1a47}},	// [1330] gtig, stje_, _taht_, _lutz,
   {{0x433b0070,0x765a1bb9,0xf41a0033,0x291f1bba}},	//   טעמב, _nety, _ডলার_, _shua_,
   {{0xfd1f00e8,0x6b8414e7,0x753a02bf,0x291f01e8}},	//   _thì_, atig, _nutz, _phua_,
   {{0x26c51bbb,0x291f006f,0xa3b801c0,0x00000000}},	//   _solo_, _qhua_, ङमा_, --,
   {{0x66040092,0x6c7a02b5,0x765a165f,0x6b841bbc}},	//   şikl, _דארפ, _bety, ctig,
   {{0x321c00d5,0x2f5c1804,0x64591bbd,0x753a0110}},	//   _ozvy_, נדונ, _sewi, _butz,
   {{0x765a01d2,0x291f1bbe,0x26c51bbf,0xd05d0095}},	//   _dety, _thua_, _volo_, sisə,
   {{0x93451bc0,0xf9920d85,0x68e917c3,0x60dd0009}},	//   оние, _קרן_, _umed, jhsm,
   {{0x26c51bc1,0xdcfc00ea,0x03a51bc2,0x76b9002d}},	//   _tolo_, ntrā, ципо, _клар_,
   {{0xdddc006c,0x21201bc3,0x765a0d35,0x65951bc4}},	//   zerű, _shih_, _gety, _мазу,
   {{0x63a400f4,0x272200e2,0x63bb01ef,0xb05b13b8}},	//   _šint, _sưng_, sxun, tkäp,
   {{0x297a02b5,0x7985001e,0x63ab012e,0x7b10033b}},	//   סטרא, ithw, _trgn, läut,
   {{0xa3bb03c5,0xb4d50026,0x63ab0036,0xbf050099}},	//   _حاضر_, हसी_, _urgn, ळवून_,
   {{0x63a91bc5,0x673b08c7,0x161d1bc6,0x217500af}},	//   mven, _muuj, _फरार_, _дуир,
   {{0x63a91bc7,0x6da319c3,0xed5a15d6,0xada30384}},	//   lven, мира, роб_, марл,
   {{0x161e0066,0x27220023,0x63a91bc8,0x60dd0110}},	//   येटर_, _tưng_, oven, chsm,
   {{0x6b841bc9,0xab661bca,0x798500e9,0x0aea1bcb}},	// [1340] utig, ювал, ethw, адай_,
   {{0x6b841bcc,0x63a91bcd,0x6023010b,0x00000000}},	//   rtig, iven, _ідэа, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac7600b5,0x765a1bce,0x6d4e008c,0x274a0fb4}},	//   _بادش, _sety, mpba, ачко_,
   {{0x63a90120,0x765a1bcf,0x7cf3003c,0x753a0065}},	//   jven, _pety, għru, _sutz,
   {{0x63a91bd0,0x356a1a5a,0x7d161bd1,0x645d008a}},	//   dven, арин_, llys, ðsin,
   {{0xd547051b,0x63a912b2,0xe6da0084,0xa9671bd2}},	//   опје_, even, _भतीज, _мира_,
   {{0x94aa0678,0x387f0037,0xa3d5022e,0x7d161bd3}},	//   ртка_, _gcur_, सनं_, nlys,
   {{0x63a91bd4,0xdb040176,0x00000000,0x00000000}},	//   gven, nviï, --, --,
   {{0x63a402c4,0x7d1600e9,0x6f020079,0x0bb700a5}},	//   _šins, hlys, _íoch, קלים_,
   {{0x6ebe0026,0x63a91bd5,0xdb0401ef,0x7d161bd6}},	//   शानु, aven, nxiñ, klys,
   {{0x63a91105,0x00000000,0x00000000,0x00000000}},	//   bven, --, --, --,
   {{0x63a90043,0x66cf0044,0x4ea7196c,0x691802d7}},	//   cven, _søki, орва, víel,
   {{0xe297146b,0xe7f2073f,0x7d160345,0x00000000}},	//   _мач_, _आइना_, elys, --,
   {{0x7b1001ae,0x78170808,0x75220345,0xddc50225}},	//   häus, _तर्क_, _khoz, _dehş,
   {{0xd5a407a8,0x69c300ab,0xdcee0228,0x00000000}},	//   _یہ_, änem, tubā, --,
   {{0x28ab0d00,0x6d4e0345,0x00000000,0x00000000}},	// [1350] _घोषि, apba, --, --,
   {{0x7e9904e8,0x69370124,0x3958099e,0x387f1bd7}},	//   _اندر_, _oćet, _bwrs_, _scur_,
   {{0xdcfc0080,0x3958001e,0x63a91bd8,0x658a00a8}},	//   strā, _cwrs_, zven, _səhn,
   {{0x79851bd9,0x236601cc,0x6ee90b16,0x63a91bda}},	//   rthw, _ovoj_, džbi, yven,
   {{0x7d0d0043,0xba7707f6,0x66dd01cb,0x98aa00fe}},	//   moas, _واست, _lèke, _hubě_,
   {{0x60dd01f4,0x63a91bdb,0x7d0d1bdc,0x752201d7}},	//   ërmj, vven, loas, _ahoz,
   {{0x3958001e,0x00000000,0x00000000,0x00000000}},	//   _gwrs_, --, --, --,
   {{0x63a902dd,0x7d0d1663,0x2ec805f7,0xb4d500ab}},	//   tven, noas, _रक्त, हसे_,
   {{0x63a90248,0x225c023a,0xdbe300f6,0x00000000}},	//   uven, _bevk_, _déço, --,
   {{0x67210a66,0x0322005f,0x2b4b00e2,0x2366063c}},	//   _uhlj, ндын, _mtcc_, _dvoj_,
   {{0xa0a60390,0x66dd0118,0x7d0d0421,0x00000000}},	//   панд, _cèke, koas, --,
   {{0x21061bdd,0x2b4b011e,0x00000000,0x00000000}},	//   रवेश_, _otcc_, --, --,
   {{0x087602b5,0xe45602b5,0xdfd2017e,0x2b590027}},	//   הערט_, _זינט_, ريس_, _nwsc_,
   {{0x75291bde,0x00000000,0x00000000,0x00000000}},	//   lmez, --, --, --,
   {{0x2cf9020d,0x412a0382,0x00000000,0x00000000}},	//   ्कूल_, _локо_, --, --,
   {{0x0b461bdf,0x201e01c2,0x2b59009f,0xb05b00c3}},	//   знан, ətin_, _bwsc_, ljän,
   {{0x7d161be0,0x2b59099e,0xfc030c90,0x98a4004b}},	// [1360] rlys, _cwsc_, епто, _gimę_,
   {{0x6d4e1be1,0x7d161be2,0x25ec00ab,0x00000000}},	//   ppba, slys, _अइली_, --,
   {{0xbe3b00a5,0x7d160304,0x75291be3,0xf1cb0099}},	//   _לעית, plys, kmez, ाहिन,
   {{0x7d0d1be4,0xc18c0070,0x658a013b,0x00000000}},	//   coas, שטאָ, _dəhl, --,
   {{0xdc3700c2,0x68e31be5,0x00000000,0x00000000}},	//   _מאכט_, ënda, --, --,
   {{0x7b10033b,0x66e3093e,0xa01b008d,0x658a013b}},	//   räus, ноча, sgög, _fəhl,
   {{0x23661be6,0x8af00095,0xceb30122,0x39e70382}},	//   _svoj_, ssəs, תיו_, _едро_,
   {{0x68130035,0x225c0225,0x00000000,0x00000000}},	//   _będą, _sevk_, --, --,
   {{0x2005027d,0x09c40033,0x66dd0118,0x225c02a7}},	//   ğlik_, _এইটা, _sèke, _pevk_,
   {{0x20050448,0x66dd0118,0xdb0f0090,0x00000000}},	//   şlik_, _pèke, _arcê, --,
   {{0x74160647,0x7d0d023c,0x00000000,0x00000000}},	//   _کوشا, yoas, --, --,
   {{0x69370a78,0x236601fe,0x09f700a5,0x55bb00a5}},	//   _kćer, _tvoj_, למים_, _למבו,
   {{0xa3cd0cea,0x00000000,0x00000000,0x00000000}},	//   रहण_, --, --, --,
   {{0xdefb06d8,0x63a21be7,0x9f4e05ee,0x00000000}},	//   сым_, _ison, ðnám_, --,
   {{0xbbc50355,0x7d0d1be8,0xec6b0210,0x629a0f93}},	//   लङ्क, toas, йрак_, meto,
   {{0xfc3f1be9,0x7aee01e4,0x51fb00a5,0x629a0cec}},	//   _baía_, _ambt, _להוצ, leto,
   {{0x7d0d002d,0x63a20069,0xfc3f1bea,0x2c22012f}},	// [1370] roas, _json, _caía_, _मरणं_,
   {{0x7f4d0132,0x63a2002f,0x80180b8d,0x7d0d1beb}},	//   _itaq, _mson, _عزيز_, soas,
   {{0x7d0d1bec,0x69da018d,0x75290031,0x00000000}},	//   poas, _ütel, ymez, --,
   {{0x3ce01bed,0x63a21bee,0x57f51347,0x629a1bef}},	//   chiv_, _oson, мпет, heto,
   {{0xd3660a42,0x629a1bf0,0x6d4a00da,0xdcfc002d}},	//   _جه_, keto, _çfar, stră,
   {{0x629a1bf1,0x658a01c2,0x2ca91bf2,0x66cf03d0}},	//   jeto, _təhl, ldad_, _nøkt,
   {{0x63a21bf3,0x65920274,0x7f4d009f,0x75291bf4}},	//   _ason, вају, _ltaq, tmez,
   {{0x2ca91bf5,0xddde0107,0x7f4d013b,0x81cb0033}},	//   ndad_, _depň, _otaq, _রইল_,
   {{0x75290484,0xb05b013c,0x2ca900de,0xe739001e}},	//   rmez, tjän, idad_, _grŵp_,
   {{0x2bdf000c,0x658a00a8,0xe3ca02d7,0x00000000}},	//   पैया, _zəhm, _soñó_, --,
   {{0x7f4d1423,0x63a21bf6,0x93ca006c,0xdb2400b5}},	//   _ataq, _eson, مایہ_, ésén,
   {{0x290f1bf7,0x6aa7023a,0x63a2005f,0x3cf90067}},	//   noga_, _lajf, _fson, ्कों_,
   {{0x2ca91bf8,0x03a5002d,0x00000000,0x00000000}},	//   ddad_, _цило, --, --,
   {{0x629a1bf9,0x6aa71bfa,0x2ca91bfb,0x290f1b68}},	//   ceto, _najf, edad_, hoga_,
   {{0x386d0446,0x290f1bfc,0x6f0e0076,0x3ce0006d}},	//   _oder_, koga_, robc, thiv_,
   {{0x386d01f4,0x00000000,0x00000000,0x00000000}},	//   _nder_, --, --, --,
   {{0x63a2027a,0xdb060097,0x658a00a8,0x394d08b7}},	// [1380] _xson, _arká, _rəhm, _česa_,
   {{0x3ce0006d,0xb05b01ff,0x658a00a8,0xe3a704cd}},	//   shiv_, hjäl, _səhm, _یر_,
   {{0x88861bfd,0x290f1bfe,0x62830453,0x00000000}},	//   длеж, foga_, _mcno, --,
   {{0x290f1bff,0xa3cd0e3b,0xa3bf0437,0x386d11cb}},	//   goga_, रहा_, ीहा_, _cder_,
   {{0x629a1c00,0xd70a00af,0x60dd0031,0x6aa7023a}},	//   yeto, онде_, ërmi, _fajf,
   {{0x386d1c01,0x473300d4,0x629a1c02,0x2b520176}},	//   _eder_, вніс, xeto, mpyc_,
   {{0x290f1c03,0x629a0fb0,0x63a2073a,0x00000000}},	//   boga_, veto, _sson, --,
   {{0x629a018e,0x66cf0185,0x290f0027,0x00000000}},	//   weto, _søkt, coga_, --,
   {{0xd90d1c04,0x629a1c05,0xa68612b1,0xb6cb00fd}},	//   _این_, teto, _олад, _ڈالے_,
   {{0xb6cb00f5,0x62830176,0x68e200ac,0x00000000}},	//   _والے_, _ccno, lhod, --,
   {{0x629a1c06,0x658a01c2,0x02a300d8,0x26cc1945}},	//   reto, _məhk, трым, _iodo_,
   {{0x63a21c07,0x629a1c08,0x7549006c,0x62830069}},	//   _tson, seto, őszö, _ecno,
   {{0x629a1c09,0x63a21c0a,0x04430b46,0x26cc1c0b}},	//   peto, _uson, _речн, _kodo_,
   {{0xe1ef1c0c,0x7ce30006,0x2cb91c0d,0x26cc122f}},	//   اسی_, _kõrg, _snsd_, _jodo_,
   {{0x26cc0f1f,0x9f3402ce,0xdc3a0723,0xc3270082}},	//   _modo_, тері, _açık, _تكون_,
   {{0x63ad0009,0xe7ab00a0,0x2ca902d7,0x68e200ac}},	//   _šani, _ďaľš, udad_, jhod,
   {{0x2ca91c0e,0x290f1c0f,0x68e21c10,0x6aa70282}},	// [1390] rdad_, voga_, dhod, _pajf,
   {{0x26cc1c11,0xcf27017e,0x60cd00cc,0x27e60118}},	//   _nodo_, _تربي, _hoam, dzon_,
   {{0x290f1c12,0x6aa70009,0x7ce300ab,0x68e31c13}},	//   toga_, _vajf, _nõrg, ëndo,
   {{0x2fe4027d,0xf8690037,0xa41e021a,0x00000000}},	//   _örgü_, سمتي_, _परंप_, --,
   {{0x26cc108a,0x6aa70478,0x60cd0160,0xf7f400fd}},	//   _bodo_, _tajf, _moam, پسند,
   {{0xf7700a42,0x26cc0453,0x6f020079,0x290f001c}},	//   شاه_, _codo_, _íoct, soga_,
   {{0x27e600d7,0x68e2023a,0x290f0124,0xa5641c14}},	//   azon_, bhod, poga_, ندين,
   {{0x68e21298,0x27e6027d,0xce38011d,0x26de00ee}},	//   chod, bzon_, ואות_, _elto_,
   {{0xe3b107f6,0x248d1c15,0x7d0301ef,0x628300ee}},	//   ارب_, rfem_, _ínsu, _pcno,
   {{0x26cc1c16,0x888100fd,0x00000000,0x00000000}},	//   _godo_, _شیڈن, --, --,
   {{0x78a900ab,0xcb12011d,0x78bb0298,0x60cd00f6}},	//   _kaev, רלי_, _knuv, _boam,
   {{0x26c701cc,0x6adc0355,0x98b80029,0xe45400d8}},	//   ljno_, _यत्र, _kurā_, _акцы,
   {{0x95221c17,0x60cd0043,0x26cc1c18,0xb05b00c3}},	//   _حکوم, _doam, _yodo_, nkäy,
   {{0x68e2114d,0xd36e11cf,0x78a9007c,0x628300d7}},	//   zhod, _اهو_, _laev, _ucno,
   {{0x60cd1c19,0x3eba0023,0x27e600b5,0x7d091c1a}},	//   _foam, _vnpt_, zzon_, česn,
   {{0xdca31c1b,0x78a91c1c,0x7693037a,0x64491c1d}},	//   ласи, _naev, lıyı, ncei,
   {{0xac070e75,0xeb971c1e,0x68e2024e,0x683601d6}},	// [13a0] ента_, нит_, vhod, _müdü,
   {{0x62811c1f,0x09e61c20,0x7693027b,0x4e1101c0}},	//   nglo, нозн, nıyı, _दुवै_,
   {{0xd9100332,0xae5b0122,0x26cc1c21,0x443d0273}},	//   لیس_, _מכיר, _rodo_, _ogw_,
   {{0x38600082,0xa01b022a,0x26cc1c22,0x68e200b8}},	//   úir_, mför, _sodo_, uhod,
   {{0xa01b013c,0x26cc1c23,0x68e203d0,0xcc3b016b}},	//   lför, _podo_, rhod, _מעכט,
   {{0x644b1c24,0x68e21321,0x569400cf,0x7ce300be}},	//   _afgi, shod, такт, _põrg,
   {{0xa01b1c25,0x68e20254,0x26cc008b,0x25a5021d}},	//   nför, phod, _vodo_, _csll_,
   {{0x28c70066,0x7ce300ab,0xe51006bc,0xd37a0279}},	//   _रचयि, _võrg, ावधि_, пчо_,
   {{0x26cc12d1,0x29041c26,0x00000000,0x00000000}},	//   _todo_, _ijma_, --, --,
   {{0x60cd0391,0xa01b013c,0x026a00c3,0x6281017b}},	//   _soam, kför, чший_, gglo,
   {{0x661100e0,0x60cd0160,0x00000000,0x00000000}},	//   _پژوا, _poam, --, --,
   {{0x73e61c27,0xa01b013c,0x443d030d,0x64490392}},	//   _поез, dför, _ggw_, ccei,
   {{0x63ad0009,0xddcc0355,0xef1f1c28,0xe3af0088}},	//   _šanv, _čišt, stüm_, _هرو_,
   {{0x661a1c29,0x673a0024,0x00000000,0x00000000}},	//   _kytk, _jitj, --, --,
   {{0xdd94004b,0x673a0955,0x60cd002d,0xfcd9006c}},	//   лары, _mitj, _toam, وارڈ_,
   {{0x673a1c2a,0x00000000,0x00000000,0x00000000}},	//   _litj, --, --, --,
   {{0x661a00ee,0x00000000,0x00000000,0x00000000}},	// [13b0] _lytk, --, --, --,
   {{0xff50004f,0x78a900b9,0x29041c2b,0x213b0069}},	//   _اخي_, _saev, _ajma_, _hiqh_,
   {{0x317e1c2c,0x00000000,0x00000000,0x00000000}},	//   nutz_, --, --, --,
   {{0x6ee201ba,0xda081c2d,0x6d550223,0x00000000}},	//   _vôbe, رينه_, mpza, --,
   {{0x317e01ae,0x07a51c2e,0x981401c8,0x7ce3007c}},	//   hutz_, талн, льшч, _võrd,
   {{0xcf9402b5,0x7e67012e,0x212900e0,0x317e01ed}},	//   רטס_, najp, _lhah_, kutz_,
   {{0x6b8d1c2f,0xceb402b8,0x24861b1c,0x673a1c30}},	//   ltag, טיס_, _bcom_, _ditj,
   {{0xdb0606d2,0x62811c31,0x24861c32,0x673a02a2}},	//   _erkä, wglo, _ccom_, _eitj,
   {{0x6b8d0dc5,0x64491c33,0x479418dd,0x6281099e}},	//   ntag, rcei, _مجلس, tglo,
   {{0x21291c34,0xd90d006c,0x64491c35,0x57f41c36}},	//   _ahah_, _ایچ_, scei, _спут,
   {{0x057400d1,0x69c50055,0x6b8d1c37,0x00000000}},	//   _ماند, nxhe, htag, --,
   {{0x212900d7,0x6b8d1c38,0x62811c39,0xa01b01ff}},	//   _chah_, ktag, sglo, vför,
   {{0xa8560122,0x33271c3a,0x660401d6,0x658a00a8}},	//   כירה_, _thnx_, şikt, _rəhi,
   {{0x658a01c2,0x6b8d1c3b,0xe1f101ca,0x249f1c3c}},	//   _səhi, dtag, _پست_, leum_,
   {{0x8d63192f,0x92580037,0x213b1c3d,0x98b80160}},	//   ивре, _أشهر_, _fiqh_, _jură_,
   {{0xa01b1c3e,0x98b80160,0x00000000,0x00000000}},	//   rför, _mură_, --, --,
   {{0xa01b022a,0x6b8d1c3f,0xcb671c40,0x6d5502a2}},	// [13c0] sför, gtag, кате_, apza,
   {{0xa01b01ff,0x00000000,0x00000000,0x00000000}},	//   pför, --, --, --,
   {{0xfaa31c41,0xa01b0093,0x673a0223,0xef1f00b5}},	//   рахо, ngön, _ritj, ztük_,
   {{0x673a1c42,0x6b8d1c43,0x080a00f8,0x00000000}},	//   _sitj, btag, وزشي_, --,
   {{0x2ca0007c,0x673a1c44,0x272901ba,0x98b80160}},	//   meid_, _pitj, kúnd_, _aură_,
   {{0x2ca01c45,0x98b80118,0x66dd0107,0xda650c74}},	//   leid_, _bură_, _dèko, _مافي,
   {{0x673a0044,0x442000d8,0x888402fd,0x5fa90035}},	//   _vitj, _ši_, _میان, _चैनल,
   {{0x442001a5,0x2ca000ab,0xb4dc0026,0xef1f00b5}},	//   _ơi_, neid_, डसे_, ttük_,
   {{0xccf30052,0xf7461c46,0x07a30132,0x2b46004f}},	//   יכה_, _резо, _катн, íoch_,
   {{0x2ca01c47,0x21291c48,0x2d9a0c61,0x673a1192}},	//   heid_, _shah_, _oppe_, _uitj,
   {{0x60f9019b,0xc486189d,0x2ca01c49,0x6b8d1c4a}},	//   ення_, _алек, keid_, ztag,
   {{0x6b8d010d,0x249f0067,0xdb040421,0x64a610b4}},	//   ytag, ceum_, lviä, _јада,
   {{0x2ca000ab,0x44200019,0x996200b8,0xddde0107}},	//   deid_, _ái_, _níže_, _depō,
   {{0x44260232,0x2d471c4b,0x6d430118,0x00000000}},	//   _izo_, _põe_, _énak, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8d1c4c,0x2ca000b9,0x2009006d,0x00000000}},	//   ttag, geid_, _txai_, --,
   {{0xbab91c4d,0x6b8d1786,0x00000000,0x00000000}},	// [13d0] нгах_, utag, --, --,
   {{0x6b8d1c4e,0x7a40024e,0x249f1c4f,0xbb19004f}},	//   rtag, vští, zeum_, رياض_,
   {{0x6b8d1b39,0x249f012f,0x2ca01c50,0x00000000}},	//   stag, yeum_, beid_, --,
   {{0xf7711c51,0x2ca0009e,0x60dd00d8,0x98ad004e}},	//   مات_, ceid_, nksm, _mieć_,
   {{0xb05b1c52,0x6d45023c,0x44260b13,0x00000000}},	//   rjäh, _huha, _nzo_, --,
   {{0x6d451c53,0x6f150033,0xd6db0352,0xc5f40033}},	//   _kuha, nozc, ьте_, _ছড়া_,
   {{0xa8a71c54,0x6d451c55,0x29881c56,0xf3f900af}},	//   _ирак, _juha, _исто_, maţi_,
   {{0xf3f9002d,0xd92800af,0x15b80409,0x60dd02a2}},	//   laţi_, _ацул_, тышы_, jksm,
   {{0x6d451c57,0xe796103b,0x42d5010b,0xf4950919}},	//   _luha, _مالک, гіну, نشکد,
   {{0xdb04051b,0x2fd90297,0x63ad18cc,0xf3f9002d}},	//   rviç, dysg_, _šans, naţi_,
   {{0x333c1c58,0x442601a8,0x658a00a8,0x6d451c59}},	//   _divx_, _ezo_, _səhv, _nuha,
   {{0xcea90052,0xf48711b9,0x7582006c,0x455a00a5}},	//   _מי_, _јужн, _ایٹم, _נכנס,
   {{0x645b1c5a,0x7760006d,0x7f441c5b,0x6d45021d}},	//   mbui, _xwmx, _quiq, _auha,
   {{0x201e0029,0x6d451c5c,0x645b1c5d,0xf3f900af}},	//   āti_, _buha, lbui, jaţi_,
   {{0xfce61c5e,0x2ca0007c,0xe29601d3,0xe8200127}},	//   гово, teid_, _сащ_, _बर्थ_,
   {{0x6d451c5f,0xee371c60,0x645b0223,0x61d6011d}},	//   _duha, унс_, nbui, _תוקף_,
   {{0x2ca01c61,0x6d45191c,0x8b65026e,0x0c261c62}},	// [13e0] reid_, _euha, لالم, уман,
   {{0x2ca00006,0x3f821c63,0xf3f900af,0xab771c64}},	//   seid_, muku_, gaţi_, املا_,
   {{0x3f821c65,0x6d450232,0x2d9a013c,0x658a00a8}},	//   luku_, _guha, _uppe_, _yəhu,
   {{0x7d7b0100,0xa3e3004e,0x00000000,0x00000000}},	//   _אנטו, नना_, --, --,
   {{0x3f821c66,0x6d451c67,0x69c318fb,0x3869008d}},	//   nuku_, _zuha, äner, ðara_,
   {{0xf3f9002d,0x645b0345,0x7d041c68,0x236d00a0}},	//   caţi_, ebui, lnis, dsej_,
   {{0x3f821c69,0x224e0065,0x98b8005f,0x44261c6a}},	//   huku_, _rffk_, _aurą_, _szo_,
   {{0x33741c6b,0x3f821c6c,0x7d040d19,0x2ed105fc}},	//   агир, kuku_, nnis, _सक्त,
   {{0x7d041c6d,0xd70a01b8,0xdb0600ee,0x98ad0067}},	//   inis, _знае_, _aské, _sieć_,
   {{0x7d041c6e,0x44260124,0x3f821c6f,0x92b60c74}},	//   hnis, _vzo_, duku_, احظا,
   {{0x6f150097,0x98b8004b,0x00000000,0x00000000}},	//   vozc, _eurą_, --, --,
   {{0x2ba50821,0x3386087b,0x6d451c70,0x7d0901c0}},	//   _ऑनला, _букв, _ruha, česk,
   {{0x6d451c71,0x60dd1c72,0x644202b3,0xe3b21c73}},	//   _suha, rksm, _igoi, _درا_,
   {{0x6d451c74,0x7d041c75,0xf1a61c76,0x78a20207}},	//   _puha, enis, _брин, heov,
   {{0x59a4004e,0x7d041c77,0x78a211f0,0x6f1500d5}},	//   _गैलर, fnis, keov, rozc,
   {{0xd9040df3,0x7d160159,0x3f8200f4,0x78a202c4}},	//   _ری_, goys, buku_, jeov,
   {{0x161b021a,0x78a21c78,0xf3f9002d,0xdbc601ae}},	// [13f0] _पुनर_, deov, taţi_, röße,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0402c9,0x658a0095,0xad270609,0xf3f9002d}},	//   bnis, _məhs, _مرحو, raţi_,
   {{0xd24601cb,0xe8200174,0x64421c79,0xf3f900af}},	//   _ژن_, _बरखा_, _ngoi, saţi_,
   {{0xd5b8013a,0x2d910291,0x62980e6a,0x47350b25}},	//   _arā_, ltze_, _obvo, андс,
   {{0x4b7a02b5,0x6aae0069,0x64421c7a,0x2d910065}},	//   _באשו, _gabf, _agoi, otze_,
   {{0x2d831c7b,0x2d9101d7,0x645b01bf,0x3f821c7c}},	//   nuje_, ntze_, tbui, zuku_,
   {{0x09e1004e,0x67d50369,0x78a2023a,0x2d9101b7}},	//   पनीय, _кобу, ceov, itze_,
   {{0x2d830991,0x645b1c7d,0xb4d50299,0xe787015a}},	//   huje_, rbui, _सकी_, _љубо,
   {{0x64421c7e,0x3ae4022a,0xa3c6007c,0x3f82011c}},	//   _egoi, _köpa_, _उपर_, vuku_,
   {{0x2d830d5c,0x645b1c7f,0x41061c80,0x3ea31c81}},	//   juje_, pbui, изов, dejt_,
   {{0x3f821c82,0xf530004f,0x00000000,0x00000000}},	//   tuku_, _فإن_, --, --,
   {{0x7d040124,0x8c3b02b1,0x3ae40523,0x00000000}},	//   vnis, _maßs, _löpa_, --,
   {{0x3f82039a,0xc8e2004e,0x2d8301d5,0xef17002d}},	//   ruku_, _खत्म_, fuje_, имя_,
   {{0x7d041c83,0xacf6192f,0x3f8201a8,0x6da61c84}},	//   tnis, ачај, suku_, шива,
   {{0x3f821c85,0xdb0f0176,0x7ce300ab,0x26f2073f}},	//   puku_, _arcà, _põra, _अग्र_,

   {{0x7d041c86,0x2d9101ed,0x78a200f4,0x00000000}},	// [1400] rnis, atze_, veov, --,
   {{0xeb971c87,0xba2600d8,0x658a00a8,0x00000000}},	//   риф_, адзк, _məhr, --,
   {{0x7e7b0122,0x78a20223,0xc8661c88,0xed5a1c89}},	//   _באיז, teov, атли, _шон_,
   {{0xd7fa1c8a,0x3ae40523,0x00000000,0x00000000}},	//   кул_, _döpa_, --, --,
   {{0x27e00514,0x78a2024b,0xb8ce0ec5,0x00000000}},	//   áin_, reov, _कस_, --,
   {{0x6442004a,0x6b84024a,0x00000000,0x00000000}},	//   _sgoi, muig, --, --,
   {{0x3567005f,0x27e002f6,0x6b841c8b,0xafdb08c8}},	//   арын_, šin_, luig, ncør,
   {{0xd9431c8c,0x658a00a8,0x63b90090,0x00000000}},	//   _фети, _bəhr, _brwn, --,
   {{0x667600bf,0x26161c8d,0xb4d600a1,0x1afb0033}},	//   _ندار, _पुरी_, _हवी_, ্তরে_,
   {{0x63ab008c,0x00000000,0x00000000,0x00000000}},	//   _dsgn, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d831c8e,0x6ee200ee,0xd5fb024b,0x63b9099e}},	//   vuje_, _bôbo, _בפבר, _frwn,
   {{0x658a01c2,0x89370070,0x61ff00a8,0x2d830035}},	//   _təhs, ירטע_, _əylə, wuje_,
   {{0xdefb01c8,0x539b011d,0x00000000,0x00000000}},	//   тым_, _סיוו, --, --,
   {{0x27290037,0x3ea301f4,0xcf8e00f8,0x8e380037}},	//   núna_, rejt_, وژی_, لسفر_,
   {{0x2d9101d7,0x3ea31c8f,0x6b840098,0x00000000}},	//   rtze_, sejt_, fuig, --,
   {{0x2d831c90,0x3ea300da,0x6f950037,0x6b841c91}},	// [1410] suje_, pejt_, _الخض, guig,
   {{0x2d83113c,0x3ce9006f,0x62881c92,0xed4e00b5}},	//   puje_, shav_, ngdo, بھی_,
   {{0xaf340a42,0xf9f902e7,0xdb2600fd,0x00000000}},	//   _بريت, دفاع_, حولی, --,
   {{0xb4d50c57,0x6d5701d7,0x6b840afc,0x00000000}},	//   _सके_, _itxa, buig, --,
   {{0x6d480187,0x395a0069,0xfbc800b8,0x00000000}},	//   ídav, apps_, रमणम, --,
   {{0x9a840431,0x29060065,0x00000000,0x00000000}},	//   _мусл, anoa_, --, --,
   {{0x25ac0023,0x00000000,0x00000000,0x00000000}},	//   _csdl_, --, --, --,
   {{0xe91900d4,0x00000000,0x00000000,0x00000000}},	//   _собі_, --, --, --,
   {{0x658a00a8,0xdd020124,0x2d7300f4,0x317e01ed}},	//   _qəhr, šuću, hće_, ertz_,
   {{0x6d5701a3,0x2d7300f4,0xa2e50279,0x00000000}},	//   _otxa, kće_, соод, --,
   {{0x6d570189,0xd9f90f06,0xb5fc0069,0x00000000}},	//   _ntxa, ्पित_, _leġj, --,
   {{0x62880223,0x658a013b,0x00000000,0x00000000}},	//   agdo, _təhr, --, --,
   {{0xe2990c93,0x2eea1c93,0x6d5701a3,0x5eb10033}},	//   _бал_, thbf_, _atxa, ঞানে,
   {{0x63a91c94,0xd9f90d2a,0x00000000,0x00000000}},	//   mwen, ्पात_, --, --,
   {{0x63a91c95,0xdef9010b,0x8db501e0,0x00000000}},	//   lwen, рыў_, ості, --,
   {{0x6b841c96,0xb4d507b5,0xa5da016b,0x79850027}},	//   tuig, _सको_, אַמי, duhw,
   {{0x60c41c97,0x3ce004ca,0x6d5701d7,0xd0fb0070}},	// [1420] _inim, rkiv_, _etxa, _תּור,
   {{0x60d60453,0xff260043,0x4bd90421,0x00000000}},	//   _hoym, _ымпо, шься_, --,
   {{0xbed702b5,0x60d6027d,0x63a9033b,0x29060009}},	//   _הויז_, _koym, hwen, tnoa_,
   {{0xb4d60b39,0x6d5c1c98,0x63a91c99,0xe89400d4}},	//   _हवे_, mpra, kwen, іаль,
   {{0x29061c9a,0x6fb800b4,0xb7960274,0xbcb700a5}},	//   rnoa_, इटिं, срећ, _הפכו_,
   {{0xef1f01d6,0x6ffc0029,0x63a9053e,0xfc3f01ef}},	//   ltür_, mācī, dwen, _caíu_,
   {{0x6d5c0c1f,0x60c40a78,0xc7af00b5,0x63a91c9b}},	//   npra, _onim, وڑے_, ewen,
   {{0xdbdd016f,0x98bc00ea,0x63a91c9c,0x98a600cd}},	//   zšír, īvē_, fwen, dmoć_,
   {{0x25ac022d,0x9696010e,0x63a91c9d,0x394a1c9e}},	//   _wsdl_, _греш, gwen, _hubs_,
   {{0xe73a08d9,0x68e21c9f,0x59dc00c0,0x6eeb1ca0}},	//   _сез_, lkod, _यथार, _kübe,
   {{0xba9b0070,0x658a00a8,0x5a9b0070,0x6d5c1140}},	//   נסטי, _təhq, נשטא, jpra,
   {{0x63a91ca1,0x68e21ca2,0x395802d7,0x692c00af}},	//   bwen, nkod, _mtrs_, _aşez,
   {{0x7afe00fb,0x5f94145f,0x6eeb1ca3,0x63a90027}},	//   kipt, пият, _lübe, cwen,
   {{0xff071ca4,0x39581ca5,0x60c41ca6,0x7afe0031}},	//   сямн, _otrs_, _enim, jipt,
   {{0x6d5c0e5b,0x0dc818c4,0xab5b1ca7,0x00000000}},	//   gpra, бути_, _krüg, --,
   {{0x9986006a,0x657c10db,0x25e01ca8,0x2d7300cd}},	//   łoś_, _århu, _कथनी_, rće_,
   {{0x09e100a1,0x8b580037,0x2a6a0090,0x8af91ca9}},	// [1430] पन्य, مجلس_, _bebb_, анас_,
   {{0x2d73029d,0xb4d500b4,0x7afe1caa,0x00000000}},	//   pće_, _सक्_, gipt, --,
   {{0x69de05f5,0x7f3c02b5,0x63a91cab,0x6d481cac}},	//   gype, _געזו, zwen, ídat,
   {{0x386900fb,0xad27064e,0xfc3f0391,0x9bc71482}},	//   úar_, _درخو, _saíu_, _лёгк,
   {{0x395801f7,0x00000000,0x00000000,0x00000000}},	//   _etrs_, --, --, --,
   {{0x7afe1cad,0xab5b02c9,0xe7391cae,0xb5791303}},	//   cipt, _prüf, шел_, ащих_,
   {{0x68e301e9,0x00000000,0x00000000,0x00000000}},	//   ënds, --, --, --,
   {{0x63a91caf,0x28040355,0x00000000,0x00000000}},	//   twen, ásná_, --, --,
   {{0x63a90120,0x6d5c1cb0,0x68fb00d7,0xd36e0098}},	//   uwen, zpra, _imud, نهي_,
   {{0x81d400c8,0x60c401cc,0x68e9000c,0x63a91cb1}},	//   _সেই_, _snim, _hled, rwen,
   {{0x63a91cb2,0x545506c2,0x68e91cb3,0x00000000}},	//   swen, _двет, _kled, --,
   {{0x60d60095,0x6d5c008b,0x68e90118,0x00000000}},	//   _qoym, vpra, _jled, --,
   {{0x2b591cb4,0xb05b1cb5,0xfc3f0042,0x00000000}},	//   _ntsc_, tjär, _maís_, --,
   {{0x6d5c1cb6,0x91e50226,0x68e21cb7,0x539a011d}},	//   tpra, _моле, zkod, _כינו,
   {{0x82370609,0x290d01ef,0x60d6021d,0x68fb01a8}},	//   _ارشا, _ojea_, _toym, _omud,
   {{0xb05b1cb8,0x39580009,0x6eeb02b1,0xdf4a00af}},	//   sjär, _rtrs_, _rübe, _кзид_,
   {{0x2a7801d1,0xa2cd178c,0x00000000,0x00000000}},	// [1440] _pdrb_, ताप्, --, --,
   {{0x6d5c1cb9,0x291f0088,0x68fb001c,0x290d01ed}},	//   ppra, _akua_, _amud, _ajea_,
   {{0x8c461cba,0x7afe1cbb,0x6f1c1cbc,0x68e21cbd}},	//   _мене, ript, morc, tkod,
   {{0x394d1cbe,0x319a0070,0x6f1c027a,0x69de1cbf}},	//   _čest_, יבענ, lorc, rype,
   {{0x7d090528,0x68e90118,0x7afe1cc0,0x68e20987}},	//   čest, _dled, pipt, rkod,
   {{0x7afe071f,0x68e21cc1,0x6f1c1cc2,0xf1c90ec5}},	//   qipt, skod, norc, िमान,
   {{0xc4480164,0xa2cd1cc3,0xbb4308a6,0xab5b007c}},	//   میان_, तान्, _церк, _prüg,
   {{0x68e91cc4,0xd4971663,0x1517004f,0x6f1c1cc5}},	//   _gled, орь_, يزية_, horc,
   {{0x6f1c0987,0x00000000,0x00000000,0x00000000}},	//   korc, --, --, --,
   {{0xb5fc035f,0xa3140067,0xe5a61566,0xe3af0286}},	//   _leġi, डवेज_, _мизи, ئري_,
   {{0x7ce300ab,0xab5b1cc6,0x00000000,0x00000000}},	//   _sõrm, _trüg, --, --,
   {{0x39440282,0x00000000,0x00000000,0x00000000}},	//   _jims_, --, --, --,
   {{0x6f1c1cc7,0xc49b00a5,0x00000000,0x00000000}},	//   forc, _כשאת, --, --,
   {{0x6f1c01a0,0x00000000,0x00000000,0x00000000}},	//   gorc, --, --, --,
   {{0x3eb30095,0x2b4b1cc8,0xdb0d0132,0xccfb0274}},	//   _vaxt_, _succ_, lvaç, аћа_,
   {{0x9f6b03fa,0x1fa70c9f,0x2016000d,0x7bcd1cc9}},	//   _кроз_, _дрог, écié_, txau,
   {{0x200c01c2,0x6f1c1cca,0xfc3f01ef,0x00000000}},	// [1450] şdir_, borc, _raís_, --,
   {{0x68e9117f,0x6f1c1ccb,0x2732002d,0xf43b00a5}},	//   _sled, corc, nând_, שתמש,
   {{0xa2b200b8,0xdcf50035,0x7f4d0069,0x3944008c}},	//   _असन्, erzą, _huaq, _bims_,
   {{0xaac90d53,0x63a21ccc,0x39440392,0xc23700a5}},	//   राहक, _opon, _cims_, קראו_,
   {{0x995400b8,0xa2cd164f,0x39440a8a,0x37ab001f}},	//   _výše_, ताम्, _dims_, ртен_,
   {{0x7f4d00d7,0xb3450132,0x7bda00a5,0x68e900e9}},	//   _muaq, _liçã, _הקשו, _wled,
   {{0x63a20370,0x39440260,0xd6ce0079,0xfc3f0183}},	//   _apon, _fims_, اقى_, _taís_,
   {{0x2ca919fd,0x68fb1ccd,0x6f1c1bfa,0x5fcb1cce}},	//   nead_, _umud, zorc, ामाल,
   {{0x291d0035,0x629a0103,0xe2990036,0x6f1c02d7}},	//   mowa_, ffto, бап_, yorc,
   {{0x2ca91ccf,0x386d152b,0x21201cd0,0x291d1cd1}},	//   head_, _heer_, _skih_, lowa_,
   {{0x386d1c47,0x63a21cd2,0x7d080187,0x6f1c1cd3}},	//   _keer_, _epon, édsk, vorc,
   {{0x291d1cd1,0x7cf11cd4,0x23751015,0xd59a00a5}},	//   nowa_, _hårf, _فاتح, _לבעל,
   {{0x386d1cd5,0xb5fc0484,0x7ce300be,0x7f4d0138}},	//   _meer_, _reġi, _tõrj, _cuaq,
   {{0x386d1cd6,0x2732002d,0x248d1cd7,0x835300b5}},	//   _leer_, când_, lgem_, _ٹھکا,
   {{0xa928024e,0x63bb008a,0x291d1cd8,0x2ca90037}},	//   ližš, lvun, kowa_, fead_,
   {{0x7afc1cd9,0x2ca90211,0x6f1c1cda,0x386d03c4}},	//   _smrt, gead_, sorc, _neer_,
   {{0x2d830c6f,0x291d004e,0xfc3f0391,0xa2b2111b}},	// [1460] arje_, dowa_, _saír_, _असम्,
   {{0xe81f0b4a,0x7cea0093,0x6b96013c,0x8b230086}},	//   _बड़ा_, _dýra, rtyg, едуе,
   {{0x6edb0122,0x39951cdb,0x6b961cdc,0x386d1cdd}},	//   _החיפ, gås_, styg, _beer_,
   {{0x2fc002df,0x3eaa033b,0x273200af,0x3e5700b8}},	//   _krig_, lebt_, zând_, pětí_,
   {{0xdcfc0ae0,0x4cbb0052,0x2d981cde,0x2d8a1cdf}},	//   strē, _הזכו, ltre_, lube_,
   {{0x6d461ce0,0xb4b40299,0x6b841ce1,0x7997006d}},	//   _hika, _छोड़_, mrig, btxw,
   {{0x6d461ce2,0x2d981ce3,0x61e1054e,0x6b840cfd}},	//   _kika, ntre_, jyll, lrig,
   {{0x6eeb01c2,0x6d46128f,0x38c8026b,0x94aa1ce4}},	//   _müba, _jika, _باسی_, стка_,
   {{0x6d461ce5,0x6b841ce6,0x2fc0006f,0x273200af}},	//   _mika, nrig, _nrig_, tând_,
   {{0x6d461ce7,0x386d0a75,0xdb0d03e6,0x248d03e6}},	//   _lika, _zeer_, rvaç, agem_,
   {{0x6b8401ae,0x2732002d,0x2d8a011e,0x64a61ce8}},	//   hrig, rând_, jube_, _нажа,
   {{0x6d461ce9,0x2fc00297,0xc0581a15,0x8504026b}},	//   _nika, _brig_, зір_, _کوچن,
   {{0x613f0080,0x38690093,0x2732002d,0x63a21cea}},	//   _jūli, ðari_, pând_, _upon,
   {{0x44261ceb,0x6b841cec,0x6d4603ad,0x61360093}},	//   _iyo_, drig, _aika, jálf,
   {{0x6d461ced,0x6b841cee,0x06fd00b8,0x2d8a1cef}},	//   _bika, erig, _říká_, gube_,
   {{0x6d46122c,0x442601a8,0x2d8300da,0x799701e8}},	//   _cika, _kyo_, rrje_, vtxw,
   {{0x6d460464,0x2d9c06d7,0x2ca91cf0,0x66dd02d0}},	// [1470] _dika, _även_, read_, _mèkr,
   {{0x7cea0076,0xf1b0018d,0x13df0083,0x386d0173}},	//   _výra, _जनान, _বেড়, _seer_,
   {{0x6d460523,0x291d1cf1,0xa2cd1662,0x75221cf2}},	//   _fika, towa_, तात्, _okoz,
   {{0xf771096a,0x6d460b04,0x6b841cf3,0xddde01c0}},	//   نات_, _gika, brig, _nepř,
   {{0x44261cf4,0x61120029,0x3f8b01d6,0xab5b01ae}},	//   _nyo_, nāla, nucu_, _drüc,
   {{0x386d019c,0x291d035d,0x6d461cf5,0xea63006c}},	//   _weer_, sowa_, _zika, _سپری,
   {{0x44261cf6,0xc9841cf7,0x672102c6,0x3f8b1cf8}},	//   _ayo_, _пути, _vklj, hucu_,
   {{0x7d0d1cf9,0x44260b55,0x04450423,0x61120228}},	//   nnas, _byo_, мейн, kāla,
   {{0x44260232,0x248d1cfa,0x61e1001e,0x3f8b0156}},	//   _cyo_, rgem_, wyll, jucu_,
   {{0x672101cc,0x7cf11cfb,0x7d0d0297,0x61e11cfc}},	//   _uklj, _hård, hnas, tyll,
   {{0x3dc1006d,0xa5670118,0x7d0d1cfd,0x44260273}},	//   _nrhw_, _ردان, knas, _eyo_,
   {{0x61e11cfe,0x7d0d1a8a,0x66dd0107,0x63a400af}},	//   ryll, jnas, _tèks, _ţine,
   {{0x61e102c7,0x6d461cff,0xdb0f1111,0xa2cd0355}},	//   syll, _rika, _escé, ताद्,
   {{0x2d981d00,0x75291d01,0x6d461d02,0x6b841be0}},	//   ttre_, llez, _sika, vrig,
   {{0x5f271858,0x6b841d03,0x311607b0,0x2fc00159}},	//   форм_, wrig, _офис, _wrig_,
   {{0x2d981d04,0xd1321d05,0x7d0d1d06,0x2d8a01d5}},	//   rtre_, _جمع_, gnas, rube_,
   {{0xeb971d07,0x6d461d08,0xddc71916,0x4426006d}},	// [1480] мит_, _vika, rajš, _xyo_,
   {{0x6d461d09,0xa01b0e80,0x7c260187,0x7d0d0ba0}},	//   _wika, rgöt, _vykr, anas,
   {{0x6d460ae0,0x6b841d0a,0x644b027a,0x7c260035}},	//   _tika, srig, _oggi, _wykr,
   {{0x6b841d0b,0x186703fa,0xa3bf06d9,0x644b00bf}},	//   prig, даци_, ुमा_, _nggi,
   {{0x7d04145d,0x753b0223,0xda660079,0x752900f4}},	//   miis, dmuz, _ياسي, dlez,
   {{0x644b0133,0x7d041d0c,0x7529000e,0x44260010}},	//   _aggi, liis, elez, _ryo_,
   {{0xa01b1d0d,0x7ae31d0e,0xdcf50035,0x442608dd}},	//   ngör, önte, erzę, _syo_,
   {{0x75291d0f,0x2902013c,0x7d041d10,0x7cf11b2f}},	//   glez, _öka_, niis, _gård,
   {{0x38661d11,0xdb0401ef,0x60cb009e,0x00000000}},	//   mbor_, lviñ, _ògmi, --,
   {{0x7d0400b9,0x6d5e0254,0x644b1d12,0x65c61d13}},	//   hiis, _otpa, _eggi, _обза,
   {{0x7d041d14,0xe8df0019,0x75291d15,0xd48f1d16}},	//   kiis, _hiền_, blez, _ир_,
   {{0x44261d17,0xf50302fb,0x75290036,0x61120228}},	//   _tyo_, _изхо, clez, tāla,
   {{0x7d041d18,0x6d5e1d19,0x7ce3007c,0xf4870118}},	//   diis, _atpa, _kõrv, _زانی,
   {{0xe8df01a5,0x3f991d1a,0x69c102c4,0x3f8b1d1b}},	//   _miền_, rtsu_, _šlem, rucu_,
   {{0x7d041d1c,0xc3480028,0xdd9401c8,0x7d0d1d1d}},	//   fiis, _nổi_, кары, tnas,
   {{0x7d041d1e,0x30a71a31,0x40351d1f,0x201e00af}},	//   giis, _цркв, _пейс, ştia_,
   {{0x7d0d1d20,0xfd4400d8,0xdb060523,0x00000000}},	// [1490] rnas, тэрн, _oskä, --,
   {{0x7d0d1d21,0x4ac90534,0x19eb0037,0x0dcb01d3}},	//   snas, राइव, يراً_, _думи_,
   {{0xceb202b5,0x7d04018f,0x212b00e9,0x5a4400af}},	//   _גיי_, biis, olch_, вэца,
   {{0x7d04013a,0xa81500af,0x7aee1d22,0x7cf10b3e}},	//   ciis, ндеш, _elbt, _båre,
   {{0x7cf1022a,0x8ccc0066,0x78ab03bc,0x2cb9021d}},	//   _vård, हारो, regv, _iasd_,
   {{0x6b8d002f,0x6d5800f7,0x7aee0069,0x7e750065}},	//   muag, _évac, _glbt, nazp,
   {{0xa2cd00e7,0x27e905e2,0x75290223,0x6b8d1d23}},	//   तास्, šan_, tlez, luag,
   {{0x3ce91d24,0x7cf1038d,0x672a01bf,0x7e7501ed}},	//   nkav_, _fåre, alfj, hazp,
   {{0x61360187,0x75290223,0x387f009f,0x753b0804}},	//   nále, rlez, _idur_, rmuz,
   {{0x752900b8,0x290f010d,0xaad21d25,0x7d041d26}},	//   slez, lnga_, सायक, ziis,
   {{0x91e50dba,0x290f0027,0x7cf10282,0x75291d27}},	//   хоне, onga_, _mårb, plez,
   {{0x290f01a2,0x644b0036,0x387f0024,0x6d5e021d}},	//   nnga_, _uggi, _jdur_, _rtpa,
   {{0x290f01e0,0x7d04127d,0x6b8d0453,0x13a700d1}},	//   inga_, viis, juag, _آنتی_,
   {{0x6136053d,0x7e7501a3,0x386614a6,0x2d550185}},	//   dále, gazp, zbor_, _båe_,
   {{0x7d041d28,0xdca61d29,0x6da30b46,0x4ac90026}},	//   tiis, нави, лира, राईव,
   {{0x7cea114d,0xa2cd018d,0xe05800d1,0x387f0024}},	//   _výro, ताव्, _زیست_, _ndur_,
   {{0x7d041d2a,0x61361d2b,0x2a710009,0x6b8d027a}},	// [14a0] riis, ráld, _bezb_, guag,
   {{0x7d041994,0x2cb90176,0x387f0bc0,0x00000000}},	//   siis, _easd_, _adur_, --,
   {{0x6d5e03d0,0x7d041d2c,0x88861d2d,0x7cf10b41}},	//   _utpa, piis, ележ, _såre,
   {{0xdd2f00b8,0x6b8d00d7,0x2cb901da,0x39510124}},	//   pěšn, buag, _gasd_, _duzs_,
   {{0x3c7700a5,0x387f1d2e,0x3eba0345,0x38660147}},	//   _אתכם_, _ddur_, _kapt_, rbor_,
   {{0xa82400d1,0x290f0037,0x7cf11d2f,0xe8df0023}},	//   _یکشن, anga_, _våre, _viền_,
   {{0x186a1d30,0x212b001e,0x6b491d31,0x7762002a}},	//   _нави_, ylch_, _užga, spox,
   {{0xe8df00e8,0xf3661d32,0xd943039e,0x7cf111cb}},	//   _tiền_, нтон, _беси, _tåre,
   {{0x7cf10a8a,0x7ce300be,0x2ca00098,0x290601b7}},	//   _hårc, _tõrv, ifid_, mioa_,
   {{0x877b02b8,0xdb9702b5,0x27e61d33,0x290601d7}},	//   _מאמי, עדיט_, myon_, lioa_,
   {{0xb05b017b,0x27e61d34,0x61360187,0xe6d90093}},	//   ndäg, lyon_, zále, _þráð,
   {{0x2b4a1d35,0x6b8d022e,0x29061176,0x00000000}},	//   _libc_, yuag, nioa_, --,
   {{0xa30b00f5,0xa2e61d36,0xe8df01a5,0x6d5a1d37}},	//   _کرنے_, _подд, _hiển_, ítan,
   {{0x9f3500d4,0x26de0054,0x290601ed,0xab5b0b74}},	//   тегі, _joto_, hioa_, _brün,
   {{0xa2cd0026,0x3eba1d38,0x7e751d39,0xf1a3002d}},	//   तार्, _dapt_, razp, _брын,
   {{0x26de1d3a,0x0ccf0083,0x6b8d1d3b,0x290601b7}},	//   _loto_, রস্ত, tuag, jioa_,
   {{0x60cd0232,0x26cc06a2,0x3eba0043,0x27e602e9}},	// [14b0] _inam, _ondo_, _fapt_, jyon_,
   {{0x26de1d3c,0x6b8d1d3d,0x00000000,0x00000000}},	//   _noto_, ruag, --, --,
   {{0xab5b02c9,0xdb04008d,0x6b8d1d3e,0x290f043d}},	//   _grün, rvið, suag, tnga_,
   {{0x6c7902b5,0xa95400d4,0x6b8d009e,0x290f002f}},	//   _קאָפ, укці, puag, unga_,
   {{0x27e60332,0x60cd0054,0x26de1d3f,0x6b8d11b8}},	//   gyon_, _mnam, _boto_, quag,
   {{0xd6db1d40,0xe8df0028,0x26de0b06,0x60df012f}},	//   яте_, _biển_, _coto_, _loqm,
   {{0xa8a71d41,0x5b141b78,0x27e6067f,0x29060065}},	//   _прак, _смрт, ayon_, bioa_,
   {{0x81c80033,0x60cd01a8,0x387f1d42,0xe8df00cc}},	//   োনা_, _nnam, _udur_, _diển_,
   {{0x249f1d43,0xf6990202,0xe78403d0,0x1fcb0099}},	//   rfum_, _овај_, _бухо, ामोड,
   {{0x60cd1d44,0x78bb1d45,0x00000000,0x00000000}},	//   _anam, _hauv, --, --,
   {{0x6723007a,0x6f0702f6,0xe4e701e0,0x60cd0044}},	//   monj, dijc, _підн, _bnam,
   {{0x67231d46,0x60cd009e,0xd00a03e6,0x8af0013b}},	//   lonj, _cnam, деме_, npər,
   {{0x78bb0248,0x3ae4013c,0x60cd00ee,0xe29903e6}},	//   _mauv, _köpt_, _dnam, _жал_,
   {{0x290603cb,0x60cd1d47,0x67230c6d,0x78bb1d48}},	//   zioa_, _enam, nonj, _lauv,
   {{0x27e61d49,0xeab200b5,0x81c700ec,0x00000000}},	//   zyon_, یٹر_, _blēž, --,
   {{0xfbe70023,0x645b1d4a,0x67231d4b,0x2d8400f4}},	//   _thể_, ncui, honj, čme_,
   {{0xdb0f01ef,0x3eba01e0,0x1c4611ab,0x00000000}},	// [14c0] _escí, _tapt_, тнам, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26de1d4c,0x67231d4d,0x78bb02b1,0xdcee0225}},	//   _roto_, donj, _bauv, şkır,
   {{0x26de1d4e,0xa96710ac,0xe78600d8,0x27e602d0}},	//   _soto_, тица_, вуко, tyon_,
   {{0xa2b20429,0x26de1d4f,0x290606a2,0x27e60008}},	//   _असल्, _poto_, rioa_, uyon_,
   {{0x67231d50,0x7bc6035f,0x290606a2,0x27e60107}},	//   gonj, _irku, sioa_, ryon_,
   {{0x27e61d51,0x66e30370,0x290601a3,0x78bb00f6}},	//   syon_, роја, pioa_, _fauv,
   {{0x399c0443,0x6abc1d52,0x7bc60009,0x75390260}},	//   mís_, _harf, _krku, _chwz,
   {{0x26de1d53,0x29040484,0x6abc1d54,0x67231d55}},	//   _toto_, _imma_, _karf, bonj,
   {{0x78bb03fd,0x78a20187,0x60cd1d56,0x672300af}},	//   _zauv, lfov, _snam, conj,
   {{0x6abc1d57,0x68e01057,0x399c1d58,0x6d5a0093}},	//   _marf, _komd, nís_, ítal,
   {{0x7bc61d59,0x3ae40523,0x00000000,0x00000000}},	//   _orku, _köps_, --, --,
   {{0x399c004f,0x7bd6006d,0x53b60fbf,0x68e30132}},	//   hís_, jxyu, _अनिश, êndi,
   {{0x3d950e88,0x28a40026,0xdb1d00d5,0x6ee2021d}},	//   лигр, _गॉसि, _prsí, _sôbr,
   {{0xdef801c8,0x5e5802ce,0x29040069,0x6f0702a7}},	//   тыя_, тися_, _omma_, rijc,
   {{0x60cd1d5a,0x8c641d5b,0x399c1d5c,0x5183061c}},	//   _unam, итуд, dís_, _туша,
   {{0x6d58000d,0x7bc6023a,0x00000000,0x00000000}},	// [14d0] _évan, _crku, --, --,
   {{0x29041d5d,0x613600fb,0x78bb1d5e,0xe8df0028}},	//   _amma_, mála, _sauv, _miễn_,
   {{0xd36600f8,0x6abc1d5f,0x6136006c,0x78bb0248}},	//   _گه_, _darf, lála, _pauv,
   {{0xfc640133,0xfc3f00de,0x68e0026e,0x2d911d60}},	//   _върн, _maíz_, _comd, muze_,
   {{0xd36617bd,0x67231d61,0x9cd60122,0x6136006c}},	//   _ده_, tonj, _עושה_, nála,
   {{0x6abc1d62,0xa5b90274,0x3ae40523,0x00000000}},	//   _garf, ећих_, _döps_, --,
   {{0x399c1d63,0x6136004f,0x67231d64,0xd5af00b5}},	//   cís_, hála, ronj, تہا_,
   {{0x69c7046a,0x260200a1,0xe3b91d65,0x67231d66}},	//   _irje, _वेळी_, еби_, sonj,
   {{0x03251d67,0x67231d68,0xecc50033,0x6136008d}},	//   лдин, ponj, _একাড, jála,
   {{0xe8df00e8,0x645b1d69,0x61e80297,0x2d911d6a}},	//   _diễn_, scui, fydl, kuze_,
   {{0x394d0903,0x04951c51,0xb1461d6b,0x13a70647}},	//   _kies_, _ملاح, лнол, رنگی_,
   {{0xa6e200fb,0x2d8a022f,0x201e027d,0x69c7008c}},	//   _öðru, vrbe_, ştim_, _mrje,
   {{0x61361d6c,0x394d0086,0xdcfc0228,0x2d910051}},	//   gála, _mies_, strī, euze_,
   {{0x69c71d6d,0x27290391,0xe29917df,0xe8d013ab}},	//   _orje, múns_, _чак_, _सच्च,
   {{0x523900c2,0x2d911815,0xd33600a5,0x613d021d}},	//   _אײַנ, guze_, _גרסה_, délf,
   {{0x394d0484,0x399c1d6e,0xa3b700ab,0x6abc1d6f}},	//   _nies_, vís_, _चना_, _sarf,
   {{0x6abc1d70,0x69c71d71,0x68e0008c,0xdc75010b}},	// [14e0] _parf, _arje, _romd, рысь,
   {{0x80a000b1,0x89f601c8,0x2d911d72,0x399c1d73}},	//   ग्रे, ляец, buze_, tís_,
   {{0x6abc1d74,0x8cbf0722,0x7ce3007c,0xcd3602e7}},	//   _varf, _लोको, _võrr, _مرحب,
   {{0x399c0890,0x394d1d75,0xdb0f0310,0x673a0031}},	//   rís_, _cies_, _escà, _shtj,
   {{0x394d1d76,0x62830bc6,0x67d4002d,0x66e618d9}},	//   _dies_, _odno, ролу, лода,
   {{0xd5ba0970,0x394d0044,0x00000000,0x00000000}},	//   еси_, _eies_, --, --,
   {{0x69c7022f,0x394d04b4,0x7bc406d8,0xdb2300b5}},	//   _grje, _fies_, lviu, _óráj,
   {{0x29040657,0xc44800d1,0xfc3f0caa,0x6283001e}},	//   _umma_, نیان_, _raíz_, _adno,
   {{0x27291a71,0xd2500082,0xc6960180,0x9cd70122}},	//   gúns_, ينة_, _مشاع, רופה_,
   {{0xf746022c,0xe8df01a5,0x61e8013c,0x6136006c}},	//   _сезо, _viễn_, tydl, vála,
   {{0x62341d77,0x48fb1d78,0x546a10bb,0xe6160279}},	//   рену, लोको_, _заем_, _сфаќ,
   {{0x2d910232,0xe8df0023,0x62830260,0x61361d79}},	//   vuze_, _tiễn_, _edno, tála,
   {{0x8cbf006a,0xe47b0070,0x41b0018d,0x00000000}},	//   _लोगो, _טראכ, _जनकस, --,
   {{0x4383004f,0x6136004f,0xef1f0644,0xb3bb00a5}},	//   _الوق, rála, mrük_, _נמוכ,
   {{0x61361d7a,0x6d5802e1,0x5186005f,0x3f800176}},	//   máln, _éval, _сула, _eviu_,
   {{0x69c700da,0x557702b5,0x613600b5,0xf19300b5}},	//   _rrje, טעלן_, láln, _اُٹھ,
   {{0xe8df00e8,0x3a750368,0xdb1d01ef,0x1bd41d13}},	// [14f0] _hiện_, илар, _arsá, ботя,
   {{0x6136122d,0xe8df0028,0x394d1d7b,0x69c7003d}},	//   náln, _kiện_, _sies_, _prje,
   {{0x394d1d7c,0xc3330122,0x00000000,0x00000000}},	//   _pies_, צוע_, --, --,
   {{0x80d8073f,0x2fc90173,0x69c71d7d,0xe8df00e2}},	//   याये, _krag_, _vrje, _miện_,
   {{0x394d1d7e,0xdb0f0b4c,0x61361d7f,0x6ed9021a}},	//   _vies_, _escá, káln, मापु,
   {{0x6b8d0249,0x6d4f027b,0x2fc9009e,0x394d0110}},	//   mrag, _hica, _mrag_, _wies_,
   {{0x45191d80,0x25ac011e,0x80d8164f,0x8aa400d4}},	//   кция_, _cpdl_, यामे, _уряд,
   {{0x2bc91d81,0x6d571d82,0x7cf81d83,0x7e771d84}},	//   रिपा, _muxa, _vírg, _lexp,
   {{0x2fc9006d,0x28f80eb1,0xe69500af,0x61361534}},	//   _nrag_, _сеть_, _визы, fáln,
   {{0x6d4f0189,0x42550798,0x61361d85,0xe8df0019}},	//   _lica, штит, gáln, _biện_,
   {{0x7cf80332,0x6b8d1d86,0x2fc91d87,0xa06a1d88}},	//   _híre, hrag, _arag_, кана_,
   {{0xe8df0028,0x2fc90cfd,0x6b8d1d89,0xe046046e}},	//   _diện_, _brag_, krag, инни,
   {{0xf3670426,0x61361d8a,0x611200ea,0x2fc90211}},	//   _стен, báln, nāli, _crag_,
   {{0x6b8d1d8b,0x7d0600d7,0x7cf80037,0x2cb20090}},	//   drag, _smks, _míre, weyd_,
   {{0x2d9e0248,0x6d5701dd,0x6b8d1d8c,0x442f1d8d}},	//   îte_, _cuxa, erag, _hyg_,
   {{0x6b8d02bf,0xb4e300a1,0x3c66004b,0x2fc91d8e}},	//   frag, _नको_, ркаг, _frag_,
   {{0x6136006c,0xec4a19fa,0x6b8d0594,0x9f600421}},	// [1500] lálo, тзал_, grag, örät_,
   {{0xff7b02b5,0x78a91842,0x7bc41d8f,0x6d5701ef}},	//   _שטימ, _abev, rviu, _fuxa,
   {{0x6d4f1d90,0x442f02a4,0x613605fa,0xdca61d91}},	//   _fica, _lyg_, nálo, _кани,
   {{0xdbdc0076,0x7e7c1d92,0x6b8d1d93,0x3ead0254}},	//   lšíc, larp, brag, đete_,
   {{0x38691d94,0x6b8d00a2,0x263500e2,0x00000000}},	//   ñara_, crag, _áo_, --,
   {{0x7cf80082,0x7e7c05ee,0x613d006c,0x6d4f1d95}},	//   _díre, narp, méle, _zica,
   {{0x7cf80079,0x6d4f04fb,0xd5b00079,0x00000000}},	//   _tírd, _yica, سفة_, --,
   {{0x7d161d96,0x7e7c1d97,0x442f08c8,0xb8cb0033}},	//   nnys, harp, _byg_, _কো_,
   {{0x2bc906bc,0x61360076,0xfbc91371,0x00000000}},	//   रिया, táln, रियम, --,
   {{0xdbdc024e,0x6eeb1c28,0x00000000,0x00000000}},	//   jšíc, _tübi, --, --,
   {{0x61360076,0x7e7c1d98,0x8af000a8,0xdbdc0097}},	//   ráln, darp, vqəl, dšíc,
   {{0xb3560ef5,0xe8df0028,0xab5b02c9,0x03a60e05}},	//   _پیدا_, _viện_, _früh, _видо,
   {{0x6d4f1d99,0x7cf10909,0x7e7c00e9,0x6d440067}},	//   _rica, _dårl, farp, dmia,
   {{0xe8df01a5,0x6b8d1d9a,0x2fc91d9b,0x7e7c1d9c}},	//   _tiện_, vrag, _vrag_, garp,
   {{0x13b600e7,0x395814d8,0xab5b1d9d,0x61361d9e}},	//   _अनुभ, _nurs_, _trük, cálo,
   {{0x26f3012f,0x2fc91d9f,0x613600b5,0x00000000}},	//   _अत्र_, _trag_, náll, --,
   {{0x113c00a5,0xdbdc00ac,0xa2cb0099,0x3d08193c}},	// [1510] _בתהל, bšíc, _थोड्, _सगरे_,
   {{0x6b8d1da0,0xf9c70ebb,0x6d4f1da1,0x6d441da2}},	//   rrag, ищен, _wica, amia,
   {{0x39581da3,0x6d4f06d0,0x6b8d0110,0x7cf1029e}},	//   _curs_, _tica, srag, _hårm,
   {{0x39581da4,0x69c100ea,0x611200ea,0x9f4200d5}},	//   _durs_, _šles, tāli, myká_,
   {{0x7d0d004e,0x23660221,0x00000000,0x00000000}},	//   mias, _ntoj_, --, --,
   {{0x39581da5,0x7cf80079,0x611200ea,0x7cea008d}},	//   _furs_, _víre, rāli, _dýru,
   {{0xa5091da6,0x442f08c8,0x395802a7,0x00000000}},	//   лека_, _syg_, _gurs_, --,
   {{0x7d0d1da7,0x613600b5,0x201e0043,0x92c30033}},	//   nias, gáll, ştii_, _একে_,
   {{0x57f503e6,0xe3b10037,0x387d016e,0x00000000}},	//   _упат, سرة_, mawr_, --,
   {{0x81e200c8,0x61361721,0x7d0d0ec0,0x6d44004e}},	//   _নেই_, tálo, hias, zmia,
   {{0x7e7c008a,0x6d44001e,0x7d0d1da8,0x613d00fd}},	//   varp, ymia, kias, zéle,
   {{0x387d001e,0x5f0506d9,0x61361da9,0x2d5c0453}},	//   nawr_, होस्_, rálo, _ríe_,
   {{0x7e7c1daa,0x442f0a21,0x320b0035,0xdbdc1dab}},	//   tarp, _uyg_, ńcy_, tšíc,
   {{0xc8f418da,0x613d1dac,0x93240d47,0x3f5d00e2}},	//   _आत्म_, véle, _ورون, _dìu_,
   {{0x6d441dad,0x61460ece,0xdbdc0187,0x80d8166b}},	//   tmia, _лека, ršíc, यादे,
   {{0x7e7c0523,0x2a7801f4,0x7d0d1dae,0x4bda0086}},	//   sarp, _serb_, gias, льзя_,
   {{0x6d441daf,0x4aaa00c9,0xdbdc0187,0x7e7c1db0}},	// [1520] rmia, лкан_, pšíc, parp,
   {{0xaad21db1,0x3f821db2,0x39581db3,0x7d161627}},	//   साइक, msku_, _purs_, snys,
   {{0x7cf804a5,0x7d0d1db4,0xc87904d4,0x8e570070}},	//   _círc, bias, _beş_, _לייג_,
   {{0x2732002d,0x2b590036,0x7c9601d3,0xada600ee}},	//   mâni_, _fusc_, _уроц, _chúť,
   {{0x3f821db5,0x09e00083,0x613610b2,0x2bc9022e}},	//   nsku_, _যেখা, váll, रिणा,
   {{0xb8ef1db6,0xe3e80332,0x3ce018b0,0x3f820c13}},	//   _वो_, یکشن_, ljiv_, isku_,
   {{0xceb30122,0x23660207,0x39580223,0x3689005f}},	//   פיה_, _stoj_, _uurs_, рсін_,
   {{0xdb1d013c,0x18a31bfd,0x3ce000cd,0x4d7b016b}},	//   _ersä, _насм, njiv_, ארקע,
   {{0x3f820a78,0xe73a00c9,0x24181db7,0xe5090023}},	//   jsku_, _беа_, ропы_, vặt_,
   {{0x2bc90266,0x3f820254,0x27f900ab,0x39460f2d}},	//   रिता, dsku_, _üsna_, lmos_,
   {{0xd25010ad,0x00000000,0x00000000,0x00000000}},	//   بند_, --, --, --,
   {{0x3a3702da,0x463b02b5,0xca3700a5,0x613600b5}},	//   מרים_, _געבע, מניה_, lálj,
   {{0x39461db8,0x28cf00b4,0x00000000,0x00000000}},	//   imos_, _सोफि, --, --,
   {{0x6136006c,0x28cf1db9,0xdb1d0279,0xbb1b0139}},	//   nálj, _सोनि, _essê, _avîn,
   {{0xc27b0779,0x7d0d1dba,0x00000000,0x00000000}},	//   _גרוי, tias, --, --,
   {{0xdb0600b5,0x3f8200d5,0xe217024b,0x00000000}},	//   _eskü, bsku_, _לקוח_, --,
   {{0x6eeb00a8,0x212b1dbb,0xa2cd0099,0x7cf1029e}},	// [1530] _sübu, moch_, ताच्, _hårk,
   {{0x629a1dbc,0x7d0d1dbd,0xda670082,0x212b1dbe}},	//   ngto, sias, صائي, loch_,
   {{0xb9b51dbf,0x7d0d1dc0,0x9962024e,0xa2c01dc1}},	//   تماع, pias, _píše_, _वसन्,
   {{0x38351dc2,0x212b1dc3,0x319b016b,0x00000000}},	//   онер, noch_, רבאנ, --,
   {{0x656800da,0x7d1d1dc4,0x6fc9021a,0x2d830051}},	//   _atdh, _ijss, िटिं, lsje_,
   {{0x39461dc5,0x212b1dc6,0x613600fd,0x2d830223}},	//   amos_, hoch_, gálj, osje_,
   {{0x2d831dc7,0x13d106fe,0x212b016f,0x286b0431}},	//   nsje_, तम्भ, koch_, _брзо_,
   {{0xf8ae01cb,0x212b00a0,0x3f820096,0x2d8301e4}},	//   _لکه_, joch_, ysku_, isje_,
   {{0x290f1dc8,0x212b1dc9,0x7ae7006d,0xd7fb0819}},	//   miga_, doch_, _kojt, _сув_,
   {{0x290f1dca,0x2d830096,0xf6f500bf,0x13090086}},	//   liga_, ksje_, _بزرگ, рной_,
   {{0xf7480082,0x4615026e,0x7ae7063b,0x2d8302a2}},	//   _اللي_, _بوار, _mojt, jsje_,
   {{0x290f1dcb,0x3f820a78,0x7ae701f4,0xa4f700d1}},	//   niga_, tsku_, _lojt, _دکتر_,
   {{0x3f84031b,0x6136006c,0x6ef000be,0x2d830223}},	//   ému_, lálk, _häbi, esje_,
   {{0x3f8211d7,0x290f1dcc,0x7ae70009,0x6ef000b9}},	//   rsku_, higa_, _nojt, _käbi,
   {{0xdd9209b9,0x290f1dcd,0xddc30012,0xa2d600b4}},	//   ظور_, kiga_, мбри, बार्,
   {{0x290f1dce,0x3f821dcf,0x4c6a1dd0,0x212b1dd1}},	//   jiga_, psku_, риан_, coch_,
   {{0x290f1dd2,0x2d831c3a,0x6ef0007c,0x69c11dd3}},	// [1540] diga_, asje_, _läbi, _šlep,
   {{0x2d91004e,0xdcfc0029,0x38cb02fd,0x80d800a1}},	//   brze_, turē, یانی_, यावे,
   {{0x60c41dd4,0x3eb81dd5,0xfce61dd6,0xf86a0312}},	//   _kaim, mert_, _доно, لماي_,
   {{0xeb9a18c4,0x60c41dd7,0x290f1dd8,0x2d981dd9}},	//   _ким_, _jaim, giga_, mure_,
   {{0x39461dda,0xdb0409a6,0x39400029,0x2d981ddb}},	//   rmos_, ntië, ķis_, lure_,
   {{0x39461ddc,0x60c41ddd,0x6b84004f,0x3eb800d4}},	//   smos_, _laim, msig, nert_,
   {{0x290f1dde,0x2d981ddf,0x6b841de0,0x776914d8}},	//   biga_, nure_, lsig, _etex,
   {{0x60c41de1,0x443d02c9,0x3eb801ae,0x290f0b1a}},	//   _naim, _bzw_, hert_, ciga_,
   {{0x6b841de2,0x14a610aa,0x3eb81de3,0xa6861a56}},	//   nsig, क्षण, kert_, _млад,
   {{0xe73a1de4,0x6136006c,0x212b01ae,0x2d981de5}},	//   _тез_, lálh, woch_, kure_,
   {{0xd62a03ad,0x3eb81de6,0x60c41de7,0x1a9b0070}},	//   _тоже_, dert_, _baim, סיטע,
   {{0x613d008a,0x60c400f1,0x6136006c,0x2d981de8}},	//   féla, _caim, nálh, dure_,
   {{0x3eb81de9,0x60c41dea,0x212b1deb,0x6b8400cd}},	//   fert_, _daim, roch_, jsig,
   {{0x2d8302a2,0x6b841dec,0x3eb81ded,0x290f0b69}},	//   tsje_, dsig, gert_, ziga_,
   {{0x290f0186,0x2d981dee,0x60c41def,0x2d8500b5}},	//   yiga_, gure_, _faim, éle_,
   {{0x290f0c75,0x6b840210,0x613d002a,0x2d831df0}},	//   xiga_, fsig, béla, rsje_,
   {{0x6b840f3a,0x2002004e,0x290f1df1,0x2ca90312}},	// [1550] gsig, czki_, viga_, rfad_,
   {{0x3eb801f7,0xdb0400f7,0x80a71119,0x2d9804fb}},	//   cert_, ntiè, ट्रे, bure_,
   {{0x6b840b31,0x7ae71df2,0xfd10006c,0x3f991df3}},	//   asig, _vojt, رجہ_, lusu_,
   {{0x6b84139c,0x02b7018d,0x636701ba,0x7cf8002a}},	//   bsig, _अस्न, nčný, _tíra,
   {{0x290f1df4,0x6b841df5,0x69ce1df6,0x3f991df7}},	//   riga_, csig, _erbe, nusu_,
   {{0x290f1df8,0xc8790160,0x00000000,0x00000000}},	//   siga_, _moşi_, --, --,
   {{0x3f9919c6,0x2bc90bc1,0x290f0657,0x7cf800b8}},	//   husu_, रिवा, piga_, _mírn,
   {{0xd5ae00ad,0x61361df9,0x3f991dfa,0x628a1dfb}},	//   افي_, rálk, kusu_, _adfo,
   {{0x2d981dfc,0x48fa02b5,0x3ea10037,0xdb1d1dfd}},	//   zure_, _פּלא, _ocht_, _assé,
   {{0x60c41dfe,0x61361dff,0x613d1e00,0x68e91e01}},	//   _saim, máli, véla, _hoed,
   {{0x3eb81e02,0x60c41e03,0x68fb1e04,0xe8df00e2}},	//   vert_, _paim, _klud, _nhịn_,
   {{0x3eb801ae,0x6b8400e9,0x3ea11e05,0x7bcf143f}},	//   wert_, ysig, _acht_, _orcu,
   {{0xe28e1e06,0x68e90fdb,0x26c51e07,0x3eb81e08}},	//   _па_, _moed, _kalo_, tert_,
   {{0x2d981e09,0x60c4002f,0xdb0f0a17,0x68e91e0a}},	//   ture_, _waim, _escú, _loed,
   {{0x26c51e0b,0x62811e0c,0x60c41e0d,0x7bcf1e0e}},	//   _malo_, malo, _taim, _arcu,
   {{0x3ea11e0f,0x3eb802ce,0x3f991e10,0x26c50269}},	//   _echt_, sert_, busu_, _lalo_,
   {{0x2d981e11,0x2fc00cca,0x3f99045e,0x212001cb}},	// [1560] sure_, _usig_, cusu_, _ijih_,
   {{0x6b841e12,0x2d9801d3,0x68fb1e13,0x26c5002f}},	//   rsig, pure_, _alud, _nalo_,
   {{0x14bd0c67,0x68e91e14,0x00000000,0x00000000}},	//   ्याण, _boed, --, --,
   {{0x6d5e002a,0x61361e15,0x7e7e1e16,0x68fb00e9}},	//   _iupa, fáli, _hepp, _clud,
   {{0x7e7e008a,0x99930129,0x68e9001e,0x68e2003c}},	//   _kepp, češe_, _doed, rjod,
   {{0x6d5e1e17,0xf1db1e18,0x26c51e19,0x62811e1a}},	//   _kupa, यमान, _calo_, jalo,
   {{0x62811e1b,0x69da1e1c,0xbb431e1d,0x7e7e1167}},	//   dalo, _štef, _черк, _mepp,
   {{0x21201dce,0x68e91e1e,0x7e7e1e1f,0x6d5e1e20}},	//   _njih_, _goed, _lepp, _mupa,
   {{0x6d5e1e21,0x26c51e22,0xd46703fa,0x61360a54}},	//   _lupa, _falo_, чиње_, cáli,
   {{0xe3af1e23,0x62811e24,0x26c51e25,0x7e7e1de4}},	//   اري_, galo, _galo_, _nepp,
   {{0xd48f0ea7,0xb5ca0ae7,0x68e9012f,0xa50a1e26}},	//   _пр_, _دوام_, _yoed, _лежа_,
   {{0x64a600c7,0x3f991e27,0x38661e28,0x63a400af}},	//   _хада, tusu_, ncor_, _ţinu,
   {{0x6d5e1e29,0x7e7e1e2a,0xe50500d1,0x255500ea}},	//   _aupa, _bepp, _تبلي, _tālr_,
   {{0x6d5e1e2b,0x628a054e,0x26c50019,0x3f991e2c}},	//   _bupa, _udfo, _xalo_, rusu_,
   {{0x6d5e1e2d,0xa2a100a1,0x7e7e1e2e,0x3f991e2f}},	//   _cupa, _खात्, _depp, susu_,
   {{0x291c1e30,0x5d541e31,0xa3c000a1,0x7cf800fe}},	//   éval_, екст, _ंना_, _díro,
   {{0x68e902c7,0x201e0723,0xd00803fa,0x3b551b96}},	// [1570] _roed, ştir_, _неће_, дкар,
   {{0x68fb0080,0x61360faa,0x7cf8006c,0x68e91e32}},	//   _slud, váli, _hírl, _soed,
   {{0x68fb1e33,0xed580370,0x68e91e34,0x6d5e0afe}},	//   _plud, _ноќ_, _poed, _gupa,
   {{0xf9900fab,0x62811e35,0x61361e36,0x26c51e37}},	//   ابل_, zalo, táli, _salo_,
   {{0x2b9307e4,0x68e90244,0x37ab1e38,0x6d5e1e39}},	//   _سیاس, _voed, стен_, _zupa,
   {{0x61361055,0x628101ef,0x6d5e0138,0x68e911ad}},	//   ráli, xalo, _yupa, _woed,
   {{0x26c704c3,0x26c51e3a,0x273200af,0x68e91e3b}},	//   rdno_, _valo_, vânt_, _toed,
   {{0x26c51296,0x68fb027d,0x290d1e3c,0x62811e3d}},	//   _walo_, _ulud, _umea_, walo,
   {{0x26c51e3e,0xa2a1131c,0xf794010b,0x7f5f003c}},	//   _talo_, _खाद्, _патэ, _nuqq,
   {{0xaae0065a,0x21cc0355,0x7bcd1e3f,0x387f00f6}},	//   नायक, _běh_, ivau, _heur_,
   {{0x387f01bf,0x7e7e1e40,0x7cf1008c,0x05c101c0}},	//   _keur_, _repp, _håru, _शनिब,
   {{0x6d5e1e41,0x7e7e1e42,0xdb0400de,0x0cd80033}},	//   _rupa, _sepp, rtié, _সত্ত,
   {{0x6d5e1e43,0x387f1e44,0xe8df00e2,0x7e7e1e45}},	//   _supa, _meur_, _nhọn_, _pepp,
   {{0x387f1010,0x56b5016b,0x7cf1008c,0x00000000}},	//   _leur_, ופֿן_, _måru, --,
   {{0x6da31e46,0xdca61e47,0x00000000,0x00000000}},	//   кира, мави, --, --,
   {{0x249f00fb,0x20561e48,0x7cf81e49,0x387f1e4a}},	//   ngum_, _отпр, _víro, _neur_,
   {{0xe8df00e8,0x7e7e1ded,0x38c600c7,0x00000000}},	// [1580] _chọn_, _tepp, _jūrų_, --,
   {{0x6d5e1e4b,0x63a91e4c,0x6a160fda,0xc31f0033}},	//   _tupa, iten, وبار, _নীতি_,
   {{0x996503d0,0x80a50864,0x63a91e4d,0x6d5e08dd}},	//   етіл, _कामे, hten, _uupa,
   {{0x63a91e4e,0x274700fe,0x00000000,0x00000000}},	//   kten, _lůně_, --, --,
   {{0x387f1e4f,0x69da02f6,0x38660176,0x2ca0011e}},	//   _deur_, _šted, rcor_, mgid_,
   {{0x6136008a,0x38660392,0xdcfc010b,0x75240124}},	//   málu, scor_, turė, čizm,
   {{0x941801c2,0x63a90043,0xceb30122,0xfaa30d46}},	//   ərə_, eten, דיו_, _шаро,
   {{0x2ca01e50,0x63a91e51,0x387f1e52,0x6128033e}},	//   ngid_, ften, _geur_, nıld,
   {{0x63a91e53,0x2ca000ab,0x77910647,0x00000000}},	//   gten, igid_, _مینا, --,
   {{0x387f0051,0x7cf11e54,0xdcfe013a,0x00000000}},	//   _zeur_, _hårt, _appļ, --,
   {{0x6128027d,0x2b581e55,0x61151e56,0x00000000}},	//   kıld, _mirc_, едну, --,
   {{0x63a91e57,0x00000000,0x00000000,0x00000000}},	//   bten, --, --, --,
   {{0x63a91e58,0xa2941958,0x2bd20035,0x24f7010b}},	//   cten, _залі, सिफा, _іншы_,
   {{0x442601ed,0x2fd2017b,0x2ca0018d,0x6d461008}},	//   _ixo_, _dryg_, egid_, _ahka,
   {{0x929b00a5,0xfcc70274,0x5e5800af,0x00000000}},	//   _ויות, мљам, диря_, --,
   {{0x23d200e7,0x2b581e59,0x2ca01e5a,0x00000000}},	//   तिपद, _airc_, ggid_, --,
   {{0x2b580124,0x8ca50355,0x8aa71e5b,0x00000000}},	// [1590] _birc_, ङ्गो, дред, --,
   {{0x2d850831,0x7bcd18af,0xab9401e0,0x00000000}},	//   áles_, rvau, тифі, --,
   {{0x387f0248,0x63a91e5c,0x13b70033,0x6f1500ae}},	//   _peur_, zten, জিয়, mizc,
   {{0x09b10083,0x63a91e5d,0x6f1501d6,0xf77100ad}},	//   ছিলা, yten, lizc, هات_,
   {{0x6d4d145d,0x00000000,0x00000000,0x00000000}},	//   mmaa, --, --, --,
   {{0xd2461e5e,0x6d4d1e5f,0x6136006c,0xc87900af}},	//   _من_, lmaa, lált, _roşu_,
   {{0x44261e60,0x6d4d1e61,0x64420160,0x3860030a}},	//   _axo_, omaa, _azoi, žira_,
   {{0x6d4d1e62,0x6136006c,0xe3c800e2,0xc9840214}},	//   nmaa, nált, _bự_, _јури,
   {{0x249f008a,0x2bd213ab,0xe3c80023,0x6d4d1e63}},	//   rgum_, सिया, _cự_, imaa,
   {{0x63a91e64,0xe3c80028,0x8af00095,0x6d4d1413}},	//   rten, _dự_, qqət, hmaa,
   {{0xa0a61126,0x6d4d1e65,0xaae004aa,0x61280448}},	//   нанд, kmaa, नातक, yıld,
   {{0xcea901f3,0x7cf10a8a,0x00000000,0x00000000}},	//   _לי_, _mårs, --, --,
   {{0xc4cf006c,0x6d4d03c4,0xdb1d1e66,0x65610051}},	//   _مےں_, dmaa, _assí, _hulh,
   {{0x6d4601d2,0x65611e67,0x6d4d19c1,0x753b0c6f}},	//   _shka, _kulh, emaa, lluz,
   {{0x656100c9,0xe81607ba,0x612800d0,0x6136021d}},	//   _julh, _देना_, tıld, fált,
   {{0x656100c9,0x6d4d1e68,0x6b961e69,0x2fd20b3e}},	//   _mulh, gmaa, tryg, _tryg_,
   {{0x2ca01e6a,0xf1c901a5,0x612804d4,0xac0a03e6}},	// [15a0] rgid_, _hạ_, rıld, чнаа_,
   {{0x34bd0ea3,0x6d4d18af,0x6b960b3e,0x61280225}},	//   ्युद, amaa, rryg, sıld,
   {{0x753b1431,0x612800d0,0x613600fd,0x00000000}},	//   kluz, pıld, bált, --,
   {{0x6d4d013a,0xf1c90023,0x61361e6b,0x6d4600c3}},	//   cmaa, _mạ_, máls, _uhka,
   {{0xf1c901a5,0xe73a0665,0x00000000,0x00000000}},	//   _lạ_, пед_, --, --,
   {{0x7bc61e6c,0xe5c61a1c,0x6561024e,0x8f9b02b5}},	//   _isku, есио, _bulh, פיצי,
   {{0xaa431e6d,0xe3c800e8,0xf1c90023,0x24841ca0}},	//   _берл, _sự_, _nạ_, tamm_,
   {{0x2d981e6e,0x7d041e6f,0xcfe60033,0x38c800b5}},	//   irre_, nhis, _পেছন, _غازی_,
   {{0xd90d0357,0xe8b506d0,0x24841e70,0x00000000}},	//   _بین_, lışı, ramm_, --,
   {{0xf1c90019,0x7aee1e71,0xe816018d,0x23d2018d}},	//   _bạ_, _jobt, _देया_, तिबद,
   {{0xe8b50716,0x61361e72,0x6d4d1e73,0x7d041e74}},	//   nışı, jáls, ymaa, khis,
   {{0xe3c800e8,0x78a21e75,0x7bc6018d,0xf1c90019}},	//   _tự_, ngov, _osku, _dạ_,
   {{0x7d041e76,0x04570082,0x65611e77,0x613600b5}},	//   dhis, _كلمة_, _zulh, vált,
   {{0x3ea5006c,0xe8b5027d,0xbe0500b5,0x1ee700f8}},	//   ült_, kışı, پورٹ, روزی_,
   {{0x7bc600da,0x6d4d1e78,0x6abe0118,0x00000000}},	//   _asku, tmaa, depf, --,
   {{0x23b71e79,0x7d041e7a,0x6d4d1e7b,0xe8b501fb}},	//   _अहमद, ghis, umaa, dışı,
   {{0x6d4d1e7c,0x613607f8,0x78a204c3,0x2d9800f6}},	// [15b0] rmaa, rált, dgov, arre_,
   {{0x6d4d1e7d,0xadf501c8,0x0a6810ac,0x61361e15}},	//   smaa, _апош, ерци_, sált,
   {{0x7bc603cb,0x7d040014,0xf1c90023,0x6d4d1e7e}},	//   _esku, bhis, _xạ_, pmaa,
   {{0x7d041e7f,0x38c904e8,0xfe7005f5,0xf094016b}},	//   chis, بائی_, _پدی_, ָנס_,
   {{0xd3660088,0xdddc1e80,0x65611e81,0xa2a11e82}},	//   _خه_, marš, _sulh, _खाल्,
   {{0x3ce902f6,0x65611e83,0x00000000,0x00000000}},	//   ljav_, _pulh, --, --,
   {{0x2bc90f17,0x50b102b4,0x00000000,0x00000000}},	//   रिका, जभाष, --, --,
   {{0x69c7022f,0x3f990207,0x00000000,0x00000000}},	//   _isje, krsu_, --, --,
   {{0x3f8b004e,0xd468004f,0x7cf801f7,0x753b1e84}},	//   jscu_, رحيم_, _dírh, rluz,
   {{0x77900332,0x753b1e85,0x2bd20af9,0x466b0c4c}},	//   _ایوا, sluz, सिता, _храм_,
   {{0x3f8b1e86,0x65940409,0x7d041e87,0x412a0036}},	//   escu_, _баху, yhis, доно_,
   {{0xdddc0200,0x69d5068f,0xf1c900e2,0x741205f5}},	//   jarš, _mrze, _vạ_, اویا,
   {{0xc95202b5,0x03a5002d,0x00000000,0x00000000}},	//   ימט_, _рило, --, --,
   {{0x69c70280,0x78a20af1,0xf1c90019,0x69d50035}},	//   _osje, zgov, _tạ_, _orze,
   {{0x7d04004a,0x386d1e88,0x7aee1e89,0xe8b500a8}},	//   this, _ofer_, _robt, xışı,
   {{0x62831e8a,0x7aee0310,0x6ef9009e,0xad3901e0}},	//   _heno, _sobt, _lìbh, ечує_,
   {{0x62830118,0x7d041e8b,0x7aee01e8,0x6b630009}},	// [15c0] _keno, rhis, _pobt, икта,
   {{0x7d041e8c,0x62831e8d,0x386d1e8e,0x69d51e8f}},	//   shis, _jeno, _afer_, _brze,
   {{0x62831e90,0x7cf81d2b,0x1d0a0d28,0x23ab01b4}},	//   _meno, _líri, _жени_, høj_,
   {{0xe8b506d3,0x34bd00b4,0x69d50035,0x29000279}},	//   rışı, ्योद, _drze, óia_,
   {{0x69d51e91,0x98a31e92,0x66e61e93,0x628300a2}},	//   _erze, риче, кода, _oeno,
   {{0x62831e94,0x799e034d,0xa3d51e95,0x47330823}},	//   _neno, pupw, हिन_, аніс,
   {{0x69d5004e,0x27e00043,0x09e31e96,0xdb0f1e97}},	//   _grze, ţin_, _корн, _escó,
   {{0x3f4f0069,0x0eff021a,0x00000000,0x00000000}},	//   _jżur_, _उत्स_, --, --,
   {{0x62831e98,0x7d03002d,0x7cf80183,0x00000000}},	//   _beno, _înse, _círi, --,
   {{0x62830252,0x7cf80037,0x80a50006,0xe6c50037}},	//   _ceno, _díri, _काहे, _متمي,
   {{0x26de0052,0xe81610a6,0xcb13011d,0x4a9b0070}},	//   _into_, _देता_, שלת_, וייג,
   {{0x29061e99,0x7cf80037,0x628301bf,0x26cc1e9a}},	//   nhoa_, _fíri, _eeno, _hado_,
   {{0x26cc1e9b,0xfc3f01ef,0x43941e9c,0x29061e9d}},	//   _kado_, _acín_, _салс, ihoa_,
   {{0x62831e9e,0x04431e9f,0x26cc1ea0,0xe57100b5}},	//   _geno, _течн, _jado_, _خطے_,
   {{0x62881423,0x63a00600,0x823303c5,0xdddc024e}},	//   mado, lumn, _پروا, tarš,
   {{0x26cc0aca,0x7e620139,0x00000000,0x00000000}},	//   _lado_, _şopt, --, --,
   {{0x63a00034,0x2b4a0014,0x7c841ea1,0xac180274}},	// [15d0] numn, _bhbc_, русе, воту_,
   {{0x69d51ea2,0x62881ea3,0x26cc1a71,0x613d1ea4}},	//   _prze, nado, _nado_, déli,
   {{0xb0aa00a1,0x612804d4,0x60cd1ea5,0xed4e006c}},	//   _कामग, lıla, _kaam, تھی_,
   {{0x60cd1ea6,0xf1b302b5,0x63a01ea7,0xa3d50127}},	//   _jaam, יסע_, kumn, हिम_,
   {{0x26cc0657,0x60cd1ea8,0xb8cb1ea9,0x62881eaa}},	//   _bado_, _maam, _खा_, kado,
   {{0x69d5006a,0x62881eab,0x60cd1eac,0x69c71ead}},	//   _trze, jado, _laam, _tsje,
   {{0x26cc1423,0xdb040279,0x7cf81eae,0x69c7012e}},	//   _dado_, stiã, _síri, _usje,
   {{0x62831eaf,0x23ab054e,0x6d5d1eb0,0x612800d0}},	//   _seno, tøj_, _jisa, kıla,
   {{0x6b8d051b,0x62831eb1,0x613d1eb2,0x63a01eb3}},	//   nsag, _peno, céli, gumn,
   {{0x6d5d1eb4,0x61280463,0x26cc1eb5,0xd90d00b5}},	//   _lisa, dıla, _gado_, _بیچ_,
   {{0x628301ba,0x60cd1eb6,0x059600b5,0x5ed20033}},	//   _veno, _baam, _مانگ, _সকলে,
   {{0x6d5d1eb7,0x63a00ac8,0x60cd07a6,0x26cc0009}},	//   _nisa, bumn, _caam, _zado_,
   {{0x60cd1eb8,0x61280225,0xe2991eb9,0x00000000}},	//   _daam, gıla, _зал_, --,
   {{0x62880aca,0x6da61eba,0x3392004f,0x481602b5}},	//   cado, лига, _الوز, אַלן_,
   {{0x6d5d0b04,0x60cd073a,0xb1760019,0x6b8d1ebb}},	//   _bisa, _faam, _trượ, esag,
   {{0xa0a6081b,0x60cd001c,0x61fc008c,0x6b8d0093}},	//   _саид, _gaam, ørle, fsag,
   {{0x61281a68,0xeb97195a,0x6d5d1425,0x6b8d1ebc}},	// [15e0] cıla, лит_, _disa, gsag,
   {{0x78a90300,0x4e360071,0x2bc909b4,0x613d0093}},	//   _acev, _معجز, रिजा, véli,
   {{0x26cc1ebd,0x6d5d1ebe,0x60cd1ebf,0x2d9501fd}},	//   _rado_, _fisa, _yaam, _кряс,
   {{0x62880aca,0x613d1ec0,0x6d5d1ec1,0xfce61ec2}},	//   zado, téli, _gisa, _сомо,
   {{0x62881ec3,0x01370070,0xbcfb1485,0x26cc1ec4}},	//   yado, אָגט_, _diéd, _pado_,
   {{0x62881ec5,0x613d1ec6,0x6d5d018c,0xbcfb000d}},	//   xado, réli, _zisa, _piég,
   {{0xe1e71ec7,0x61280d6f,0x26cc0bff,0x80a508a9}},	//   _اس_, zıla, _vado_, _काले,
   {{0x26cc1ec8,0x443d0297,0x6d5d1505,0x80d4135e}},	//   _wado_, _byw_, _xisa, _बोले,
   {{0x62881423,0x29041ec9,0x60cd1eca,0x28e1051d}},	//   tado, _ilma_, _raam, फारि,
   {{0x60cd1ecb,0xc8790644,0x443d00e9,0xadf60066}},	//   _saam, _inşa_, _dyw_, ीनान_,
   {{0x60cd010d,0xba9b02b5,0x22581ecc,0x63a001a0}},	//   _paam, עסטי, ärk_, sumn,
   {{0x60cd0069,0x612806d3,0x6b8d0248,0x443d001e}},	//   _qaam, tıla, ysag, _fyw_,
   {{0x62881ecd,0x33f601b2,0x06fa0026,0x60cd1ece}},	//   pado, _حساس, _्ताव_, _vaam,
   {{0x6d5d1ecf,0x61280092,0x60cd05db,0x6b8d00d4}},	//   _sisa, rıla, _waam, vsag,
   {{0x60cd1ed0,0x69da1ed1,0xbcfb0248,0x6b4b033b}},	//   _taam, _šten, _liée, nüge,
   {{0x61280723,0x2fc9006d,0x6b8d1ed2,0x6d5d1ed3}},	//   pıla, _tsag_, tsag, _qisa,
   {{0x6d5d1ed4,0x5b151ed5,0x443d006d,0x6e950043}},	// [15f0] _visa, амат, _xyw_, _кипу,
   {{0x91a8009a,0xa3d5157d,0x6d5d1ed6,0x6b8d1ed7}},	//   _कमाई, हित_, _wisa, rsag,
   {{0x6b8d1ed8,0x6d5d1ed9,0xba47010b,0x64b40099}},	//   ssag, _tisa, ухай, ंभाळ,
   {{0xd7d503e6,0xc9130033,0x6b8d1eda,0xe81608b0}},	//   ижењ, িক্ত_, psag, _देहा_,
   {{0xdb040b06,0x21290051,0x75dc0139,0x00000000}},	//   stiá, _mjah_, _lăză, --,
   {{0x6b4b02c9,0x443d00e9,0x29041edb,0xa2a9057c}},	//   füge, _ryw_, _elma_, ज्ञ्,
   {{0x5a440a93,0xba740332,0x6ead00b8,0x256a00f1}},	//   _гэта, _چاہت, _जानु, _cùl_,
   {{0xb4650009,0x2d9e0200,0xe8161edc,0x195806d8}},	//   шкил, šteg_, _देवा_, _басы_,
   {{0xab5b00ab,0x394d01a3,0x67d400af,0xf770014a}},	//   _psüh, _ihes_, _лоту, _فال_,
   {{0x82f51edd,0x98140d82,0x21290118,0x57f40274}},	//   рчиц, _طبقا, _ajah_, _упут,
   {{0x394d0221,0xf8c91ede,0x3245141d,0x61fa099e}},	//   _khes_, _रसाय, ренг, gytl,
   {{0x33d50131,0x2486027a,0xa2a900e7,0xa3d51edf}},	//   _вікт, _geom_, ज्ज्, हिद_,
   {{0x955409b9,0xa93600a5,0x320c0035,0x00000000}},	//   _اخلا, שטרה_, azdy_, --,
   {{0x394d0279,0xa8560122,0xe299145c,0x00000000}},	//   _lhes_, יירה_, _рак_, --,
   {{0x21a50036,0x2cb90211,0x764e0097,0xe2da00fd}},	//   _тийм, _bbsd_, _úbyt, _جانچ_,
   {{0x25ed1ee0,0xd24e1ee1,0x395f1ee2,0x00000000}},	//   _अपनी_, _غني_, _nius_, --,
   {{0xed57051b,0xcb67002d,0x6b4b1ee3,0x81cc0033}},	// [1600] рот_, иате_, züge, রমণ_,
   {{0x0d861566,0x00000000,0x00000000,0x00000000}},	//   _клон, --, --, --,
   {{0x395f046a,0x6f1c1ee4,0x7e9b00a5,0xfe9b0070}},	//   _bius_, mirc, _בסיו, _ביימ,
   {{0x613d01ef,0x394d099e,0x395f005f,0x67280069}},	//   bélu, _ches_, _cius_, _sjdj,
   {{0x67d41a33,0x395f0310,0x394d0118,0x613d01ef}},	//   солу, _dius_, _dhes_, célu,
   {{0x7cf81ee5,0x6f1c1ee6,0x3ce20345,0xb8fd021a}},	//   _víru, nirc, _hnkv_, _थो_,
   {{0x4420002d,0x95ca1ee7,0x55060012,0x395f1ee8}},	//   _ţi_, тула_, ичиа, _fius_,
   {{0x764800ac,0xdb1d0523,0x75dc0160,0x00000000}},	//   _vzdy, _essä, _răză, --,
   {{0x6f1c1ee9,0xdcef00cd,0x00000000,0x00000000}},	//   kirc, žeće, --, --,
   {{0x21290051,0x00000000,0x00000000,0x00000000}},	//   _sjah_, --, --, --,
   {{0x8ad90070,0x98af00ea,0x05661eea,0x6f1c1eeb}},	//   אַרפ, logā_, _твен, dirc,
   {{0x236600c7,0x25be08c7,0x656801da,0xd5fb016b}},	//   _tuoj_, _iptl_, _iudh, _שפאר,
   {{0x65681eec,0x69da1eed,0x9f5900a2,0x853500b5}},	//   _hudh, _štel, lysé_, _اونچ,
   {{0x65681eee,0x31670069,0xe7f90266,0x7d061eef}},	//   _kudh, _funz_, ्नता_, _alks,
   {{0x51860395,0xe29703fa,0x3eba0159,0x31671ef0}},	//   _тула, _тај_, _dbpt_, _gunz_,
   {{0x656800d1,0x6f1c009e,0x67380207,0x00000000}},	//   _mudh, airc, hovj, --,
   {{0x67381ef1,0x2d581470,0x65681ef2,0x395f0310}},	// [1610] kovj, рить_, _ludh, _rius_,
   {{0x673800cb,0x21390031,0x65680d35,0x261700ab}},	//   jovj, losh_, _oudh, _भइली_,
   {{0x395f1ef3,0x6738003d,0x656800e0,0x3ce200fe}},	//   _pius_, dovj, _nudh, _fnkv_,
   {{0x80c50033,0xbcfb0118,0x21390031,0x00000000}},	//   ষাক্, _diéc, nosh_, --,
   {{0x395f0310,0x2d910067,0x6568034d,0x00000000}},	//   _vius_, lsze_, _audh, --,
   {{0x65681ef4,0x67380a16,0x612800a8,0xa3d51ef5}},	//   _budh, govj, yılo, हिस_,
   {{0x394d1ef6,0x213901f4,0xdcfb07b5,0xdb0d1ef7}},	//   _thes_, kosh_, _एकाध_, ltaï,
   {{0x2ca91ef8,0x28cf14ab,0x6ac70066,0xb9251ef9}},	//   ngad_, _सोचि, _रघुर, _افري,
   {{0x291d1efa,0x21391efb,0x6f1c0225,0x00000000}},	//   miwa_, dosh_, yirc, --,
   {{0x291d19c6,0xddde1efc,0x730512f8,0xdb041efd}},	//   liwa_, _lepš, споз, rtiç,
   {{0xdb040370,0x65681efe,0x7af51eff,0x2d910035}},	//   stiç, _gudh, _mozt, jsze_,
   {{0x291d0054,0x21390031,0x00000000,0x00000000}},	//   niwa_, gosh_, --, --,
   {{0xc50c0070,0xa2d20b35,0x9fd60033,0x00000000}},	//   _בלאָ, _भोक्, সঙ্গ, --,
   {{0xe3b00118,0x656816ec,0x291d1f00,0x644b03ab}},	//   _زره_, _yudh, hiwa_, _izgi,
   {{0x291d19c6,0x6b5006d7,0xf2d202b5,0x7d060029}},	//   kiwa_, lägg, _מעג_, _plks,
   {{0x3c6601c8,0x291d000e,0x2ca9022a,0xddde02d4}},	//   скаг, jiwa_, ggad_, _cepš,
   {{0x612806d3,0x291d000e,0x6f1c1f01,0x6d4f0211}},	// [1620] nılm, diwa_, pirc, _dhca,
   {{0x78bb0371,0xbcfb00a2,0x60c600fd,0x00000000}},	//   _abuv, _piéc, lekm, --,
   {{0x7c2f1f02,0x291d0054,0x8db600d4,0x67380506}},	//   _excr, fiwa_, _успі, vovj,
   {{0x98a61f03,0x65681ef2,0x291d1f04,0x6128027d}},	//   сиде, _rudh, giwa_, kılm,
   {{0xc7a311b9,0x65681f05,0x31b1006c,0x6738040b}},	//   зичк, _sudh, ház_, tovj,
   {{0x61280095,0x6d441f06,0x09e601d3,0x78bb018e}},	//   dılm, llia, _логн, _ebuv,
   {{0x6d440297,0x291d000e,0x38690bc6,0x69070279}},	//   olia, biwa_, žara_, órdã,
   {{0x69ce1f07,0x53981f08,0x6d441f09,0x21390031}},	//   _isbe, авия_, nlia, xosh_,
   {{0x67380c0a,0x2d850f56,0xe8df0019,0x6d441f0a}},	//   povj, ález_, _nhộn_, ilia,
   {{0x6d441f0b,0x65681f0c,0x00000000,0x00000000}},	//   hlia, _tudh, --, --,
   {{0xe3af07e4,0x6d441f0d,0x213901f4,0xf53900b8}},	//   وری_, klia, tosh_, boť_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d91006a,0x6d44001e,0x213901f4,0xb0aa0f06}},	//   wsze_, dlia, rosh_, _कारग,
   {{0xa3d5164f,0x291d1f0e,0x69dc1f0f,0x21390031}},	//   हिर_, ziwa_, _orre, sosh_,
   {{0x7af51b66,0x62980009,0x2d851f10,0x8cda00a1}},	//   _rozt, _idvo, èle_, _पोहो,
   {{0x6d440133,0x2d911f11,0x6442012f,0x50670009}},	//   glia, rsze_, _kyoi, _утка,
   {{0x69ce1f12,0x7af501a3,0x2ca91f13,0x291d034d}},	// [1630] _asbe, _pozt, rgad_, viwa_,
   {{0x2d91004e,0xaa671f14,0x6d441f15,0x69dc009e}},	//   psze_, стак, alia, _brre,
   {{0x291d000e,0x6128037a,0x7d0300af,0xd8790037}},	//   tiwa_, zılm, _înso, لمات_,
   {{0x612804d4,0x628a00b5,0x04fa0033,0xdcfc00ea}},	//   yılm, _lefo, ইফুর_, rurģ,
   {{0x69dc1f16,0x629807c0,0x291d1f17,0x69ce13dc}},	//   _erre, _odvo, riwa_, _esbe,
   {{0x7d0d0332,0x291d1f18,0xdb0d0037,0xab5b006c}},	//   lhas, siwa_, otaí, _csüt,
   {{0xceb402b8,0x24e90133,0xdb0d0037,0x291d08c7}},	//   פיק_, имки_, ntaí, piwa_,
   {{0x612806d3,0x7d0d1f19,0x6562009e,0x77690453}},	//   tılm, nhas, _cioh, _tuex,
   {{0x628a1f1a,0x13091f1b,0x248d0183,0xd6ab0413}},	//   _befo, иний_, raem_, _مدام_,
   {{0x61280dac,0xe299052c,0x248d0098,0x42250ef3}},	//   rılm, јан_, saem_, ждов,
   {{0x26c71f1c,0x7d0d1f1d,0x90c61f1e,0x6d44001e}},	//   meno_, khas, обне, ylia,
   {{0xf992035e,0x7bcf1f1f,0x6128008f,0x69da1f20}},	//   ורט_, _oscu, pılm, _štek,
   {{0x75290043,0x6b5006d2,0x7d0d00f8,0x60c6027d}},	//   mnez, läge, dhas, rekm,
   {{0xb4c90d1f,0x26c7000e,0xa3d60992,0x6d44001e}},	//   _लघु_, neno_, ाटर_, wlia,
   {{0x62811f21,0x7bcf0043,0x75291f22,0x7bdd14c0}},	//   mblo, _ascu, onez, _arsu,
   {{0x62811f23,0x7d0d1f24,0x6d441f25,0x75291f26}},	//   lblo, ghas, ulia, nnez,
   {{0x8c431f27,0x6d56026e,0x6d441f28,0x8eba002d}},	// [1640] дете, rmya, rlia, _кынт_,
   {{0x26c702dd,0xb0aa1f29,0x98ad00a0,0x00000000}},	//   jeno_, _काँग, _cieľ_, --,
   {{0x7bcf1111,0x26c715b5,0x6d441f2a,0x7d0d1f2b}},	//   _escu, deno_, plia, bhas,
   {{0x7d0d02a8,0x31ba02b5,0xdb04004f,0x752907e7}},	//   chas, יזענ, ntiú, jnez,
   {{0x765f01c2,0x75290359,0x62811f2c,0x26c71f2d}},	//   əyyə, dnez, kblo, feno_,
   {{0x7d040086,0x62811f2e,0x75291f2f,0x00000000}},	//   lkis, jblo, enez, --,
   {{0xb0aa00b1,0x69dc1f30,0x62811f31,0xaa431ec2}},	//   _कांग, _urre, dblo, _жерл,
   {{0x7d041f32,0x628a0260,0x62811f33,0xa3d51f34}},	//   nkis, _sefo, eblo, हिं_,
   {{0x26c71f35,0x628a0260,0x39461f36,0x25e60387}},	//   beno_, _pefo, mlos_, _झपकी_,
   {{0x39461f37,0x26c71f38,0x20d70023,0x7d04145d}},	//   llos_, ceno_, _ủi_, hkis,
   {{0xd48f0043,0x7d041f39,0xdb040453,0x753b06fe}},	//   _ор_, kkis, guié, bouz,
   {{0x394602c9,0x657a00b5,0x7d0d0c6f,0x386002c4}},	//   nlos_, _itth, xhas, žiru_,
   {{0x62811f3a,0x39461f3b,0x00000000,0x00000000}},	//   bblo, ilos_, --, --,
   {{0x62810310,0xdb041f3c,0x62981f3d,0xbcfb02d7}},	//   cblo, quiè, _udvo, _cién,
   {{0x7d0d1f3e,0xf27b0122,0x394601c8,0xc27b0070}},	//   thas, _דרוש, klos_, _דרוי,
   {{0xd9040220,0xdb04004f,0x26c701c0,0x3946006d}},	//   _شی_, ctiú, zeno_, jlos_,
   {{0x7d0d02cb,0xdb0d004f,0x39461f3f,0x00000000}},	// [1650] rhas, staí, dlos_, --,
   {{0x7d0d1f40,0x657a006c,0x26c70391,0x394605c9}},	//   shas, _otth, xeno_, elos_,
   {{0x7d04006d,0x7d0d1f41,0x753b08c7,0x00000000}},	//   bkis, phas, youz, --,
   {{0x39461f42,0x7d041f43,0xcdda02b5,0x6b501f44}},	//   glos_, ckis, _פֿיר, väge,
   {{0x657a012f,0x60dc02b5,0x26c71f45,0x66e50382}},	//   _atth, יקאנ, teno_, зола,
   {{0x628101b4,0xff7c0070,0x394607a6,0x00000000}},	//   xblo, סטומ, alos_, --,
   {{0x2bcf009a,0x80ac02cb,0x39461f46,0x7bcd1f47}},	//   _सैता, _झाले, blos_, lwau,
   {{0x39460473,0x61360332,0x6b5001ae,0xf8ae01cb}},	//   clos_, bály, räge, _مکه_,
   {{0x62811f48,0x26c71c1a,0x6b50191b,0x75290139}},	//   tblo, peno_, säge, rnez,
   {{0x753b0355,0x13091397,0x00000000,0x00000000}},	//   souz, сной_, --, --,
   {{0x7d041f49,0xcb1200a5,0xbcfb02d7,0x59de0067}},	//   ykis, גלי_, _rién, _नज़ार,
   {{0x62811f4a,0xbcfb0a17,0x00000000,0x00000000}},	//   sblo, _sién, --, --,
   {{0x4aac00a1,0xaaac111a,0xbcfb02d7,0xa3d6018d}},	//   _चालव, _चालक, _pién, ाटः_,
   {{0x3f9e024e,0x3ebe008d,0x63a908c7,0xe7f300be}},	//   čtu_, ýtt_, muen, _आपना_,
   {{0x7d041f4b,0xdb0400f7,0xbcfb0453,0xc27a00a5}},	//   tkis, quié, _vién, _פרקי,
   {{0x2571008a,0x61fc017b,0x41b20037,0x7c2900f4}},	//   _mál_, ärle, _أمير, _žera,
   {{0xeb9a0036,0x7d0404d5,0xfbdf0183,0x80bc022e}},	// [1660] сиз_, rkis, _crê_, ष्णे,
   {{0xa3dc1f4c,0x7d041f4d,0x60d61f4e,0xe81f04bc}},	//   डित_, skis, _haym, _मेधा_,
   {{0x9d460847,0x60d6027d,0x63a90138,0xfbdf021d}},	//   _неод, _kaym, huen, _erê_,
   {{0x60d6021d,0x7ae70031,0x613600b5,0x00000000}},	//   _jaym, _enjt, tály, --,
   {{0x39461f4f,0xe8160b47,0x2efa01ae,0xe0df02d0}},	//   rlos_, _देखा_, _kopf_, klòn_,
   {{0x613600b5,0x39461f50,0x4e7a0070,0x00000000}},	//   rály, slos_, זאַצ, --,
   {{0xb4d7009a,0x394610ca,0x257101ef,0x38c804cd}},	//   ायू_, plos_, _cál_, _واری_,
   {{0x399b0122,0x257100b8,0x63a91f51,0x290701f4}},	//   _לילד, _dál_, fuen, ënat_,
   {{0x63a91f52,0x2a6a012f,0x07a303e6,0x00000000}},	//   guen, _kgbb_, _патн, --,
   {{0xa3ab004e,0x877b0319,0x957c0067,0x25710098}},	//   गढ़_, _לאמי, _prąd, _fál_,
   {{0x29061f53,0xbcfb00a2,0x54360987,0x00000000}},	//   okoa_, _biél, _کرار, --,
   {{0x63a91ccb,0x29061f54,0x644e00a8,0x69c400ab}},	//   buen, nkoa_, əbin, _रहनी,
   {{0x63a91166,0x5f9401d3,0xbcfb1f55,0xe8df00e2}},	//   cuen, ният, _diél, _nhờn_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9e0a78,0xb2bb0122,0x3cf90009,0x29060086}},	//   šten_, _המור, _posv_, kkoa_,
   {{0x614403e6,0x00000000,0x00000000,0x00000000}},	//   _пеја, --, --, --,
   {{0xa3d5006a,0x3c58002d,0xe8df00cc,0x00000000}},	// [1670] हिए_, зитэ_, _chờn_, --,
   {{0xc8790160,0x290601ed,0x00000000,0x00000000}},	//   _inşi_, ekoa_, --, --,
   {{0x63a901a3,0x30a600fd,0x60d6027b,0x777b00ee}},	//   zuen, _علیہ, _yaym, _stux,
   {{0xe6c50302,0x25e01a75,0x5fb10437,0x00000000}},	//   लज्ज, किनी_, _जमाल, --,
   {{0x25711f56,0x613601ef,0x333e01ed,0x00000000}},	//   _sál_, rálx, kotx_, --,
   {{0x290f1505,0xb9041f57,0x257100b5,0x9b580036}},	//   shga_, _भो_, _pál_, _ният_,
   {{0x69da108a,0x2002004e,0x00000000,0x00000000}},	//   _štev, zyki_, --, --,
   {{0x58d41f58,0x63a91f59,0xb4d70b4a,0x6b500282}},	//   _пост, tuen, ाये_, mäga,
   {{0x2be00e6f,0x68e91f5a,0xfbe00e61,0x195800c7}},	//   निया, _ined, नियम, _хаты_,
   {{0x68fb1f5b,0x63a91f5c,0x68e90501,0x60d6045e}},	//   _houd, ruen, _hned, _saym,
   {{0xa0a61f5d,0x68e90393,0x80d70083,0x68fb1f5e}},	//   манд, _kned, ধান্, _koud,
   {{0x2002004e,0x67231f5f,0x68fb1f60,0x63a902d7}},	//   tyki_, linj, _joud, puen,
   {{0x63a91c33,0x21221d11,0x68fb1f61,0xe2991f62}},	//   quen, rikh_, _moud, _дал_,
   {{0x29060291,0x67231f63,0x7f19010b,0x20020067}},	//   zkoa_, ninj, пісу_, ryki_,
   {{0xa3d50b54,0xdd1c024e,0x68e90168,0x60d61f64}},	//   हिक_, _vážn, _oned, _taym,
   {{0x67231f65,0xdb0d01ae,0x68fb1f66,0x68e905a0}},	//   hinj, traß, _noud, _nned,
   {{0xab661f67,0x672305e2,0x2efa02b1,0xe3b900b5}},	// [1680] двал, kinj, _topf_, ntű_,
   {{0x290d09d1,0x6723018e,0x68fb0024,0x68e91f68}},	//   _alea_, jinj, _aoud, _aned,
   {{0x67230888,0x68fb1f69,0x68e9007a,0x6b960b3e}},	//   dinj, _boud, _bned, ssyg,
   {{0xc7c61f6a,0x6603004e,0xb4d700b8,0x68fb00f7}},	//   дски, dynk, ायो_, _coud,
   {{0x4c3601c8,0x68fb1f6b,0x29061c9a,0x224700cc}},	//   _цэнт, _doud, rkoa_, _lynk_,
   {{0x67230528,0x290601d7,0x68e91f6c,0xdddc0067}},	//   ginj, skoa_, _ened, karż,
   {{0x8a06005f,0x68fb000d,0x7afc01ed,0xdd1d00ac}},	//   _ўзбе, _foud, _iort, lášs,
   {{0x7afc1f6d,0x68fb1f6e,0x25a01f6f,0xe81f05a2}},	//   _hort, _goud, čil_, _मेवा_,
   {{0x67231f70,0x644e004e,0x68431f71,0x06bd0831}},	//   binj, ębio, _анта, _আফরি,
   {{0x68fb0a75,0x67231f72,0x00000000,0x00000000}},	//   _zoud, cinj, --, --,
   {{0x7afc1f73,0x360601b2,0xbcfb0118,0x2d9e0355}},	//   _mort, _تواف, _diéj, átel_,
   {{0x7afc0291,0x7bc60051,0x849600b5,0x249d034d}},	//   _lort, _opku, _آجائ, _gdwm_,
   {{0x7afc0173,0x2d9e1942,0x611400af,0x7d030160}},	//   _oort, štel_, тдяу, _însi,
   {{0x7afc1f74,0x15f205dc,0x05c200b4,0x00000000}},	//   _nort, _अपार_, _शहाब, --,
   {{0xa3d60cf1,0x7bc600ea,0x64550067,0xdb0d0183}},	//   ाटक_, _apku, ęzie, ltaç,
   {{0x7afc1f75,0x50670de3,0x6ca41f76,0x6b5001ff}},	//   _aort, _отпа, круж, väga,
   {{0xdb0d00c9,0x3b550012,0x68fb1f77,0x7afc0533}},	// [1690] ntaç, екар, _roud, _bort,
   {{0x68fb1f78,0xdb0d03e6,0x68e91f79,0x00000000}},	//   _soud, itaç, _sned, --,
   {{0x672302f6,0x68fb1f7a,0x7afc1f7b,0x2bab04bc}},	//   vinj, _poud, _dort, _चमका,
   {{0x6ebb035d,0x38351f7c,0xe7f30067,0x2d8301e4}},	//   श्रु, ннер, _आपदा_, mpje_,
   {{0x672301cc,0x69da0a78,0x68fb0248,0x941d0437}},	//   tinj, _štet, _voud, _बेंच_,
   {{0x7afc1f7d,0x68fb0d35,0xe7331d05,0x316900d5}},	//   _gort, _woud, خصص_, _liaz_,
   {{0xe81f006a,0x6723068e,0x236701f4,0x68fb0359}},	//   _मेरा_, rinj, _rinj_, _toud,
   {{0x6723003c,0x68e900e9,0x67d51f7e,0x7afc06a2}},	//   sinj, _uned, _побу, _zort,
   {{0x67231f7f,0x373500d8,0x7768002a,0x386d1f80}},	//   pinj, _знаё, _fidx, _iger_,
   {{0xcb1202b5,0x7afc003c,0xfbd20122,0xf77200a5}},	//   ָלט_, _xort, נתי_, _עקב_,
   {{0x76481f81,0x032200d8,0xe1261f82,0x7d0f006c}},	//   _gydy, удэн, емни, _olcs,
   {{0x75d301c2,0xab5b033b,0xe8df0023,0xbcfb0118}},	//   _nəzə, _spül, _khốn_, _diék,
   {{0x31691f83,0x2d8302a2,0x13f402fb,0xdb0d0183}},	//   _diaz_, epje_, _изця, ctaç,
   {{0x2d9e0254,0x63bb0b4f,0x69c70506,0x61ee0098}},	//   štem_, mtun, _opje, óilí,
   {{0x63bb1f84,0x2f14022a,0x2d8c0248,0xed5a0994}},	//   ltun, _lägg_, ède_, зов_,
   {{0xc5f202b5,0x00000000,0x00000000,0x00000000}},	//   נדן_, --, --, --,
   {{0xe81f06bc,0x60c40010,0x2d830051,0x67210282}},	// [16a0] _मेला_, _ibim, apje_, _omlj,
   {{0x7afc1f85,0x63bb1f86,0x386d1f87,0x4e1c0033}},	//   _qort, itun, _ager_, _দুঃখ_,
   {{0x7afc1f88,0x63bb1f89,0x39441f8a,0xfbdf0023}},	//   _vort, htun, _pkms_, _uyên_,
   {{0x76480297,0x61fc1f8b,0x7afc1f8c,0xf1b200a5}},	//   _rydy, ørli, _wort, רסא_,
   {{0x6d461f8d,0x69d51f8e,0x67d4002d,0x7afc10a7}},	//   _ikka, _esze, толу, _tort,
   {{0x386d1f8f,0x6b841f90,0x63bb1f91,0x98c50228}},	//   _eger_, mpig, dtun, ītās_,
   {{0x60c41f92,0xceb302b5,0x63bb1f93,0xdb04000d}},	//   _obim, טיג_, etun, vriè,
   {{0x63bb1f94,0x75d30095,0xa3dc167e,0x6b84023c}},	//   ftun, _xəzə, डिल_, opig,
   {{0xd4e30086,0x63bb1f95,0xdb041f96,0x61e309bd}},	//   ующи, gtun, triè, _arnl,
   {{0x60c41f97,0xdb0d1f98,0x0bb700a5,0x2d830031}},	//   _abim, rtaç, עלים_, ypje_,
   {{0x6d461f99,0xdb0402e1,0xdb0d03e6,0x3f8001ef}},	//   _okka, rriè, staç, _atiu_,
   {{0xdb0d03e6,0x6d46010d,0xdcdf0722,0x7c2902c4}},	//   ptaç, _nkka, _पोंछ, _žerm,
   {{0xa3e401c0,0xdb040042,0x63bb055c,0x61e30282}},	//   _पछि_, ntió, ctun, _ernl,
   {{0x6d461f9a,0x545302ce,0x60c401a8,0x32050355}},	//   _akka, _світ, _ebim, byly_,
   {{0x0dc81f9b,0x7c8703fa,0x720300b5,0x00000000}},	//   нути_, еузе, _مووم, --,
   {{0x2b58011e,0x38690121,0x75d300a8,0x00000000}},	//   _ahrc_, žari_, _qəzə, --,
   {{0x69c71f9c,0x8aa7093c,0xfaa703fe,0x6b8408dd}},	// [16b0] _spje, еред, ешен, gpig,
   {{0x60dd1f9d,0x2fc91292,0x6d4601a8,0x00000000}},	//   ldsm, _ipag_, _ekka, --,
   {{0xf9930206,0x7dc4006c,0x63bb1e5c,0x69da1f9e}},	//   ابط_, _یقین, ztun, _šter,
   {{0x60dd14c2,0x2d81009d,0x2fc9010d,0x63bb1f9f}},	//   ndsm, _ithe_, _kpag_, ytun,
   {{0xb8c90755,0x69d5004e,0xd24601df,0xb09c00a5}},	//   _गए_, _wsze, _چن_, ליאר,
   {{0x6d4d1fa0,0xd2461abd,0x7522073a,0x9f4000f6}},	//   llaa, _نن_, _amoz, _prié_,
   {{0xa3b300a1,0x6d460093,0xda090c74,0x798e016e}},	//   जून_, _ykka, _غيره_, _gwbw,
   {{0x63bb1fa1,0x386d1fa2,0x60dd01b4,0x6d4d1fa3}},	//   ttun, _uger_, jdsm, nlaa,
   {{0x63bb00c3,0x7d0300af,0xdb040132,0x7c290116}},	//   utun, _însu, quiã, _žerj,
   {{0x63bb06d1,0x613d0332,0x75221fa4,0x6d4d1fa5}},	//   rtun, mély, _emoz, hlaa,
   {{0x6d4d0006,0x63bb1fa6,0x3f800043,0x2d8101e8}},	//   klaa, stun, _stiu_, _nthe_,
   {{0xbcfb0132,0x3f800160,0x6d4d0051,0xdb0400f6}},	//   _fiéi, _ptiu_, jlaa, rrié,
   {{0x889a0122,0x6d4d1fa7,0x2f14013c,0x4ab30096}},	//   וברי, dlaa, _läge_, ुभाव,
   {{0x2be0009a,0xdb0402e1,0x656b1fa8,0x4ed51fa9}},	//   निसा, prié, _high, люст,
   {{0x656b1faa,0x60c4009e,0x6d4d1fab,0x3f6702ee}},	//   _kigh, _tbim, flaa, тиро_,
   {{0x6d4d1fac,0x63a91fad,0x657c00b5,0x6128027b}},	//   glaa, oren, _érhe, rıls,
   {{0x656b0122,0xeb971fae,0x765c00ac,0x2d811faf}},	// [16c0] _migh, кит_, _úryv, _ethe_,
   {{0x656b1fb0,0x613d006c,0x63a91fb1,0x6d4d1fb2}},	//   _ligh, dély, iren, alaa,
   {{0x63a91fb3,0x656b09bb,0x644b00d8,0x2be01fb4}},	//   hren, _oigh, _lygi, निहा,
   {{0x63a91fb5,0x656b1fb6,0xfbab0581,0x2bab0380}},	//   kren, _nigh, _चमचम, _चमचा,
   {{0x68430bbc,0x644b038d,0x613d00fd,0x00000000}},	//   анца, _nygi, gély, --,
   {{0x656b009d,0x6d441fb7,0xd09a00a8,0xdb0401f7}},	//   _aigh, loia, rçək, quià,
   {{0x63a91fb8,0xdb0409ab,0x656b0159,0x2be00275}},	//   eren, stió, _bigh, निवा,
   {{0x63a91fb9,0x6d441200,0x644b099e,0x7d030395}},	//   fren, noia, _bygi, _înst,
   {{0xa7661fba,0x63a91fbb,0xdce60009,0xdb0401ef}},	//   _акад, gren, _nikč, ltiñ,
   {{0x86ea004f,0x656b1fbc,0x6d441fbd,0x14ae0099}},	//   _تعرف_, _eigh, hoia, _टाकण,
   {{0xdb040391,0x63a91fbe,0x656b00a5,0x6d4401a3}},	//   ntiñ, aren, _figh, koia,
   {{0x94260086,0x6913027d,0x656b0211,0x6d4401ed}},	//   _имее, _içec, _gigh, joia,
   {{0x60dd1e74,0x6d441fbf,0x63a91fc0,0x00000000}},	//   rdsm, doia, cren, --,
   {{0xdce6005f,0x00000000,0x00000000,0x00000000}},	//   _dikč, --, --, --,
   {{0x7e281112,0x6e941edd,0x6d4d1fc1,0x6b500f8e}},	//   віта_, рису, tlaa, rägl,
   {{0xe7f300a1,0x6d441fc2,0x7d16016e,0xbcfb00f6}},	//   _आपला_, goia, ghys, _liév,
   {{0xdc55051b,0x6d4d0136,0x2571003a,0xfbd00037}},	// [16d0] увањ, rlaa, _išle_, يتك_,
   {{0x6d4d0a45,0xf1b61fc3,0x200402b1,0x00000000}},	//   slaa, _अमान, ämie_, --,
   {{0x6d4d1fc4,0x2d81022e,0x63a91fc5,0x6d441fc6}},	//   plaa, _uthe_, zren, boia,
   {{0x7d160097,0xe0df1fc7,0xa3d2007c,0x6d441599}},	//   chys, ndò_, _हईं_, coia,
   {{0x656b0052,0xfd5602b5,0x4993006c,0x7d0d1fc8}},	//   _righ, _תשרי_, _چیئر, mkas,
   {{0x656b1fc9,0x2be0022e,0xe8df00cc,0x00000000}},	//   _sigh, निरा, _phồn_, --,
   {{0x996705a1,0xdb041fca,0x656b1fcb,0x25710124}},	//   _атал, quiá, _pigh, _ošle_,
   {{0x7d0d1fcc,0x257800b5,0x693c00cd,0x680a00ec}},	//   nkas, _dél_, včeg, _bēdā,
   {{0x63a91fcd,0x7d0d1fce,0x38351fcf,0x2c4a005f}},	//   uren, ikas, _снар, _gėdą_,
   {{0xe1f903ad,0x63a91fd0,0x2578006c,0x6d441fb7}},	//   его_, rren, _fél_, zoia,
   {{0x7d0d1b34,0x63a91fd1,0x656b1fd2,0x9afa00a5}},	//   kkas, sren, _tigh, תפתח,
   {{0x7d0d18b0,0x64550095,0x63a91fd3,0x656b1fd4}},	//   jkas, əzin, pren, _uigh,
   {{0x03a509a5,0x7d0d1fd5,0x00000000,0x00000000}},	//   _сило, dkas, --, --,
   {{0x75291fd6,0x69c400ab,0xfd6500e2,0x00000000}},	//   liez, _रहली, _truồ, --,
   {{0xc0e61fd7,0xdd1d00b8,0xdb040279,0xdca61fd8}},	//   _бойк, lářs, luiç, лави,
   {{0x7529018a,0x7d0d1fd9,0x7e7c0124,0x9f400176}},	//   niez, gkas, scrp, _triï_,
   {{0x0aea1fda,0x6eac0939,0xdb040279,0xdd1d00b8}},	// [16e0] ндай_, _जयपु, nuiç, nářs,
   {{0x7d0d0086,0x945d0035,0x6d4401a3,0x8a3a00c3}},	//   akas, leńs, soia, няет_,
   {{0x888601d3,0x7d16062c,0x80d70033,0x7d0d005f}},	//   глеж, phys, ধার্, bkas,
   {{0xc9550409,0x7d0d1fdb,0xdb041fdc,0x7aeb0228}},	//   атчы, ckas, rtiñ, ēgta,
   {{0xa3d21ea2,0x6ac900c8,0xdb041fdc,0x257800e0}},	//   _हैं_, রয়ো, stiñ, _sél_,
   {{0xdd1d00b8,0x3ce01fdd,0xda6600ce,0x00000000}},	//   dářs, ldiv_, _مازي, --,
   {{0x645d064b,0xceb30122,0x2d7802a7,0xe5c61fde}},	//   ýsin, ציה_, _očem_, усло,
   {{0x752901a3,0x3ce00553,0x25781fdf,0x00000000}},	//   giez, ndiv_, _vél_, --,
   {{0x28dd1fe0,0xdb040279,0x46b605bc,0xf3660c06}},	//   _नोटि, guiç, _محاس, лтон,
   {{0x39461fe1,0x25781fe2,0x9bbb02b5,0x81cd0033}},	//   loos_, _tél_, עציפ, রিন_,
   {{0xaac6142a,0x80de00c8,0x4ac60c67,0xd25000bf}},	//   र्यक, যান্, र्यव, تند_,
   {{0xdb040370,0x26de1fe3,0x75291fe4,0xdd1d0355}},	//   buiç, _hato_, ciez, bářs,
   {{0xa3b30299,0x7d0d1fe5,0x26de1fe6,0x09d10380}},	//   जूद_, vkas, _kato_, _सन्य,
   {{0x26de0fc5,0x4ac6022e,0x3dda02b1,0x39461fe7}},	//   _jato_, र्मव, _bspw_, hoos_,
   {{0xc27b0779,0x26de1fe8,0xdd950409,0x7d0d1fe9}},	//   _ארוי, _mato_, рабы, tkas,
   {{0xf1a9004e,0x26de1fea,0x629a1feb,0x25710ce9}},	//   _कितन, _lato_, lato, _ušle_,
   {{0x39461fec,0x212b1fed,0xaac6007e,0x00000000}},	// [16f0] doos_, mich_, र्भक, --,
   {{0x212b0446,0x7d0d1fee,0x00000000,0x00000000}},	//   lich_, skas, --, --,
   {{0x7d0d1fef,0x00000000,0x00000000,0x00000000}},	//   pkas, --, --, --,
   {{0x629a1ff0,0x212b01a6,0x00000000,0x00000000}},	//   hato, nich_, --, --,
   {{0x26de1ff1,0xbcfb1ff2,0x75291ff3,0xab5b0176}},	//   _bato_, _diét, viez, _aqüe,
   {{0x7ceb06d7,0xd6291a33,0x212b1ff4,0x945d004e}},	//   _förä, коле_, hich_, zeńs,
   {{0x212b006a,0x26de1ff5,0x629a1ff6,0xbcfb0042}},	//   kich_, _dato_, dato, _chég,
   {{0xdb040370,0x212b086d,0x81cd0033,0x2bac021a}},	//   tuiç, jich_, রিম_, _चिमा,
   {{0x212b1ff7,0x26de0370,0x75291ff8,0x80de0083}},	//   dich_, _fato_, riez, যাম্,
   {{0x032500d4,0x26de1ff9,0xa1c501c8,0x13090086}},	//   рдон, _gato_, абод, тной_,
   {{0xcb140052,0x75291ffa,0xe1f60043,0x00000000}},	//   מלץ_, piez, агэ_, --,
   {{0x26de1ffb,0x75ca01c2,0x212b1ffc,0x95670133}},	//   _zato_, _qəze, gich_, _създ,
   {{0x4ac602e4,0x248d1ffd,0x5edf0083,0x2fdb0024}},	//   र्डव, mbem_, মানে, _csqg_,
   {{0xb05b1788,0x91e50f08,0x39460042,0xf8d20026}},	//   pfän, _воке, zoos_, _सस्प,
   {{0xde0312b3,0x212b0260,0xb05b0f8e,0x78bb0124}},	//   опри, bich_, lfäl, _ocuv,
   {{0x212b016f,0xac86081b,0x39461ffe,0x4fea05a1}},	//   cich_, ргал, xoos_, _амин_,
   {{0x998d0470,0xac071fff,0x3ce02000,0xbea61e38}},	// [1700] _ćeš_, анта_, rdiv_, _капк,
   {{0x6d5d2001,0x8d7603fc,0xfaa60466,0xdb040421}},	//   _ehsa, _پادا, ражо, htiö,
   {{0xa2bd051d,0x26de1f3b,0xbcfb000d,0xa96a0036}},	//   _शान्, _rato_, _piét, вижа_,
   {{0x629a193d,0xfce60dfc,0x26de2002,0x497300d8}},	//   zato, _томо, _sato_, іліс,
   {{0x2d780009,0x39462003,0xa81a05bc,0x629a2004}},	//   _oček_, roos_, ختار_, yato,
   {{0x212b0223,0x3946006d,0x629a2005,0x38af0225}},	//   zich_, soos_, xato, törü_,
   {{0xfaa312f8,0x212b046a,0x26de023a,0xaac6164f}},	//   _фасо, yich_, _vato_, र्णक,
   {{0x629a2006,0xbcfb2007,0xb4e0012f,0xd9432008}},	//   wato, _hiér, दये_, _деси,
   {{0x26de01c0,0xaac60567,0x2fc001e8,0x539700d8}},	//   _tato_, र्थक, _nqig_, авыя_,
   {{0x68e02009,0x2904002f,0x64590067,0x00000000}},	//   _hamd, _homa_, _dzwi, --,
   {{0xbcfb200a,0x2904200b,0x212b200c,0x68e0200d}},	//   _miér, _koma_, tich_, _kamd,
   {{0x68e200da,0x4ac6175f,0x29040228,0x443d00fe}},	//   ndod, र्तव, _joma_, _fxw_,
   {{0x212b200e,0x2f14022a,0x2571200f,0xa3dc00a1}},	//   rich_, _säga_, _išla_, डिओ_,
   {{0x212b01a6,0x63a22010,0x29042011,0x69dc008b}},	//   sich_, _ivon, _loma_, _osre,
   {{0x2d850a45,0x4d2703e6,0xa3d20067,0x70950382}},	//   ële_, аќаа, हौर_, _лайф,
   {{0x2f140006,0x5c752012,0x29042013,0x629800c3}},	//   _väga_, слат, _noma_, _hevo,
   {{0x68e2001e,0xa3dc0518,0x5ecc0033,0x645c00a8}},	// [1710] ddod, डिट_, ায়ে, əric,
   {{0xf1da006a,0x629804c4,0xa3d70099,0xdce6013a}},	//   _बनान, _jevo, ाबत_, _vikā,
   {{0x29042014,0x25710124,0xceb20070,0xf8750079}},	//   _boma_, _ošla_, _ציט_, مهاج,
   {{0x29041a71,0x62982015,0xc8790ec4,0x68e02016}},	//   _coma_, _levo, _başa_, _camd,
   {{0x27e92017,0x29042018,0x68e000a7,0x80bc112b}},	//   ían_, _doma_, _damd, ष्टे,
   {{0x62982019,0x7bdd0052,0x81cd0083,0xc72401e0}},	//   _nevo, _issu, রিত_, одій,
   {{0x63a2201a,0xe7f3004e,0x212900bf,0x80de0033}},	//   _avon, _आपका_, _omah_, যাত্,
   {{0xce3802da,0x25a9201b,0xb05b1788,0xd5b80354}},	//   יאות_, čal_, tfäl, _इमरज,
   {{0x6298201c,0xa3d20299,0xb3820bbc,0x443d0118}},	//   _bevo, हौल_, плыл, _qxw_,
   {{0xf7700082,0xc2e90332,0xb05b0ed4,0x63a2201d}},	//   _قال_, اعظم_, rfäl, _dvon,
   {{0x7c3b00fb,0x395f006d,0x68e0012f,0x290400d7}},	//   _þurf, _khus_, _yamd, _yoma_,
   {{0x443d006d,0x628e0093,0x7bdd0103,0xc8790457}},	//   _txw_, ðbor, _ossu, _yaşa_,
   {{0xe28e0896,0x43850514,0x638503fa,0x21290176}},	//   _на_, _التق, _угла, _dmah_,
   {{0x6298201e,0xe7fa00a1,0xe299201f,0x61ea0156}},	//   _gevo, ्हता_, _сак_, _frfl,
   {{0x63a215b5,0x7bdd2020,0xa3b30591,0xfc3f0176}},	//   _zvon, _assu, जूर_, _axí_,
   {{0x31a3036a,0x62810814,0x61432021,0x2bac012f}},	//   mız_, lclo, _неща, _चिदा,
   {{0x29042022,0xed5700c9,0x68e00dc3,0x75ca00a8}},	// [1720] _roma_, сот_, _ramd, _məza,
   {{0x62812023,0x290416a7,0x68e00c53,0x394d0118}},	//   nclo, _soma_, _samd, _akes_,
   {{0x31a32024,0x5886010b,0x7bdd09d6,0x395f006b}},	//   nız_, была, _essu, _bhus_,
   {{0x75ca0095,0x61fc0301,0xc879033e,0xc8b60037}},	//   _nəza, ärli, _paşa_, إصاب,
   {{0xe1e70ef5,0x68e22025,0x765a2026,0x69dc009e}},	//   _کس_, rdod, _szty, _wsre,
   {{0x27e613b8,0x997600af,0xdb040138,0x612f021e}},	//   rvon_, _гуаш, briá, _kòlè,
   {{0x63a200fb,0x29040995,0x6d4100fb,0x69dc03fd}},	//   _svon, _toma_, élag, _usre,
   {{0x75ca0095,0x7d062027,0x186a2028,0x7644027d}},	//   _cəza, _joks, _баби_, şiyo,
   {{0x7d0601c8,0x5edf0033,0x68fd0211,0x00000000}},	//   _moks, মাতে, _òsda, --,
   {{0x62812029,0x7d06202a,0xfc3f002a,0xaab301c0}},	//   gclo, _loks, _odín_, ुभएक,
   {{0x60f9019b,0x14ca03ad,0x2d9e000d,0x8afb1804}},	//   ання_, _были_, âtel_, אליז,
   {{0x63a2202b,0x7d0601e0,0x657a0211,0x00000000}},	//   _tvon, _noks, _iuth, --,
   {{0x25710254,0x6298202c,0x321e0035,0x4ad80775}},	//   _ušla_, _tevo, szty_, ड़ाव,
   {{0x657a104d,0x543b02b5,0x31a30381,0x612f021e}},	//   _kuth, _געדא, bız_, _bòlè,
   {{0x918618dd,0x7d06202d,0x98bd0067,0x00000000}},	//   _اجتم, _boks, lową_, --,
   {{0x5d55093e,0x212900e0,0x00000000,0x00000000}},	//   ікат, _umah_, --, --,
   {{0x657a202e,0x2d5808a6,0x2d9e202f,0x60cd2030}},	// [1730] _luth, сить_, áter_, _ibam,
   {{0x657a0282,0x2dd52031,0x67380009,0x3f89021d}},	//   _outh, _джор, jnvj, _itau_,
   {{0x395f006d,0x5edf0083,0x657a0118,0x2d9e02f6}},	//   _phus_, মাদে, _nuth, šter_,
   {{0xfbd000b5,0xa3e80026,0x26cc00f6,0x7644027d}},	//   بتہ_, मटा_, _abdo_, ğiyl,
   {{0x657a0052,0x7bc42032,0x2b930a86,0x628104f4}},	//   _auth, ctiu, _ریاس, yclo,
   {{0x6b8d2033,0x657a2034,0x31a300d0,0xa2ca01d1}},	//   mpag, _buth, yız_, त्म्,
   {{0x6b8d2035,0x45192036,0x657a0211,0xceb40100}},	//   lpag, иция_, _cuth, ליס_,
   {{0x69c52037,0x6b8d2038,0x657a2039,0x75ca0095}},	//   mthe, opag, _duth, _qəza,
   {{0x3f890d4b,0x69c5203a,0x4ac60d34,0x6b8d203b}},	//   _ntau_, lthe, र्वव, npag,
   {{0x69c5203c,0x60cd203d,0x693c05cd,0x6b8d203e}},	//   othe, _abam, nčen, ipag,
   {{0x3f89203f,0x657a2040,0x69c52041,0x7ae5006b}},	//   _atau_, _guth, nthe, idht,
   {{0x69c50a24,0xe56e0a55,0x27ed00d7,0x25712042}},	//   ithe, _із_, _kren_, _išlo_,
   {{0x31a306d3,0x69c52043,0xb05b02b1,0x62830065}},	//   sız_, hthe, nfäh, _tfno,
   {{0xe3b00a42,0x6b8d2044,0x249f2045,0x69c52046}},	//   _سره_, dpag, laum_, kthe,
   {{0x78a92047,0x693c0187,0xec9a0279,0x6b8d0223}},	//   _odev, dčen, итај_, epag,
   {{0x27ed2048,0xa01b2049,0x311e0096,0x2d7800cd}},	//   _oren_, rbör, _पतिः_, _očev_,
   {{0x8e76002d,0x6b8d204a,0xdee6204b,0x7d060909}},	// [1740] _мунч, gpag, _допи, _voks,
   {{0x249f0189,0x78a90012,0xab5b033b,0xfc3f01f7}},	//   haum_, _adev, _spür, _idíl_,
   {{0x7bc4204c,0xed5a204d,0xe9da204e,0x69c5204f}},	//   stiu, _вон_, рке_, gthe,
   {{0x6b8d2050,0x7bc42051,0x27ed00e5,0x7c3b03c9}},	//   bpag, ptiu, _bren_, _žure,
   {{0x2ca02052,0x657a2053,0x27ed0042,0xc7a3083e}},	//   maid_, _suth, _cren_, дичк,
   {{0x657a2054,0x6d562055,0x4ac61604,0xfdfe0456}},	//   _puth, llya, र्शव, _उपास_,
   {{0x27ed2056,0xd5b0004f,0x69c52057,0x25dd0127}},	//   _eren_, رفة_, cthe, _कैदी_,
   {{0x291d2058,0x4ac60f09,0x2ca02059,0x98bd0035}},	//   chwa_, र्रव, naid_, tową_,
   {{0xdddc011c,0x657a0118,0x27ed205a,0x2be00099}},	//   jbrž, _wuth, _gren_, निटा,
   {{0xbcfb004f,0x657a205b,0x78a900ac,0xa3cb205c}},	//   _mhéa, _tuth, _zdev, _लहर_,
   {{0x3f89002d,0x2ca000ab,0x249f205d,0xdcfc010b}},	//   _stau_, kaid_, baum_, sprę,
   {{0x645c0669,0x2ca0007c,0x00000000,0x00000000}},	//   ərin, jaid_, --, --,
   {{0xc05b0044,0xb4b61db9,0x5f940382,0xa2e61f39}},	//   рін_, जली_, мият, _модд,
   {{0xf6510332,0xa3d70c57,0x764d013b,0xc44400fd}},	//   _آئے_, ाबर_, şaye, _ویژن_,
   {{0x6b8d205e,0x69c5205f,0xf1c300b8,0x693c15ce}},	//   wpag, xthe, _vaší_, včen,
   {{0x6b8d0051,0xbcfb0037,0x2ca02060,0x81cd0033}},	//   tpag, _bhéa, gaid_, রিশ_,
   {{0xbcfb0082,0x7c3b012e,0x0ca801d3,0x6b8d2061}},	// [1750] _chéa, _žurb, ютри_, upag,
   {{0xbcfb0514,0x6b8d2062,0x81cd0083,0x249f006d}},	//   _dhéa, rpag, রির_, zaum_,
   {{0xa2bd0e1d,0x69c52063,0x13d30083,0x291d0345}},	//   _शास्, uthe, ়িয়, thwa_,
   {{0xa2ca2064,0xbcfb0082,0x2ca02065,0x69c52066}},	//   त्त्, _fhéa, caid_, rthe,
   {{0x6cfa00a5,0x693c201d,0xbcfb0079,0x27ed0183}},	//   _הפרס, pčen, _ghéa, _qren_,
   {{0x291d2067,0x65620371,0xb05b02b1,0x00000000}},	//   shwa_, _ahoh, rfäh, --,
   {{0x6ecd09b1,0xb05b033b,0x00000000,0x00000000}},	//   द्यु, sfäh, --, --,
   {{0xdb040279,0xd4d900d4,0x2e3c0070,0xa3d70bad}},	//   triç, ські_, יגונ, ाबल_,
   {{0x249f0938,0x6562022e,0x27ed2068,0xe3b1004f}},	//   raum_, _dhoh, _uren_, ررة_,
   {{0x249f01e8,0x00000000,0x00000000,0x00000000}},	//   saum_, --, --, --,
   {{0xdb0d0f56,0x06760070,0x257100f4,0x6562009e}},	//   ntañ, _זײער_, _ušlo_, _fhoh,
   {{0xdb0d2069,0x00000000,0x00000000,0x00000000}},	//   kraï, --, --, --,
   {{0x2ca0007c,0x20561eb9,0x2458010b,0x645d00be}},	//   vaid_, ятор, _даць_, üsid,
   {{0xb4d60066,0xd34300b5,0x6569206a,0x00000000}},	//   ाड़ी_, _تفتی, lmeh, --,
   {{0x551f0311,0xdb0d0248,0xbcfb0079,0x12fa00a5}},	//   _बताए_, traî, _shéa, _להסב,
   {{0x753b027a,0xec7a0ecf,0x3b8605e8,0x6569206b}},	//   nnuz, спа_, злаг, nmeh,
   {{0x25dd05e7,0x6d56010d,0x1d07206c,0x2ca0206d}},	// [1760] _कैसी_, rlya, чети_, raid_,
   {{0x2ca00d8e,0x6b5001ff,0xdb1c027b,0x00000000}},	//   said_, vägs, _üzüm, --,
   {{0x6d561a22,0x7e7b00a5,0x49ca1052,0x1e9700a5}},	//   plya, _לאיז, слен_, _מכיל_,
   {{0xbcfb004f,0x203300b5,0x00000000,0x00000000}},	//   _théa, _آفیس, --, --,
   {{0x80ce03de,0xdb04053e,0x24c30033,0x5edf0831}},	//   ध्ये, nsië, ্যাহ, মারে,
   {{0x656200da,0xdbc700ab,0x7d04206e,0xa9a6206f}},	//   _shoh, tööt, ljis, _нигд,
   {{0xdb04013c,0x7c24002d,0xc1da0035,0x9f4003bc}},	//   rriä, lzir, _बनेग, _asië_,
   {{0xb4d6065a,0xdce403fa,0x48e32070,0x7d042071}},	//   ाजे_, kmič, _посв, njis,
   {{0x7c242072,0xd9431362,0xa2bd0253,0xa3b30246}},	//   nzir, _чети, _शाश्, जंग_,
   {{0x645c01c2,0xdb0d0093,0x98bd0035,0xdce42073}},	//   əril, ntað, dowę_, dmič,
   {{0x867501c8,0x65622074,0xa2bd2075,0x00000000}},	//   _жыцц, _thoh, _शार्, --,
   {{0x2d5701d6,0x78a2023c,0x7aeb00ea,0x3a3700a5}},	//   rçek_, naov, ēgti, לרים_,
   {{0x50642076,0x75ca00a8,0xf4871328,0xdb0d003e}},	//   етра, _məzm, _رانی, ktað,
   {{0x7c242077,0x70770416,0xbcfb00f6,0x00000000}},	//   dzir, _کاغذ, _chén, --,
   {{0x97570d85,0x00000000,0x00000000,0x00000000}},	//   פילו_, --, --, --,
   {{0x7d0401d2,0x9f49021d,0x3a3f00f4,0x9ce400af}},	//   gjis, _iraí_, _ćup_, нцул,
   {{0xdb0d0132,0x6f0100b5,0x693c080a,0x00000000}},	// [1770] nuaç, ölcs, rčel, --,
   {{0x501c00a5,0xdb0d01f7,0x00000000,0x00000000}},	//   _לוחו, rraï, --, --,
   {{0xceb20779,0xdb040248,0x89d9103b,0x99d906ee}},	//   _ביי_, isiè, توار_, تواء_,
   {{0xb4d60387,0x7d161ae2,0xdb0d0079,0x7c2400cd}},	//   ाजो_, ckys, mraí, bzir,
   {{0xdb0d2078,0x66e52079,0xa8780079,0xdce60207}},	//   stañ, дола, أحمر_, _sikć,
   {{0xdb0d03e6,0x8ae402ce,0x3ea3207a,0x3ce900ab}},	//   duaç, _післ, najt_, ldav_,
   {{0xdb0d0037,0xdce40121,0x2d7802a7,0x2d860207}},	//   nraí, zmič, _hčer_, _čoek_,
   {{0xa2ca0b35,0xfdf80122,0x7ae7207b,0x3ce900ab}},	//   त्स्, לצות_, _hajt, ndav_,
   {{0x04770332,0x6569207c,0x7ae7008b,0xdb0d0fe0}},	//   _ہلاک_, rmeh, _kajt, guaç,
   {{0x394f0029,0x6569207d,0xdb1602d7,0x81d60033}},	//   logs_, smeh, tuyé, সিন_,
   {{0xf74801b2,0x7ae7207e,0x645c0095,0x7d1d207f}},	//   _علمي_, _majt, ərim, _olss,
   {{0xcea901f3,0x7ae72080,0x8fa6031a,0xdce405e2}},	//   _כי_, _lajt, маме, tmič,
   {{0xbcfb0248,0xd9aa051d,0x25a000cd,0xdb0d021d}},	//   _phén, _चट्ट, ćile_, cuaç,
   {{0x69d50120,0xdce41bd8,0x7d1d008c,0x3cf908c8}},	//   _opze, rmič, _alss, _ansv_,
   {{0xdb0d0082,0x63bb0447,0xdce41977,0xc1060037}},	//   graí, luun, smič, _يوتي,
   {{0x7c2401d7,0x2f1400be,0x00000000,0x00000000}},	//   tzir, _mägi_, --, --,
   {{0x63bb2081,0x3ce60038,0x7d042082,0xdb0d008d}},	// [1780] nuun, ľov_, rjis, ttað,
   {{0x3ce601ba,0xd9100df3,0x6ecd021a,0x7ae72083}},	//   žov_, گیر_, द्दु, _cajt,
   {{0x7ae72084,0x3ce901a2,0x78a21b99,0x6e4618c4}},	//   _dajt, bdav_, taov, _ценз,
   {{0xdb0d008a,0x63bb2085,0xd9100416,0xd056013b}},	//   stað, kuun, دیر_, _sayə,
   {{0x87da2086,0x98a30d17,0x97da2087,0x31da2088}},	//   تباس_, тиче, تظار_, _बन्ध,
   {{0x63bb2089,0x7ae7208a,0x66e30274,0x758a208b}},	//   duun, _gajt, воља, осив_,
   {{0x60c4025c,0x6b840069,0x693c208c,0x2d7802c4}},	//   _ocim, lqig, nček, _učes_,
   {{0xdb0d0370,0x7ae701fe,0x60c40009,0x38ca006c}},	//   tuaç, _zajt, _ncim, _گاڑی_,
   {{0x7ae7006d,0x33740d6e,0x693c0355,0x63bb208d}},	//   _yajt, нгир, yčej, guun,
   {{0x60c40370,0x764d0463,0x59d213ab,0x1bfb0070}},	//   _acim, şaya, _सहार, קליב,
   {{0xe1350d36,0xdb04208e,0x3ea304c4,0x26dc0036}},	//   енны, friú, vajt_, mevo_,
   {{0x26dc208f,0x92be0083,0xdb0400f7,0x63bb001c}},	//   levo_, ঁজে_, ssiè, buun,
   {{0x78a02090,0xdb0d0279,0xc178010b,0x2eca0096}},	//   _memv, quaç, tvės_, िभूत,
   {{0xdef8081b,0x26dc2091,0x78a008c8,0x81d60033}},	//   мыс_, nevo_, _lemv, সিব_,
   {{0x7ae72092,0x3ea32093,0xdb040037,0x628a007a}},	//   _rajt, rajt_, briú, _iffo,
   {{0x7ae72094,0xa2ca2095,0xdb0d2096,0x3ea32097}},	//   _sajt, त्र्, rraí, sajt_,
   {{0x7ae72098,0x60dd01bf,0x3f800176,0xc179010b}},	// [1790] _pajt, mesm, _guiu_, svės_,
   {{0x26dc0690,0x60dd2099,0xbcfb0248,0xc879002d}},	//   jevo_, lesm, _théo, _iaşi_,
   {{0x7ae7209a,0x26dc209b,0x79e700b5,0x394f017b}},	//   _vajt, devo_, بوضہ_, togs_,
   {{0x25f4209c,0x60dd209d,0x25610093,0xbb1b0139}},	//   ्मनी_, nesm, kóla_, _atît,
   {{0x628a209e,0x06e80033,0x394f209f,0x00000000}},	//   _offo, পানি, rogs_, --,
   {{0x2571200f,0x7c200225,0x2d78023a,0x00000000}},	//   _išli_, _ümra, _učer_, --,
   {{0x60dd20a0,0x2d8120a1,0x9f40009e,0xc8790139}},	//   kesm, _juhe_, _criù_, _laşi_,
   {{0x63bb20a2,0xfba320a3,0x3ea120a4,0x2d8120a5}},	//   tuun, _ओबाम, _leht_, _muhe_,
   {{0x2fc9006d,0x36d520a6,0x4ac600b4,0xf7780024}},	//   _nqag_, _поар, र्कव, _fiħ_,
   {{0x291f0221,0x60c420a7,0x26dc0382,0x63bb20a8}},	//   _hlua_, _scim, cevo_, ruun,
   {{0x68fb20a9,0x68e91d11,0x63bb20aa,0x00000000}},	//   _knud, _kaed, suun, --,
   {{0xaacf20ab,0x4acf157d,0x60dd2063,0x628a20ac}},	//   स्तक, स्तव, gesm, _effo,
   {{0x7c3b20ad,0x653a02b5,0xbcfb00a0,0x80c10e96}},	//   _žurn, _צענד, _chém, _वारे,
   {{0x63a920ae,0xfd1f027a,0xe7f020af,0x2d8120b0}},	//   msen, _alì_, चिता_, _buhe_,
   {{0x63a91e54,0x523902b5,0x60dd20b1,0x68fb20b2}},	//   lsen, _מײַנ, besm, _onud,
   {{0xfce30f9e,0x693c016f,0x1d0705a1,0x2d8120b3}},	//   лосо, rček, неси_, _duhe_,
   {{0x63a9190f,0x6b4b00b5,0xab6620b4,0x78a00051}},	// [17a0] nsen, lügy, евал, _remv,
   {{0x3ea102bf,0x63a920b5,0x291f0065,0x68fb0103}},	//   _geht_, isen, _alua_, _anud,
   {{0x81cd0083,0x26dc07e5,0x25710009,0x78a000d7}},	//   রিক_, vevo_, _ešli_, _pemv,
   {{0xc7c620b6,0x63a920b7,0x80de0083,0x291f01f7}},	//   ески, ksen, যাক্, _clua_,
   {{0x26dc20b8,0x63a920b9,0xb05b01ff,0x64591766}},	//   tevo_, jsen, lfär, _nywi,
   {{0x63a901b4,0x290d0107,0x81d60033,0x75ca013b}},	//   dsen, _eoea_, সিত_, _həzi,
   {{0xd91007e4,0x26dc20ba,0x68e9104e,0x78a0008b}},	//   _پیش_, revo_, _faed, _temv,
   {{0xd90d04cd,0x44f40836,0xdb0401ef,0x68e920bb}},	//   _ویل_, тпис, muiñ, _gaed,
   {{0x645920bc,0x26dc0382,0x63a920bd,0x394701ef}},	//   _cywi, pevo_, gsen, énse_,
   {{0x2120005d,0x2f1400be,0x9f40009e,0x00000000}},	//   _alih_, _kägu_, _triù_, --,
   {{0x2258054e,0x75d3017e,0x60dd20be,0x63a920bf}},	//   ærk_, _ميلا, tesm, asen,
   {{0x2d8120c0,0x3ea102b1,0xaac720c1,0xc8790160}},	//   _ruhe_, _seht_, _लाभक, _saşi_,
   {{0x60dd20c2,0x645900e9,0x2d811a08,0x777a01ed}},	//   resm, _gywi, _suhe_, _kitx,
   {{0xb05b01ff,0x60dd0c2c,0x00000000,0x00000000}},	//   ffär, sesm, --, --,
   {{0xa01b006c,0x777a01a3,0x2ca20107,0x1df81ac5}},	//   nböz, _mitx, _bekd_, неры_,
   {{0x81cd0083,0xbcfb0248,0x2d8c1dad,0x212008b7}},	//   রিখ_, _thém, ídea_, _glih_,
   {{0x80de0033,0xfe7000b5,0x5c750382,0x7ff70079}},	// [17b0] যাখ্, لدہ_, тлат, _أسعا,
   {{0x79a720c3,0x2120011c,0xbb1b0160,0x291f0079}},	//   ерде, _zlih_, _atîr, _slua_,
   {{0xc3330122,0x291f01e8,0x290d0159,0xdb041e6e}},	//   נוע_, _plua_, _poea_, guiñ,
   {{0x6ecd009a,0x9f52021e,0x777a0065,0x63a920c4}},	//   द्रु, _aryè_, _aitx, ysen,
   {{0x672301f4,0x777a06a2,0x25710254,0x7afc009e}},	//   thnj, _bitx, _ušli_, _fnrt,
   {{0x7bcd20c5,0x61260093,0x45d50f8c,0x765a20c6}},	//   mtau, _gólf, вцит, _byty,
   {{0x7d0f00b5,0x7bcd20c7,0xb8950037,0x5a4400af}},	//   _kocs, ltau, _للأع, _бэта,
   {{0x63a920c8,0x672301f4,0x645901ef,0x68fb00a8}},	//   tsen, shnj, _pywi, _unud,
   {{0x777a20c9,0x49440d8a,0xab5b1eae,0xa775021d}},	//   _fitx, _сэрб, _aqüi, _алач,
   {{0x765a01f4,0x7d0f20ca,0x777a01d7,0x00000000}},	//   _fyty, _locs, _gitx, --,
   {{0x63a920cb,0x64590035,0x7bcd00c3,0x31690069}},	//   ssen, _wywi, htau, _bhaz_,
   {{0x63a920cc,0xa2bd1f57,0x7bcd0110,0x777a0065}},	//   psen, _शाक्, ktau, _zitx,
   {{0xa3e509a3,0x61e1001e,0x7bcd0009,0xab5b0183}},	//   _पनि_, swll, jtau, _eqüi,
   {{0x81bc00ea,0x7bcd20cd,0x777a0176,0xb46401e0}},	//   izēj, dtau, _xitx, _скіл,
   {{0xed5a20ce,0x7d0f20cf,0x2d9e20d0,0xb14620d1}},	//   дов_, _bocs, ète_, _инкл,
   {{0xed4320d2,0x693c0169,0xb05b0301,0x3169009f}},	//   ансп, lčev, rfär, _ghaz_,
   {{0xed57051b,0x75ca01c2,0xb05b038e,0xac830036}},	// [17c0] тот_, _vəzi, sfär, ргул,
   {{0x693c0496,0x81bc0029,0x387f01d7,0xdcef0395}},	//   nčev, dzēj, _agur_, _pică,
   {{0x18a620d3,0x7d0f20d4,0xb05b20d5,0x777a0065}},	//   ваем, _focs, ngän, _ritx,
   {{0x693c0009,0x672120d6,0xdcfe20d7,0x00000000}},	//   hčev, _allj, _kupč, --,
   {{0x2ba920d8,0xc0ad0070,0x765a0421,0x693c030a}},	//   _चौपा, ליאָ, _syty, kčev,
   {{0xcf9300c2,0x693c02f6,0x387f01b7,0xdcef0139}},	//   סטו_, jčev, _egur_, _tică,
   {{0x644e0095,0x19b900c3,0x777a0176,0xdb0420d9}},	//   əbiy, _путь_, _vitx, quiñ,
   {{0x291c00ea,0x765a00ac,0xaa4318e8,0x00000000}},	//   īvas_, _vyty, _тесл, --,
   {{0xf3660c4c,0x9f4000fe,0x00000000,0x00000000}},	//   ктон, _asií_, --, --,
   {{0x5186151c,0xd76400d1,0x81d60033,0x764d00b5}},	//   кума, _صنای, সিস_, ényé,
   {{0x69130723,0xaad40f9c,0x54c600af,0x6d4600f4}},	//   _içer, ठ्यक, _абеб, _ojka,
   {{0x7bcd010b,0xf48320da,0x00000000,0x00000000}},	//   ytau, _кушн, --, --,
   {{0x693c0a66,0x69c400b4,0xc05801e0,0x7d0f20db}},	//   bčev, ांडी, вір_, _rocs,
   {{0xdcfe0009,0x82330416,0x81cd0033,0xdb23027d}},	//   _dupč, اریا, রিজ_, örün,
   {{0xd37b1804,0x98ad20dc,0x00000000,0x00000000}},	//   _קרוט, _smeč_, --, --,
   {{0x7bcd0086,0xaac60d91,0xdb21027d,0x00000000}},	//   ttau, र्घक, ştür, --,
   {{0x2d5803ad,0x8aa703f5,0x213920dd,0x7bcd0024}},	// [17d0] тить_, вред, mish_, utau,
   {{0xd5a407a8,0x7bcd20de,0xdd110029,0xbcfb0037}},	//   _وہ_, rtau, _kļūd, _mhéi,
   {{0x7bcd20df,0x9f4901d6,0x6d4000f4,0xdcfe00cd}},	//   stau, _araç_, čmar, _zupč,
   {{0x213920e0,0x99d40118,0x9f490392,0x7bcd20e1}},	//   nish_, شتما, _braç_, ptau,
   {{0x2ca900ab,0x75ca00a8,0x2b58008c,0x8c67010b}},	//   maad_, _məzu, _fkrc_, _штод,
   {{0xd2460037,0x2ca91153,0x213920e2,0x366920e3}},	//   _هن_, laad_, hish_, нало_,
   {{0xa4930609,0x693c0169,0x442901ba,0x752220e4}},	//   لیات, včev, _ťa_, _bloz,
   {{0x2ca920e5,0xa3e918e0,0xdb0d0279,0x13e90fa7}},	//   naad_, едиа_, fraç, емий_,
   {{0xbcfb0082,0xdb0d0370,0x291d20e6,0x67380124}},	//   _chéi, graç, mkwa_, bivj,
   {{0x2ca920e7,0x201920e8,0xdcfe0124,0xbcfb0079}},	//   haad_, dysi_, _rupč, _dhéi,
   {{0xc69200c2,0xa0a60de3,0x693c129f,0xbbd001c0}},	//   _האב_, ланд, rčev, _सङ्क,
   {{0x85040118,0xbcfb004f,0xdb0d0279,0xb05b033b}},	//   _پوهن, _fhéi, braç, rgän,
   {{0x2ca90298,0x693c0121,0xf53901ba,0xbcfb0079}},	//   daad_, pčev, miť_, _ghéi,
   {{0xf539016f,0x248d20e9,0x752220ea,0x343a0070}},	//   liť_, lcem_, _zloz, _אײנע,
   {{0x63bb0029,0x2f1401ff,0xa30a00b5,0x715a0b25}},	//   lrun, _sägs_, _سروے_, _прис_,
   {{0x248d20eb,0xf539016f,0x693c0690,0x673820ec}},	//   ncem_, niť_, nčet, zivj,
   {{0xb7be00c8,0x6126171c,0x2d9301d7,0x63bb20ed}},	// [17e0] _ইন্ট, _cóle, _etxe_, nrun,
   {{0x81d60083,0x4f9b025a,0x00000000,0x00000000}},	//   সির_, _רביצ, --, --,
   {{0x63bb02bf,0x2ca91505,0x991603d0,0xeb75010b}},	//   hrun, baad_, льді, рытэ,
   {{0xf53901ba,0xb95a0037,0x248d20ee,0x63a4027b}},	//   jiť_, رجاء_, jcem_, _çing,
   {{0x6d4420ef,0xf539016f,0xb8dc0e68,0x645d00ab}},	//   mnia, diť_, _आय_, üsil,
   {{0x6d441647,0x21390031,0x63bb20f0,0x752220f1}},	//   lnia, zish_, drun, _sloz,
   {{0x63bb02c9,0x25a0011c,0x6d4400be,0xbcfb0098}},	//   erun, ćilo_, onia, _shéi,
   {{0x6d4420f2,0x6d5620f3,0xdb0d0279,0x7aee009f}},	//   nnia, noya, traç, _habt,
   {{0x63bb20f4,0xd90d0332,0x7aee043d,0x6d4420f5}},	//   grun, _تین_, _kabt, inia,
   {{0x6d560a2d,0xdb0d0279,0x6fdf0380,0x254c00b8}},	//   hoya, rraç, _पैगं, děle_,
   {{0x2d980274,0x6d5620f6,0xf539016f,0x2ca9034d}},	//   jpre_, koya, biť_, yaad_,
   {{0x46131a95,0x63bb20f7,0x6d44006f,0x752200cd}},	//   _دومر, brun, jnia, _uloz,
   {{0x63bb20f8,0x213920f9,0x6d441cca,0x29370070}},	//   crun, rish_, dnia, ראכן_,
   {{0x69dc20fa,0x2ca901bf,0xa29401c8,0x7aee01e8}},	//   _opre, waad_, _такі, _nabt,
   {{0x693c0df4,0x6d44001e,0x65600037,0x213901e9}},	//   nčes, fnia, olmh, pish_,
   {{0x6d5620fb,0x6ed609b4,0x6d4420fc,0x213901e9}},	//   goya, म्बु, gnia, qish_,
   {{0x69dc20fd,0x2ca917ff,0x81c60033,0x69ce035f}},	// [17f0] _apre, raad_, _উনি_, _aqbe,
   {{0xf539016f,0x2ca920fe,0x63a220ff,0x6d440d98}},	//   ziť_, saad_, _mwon, ania,
   {{0x6d442100,0x7aee0189,0x6d56011e,0x13c1164f}},	//   bnia, _dabt, boya, _शम्भ,
   {{0x2ba90324,0x57f52101,0x6d440035,0x9f4002d7}},	//   _चौथा, ипет, cnia, _frió_,
   {{0xf5390038,0x69dc2102,0x6b860118,0x00000000}},	//   viť_, _epre, _gukg, --,
   {{0x7d0d2103,0xc5f90083,0x291d0ed1,0xdb231a95}},	//   ljas, _অথবা_, skwa_, _اوسی,
   {{0xf539016f,0x63a22104,0x80ab0083,0x2ba90761}},	//   tiť_, _awon, _কান্, _चौता,
   {{0x63bb2105,0x7d0d2106,0xdb04069c,0x63a22107}},	//   trun, njas, brió, _bwon,
   {{0x7c2d2108,0xf576004f,0xf539016f,0x61f80282}},	//   nzar, جميع_, riť_, _arvl,
   {{0x63bb2109,0xc6a40370,0xadf7210a,0x248d210b}},	//   rrun, _грци, ुमान_, scem_,
   {{0x6d440297,0x248d210c,0xf539016f,0x6d560054}},	//   ynia, pcem_, piť_, yoya,
   {{0x63bb210d,0x7bdd008c,0x63a202d0,0x61f800f4}},	//   prun, _opsu, _fwon, _drvl,
   {{0xe28e210e,0x53a5210f,0xa6e80083,0x6d562110}},	//   _ма_, _талб, পারট, voya,
   {{0x26c72111,0x6d442112,0x08760070,0x753b2113}},	//   ngno_, wnia, יערט_, liuz,
   {{0x7aee003c,0x442d2114,0x7bdd2115,0xada601db}},	//   _rabt, lze_, _apsu, рабл,
   {{0x7aee20fb,0xef862116,0x06af0033,0x27e60090}},	//   _sabt, _клип, চ্চি, ywon_,

   {{0x2d9809eb,0x6d442117,0xafe61a1c,0x442d16a3}},	// [1800] spre_, rnia, _топл, nze_,
   {{0x25610093,0x69dc2118,0x693c00ac,0x7d0d2119}},	//   fólk_, _ppre, jčer, ajas,
   {{0x6d56211a,0x09e603fe,0xfc3f00de,0x7c2d01ef}},	//   poya, роен, _veía_, azar,
   {{0xe3a7211b,0x442d1b66,0x2900188a,0x753b0054}},	//   _ور_, kze_, ñia_, jiuz,
   {{0x7aee211c,0x442d211d,0x06af0083,0x7c2d0067}},	//   _tabt, jze_, চ্ছি, czar,
   {{0x442d211e,0xdb040300,0x501b0d85,0x699601e0}},	//   dze_, rrió, כונו, _врах,
   {{0xe1e7211f,0x69dc2120,0xf526019e,0xceb300a5}},	//   _بس_, _upre, ифин, קיה_,
   {{0x62832121,0x7c3b011c,0x63a202d0,0x75292122}},	//   _agno, _žuri, _pwon, ghez,
   {{0x39460f56,0x430601e0,0x5346126e,0x00000000}},	//   mnos_, аїна, ихоа, --,
   {{0xf3662123,0x394600e1,0x00000000,0x00000000}},	//   јтин, lnos_, --, --,
   {{0x79801cf5,0x26cc046a,0x442d030d,0x7c2d0a1f}},	//   _kimw, _icdo_, aze_, zzar,
   {{0x75290657,0x63a22124,0xd2571ca4,0x39462125}},	//   chez, _twon, рць_, nnos_,
   {{0x442d0755,0x63a22126,0x39462127,0x25a900cd}},	//   cze_, _uwon, inos_, ćale_,
   {{0xdced0076,0x6d482128,0x394600e9,0xd4670274}},	//   rmač, édan, hnos_, _тиче_,
   {{0x28d71f57,0xeca70798,0x6233021d,0x7d0d2129}},	//   ण्डि, ијан, _мешу, tjas,
   {{0x7c2d212a,0xc27b02b5,0x3946006c,0xdb0420d9}},	//   tzar, _ברוי, jnos_, driñ,
   {{0x7d0d212b,0x29e80043,0x67da00ea,0x7bc4212c}},	// [1810] rjas, _aşa_, nājā, guiu,
   {{0x7c2d212d,0x39460a09,0x6aa70031,0x7d0d212e}},	//   rzar, enos_, _qejf, sjas,
   {{0x442d212f,0x2b4a022e,0x79800010,0x7c2d2130}},	//   zze_, _djbc_, _bimw, szar,
   {{0x39462131,0x645d00ab,0x7980099e,0x00000000}},	//   gnos_, üsik, _cimw, --,
   {{0x6126008a,0x6d5d0430,0xa91d011c,0x79800260}},	//   _jóla, _iksa, _niže, _dimw,
   {{0x39462132,0xdb0401dd,0x6d5d011e,0x66e52133}},	//   anos_, briñ, _hksa, сока,
   {{0x60cd2134,0x3f890160,0x7afa0093,0xa3a92135}},	//   _ocam, _luau_, _ótta, गीन_,
   {{0x442d2136,0x7ae50f67,0x69c52137,0x22490124}},	//   tze_, leht, muhe, _ćak_,
   {{0xc95202da,0x442d2138,0xf79400d8,0x3d081b8f}},	//   _זמן_, uze_, _матэ, हाते_,
   {{0x442d0632,0x78a92139,0xa91d213a,0x798001d5}},	//   rze_, _heev, _diže, _zimw,
   {{0x442d213b,0x568c0070,0x75290110,0x78a900be}},	//   sze_, _סטאַ, phez, _keev,
   {{0x2d6802c9,0x6126213c,0x7ae501f4,0x614600af}},	//   eßen_, _bóla, heht, сема,
   {{0x78a9213d,0x3f810027,0x69c5213e,0x00000000}},	//   _meev, _bihu_, huhe, --,
   {{0x6d5d213f,0x539a0122,0x61262140,0x39462141}},	//   _aksa, _עיצו, _dóla, znos_,
   {{0xe16400d1,0xfbdf021d,0x853c00c7,0x394600c7}},	//   _وضعی, _apê_, _kvėp, ynos_,
   {{0x2ba90084,0x4c862142,0x61362143,0x60cd0098}},	//   _चौहा, слав, kšli, _gcam,
   {{0x79800010,0xf3880023,0xdb040132,0x3f891c5b}},	// [1820] _rimw, _lợn_, nsiç, _guau_,
   {{0xf1db0f39,0xdb0403e6,0x6ac6004f,0x79802144}},	//   _बहान, isiç, إقام, _simw,
   {{0x1efb02b5,0x27ed021e,0x69c52145,0x78a92146}},	//   _עלטע, _asen_, guhe, _beev,
   {{0x78a90221,0x1d0a2147,0xdb042148,0xbcfb2149}},	//   _ceev, _семи_, rriñ, _dhés,
   {{0x39462140,0x7bc41228,0xaab80609,0x27ed0036}},	//   rnos_, quiu, _نگار_, _csen_,
   {{0x96f8002d,0x254c00b8,0x69c5214a,0x3946005f}},	//   рект_, děla_, buhe, snos_,
   {{0x2d820054,0x39460282,0x78a9214b,0xa91d00ec}},	//   _kike_, pnos_, _feev, _siže,
   {{0x77860086,0x2ca003bc,0x78a90051,0x81bf0033}},	//   _глаз, nbid_, _geev, ুবা_,
   {{0x2d8200a5,0xccf3011d,0x4acf0026,0x2904214c}},	//   _mike_, לכה_, स्कव, _inma_,
   {{0x2d82214d,0xaaa80d53,0x78a90223,0x60cd214e}},	//   _like_, गरिक, _zeev, _scam,
   {{0xe7f01e79,0xd5b902ce,0x61260093,0x71270037}},	//   चिका_, _всі_, _sóla, مرحل,
   {{0x81bc0080,0x78a901e8,0x6126214f,0xa1592150}},	//   dzēt, _xeev, _póla, раму_,
   {{0xa2d31e79,0xd8d70070,0xf09f0176,0x00000000}},	//   _बॉक्, זוכט_, rbà_, --,
   {{0x437400bf,0xdb041ba3,0x6e940421,0x2d68033b}},	//   _بهتر, nsiä, зиру, ußen_,
   {{0xd0470095,0xe1890019,0x2d822151,0x9cf52152}},	//   _əməl, _hẳn_, _bike_, озві,
   {{0x2d820055,0x61440d6e,0x00000000,0x00000000}},	//   _cike_, _неја, --, --,
   {{0x5b151238,0x2d8201f4,0x7ae500c3,0xdb042153}},	// [1830] омат, _dike_, teht, trið,
   {{0xbcfb2154,0x78a92155,0x2d822156,0xdcfe0160}},	//   _chér, _seev, _eike_, _pupă,
   {{0x78a92157,0xd91b03d4,0x7ae51cfc,0x13e10033}},	//   _peev, льд_, reht, বিয়,
   {{0x69c52158,0xf38800e2,0x7ae52159,0x2d820371}},	//   ruhe, _rợn_, seht, _gike_,
   {{0xf771215a,0x6b8d0069,0x78a900be,0x212900e0}},	//   وات_, qqag, _veev, _mlah_,
   {{0xb6a5215b,0x290400d7,0x69c500c3,0x2129215c}},	//   цикл, _enma_, puhe, _llah_,
   {{0x2129149f,0x36fe0084,0x78a9215d,0xf59202e7}},	//   _olah_, लाड़ी_, _teev, ولوج,
   {{0x58d4215e,0xe3b90ef3,0x321e0035,0x254c00b8}},	//   _ност, аби_, dyty_, těla_,
   {{0x27ed215f,0x981700bf,0x395f06a2,0x2cab008c}},	//   _usen_, _ابزا, _ikus_, _mecd_,
   {{0xdb160086,0x21290088,0xaacc2160,0xf38800e2}},	//   styö, _alah_, ालयक, _tợn_,
   {{0x9f4901ae,0x81bc00ea,0xdcfd0409,0x21290147}},	//   _spaß_, dzēs, _aisč, _blah_,
   {{0x6f0500e2,0x00000000,0x00000000,0x00000000}},	//   _anhc, --, --, --,
   {{0x2d822161,0x28d10266,0x6f171505,0x200f0392}},	//   _rike_, _हानि, _boxc, _àgil_,
   {{0xe29913ad,0x05dd0b35,0x321e2162,0xdcfd02c4}},	//   _так_, _महाब, byty_, _disč,
   {{0x395f2163,0xad3a00d4,0x2ca00312,0x321e06bc}},	//   _okus_, ачає_, tbid_, cyty_,
   {{0x644a012e,0xc5f2011d,0x8d66010b,0x4d6602a4}},	//   šmiš, ודל_, івае, ікав,
   {{0xcb050461,0x25a0011c,0x4aaa18cd,0x2d820210}},	// [1840] रांड_, ćili_, икан_, _vike_,
   {{0x5ec10083,0x395f01e9,0x00000000,0x00000000}},	//   শ্বে, _akus_, --, --,
   {{0xa3a90f8a,0x2d822164,0x7f5c00f7,0xb9ea00af}},	//   गीत_, _tike_, morq, рмез_,
   {{0x6d4100f7,0x7f5c0036,0xdd0f0225,0x2006009e}},	//   élat, lorq, mışs, _àois_,
   {{0x7d0600c7,0xbcfb00f7,0x321e0067,0x00000000}},	//   _inks, _thér, zyty_, --,
   {{0xd5ba14a1,0xab2a0202,0x394d2165,0x3d080099}},	//   аси_, _тога_, _ejes_, हावे_,
   {{0x386d2166,0x76a900d4,0x7f5c002a,0x3eba00ee}},	//   _ezer_, стів_, iorq, _mdpt_,
   {{0xdb04081b,0x89d700fd,0x00000000,0x00000000}},	//   ssiä, _گوہر_, --, --,
   {{0x73fa0083,0x25a90254,0x78a22167,0xd7d10067}},	//   েন্ট_, ćala_, mbov, _समयच,
   {{0x5edf0033,0x2d9a0176,0x1fd00033,0xd370017e}},	//   _ফোনে, _otpe_, িবাস, عهد_,
   {{0x92581b17,0xaacf020d,0x6126021d,0x00000000}},	//   сант_, स्टक, _cólo, --,
   {{0xd13b0036,0x7bd608dd,0x69c308b7,0x78a22168}},	//   рхо_, ktyu, šneg, nbov,
   {{0xb97b0100,0xf8b30122,0x357300b5,0xb03400c3}},	//   ינטי, ושר_, _تھوڑ, дняш,
   {{0x7d0601c8,0x321e00a0,0x00000000,0x00000000}},	//   _anks, pyty_, --, --,
   {{0xdef801c8,0x61262169,0x6f17021d,0x00000000}},	//   цыя_, _gólo, _voxc, --,
   {{0x2129216a,0x254500ea,0x4add022e,0xaadd0355}},	//   _ulah_, tēli_, न्नव, न्नक,
   {{0xb7c50033,0x29fa00ee,0x78a200d5,0xa91d02a7}},	// [1850] _এন্ট, _aďa_, dbov, _niža,
   {{0xdea1006c,0xcb050026,0x6f05216b,0x395f0501}},	//   _سیری, राइड_, _unhc, _skus_,
   {{0x386d07cf,0x4c9500af,0x394d0031,0x78a2021d}},	//   _szer_, _нинс, _pjes_, fbov,
   {{0xdb0d0037,0xa91d0207,0x00000000,0x00000000}},	//   msaí, _biža, --, --,
   {{0x3d080299,0x8cd8007c,0x07a50be8,0x395f00ac}},	//   हारे_, मभरो, чалн, _vkus_,
   {{0x370700c3,0xa91d00ec,0x00000000,0x00000000}},	//   ючев, _diža, --, --,
   {{0x394d216c,0x7af501ed,0x98a600d5,0x67230207}},	//   _tjes_, _iazt, choď_, rknj,
   {{0x7af5216d,0x67d50664,0x395f011c,0x6126002a}},	//   _hazt, _нобу, _ukus_, _cóll,
   {{0x26de0051,0x7f5c0453,0x3a210159,0x6126143e}},	//   _fbto_, yorq, lyhp_, _sólo,
   {{0xfbd202b8,0x395d00a5,0x27ff01a3,0x6126021d}},	//   עתי_, lows_, _irun_, _pólo,
   {{0x644d01c8,0x4add01d1,0xaadd0569,0x69d701a3}},	//   _žaid, न्यव, न्यक, ntxe,
   {{0x395d0159,0x70c600a1,0x7af501a3,0x69d701ed}},	//   nows_, वलेल, _lazt, itxe,
   {{0x7f5c216e,0x4f96010b,0x80ab0831,0x00000000}},	//   torq, ярну, _কাশ্, --,
   {{0x2d96216f,0xe7e313a0,0x539a00a5,0x00000000}},	//   зрас, _गहना_, _היסו, --,
   {{0x80ab00c8,0x78bb0254,0x78a20097,0x69d701e8}},	//   _কার্, _oduv, ybov, jtxe,
   {{0x80da00c8,0x6d4f0176,0x7af501ed,0x69d70176}},	//   _বোর্, _cjca, _aazt, dtxe,
   {{0x7af506a2,0x3b182170,0xe8df0019,0x31db0099}},	// [1860] _bazt, _porq_, _ngựa_, _बहुध,
   {{0x7bd60159,0x59d00066,0xa91d02a7,0x00000000}},	//   rtyu, _हमदर, _riža, --,
   {{0x2730098b,0xe9da2171,0xdb0d0079,0x78a200d5}},	//   _hàng_, ске_, csaí, tbov,
   {{0x27ff2172,0xdb040079,0xd9100416,0xa91d20d7}},	//   _brun_, nsiú, خیر_, _piža,
   {{0x78a22173,0xdb040079,0x27ff01da,0xa09b025a}},	//   rbov, isiú, _crun_, ציסט,
   {{0x7af503cb,0x27300019,0xe3c30033,0x28d10066}},	//   _gazt, _màng_, ্বাব, _हाथि,
   {{0x09e30de1,0x273001a5,0x98a60346,0xa5d70037}},	//   _порн, _làng_, _ниве, كبير_,
   {{0x53982174,0x27ff017b,0x00000000,0x00000000}},	//   овия_, _frun_, --, --,
   {{0x273001a5,0x27ff2175,0x7af50103,0x00000000}},	//   _nàng_, _grun_, _yazt, --,
   {{0x59d01ee0,0x798e2176,0xaacc2177,0x96660043}},	//   _हमार, _kubw, ालिक, _екзе,
   {{0xc4862178,0x200000ea,0x00000000,0x00000000}},	//   _елек, _arii_, --, --,
   {{0x27300023,0x798e018c,0x7bc4004b,0x92ac0033}},	//   _bàng_, _mubw, kriu, গলে_,
   {{0xc05b00c7,0x273001a5,0xb4e804bc,0xe509021a}},	//   сін_, _càng_, मजी_, वारि_,
   {{0x7bc4010b,0x273001a5,0xa91d07c0,0x80cf00ab}},	//   driu, _dàng_, _nižn, _थावे,
   {{0x7bc4007c,0x798e0010,0x7af508b7,0x00000000}},	//   eriu, _nubw, _razt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6c54135d,0xc1580052,0x705500d1,0x31ae0083}},	// [1870] екту, _משהו_, _زندا, _কমিশ,
   {{0x60dd2179,0x798e001c,0x00000000,0x00000000}},	//   lfsm, _bubw, --, --,
   {{0xa2cf0067,0x79a400c3,0x995e06fe,0x00000000}},	//   _दास्, ерче, _hůř_, --,
   {{0x7bc4217a,0x656201ac,0x63740310,0x69d701b7}},	//   briu, _nkoh, lànd, rtxe,
   {{0x7bc412c3,0x6d4d00ab,0x63740176,0x395d024b}},	//   criu, mnaa, càng, rows_,
   {{0x6d4d217b,0xf7730bf5,0x6562217c,0x00000000}},	//   lnaa, راش_, _akoh, --,
   {{0x6d4d1b43,0x25a9011c,0x798e0103,0x00000000}},	//   onaa, ćalo_, _gubw, --,
   {{0x6d4d217d,0x92ac0083,0x63bd0097,0x6298217e}},	//   nnaa, গলো_, ásno, _afvo,
   {{0x47d50082,0x6ece00a1,0x68eb0c99,0x5eb30083}},	//   _زيار, _तालु, megd, _জানে,
   {{0x70c6052f,0x27300019,0x68eb217f,0x20fa00e2}},	//   वल्ल, _ràng_, legd, _ỏi_,
   {{0x27300023,0x69c500e9,0x6d4d2180,0x60dd05aa}},	//   _sàng_, nrhe, knaa, ffsm,
   {{0xd7d10a5e,0xe7d10e6f,0x4add0355,0xaadd00b8}},	//   _समाच, _समाप, न्तव, न्तक,
   {{0x6d4d2181,0x69c501ae,0x316c0228,0x00000000}},	//   dnaa, hrhe, ēdz_, --,
   {{0x27300028,0x65692182,0xf1a801cb,0x6d4d2183}},	//   _vàng_, lleh, _کاوه_, enaa,
   {{0xa3a90d1f,0xa91d01a0,0x00000000,0x00000000}},	//   गीर_, _nižo, --, --,
   {{0x6d4d2184,0x27300019,0x65692185,0x69c500d5}},	//   gnaa, _tàng_, nleh, drhe,
   {{0x3b8607e5,0x6b870a75,0x2cb20159,0x8c432186}},	// [1880] длаг, _bijg, rayd_, вете,
   {{0x6d4d030d,0xdcfd0029,0xfaa300af,0x63740392}},	//   anaa, _visā, вафо, cànd,
   {{0xa91d02c4,0xaadd0355,0xfe720037,0x68eb0009}},	//   _vižn, न्धक, _جدة_, fegd,
   {{0x7bc400af,0x2d57003c,0xeb9f0c71,0x6fd2021a}},	//   priu, għed_, _brød_, _तमां,
   {{0x69c502e6,0x9f490176,0x65692187,0x6d4408c7}},	//   arhe, _graó_, dleh, miia,
   {{0x4add0edf,0x81e40033,0xaadd0edf,0xa91d0116}},	//   न्दव, নিত_, न्दक, _fižo,
   {{0xa3b02188,0x80cf000c,0xb05b191b,0xdce4031d}},	//   टीन_, _थाले, ngär, hlič,
   {{0xdce40693,0x6ba5013c,0x65692189,0xdb060185}},	//   klič, _åtgä, gleh, _avkø,
   {{0xd8d700c2,0x7c24218a,0xa3a900a1,0xeb9f1f8b}},	//   _קומט_, nyir, गील_, _grød_,
   {{0x612600fb,0xdce4031d,0x5214218b,0x00000000}},	//   _fólk, dlič, едот, --,
   {{0x656901a2,0x6d4d0345,0x7c240010,0xa2cf00c0}},	//   bleh, ynaa, hyir, _दार्,
   {{0xf3880028,0x6569218c,0x65620027,0x60dd02b1}},	//   _lợi_, cleh, _ukoh, ufsm,
   {{0xdce4024e,0x60dd008a,0x28d100b1,0x61ed0207}},	//   glič, rfsm, _हासि, _ćale,
   {{0x4424004e,0x272b0185,0x6560218d,0x00000000}},	//   mym_, _lønn_, lomh, --,
   {{0x4424218e,0x6d4d218f,0x6d5f0be2,0x200d002d}},	//   lym_, tnaa, toqa, ţei_,
   {{0xdce4039c,0x6d4d081b,0xa91d2190,0x5cc40d6e}},	//   blič, unaa, _rižo, ксуз,
   {{0x44242191,0x4ea72192,0x6d4d0130,0x31340036}},	// [1890] nym_, _орна, rnaa, _шеър,
   {{0xa3e60084,0x65600315,0x6d4d2193,0xdb1602d0}},	//   _पहन_, homh, snaa, nsyè,
   {{0x6d4d0223,0x44240168,0x6b870051,0x6569081b}},	//   pnaa, hym_, _vijg, yleh,
   {{0x7c240010,0x69c52194,0x6b9d011e,0x44240334}},	//   byir, rrhe, _ttsg, kym_,
   {{0xdb1602d0,0xa3b00026,0x7c2401d5,0x6b8702a2}},	//   ksyè, टीम_, cyir, _tijg,
   {{0x7d1d006c,0x44240297,0x96da021a,0x00000000}},	//   _hoss, dym_, प्लॉ, --,
   {{0xdce40888,0xf38801a5,0x65692195,0x3cf900be}},	//   zlič, _gợi_, tleh, _kasv_,
   {{0x7d1d03ad,0xa565132d,0x00000000,0x00000000}},	//   _joss, رگان, --, --,
   {{0x7d1d2196,0x65692197,0xa3c10722,0xa3a90066}},	//   _moss, rleh, ौंध_, गीं_,
   {{0x65692198,0xdce40169,0x657b08dd,0x7d1d2199}},	//   sleh, vlič, smuh, _loss,
   {{0xcb120bed,0x216a219a,0x79890298,0x7bcd021d}},	//   אלי_, зини_, _kiew, huau,
   {{0x7d1d00c9,0x4424219b,0xdce4219c,0x6126219d}},	//   _noss, bym_, tlič, _kóli,
   {{0xdce40129,0xb42703c7,0x4424004e,0x442701b2}},	//   ulič, _تعاو, cym_, _تراف,
   {{0x79890173,0x7529006c,0xdce4219e,0x7bcd00be}},	//   _liew, lkez, rlič, duau,
   {{0xdd9203c7,0xfce6219f,0xdce400ac,0x6e9321a0}},	//   اور_, ново, slič, الفا,
   {{0x7989004e,0x7d1d21a1,0x5ec10033,0x2d9e00ea}},	//   _niew, _coss, শ্লে, īte_,
   {{0x7d1d21a2,0xf3880019,0x2d9e0197,0x7ff60037}},	// [18a0] _doss, _sợi_, ūte_, _أسبا,
   {{0xe8030127,0x637401f7,0x272b0044,0x00000000}},	//   लिना_, mànc, _sønn_, --,
   {{0x3cfb08b0,0x7d1d09b5,0x3f92000e,0x4424004e}},	//   _लोके_, _foss, _huyu_, zym_,
   {{0x59d2083f,0x69c31111,0xed5a0210,0xdcfd0139}},	//   दंबर, ánea, _хом_, _visă,
   {{0x61261d2b,0x6f1e15bc,0x798921a3,0x28d1178c}},	//   _cóli, _kopc, _diew, _हारि,
   {{0xa847004f,0x57f303fa,0x254c0355,0x44240bca}},	//   علوم_, упшт, měli_, vym_,
   {{0x612621a4,0x4424006a,0x00000000,0x00000000}},	//   _eóli, wym_, --, --,
   {{0x61261d85,0xc44801cb,0x442421a5,0x752900b5}},	//   _fóli, ویان_, tym_, gkez,
   {{0x394621a6,0x84970037,0x3f920371,0x00000000}},	//   mios_, رئيس_, _nuyu_, --,
   {{0x394621a7,0x65600568,0x81e40083,0x2eaa01d1}},	//   lios_, somh, নিস_, करोत,
   {{0x041e0083,0x6ed721a8,0xd9430043,0xa15921a9}},	//   _বেশী_, _बाबु, _реӂи, дану_,
   {{0x394621aa,0xb7f40084,0x2a6a21ab,0x63740310}},	//   nios_, _इनाम_, _mybb_, fànc,
   {{0x7d1d21ac,0x5f940382,0xe803073f,0xb8030803}},	//   _ross, лият, लिया_, लियम_,
   {{0x39460608,0x254c00b8,0x539b0317,0xdefb00d8}},	//   hios_, děli_, _ציוו, чым_,
   {{0x7d1d21ad,0x394600d8,0xdb0d21ae,0x28d104aa}},	//   _poss, kios_, drað, _हालि,
   {{0x9d180896,0xe8030266,0xa91d063c,0x00000000}},	//   ност_, लिमा_, _pižm, --,
   {{0x39462140,0xdb0d1f98,0x7d1d21af,0x70bf1a75}},	// [18b0] dios_, nsaç, _voss, ्लील,
   {{0xdb0d0f56,0x798921b0,0x7bcd028b,0x7d1d081b}},	//   trañ, _siew, ruau, _woss,
   {{0x7d1d21b1,0xa2d821b2,0x394617db,0xa7fd006c}},	//   _toss, _मान्, fios_, _gyűj,
   {{0x394621b3,0x61260093,0x3f920118,0xdb0d21b4}},	//   gios_, _póli, _yuyu_, rrañ,
   {{0x79890052,0x2ca921b5,0x7c6721b6,0x00000000}},	//   _view, mbad_, _ساحل, --,
   {{0x2d8b0831,0x2ca9043d,0x366921b7,0x66e5052a}},	//   _hice_, lbad_, мало_, тока,
   {{0x75290332,0x79890345,0x2d8b005f,0x00000000}},	//   tkez, _tiew, _kice_, --,
   {{0x39460d65,0x2ca921b8,0x73e505c2,0x00000000}},	//   cios_, nbad_, воиз, --,
   {{0x80a204aa,0x752921b9,0x442b21ba,0x2d9321bb}},	//   _क्षे, rkez, ác_, _luxe_,
   {{0x2d8b0470,0x3eb30052,0x69ca0279,0x68fb2198}},	//   _lice_, _next_, áfeg, _haud,
   {{0x68fb21bc,0x2d8b21bd,0x3f9200d0,0xbcfb0168}},	//   _kaud, _oice_, _suyu_, _akém,
   {{0x2eaa0c67,0x614621be,0x236c21bf,0x629a0024}},	//   कर्त, тема, aldj_, acto,
   {{0x200421c0,0x291f006d,0x68fb21c1,0x2ca921c2}},	//   ími_, _moua_, _maud, dbad_,
   {{0x2d8b0094,0x80a20d00,0x394621c3,0x6f630421}},	//   _aice_, _क्रे, zios_, ивяз,
   {{0x63bb21c4,0x63a4003c,0x2d8b01d5,0x0cdd021a}},	//   lsun, _ħini, _bice_, मभूम,
   {{0x68fb21c5,0x291f0043,0x39460391,0x57d1052b}},	//   _naud, _noua_, xios_, _समूह,
   {{0x6f1e21c6,0x394621c7,0x61e40c99,0x63bb21c8}},	// [18c0] _topc, vios_, _ćili, nsun,
   {{0x5fb70122,0x6f1e025c,0x63bb21c9,0x81e40083}},	//   _שהיא_, _uopc, isun, নির_,
   {{0x39460995,0x68fb21ca,0x2ca921cb,0x7e56002d}},	//   tios_, _baud, bbad_, _штиц,
   {{0x3eb821cc,0xc7c6189d,0x1e570122,0x621a0070}},	//   lart_, вски, _ישיר_, וועק,
   {{0x39462132,0x68fb21cd,0x2d80053e,0x291f0012}},	//   rios_, _daud, mmie_, _doua_,
   {{0x394601c8,0x63bb21ce,0x2d8b002d,0xfaa321cf}},	//   sios_, dsun, _zice_, _варо,
   {{0x39461423,0x68fb0248,0xbb431ec2,0x7afc21d0}},	//   pios_, _faud, _терк, _iart,
   {{0x7afc21d1,0x29dc09ab,0x3eb8004a,0x68fb21d2}},	//   _hart, mía_, hart_, _gaud,
   {{0x29dc21d3,0x63bb05c8,0x3eb821d4,0x2c05012f}},	//   lía_, gsun, kart_, रियं_,
   {{0x68fb21d5,0x7afc06a2,0xa6c7150d,0xdb0d0132}},	//   _zaud, _jart, _алфа_, rsaç,
   {{0x29dc09ab,0x7c3a01c2,0x63bb02ee,0x69de21d6}},	//   nía_, _ətra, asun, ntpe,
   {{0x7afc01d2,0x64a621d7,0x68e200e9,0x2d800067}},	//   _lart, _рада, nfod, jmie_,
   {{0xb4ae0e1d,0xdb0409ab,0x29dc21d8,0x3eb8039b}},	//   करी_, nsió, hía_, fart_,
   {{0x63a20269,0x3eb821d9,0x2d8b01c0,0x63ad033e}},	//   _iton, gart_, _sice_, _çana,
   {{0x2d8b21da,0x29dc21db,0xdb0400a2,0x69de0031}},	//   _pice_, jía_, mpiè, jtpe,
   {{0x29dc09ab,0x7afc21dc,0xa3e600a1,0x63a20103}},	//   día_, _aart, _पहा_, _kton,
   {{0x3eb321dd,0x3eb821de,0x5c7521df,0x2ca921e0}},	// [18d0] _text_, bart_, улат, rbad_,
   {{0x29dc1f37,0x69de21e1,0xe4e20a5e,0x7e4721e2}},	//   fía_, ftpe, क्ति_, _ахме,
   {{0x29dc00c8,0x68e200e9,0x2d8b21e3,0x612601dd}},	//   gía_, ffod, _tice_, _vólv,
   {{0x63a221e4,0x7afc21e5,0x23c20099,0x63bb21e6}},	//   _oton, _eart, _शिंद, ysun,
   {{0xb8db0722,0x69dc21e7,0x68fb21e8,0x63a21642}},	//   _आज_, _eqre, _vaud, _nton,
   {{0x7afc21e9,0x29dc09ab,0x00000000,0x00000000}},	//   _gart, bía_, --, --,
   {{0x29dc09ab,0x63a221ea,0x74d70026,0x69de01e4}},	//   cía_, _aton, _यादृ, ctpe,
   {{0x7afc21eb,0x290d01a3,0x7995034d,0x00000000}},	//   _zart, _unea_, _iuzw, --,
   {{0xa8550d36,0x25be01ae,0x61ea009e,0xa91d0ce9}},	//   _скач, _evtl_, _apfl, _niži,
   {{0x63bb21ec,0x386d10c3,0x3169021e,0x79950027}},	//   rsun, _iyer_, _akaz_, _kuzw,
   {{0x63bb21ed,0x3eb821ee,0x63a221ef,0xe8df0023}},	//   ssun, vart_, _eton, _ngừa_,
   {{0x7fd61112,0x349503fa,0x8fa61ca4,0x63bb21f0}},	//   лігі, _садр, ламе, psun,
   {{0xa2e5034b,0x672121f1,0xc8d10026,0x00000000}},	//   _болд, _kolj, _हाईट, --,
   {{0x08760070,0x083a0070,0x612600b5,0xdbd102b1}},	//   טערט_, געשל, _rólu, _süße,
   {{0xa2d821f2,0x29dc1a71,0xe4f90edf,0x672104c3}},	//   _मात्, xía_, ्यपि_, _molj,
   {{0x7afc21f3,0x29dc0f56,0x5c160086,0xfc3f0453}},	//   _sart, vía_, льзу, _reír_,
   {{0x3eb800a2,0x2d8021f4,0x6ab500ee,0xbf9b0183}},	// [18e0] part_, rmie_, _bezf, lvên,
   {{0x7afc00da,0x29dc0b4c,0x0eaa00d8,0x2d8000a0}},	//   _qart, tía_, _якой_, smie_,
   {{0x7afc21f5,0x386d21f6,0xbf9b03e6,0x9d4621f7}},	//   _vart, _ayer_, nvên, _бенд,
   {{0x29dc1175,0x7afc21f8,0x386d0c71,0x69de21f9}},	//   ría_, _wart, _byer_, rtpe,
   {{0x7afc21fa,0x6846005f,0x67210888,0x6d460463}},	//   _tart, ында, _bolj, _imka,
   {{0xdb0409ab,0x29dc21fb,0x7afc0a8a,0x67210051}},	//   rsió, pía_, _uart, _colj,
   {{0xf41f0d36,0x672121fc,0xe9a300d8,0x63a221fd}},	//   ään_, _dolj, _гасп, _ston,
   {{0xb4ae21fe,0x60c40aee,0x80d600a1,0x63a201f7}},	//   करे_, _ndim, _भाषे, _pton,
   {{0x14d5164f,0x672121e7,0x68e400ab,0x7454026b}},	//   _धारण, _folj, õidu, جھائ,
   {{0xa3b5009a,0x60c421ff,0x672103ab,0x79822200}},	//   _जबर_, _adim, _golj, lmow,
   {{0xe6930514,0x41552201,0x6d462202,0x065600d8}},	//   _المد, ивос, _omka, _стаў,
   {{0x6ed72203,0x672100f4,0x63a2001c,0x00000000}},	//   _बाहु, _zolj, _tton, --,
   {{0x63a22204,0x5ede0033,0x60c42205,0x81e40033}},	//   _uton, য়নে, _ddim, নিই_,
   {{0x88bd004e,0x2fc008b7,0x6d462206,0x752203d0}},	//   _kośc, _dvig_, _amka, _hooz,
   {{0x2bc72207,0xd2b70070,0x57d11f57,0x2fc01e54}},	//   _लिहा, _גלות_, _सम्ह, _evig_,
   {{0x79820035,0xeb9f0a8a,0x79950371,0x3169068f}},	//   jmow, _drøn_, _ruzw, _ukaz_,
   {{0x7522006d,0x00000000,0x00000000,0x00000000}},	// [18f0] _mooz, --, --, --,
   {{0x2009000d,0x9b440037,0x386d0345,0xf09f0392}},	//   _irai_, منقو, _ryer_, lcà_,
   {{0xdb580086,0xeb9f035b,0x386d2208,0x2bc700b4}},	//   уют_, _grøn_, _syer_, _लिवा,
   {{0xb4ae018d,0x2009028b,0x7522073a,0xf09f0176}},	//   करो_, _krai_, _nooz, ncà_,
   {{0x67210496,0xdcef0067,0x00000000,0x00000000}},	//   _polj, _chcą, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67212209,0x7bcd0093,0x236502c6,0x386d0b88}},	//   _volj, lrau, volj_, _wyer_,
   {{0x200900d8,0xf8b90722,0xddde00fe,0xa5250210}},	//   _orai_, _उजिय, _cypř, рмид,
   {{0x36d5220a,0xa3b000a1,0xe3b60104,0x6721220b}},	//   _возр, टील_, абы_, _tolj,
   {{0x6ac70083,0x7bcd220c,0xa3e6046c,0x27ed220d}},	//   র্রো, irau, _पहर_, _ipen_,
   {{0x88bd004e,0x7bcd220e,0x637d01cb,0x00000000}},	//   _gośc, hrau, hèng, --,
   {{0x291d1526,0x7bcd220f,0x0086117a,0x20090118}},	//   njwa_, krau, илно, _brai_,
   {{0x236501f2,0xa0760409,0x68e900f8,0x6126008d}},	//   polj_, рынш, _mbed, _sóls,
   {{0x82a503ad,0x56b502b5,0x7982004e,0x6d4600d7}},	//   _такж, יפֿן_, zmow, _smka,
   {{0x63a92210,0xa0a62211,0x69c30bc9,0x99d70033}},	//   lpen, _кайд, šnej, সবুক,
   {{0xf38800e8,0x27ed2212,0xf09f0036,0x2fc00132}},	//   _hợp_, _open_, ccà_, _tvig_,
   {{0xfc030424,0x7bcd2213,0x0b462214,0x4d6301e0}},	// [1900] опто, grau, анан, ікув,
   {{0x63a92215,0x68e92216,0xb4ab0093,0x09e60374}},	//   ipen, _abed, íþjó, иозн,
   {{0xe9da2217,0xa2d82218,0xfce61956,0x27ed0223}},	//   тке_, _मास्, _коно, _apen_,
   {{0x7bcd2219,0x57a61d99,0xa3e600c0,0x88e600c3}},	//   brau, ашка, _पहल_, ржде,
   {{0x7982006a,0x760000b8,0x25a50176,0xdced00a8}},	//   rmow, kázá, _atll_, lmağ,
   {{0x75220298,0x88bd0067,0x68e90381,0x00000000}},	//   _sooz, _pośc, _ebed, --,
   {{0xd5b7037c,0x6d56030d,0x27ed0051,0xdced00a8}},	//   асы_, onya, _epen_, nmağ,
   {{0x6d56221a,0x00000000,0x00000000,0x00000000}},	//   nnya, --, --, --,
   {{0x07a30132,0xe4e2021a,0xa3b004bc,0x63a9221b}},	//   _матн, क्षि_, टीं_, gpen,
   {{0x27390118,0xa91d0207,0x7522030d,0x00000000}},	//   _rèng_, _dižu, _wooz, --,
   {{0x7bcd00ea,0x2d9e0355,0xd25701e0,0x63a901ed}},	//   zrau, ítel_, ицю_, apen,
   {{0x249f0118,0xeb9f008c,0x2bc7221c,0x6126008d}},	//   ccum_, _brøl_, _लिला, _sólr,
   {{0xc05b0185,0xe53b0122,0x612601ef,0xb4c4049c}},	//   тін_, _בתאר, _cólq, ौली_,
   {{0x200902e1,0x637d00e0,0x3ef90043,0xe4e200b8}},	//   _vrai_, gènd, ынгэ_, क्रि_,
   {{0x937b016b,0x00000000,0x00000000,0x00000000}},	//   _שטות, --, --, --,
   {{0x7bcd221d,0x2009221e,0xc0cb0267,0x69c3221f}},	//   trau, _trai_, _руке_, šnek,
   {{0xe4f90b35,0x7bcd2220,0x2d9c00fd,0x00000000}},	// [1910] ्यति_, urau, _éven_, --,
   {{0x7bcd2221,0x6d562222,0xfaa72223,0x00000000}},	//   rrau, anya, ршан, --,
   {{0x81e400c8,0x63a906a2,0xceb20317,0x7bcd2224}},	//   নিক_, zpen, _מיי_, srau,
   {{0x63a92225,0x637d2226,0x2739000d,0x7bcd2227}},	//   ypen, mène, _mène_, prau,
   {{0xcce613cf,0x98e40037,0x9ac700b5,0x6d4d0328}},	//   _اسپي, تكنو, _نگاہ_, miaa,
   {{0x9b450580,0x00000000,0x00000000,0x00000000}},	//   _طنزو, --, --, --,
   {{0x80c200c8,0x7c2d2228,0x80dd0033,0x6d4d0051}},	//   ষ্ট্, lyar, _বসন্, oiaa,
   {{0x68e9042a,0x1e580122,0x63a92229,0xdced0097}},	//   _ubed, ישור_, tpen, klač,
   {{0x7c2d070b,0xe2990009,0x63a9222a,0x249f0471}},	//   nyar, лап_, upen, rcum_,
   {{0xf5e700d4,0x6d4d00be,0x63a9222b,0x85b8026b}},	//   _відм, hiaa, rpen, _چانس_,
   {{0xa2d80ac4,0x7c2d222c,0xdced013b,0x22490c98}},	//   _मार्, hyar, xmağ, упни_,
   {{0x63a9222d,0x645e0035,0x04950037,0xdced00d5}},	//   ppen, _śpie, _الإح, flač,
   {{0x6d4d222e,0x7c2d01d5,0xdced0207,0x00000000}},	//   diaa, jyar, glač, --,
   {{0x442d222f,0xdced00a8,0x31970160,0x00000000}},	//   mye_, tmağ, _lăzi_, --,
   {{0x442d2230,0x443f2231,0x6da60009,0x6d56012f}},	//   lye_, lzu_, сиба, tnya,
   {{0xe0da03fa,0xdced2232,0x443f0065,0x6d561855}},	//   _сви_, rmağ, ozu_, unya,
   {{0x442d2233,0x443f2234,0xec7a2235,0x7c2d0332}},	// [1920] nye_, nzu_, упа_, gyar,
   {{0x8a3a0086,0x442d054b,0x2ca0027b,0xdce400f4}},	//   ляет_, iye_, scid_, klić,
   {{0xb4f90f9f,0xd91000d1,0x442d0031,0xdce40124}},	//   ्याय_, ویس_, hye_, jlić,
   {{0x7c2d1cf5,0x6d4d0120,0x442d2236,0x00000000}},	//   byar, ciaa, kye_, --,
   {{0x2912037a,0x442d0a0d,0x2bba0037,0x443f0156}},	//   ıya_, jye_, _حاجة_, jzu_,
   {{0x2d9a2237,0x7d042238,0x443f0029,0x442d2239}},	//   _kupe_, ldis, dzu_, dye_,
   {{0xe7f40299,0x442d030d,0x2d9a223a,0xa3b000b4}},	//   _इनका_, eye_, _jupe_, टीई_,
   {{0x7d04223b,0x442d0c1f,0x3e83000d,0xa91d00ec}},	//   ndis, fye_, lété_, _dižs,
   {{0x442d223c,0x7d04223d,0x78a20187,0xf36603d0}},	//   gye_, idis, mcov, йтон,
   {{0xdced0496,0x78a20187,0x7d040086,0xd6d20fab}},	//   vlač, lcov, hdis, _رقص_,
   {{0x443f0176,0x442d223e,0x753b223f,0x65690118}},	//   azu_, aye_, bhuz, boeh,
   {{0x78a20076,0x442d19c7,0xd2570560,0xdced2240}},	//   ncov, bye_, сць_, tlač,
   {{0x7d042241,0x50670945,0x443f0035,0x85030088}},	//   ddis, стна, czu_, _روون,
   {{0x7bd6011e,0x6d5a2242,0xdced0009,0xa85700a5}},	//   duyu, étan, rlač, מיכה_,
   {{0x6d4d2243,0xdced00cd,0x8d7701b2,0x2d9a0139}},	//   tiaa, slač, مارا, _cupe_,
   {{0x7d042244,0xdced02c6,0x7c2d03d0,0x78a20334}},	//   gdis, plač, tyar, jcov,
   {{0x6d4d2245,0xac182246,0x78a20334,0x7bd62247}},	// [1930] riaa, боту_, dcov, guyu,
   {{0x6d4d2248,0x7c2d04fb,0x64402249,0x7d0400be}},	//   siaa, ryar, izmi, adis,
   {{0x443f029d,0x7c2d124f,0x637d12c3,0x442d02d0}},	//   zzu_, syar, lènc, zye_,
   {{0x273000e8,0x26de0f56,0x7bd605ca,0xcebc0095}},	//   _hành_, _acto_, buyu, _şəxs_,
   {{0x81e40083,0xb9010a40,0x18690166,0x637d0310}},	//   নিট_, _दा_, јали_, nènc,
   {{0x443f0095,0xe736224a,0x442d224b,0xdce400cd}},	//   vzu_, жеш_, vye_, tlić,
   {{0xf77000bf,0xca24224c,0x78a20bca,0x442d224d}},	//   راه_, _ефти, bcov, wye_,
   {{0x442d0c1f,0x443f06a2,0x27300019,0xb3c91583}},	//   tye_, tzu_, _lành_, ализ_,
   {{0x442d224e,0x753b00fd,0xdce400cd,0x00000000}},	//   uye_, rhuz, slić, --,
   {{0x442d224f,0x637d12c3,0x776a00de,0x78bb02a2}},	//   rye_, dènc, cofx, _heuv,
   {{0x442d2250,0x2d572251,0x5f1d09b4,0xe7842252}},	//   sye_, għek_, मान्_, _хуто,
   {{0x2d9a2253,0x3eba2254,0x442d02e9,0x216a1f9b}},	//   _rupe_, _sept_, pye_, рими_,
   {{0x41c50d00,0x2d9a2255,0x637d0443,0x28de00dc}},	//   _विकस, _supe_, gènc, फ्टि,
   {{0x78bb2256,0x27300023,0x3f81009e,0x00000000}},	//   _leuv, _cành_, _chhu_, --,
   {{0x27300028,0x78bb0248,0x6da3005c,0x272b11cb}},	//   _dành_, _oeuv, диса, _høns_,
   {{0x78bb2257,0x0d99021f,0x69d701ef,0x2fcd02c6}},	//   _neuv, стры_, duxe, šega_,
   {{0x637d12c3,0x78a20237,0x6abe1ad9,0xbcfb0168}},	// [1940] cènc, vcov, tapf, _akés,
   {{0x91ed0bc1,0x2d9a002f,0x7bd6037a,0x63a40079}},	//   _जहाज_, _tupe_, ruyu, _éine,
   {{0x78a20160,0x6abe01d5,0x3e83000d,0x78bb00f6}},	//   tcov, rapf, rété_, _beuv,
   {{0x7d041505,0x1d0a2258,0x3f93022e,0x7bd600d7}},	//   qdis, _теми_, _zixu_, puyu,
   {{0x78a22259,0xaae2012f,0xa81700fd,0x386000a8}},	//   rcov, _पापक, قتور_, çir_,
   {{0x78a2225a,0x00000000,0x00000000,0x00000000}},	//   scov, --, --, --,
   {{0xa3dc0785,0x78a20501,0x59d100ab,0x00000000}},	//   तून_, pcov, _हियर, --,
   {{0x6abc225b,0x7bc4010b,0x80d6164f,0x1c0e1f4c}},	//   _herf, osiu, _भागे, सिपल_,
   {{0x7bc4225c,0x6440042a,0x5454225d,0x6abc008a}},	//   nsiu, uzmi, явит, _kerf,
   {{0x290414cc,0x799c0232,0x27e60140,0x6abc009f}},	//   _hama_, _kurw, mton_, _jerf,
   {{0x2904225e,0x7bc40d6c,0x200006fe,0x2ef803bc}},	//   _kama_, hsiu, _asii_, derf_,
   {{0x09cf00c8,0x2904225f,0x29062260,0x637d0443}},	//   _রহমা, _jama_, ndoa_, tènc,
   {{0x29042261,0x6abc218e,0x00000000,0x00000000}},	//   _mama_, _oerf, --, --,
   {{0x29041201,0x26dc0409,0x637d0955,0x6abc2262}},	//   _lama_, ngvo_, rènc, _nerf,
   {{0x62660088,0x637d12c3,0xdcbb2263,0x31352264}},	//   _باشق, sènc, ища_, _некр,
   {{0x29040e9a,0x5c99086c,0x27e62265,0xa3ae1a75}},	//   _nama_, ская_, kton_, _ओझा_,
   {{0x6abc2266,0x27e62267,0x3fc90df3,0x7bc42268}},	// [1950] _berf, jton_, _ادبی_, gsiu,
   {{0x6abc2269,0x799c0b13,0x60dd049a,0x6e2a0031}},	//   _cerf, _burw, lgsm, ëmbë,
   {{0x78bb02e1,0x6abc226a,0x27e6226b,0x7bc400ab}},	//   _peuv, _derf, eton_, asiu,
   {{0x60dd11cb,0x29041430,0x27e6226c,0x673a0553}},	//   ngsm, _cama_, fton_, _altj,
   {{0x01e00083,0x2d89226d,0x27e60023,0x394f226e}},	//   ববিদ, mmae_, gton_, rigs_,
   {{0x69d701dd,0xb6a51765,0x2d89028b,0x27390107}},	//   puxe, чикл, lmae_, _bèna_,
   {{0x67280c21,0x27e60086,0x6b9d226f,0x7f3c0070}},	//   _dodj, aton_, _husg, שעוו,
   {{0x69c52270,0x6b9d0008,0x27e60430,0x6aa52271}},	//   mshe, _kusg, bton_, lchf,
   {{0x27ff07b5,0x36d500af,0x394d03d0,0x69c700fe}},	//   _usun_, _ноар, _imes_, _hvje,
   {{0x29042272,0x60dd2273,0xaacb00dc,0x6f05008c}},	//   _zama_, egsm, ाणिक, _nahc,
   {{0xe8030d53,0x69c52274,0x29042275,0x200000a2}},	//   लिका_, nshe, _yama_, _ssii_,
   {{0x67232276,0x7bc42277,0x2000022e,0x2ef81e7e}},	//   ljnj, ysiu, _psii_, werf_,
   {{0x88bd0035,0x200f2278,0x69c52279,0x23a0021e}},	//   _rośl, _ágil_, hshe, _gòj_,
   {{0x69c5227a,0x69c7025c,0x395f013c,0x2d9c00b5}},	//   kshe, _ovje, _ljus_, _évek_,
   {{0x6b9d02bf,0x69c5227b,0x6b40227c,0x88bd0067}},	//   _ausg, jshe, _högg, _pośl,
   {{0x6abc17b3,0x2bc7227d,0x7bc4189c,0x6b9d227e}},	//   _serf, _लिखा, tsiu, _busg,
   {{0xd00f00f8,0x2904227f,0x6abc2280,0x27e609b3}},	// [1960] _ملي_, _rama_, _perf, xton_,
   {{0xa3dc009a,0x7bc42281,0x799c2282,0x4a9a00d8}},	//   तंत_, rsiu, _purw, стаў_,
   {{0x6abc02bf,0x7bc42283,0x69c70c21,0x4ae202cb}},	//   _verf, ssiu, _cvje, _पाठव,
   {{0x27e62284,0x69c7012e,0x6abc2285,0x7bc42286}},	//   tton_, _dvje, _werf, psiu,
   {{0x67282287,0x29042288,0x6abc2289,0x69c50b88}},	//   _podj, _vama_, _terf, ashe,
   {{0x395f228a,0x28d80066,0x7d06228b,0x2904228c}},	//   _ejus_, _डाकि, _haks, _wama_,
   {{0x2904228d,0x7d06228e,0x27e6228f,0x56930d54}},	//   _tama_, _kaks, ston_, нашт,
   {{0x27e62290,0x7d062291,0xda5b011d,0x660100ee}},	//   pton_, _jaks, _הכלל, _dslk,
   {{0x69c7029d,0x00000000,0x00000000,0x00000000}},	//   _zvje, --, --, --,
   {{0x883b0122,0x637d02e9,0x00000000,0x00000000}},	//   _התמו, tèna, --, --,
   {{0x7643006a,0x26cc0297,0x6587008d,0x3253002d}},	//   czny, _iddo_, árhæ, евэр,
   {{0xf4872292,0x867b0070,0xfbb20033,0xa2d809b4}},	//   _کامی, _פראו, _চিনত, _माक्,
   {{0x60dd2293,0xfc3f0300,0xcfa70421,0x00000000}},	//   rgsm, _afín_, яшни, --,
   {{0x3da72294,0x7d0608dd,0x69c52295,0x6b9d01da}},	//   зраб, _aaks, yshe, _rusg,
   {{0xdef800d8,0x6303026e,0x6b950055,0x00000000}},	//   чыя_, _سويل, _rizg, --,
   {{0x6b9d0228,0x6b400282,0x00000000,0x00000000}},	//   _pusg, _lögd, --, --,
   {{0x69c72296,0xd11a112b,0xfe700332,0x2d89012f}},	// [1970] _svje, धारण_, ندہ_, rmae_,
   {{0x69c52297,0x23d409b1,0x69c30132,0x7d0603d0}},	//   tshe, _दिनद, âneo, _eaks,
   {{0x7d062298,0x6aa52299,0xf9f90c26,0x394d021d}},	//   _faks, rchf, تفاع_, _pmes_,
   {{0x69c500da,0xac191b3a,0x26cc229a,0x6aa5229b}},	//   rshe, _дому_, _addo_, schf,
   {{0x69c5229c,0x60cd0159,0x6d4f229d,0x394d08b7}},	//   sshe, _mdam, _imca, _vmes_,
   {{0xe29a0019,0x69c5229e,0x00000000,0x00000000}},	//   _ngư_, pshe, --, --,
   {{0x69c70280,0xba77064e,0x60cd229f,0x7d0622a0}},	//   _uvje, _راست, _odam, _yaks,
   {{0x60cd22a1,0xbe3c00a5,0x76430067,0xeb9f008c}},	//   _ndam, מעות, rzny, _drøv_,
   {{0xb4ad1db6,0x387f0fef,0x395d006d,0x67d42079}},	//   _कभी_, _uzur_, mnws_, _поту,
   {{0x60cd22a2,0x644d010b,0xd75b00d1,0xe0df0036}},	//   _adam, _žais, _اجرا_, egò_,
   {{0x61e8011e,0x00000000,0x00000000,0x00000000}},	//   gtdl, --, --, --,
   {{0xa3b022a3,0x00000000,0x00000000,0x00000000}},	//   टीङ_, --, --, --,
   {{0x7d060ae0,0x6b40013c,0x60cd22a4,0x00000000}},	//   _raks, _höge, _ddam, --,
   {{0x7d0622a5,0x6d4f22a6,0xe4e322a7,0x4f9500af}},	//   _saks, _amca, _गाडि_, ерсу,
   {{0x7d0622a8,0x2d9e02e1,0x1b060083,0x2d961fda}},	//   _paks, ête_, রামে_, драс,
   {{0x395d006d,0x6b4019ee,0x00000000,0x00000000}},	//   jnws_, _möge, --, --,
   {{0x7d0603d0,0x5ed30083,0xed5703e6,0x27390260}},	// [1980] _vaks, দ্ধে, фот_, _rènn_,
   {{0x5fd30084,0xf1c10084,0x27390107,0x00000000}},	//   _तितल, _शबान, _sènn_, --,
   {{0x7d060a1e,0x63740310,0xe800017f,0x752b0051}},	//   _taks, mànt, लौना_, _oogz,
   {{0x395d006d,0x63740392,0xa3ae0387,0x7d0603d0}},	//   gnws_, lànt, _ओझल_, _uaks,
   {{0xf74622a9,0x07fa0b8d,0xc7a31c20,0x07a322aa}},	//   медо, تراع_, вичк, вачн,
   {{0xeb9f177c,0xb8650647,0x6b4005aa,0x2fcf1b99}},	//   _prøv_, رانو, _böge, _ægge_,
   {{0x395d01e8,0x8a030272,0x752b22ab,0x00000000}},	//   bnws_, _изре, _bogz, --,
   {{0x49060066,0xa926010b,0x00000000,0x00000000}},	//   _सोचो_, _ўдал, --, --,
   {{0x671e0e1d,0x752b01e9,0x14180079,0x00000000}},	//   पादक_, _dogz, سيدة_, --,
   {{0xf772004f,0x778310ac,0x6b40017b,0x00000000}},	//   _شاء_, _алуз, _högb, --,
   {{0x2fc922ac,0x00000000,0x00000000,0x00000000}},	//   _svag_, --, --, --,
   {{0x92be00c8,0x914b1958,0xae0d00ab,0x00000000}},	//   ইলে_, ічна_, हिसन_, --,
   {{0xb4da046c,0x945d0067,0xf41f0421,0x6b4002b1}},	//   ़ली_, rańc, äät_, _zöge,
   {{0x6b400093,0x5f94027a,0x00000000,0x00000000}},	//   _lögb, кият, --, --,
   {{0xf20602fb,0x00000000,0x00000000,0x00000000}},	//   _цяло, --, --, --,
   {{0x9d1802fb,0x2c0b0099,0x00000000,0x00000000}},	//   мост_, हटलं_, --, --,
   {{0x63ad22ad,0x395d006d,0xfd1f0023,0x37be0033}},	// [1990] _çant, vnws_, _chìa_, _উৎসর,
   {{0xdb0d0093,0x63740176,0x00000000,0x00000000}},	//   gsað, cànt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2d802cb,0x656201d2,0xdce4027d,0x00000000}},	//   _माझ्, _njoh, mliğ, --,
   {{0x7ac70de3,0xdce401d6,0x2ca90207,0x00000000}},	//   _осве, lliğ, mcad_, --,
   {{0x6d9101ba,0x395d006d,0xd7060044,0x8038016b}},	//   _sťah, snws_, енше_, ונדע_,
   {{0x58d5110a,0xdce401d6,0x2d9922ae,0x2ca902d7}},	//   _повт, nliğ, _kise_, ocad_,
   {{0x6b40033b,0xd6180c74,0x00000000,0x00000000}},	//   _vöge, بتها_, --, --,
   {{0x2d9922af,0x443922b0,0x47d5004f,0x6d5a02e1}},	//   _mise_, ás_, _سيار, étai,
   {{0x42251150,0x2d9922b1,0xdce4027d,0x00000000}},	//   едов, _lise_, kliğ, --,
   {{0x4ae2004e,0x78a422b2,0x2d9900f7,0x63a40037}},	//   _पासव, žive, _oise_, _éinn,
   {{0x2d9900f1,0xa06a0200,0x00000000,0x00000000}},	//   _nise_, зама_, --, --,
   {{0x98a400ea,0x1b060033,0xa07500af,0x2c6c06fe}},	//   _jomā_, রাতে_, вырш, _kódů_,
   {{0xa35700bf,0x657b22b3,0x2d9922b4,0xcad50033}},	//   _تخصص, lluh, _aise_, স্তফ,
   {{0x2d9922b5,0x00000000,0x00000000,0x00000000}},	//   _bise_, --, --, --,
   {{0x62830500,0x2d990211,0x00000000,0x00000000}},	//   _izno, _cise_, --, --,
   {{0xe7da00c8,0x2d9922b6,0x60c6128f,0x4f9618d0}},	// [19a0] _ধন্য, _dise_, makm, _проу,
   {{0x2d9903bc,0x657b0fa0,0x2d9e0132,0xdce405f9}},	//   _eise_, hluh, ítes_, bliğ,
   {{0x533600c2,0xdebb0319,0x657b0159,0xe8fa1738}},	//   ענען_, _ממיל, kluh, зле_,
   {{0xe1ff004e,0xeb9a1470,0xdb0d0093,0xfd1f0023}},	//   łów_, _ним_, ssað, _thìa_,
   {{0x6d5622b7,0x6d4422b8,0x3f9a136b,0x4e9600f8}},	//   miya, mhia, _kipu_, _تشکر,
   {{0x6d5622b9,0x6d4422ba,0x62830506,0x2d9900af}},	//   liya, lhia, _ozno, _zise_,
   {{0xceb30052,0x6b6322bb,0x850400b5,0xeb9f008c}},	//   ניה_, _скра, ہوںن, _frøs_,
   {{0x6d5622bc,0x5976010b,0x657b0a2d,0x6d4422bd}},	//   niya, _чыгу, gluh, nhia,
   {{0x75d401cb,0xe3af0148,0xa3e703fa,0x60c622be}},	//   ريکا, یری_, едња_, dakm,
   {{0x6d5622bf,0xfd1f0028,0x68e222c0,0x3f9a0118}},	//   hiya, _nhìn_, lgod, _nipu_,
   {{0x6d440ce8,0xf41f00be,0x00000000,0x00000000}},	//   khia, äär_, --, --,
   {{0x88bd004e,0x68e222c1,0x7afe22c2,0x846602fb}},	//   _dośw, ngod, hept, _пъле,
   {{0x6d5622c3,0x557702b5,0x543322c4,0x6d4422c5}},	//   diya, _װעגן_, _مرور, dhia,
   {{0x69de22c6,0x15f422c7,0x2d9922c8,0x00000000}},	//   kupe, _आहार_, _sise_, --,
   {{0x63a222c9,0x6d5622ca,0x2d991e85,0x69de056c}},	//   _huon, fiya, _pise_, jupe,
   {{0x63a219c6,0x6d5622cb,0x6d4422cc,0xdce401d6}},	//   _kuon, giya, ghia, rliğ,
   {{0x2d9922cd,0x2ca9026e,0x65600719,0x63a200c3}},	// [19b0] _vise_, rcad_, inmh, _juon,
   {{0xaa6710d4,0x63a222ce,0x6d6700ac,0xeb9f03d0}},	//   нтек, _muon, _špač, _brør_,
   {{0x4ae2009a,0xda6707f6,0x6d5622cf,0x63a203ad}},	//   _पारव, رائي, biya, _luon,
   {{0x6d4422d0,0x6d5610e7,0x637d0c1f,0xacbb0248}},	//   chia, ciya, vènm, _coût,
   {{0x63a222d1,0x7d0d0093,0x66e506e4,0xdb1d0523}},	//   _nuon, mdas, вола, _avså,
   {{0x7d0d22d2,0x7bdf0036,0x69de028b,0xf72b00d8}},	//   ldas, muqu, bupe, яцей_,
   {{0x7bdf22d3,0xae1422d4,0xc17900d8,0x657b0159}},	//   luqu, डियन_, ntės_, tluh,
   {{0x63a222d5,0x7d0d22d6,0xacbb00f7,0xc17900c7}},	//   _buon, ndas, _goût, itės_,
   {{0x63a20023,0x78a40124,0x6b4001ff,0x24560a8a}},	//   _cuon, živc, _höga, _rømø_,
   {{0x6d5622d7,0x6d4422d8,0x63a222d9,0x88bd0035}},	//   ziya, zhia, _duon, _pośw,
   {{0x216a22da,0x7d1d053e,0x61460265,0x6d5622db}},	//   дини_, _onss, вена, yiya,
   {{0x26c722dc,0x7afe22dd,0x6d56013b,0x85040647}},	//   lano_, zept, xiya, _مومن,
   {{0xf99200c2,0xa3a800a1,0x7d0d22de,0x6d5622df}},	//   ירט_, _खूप_, ddas, viya,
   {{0x68e222e0,0x26c722e1,0x75290a78,0x6d5600d6}},	//   zgod, nano_, ljez, wiya,
   {{0x6d440297,0x6d5622e2,0x6283042a,0x50b622e3}},	//   thia, tiya, _uzno, _испу,
   {{0x26c70010,0x7d0d067f,0x752922e4,0x63a20159}},	//   hano_, gdas, njez, _yuon,
   {{0x26c722e5,0x644902c9,0x6d44128f,0x7afe0043}},	// [19c0] kano_, nzei, rhia, tept,
   {{0x6d5622e6,0x6d440189,0x60c42129,0x69de22e7}},	//   siya, shia, _heim, tupe,
   {{0xa3a80e1d,0x26c722e8,0x3ed902b5,0x644901ae}},	//   _खून_, dano_, _אַרא, hzei,
   {{0xd7fa0009,0x7afe22e9,0x798922ea,0x6c86004f}},	//   дук_, sept, _chew, _للجم,
   {{0xb90a051d,0x69de22eb,0x26c722ec,0x798901ca}},	//   _मा_, supe, fano_, _dhew,
   {{0x6a86005f,0x60c422ed,0x68e222ee,0xa773010b}},	//   _алга, _leim, sgod, аліч,
   {{0x63a222ef,0x2d9c006c,0x24800029,0x2bda0099}},	//   _suon, _éves_, _šim_, यंका,
   {{0x6b9c0090,0x644901ae,0x00000000,0x00000000}},	//   _hirg, fzei, --, --,
   {{0x26c722f0,0x07a622f1,0x46ea0009,0x6b9c22f2}},	//   bano_, _разн, _одан_, _kirg,
   {{0x394600c9,0x7d0d0332,0x63a20086,0xdced0254}},	//   lhos_, zdas, _vuon, plać,
   {{0x53d400a1,0x6b9c22f3,0x7d0d0644,0x60c41ab9}},	//   _दिवश, _mirg, ydas, _beim,
   {{0x394600c9,0x51870202,0x63a222f4,0xdb0f01f7}},	//   nhos_, ђуна, _tuon, _etcè,
   {{0x14d702b5,0x60c422f5,0x93461053,0xe815046c}},	//   _יואל_, _deim, _инде, ढिया_,
   {{0x53330431,0x6b9c22f6,0x46b400ab,0x00000000}},	//   _вешт, _nirg, ुरिह, --,
   {{0x2fc022f7,0x3946012f,0xa3a8198f,0x8d770aaa}},	//   _ewig_, khos_, _खंड_, نارا,
   {{0x60c422f8,0x7bdf22f9,0xd7d200b4,0xc179010b}},	//   _geim, tuqu, _सिंच, rtės_,
   {{0x7d0d0f1a,0xdd94010b,0x6b9c22fa,0x26c722fb}},	// [19d0] rdas, раты, _birg, yano_,
   {{0x7d0d22fc,0x26c70485,0x7cde002d,0x6b9c0027}},	//   sdas, xano_, tărâ, _cirg,
   {{0x26c722fd,0x6b9c22fe,0x00000000,0x00000000}},	//   vano_, _dirg, --, --,
   {{0x26c71cf1,0x98a40139,0x00000000,0x00000000}},	//   wano_, _romă_, --, --,
   {{0x26c722ff,0x38692300,0x7bdf00a8,0x9bc400d8}},	//   tano_, çar_, ququ, _вёск,
   {{0xa03c0122,0x3869048c,0x00000000,0x00000000}},	//   ועדפ, ħar_, --, --,
   {{0x26c72301,0xa3a81163,0x78a401cc,0x7bcd1789}},	//   rano_, _खूब_, živa, lsau,
   {{0xf3ff2302,0x39462303,0x26c72304,0xb4ad02cb}},	//   ção_, chos_, sano_, कडे_,
   {{0x26c72305,0xf8ae006c,0x9f400093,0x68e90069}},	//   pano_, _رکن_, _opið_, _iced,
   {{0x644902bf,0x60c42306,0x753b01c0,0xe7300c26}},	//   rzei, _seim, skuz, _وصل_,
   {{0x64492307,0x7ae5184f,0x2fc02308,0x290d034d}},	//   szei, ight, _swig_, _kaea_,
   {{0xe4cb00bf,0x26c52309,0x68e90069,0x6d1200b4}},	//   _آبان_, _helo_, _jced, _ढोंग_,
   {{0xb4df02cb,0x25a5230a,0xdb0f1111,0xfd1f0023}},	//   तली_, _hull_, _etcé, _chìm_,
   {{0xe8e000b8,0x25a5048c,0x26c5230b,0x60c4230c}},	//   _पञ्च, _kull_, _jelo_, _weim,
   {{0x60c4230d,0x26c5230e,0x2009230f,0x160922d4}},	//   _teim, _melo_, _esai_, विटर_,
   {{0x2d8b1298,0x61e10328,0x68e90069,0x26c52310}},	//   _chce_, mull, _nced, _lelo_,
   {{0x61e12311,0x7bcd2312,0xac860eee,0x25a50523}},	// [19e0] lull, gsau, угал, _lull_,
   {{0xec772313,0x68e92314,0x5fbb00a5,0xaf062315}},	//   упу_, _aced, _רצינ, _спол,
   {{0x61e12316,0x212000b8,0x25a52317,0xe7c6021a}},	//   null, _knih_, _null_, रीनप,
   {{0x07a600d8,0x53d40026,0x23d400b4,0x68e92318}},	//   гадн, _दिलश, _दिलद, _cced,
   {{0x26c52319,0x6b9c0029,0x7e7e231a,0x2d80231b}},	//   _belo_, _tirg, _hypp, mlie_,
   {{0x61e101d2,0x26c502c6,0xfaa3231c,0x6b9c0211}},	//   kull, _celo_, _гаро, _uirg,
   {{0x21200a78,0x394601a2,0x26c5231d,0x61e1231e}},	//   _onih_, phos_, _delo_, jull,
   {{0x9d2200c8,0xa534231f,0x61e12320,0xd9430036}},	//   _নতুন_, рнич, dull, _леси,
   {{0x786613ad,0x7786185f,0x00000000,0x00000000}},	//   _сказ, _блаз, --, --,
   {{0x25a52321,0x26c52322,0x29260009,0x57fb00a5}},	//   _full_, _gelo_, štač_, _אלמו,
   {{0x61e12323,0x521300af,0xa3e50067,0x613f01e9}},	//   gull, бдэт, बूब_, _fëll,
   {{0x613f01e9,0x26c5108a,0x64a62324,0xa1592325}},	//   _gëll, _zelo_, _сада, таму_,
   {{0xd0e60e6f,0x54360fab,0x26c52326,0xdce600ec}},	//   _कारण_, _حرار, _yelo_, _dikļ,
   {{0xa2942327,0x2d800298,0x26c5002a,0x212008b7}},	//   _калі, elie_, _xelo_, _enih_,
   {{0x61e12328,0x1df8037c,0x00000000,0x00000000}},	//   cull, леры_, --, --,
   {{0x2d802329,0x7bcd232a,0x7e7e0a8a,0x00000000}},	//   glie_, tsau, _dypp, --,
   {{0x200900e7,0x6fd90e11,0x3b55061c,0x2bc0142a}},	// [19f0] _usai_, _भटिं, акар, शीला,
   {{0x7bcd09df,0x3ea1011e,0x290d0159,0x6d5a232b}},	//   rsau, _ught_, _saea_, étar,
   {{0x7bcd232c,0x2d80232d,0x26c5121e,0x9b6815df}},	//   ssau, blie_, _relo_, ушта_,
   {{0x26c5232e,0x98c7004f,0x78a4232f,0xfd1f0036}},	//   _selo_, اغان, živn, _unì_,
   {{0xf77102aa,0x26c5051b,0x25a501d3,0x61e12330}},	//   يات_, _pelo_, _sull_, zull,
   {{0xaae201c0,0x25a52331,0x6eba07df,0x45d51e46}},	//   _पाएक, _pull_, ्रयु, ацит,
   {{0x6b4002bf,0x26c52332,0x7d0f00fd,0x65c20c46}},	//   _mögl, _velo_, _kacs, обща,
   {{0xb4df2333,0x613f00da,0x61e12334,0x25a512c3}},	//   तले_, _qëll, vull, _vull_,
   {{0x26c51be6,0xa3e50fd1,0x613f00da,0x93451f08}},	//   _telo_, बंध_, _vëll, иние,
   {{0x61e12335,0x7d0f0176,0x25a52336,0x63a901f4}},	//   tull, _lacs, _tull_, rqen,
   {{0xe1262337,0x00000000,0x00000000,0x00000000}},	//   амни, --, --, --,
   {{0xa3e50026,0x00000000,0x00000000,0x00000000}},	//   बंद_, --, --, --,
   {{0x22590035,0x31690359,0x8fa60217,0x00000000}},	//   ńsk_, _djaz_, раге, --,
   {{0x61e12338,0x6fd7045c,0x3f9e2339,0xd0070200}},	//   pull, _बिरू, ötu_, јере_,
   {{0x427902b5,0x3f840029,0xed5a00c3,0xef170166}},	//   _באַג, ēmu_, вов_, јмс_,
   {{0x2056233a,0x2120023a,0xdca31f7c,0x00000000}},	//   _втор, _unih_, жати, --,
   {{0x0c260dfc,0xe4f8018d,0x6b400282,0x2ca70009}},	// [1a00] шман, ्जति_, _fögl, ркуп_,
   {{0x973c0124,0x00000000,0x00000000,0x00000000}},	//   _kiće, --, --, --,
   {{0xa3e50fd1,0x60d6028b,0x6edb00a5,0x2d8000a2}},	//   बूत_, _kdym, _בחיפ, plie_,
   {{0xd94603fa,0x387f0118,0xaae20099,0xdb060031}},	//   једи, _byur_, _पाकक, _kukë,
   {{0x7d04233b,0xfaa60373,0x4cbb00a5,0x88bd0035}},	//   meis, _ваго, _בזכו, _pośr,
   {{0xed5901ba,0x5777010b,0x00000000,0x00000000}},	//   ďže_, абіў_, --, --,
   {{0x645d008d,0x1c0e00b4,0x00000000,0x00000000}},	//   úsin, सिकल_, --, --,
   {{0x7d040086,0x2b58233c,0x00000000,0x00000000}},	//   neis, _hmrc_, --, --,
   {{0xf366141d,0x66e60166,0x6aa9233d,0x6b400093}},	//   итон, _воза, _şefi, _lögm,
   {{0x7d04233e,0x79820052,0x973c011c,0x16760274}},	//   heis, llow, _biće, _кћер,
   {{0x7d0415eb,0x6d460421,0x00000000,0x00000000}},	//   keis, _olka, --, --,
   {{0x855600fd,0x92570421,0xdb060055,0x7d040421}},	//   _خیبر_, рают_, _bukë, jeis,
   {{0x320201c0,0x7522233f,0x74160ef2,0x661a0009}},	//   ňky_, _inoz, _خوشا, _hrtk,
   {{0x6d462340,0x7d0f2341,0xc05801e0,0x6b400282}},	//   _alka, _sacs, рію_, _bögm,
   {{0xd37801cc,0x98bf0009,0xcda9183b,0x7d042342}},	//   moć_, _sluč_, اهره_, feis,
   {{0x929b0052,0x7d042343,0x7c872344,0xe29b011d}},	//   _ביות, geis, аузе, _בשור,
   {{0xdfd10c74,0x75221dab,0xfaa720b4,0x69de0051}},	// [1a10] _عيد_, _mnoz, ашен, erpe,
   {{0x6d462345,0x78a41851,0xd3782346,0xd5a4006c}},	//   _elka, živl, noć_, _يہ_,
   {{0x7d0f2347,0x3f830a78,0x7d042348,0x69d800c7}},	//   _tacs, mlju_, beis, šven,
   {{0xae1a00a5,0x3e160070,0xfcab103b,0x79820067}},	//   _עורכ, _פֿיל_, _جادو_, glow,
   {{0x1b0f0083,0xd378022f,0xf8072349,0x00000000}},	//   সাবে_, koć_, рчен, --,
   {{0xd246234a,0x75220027,0xdb230919,0x00000000}},	//   _فن_, _anoz, _بوسی, --,
   {{0x7982234b,0x69de0009,0xeb0322c7,0x6eba012f}},	//   blow, crpe, रजीत_, ्रतु,
   {{0xf8ab046c,0x7bdf0176,0x637d0118,0x00000000}},	//   _छलिय, orqu, hènt, --,
   {{0x973c01f2,0x142200d8,0x2eb70f17,0x52e2046c}},	//   _siće, здым, _अभूत, पलूस,
   {{0x7d04234c,0x973c00cd,0x27ff01cb,0xddde00fe}},	//   zeis, _piće, _ipun_, _expř,
   {{0xc4cf00b5,0x7d0408c7,0xdb0603d0,0x00000000}},	//   _ہےں_, yeis, _utkå, --,
   {{0x973c02c4,0x00000000,0x00000000,0x00000000}},	//   _viće, --, --, --,
   {{0x4429234d,0x0574004f,0x7d04234e,0xdb060107}},	//   _ça_, _بالد, veis, _fukè,
   {{0x63bb0b0e,0x7d0402c9,0x023916a4,0x1fa700af}},	//   mpun, weis, _مثبت_, скри_,
   {{0x7d04234f,0x68fb2350,0x6ade0083,0xeb9f0185}},	//   teis, _obud, ন্ডো, _esøk_,
   {{0xed570036,0x90c62351,0x2b58022f,0x27ff0139}},	//   бос_, _убие, _smrc_, _opun_,
   {{0x63bb2352,0x3f830a78,0x6d4600d5,0x6d5800c7}},	// [1a20] npun, blju_, _vlka, _įvad,
   {{0x69de2353,0x7d041246,0x68fb2354,0x798200fe}},	//   trpe, seis, _abud, wlow,
   {{0x27ff012f,0x7d042355,0xe9da0267,0x993a1958}},	//   _apun_, peis, уке_, ляду_,
   {{0x68fb009e,0x00000000,0x00000000,0x00000000}},	//   _cbud, --, --, --,
   {{0xe73a0ca6,0xacf700b5,0x18670274,0x6fcb0e61}},	//   лед_, _اسپت, баци_, तीपू,
   {{0x63bb017b,0x78250079,0x798207df,0x00000000}},	//   dpun, تعمل, slow, --,
   {{0xa96a2356,0xceb30319,0x8f9b100a,0x63bb0051}},	//   _бива_, ליג_, ניצי, epun,
   {{0x63bb2357,0x661a00d5,0x73d80d46,0x00000000}},	//   fpun, _vrtk, адир_, --,
   {{0x63bb2358,0x628a00ee,0x00000000,0x00000000}},	//   gpun, _szfo, --, --,
   {{0xaaba114e,0xdb04043f,0x27e602b3,0x68fb2359}},	//   ेरिक, mpió, muon_, _zbud,
   {{0x3f830a78,0x63bb01a3,0x4b7b0070,0x2e18021e}},	//   vlju_, apun, רטיג, _nčf_,
   {{0x73e601c8,0x1a9b0070,0xfbd9046c,0x71470421}},	//   _годз, טייע, _ढिलम, схож,
   {{0x7afc0528,0x27e602b3,0x3f8300f4,0x04960079}},	//   _obrt, nuon_, tlju_, _الشح,
   {{0x2e18021e,0xc9050066,0x00000000,0x00000000}},	//   _bčf_, _रस्म_, --, --,
   {{0x20000107,0x29060065,0x00000000,0x00000000}},	//   _epii_, keoa_, --, --,
   {{0x52830082,0x78a40c0a,0x27e60008,0x3f83219c}},	//   _عليك, živj, kuon_, slju_,
   {{0xfd4f01a5,0x26ce0103,0x290606a2,0x2000012f}},	// [1a30] _khiế, kafo_, deoa_, _gpii_,
   {{0x27e60a2d,0x321c00ee,0x00000000,0x00000000}},	//   duon_, _krvy_, --, --,
   {{0x27ff0043,0xc98710da,0x00000000,0x00000000}},	//   _spun_, буди, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa900af,0x6d4d07b6,0xdd980043,0x6d5f0510}},	//   _şefu, mhaa, _ышь_, miqa,
   {{0xfd4f0019,0x6d4d12ba,0x70b50325,0xdced0124}},	//   _nhiế, lhaa, ंडुल, mlađ,
   {{0xc5d501e0,0x7f3c016b,0x00000000,0x00000000}},	//   ціль, רעוו, --, --,
   {{0x63bb235a,0x68fb235b,0x6d4d235c,0x261a007c}},	//   tpun, _ubud, nhaa, _मछरी_,
   {{0x69da06d7,0x3834235d,0x86eb042c,0x63bb00c3}},	//   _åter, _ентр, _معاف_, upun,
   {{0xfd4f00e8,0x6d4d235e,0x63bb235f,0x95cb2360}},	//   _chiế, hhaa, rpun, _буда_,
   {{0x63bb2361,0x6d4d2362,0x6f0700b8,0xdced00cd}},	//   spun, khaa, dejc, hlađ,
   {{0x63bb2363,0x27e01851,0xdced011c,0xd24e00f8}},	//   ppun, šine_, klađ, خچه_,
   {{0x6d4d2364,0x23290a9f,0x297a016b,0x00000000}},	//   dhaa, _воли_, שטרא, --,
   {{0x6da62365,0x65692366,0x63ab0159,0xe2991566}},	//   жива, lneh, _iugn, _кал_,
   {{0x63ab2367,0xa3e50299,0x41760df3,0x8d5a2368}},	//   _hugn, बूर_, _وابس, ашат_,
   {{0x63a32369,0x6569236a,0x6d43002d,0x6d4d236b}},	//   _hinn, nneh, _înal, ghaa,
   {{0x63a3236c,0x443f236d,0x442d0391,0xfd1f0019}},	// [1a40] _kinn, nyu_, nxe_, _nhìu_,
   {{0x261a0992,0x63a3236e,0x63ab236f,0x62830e7d}},	//   _मछली_, _jinn, _mugn, _kyno,
   {{0xdce40292,0xdca60011,0x2d8c2370,0x63ab013c}},	//   lnič, _мани, ïdes_, _lugn,
   {{0x63a32371,0x6d4d0a75,0x443f2372,0x98a60dc8}},	//   _linn, chaa, kyu_, циде,
   {{0xd70a00af,0x186a0328,0x63ab08dd,0xd90d042c}},	//   инде_, шади_, _nugn, دیق_,
   {{0xd04e0095,0x501b02b8,0x6d442373,0x17542374}},	//   ükəs, יונו, lkia, явля,
   {{0xdce40888,0x26ce1d2b,0x56930d6e,0xd9462375}},	//   hnič, rafo_, машт, _деви,
   {{0x6d4400d8,0x7d162376,0x63a3184f,0xdb040300}},	//   nkia, ndys, _ainn, mpiñ,
   {{0x63a3201e,0xfd4f01a5,0xdce40254,0x63ad0098}},	//   _binn, _phiế, jnič, _éanl,
   {{0x63a304d6,0xdce4011c,0x63ab2377,0x2be2046c}},	//   _cinn, dnič, _dugn, _पिना,
   {{0x442d0391,0x6283001e,0x6d4400c3,0x63a32378}},	//   axe_, _cyno, kkia, _dinn,
   {{0x63a300fb,0x628300e9,0x656905ed,0x443f2379}},	//   _einn, _dyno, cneh, byu_,
   {{0x63a3237a,0xfd4f00e8,0x63ab027a,0x7d16237b}},	//   _finn, _thiế, _gugn, ddys,
   {{0xdced0c99,0x26cc1704,0x93770037,0x6560237c}},	//   vlađ, _jedo_, _وصور_, limh,
   {{0x26cc237d,0x6d5f0095,0x6d4d237e,0x6f07237f}},	//   _medo_, tiqa, thaa, rejc,
   {{0x63a32380,0xdce42381,0x91b70609,0x25ac0009}},	//   _zinn, bnič, _بطور_, _mudl_,
   {{0x6d4d2382,0x6d5f2383,0x6f071cb0,0x61e82384}},	// [1a50] rhaa, riqa, pejc, ludl,
   {{0x6d4d2385,0x26cc0009,0xce9501d3,0xbcfb2386}},	//   shaa, _nedo_, _напъ, _omég,
   {{0x60cd0452,0x2fc908dd,0x61e802b3,0x657b011e}},	//   _keam, _hwag_, nudl, youh,
   {{0x443f2387,0x6d442388,0x889500af,0xa3ad021a}},	//   yyu_, ckia, пиех, कदम_,
   {{0x88070a86,0x6d5d2389,0x2be2238a,0x657b238b}},	//   تظام, _imsa, _पिया, vouh,
   {{0x60cd04e6,0x61e80159,0x26cc238c,0x63ab0051}},	//   _leam, kudl, _cedo_, _rugn,
   {{0x26cc21a4,0xdce406e2,0x63a3238d,0x63ab238e}},	//   _dedo_, znič, _rinn, _sugn,
   {{0x60cd238f,0x63ab2390,0x442d2391,0x61e82392}},	//   _neam, _pugn, txe_, dudl,
   {{0x65692393,0xb4bb1033,0xb4ab0084,0x442d0279}},	//   rneh, _अभी_, _खली_, uxe_,
   {{0x442d0391,0x6d4406a2,0xaacb0d00,0x6d932394}},	//   rxe_, zkia, िरिक, lçad,
   {{0x63a32395,0x6d442396,0x443f2397,0x60cd06c6}},	//   _vinn, ykia, syu_, _beam,
   {{0x6d932398,0xdce401cc,0x216a2399,0x60cd0037}},	//   nçad, tnič, сими_, _ceam,
   {{0x60cd239a,0xe81e0174,0x2ba70066,0x823500d1}},	//   _deam, पिया_, _कंगा, زرگا,
   {{0x61e8239b,0x28db057c,0x6b40017b,0x63a300f1}},	//   budl, मृति, _högv, _uinn,
   {{0xdce41635,0x6146239c,0x60cd19fd,0x00000000}},	//   snič, _нека, _feam, --,
   {{0x60cd239d,0x78a40496,0xf8a503fc,0xdce4040b}},	//   _geam, živi, _لک_, pnič,
   {{0x6d44239e,0x7d161b84,0x2fc900e9,0xb05b038e}},	// [1a60] rkia, rdys, _gwag_, lbän,
   {{0x78a90382,0x6d441da8,0x6d5d1008,0x8eea00d4}},	//   _agev, skia, _emsa, _умов_,
   {{0x7ae3239f,0x64400e18,0x1d0a1309,0x00000000}},	//   ónta, zymi, _лени_, --,
   {{0xdb040138,0x26cc23a0,0x00000000,0x00000000}},	//   rpiñ, _sedo_, --, --,
   {{0x2d8223a1,0x26cc12d5,0x0c2300d8,0xdb0401ef}},	//   _ikke_, _pedo_, _змян, spiñ,
   {{0x6d930132,0x78a9008c,0x25ac23a2,0xa3e5060a}},	//   açad, _egev, _pudl_, बंई_,
   {{0x78ad0496,0x26cc23a3,0x945d0035,0x644001a7}},	//   žava, _vedo_, kańs, wymi,
   {{0xfaa323a4,0x644023a5,0xe5a30274,0x6d9300a2}},	//   _часо, tymi, нији, rçag,
   {{0x60cd23a6,0x7bd6011e,0x26cc023a,0x00000000}},	//   _ream, nsyu, _tedo_, --,
   {{0x60cd23a7,0x6560009f,0x61e802b3,0x394623a8}},	//   _seam, simh, tudl, lkos_,
   {{0x60cd007c,0x7bd6046a,0x62870484,0x6728003c}},	//   _peam, hsyu, żjon, _indj,
   {{0xf8cc0f9c,0x394600d8,0x61e823a9,0x673a055c}},	//   ारिय, nkos_, rudl, _hotj,
   {{0x60cd23aa,0x61e823ab,0x394623ac,0xb97b00a5}},	//   _veam, sudl, ikos_, מנטי,
   {{0x973c0009,0x2d820103,0x6d5d23ad,0x673a23ae}},	//   _mićo, _akke_, _smsa, _jotj,
   {{0xf8cc175f,0xfe700037,0x394623af,0x00000000}},	//   ाराय, هدف_, kkos_, --,
   {{0x6b40008a,0x2d580f78,0x2fc9010d,0x673a12ba}},	//   _mögu, пись_, _twag_, _lotj,
   {{0x6728025c,0x6b40008a,0x212923b0,0xb0c30380}},	// [1a70] _ondj, _lögu, _inah_, _व्यग,
   {{0x2aab03fa,0x2d8223b1,0xe1ab00ab,0x6b52008c}},	//   стао_, _ekke_, _घूँघ, _lægf,
   {{0x7f3c0122,0x62860035,0x442b0023,0x39460051}},	//   _לעזו, ękow, ̣c_, fkos_,
   {{0xbcfb0831,0x672823b2,0x6d5d23b3,0x2bb50026}},	//   _ejér, _andj, _umsa, _अंपा,
   {{0x24860221,0x6d9323b4,0x673a23b5,0xe73923b6}},	//   _nyom_, rçad, _botj, жел_,
   {{0x2be206bc,0x66e500af,0x00000000,0x00000000}},	//   _पिता, фока, --, --,
   {{0xf8ae0332,0x673a0124,0x25a6024b,0xe1ab0066}},	//   اکہ_, _dotj, _biol_, _घूंघ,
   {{0x27e023b7,0xe3b923b8,0x6b40008a,0xb9250372}},	//   šina_, оби_, _dögu, _تفري,
   {{0x395f23b9,0x25a623ba,0x0ebf021a,0x394d23bb}},	//   _imus_, _diol_, ्राड, _iles_,
   {{0x673a0009,0xf8680af8,0x00000000,0x00000000}},	//   _gotj, _عملي_, --, --,
   {{0x77900e3a,0x66f2111a,0x25a623bc,0x6f0c013b}},	//   _حیوا, _घातक_, _fiol_, _öncə,
   {{0x2ec60b54,0x69d803e6,0x764323bd,0x6b40013c}},	//   वर्त, ávei, myny, _högt,
   {{0x764323be,0x657c00fd,0x00000000,0x00000000}},	//   lyny, _írha, --, --,
   {{0x394d23bf,0x62650dbf,0x7763002a,0x25a601f7}},	//   _lles_, _овла, ninx, _ziol_,
   {{0x8fa323c0,0x764323c1,0xdef900d8,0x945d0067}},	//   таре, nyny, чыў_, pańs,
   {{0xa18702fb,0x00000000,0x00000000,0x00000000}},	//   _обща_, --, --, --,
   {{0x248601e8,0x6f170168,0x00000000,0x00000000}},	// [1a80] _xyom_, _faxc, --, --,
   {{0x394d0043,0x7bd606b3,0x76430328,0x5f06010b}},	//   _ales_, rsyu, kyny, _ўзна,
   {{0xa3cd009a,0x6b52054e,0x673a0051,0x394d23c2}},	//   षीत_, _lægg, _rotj, _bles_,
   {{0x78ad0888,0x394600d8,0x673a0176,0x394d00a2}},	//   žavn, ukos_, _sotj, _cles_,
   {{0x394623c3,0x673a23c4,0x6b40008a,0x25a60176}},	//   rkos_, _potj, _sögu, _riol_,
   {{0x394d0bb0,0xd5ba23c5,0x394623c6,0x25a623c7}},	//   _eles_, оси_, skos_, _siol_,
   {{0x764323c8,0x394d0130,0xfbb00033,0x09d80033}},	//   gyny, _fles_, _ছবিত, _সহকা,
   {{0xb4e80a5e,0x2d800036,0x394d0523,0x00000000}},	//   बले_, noie_, _gles_, --,
   {{0xd90d064e,0x25a623c9,0xdc1100a8,0x00000000}},	//   _دین_, _viol_, _məğl, --,
   {{0x25f605e7,0x628f0035,0x76430090,0x28cc0b35}},	//   _एमपी_, ęcon, byny, ारवि,
   {{0x6b40022a,0xe5a60009,0x25a6002a,0xbf9b0345}},	//   _högs, _жижи, _tiol_, kwêr,
   {{0x2d8023ca,0x2d470183,0x0566083e,0x00000000}},	//   joie_, _põem_, _ювен, --,
   {{0x6d430043,0x59ce00a1,0x104b01e0,0xdcfd007a}},	//   _înai, हीतर, іями_, _nisġ,
   {{0x2bb51e79,0x00000000,0x00000000,0x00000000}},	//   _अंबा, --, --, --,
   {{0x27e623cb,0x3da700d8,0x6f1700e0,0xbf9b0b88}},	//   hron_, драб, _vaxc, fwêr,
   {{0x212900d7,0x98a40260,0x6b52008c,0xbf9b0345}},	//   _unah_, _anmč_, _lægd, gwêr,
   {{0x27e623cc,0x21f80118,0x1eab0037,0x7c2900f4}},	// [1a90] jron_, léh_, _وادي_, _šerb,
   {{0x6ec002cb,0xa3e60534,0x7f5918cd,0x25ef046c}},	//   वडणु, _बटन_, _хаос_, _इमली_,
   {{0x27e60033,0x27e0004f,0x394d068f,0x1a65006c}},	//   eron_, áinn_, _ples_, ریری_,
   {{0x26de02b3,0xab5b0225,0x7e9a00a5,0x0e9a00a5}},	//   _adto_, _stüd, _מסתו, _משתל,
   {{0x7d0d23cd,0x6d4f027a,0xf2100066,0x78ad00cd}},	//   meas, _ilca, ़बड़_, žavo,
   {{0xf77307f6,0x7d0d23ce,0x76430086,0xae0317f1}},	//   خاص_, leas, tyny, _लहान_,
   {{0x27e623cf,0x776301dd,0x6d4f028b,0xb9050033}},	//   aron_, rinx, _klca, _বউ_,
   {{0x764300e5,0x7d0d23d0,0x00000000,0x00000000}},	//   ryny, neas, --, --,
   {{0x76430421,0x998500b5,0xf8b20317,0xa775010b}},	//   syny, _élő_, _תשמ_, _злач,
   {{0x7d0d23d1,0x7c200c21,0x6b40022a,0x6b5208c8}},	//   heas, _šmrk, _högr, _vægg,
   {{0xe1f60043,0x7d0d0086,0x26c7008b,0x6d4f23d2}},	//   нгэ_, keas, mbno_, _olca,
   {{0x361a0122,0x2611022f,0x7d0d0139,0xdb070055}},	//   _מועד, _išo_, jeas, _bijë,
   {{0x2d8023d3,0xdb061d8a,0x7d0d0727,0xd24e04cd}},	//   voie_, _luká, deas, لنی_,
   {{0x6d4f23d4,0x6b40008a,0x21f80118,0xa85600a5}},	//   _alca, _lögr, béh_, גישה_,
   {{0x2365022a,0x7d0d23d5,0x2d960c4c,0x6b52082b}},	//   milj_, feas, ерас, _jæge,
   {{0x27e623d6,0x1de10253,0xf11a0cd1,0x00000000}},	//   yron_, _फिरत, _رغبت_, --,
   {{0xec770012,0x6b52054e,0xed5723d7,0x00000000}},	// [1aa0] епт_, _læge, хот_, --,
   {{0x78ad23d8,0x261123d9,0x06e50033,0x00000000}},	//   žavl, _ošo_, প্তি, --,
   {{0x7d0d23da,0xeef700a5,0x2d73011c,0xdb070118}},	//   beas, _אמיר_, mćen_, _mijè,
   {{0x27e623db,0x6d4f009e,0xb4de018d,0x6eba04e9}},	//   tron_, _glca, _तये_, ्रकु,
   {{0x27e623dc,0x58831667,0xb865026b,0x2bd80594}},	//   uron_, лыша, پانو, _تاجک_,
   {{0xf09300c2,0x7bc423dd,0x27e623de,0x27e023df}},	//   אנד_, mpiu, rron_, šino_,
   {{0x3872002d,0x06cf0033,0xe1e70ca8,0x00000000}},	//   _ţară_, _রাশি, _حس_, --,
   {{0x260100c4,0x27e623e0,0x69dc23e1,0x85ba00b5}},	//   _शहरी_, pron_, _ivre, _ہاؤس_,
   {{0xb6030029,0x888100bf,0xd7ca0079,0x00000000}},	//   āšan, _پیون, _رواه_, --,
   {{0x26de011e,0x7982073a,0x41e6093e,0xb7d70037}},	//   _udto_, loow, німа, _أولا_,
   {{0xdb0723e2,0x2fc00090,0xf6290079,0x00000000}},	//   _dijè, _atig_, _يسمى_, --,
   {{0x613f00da,0x2902013c,0x21f80118,0xeb0d23e3}},	//   _pëlq, _ökad_, réh_, _हस्त_,
   {{0xe53b00a5,0x656223e4,0x7d0d00af,0x2bb50253}},	//   _מתאר, _imoh, veas, _अंधा,
   {{0x4ea71294,0xdb070055,0x69dc23e5,0x6b52008c}},	//   ерба, _vijë, _ovre, _lægb,
   {{0x7d0d23e6,0x3ea523e7,0xdcfd009f,0x00000000}},	//   teas, ält_, _jisħ, --,
   {{0x2bb50b7a,0xdb060187,0x3ceb0066,0x6ab90761}},	//   _अंदा, _ruká, टलें_, इड्र,
   {{0x69dc18fd,0xe7cf0035,0x7d0d23e8,0x00000000}},	// [1ab0] _avre, _सौंप, reas, --,
   {{0x7d0d23e9,0x29040051,0x64c40355,0x00000000}},	//   seas, _abma_, lčič, --,
   {{0x7d0d23ea,0xf8cc05f7,0x2ebf022e,0xdcfd00ea}},	//   peas, ारूप, ्रीत, _eksā,
   {{0x628a13da,0x64c423eb,0x3f8323ec,0x213923ed}},	//   _myfo, nčič, loju_, njsh_,
   {{0xb9090084,0x69dc23ee,0x399e0355,0xdb0f0183}},	//   _मय_, _evre, _růst_, _lucé,
   {{0x6562011e,0x3f8323ef,0x290400ee,0x34c923f0}},	//   _amoh, noju_, _ebma_, रर्द,
   {{0xda051163,0xf7700180,0xc8f50133,0x23650009}},	//   _रहित_, حان_, _извъ, vilj_,
   {{0x2ebf035d,0xab64045e,0xdb0f0118,0x6b400523}},	//   ्रुत, rmüş, _sucè, _högp,
   {{0x290f23f1,0x69c5009e,0x3f8323f2,0x236500f4}},	//   mega_, lphe, koju_, tilj_,
   {{0x290f23f3,0x656200e0,0x628a23f4,0x6b52008c}},	//   lega_, _emoh, _byfo, _tæge,
   {{0x2fc023f5,0x628a001e,0x63aa17a4,0xe5150043}},	//   _stig_, _cyfo, _difn, _афлэ,
   {{0x291d23f6,0x290f108a,0x2be2073f,0x628a001e}},	//   ndwa_, nega_, _पिला, _dyfo,
   {{0x61e823f7,0xc8da00a5,0x30760279,0x00000000}},	//   ardl, וקרט, тунс, --,
   {{0xdf1502ce,0x3f8300c5,0x2d990176,0x290f23f8}},	//   льсь, goju_, _ahse_, hega_,
   {{0x5ed40b52,0x290f108a,0x628a00e9,0x200901b7}},	//   _তাদে, kega_, _gyfo, _epai_,
   {{0x290f23f9,0x973c0207,0x7c2900f4,0x00000000}},	//   jega_, _pićk, _šera, --,
   {{0xc4d200c2,0x290f0006,0x6da30de2,0x291d09d6}},	// [1ac0] יגן_, dega_, рита, ddwa_,
   {{0x7bc400c7,0x00000000,0x00000000,0x00000000}},	//   rpiu, --, --, --,
   {{0xab5b01ae,0xe8fa01c8,0xbea60166,0xa9a602fb}},	//   _stüc, дле_, _јанк, вижд,
   {{0x290f23fa,0x81bc00ea,0xd7e60746,0x00000000}},	//   gega_, lvēc, віко, --,
   {{0xa41c00c8,0x79820103,0xe7b323fb,0x00000000}},	//   _তথ্য_, roow, لمند, --,
   {{0x6d9323fc,0xbcfb000c,0x69d8024e,0x69c501e8}},	//   nçan, _jmén, áves, bphe,
   {{0x6f030723,0x69c500f1,0x69dc0254,0x290f23fd}},	//   _önce, cphe, _uvre, bega_,
   {{0x1514002d,0xd9430dbf,0x973c0c99,0x38c804e8}},	//   удия, _кеси, _mići, _ساری_,
   {{0x98a323fe,0xdb0f002a,0xd9430f08,0xa96710da}},	//   _вите, _sucé, _тети, _рита_,
   {{0x5fdc0b4a,0x2bb50084,0xdc9b016b,0x00000000}},	//   _बिजल, _अंसा, ויפל, --,
   {{0x6d5600d7,0x3f831f45,0x973c01f2,0xe73723ff}},	//   khya, voju_, _nići, _шеф_,
   {{0xbcfb0248,0x27e918b0,0x044a0390,0x995e00fe}},	//   _amén, šane_, _опек_, _lůž_,
   {{0x6d562400,0x50642401,0x3f83025f,0xc0ab2402}},	//   dhya, атра, toju_, بادل_,
   {{0x442602b3,0x973c00cb,0x643b0070,0x2ebf0355}},	//   _iro_, _bići, _קעגנ, ्रेत,
   {{0x3f832403,0x00000000,0x00000000,0x00000000}},	//   roju_, --, --, --,
   {{0x44262404,0xf8cc157d,0xf1a41a0e,0x2caf0185}},	//   _kro_, ारोप, _крын, øgd_,
   {{0x290f2405,0x27e02406,0x442600e0,0xdb0f0160}},	// [1ad0] vega_, šinj_, _jro_, _ducî,
   {{0x69c52407,0x44260090,0x3b542408,0xdca40274}},	//   tphe, _mro_, акур, рађи,
   {{0x290f2409,0x7c26033b,0x7d060031,0x2bdf074f}},	//   tega_, _erkr, _fbks, _फटका,
   {{0x4426240a,0x00000000,0x00000000,0x00000000}},	//   _oro_, --, --, --,
   {{0x290f240b,0x4426240c,0x5fdc0066,0x69c511be}},	//   rega_, _nro_, _बिछल, sphe,
   {{0x6d4d240d,0x290f0ccf,0x778400ef,0xdced00cd}},	//   lkaa, sega_, аліз, inač,
   {{0x4426240e,0x644601e0,0x290f240f,0x7f3c0070}},	//   _aro_, økin, pega_, ועגו,
   {{0x6d4d2410,0xdb0d1166,0x44262411,0x7d1d035f}},	//   nkaa, mpañ, _bro_, _jass,
   {{0x38600037,0xaaa71371,0x00000000,0x00000000}},	//   úirt_, _कृतक, --, --,
   {{0x7d1d2412,0x44262413,0xdced0254,0x2ebf00db}},	//   _lass, _dro_, dnač, ्रोत,
   {{0x6d4d2414,0x44262415,0xfb1602b5,0x799b00d7}},	//   kkaa, _ero_, אַכט_, _khuw,
   {{0x442600e9,0xdce40009,0x00000000,0x00000000}},	//   _fro_, mnić, --, --,
   {{0x09e00302,0xd9e01e79,0x6d4d2416,0x44262417}},	//   _पट्य, _पट्ट, dkaa, _gro_,
   {{0x06e50083,0x65692418,0xd6e50033,0x3cf90345}},	//   প্রি, lieh, প্রয, _acsv_,
   {{0xfce62419,0x6d56009e,0x6d4d0d35,0x6d93241a}},	//   лово, thya, fkaa, rçan,
   {{0x7d1d241b,0x6d4d241c,0xbacd0083,0xe6d00d2a}},	//   _cass, gkaa, _লাগছ, _सज्ज,
   {{0x5f7606ca,0x645b241d,0x7d1d241e,0x0c2600d8}},	// [1ae0] _مادر, nzui, _dass, ыман,
   {{0x6d560232,0xe8cc021a,0x79890103,0x656902b1}},	//   shya, ार्च, _akew, hieh,
   {{0x6d4d241f,0x7d1d2420,0x799b022e,0x60d62421}},	//   bkaa, _fass, _bhuw, _keym,
   {{0x39400093,0x6d93092a,0x7d1d2422,0xdce40207}},	//   ðis_, nçal, _gass, dnić,
   {{0x6f1e00f5,0x799b00bf,0x65691736,0x7d040210}},	//   _kapc, _dhuw, dieh, mfis,
   {{0x7791064e,0x7c240010,0x7d1d1388,0x6f1e2423}},	//   قیقا, mvir, _zass, _japc,
   {{0xdced0097,0x44262424,0x6f1e2425,0x7d0408c7}},	//   znač, _sro_, _mapc, ofis,
   {{0x442609a3,0x69de2426,0x60d62427,0x7d1d2428}},	//   _pro_, mspe, _neym, _xass,
   {{0x7c242429,0x69de242a,0x136a07c1,0x385602fb}},	//   nvir, lspe, ешни_, _съвс,
   {{0xa3e51033,0x44260589,0xbcfb0248,0xe3bf0391}},	//   _फिर_, _vro_, _amél, íña_,
   {{0xe13503ad,0x92940b30,0x656901ba,0xa29412ea}},	//   анны, ранц, bieh, рані,
   {{0x4426242b,0xd25701c8,0x69de004f,0x51870370}},	//   _tro_, уць_, ispe, ѓуна,
   {{0x4426242c,0x644600ab,0x60d6242d,0x00000000}},	//   _uro_, äkid, _deym, --,
   {{0x2b8f02c9,0x7d1d242e,0x7c24242f,0x7c290009}},	//   rück_, _sass, dvir, _šero,
   {{0x7d042430,0xd9040332,0x6d4d2431,0x69de2432}},	//   ffis, _ٹی_, tkaa, jspe,
   {{0x62980bc6,0x69de071b,0x7d1d007a,0x7d042433}},	//   _izvo, dspe, _qass, gfis,
   {{0x81b600c8,0x7d1d2434,0x69de2435,0xd7e0018d}},	// [1af0] _ছবি_, _vass, espe, _निगच,
   {{0x7d1d2436,0x656902c9,0x6d4d2248,0xda7b00d8}},	//   _wass, zieh, skaa, няе_,
   {{0x7d1d2437,0xda150279,0x6d932438,0x6d4d2439}},	//   _tass, рдењ, lçam, pkaa,
   {{0x7c2401ef,0x973c02c4,0xe0e70033,0xa3e504bc}},	//   bvir, _miću, গ্রহ_, _फिल_,
   {{0x6d932398,0xdb0d1f51,0x69de243a,0x6569081b}},	//   nçam, spañ, aspe, vieh,
   {{0xb8ec074f,0x6d5801c8,0x69de243b,0x99d70d82}},	//   _श्_, _įvai, bspe, _مترا,
   {{0xb8db00c8,0xf8c90248,0x6569243c,0x00000000}},	//   _আজ_, _créé_, tieh, --,
   {{0x79a40370,0x7545174b,0x7bdf0a4f,0xdce4012e}},	//   _груе, рниз, osqu, rnić,
   {{0x65691be0,0xdb0f0300,0x7bdf02b1,0xdce40506}},	//   rieh, _lucí, nsqu, snić,
   {{0x7bdf0279,0x6569243d,0x60d6243e,0xe787243f}},	//   isqu, sieh, _seym, _субо,
   {{0x291f00ab,0x461508cf,0x7d042440,0x6dbc0009}},	//   _kaua_, _خوار, yfis, _ačan,
   {{0x6f1e2441,0xc4f80037,0x7c242442,0xdb0f0139}},	//   _sapc, _معها_, yvir, _jucâ,
   {{0xb4c304aa,0x291f0054,0x6d93037a,0x6f1e2443}},	//   ्री_, _maua_, rçal, _papc,
   {{0x2d8b000c,0x69de2444,0x291f2445,0x644600c3}},	//   _akce_, yspe, _laua_, äkie,
   {{0x7d042446,0x7bdf01ef,0x69de0282,0xbea62447}},	//   tfis, esqu, xspe, равк,
   {{0x27e01367,0x7c2401c8,0xccc614d0,0x291f0176}},	//   šini_, tvir, рбай, _naua_,
   {{0xdee62448,0x7d04008a,0xab662449,0x69de0973}},	// [1b00] _копи, rfis, авал, wspe,
   {{0x69de244a,0x68fb244b,0xd00f0e3a,0x7d040f0a}},	//   tspe, _acud, _کلی_, sfis,
   {{0xbd8a03c7,0x399c004f,0x291f0159,0x7d040d51}},	//   _لندن_, híse_, _baua_, pfis,
   {{0x06cf0033,0x6d43002d,0x68fb009e,0xc7c60432}},	//   _রাগি, _înap, _ccud, аски,
   {{0x27e0184f,0x77940df3,0xdb0d008d,0xdb0f0139}},	//   éin_, میرا, ppað, _ducâ,
   {{0xd70712a2,0x69de244c,0x00000000,0x00000000}},	//   инче_, pspe, --, --,
   {{0xdb0e01f4,0xcb670043,0x06d80033,0x09e3244d}},	//   _libë, _таре_, _সাদি, _морн,
   {{0x27e90ae0,0x399c0037,0xa5341b5d,0x291f01a3}},	//   šana_, físe_, снич, _gaua_,
   {{0xd4970043,0x973c00cd,0x362400fd,0x00000000}},	//   ирь_, _siću, _گواہ, --,
   {{0x316b004e,0x7338081b,0x39440176,0xb354244e}},	//   wicz_, узор_, _homs_, скош,
   {{0xe81e00df,0x44e80033,0x291f002f,0x394403bc}},	//   पिका_, ক্ষক_, _yaua_, _koms_,
   {{0x2b060162,0x7bc60a78,0x26dc244f,0x8c48037a}},	//   स्तु_, _otku, lavo_, _kağı,
   {{0xb4d22450,0x64a60274,0x1b1d0083,0x7afc00cd}},	//   वरी_, _тада, নাতে_, _ocrt,
   {{0x20050484,0x26dc2451,0xdb0e0055,0x27f92452}},	//   ċli_, navo_, _dibë, _åsne_,
   {{0x139b02b8,0x539b0122,0xc179010b,0x629800cd}},	//   _שבוע, _שיוו, urės_, _uzvo,
   {{0x39442453,0x26dc2454,0x3a2d07e7,0xaaa700b8}},	//   _noms_, havo_, _čep_, _कृषक,
   {{0x60dd010d,0x26dc2455,0x291f018d,0x31690b3f}},	// [1b10] masm, kavo_, _raua_, _imaz_,
   {{0x7bdf02e1,0x60dd2456,0x68fb2457,0x26dc2458}},	//   rsqu, lasm, _scud, javo_,
   {{0x26dc00d8,0x6f150300,0x79a70c98,0x7bc6005f}},	//   davo_, mezc, арде, _etku,
   {{0x8c4806d0,0x39442459,0xdb0e02e9,0x6f15245a}},	//   _bağı, _coms_, _libè, lezc,
   {{0xdc35012b,0x3944245b,0x27ff00a2,0xec35016b}},	//   _האָט_, _doms_, _qqun_, _האָר_,
   {{0x8c480092,0x26dc010b,0xf3fe0083,0x6f15245c}},	//   _dağı, gavo_, ্টার_, nezc,
   {{0x291f009e,0xb4d2009a,0xcf58011d,0xb3450183}},	//   _taua_, वरू_, שבות_, _loçã,
   {{0xb4c31bb5,0x7415004f,0xe3bf01dd,0x5e7800a5}},	//   ्रे_, موعا, íño_, יתון_,
   {{0x69c7029d,0x21200feb,0x26dc245d,0xb3450279}},	//   _htje, _raih_, bavo_, _noçã,
   {{0x26dc245e,0xda0e0fbf,0x437401e0,0x00000000}},	//   cavo_, _सहमत_, жуют, --,
   {{0xe695004f,0x6f150831,0xdb0e0118,0x00000000}},	//   _الاد, dezc, _dibè, --,
   {{0xf6520bed,0x6721245f,0x8c480644,0x92d70033}},	//   _מצב_, _halj, _yağı, িলে_,
   {{0x6721023f,0x98790070,0xc88200a8,0x297a016b}},	//   _kalj, ראָט, _peşə_, רטרא,
   {{0x20022460,0x69c7025c,0x398e003e,0x00000000}},	//   rtki_, _otje, lýst_, --,
   {{0x67212461,0xed5a2462,0x200207ba,0x6b6f010b}},	//   _malj, гов_, stki_, _mėgė,
   {{0x26dc2463,0x5d6700af,0xc21200a5,0x50b6021d}},	//   zavo_, бисм_, _זהה_, _уску,
   {{0x39442464,0xdca30210,0x629e00d5,0x69c72465}},	// [1b20] _roms_, зати, _úpor, _atje,
   {{0x67212466,0x39440903,0xef1a03fa,0xb05b013c}},	//   _nalj, _soms_, _смо_, rbät,
   {{0x26dc2467,0x3f8a2468,0x26010138,0x31690345}},	//   vavo_, mobu_, jóo_, _ymaz_,
   {{0xb4c30a64,0xd9100a86,0x3f8a00d5,0x69c30037}},	//   ्रो_, بیر_, lobu_, ínea,
   {{0x7d16048f,0xdb0e2469,0x2be20f8a,0x69c715a8}},	//   meys, _libé, _पिटा, _etje,
   {{0x7d16246a,0xa09b0c37,0x3f8a246b,0x06d80083}},	//   leys, ניסט, nobu_, _সাহি,
   {{0x26dc246c,0x6d46246d,0x67210121,0x3944246e}},	//   ravo_, _koka, _dalj, _toms_,
   {{0x7d16246f,0x6d462470,0x92d70083,0x26dc2471}},	//   neys, _joka, িলো_, savo_,
   {{0x6d462472,0x672101f4,0x3f8a2473,0x26dc0207}},	//   _moka, _falj, kobu_, pavo_,
   {{0x69c102e1,0x7d16081b,0x8c1b0122,0x60c42474}},	//   _élec, heys, נויי, _afim,
   {{0x60dd06a2,0x3f8a0187,0x6d462475,0x60c907a6}},	//   tasm, dobu_, _ooka, ñemo,
   {{0x67210496,0x27e00a78,0x6d462476,0xdb0e00e0}},	//   _zalj, šinu_, _noka, _dibé,
   {{0xc0581645,0x60dd2477,0xd4672399,0x7d160225}},	//   бір_, rasm, _лице_, deys,
   {{0x2bdb2478,0xc0580402,0x31690345,0x60dd2479}},	//   मीफा, сію_, _wmaz_, sasm,
   {{0x6d46247a,0x6f150033,0x2bdb020d,0xdb0e0118}},	//   _boka, rezc, मीना, _gibé,
   {{0x22ae0669,0x2b9400a6,0x00000000,0x00000000}},	//   mək_, bäck_, --, --,
   {{0x69c7247b,0x6d460888,0x6d931010,0xc17400a5}},	// [1b30] _stje, _doka, nçai, _מחק_,
   {{0x75221e77,0x2d55008c,0x8aa70279,0xdb07007e}},	//   _laoz, _gåen_, бред, _bijá,
   {{0x6721247c,0x2b580160,0xdb0f00fe,0xde4700e0}},	//   _ralj, _dlrc_, _cucá, _ایزو_,
   {{0x67212181,0x6dbc0254,0x7522016f,0xb4d20355}},	//   _salj, _očaj, _naoz, वरो_,
   {{0x6721247d,0x387f0024,0x00000000,0x00000000}},	//   _palj, _qxur_, --, --,
   {{0x7bcd247e,0x27e903ab,0x2fc9011e,0xdb0702d7}},	//   mpau, šano_, _mtag_, _fijá,
   {{0x672105e2,0x69c7029d,0x67230254,0x6d4601a8}},	//   _valj, _utje, rdnj, _yoka,
   {{0x22ae0095,0x672100e0,0xdb0e0e8c,0xd7c90079}},	//   dək_, _walj, _ribé, _نوره_,
   {{0xe3b6247f,0x7bcd2480,0x27e0004f,0x6721035f}},	//   обы_, npau, áint_, _talj,
   {{0x98ad01ba,0x798b2481,0x00000000,0x00000000}},	//   _hneď_, logw, --, --,
   {{0xe2991e46,0x44270e3a,0x7d160a21,0xd064013b}},	//   ран_, _گراف, yeys, ərəs,
   {{0xb81e0066,0xe435103b,0x00000000,0x00000000}},	//   _मैडम_, _وفاد, --, --,
   {{0x6d462482,0x2bb52483,0x656b2484,0x7bcd006d}},	//   _roka, _अंगा, _imgh, jpau,
   {{0x6d462485,0xbf9b0370,0x752202c4,0x83fd006c}},	//   _soka, stên, _zaoz, rződ,
   {{0x614617d0,0x22ae0669,0x3f8a01c6,0x7d160086}},	//   _мека, cək_, robu_, teys,
   {{0x68e900f8,0x2b9402b1,0x3f8a088a,0xdb0700ee}},	//   _nded, päck_, sobu_, _rijá,
   {{0x7d162486,0x0b460009,0xfc031fff,0x7bcd2487}},	// [1b40] reys, онан, мпто, gpau,
   {{0x290d0139,0x68e9141c,0x6d460067,0x4c6700af}},	//   _abea_, _aded, _woka, циун_,
   {{0x32050052,0x6d462488,0xc8ca2489,0x1d0a0336}},	//   ntly_, _toka, لوان_, _кени_,
   {{0xc27a0070,0x25ef0099,0x798b04fb,0x6d46248a}},	//   ברעי, ींनी_, gogw, _uoka,
   {{0x68e9248b,0x3ce0006d,0x6dbc01ba,0x881600d1}},	//   _dded, maiv_, _očak, تباط,
   {{0x05ea248c,0xe3a70180,0x00000000,0x00000000}},	//   афии_, _زر_, --, --,
   {{0xd6d90a55,0xd5b703ad,0xda0e09f9,0x00000000}},	//   сті_, осы_, _सहित_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d5b0070,0x1b1d0033,0x00000000,0x00000000}},	//   יכקי, নারে_, --, --,
   {{0x46a600d8,0x3ce001e8,0xc7b900b5,0xd764103b}},	//   _дазв, haiv_, _erős_, _عنای,
   {{0x2b9401ae,0x20120260,0x84ea1c73,0x00000000}},	//   räch_, _apyi_, _نفاق_, --,
   {{0x81bc0ae0,0x22ae01c2,0x6d930176,0x00000000}},	//   lvēk, rək_, lçav, --,
   {{0x3205024b,0x22ae013b,0x00000000,0x00000000}},	//   atly_, sək_, --, --,
   {{0xdefb00d8,0x6d93248d,0x7c3b01f7,0x389b016b}},	//   шым_, nçav, _àuri, ייכנ,
   {{0xd250004f,0x3205248e,0x20120107,0x6d5800c7}},	//   _سنة_, ctly_, _epyi_, _įvar,
   {{0x8d77006c,0x395d006d,0x6ecb111a,0x5cb9010b}},	//   زازا, xhws_, _त्रु, слаў_,
   {{0x4c940086,0x0cab248f,0x00000000,0x00000000}},	// [1b50] дитс, ртви_, --, --,
   {{0x69c3002a,0x88d70033,0xdc3102d4,0x399c008d}},	//   íneo, _হাইক, _aļģe, vísa_,
   {{0x7bcd00d8,0x39152490,0x0a680ef3,0x00000000}},	//   spau, змер, орци_, --,
   {{0x28f82491,0x7bcd2492,0xc8790160,0x628e0067}},	//   жець_, ppau, _leşe_, żbow,
   {{0xdd3a00a5,0x25fd00b4,0xe81e2493,0x798b2494}},	//   _הערכ, रूनी_, _मैदा_, rogw,
   {{0x9a872495,0x70b70761,0xc8791008,0x00000000}},	//   _дубл, ःशुल, _neşe_, --,
   {{0xd90f0332,0x80dc0083,0xb9010033,0x64460303}},	//   _لیا_, _ভাস্, _দা_, äkin,
   {{0xea000023,0xab5b02b1,0x6d93021d,0x00000000}},	//   _hiếp_, _stüh, açav, --,
   {{0x657e0248,0xea000023,0xf3f10037,0xb7d50833}},	//   épha, _kiếp_, رأة_, _رقاب,
   {{0xdce40225,0x00000000,0x00000000,0x00000000}},	//   kniğ, --, --, --,
   {{0x6b5203d0,0x00000000,0x00000000,0x00000000}},	//   _dægh, --, --, --,
   {{0x69d00084,0x9f4200b8,0x3205024b,0x00000000}},	//   डीटी, mské_, rtly_, --,
   {{0x9f42033a,0x32052496,0x23290227,0x659a1804}},	//   lské_, stly_, _голи_, _פינק,
   {{0x7d0f0168,0x442f03d0,0x80cc0067,0x6dbc023a}},	//   _abcs, _irg_, _थ्रे, _učak,
   {{0x9f4205d3,0x6da62497,0xd24e06ca,0x2bb50461}},	//   nské_, зива, _منو_, _अंजा,
   {{0xf8b90019,0x657b2498,0xc692025a,0x2bf0021a}},	//   _ngũ_, nnuh, גאל_, _चिदं_,
   {{0x27e9008b,0x442f0051,0xaaba2499,0x52de0033}},	// [1b60] šanj_, _jrg_, مدار_, _মাতৃ,
   {{0x8b2601c8,0xed160035,0x442f009e,0x8b231ac5}},	//   ядзе, _łódź_, _mrg_, ндуе,
   {{0x9f420187,0x442f061c,0x7c2f01ed,0x69da0037}},	//   jské_, _lrg_, _ercr, صباح_,
   {{0xa6d80083,0x9f420314,0xf99212de,0xf9830009}},	//   _সাইট, dské_, ربا_, нгхо,
   {{0x98a600af,0x28cb0084,0x7c290009,0x18180e3a}},	//   чиде, ाड़ि, _šerv, تراک_,
   {{0xbb4a0082,0x7bcb249a,0xf8af00fd,0x00000000}},	//   _الآن_, ígue, اکِ_, --,
   {{0x442f249b,0xfaa60009,0x6b52008d,0xdb0f021d}},	//   _arg_, _хаво, _nægi, _sucç,
   {{0x6d441b0f,0xceb302b8,0xd90d0609,0x6d56073a}},	//   njia, עיה_, _نیم_, nkya,
   {{0x9f59022a,0xdb0e00fe,0x00000000,0x00000000}},	//   ltså_, _libí, --, --,
   {{0x442f249c,0x68e2249d,0xdb1d0279,0x3254249e}},	//   _drg_, laod, _ausê, двор,
   {{0x442f0261,0x6d560103,0x27e6249f,0x98bf0024}},	//   _erg_, kkya, lson_, _qmuħ_,
   {{0x463b02b5,0x442f01ef,0x26de0dc3,0x55bb00a5}},	//   _לעבע, _frg_, _heto_, _המאו,
   {{0x27e624a0,0x26de01d2,0x24aa0083,0xdb050079}},	//   nson_, _keto_, _গ্রহ, smhé,
   {{0x27e602e1,0xd37000bf,0xbf9b000d,0xdb0e021d}},	//   ison_, _جهت_, ptêm, _libâ,
   {{0x80dc0083,0x2cb924a1,0x26de24a2,0x00000000}},	//   _ভার্, _pgsd_, _meto_, --,
   {{0x26de24a3,0x5d9901c8,0x61fa24a4,0x00000000}},	//   _leto_, ікаў_, mutl, --,
   {{0x27e602c4,0x68e224a5,0x61fa24a6,0x7bc0000d}},	// [1b70] json_, daod, lutl, _émul,
   {{0x26de24a7,0x8aa705c2,0x6d5624a8,0xbcfb00f6}},	//   _neto_, пред, akya, _amét,
   {{0x98bf002d,0x61fa24a9,0x00000000,0x00000000}},	//   _nouă_, nutl, --, --,
   {{0x9f42024e,0x1a680148,0x0dba006c,0x27e60282}},	//   vské_, سیقی_, _گئیں_, fson_,
   {{0xea0000e8,0x26de24aa,0x443f003c,0xbcfb1c02}},	//   _tiếp_, _beto_, xxu_, _alég,
   {{0x9f420076,0x26de24ab,0x7c2d24ac,0xe736010c}},	//   tské_, _ceto_, mvar, деш_,
   {{0x442f24ad,0x68e2012f,0xa3df0b54,0xe7080413}},	//   _srg_, baod, धीन_, ستون_,
   {{0x98bf0043,0x9f4205d3,0x443f06a2,0x53c90267}},	//   _două_, rské_, txu_, огим_,
   {{0xb4bd02cb,0x7c2d24ae,0xbcfb00b5,0x657b24af}},	//   _आली_, nvar, _elég, rnuh,
   {{0x04ff0083,0x9f4200b8,0xdb1d01ff,0xdced00ac}},	//   ্যের_, pské_, _utsä, diač,
   {{0x6d5d037a,0x61fa011e,0x7c2d24b0,0x7d0d0345}},	//   _olsa, gutl, hvar, kfas,
   {{0x442f24b1,0x6560184f,0xdb06002a,0x7dfe0160}},	//   _trg_, chmh, _yukó, _lăsî,
   {{0x7d0d008c,0xdb0e0168,0x00000000,0x00000000}},	//   dfas, _sibí, --, --,
   {{0xdfcf0082,0x7c2d1f9d,0x6d5d24b2,0x61fa24b3}},	//   شيف_, dvar, _alsa, butl,
   {{0x490e0066,0x7d0d24b4,0x7c2d00c7,0x78bb001c}},	//   ण्डो_, ffas, evar, _oguv,
   {{0x752924b5,0x78bb0657,0x6da324b6,0xf8a503fc}},	//   ndez, _nguv, виса, _مک_,
   {{0xdced24b7,0x7c2d2426,0x442d24b8,0x7b4a00af}},	// [1b80] znać, gvar, nve_, опаг_,
   {{0x442d24b9,0x6d5d24ba,0xbcfb01ef,0x995c0187}},	//   ive_, _elsa, _aléd, díš_,
   {{0xb4bd0992,0x26de0181,0x442d24bb,0x7c2d24bc}},	//   _आलू_, _reto_, hve_, avar,
   {{0x442d01cc,0x98a0008b,0x6f1c1008,0x75290051}},	//   kve_, žič_, lerc, jdez,
   {{0xa3f800c8,0x442d00da,0x8b660105,0x75290036}},	//   _অন্য_, jve_, _قاسم, ddez,
   {{0x27e6060e,0x442d24bd,0x28ce00b4,0x644600ab}},	//   rson_, dve_, _ह्रि, äkim,
   {{0xe1e700f5,0x442d24be,0x27e624bf,0x656011d9}},	//   _جس_, eve_, sson_, thmh,
   {{0xfaa324c0,0x6f1c00ac,0xbcfb0118,0x03c624c1}},	//   _расо, herc, _gléd, мсом,
   {{0x26de24c2,0xea000019,0x6f1c24c3,0x442d24c4}},	//   _teto_, _khắp_, kerc, gve_,
   {{0x6d9324c5,0x332701ef,0x68e024c6,0x61fa24c7}},	//   nçar, _canx_, _hemd, tutl,
   {{0x442d02fb,0x7d0d01d6,0x7c2d013a,0xf74324c8}},	//   ave_, yfas, zvar, _шефо,
   {{0x394624c9,0x9f4001f7,0x7c2d24ca,0x2fc003bc}},	//   njos_, _avià_, yvar, _buig_,
   {{0x386603e0,0x442d0160,0x6f1c0090,0x394624cb}},	//   nzor_, cve_, ferc, ijos_,
   {{0x6f1c24cc,0x61fa24cd,0x67280051,0x7c2d24ce}},	//   gerc, putl, _jadj, vvar,
   {{0x672824cf,0x7d0d0024,0x62660987,0x6e941218}},	//   _madj, tfas, _تاشق, виру,
   {{0x672824d0,0x27e90121,0x7aee0069,0x2fc001f7}},	//   _ladj, šani_, _adbt, _fuig_,
   {{0x7d0d02c9,0xdd941023,0x25a60719,0xe81e07b5}},	// [1b90] rfas, таты, _mhol_, _मैला_,
   {{0x6f1c24d1,0x672824d2,0x7d0d24d3,0x386624d4}},	//   cerc, _nadj, sfas, dzor_,
   {{0x442d24d5,0x7c2d24d6,0x2bdf0026,0xfe350070}},	//   zve_, svar, _पौरा, _װאָך_,
   {{0xb4bd02cb,0xdb1d24d7,0x8aa424d8,0x673a24d9}},	//   _आले_, _musé, труд, _antj,
   {{0xdd910332,0xe73924da,0x27e924db,0x672824dc}},	//   _لوگ_, зел_, éan_, _badj,
   {{0x25a6006c,0x9f59000d,0x442d24dd,0x21290118}},	//   _ahol_, fusé_, vve_, _laah_,
   {{0xf7700ca8,0xe61100d1,0x69dc001e,0x995c0187}},	//   جان_, اشت_, _gwre, síš_,
   {{0x6f1c114d,0x442d24de,0x942518ff,0x693424df}},	//   zerc, tve_, емие, _инсу,
   {{0x442d24e0,0x291d24e1,0x7529006c,0x96ca02e4}},	//   uve_, mewa_, rdez, _स्कॉ,
   {{0x291d0657,0x1b1d00c8,0xb6c9006c,0x672824e2}},	//   lewa_, নাকে_, _رائے_, _gadj,
   {{0x442d24e3,0x63b824e4,0x6f1c24e5,0x394d24e6}},	//   sve_, _divn, verc, _koes_,
   {{0x04c824e7,0x2fc00443,0x291d24e8,0x6f05009e}},	//   _قومي_, _puig_, newa_, _achc,
   {{0x25ad24e9,0x394d0626,0xdbd71c55,0x6f1c24ea}},	//   mmel_, _moes_, _jäät, terc,
   {{0x7ae524eb,0x63b824ec,0x291d04be,0x2bb20107}},	//   jaht, _givn, hewa_, _gņch_,
   {{0x291d24ed,0x41c607df,0xf1c601c0,0x6b520b3e}},	//   kewa_, _रूपस, _रूपन, _mægt,
   {{0xa0a6004b,0x6f1c1ab8,0x2fc003be,0xb4bd0099}},	//   _пайд, serc, _tuig_, _आलो_,
   {{0x6f1c06b3,0xac8624ee,0x291d24ef,0xd00f026e}},	// [1ba0] perc, хгал, dewa_, _هلي_,
   {{0xe6250028,0x395f24f0,0x31720097,0xbcfb0183}},	//   _đông_, _alus_, _hmyz_, _cléb,
   {{0x672824f1,0xfce624f2,0x68e00703,0x4ae10035}},	//   _radj, _поно, _pemd, _फ़रव,
   {{0x8c461056,0x02b60070,0x672824f3,0xab5b033b}},	//   _земе, גלעך_, _sadj, _stüt,
   {{0x394d24f4,0x3105012f,0x7ae524f5,0x2d8024f6}},	//   _does_, ष्टः_, baht, mnie_,
   {{0x2d80006a,0x395f0a47,0x69dc24f7,0x96f824f8}},	//   lnie_, _elus_, _twre, фект_,
   {{0xfaa324f9,0x56930b3b,0x395f003c,0x25a6009e}},	//   _баро, лашт, _flus_, _phol_,
   {{0x291d0ce8,0xa534117a,0x394d24fa,0x248601ef}},	//   cewa_, тнич, _goes_, _pxom_,
   {{0x63b80187,0x672823ca,0x6b520a8a,0x2bb20107}},	//   _pivn, _tadj, _fægt, _pņch_,
   {{0x2d8024fb,0x7c3b09ca,0x2d9204fb,0x3f8500f4}},	//   hnie_, _áure, hoye_, čluk_,
   {{0x7d0606d7,0x3f9100b8,0x63b801e8,0x2d9224fc}},	//   _ocks, vozu_, _vivn, koye_,
   {{0xea0000e8,0x25d900bf,0x2d80004e,0x24860189}},	//   _nhập_, _آهنگ_, jnie_, _txom_,
   {{0x2d80006a,0xe5a322a9,0x00000000,0x00000000}},	//   dnie_, _сици, --, --,
   {{0x442624fd,0x2d80004e,0x291d24fe,0x316024ff}},	//   _iso_, enie_, zewa_, _eliz_,
   {{0xbe882500,0x59b02501,0x3f912502,0x3da72503}},	//   есте_, जगार, rozu_, ераб,
   {{0x2d802504,0x44262505,0x2d922506,0xea0000e2}},	//   gnie_, _kso_, goye_, _chập_,
   {{0x44260009,0x7ae51b43,0xab640225,0xbcfb2507}},	// [1bb0] _jso_, taht, klüğ, _pléb,
   {{0x44260024,0x6d5a01d2,0x2d800035,0xae21007c}},	//   _mso_, ëtar, anie_, मबदन_,
   {{0x395f20ac,0xf771064e,0x2d920232,0x2d800035}},	//   _plus_, یات_, boye_, bnie_,
   {{0x44260291,0xdbd703ad,0x2d800035,0xd8790c9e}},	//   _oso_, _päät, cnie_, ومات_,
   {{0x291d2508,0xbcfb0f56,0x7ae503ad,0x44262509}},	//   rewa_, _eléc, paht, _nso_,
   {{0x394d250a,0x6dbc02c4,0x6d4f027d,0xbcfb000d}},	//   _woes_, _ičar, _hoca, _fléc,
   {{0x4426250b,0x291d000e,0x6d4f250c,0x6b5201b4}},	//   _aso_, pewa_, _koca, _vægt,
   {{0x4426250d,0x1da708a9,0x6d4f250e,0x7415250f}},	//   _bso_, _कीमत, _joca, نوعا,
   {{0x42d500d8,0xc9840d46,0xc3250033,0xe4c811c0}},	//   кіну, _сури, বাসি_, ربين_,
   {{0x6b520093,0x2d802510,0x60cd2511,0x316000d5}},	//   _hægr, znie_, _afam, _sliz_,
   {{0x4426182c,0x96ca1e79,0x36d40086,0x2d802512}},	//   _eso_, _स्टॉ, _сохр, ynie_,
   {{0x27e90080,0x6d4f2513,0x2902013c,0x6aba2514}},	//   šanu_, _noca, _ökat_, _útfe,
   {{0xd24e0a86,0x4426023a,0x25fd0067,0x2d920fce}},	//   منی_, _gso_, रूरी_, voye_,
   {{0x63640176,0x6b520093,0x3ebe01e0,0x2d80107d}},	//   _cònd, _lægr, øtt_, wnie_,
   {{0x6d4f00bf,0x2d80006a,0xfce62515,0xdee300c3}},	//   _boca, tnie_, ково, роси,
   {{0xc5f202b5,0xab64027d,0x16022516,0x2b14166b}},	//   ידל_, zlüğ, रंतर_, न्नु_,
   {{0x2d802517,0x00000000,0x00000000,0x00000000}},	// [1bc0] rnie_, --, --, --,
   {{0x998d2518,0x2d800035,0xab5b033b,0x6b632519}},	//   _češ_, snie_, _stür, акуа,
   {{0x6d4f0082,0xeb970202,0xea000019,0x27ed251a}},	//   _foca, њих_, _thập_, _aven_,
   {{0x6d4f251b,0x3236016b,0x00000000,0x00000000}},	//   _goca, כטען_, --, --,
   {{0xf74602e3,0x7c2603fd,0x6e930594,0x00000000}},	//   кедо, _uskr, _ملیا, --,
   {{0x7bd6251c,0x7d04251d,0x6d4f02d7,0x7c24251e}},	//   mpyu, lgis, _zoca, mwir,
   {{0x27ed0052,0xab6401d6,0x16020035,0x7c24251f}},	//   _even_, rlüğ, रंधर_, lwir,
   {{0x6d4f2520,0x00000000,0x00000000,0x00000000}},	//   _xoca, --, --, --,
   {{0x7c24033b,0x7bd6011e,0x872600af,0xd3a61b79}},	//   nwir, npyu, _имаж, кроп,
   {{0x4426008b,0x80dc0033,0x60cd0036,0x00000000}},	//   _vso_, _ভাগ্, _sfam, --,
   {{0x2b1404bc,0xd5af2521,0x81bc00ea,0xa26602fb}},	//   न्यु_, _вс_, evēr, тъпл,
   {{0x442601a9,0x7c240010,0x925700c3,0xd5e90037}},	//   _tso_, kwir, тают_, _أعلن_,
   {{0x6d4f2522,0x250b006c,0xf1c300ee,0x00000000}},	//   _roca, _آرمی_, _peší_, --,
   {{0x7c240069,0x656201ba,0x64a30200,0xc7b4016b}},	//   dwir, _hloh, _тача, רבֿ_,
   {{0xd3782523,0x798200a5,0x44240611,0xbcfb00f7}},	//   mić_, know, lwm_, _aléa,
   {{0xd3782524,0x7982004e,0x7d042525,0x9f59024e}},	//   lić_, jnow, ggis, musí_,
   {{0x6c542526,0x7c24018c,0x6562022f,0xd01102e7}},	// [1bd0] акту, gwir, _mloh, _الخ_,
   {{0xd3782527,0x7d042528,0xf0e30067,0x31792529}},	//   nić_, agis, _ख़ुद_, lisz_,
   {{0xdb050082,0x27ed252a,0x44240189,0xf8de022e}},	//   gmhá, _sven_, hwm_, मरूप,
   {{0x7c240232,0x50e3252b,0xd37800cd,0x9f421dab}},	//   bwir, परिष, hić_, mská_,
   {{0xd3780a78,0x9f42053d,0xbcfb0037,0x4424006d}},	//   kić_, lská_, _gléa, jwm_,
   {{0x66e20009,0xd3780a78,0x4908252c,0x628a252d}},	//   боша, jić_, _हाथो_, _oxfo,
   {{0x9f420076,0xd37801cc,0x2d55054e,0x65620298}},	//   nská_, dić_, _fået_, _bloh,
   {{0xdb1d0076,0x2d5501b4,0x442401e8,0x81bd00ea}},	//   _musí, _gået_, fwm_, zvēr,
   {{0xd378252e,0x3f83012e,0x6562252f,0xe70500f8}},	//   fić_, knju_, _dloh, _مسای,
   {{0x2902013c,0xd3780254,0x65622530,0x399c0093}},	//   _ökar_, gić_, _eloh, vísi_,
   {{0x3f8301cc,0x9f420334,0x6562033b,0x752b01a3}},	//   dnju_, jská_, _floh, _tagz,
   {{0x9f420187,0xf5300037,0xd4350d93,0x741200d1}},	//   dská_, _وإن_, _معتب, جویا,
   {{0xd3782531,0xa3df0567,0x4424001e,0x7d04045e}},	//   bić_, धीश_, cwm_, vgis,
   {{0xd378004e,0x2d992532,0x3f830207,0x00000000}},	//   cić_, _akse_, gnju_, --,
   {{0x31790035,0x79820035,0x81bd00ea,0xdb150355}},	//   bisz_, ynow, rvēr, _cizí,
   {{0x7c242533,0xbcfb0079,0xdb1d0097,0x6ed40f17}},	//   twir, _pléa, _dusí, _ब्रु,
   {{0x6da300af,0x09cc02cb,0x9db9005f,0x3f83012e}},	// [1be0] сита, ाऱ्य, тыру_, bnju_,
   {{0xfbcd00c8,0x7c242534,0x2122012f,0x2d990107}},	//   _লিখত, rwir, lekh_, _ekse_,
   {{0xe8fa2535,0x798207df,0x20022536,0x7c242537}},	//   еле_, tnow, luki_, swir,
   {{0xd3782531,0x786a00b5,0x88e600c3,0xa9670f7a}},	//   zić_, _növé, ужде, лиха_,
   {{0x2002011e,0xe3c801a5,0x4424006d,0x79822538}},	//   nuki_, _mực_, xwm_, rnow,
   {{0xe3c80028,0xdb1c00da,0xfee20033,0x79820035}},	//   _lực_, _mirë, _বাঁধ, snow,
   {{0x6b632539,0xd3780537,0xd6d901e0,0xb90a00c8}},	//   _укра, vić_, тті_, _মা_,
   {{0x7bc6253a,0x1db402cb,0xd378004e,0xbf9b0b88}},	//   _kuku, ंगित, wić_, ntêr,
   {{0xd3780a78,0xe6440463,0x7bc60054,0xa3df00a1}},	//   tić_, ılığ, _juku, धील_,
   {{0x2002253b,0x7bc619c7,0x4424001e,0x06b90033}},	//   duki_, _muku, rwm_, ঁড়ি,
   {{0xd3780a78,0x7bc6253c,0x3624006c,0x3f83025c}},	//   rić_, _luku, _خواہ, vnju_,
   {{0x2b140299,0xd3782527,0x9f420076,0xe3c80028}},	//   न्तु_, sić_, vská_, _cực_,
   {{0xd3782531,0x69c10248,0xf593004f,0x3f830254}},	//   pić_, _élev, _النج, tnju_,
   {{0x9f42024e,0x3179004e,0x63aa00d7,0x61fa0207}},	//   tská_, sisz_, _uhfn, prtl,
   {{0x3179004e,0x3f83011c,0x52370697,0x7bc60306}},	//   pisz_, rnju_, _مسيح_, _auku,
   {{0x7bc6253d,0x9f42024e,0x3cd5081b,0x3f830506}},	//   _buku, rská_, ржас, snju_,
   {{0x7bc6253e,0x3f83003a,0x20020009,0x00000000}},	// [1bf0] _cuku, pnju_, cuki_, --,
   {{0x7bc6043c,0x9f4200b8,0xa3e60433,0x332e009f}},	//   _duku, pská_, यीय_, _jafx_,
   {{0x8aa70009,0x0b88066d,0x2b140e6f,0xfaa7253f}},	//   урад, усти_, न्धु_, ушан,
   {{0xdc34024e,0x3835002d,0x2d9900be,0xf1c900e2}},	//   _zúča, инер, _ukse_, _hạc_,
   {{0x7bc62540,0xdb150139,0x00000000,0x00000000}},	//   _guku, _vizâ, --, --,
   {{0x290606a2,0x2b14210a,0x6d4d2541,0x28d50f06}},	//   agoa_, न्दु_, ljaa, _ड्रि,
   {{0x7bc601ae,0xcf580122,0xd0560095,0xf1c90019}},	//   _zuku, רבות_, _deyə, _mạc_,
   {{0xf1c90028,0x6d4d2542,0x69d52543,0xdd2100b8}},	//   _lạc_, njaa, _itze, _lůžk,
   {{0x7bc6021d,0x68eb0d0d,0x7ae72544,0xe3c80019}},	//   _xuku, magd, _kejt, _rực_,
   {{0x69c7000e,0x68eb057f,0xdced033e,0xdbd200ab}},	//   _kuje, lagd, ynağ, _rüüt,
   {{0x216a2545,0x67231b88,0xdb1c2546,0x75d10029}},	//   вини_, menj, _dirè, _bāze,
   {{0x69c700c8,0x672308b7,0xdc34016f,0x20022547}},	//   _muje, lenj, _súča, tuki_,
   {{0xe3c80028,0x66032548,0xf1c901a5,0x613b081b}},	//   _vực_, lunk, _bạc_, _sälä,
   {{0x7bc62549,0x2002254a,0x6723254b,0xdee3254c}},	//   _ruku, ruki_, nenj, жори,
   {{0x13da0b52,0x7bc6254d,0x20020388,0x799b09d6}},	//   _দিয়, _suku, suki_, _okuw,
   {{0x7bc6254e,0x6723254f,0x6446013c,0xdb1d0392}},	//   _puku, henj, åkig, _ausà,

   {{0x67231877,0x69d50291,0x64490391,0x68eb121e}},	// [1c00] kenj, _atze, nxei, dagd,
   {{0x67230888,0x66032550,0x65692551,0xaaba0609}},	//   jenj, kunk, hheh, ندار_,
   {{0x67230169,0x66032552,0x7ae72553,0x69c7025c}},	//   denj, junk, _dejt, _cuje,
   {{0x7bc62554,0xe3c801a5,0xd9100e3a,0x66032555}},	//   _tuku, _lựa_, ثیر_, dunk,
   {{0x38602556,0x6569002f,0x69d50065,0x290601a3}},	//   áir_, dheh, _etze, rgoa_,
   {{0x67232557,0x7ae72558,0xf1c900e2,0x799b073a}},	//   genj, _gejt, _xạc_, _ekuw,
   {{0xa2c402d1,0x660307cf,0x25fd0325,0x9f5900f7}},	//   रशस्, gunk, रंगी_, ursé_,
   {{0xb4c205e7,0x3f9801c0,0xa6e90019,0x60c400f8}},	//   ्डे_, horu_, _ngươ, _ngim,
   {{0x67232559,0xdb0705c9,0xdb1d1534,0x3f98255a}},	//   benj, _gijó, _husá, koru_,
   {{0x4aaa255b,0x60c4255c,0x69c0255d,0x67230bc6}},	//   _कराव, _agim, _hime, cenj,
   {{0x69c10332,0x69c0255e,0xe3c80019,0xa15901e0}},	//   _élet, _kime, _dựa_, гану_,
   {{0x69c0255f,0x506700c7,0xf1c90019,0x2c5e0029}},	//   _jime, атга, _sạc_, _kādā_,
   {{0x69c02560,0xb4c22561,0x938a01d3,0x8ca20722}},	//   _mime, ंशी_, _иска_, _खरगो,
   {{0x69c02562,0x09d70083,0x3f981e1a,0x2bb200a1}},	//   _lime, _হিসা, goru_, _जळगा,
   {{0x7ae72563,0xdef801c8,0xa18710b0,0x63640176}},	//   _rejt, шыя_, _выпл, _gòna,
   {{0x69c02564,0x6723040b,0x69c70160,0x7ae700b5}},	//   _nime, zenj, _ruje, _sejt,
   {{0x69c72565,0x2ac703fa,0x7ae7082d,0x66032566}},	// [1c10] _suje, аљев, _pejt, zunk,
   {{0x69c02567,0x6d4d0a43,0x69c701f7,0xaad2052f}},	//   _aime, sjaa, _puje, दुलक,
   {{0x67232568,0x69c02569,0xdb0f0176,0xc8790395}},	//   venj, _bime, _bucò, _ieşi_,
   {{0xdb0f02d7,0x69c700f4,0x98a900f4,0xb4c20b54}},	//   _pucó, _vuje, žač_, ्डो_,
   {{0xe8f8256a,0x67231a4c,0x7ae70038,0x68eb00a7}},	//   рлі_, tenj, _tejt, ragd,
   {{0x2fc901a9,0x69c7256b,0x6603256c,0x68eb256d}},	//   _muag_, _tuje, tunk, sagd,
   {{0x67230496,0x2fc901a9,0x69c00359,0x6569256e}},	//   renj, _luag_, _fime, theh,
   {{0x99850082,0x6603256f,0x67232570,0xe61600d8}},	//   _الرو, runk, senj, ёды_,
   {{0x66032571,0x681a0029,0x44392572,0x290d0176}},	//   sunk, gādā, ís_, _icea_,
   {{0x69c0000e,0x65692573,0x68e9001c,0xb4e60035}},	//   _zime, sheh, _heed, _बड़ी_,
   {{0xb63503c7,0xcb12011d,0x68e900be,0x69c02574}},	//   _دفاع, הלי_, _keed, _yime,
   {{0x68e9013a,0xd05d00a8,0x261c143a,0x3f980067}},	//   _jeed, lasə, _महती_, woru_,
   {{0x3f982575,0x3438006c,0x68e92576,0x2fc90189}},	//   toru_, _پسند_, _meed, _cuag_,
   {{0x68e9225f,0x50d806bc,0x98a00a78,0xf1cf00fa}},	//   _leed, _भ्रष, žić_, _संपन,
   {{0x25fd0084,0xc879002d,0xbcfb0320,0x00000000}},	//   रंटी_, _deşi_, _elém, --,
   {{0x68e90122,0xbf9b03e6,0x3f982577,0xc6920317}},	//   _need, quên, soru_, פאן_,
   {{0x69c02578,0x3f982579,0x7ff614ac,0x8c43002d}},	// [1c20] _rime, poru_, _اسبا, пете,
   {{0x290d002d,0x2b4301f7,0x00000000,0x00000000}},	//   _acea_, _cnjc_, --, --,
   {{0xcf5701f3,0xe80a0302,0x69c0257a,0x2fc90221}},	//   _הבית_, हूना_, _pime, _zuag_,
   {{0xb4e600c0,0x2fc90221,0xea000023,0x26c500ee}},	//   _बजे_, _yuag_, _nhấp_, _aglo_,
   {{0x69c00054,0x68e90f00,0x00000000,0x00000000}},	//   _vime, _deed, --, --,
   {{0xaa46257b,0xc4480118,0x681a0228,0x69c00371}},	//   _легл, ییان_, vādā, _wime,
   {{0x69c0257c,0x68e9257d,0x1b7b02b5,0x6b631397}},	//   _time, _feed, _עטלע, _экра,
   {{0xea0001a5,0x32050187,0xf3f80227,0x69c0257e}},	//   _chấp_, duly_, аниш_, _uime,
   {{0x7866257f,0x00000000,0x00000000,0x00000000}},	//   _указ, --, --, --,
   {{0x681a0080,0x2fc92580,0x68e90051,0x00000000}},	//   rādā, _ruag_, _zeed, --,
   {{0x6b9b02b5,0xcb9b0d85,0x320507df,0x681a00ec}},	//   רשיד, רסיט, guly_, sādā,
   {{0x2fc90189,0xe5722499,0x21672581,0x00000000}},	//   _puag_, _عطا_, стог, --,
   {{0x2fc9006d,0xf8ba1022,0x91ca051d,0x00000000}},	//   _quag_, ेशिय, _संवै, --,
   {{0x2fc9006f,0x995c0355,0x320500d5,0x25ef0099}},	//   _vuag_, jíž_, buly_, ींची_,
   {{0xf1c90028,0x995c0355,0x00000000,0x00000000}},	//   _hạn_, díž_, --, --,
   {{0x2fc92582,0xf1c90023,0x0dc8021d,0x00000000}},	//   _tuag_, _kạn_, сури_, --,
   {{0x68e92583,0xd05d01c2,0x3b5507bc,0x00000000}},	// [1c30] _reed, yasə, окар, --,
   {{0xf1c90019,0x68e92584,0xdb050079,0x88d20033}},	//   _mạn_, _seed, lmhú, ারফক,
   {{0x9d192585,0x6aba008d,0x2d8b0183,0x68e92586}},	//   _конт_, _útfl, _tjce_, _peed,
   {{0xad270416,0x9f520260,0xbcfb00b8,0x8ed80609}},	//   _اردو, _avyè_, _mlék, _پذیر_,
   {{0xf1c901a5,0xbae80083,0xb4e60461,0x31690506}},	//   _nạn_, _পারছ, _बड़े_, _mlaz_,
   {{0x7c2f0133,0xe7390204,0x45d51784,0xaded0324}},	//   _iscr, рек_, оцит, _जबान_,
   {{0x636d2587,0x68e900ab,0x27e00228,0x00000000}},	//   _húng, _teed, ģina_, --,
   {{0xf1c9098b,0xf7732588,0x160b0035,0xf1cf1140}},	//   _bạn_, _کار_, संबर_, _संबन,
   {{0x25fd0437,0xf1c90023,0xe70b0088,0x7c3b00cd}},	//   रूजी_, _cạn_, _متان_, _šurj,
   {{0x32050187,0x6d93003c,0x31690051,0xf1c900e2}},	//   tuly_, lħad, _alaz_, _dạn_,
   {{0xea0001a5,0xe12613a1,0x316902a7,0x00000000}},	//   _thấp_, омни, _blaz_, --,
   {{0x26130370,0x241900c3,0x8cd91119,0x61fc2589}},	//   mão_, _воды_, _फ्लो, árla,
   {{0x26130370,0x00000000,0x00000000,0x00000000}},	//   lão_, --, --, --,
   {{0x88ba00a5,0xfe460210,0x442f008e,0x53340421}},	//   יזרי, онго, _isg_, _нечт,
   {{0x3ebe258a,0x26130279,0x442f258b,0x443d258c}},	//   ätt_, não_, _hsg_, _hrw_,
   {{0x443d1ae2,0x9f4200a0,0xf1c900e2,0x3cf600ab}},	//   _krw_, nskú_, _hạo_, ेलें_,
   {{0xdca3258d,0x26130132,0x636d0079,0x00000000}},	// [1c40] дати, hão_, _cúng, --,
   {{0x443d258e,0x1dd20067,0x670e258f,0x69cb00ab}},	//   _mrw_, _दंपत, _साधक_, _तूही,
   {{0x26130279,0x2d9e00f7,0xf1c90023,0x442f102f}},	//   jão_, îtes_, _mạo_, _lsg_,
   {{0x8c460346,0x26130370,0x443d073a,0x00000000}},	//   _деме, dão_, _orw_, --,
   {{0x274a2590,0x6d462591,0x443d01ae,0x00000000}},	//   ичко_, _inka, _nrw_, --,
   {{0x29d7009f,0x26130132,0xf1c900e2,0x2b3a00af}},	//   _bħad_, fão_, _nạo_, _тямэ_,
   {{0x26130370,0xf1c901a5,0xa3e2020d,0xc2e80033}},	//   gão_, _sạn_, _फौज_, _খালি_,
   {{0x54541109,0x2240023a,0xdb1c01ef,0x442f2592}},	//   звит, _čik_, _mirí, _bsg_,
   {{0x68e22593,0xf1c90019,0x18672594,0x6d46030d}},	//   mbod, _bạo_, _дати_, _mnka,
   {{0x2d6801d6,0xf1c90023,0x26130279,0x68e20185}},	//   rşey_, _vạn_, bão_, lbod,
   {{0x31692595,0x26130279,0xf1c90019,0x443d2596}},	//   _plaz_, cão_, _dạo_, _erw_,
   {{0xdb1d02c9,0x68e22597,0x443d0010,0x2efa021d}},	//   _zusä, nbod, _frw_, _adpf_,
   {{0xdb1c0079,0x98c50009,0x00000000,0x00000000}},	//   _airí, šuća_, --, --,
   {{0x6d462598,0x53340705,0xf1c90019,0x59ca018d}},	//   _anka, _хект, _gạo_, िदार,
   {{0xdb1c01ef,0x9e34002d,0xa2da022e,0xcdd80274}},	//   _cirí, мерч, पुण्, жњу_,
   {{0xdb1c0b4c,0x31690254,0xd65700a5,0xdb1d03d0}},	//   _dirí, _ulaz_, חילת_, _muså,
   {{0x261303e6,0x2d890098,0x69de0a8a,0x636d0042}},	// [1c50] zão_, rnae_, eppe, _fúnd,
   {{0x6d462599,0xfaa70b00,0x8aa7117a,0x628b00cd}},	//   _enka, ошен, оред, šloš,
   {{0x26130370,0x2d5c01ef,0x539b00a5,0x00000000}},	//   xão_, _cíes_, סיבו, --,
   {{0xa2da143a,0x26130279,0x68e20282,0x2d5c0176}},	//   पुत्, vão_, gbod, _díes_,
   {{0xf745259a,0x69de0036,0x8ca20026,0x9cd6011d}},	//   зело, appe, _कुपो, _מורה_,
   {{0x261300c9,0x7d0d259b,0x7c2d259c,0x442f03bc}},	//   tão_, lgas, mwar, _rsg_,
   {{0xf99303c7,0xf1c600b4,0x7d0d0065,0x00000000}},	//   _قبر_, _रंगन, ogas, --,
   {{0x261300c9,0x7d0d259d,0x442f259e,0x2002008d}},	//   rão_, ngas, _psg_, yrki_,
   {{0x261300c9,0x7c2d259f,0x68fb010d,0xe80a046c}},	//   são_, nwar, _idud, हूदा_,
   {{0x31b606fe,0x261303e6,0x6d930484,0x77ad01ef}},	//   ृद्ध, pão_, nħab, búxa,
   {{0xe29925a0,0x7c2d25a1,0x636d0037,0x00000000}},	//   сан_, hwar, _rúnd, --,
   {{0x661c00be,0x3a3100b5,0xea0000e2,0x442f0110}},	//   _ärka, _mszp_, _chẹp_, _tsg_,
   {{0xf1c900e8,0x555200b5,0x81cc0083,0x645d01ae}},	//   _tạo_, _سپور, শীল_, äsid,
   {{0x442d25a2,0x7c2d25a3,0x752925a4,0xdc3a0095}},	//   mwe_, dwar, leez, xçıv,
   {{0x442d25a5,0xf2d202b5,0x2ca700a8,0x68e225a6}},	//   lwe_, _טעג_, əndi_, ybod,
   {{0x7d0d25a7,0x442d0035,0x636d01ef,0xdb1c25a8}},	//   ggas, owe_, _dúne, _virí,
   {{0x7c2d25a9,0x442d25aa,0x2b5825ab,0xed570370}},	// [1c60] gwar, nwe_, _porc_, чот_,
   {{0x636d25ac,0x7d0d25ad,0xf1c90023,0x442d25ae}},	//   _fúne, agas, _lạm_, iwe_,
   {{0xa9261eea,0x68e20051,0x442d25af,0xdb1c0183}},	//   здел, tbod, hwe_, _pirâ,
   {{0x442d25b0,0xfc3f0093,0xc7c60798,0x31b2053d}},	//   kwe_, _frí_, пски, báze_,
   {{0x6846061c,0x442d070b,0x07a61641,0x68e225b1}},	//   янда, jwe_, падн, rbod,
   {{0xe3a70e0c,0x501b0122,0x442d0107,0x656b25b2}},	//   _سر_, מונו, dwe_, _algh,
   {{0x442d0173,0xbcfb0037,0x00000000,0x00000000}},	//   ewe_, _sléi, --, --,
   {{0x69ce0043,0x6b9e0b3e,0x75290273,0xbcfb0079}},	//   _iube, lopg, geez, _pléi,
   {{0x442d0aee,0xa3e60324,0x69dc009e,0xdb1c021d}},	//   gwe_, यीं_, _htre, _girã,
   {{0x69ce0c1b,0x27f7000c,0xb4ac0311,0x798225b3}},	//   _kube, ření_, _गरी_, liow,
   {{0xcfc40083,0x442d25b4,0xe3b8037a,0x7c2d25b5}},	//   ্ঠান, awe_, rmı_, zwar,
   {{0x442d25b6,0x7982004e,0x69ce25b7,0xe3b8027d}},	//   bwe_, niow, _mube, smı_,
   {{0x69ce25b8,0x43460e0a,0x6b9e0a8a,0x24490286}},	//   _lube, _недв, kopg, _وجهي_,
   {{0x7aee00d7,0x69ce0103,0x00000000,0x00000000}},	//   _nebt, _oube, --, --,
   {{0xd78800e8,0x21200129,0x69ce0300,0x070500b4}},	//   yển_, _fbih_, _nube, _राघव_,
   {{0xbcfb00de,0x7d0d25b9,0x7aee0065,0x7c2d25ba}},	//   _llév, ugas, _aebt, twar,
   {{0x7d0d25bb,0x2d581470,0x69ce25bc,0x212b25bd}},	// [1c70] rgas, чить_, _aube, mech_,
   {{0x212b25be,0x69ce030d,0x7c2d1425,0x65a5006c}},	//   lech_, _bube, rwar, róhi,
   {{0x442d25bf,0x69ce25c0,0x7c2d08eb,0x3f8325c1}},	//   zwe_, _cube, swar, miju_,
   {{0xfc3f25c2,0x212b25c3,0x69ce25c4,0x442d25c5}},	//   _trí_, nech_, _dube, ywe_,
   {{0xf7700148,0x69dc25c6,0x201925c7,0x200b00cb}},	//   گان_, _etre, ntsi_, nuci_,
   {{0xf09402b5,0x3f830d77,0x7bdd25c8,0xb6a502ee}},	//   ענס_, niju_, _itsu, милл,
   {{0xf77005bc,0x442d053e,0x69ce00a1,0xa3c207b5}},	//   دان_, wwe_, _gube, ्दन_,
   {{0x442d19c7,0x3f8325c9,0x7982004e,0xbcfb25ca}},	//   twe_, hiju_, ciow, _elév,
   {{0x442d25cb,0x200b25cc,0x69ce25cd,0x212b01c0}},	//   uwe_, juci_, _zube, dech_,
   {{0xe1f91109,0x442d25ce,0x200b25cf,0xd2f7006c}},	//   ого_, rwe_, duci_, سکتا_,
   {{0x3f8311c6,0x442d01d5,0x7bc725d0,0xf1c901a5}},	//   diju_, swe_, _miju, _tạm_,
   {{0x290f0464,0x7bdd0006,0xdb1c02d7,0x442d25d1}},	//   ngga_, _otsu, _mirá, pwe_,
   {{0x7bdd01a9,0xbf9b03e6,0x3f8325d2,0x41cf018d}},	//   _ntsu, rrên, fiju_, _संवस,
   {{0x3f830a78,0x1b030033,0x7bc7023c,0x16210253}},	//   giju_, র্তে_, _niju, _महार_,
   {{0x7bcf1010,0x7bdd25d3,0x212b25d4,0xddd400a0}},	//   _aucu, _atsu, bech_, ňažn,
   {{0x7bcf09eb,0xc6920070,0x2019006f,0x29f801ba}},	//   _bucu, דאל_, btsi_, vča_,
   {{0x67211038,0x7bc725d5,0x1fb60210,0x3f8325c1}},	// [1c80] _oblj, _biju, _осор, biju_,
   {{0x3f8325d6,0x09e6172a,0x2c0b00b5,0x7bcf0371}},	//   ciju_, дожн, تعفی_, _ducu,
   {{0x7bc71b0f,0xed5a079d,0x69ce013b,0x00000000}},	//   _diju, _дон_, _qube, --,
   {{0x7aee25d7,0xdb1c0300,0x7bcf0211,0x2d8500fd}},	//   _webt, _dirá, _fucu, élet_,
   {{0xb4ac000c,0x7bcf0010,0x2baf25d8,0x38cb25d9}},	//   _गरे_, _gucu, _जीवा, زانی_,
   {{0x212b04aa,0x7bc7012f,0x29f80cc2,0x5b35002d}},	//   zech_, _giju, pča_, _пэсу,
   {{0x69dc25da,0x8b0301c0,0x7bcf0036,0x79820035}},	//   _utre, _úřad, _zucu, piow,
   {{0x3f8325c1,0xd8260431,0x7bc725db,0xdb070328}},	//   ziju_, _одби, _ziju, _ehjä,
   {{0xf8b20084,0x212b25dc,0x764100e9,0x7bc70371}},	//   _जरिय, vech_, _erly, _yiju,
   {{0xd37010ee,0x200b0c21,0x74150118,0x212b016e}},	//   اهد_, vuci_, روپا, wech_,
   {{0x212b25dd,0xa2da25de,0x3f830eac,0x63a825df}},	//   tech_, पुष्, viju_, rldn,
   {{0x80fb1cce,0xe7f50035,0x63640392,0x200b25e0}},	//   ्लेख_, ुंचा_, _mòni, tuci_,
   {{0x212b25e1,0x3f8325e2,0x320500a5,0xbcfb0118}},	//   rech_, tiju_, arly_, _mlét,
   {{0xa2940a93,0x442625e3,0x212b00b8,0x200b00cd}},	//   _палі, _ipo_, sech_, ruci_,
   {{0x3f8325d6,0x7bcf25e4,0x13e30083,0x290f014e}},	//   riju_, _sucu, _মিয়, ygga_,
   {{0x3f8325e5,0x7bc7000e,0x7bcf1034,0xa2da20ab}},	//   siju_, _siju, _pucu, पुर्,
   {{0x3f83180c,0x7bc725e6,0x60cd01d5,0x9f420314}},	// [1c90] piju_, _piju, _igam, lský_,
   {{0x09b9012f,0x442625e7,0x798025e8,0x00000000}},	//   ेद्य, _mpo_, _ammw, --,
   {{0x9f4205d3,0x752225e9,0x7bc725ea,0x291d021e}},	//   nský_, _oboz, _viju, tfwa_,
   {{0x4adf114e,0x1adf09a8,0x394909ab,0x7bcf25eb}},	//   _प्रव, _प्रथ, ñas_, _tucu,
   {{0x44260221,0x636d004f,0x7bc725ec,0xba7403c5}},	//   _npo_, _lúna, _tiju, _یافت,
   {{0xbcfb03e6,0xdb1c25ed,0x63640107,0x75220027}},	//   _elét, _tirá, _fòni, _aboz,
   {{0x4426071f,0x60cd25ee,0x9f420187,0xe5a525ef}},	//   _apo_, _ogam, jský_, ники,
   {{0x60cd25f0,0x77ad01dd,0x9f420187,0x644223e8}},	//   _ngam, púxo, dský_, _broi,
   {{0x6d5d25f1,0x644225f2,0x20fb0067,0x3f8111cb}},	//   _mosa, _croi, ्लैश_, _omhu_,
   {{0x64421079,0x60cd25f3,0xf1c901a5,0x442625f4}},	//   _droi, _agam, _hại_, _dpo_,
   {{0x636d0037,0x64421315,0x442625f5,0xdb050037}},	//   _cúna, _eroi, _epo_, lmhó,
   {{0x6d5d25f6,0x644225f7,0x27ed02d0,0x44261c35}},	//   _nosa, _froi, _kwen_, _fpo_,
   {{0xf1c90028,0x27ed02e9,0x60cd02d7,0x65690e0e}},	//   _mại_, _jwen_, _dgam, mkeh,
   {{0x27ed0c05,0xf1c900e8,0x443f0232,0x257101c0}},	//   _mwen_, _lại_, mvu_, _dále_,
   {{0x6d5d25f8,0x443f25f9,0x27ed02e9,0xf8a502fd}},	//   _bosa, lvu_, _lwen_, _چک_,
   {{0x6d5d25fa,0x753b25fb,0xed5725fc,0xf65202b5}},	//   _cosa, nduz, нос_, נצן_,
   {{0x6d5d25fd,0x443f0273,0xf1ca0019,0x4095002d}},	// [1ca0] _dosa, nvu_, _nại_, _арэт,
   {{0x5ba70043,0x99710067,0x909b00a5,0x00000000}},	//   екум_, jął_, _מספק, --,
   {{0x09062462,0x37090066,0xa3c025fe,0xbcfb1f55}},	//   епен, _साड़ी_, ंगत_, _boéd,
   {{0x443f01cc,0x7e61022a,0xf1ca0019,0x63a125ff}},	//   kvu_, älpe, _bại_, holn,
   {{0x63a12600,0x9f4200b8,0x69c92601,0x443f0009}},	//   koln, zský_, _diee, jvu_,
   {{0xb90700b4,0xf1ca0023,0x27ed0107,0x78a90260}},	//   _म्_, _dại_, _dwen_, _dyev,
   {{0xe5c60945,0x443f0d5e,0x27ed0211,0x44262602}},	//   нсио, evu_, _ewen_, _spo_,
   {{0x9f420076,0xdb1c01d6,0x636d2603,0xd5b70f99}},	//   vský_, _birç, _rúna, нсы_,
   {{0x70af1db1,0x27ed123d,0xbcfb00e0,0xe4522604}},	//   _घरेल, _gwen_, _klér, اضع_,
   {{0x88831fba,0x9f42024e,0x320c0159,0xbf9b0248}},	//   _служ, tský_, tudy_, trêm,
   {{0x25710097,0x66e30210,0x69c900e0,0x00000000}},	//   _sále_, _соха, _yiee, --,
   {{0x3202114d,0x64422605,0x9f420237,0x61e40009}},	//   čky_, _troi, rský_, _čild,
   {{0x38660443,0x63a1078a,0x44262606,0x25a60069}},	//   nyor_, boln, _upo_, _ikol_,
   {{0x6d5d2607,0xbf9b000d,0x9f421dab,0x00000000}},	//   _sosa, prêm, pský_, --,
   {{0xf1a72608,0x673a2609,0x64470029,0x1c03007c}},	//   _прин, _matj, ājie, _लिहल_,
   {{0x5ba921b2,0xbcfb1417,0x60cd260a,0x29d70024}},	//   कत्व, _alér, _ugam, _bħan_,
   {{0xfbd318dd,0x6d5d0443,0x6386000d,0xbcfb0118}},	// [1cb0] اتر_, _vosa, _génè, _roéd,
   {{0x673a029d,0xbcfb002a,0xf1bf0042,0x78bd00ac}},	//   _natj, _clér, lmá_, _úsvi,
   {{0x6d5d0082,0x61fa02c9,0x69c90080,0x27ed02e9}},	//   _tosa, nstl, _piee, _swen_,
   {{0xbcfb006c,0x27ed02e9,0xfaa40036,0x25a6023a}},	//   _elér, _pwen_, ушун, _nkol_,
   {{0xe7390f94,0xa3c20311,0xa3c004cc,0x29d7003c}},	//   дел_, ्दा_, ंगा_, _għan_,
   {{0xdb050037,0x25a61388,0x61fa260b,0x00000000}},	//   rmhó, _akol_, kstl, --,
   {{0x63a10314,0x673a01bf,0xf1bf00d5,0x00000000}},	//   voln, _datj, kmá_, --,
   {{0xf1ca00e8,0x443f0121,0x63a10035,0xa3cc0440}},	//   _tại_, tvu_, woln, _शंख_,
   {{0x02c9065f,0x656902c9,0xe3b912f3,0x210401c8}},	//   रश्न, rkeh, мби_, nčių_,
   {{0x443f260c,0x6569260d,0x2104010b,0x00000000}},	//   rvu_, skeh, ičių_, --,
   {{0x779009b9,0x3dcb00d7,0x443f260e,0xc0e6260f}},	//   _دیوا, _oicw_, svu_, конк,
   {{0x395f021e,0x63a100fd,0x638600a2,0x673a0207}},	//   _jous_, soln, _pénè, _zatj,
   {{0x63a1108a,0x62980176,0x61e4011c,0x395f00f6}},	//   poln, _exvo, _čile, _mous_,
   {{0x25ad2610,0x25a015d7,0x25bf002d,0x395f0260}},	//   llel_, čile_, lmul_, _lous_,
   {{0xe3c80019,0xbea62611,0x539a011d,0x394d00a5}},	//   _cựu_, тавк, _קיצו, _ones_,
   {{0x395f2612,0x41b6006c,0xa5c20093,0x6386000d}},	//   _nous_, _جمعر, _þótt, _ténè,
   {{0x636d0168,0x29d7013b,0x91bb00a5,0xbcfb00f6}},	// [1cc0] _júno, _aça_, _קמפי, _plér,
   {{0x09ca04cc,0x395f009e,0x394d0c6f,0x00000000}},	//   िद्य, _aous_, _anes_, --,
   {{0xc3320122,0x395f2613,0x673a0051,0x00000000}},	//   שוב_, _bous_, _ratj, --,
   {{0x395f0036,0x02b60070,0x394d216e,0x3866013b}},	//   _cous_, דלעך_, _cnes_, tyor_,
   {{0x395f2614,0x394d086d,0x261406bb,0x673a2615}},	//   _dous_, _dnes_, नूनी_, _patj,
   {{0x25a62616,0xbf9b0248,0x186703fa,0x394d2617}},	//   _skol_, quêt, ђаји_, _enes_,
   {{0xe9d70009,0x2bd80f8a,0x6aa301ae,0x395f000d}},	//   _акс_, _भंडा, ünft, _fous_,
   {{0x316001d7,0x2d922618,0x2ef8033b,0x395f1080}},	//   _noiz_, nnye_, harf_, _gous_,
   {{0x47c600d8,0xd0e30f9f,0x41cf00ab,0x00000000}},	//   _абав, _क्षण_, _संउस, --,
   {{0xbcfb0176,0x31bd1371,0x316001ed,0x63760139}},	//   _llép, ोद्ध, _aoiz_, _mâng,
   {{0xcb130122,0x2ef801ae,0x27e600d1,0x6376002d}},	//   בלת_, darf_, lpon_, _lâng,
   {{0x25a60dc3,0x2bd80e61,0x00000000,0x00000000}},	//   _ukol_, _भूभा, --, --,
   {{0x27e62619,0xf1bf0952,0x3a380211,0x00000000}},	//   npon_, rmá_, _lsrp_, --,
   {{0x29d70484,0x27e6010d,0x00000000,0x00000000}},	//   _bħal_, ipon_, --, --,
   {{0xd24f00f3,0x636d0037,0xc333011d,0x3da703e6}},	//   _ونه_, _múnl, _כוס_, враб,
   {{0x316001a3,0xa3c0021a,0x463b016b,0x00000000}},	//   _goiz_, ंगव_, ועלע, --,
   {{0x0dc80b07,0x4ec50033,0xc05b01e0,0x00000000}},	// [1cd0] тури_, ্রেল, _цій_, --,
   {{0x395f261a,0x2571261b,0x2d92018e,0xe3c80023}},	//   _sous_, _mála_, anye_, _tựu_,
   {{0x29d72251,0xe805045c,0x210400d8,0x395f261c}},	//   _għal_, _रिहा_, sčių_, _pous_,
   {{0x67d5261d,0x26de0312,0x00000000,0x00000000}},	//   году, _afto_, --, --,
   {{0x395f168b,0x6d4f261e,0xd825261f,0x63761bec}},	//   _vous_, _inca, удли, _gâng,
   {{0xf1ca01a5,0xa3b20084,0x394d016e,0x00000000}},	//   _hạt_, _झील_, _wnes_, --,
   {{0x395f105d,0x637600af,0x00000000,0x00000000}},	//   _tous_, _mând, --, --,
   {{0x224901cc,0x394d12c3,0x84590370,0x25711534}},	//   _čak_, _unes_, ерот_, _bála_,
   {{0xc9841f9b,0x25bf2620,0x7af501ed,0xf1ca00e2}},	//   _тури, rmul_, _kezt, _mạt_,
   {{0x25bf0043,0x25ad0187,0xf1ca0019,0x69d52621}},	//   smul_, slel_, _lạt_, _kuze,
   {{0x75150514,0x6d4f01cb,0x200b0035,0xa18a117a}},	//   _مواض, _onca, erci_, ебна_,
   {{0x69d52622,0x9f5e0355,0xdb1d02b1,0xd00a0f8c}},	//   _muze, čtí_, _ausü, неме_,
   {{0x69d52623,0x2d890118,0xe44e0a2b,0x63640392}},	//   _luze, diae_, _уж_, _còns,
   {{0x6d4f00c1,0x63762624,0x77ad002a,0x00000000}},	//   _anca, _când, fúxi, --,
   {{0xa3c20299,0x200b07e5,0x63760395,0xf1ca0023}},	//   ्दर_, arci_, _sâng, _bạt_,
   {{0xcd3600b5,0x22470009,0x261400a1,0x63760160}},	//   درآب, _irnk_, नंती_, _pâng,
   {{0x69d50139,0xf1ca00e2,0x1c46010b,0x7de9021e}},	// [1ce0] _auze, _dạt_, ынам, _pèsò,
   {{0x6d4f1083,0x69d52625,0x63760043,0x3a38023c}},	//   _enca, _buze, _gând, _psrp_,
   {{0xd9462626,0x68e40138,0x22f6016b,0x27ff0328}},	//   лежи, ñido, רזען_, _avun_,
   {{0x2d8901ef,0xed5718a4,0xf1ca0023,0x69d52627}},	//   ciae_, _бою_, _gạt_, _duze,
   {{0x27e60069,0x77610042,0xb6c800b5,0xe7860200}},	//   upon_, _bolx, ھاتے_, луко,
   {{0x7d162628,0x3f8a00ec,0x224702a7,0x07a31b60}},	//   lgys, nibu_, _ornk_, бачн,
   {{0x27e62629,0x2bd800e7,0xe1e7006c,0x2a350043}},	//   spon_, _भूता, _دس_, _кэтр,
   {{0x7bce0464,0x78b1008d,0x636d0079,0x3f8a08c7}},	//   _hibu, ðkvæ, _dúnm, hibu_,
   {{0x7bce262a,0x69d503cb,0xb716004f,0xa3c202cb}},	//   _kibu, _zuze, _مباش, ्दल_,
   {{0x3f8a0657,0x14c000e7,0x69c22069,0x28b9002d}},	//   jibu_, शेषण, lmoe, _русэ_,
   {{0x6b7b02b5,0x200002c4,0x2d5c215f,0x6376002d}},	//   גרינ, _avii_, _díez_, _rând,
   {{0x84461d05,0x7bce0635,0xdb1c2314,0x69c20b0d}},	//   _مختل, _libu, _cirú, nmoe,
   {{0x200b000d,0x2000009e,0x133900b5,0x63760139}},	//   urci_, _cvii_, رتیں_, _pând,
   {{0x447b0779,0x6562008c,0x7bce0010,0xf1ca00e2}},	//   _אנדע, _hooh, _nibu, _sạt_,
   {{0x2904025c,0x63030037,0x63760139,0x1b1a0033}},	//   _odma_, _طويل, _vând, ড়াই_,
   {{0x69d50add,0x7bce08c7,0x69c20051,0xfbdf00e5}},	//   _ruze, _aibu, jmoe, _drên_,
   {{0x7bce2107,0x69d50fd4,0x3f8a262b,0x29d70069}},	// [1cf0] _bibu, _suze, bibu_, _għaj_,
   {{0x7bce262c,0x34d1007c,0x59d902e4,0x2904262d}},	//   _cibu, _हल्द, _बंदर, _adma_,
   {{0x5a35262e,0x7bce0ce8,0x5f7400f3,0xf1ca00e2}},	//   рнет, _dibu, _داير, _tạt_,
   {{0xe9ab00f8,0x69c21e7e,0xe0df0036,0x6aae008c}},	//   ردان_, gmoe, ncò_, _dybf,
   {{0x68f9006a,0xf8071346,0x21290703,0x69da0248}},	//   rawd, учен, _mbah_, _éten,
   {{0x7bce03be,0x68f9001e,0xf745262f,0x69d52630}},	//   _gibu, sawd, реко, _tuze,
   {{0x7f3c02b5,0xfaa90413,0x9c8700d5,0x212900f8}},	//   געוו, _شهري_, bočí, _obah_,
   {{0x3f8a0273,0xdb15002a,0x7bce2631,0x05651e1d}},	//   zibu_, _tizó, _zibu, рвин,
   {{0x6562022e,0xa3c2012f,0x7bce01d5,0x320b0035}},	//   _dooh, ्दं_, _yibu, ącym_,
   {{0x25a0068b,0x42252632,0x21292633,0x2bd822a7}},	//   čila_, адов, _abah_, _भंसा,
   {{0xe29907be,0x45d52634,0xe3b6002d,0x00000000}},	//   тан_, _тоес, рбэ_, --,
   {{0x69d803e6,0x798b2635,0xa06a0274,0x00000000}},	//   ívei, nigw, вама_, --,
   {{0x3f8a0657,0x671c0e7f,0x320c0d14,0x00000000}},	//   tibu_, _नामक_, ardy_, --,
   {{0xb4c10821,0x224702c4,0x21292636,0x798b01d5}},	//   ंधी_, _trnk_, _ebah_, higw,
   {{0x3f8a0657,0x7bce06b3,0x0fc302ce,0x65622637}},	//   ribu_, _ribu, ійсн, _yooh,
   {{0x4aa90084,0x2571053d,0xb04a021d,0xe0df027a}},	//   _कड़व, _málo_, _азиз_, ccò_,
   {{0x3b8600d8,0x9c8700a0,0x7d160987,0x00000000}},	// [1d00] алаг, vočí, rgys, --,
   {{0xfbdf00e8,0xdcf610b1,0x1db80099,0x7bce0103}},	//   _trên_, ıcın, _आठवत, _qibu,
   {{0x69c20136,0x27e4012f,0x7bce2638,0x25780051}},	//   tmoe, _stmn_, _vibu, _héle_,
   {{0x27e4022e,0xc8ca0125,0xfd120037,0x7bce04fb}},	//   _ptmn_, نوان_, _بجد_, _wibu,
   {{0x7bce03be,0x69c202e6,0x97c6172a,0xa01b033b}},	//   _tibu, rmoe, айде, rzög,
   {{0x6376002d,0x69c22639,0x00000000,0x00000000}},	//   _mânc, smoe, --, --,
   {{0x9c87024e,0x656200fe,0xbcfb0118,0x798b263a}},	//   počí, _pooh, _moén, bigw,
   {{0x290401a2,0xa4f8042c,0x00000000,0x00000000}},	//   _udma_, اکار_, --, --,
   {{0x68ed0138,0xdb1c0044,0xa3e70274,0x00000000}},	//   ñade, _birø, адња_, --,
   {{0xf366263b,0x765500b5,0x00000000,0x00000000}},	//   ртин, ógyí, --, --,
   {{0x1b0300c8,0x0bb70122,0x81de0033,0xa2c905f8}},	//   র্কে_, שלים_, দীন_, _हृद्,
   {{0x672d00cd,0x51f71667,0x00000000,0x00000000}},	//   đaje, шнюю_, --, --,
   {{0x04140083,0x63760279,0xe0df027a,0x5064263c}},	//   _তৈরী_, _cânc, rcò_, отра,
   {{0x93fb0052,0x63760160,0x1ee713cf,0x25780355}},	//   _ילדי, _dânc, شوری_, _déle_,
   {{0x63a82182,0x59a602e4,0x00000000,0x00000000}},	//   modn, गकार, --, --,
   {{0x21290ec0,0x2baf0b4d,0x257800b5,0x00000000}},	//   _ubah_, _जीजा, _féle_, --,
   {{0x91bc00a5,0x00000000,0x00000000,0x00000000}},	// [1d10] _במהי, --, --, --,
   {{0x3b54263d,0x8ae702ce,0x3f152626,0x2d8c000d}},	//   окур, ріал, _удос, éder_,
   {{0xcfe20083,0x69da00b5,0x2d990183,0x2bc8263e}},	//   _বিএন, _étel, _tjse_, руто_,
   {{0x63a8201b,0xac95005f,0x00000000,0x00000000}},	//   hodn, _гамш, --, --,
   {{0x8d5a0052,0x63a805e2,0x66e5021d,0x41d000b8}},	//   _עכשי, kodn, бола, _संघस,
   {{0xcc3a00c2,0xdc3a00c2,0xf1ca0023,0x798b0651}},	//   _געשט, _געשר, _lạp_, sigw,
   {{0x798b000e,0xaac30067,0x6446008d,0xa3c00387}},	//   pigw, वेशक, ækin, ंगई_,
   {{0xf1ca0019,0x1e980277,0x00000000,0x00000000}},	//   _nạp_, יכול_, --, --,
   {{0x79890054,0x26130d2a,0xe80e00ab,0xa2c9178c}},	//   _imew, _धमकी_, _सिया_, हेन्,
   {{0xf7731c0c,0x63a8263f,0xc6a70166,0x78bb00f4}},	//   _بار_, godn, _креи, _izuv,
   {{0x636d2640,0x216a0812,0x61460f8c,0x00000000}},	//   _júni, гини_, бена, --,
   {{0x249d0189,0x636d20d9,0xdb0501ff,0xf1ca00e2}},	//   _txwm_, _múni, llhä, _cạp_,
   {{0x63a80690,0x636d0176,0x23291d30,0x2418010b}},	//   bodn, _lúni, _боли_, _вочы_,
   {{0x2bdb0953,0xdee32641,0x442f00d7,0x53341583}},	//   _बढ़ा, зори, _ipg_, _мечт,
   {{0x2bbd20af,0x3cf9008c,0x7c3d0282,0x22581788}},	//   ्गना, _besv_, _assr, ärkt_,
   {{0xf1d025d8,0xa1930798,0x1c030006,0x442f0159}},	//   _सूचन, _најч, _लिखल_, _kpg_,
   {{0x443d2642,0x00000000,0x00000000,0x00000000}},	// [1d20] _jsw_, --, --, --,
   {{0xf3f912eb,0x20021577,0x79890054,0x636d0093}},	//   _আমার_, mski_, _amew, _búni,
   {{0x20020fe2,0x6e4601ca,0x25710093,0x7c3d0036}},	//   lski_, _انجم, _páll_, _essr,
   {{0x9f49064b,0xf8fa0037,0x442f008c,0x08c6002d}},	//   _hvað_, اءات_, _opg_, ббен,
   {{0x200202dd,0x657b2643,0xbf9b000d,0x443d0f00}},	//   nski_, dhuh, prêt, _nsw_,
   {{0x6d440291,0x394000d8,0x7c242644,0x00000000}},	//   ldia, žis_, mtir, --,
   {{0x644b2645,0x443d2646,0x8afb02b8,0x65be00da}},	//   _argi, _asw_, _תהלי, hëhe,
   {{0x25a0108a,0x63a8004e,0xb996004f,0x7afe2647}},	//   čilo_, wodn, _الرب, lapt,
   {{0x20022648,0x7c242649,0x442f264a,0xf1ca0019}},	//   jski_, ntir, _cpg_, _rạp_,
   {{0x20020496,0x7afe264b,0x68e20223,0xf1ca0023}},	//   dski_, napt, lcod, _sạp_,
   {{0x63a82648,0x7c24264c,0x869a09eb,0x2002025c}},	//   rodn, htir, _стат_, eski_,
   {{0x20020fd5,0x7c24264d,0xf6510332,0x5a9b02b5}},	//   fski_, ktir, _کئے_, רשטא,
   {{0x6d4402c7,0x63a8003a,0x7afe264e,0x644b264f}},	//   ddia, podn, kapt, _grgi,
   {{0x60d6006c,0x6d440c73,0x29d70069,0x7c242650}},	//   _egym, edia, _għaw_, dtir,
   {{0x41e60a9b,0x7afe1162,0xf1ca01a5,0xdb1c0037}},	//   _استف, dapt, _tạp_, _ghré,
   {{0x161902cb,0xd011096a,0x7c240093,0x6d442637}},	//   नंतर_, _قلب_, ftir, gdia,
   {{0xe5200354,0x68e20051,0x7c2408dd,0xfe7000b5}},	// [1d30] _यानि_, dcod, gtir, ودہ_,
   {{0x69c01889,0x636d2651,0xda7b010b,0x68e22652}},	//   _ahme, _púni, ляе_, ecod,
   {{0x6d442653,0x7a350037,0x7bc52654,0xce590f8c}},	//   bdia, تفاص, rmhu, _танц_,
   {{0x69c000ac,0xac192655,0x68e22656,0x7c2400af}},	//   _chme, _кому_, gcod, btir,
   {{0x7afe2657,0x7c242658,0xe8f82659,0xa3b822c7}},	//   bapt, ctir, слі_, चता_,
   {{0xd7c81ee1,0x7afe265a,0x442f265b,0x636d265c}},	//   مونه_, capt, _rpg_, _túni,
   {{0x443d265d,0x00000000,0x00000000,0x00000000}},	//   _ssw_, --, --, --,
   {{0x2409265e,0x68e2027a,0x443d0036,0x442f0090}},	//   ании_, ccod, _psw_, _ppg_,
   {{0x75ca004e,0xdced0c99,0x00000000,0x00000000}},	//   _języ, jkač, --, --,
   {{0x657b000e,0x02050036,0x644b0009,0xb80e0066}},	//   shuh, озон, _vrgi, _सितम_,
   {{0x2002006a,0xcb1202da,0x6444160b,0x68fb00d7}},	//   wski_, ולי_, _šiit, _keud,
   {{0x200210ec,0x68fb02e1,0x443d006f,0xa4f70a86}},	//   tski_, _jeud, _tsw_, _اکثر_,
   {{0x443d01ae,0xbee500a1,0x7afe0a21,0x68fb00f1}},	//   _usw_, कडून_, yapt, _meud,
   {{0x68fb01a6,0xdb1c0037,0x9474126b,0x65be0031}},	//   _leud, _thré, _عدنا, rëhe,
   {{0xfc3f1166,0x6449265f,0xdce400cd,0x00000000}},	//   _así_, lvei, nkić, --,
   {{0x20020fd5,0x68fb0393,0x7c242660,0x291f006f}},	//   pski_, _neud, ttir, _ncua_,
   {{0xab662661,0x236710e5,0x64492662,0x2b43023a}},	// [1d40] овал, _konj_, nvei, _bajc_,
   {{0x6d442663,0x2fd700d1,0x2b4300fe,0x75e70225}},	//   sdia, _گوید_, _cajc_, _kızd,
   {{0x7c242664,0x68e20223,0xdce40c99,0x68fb2665}},	//   stir, tcod, jkić, _beud,
   {{0x671c007c,0x68fb00f1,0x7afe2666,0x23670107}},	//   _नाहक_, _ceud, sapt, _lonj_,
   {{0x68fb2667,0xa2c90026,0x68ed0b4c,0x183600ad}},	//   _deud, हेत्, ñada, تراح,
   {{0x68e22668,0x69d82669,0xbb560037,0x291f081b}},	//   scod, íves, _بنسب, _ecua_,
   {{0x7afc00af,0xd95a03fa,0x6996002d,0x6281201d}},	//   _iert, _краљ_, _драх, jzlo,
   {{0x1dbf0355,0x69dc09c5,0x8ebf0033,0x2578266a}},	//   ्षयत, _iure, _আলমগ, _béla_,
   {{0x7afc266b,0x69dc266c,0x6603006d,0x00000000}},	//   _kert, _hure, asnk, --,
   {{0x69dc266d,0x3946266e,0x7afc266f,0x68fb01d7}},	//   _kure, ldos_, _jert, _zeud,
   {{0xc4e617f9,0x39460138,0x6ab800b4,0x39442670}},	//   _джей, odos_, _अरोर, _kams_,
   {{0x69dc2671,0x442400d7,0x7afc01a3,0x39462672}},	//   _mure, ptm_, _lert, ndos_,
   {{0x39462673,0x43462674,0x81ba0083,0x8496006c}},	//   idos_, _медв, _অংশ_, _بجائ,
   {{0x69dc2675,0x25a92676,0x6738022f,0x7afc2677}},	//   _oure, čale_, nevj, _nert,
   {{0xccfb03fa,0xa3de0026,0xdced00cd,0xed8b01f2}},	//   ића_, _दूत_, skač, асак_,
   {{0x7afc2678,0x394400ea,0xfc3f1dab,0x1b150831}},	//   _aert, _nams_, _psí_, ড়ছে_,
   {{0x7afc2679,0x213901f4,0x0bd5004f,0xdcef00af}},	// [1d50] _bert, mesh_, سياح, _alcă,
   {{0x69dc267a,0x2019267b,0x7afc1691,0x394603e6}},	//   _bure, musi_, _cert, edos_,
   {{0x2019267c,0x7afc267d,0xea0001a5,0x3944012f}},	//   lusi_, _dert, _đảo_, _bams_,
   {{0x69dc267e,0xe9d801c8,0x2139267f,0x777a01d7}},	//   _dure, ікі_, nesh_, _altx,
   {{0x69dc2680,0x66e50e02,0x20190a09,0xe72e2681}},	//   _eure, пола, nusi_, не_,
   {{0x39460aca,0x7afc0291,0x213900da,0xe7392682}},	//   ados_, _gert, hesh_, сек_,
   {{0xf7700d82,0x69dc06a2,0x7c3901d6,0x7bdd2683}},	//   خان_, _gure, şarı, _husu,
   {{0x20192684,0x7afc2685,0x21390031,0x7e9c0070}},	//   kusi_, _zert, jesh_, יסוו,
   {{0x20192686,0x7bdd2687,0x69dc2688,0x75292689}},	//   jusi_, _jusu, _zure, rfez,
   {{0x6449268a,0x2571008a,0x7ae5268b,0x69dc268c}},	//   rvei, _máli_, ncht, _yure,
   {{0xcb120779,0x6449268d,0x7ae50014,0xa91d00d8}},	//   עלט_, svei, icht, _amži,
   {{0x291d08e1,0x241900c3,0x2019268e,0x7bd51297}},	//   ngwa_, _годы_, fusi_, _lizu,
   {{0x2019246d,0x7bdd268f,0x316901a3,0xfbbd09b4}},	//   gusi_, _nusu, _doaz_, ्गाम,
   {{0xdb1c0211,0x7bd52690,0x636d0079,0x98bf00d5}},	//   _chrì, _nizu, _cúnt, _nauč_,
   {{0xe2962691,0xed5a10fe,0x272f06d3,0x636d0037}},	//   _наш_, бов_, mını_, _dúnt,
   {{0x7afc2692,0x20192693,0xa0a60f9e,0x7bdd073a}},	//   _sert, busi_, _найд, _busu,
   {{0x7afc2694,0x7bdd0395,0xdca32695,0x7bd52696}},	// [1d60] _pert, _cusu, еати, _bizu,
   {{0xef8607f5,0x272f037a,0x316901b7,0x257100fe}},	//   _хлоп, nını_, _zoaz_, _dáli_,
   {{0x7afc0ddf,0x69dc2697,0x19ba2698,0x7bd506a2}},	//   _vert, _qure, будь_, _dizu,
   {{0x7ae50514,0x7afc2699,0x3946010b,0xada611d0}},	//   acht, _wert, udos_, _хамл,
   {{0x7afc1201,0x2d920010,0x25ad1516,0x7bdd0010}},	//   _tert, miye_, doel_, _gusu,
   {{0x6d46269a,0x272f01d6,0x2d92269b,0x4cbb0122}},	//   _haka, jını_, liye_, _לזכו,
   {{0x6d46269c,0xfaa31fba,0xe80e0324,0x272f04d4}},	//   _kaka, _заро, _सिवा_, dını_,
   {{0x6d46269d,0x7ec70332,0x2d92269e,0x7bd5269f}},	//   _jaka, lépé, niye_, _zizu,
   {{0x6d460c40,0x7bdd0be2,0x66180187,0xb4c800b4}},	//   _maka, _xusu, suvk, ोखे_,
   {{0x6d4626a0,0x201926a1,0xa87b00a5,0x2d920908}},	//   _laka, vusi_, _האמר, hiye_,
   {{0x213900da,0x2d920232,0x0cb909b1,0x25ad26a2}},	//   tesh_, kiye_, _आर्म, boel_,
   {{0x6d4626a3,0x201926a4,0x63640107,0x25ad00e0}},	//   _naka, tusi_, _jònz, coel_,
   {{0x2d9201d6,0x213901f4,0x272f045e,0xbbdb000c}},	//   diye_, resh_, bını_, _बढेक,
   {{0x201926a5,0x7bdd26a6,0x6d4608dd,0x1be30066}},	//   rusi_, _rusu, _aaka, _कंबल_,
   {{0x6d4626a7,0x201926a8,0x7bdd26a9,0x213900da}},	//   _baka, susi_, _susu, pesh_,
   {{0x6d4626aa,0x2d920232,0xf1a401c8,0xe3b80644}},	//   _caka, giye_, _прын, llı_,
   {{0x6d4626ab,0xea000028,0x7ae526ac,0x071c1404}},	// [1d70] _daka, _đạo_, tcht, _नांव_,
   {{0xe3b806a8,0xad2700fd,0x7ae501ae,0x6d4600be}},	//   nlı_, _کردو, ucht, _eaka,
   {{0x6d4626ad,0x7bd526ae,0x68ed0f56,0x7ae501ae}},	//   _faka, _vizu, ñado, rcht,
   {{0x7ae501ae,0xd2460ef2,0x64420086,0xe3b80716}},	//   scht, _ین_, _osoi, hlı_,
   {{0x442626af,0x25ad0136,0xe3b801d6,0xb9050324}},	//   _nqo_, voel_, klı_, _नल_,
   {{0x6d4626b0,0xe80e046c,0xe3b80448,0x00000000}},	//   _zaka, _सिरा_, jlı_, --,
   {{0x6d4626b1,0x25ad0fdb,0xda3400d8,0xe3b800a8}},	//   _yaka, toel_, _перы, dlı_,
   {{0x1dbf143a,0x2bbd0026,0x999809ce,0xa3de00b4}},	//   ्षित, ्गवा, _екст_, _दंश_,
   {{0xe3b80716,0x272f0463,0x290d26b2,0x637f0345}},	//   flı_, tını_, _idea_, _lêne,
   {{0x2d9226b3,0x27ed26b4,0x69cb26b5,0xd38900d4}},	//   ziye_, _iten_, lmge, ійне_,
   {{0x272f036a,0xda7a02b5,0x32050122,0x25ad0b88}},	//   rını_, ַנשר, usly_, poel_,
   {{0x272f06a8,0x7207006c,0x00000000,0x00000000}},	//   sını_, _ہفتہ_, --, --,
   {{0xe3ae0a93,0x6d4626b6,0xa01b0332,0x2d92027d}},	//   _аб_, _raka, szön, viye_,
   {{0xdb1c004f,0x2d920010,0x656b0211,0x753b26b7}},	//   _phrí, wiye_, _hogh, leuz,
   {{0x6d461aaf,0x59ad00c4,0xa2c90380,0x2d920010}},	//   _paka, टकार, हेश्, tiye_,
   {{0xed5705a1,0x656b26b8,0x27ed13d6,0x9f5900c3}},	//   мос_, _jogh, _oten_, essä_,
   {{0x6d4626b9,0x2d92070b,0x656b26ba,0x443f007a}},	// [1d80] _vaka, riye_, _mogh, nwu_,
   {{0x6d4626bb,0x25a018b0,0x656b26bc,0x2d9226bd}},	//   _waka, čili_, _logh, siye_,
   {{0x6d4626be,0x2d8026bf,0x637f26c0,0x443f046a}},	//   _taka, phie_, _gêne, hwu_,
   {{0xe3b8008f,0x443f26c1,0x656b0211,0x6d460027}},	//   zlı_, kwu_, _nogh, _uaka,
   {{0x7d0426c2,0xe3b806d0,0xd90d09b9,0x63760160}},	//   mais, ylı_, صیل_, _sânm,
   {{0x7d0426c3,0x752207e5,0x656b01da,0x69cb0298}},	//   lais, _scoz, _aogh, amge,
   {{0x27ed26c4,0x656b26c5,0xa3c326c6,0xa3c10d2a}},	//   _eten_, _bogh, ्षन_, ंतन_,
   {{0x7d0426c7,0x25780248,0x753b0054,0x656b05b9}},	//   nais, _vélo_, geuz, _cogh,
   {{0xe3b806d3,0x443f007a,0xa2d00864,0x656b0312}},	//   tlı_, gwu_, डेन्, _dogh,
   {{0x57c9021a,0x7d0426c8,0x636d0176,0x656b26c9}},	//   िगृह, hais, _búnq, _eogh,
   {{0x656b09e3,0xa3de0fd1,0x7d040d36,0xd5af2028}},	//   _fogh, _दूर_, kais, _ас_,
   {{0x7d0426ca,0xe3b80644,0xc5f3011d,0x2d9e006c}},	//   jais, slı_, _ידע_, étel_,
   {{0xe3b801fb,0x9f5900c3,0x637f0b88,0xdb1c009e}},	//   plı_, yssä_, _sêne, _ohrà,
   {{0xe3b80095,0x81bd0029,0xd2500dc0,0xd90400b5}},	//   qlı_, otēk, _منت_, _ھی_,
   {{0xdfd426cb,0xd9041aa6,0x656b0ac0,0x7d0426cc}},	//   торы, _پی_, _yogh, fais,
   {{0x7d0426cd,0x656b035f,0x00000000,0x00000000}},	//   gais, _xogh, --, --,
   {{0xfbdf26ce,0x79820118,0xdb1c00f1,0x3b5526cf}},	// [1d90] _quê_, dhow, _bhrà, нкар,
   {{0x31a4037a,0xa3c31fe0,0x60c026d0,0xdb1c01da}},	//   mıza_, ्षय_, ümme, _chrà,
   {{0xdb1c26d1,0x27ed26d2,0xc9150202,0x290d010d}},	//   _virð, _sten_, едећ, _pdea_,
   {{0x7d0426d3,0x00000000,0x00000000,0x00000000}},	//   cais, --, --, --,
   {{0x656b04d6,0x31a406d3,0xa3c30d00,0x69cb13ee}},	//   _rogh, nıza_, ्षम_, rmge,
   {{0x656b004f,0xf1ca01a5,0xdb1c00f1,0xf62501f5}},	//   _sogh, _dạy_, _ghrà, едко,
   {{0xd90f04e8,0x81bd0080,0xbbbd26d4,0x45d52351}},	//   _نیا_, rtēj, ्गीक, нцит,
   {{0x7982006a,0x443f0067,0x290d01ed,0x81bd0228}},	//   chow, twu_, _udea_, stēj,
   {{0x656b027a,0xfbdf0023,0x27ed02ce,0x753b26d5}},	//   _vogh, _trêu_, _uten_, reuz,
   {{0x2d8c000d,0xc8a800be,0x00000000,0x00000000}},	//   édez_, _छुटट, --, --,
   {{0x656b0037,0x68e400cb,0x032200d8,0x7d0426d6}},	//   _togh, žide, ыдэн, yais,
   {{0x92df0083,0x31a40225,0x00000000,0x00000000}},	//   তরে_, fıza_, --, --,
   {{0x7d0426d7,0x600702ce,0xa80602d7,0x00000000}},	//   vais, нням_, mañó, --,
   {{0xdb1c00ac,0x7d0426d8,0x00000000,0x00000000}},	//   _ohrá, wais, --, --,
   {{0x7d0426d9,0xa3ac0026,0xed5a1622,0xf7720317}},	//   tais, ककर_, пов_, נקל_,
   {{0x61ee05c9,0x7bc700be,0x5d67002d,0xdb1c0284}},	//   íble, _ahju, нисм_, _shrà,
   {{0x7d0426da,0xdee626db,0xc19b00a5,0xdb1c0211}},	// [1da0] rais, _попи, _משקי, _phrà,
   {{0x8fa60987,0x7d0426dc,0xd9ba1cce,0xdb1c0037}},	//   _سمجه, sais, ेष्ट, _bhrá,
   {{0xdb1c0076,0xe9da2171,0x7d0426dd,0x4efb00a5}},	//   _chrá, чке_, pais, _מהיו,
   {{0xfbdf0248,0x307a0070,0x2571008d,0x00000000}},	//   _prêt_, ּאַנ, _máls_, --,
   {{0xb8e80437,0x1dbf021a,0xdb1c00f1,0x00000000}},	//   _उर_, ्षरत, _thrà, --,
   {{0x38cb064e,0x60c40054,0xfc3f002a,0xdb1c0098}},	//   سانی_, _mzim, _uxía_, _fhrá,
   {{0xdb1c0079,0xe2870037,0x2b4a00fe,0x00000000}},	//   _ghrá, _إذ_, _iabc_, --,
   {{0x60c426de,0x00000000,0x00000000,0x00000000}},	//   _ozim, --, --, --,
   {{0x81e70083,0x60c426df,0x98a30fc5,0xd4970043}},	//   মীম_, _nzim, _бите, ерэ_,
   {{0xecc50084,0x290601ed,0x00000000,0x00000000}},	//   लेटफ, laoa_, --, --,
   {{0x60c426e0,0x6376021d,0x00000000,0x00000000}},	//   _azim, _jâni, --, --,
   {{0x4a9b02b5,0x3a38012f,0x546a01d3,0xc4860043}},	//   לייג, _mprp_, _наем_, _плек,
   {{0xc95302b8,0x257100b5,0x06d50033,0x741303fb}},	//   אמר_, _vált_, _স্পি, _مونا,
   {{0xa3c30567,0x60c40029,0x25a0008b,0x3dd90159}},	//   ्षण_, _dzim, čilu_, _sisw_,
   {{0x60c4018e,0x5e5800af,0x00000000,0x00000000}},	//   _ezim, ниря_, --, --,
   {{0x9f49021d,0x3eba0044,0x212f009e,0x00000000}},	//   _itaí_, _dypt_, _ùgh_, --,
   {{0x2ef50133,0xe80201c0,0xdb1c0098,0x321e0067}},	// [1db0] _изпр, रीमा_, _shrá, luty_,
   {{0xc5f60083,0x8aa71362,0x20190207,0x00000000}},	//   _ঘটনা_, нред, mrsi_, --,
   {{0xd5df0084,0x321e26e1,0xa3e70026,0x3f930069}},	//   _पूंज, nuty_, _मून_, _imxu_,
   {{0x3a38012f,0x27e60051,0x27e901ef,0x00000000}},	//   _dprp_, fqon_, íano_, --,
   {{0x6d5d26e2,0x200b0036,0x00000000,0x00000000}},	//   _insa, nsci_, --, --,
   {{0x7c2d01d2,0x6d4d03c4,0x394926e3,0xdb1c0037}},	//   mtar, ldaa, žas_, _thrá,
   {{0xfbdf0370,0xe7080125,0xcf580122,0xdb1c00ac}},	//   _três_, رتون_, תבות_, _uhrá,
   {{0x6d4d26e4,0x490416e6,0x99d406ca,0x7c2d26e5}},	//   ndaa, _موفق, _متقا, otar,
   {{0x200b26e6,0xd6db12b9,0x6d5d010d,0x628800a0}},	//   jsci_, _ете_, _mnsa, ezdo,
   {{0x7c2d26e7,0x6d4d02ec,0x69da26e8,0x00000000}},	//   itar, hdaa, _éter, --,
   {{0x7c2d26e9,0x69c901a9,0x6f07016f,0xdce60228}},	//   htar, _khee, dajc, _lokā,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4d01a8,0x656926ea,0x7c2d01f4,0x1b0c0083}},	//   ddaa, mjeh, jtar, স্টে_,
   {{0x6d5d26eb,0x6d4d26ec,0x425526ed,0x672300d7}},	//   _ansa, edaa, _атит, ngnj,
   {{0x7c2d26ee,0x201926ef,0x3f8107c0,0x637f00a2}},	//   etar, arsi_, _dlhu_, _gêna,
   {{0x656900da,0x69db26f0,0xe80200a1,0x6d4d190b}},	//   njeh, _niue, रीडा_, gdaa,
   {{0x60c426f1,0x7c2d26f2,0x1ae626f3,0x61e326f4}},	// [1dc0] _uzim, gtar, возм, _hunl,
   {{0x6d5d26f5,0xa3c10953,0x6d4d26f6,0x6f0726f7}},	//   _ensa, ंति_, adaa, cajc,
   {{0x442d26f8,0xbcfb1d2b,0x3f9826f9,0x7c2d26fa}},	//   hte_, _poét, miru_, atar,
   {{0x3f9826fb,0x69c926fc,0xa91d0097,0x63760183}},	//   liru_, _chee, _alžb, _vâni,
   {{0x442d0d66,0x69c901e8,0xa3c3017f,0x7c2d26fd}},	//   jte_, _dhee, ्षा_, ctar,
   {{0x3f98128f,0xf8a90088,0xa92501ba,0xbb7602fb}},	//   niru_, ردنه_, _rožň, _румъ,
   {{0x442d26fe,0xd6d50033,0xbf9b016b,0x00000000}},	//   ete_, _স্বয, ויסש, --,
   {{0x7bdc26ff,0x657b2700,0x3f9801a3,0xfaa32701}},	//   _hiru, gkuh, hiru_, _тасо,
   {{0x442d2702,0x7bdc2703,0x75e701d6,0x37e602ce}},	//   gte_, _kiru, _hızl, _розг,
   {{0x61e30d6f,0x75e701d6,0x2019022f,0x637f0132}},	//   _bunl, _kızl, vrsi_, _pêna,
   {{0x442d2704,0xf3630bbc,0xe5262705,0x7c2d1f8e}},	//   ate_, ртын, _адеп, ztar,
   {{0x442d2706,0x7c2d2707,0x29042708,0x7bdc2709}},	//   bte_, ytar, _jema_, _liru,
   {{0x442d270a,0x7c2d270b,0x29040054,0x3f8101e8}},	//   cte_, xtar, _mema_, _plhu_,
   {{0x7bdc08c6,0xe3af0312,0x3f98270c,0x61e30023}},	//   _niru, _ورو_, giru_, _funl,
   {{0xcddb0202,0x91e303fa,0x7c2d0035,0x25a6017b}},	//   дња_, _које, wtar, _kjol_,
   {{0x7c2d270d,0x2904270e,0x672d0254,0xdd1100a8}},	//   ttar, _nema_, đaji, _düşd,
   {{0x60990098,0x6d4d0244,0x69c9270f,0x7bdc2710}},	// [1dd0] _سندس_, rdaa, _rhee, _biru,
   {{0x09cb05f7,0xd9cb0e62,0x2d820d26,0x7bdc1417}},	//   िष्य, िष्ट, _elke_, _ciru,
   {{0x442d2711,0x7bdc2712,0x69c90189,0x6abc00e9}},	//   zte_, _diru, _phee, _cyrf,
   {{0x7c2d071f,0x6d5d0b04,0x6d4d0103,0x27e400e7}},	//   ptar, _unsa, qdaa, _bumn_,
   {{0x442d2713,0x7bdc2714,0xec3502b5,0xdc350070}},	//   xte_, _firu, _גאָר_, _גאָט_,
   {{0x442d024e,0xd7c80079,0x69c92715,0x7bdc2716}},	//   vte_, نونه_, _whee, _giru,
   {{0x69c9006f,0xc79400d1,0x442d2717,0x6abc001e}},	//   _thee, جشنب, wte_, _gyrf,
   {{0x2904022e,0x61e30176,0x69db009e,0x7bdc2718}},	//   _gema_, _runl, _uiue, _ziru,
   {{0x442d2719,0x77930164,0xf1bf0038,0xf770006c}},	//   ute_, _پیغا, dlá_, _ڈال_,
   {{0xf7700dc0,0x61e30cca,0x657b271a,0xe1f90374}},	//   _وال_, _punl, skuh, нго_,
   {{0x3f98271b,0x35f5271c,0x6569124d,0x29040453}},	//   viru_, _спер, pjeh, _yema_,
   {{0x2904002a,0x06d50033,0x00000000,0x00000000}},	//   _xema_, _স্থি, --, --,
   {{0x394d0297,0x442d01f4,0xdb150097,0xd0960aeb}},	//   _maes_, qte_, _ekzé, ушны,
   {{0x649a00c2,0x749a1899,0x61e30d92,0xe7c30761}},	//   _אינה, _אינפ, _tunl, षतिप,
   {{0xe1f11c04,0x2000271d,0x395f271e,0x61e308dd}},	//   _است_, _wwii_, _onus_, _uunl,
   {{0x0ce20083,0x3f9801a8,0x225801b4,0x7f9400a8}},	//   বর্ত, siru_, ærke_, _müqə,
   {{0x7bdc271f,0x29042720,0x3f980254,0xbcfb00a2}},	// [1de0] _piru, _rema_, piru_, _coéq,
   {{0xdd040dac,0x29042721,0x7bdc00d7,0x09dc0099}},	//   ısın, _sema_, _qiru, यद्य,
   {{0x7bdc2722,0x75e700a8,0x29042723,0x00000000}},	//   _viru, _qızl, _pema_, --,
   {{0xfe9b0319,0x394d014c,0x7bdc2724,0x27e40139}},	//   _טיימ, _caes_, _wiru, _pumn_,
   {{0x29040054,0x394d00ee,0x9f40009e,0xed572725}},	//   _vema_, _daes_, _stiù_, _соя_,
   {{0x7d062726,0xc3190083,0x29040054,0x6fb405e7}},	//   _heks, ত্তি_, _wema_, ंकिं,
   {{0x7d062727,0x394d00e9,0x637600af,0x00000000}},	//   _keks, _faes_, _mânt, --,
   {{0x78260082,0x5e5702b5,0x746a0086,0x81bd0029}},	//   _معطل, ריקע_, еров_, ntēt,
   {{0x4991026b,0x00000000,0x00000000,0x00000000}},	//   _بینر, --, --, --,
   {{0x7d060533,0x883b0122,0x25bf00af,0x316000fe}},	//   _leks, _אתמו, alul_, _aniz_,
   {{0x4ebf0083,0x877b016b,0x25a60298,0x65be0055}},	//   _আল্ল, _ראבי, _tjol_, hëhi,
   {{0x6fc001ff,0x00000000,0x00000000,0x00000000}},	//   böck, --, --, --,
   {{0x33f600af,0x63760139,0x637f021d,0x00000000}},	//   _счес, _bânt, _gêno, --,
   {{0x6376002d,0xf1bf0334,0x1b1a0033,0x00000000}},	//   _cânt, slá_, ন্তে_, --,
   {{0xa3c102cb,0x7d062728,0xa3c313f0,0x3da72729}},	//   ंतर_, _beks, ्षर_, граб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcfb1111,0xd011132d,0x63760395,0xcb1b0279}},	// [1df0] _anéc, _بلخ_, _fânt, еќе_,
   {{0x7d060159,0x3dc008dd,0x395f21cc,0x00000000}},	//   _eeks, aliw_, _snus_, --,
   {{0xe8dd00b4,0x394d272a,0x7d0600fd,0x00000000}},	//   यश्च, _paes_, _feks, --,
   {{0x4dfa02b5,0x7d0612ba,0x49b80118,0xa907272b}},	//   _שפרא, _geks, هاند_, ابان,
   {{0x1b1a0033,0x6d4f0952,0x00000000,0x00000000}},	//   ন্ধে_, _iaca, --, --,
   {{0x7d0602c4,0xe739272c,0x25780118,0x07a503e6}},	//   _zeks, тек_, _mélu_, јакн,
   {{0x6d4f272d,0x25bf0043,0x7c3d01ed,0x27f808b7}},	//   _kaca, tlul_, _hpsr, _črne_,
   {{0x6d4f272e,0x1b1a0033,0x00000000,0x00000000}},	//   _jaca, ন্দে_, --, --,
   {{0x87272499,0x64a5010b,0x27f8024e,0x57270c26}},	//   _معام, рапа, čený_, _مراق,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x49b800b5,0x00000000,0x00000000,0x00000000}},	//   _شاہد_, --, --, --,
   {{0x249600bf,0x672d011c,0xe802073f,0xe296272f}},	//   انید_, đaju, रीवा_, раю_,
   {{0x764e008a,0x7d062730,0x63761e6d,0x00000000}},	//   _ábyr, _reks, _pânt, --,
   {{0x248d01e8,0x63760395,0x644b004b,0x00000000}},	//   mzem_, _dâns, _isgi, --,
   {{0x2d96010b,0x3ebe008a,0xe81c0084,0x7d062731}},	//   арас, ætt_, _निभा_, _peks,
   {{0x6d4f2732,0xa1930d6e,0x64590067,0x00000000}},	//   _caca, _мајч, _krwi, --,
   {{0x7d060044,0x81bd00ea,0x257800ee,0x6376021d}},	// [1e00] _veks, rtēt, _gélu_, _tânt,
   {{0x644b01ca,0x6d4f2733,0x2578008a,0xab63052a}},	//   _msgi, _eaca, _hélt_, овул,
   {{0x7d0603d0,0x6d4f0014,0x7c3d2734,0xeb9703fa}},	//   _teks, _faca, _epsr, јих_,
   {{0x6d4f25bf,0x2d89012f,0x323602b5,0x644b01ef}},	//   _gaca, chae_, יטען_, _osgi,
   {{0x6d442735,0x7c3d01ed,0x2d80034d,0xa01b00fd}},	//   meia, _gpsr, mkie_, szöv,
   {{0x6d4f2736,0x2d802737,0x6e3e012f,0x6d442738}},	//   _zaca, lkie_, _kppb, leia,
   {{0xfaa32739,0x7c24273a,0xeb970fdd,0x6d4f273b}},	//   _даро, luir, _тир_, _yaca,
   {{0x2d800626,0xdb070044,0x6d4f01ef,0x6d44273c}},	//   nkie_, _skjø, _xaca, neia,
   {{0xa3c301d1,0xb71600d1,0x69c200be,0xd3a60369}},	//   ्षं_, _نباش, mloe, ироп,
   {{0x443d012f,0x69c2001e,0x6e3e01e0,0x1c1e021a}},	//   _dpw_, lloe, _oppb, यूएल_,
   {{0x0cc300c0,0x672d0c21,0x2d800626,0xa69611b9}},	//   _शर्म, đajt, kkie_, _трај,
   {{0x7c240a66,0x765a01ef,0xa3e7046c,0xdb1c026e}},	//   kuir, _irty, _मूव_, _chrú,
   {{0x6d4f273d,0x6d44273e,0x248d0035,0x6e3e0282}},	//   _raca, deia, czem_, _appb,
   {{0xa3c3021a,0x7c24273f,0x8cb00006,0xdb05013c}},	//   ्षः_, duir, _अँजो, llhö,
   {{0x6d4f2740,0x8de80340,0x69c201a3,0xf20602fb}},	//   _paca, ифта_, kloe, _тяло,
   {{0x69c80080,0xdb1c0037,0xccf80274,0x6d442741}},	//   _ūden, _ghrú, ићу_, geia,
   {{0x44242742,0x65620076,0x69c300f7,0x5b152743}},	// [1e10] num_, _mnoh, înem, ймат,
   {{0x25a92744,0x6d4f2745,0x2d9b0055,0x69c20118}},	//   čali_, _waca, siqe_, eloe,
   {{0x6d4f0082,0x442403be,0x69c2099e,0x5a352746}},	//   _taca, hum_, floe, снет,
   {{0x44242747,0x2d802748,0x7c242749,0x79a4274a}},	//   kum_, ckie_, buir, орче,
   {{0x4424274b,0x765a006a,0x7d0d274c,0xbcfb0037}},	//   jum_, _arty, maas, _gnéa,
   {{0x4424274d,0xbb850514,0x7d0d274e,0xf745274f}},	//   dum_, _السي, laas, секо,
   {{0x69c22750,0x443d0223,0x7f3c016b,0x00000000}},	//   bloe, _spw_, דעוו, --,
   {{0x7d0d2751,0x442400fb,0xa01b01ae,0x248d0310}},	//   naas, fum_, nzös, tzem_,
   {{0x44242752,0xe3b92753,0x80d9021a,0x00000000}},	//   gum_, лби_, नेमे, --,
   {{0xd7740082,0x7d0d023f,0x248d2754,0x2d802755}},	//   _والع, haas, rzem_, zkie_,
   {{0x7d0d2756,0x248d1f11,0xdb1c0284,0x29d70024}},	//   kaas, szem_, _chrù, _bħax_,
   {{0x44240fe4,0x7d0d018e,0xdb1c0211,0x0f2000b4}},	//   bum_, jaas, _dhrù, बल्स_,
   {{0x44242757,0x55520332,0x645d01b4,0x645901d5}},	//   cum_, _رپور, æsid, _urwi,
   {{0xa02700fb,0x644900e9,0x7d0d018d,0x00000000}},	//   _stöð, mwei, eaas, --,
   {{0x51f517bd,0x64492758,0x7d0d2759,0xdb1c009e}},	//   _استر, lwei, faas, _ghrù,
   {{0x7d0d275a,0x7529275b,0x7c24275c,0x29d7003c}},	//   gaas, ngez, tuir, _għax_,
   {{0x644902c9,0x69c202e6,0x2d8003bc,0x3b86275d}},	// [1e20] nwei, vloe, rkie_, благ,
   {{0x2d80275e,0x7c24275f,0x4f2603fe,0xcb0a01cb}},	//   skie_, ruir, _удоб, ايان_,
   {{0x644902c9,0x44242760,0x7d0d2761,0x6e3e2762}},	//   hwei, zum_, baas, _uppb,
   {{0x44242763,0x7d0d0103,0xa91d00ee,0x645500ea}},	//   yum_, caas, _dlžo, āzij,
   {{0xe80b0299,0x7c241f74,0xa3e70d55,0x44242764}},	//   _सौदा_, quir, _मूल_, xum_,
   {{0x44242765,0x6449001e,0x9f400176,0x3e58007e}},	//   vum_, dwei, _juià_, _kčt_,
   {{0x44242766,0x69c22069,0x7529033b,0xd5ba0227}},	//   wum_, ploe, fgez, лси_,
   {{0x75292767,0x6449033b,0x9f8400c3,0x3e5802d0}},	//   ggez, fwei, löä_, _mčt_,
   {{0x644912e1,0x3f9a012f,0x39462768,0x81ae0033}},	//   gwei, _ompu_, meos_, কতা_,
   {{0x442408ee,0xf3662769,0x394607a6,0xa3e700a1}},	//   rum_, стин, leos_, _मूळ_,
   {{0x4424276a,0x7d0d001c,0xb7d7017e,0x3e580359}},	//   sum_, yaas, _اولا_, _nčt_,
   {{0x7982004e,0x44240093,0x3946276b,0x65620086}},	//   nkow, pum_, neos_, _unoh,
   {{0x54330357,0x7d0d276c,0x00000000,0x00000000}},	//   _فرور, vaas, --, --,
   {{0x7d0d276d,0x3e580359,0xdb1c0211,0x00000000}},	//   waas, _bčt_, _thrù, --,
   {{0x63ba0e7d,0x7d0d276e,0x7a1c002d,0xdb1c0260}},	//   motn, taas, nătă, _ikrè,
   {{0x63ba008b,0x71a40431,0xdb1701dd,0xdd9400c7}},	//   lotn, _најз, moxé, пасы,
   {{0x7d0d276f,0x79820035,0x2d580086,0xdb1701ef}},	// [1e30] raas, dkow, щить_, loxé,
   {{0x7d0d2761,0x5b1515d6,0x3e5802e9,0x63ba00d5}},	//   saas, імет, _fčt_, notn,
   {{0x27f802c6,0x39461111,0x7d0d00c3,0x6449033b}},	//   _črna_, feos_, paas, zwei,
   {{0x41c905fc,0xf1c909a8,0x63ba024e,0x61ea028b}},	//   रतिस, रतिन, hotn, _mufl,
   {{0x18692770,0x63ba2771,0x00000000,0x00000000}},	//   рали_, kotn, --, --,
   {{0x36190086,0xa09c0070,0xb09c016b,0x60cd023c}},	//   ацию_, ניגט, ניגר, _mzam,
   {{0x752901e4,0x39460300,0x994d00a0,0xf1c90099}},	//   tgez, beos_, môžu_, रतान,
   {{0xe5790ef3,0x64492772,0x39462773,0xdb1c23e2}},	//   рзи_, twei, ceos_, _akrè,
   {{0x290f2774,0xe1010083,0x61ea01ae,0x75292775}},	//   maga_, ্লাহ_, _aufl, rgez,
   {{0x290f2776,0x64492777,0x75292778,0x61ea0069}},	//   laga_, rwei, sgez, _bufl,
   {{0x64491fb3,0x76ab2779,0x60cd277a,0x7989277b}},	//   swei, _став_, _azam, _klew,
   {{0x290f19d4,0x98a4035f,0x61ea00f6,0x00000000}},	//   naga_, _qamħ_, _dufl, --,
   {{0x2bbe0567,0x637f00e2,0x799b001c,0x79890024}},	//   ्तमा, _lêni, _mmuw, _mlew,
   {{0x290f277c,0x3e8a00d8,0x7989016e,0x56b50070}},	//   haga_, айго_, _llew, ַפּן_,
   {{0xdee3277d,0x290f277e,0xe2960036,0x7989277f}},	//   дори, kaga_, _маш_, _olew,
   {{0xa0a62780,0x290f2781,0x7242006c,0xb4f90070}},	//   _майд, jaga_, _کھیل, שפּי,
   {{0x290f2782,0xada30183,0x9f8400c3,0xbcfb00a2}},	// [1e40] daga_, фатл, töä_, _inél,
   {{0x76410022,0x61e418af,0x3e5802d0,0x3f9a012f}},	//   _oply, _hiil, _tčt_, _umpu_,
   {{0x7982006a,0xe81c0302,0xfce61c80,0x8a060210}},	//   tkow, _निहा_, _моно, ізде,
   {{0xed5a2783,0x290f0010,0x5f460357,0x08c62784}},	//   _том_, gaga_, _انگل, обен,
   {{0x79822785,0x39461bea,0x764101ef,0x61e41986}},	//   rkow, reos_, _aply, _miil,
   {{0x39460b4c,0x7982004e,0x395200d8,0x79892786}},	//   seos_, skow, žys_, _elew,
   {{0x63ba031d,0x39460caa,0x290f050f,0x637f0132}},	//   votn, peos_, baga_, _gêni,
   {{0x6d562787,0x61e400c3,0x290f04fb,0x63ba0035}},	//   ndya, _niil, caga_, wotn,
   {{0x98a32788,0x7c36038d,0x61ea0043,0x60c42789}},	//   _жите, ntyr, _sufl, _nyim,
   {{0xd37a0432,0x61e4009e,0xdb170042,0x61ea0160}},	//   рчи_, _aiil, toxé, _pufl,
   {{0x63ba278a,0x60cd278b,0x326600d4,0x60c401a8}},	//   rotn, _szam, ітов, _ayim,
   {{0x63ba278c,0x60c404fb,0xdb170042,0x52ba021a}},	//   sotn, _byim, roxé, _उडीस,
   {{0x9f490279,0x63ba008b,0x1b110033,0x60c404fb}},	//   _itaú_, potn, ালতে_, _cyim,
   {{0x290f0010,0x60cd008b,0x644206fe,0x9294002d}},	//   zaga_, _vzam, _ipoi, _налц,
   {{0xdd9b278d,0x290f050f,0x3f830093,0x61e4278e}},	//   аша_, yaga_, rkju_, _fiil,
   {{0xf1a4002d,0x1b0400c8,0x3f831057,0x61e41b82}},	//   _орын, _লাগে_, skju_, _giil,
   {{0x6ebb0c57,0x60cd278f,0x290f2790,0x637f0132}},	// [1e50] _शुरु, _uzam, vaga_, _sêni,
   {{0x69c02791,0x290f2792,0xddeb00f8,0x637f0132}},	//   _akme, waga_, _پرده_, _pêni,
   {{0xdced039a,0xdb070093,0x290f2793,0xfc3f00cc}},	//   ljač, _skjó, taga_, _axít_,
   {{0xe81c0026,0x637f021d,0x00000000,0x00000000}},	//   _निशा_, _vêni, --, --,
   {{0x290f2794,0x64460095,0xdced0bc6,0xa80400d8}},	//   raga_, çkil, njač, дзіл,
   {{0x290f2795,0x637f0279,0x69c0027d,0x20091982}},	//   saga_, _têni, _ekme, _mwai_,
   {{0x64420bb0,0xf96b2796,0x290f2797,0x00000000}},	//   _apoi, _край_, paga_, --,
   {{0xe795064e,0x2bd9021a,0x764101ba,0x64420037}},	//   _کارک, भगवा, _vply, _bpoi,
   {{0xdced0254,0x68e90024,0x00000000,0x00000000}},	//   jjač, _iged, --, --,
   {{0x61e4005b,0x69d90067,0xdced00cd,0x6442021d}},	//   _siil, lmwe, djač, _dpoi,
   {{0x4b7c00c2,0x76410187,0x61e40196,0x2bbe2798}},	//   יאזו, _uply, _piil, ्तता,
   {{0xe8020632,0x644f01b4,0x7c360031,0x27ed00e0}},	//   रीका_, æcis, ytyr, _kuen_,
   {{0x64420159,0x61e42799,0xe5c4010b,0x27ed01ed}},	//   _gpoi, _viil, _ўсхо, _juen_,
   {{0x61e4081b,0x2d8b0036,0xdce400cd,0x00000000}},	//   _wiil, _alce_, ljić, --,
   {{0x63a1279a,0x257100ac,0x61e40421,0x68e9030d}},	//   miln, _sály_, _tiil, _oged,
   {{0x753b279b,0x68e900d1,0x63a1279c,0xdce4011c}},	//   nfuz, _nged, liln, njić,
   {{0x27ed06a2,0x8c43279d,0x27f8008b,0x8b2600d8}},	// [1e60] _nuen_, нете, _črno_, здзе,
   {{0xe7ef0084,0x7c36279e,0x63a10693,0xcd3613cf}},	//   _चढ़ा_, rtyr, niln, _کردب,
   {{0x7c36279f,0x6ac60037,0x5eda0033,0x290d023a}},	//   styr, أقام, _ব্রে, _beea_,
   {{0x27ed0083,0x290d0012,0x7e61054e,0xb4ea052f}},	//   _buen_, _ceea_, ælpe, _मले_,
   {{0x7d0427a0,0xa3cb0f19,0x63a127a1,0x2bbe0d34}},	//   mbis, लता_, kiln, ्तदा,
   {{0x27ed0291,0x26c5000c,0x80d90083,0x69d927a2}},	//   _duen_, _bylo_, ভুক্, amwe,
   {{0x63a127a3,0x68ed00b8,0xaa432725,0x27ed01ed}},	//   diln, žada, _перл, _euen_,
   {{0x7f8b0095,0xb60801c0,0x7d041a25,0xe944103b}},	//   _müqa, jišť, nbis, _ترسی,
   {{0xdb051111,0xbcfb00a0,0x7d0427a4,0x27ed27a5}},	//   cohó, _poéz, ibis, _guen_,
   {{0xfbbe142a,0x63a127a6,0x57fb0122,0x7d0407d4}},	//   ्तिम, giln, _ללמו, hbis,
   {{0x27ed03cb,0x200908c7,0x00000000,0x00000000}},	//   _zuen_, _swai_, --, --,
   {{0x27ed00d7,0x7c2427a7,0xdcef0160,0x63a10211}},	//   _yuen_, krir, _mocă, ailn,
   {{0x63a127a8,0xfbbe00b8,0x533400c3,0x7d040254}},	//   biln, ्ताम, _желт, dbis,
   {{0x63a127a9,0x7c2407e7,0xdced080a,0x00000000}},	//   ciln, drir, rjač, --,
   {{0x433b0122,0xe3b30070,0x777a27aa,0x26c500d5}},	//   _העוב, _אױס_, _motx, _xylo_,
   {{0x7c2427ab,0x7d042487,0x5bc5007e,0xbbc506fe}},	//   frir, gbis, वत्व, वत्क,
   {{0xb606011c,0x00000000,0x00000000,0x00000000}},	// [1e70] lošć, --, --, --,
   {{0x3b5427ac,0x4424066a,0xeb9b27ad,0x2fc700cc}},	//   нкур, irm_, حضرت_, _óng_,
   {{0xdd95005f,0x7d0427ae,0x7c24027a,0xb6060254}},	//   _жаны, bbis, arir, nošć,
   {{0xdb1c0079,0x442400ac,0xf1bf0183,0x00000000}},	//   _bhró, krm_, noá_, --,
   {{0x27ed27af,0xdb171a71,0xa7b90009,0x7c2400f7}},	//   _quen_, loxí, олду_, crir,
   {{0x777a12c3,0x3dc927b0,0xb6060124,0xf77107f6}},	//   _cotx, llaw_, košć, ضات_,
   {{0x63a1068b,0x7d0f00b5,0x777a01ed,0xb60600f4}},	//   viln, _kecs, _dotx, jošć,
   {{0x3dc9010d,0x63a10035,0x497500d8,0x68e90b3e}},	//   nlaw_, wiln, _ўлас, _uged,
   {{0x63a127b1,0xd7c800e0,0x69c300f7,0x47350036}},	//   tiln, _کوله_, îneu, _онас,
   {{0x645b217b,0x7d0411a2,0x7d0f00fd,0x00000000}},	//   rvui, zbis, _lecs, --,
   {{0x63a1008b,0x3dc90dc3,0x3ce601ba,0xa91d18b0}},	//   riln, klaw_, ľovi_, _alži,
   {{0xa0a60200,0x7c240093,0x7d0f0160,0x628127b2}},	//   дамд, yrir, _necs, rylo,
   {{0x63a127b3,0x3dc902b3,0xbcfb01ba,0x31b900ac}},	//   piln, dlaw_, _inéh, nézy_,
   {{0x7c2427b4,0x637f021d,0xf8ab00e2,0xb60600f4}},	//   vrir, _cênt, _đời_, bošć,
   {{0xafe30036,0x25ad27b5,0x02d100b4,0x7d0f27b6}},	//   торл, onel_, _हरिभ, _becs,
   {{0x25ad27b7,0x7c240055,0x7f8b013b,0x637f0183}},	//   nnel_, trir, _vüqa, _vênu,
   {{0x7d0427b8,0xdca327b9,0x629c00a0,0x7c2427ba}},	// [1e80] rbis, вати, úrov, urir,
   {{0x25bf0260,0x7c2406a2,0x637f021d,0xdcef0139}},	//   houl_, rrir, _tênu, _pocă,
   {{0xdb1c0284,0x3dc900e9,0x00000000,0x00000000}},	//   _bhrò, blaw_, --, --,
   {{0x7c2427bb,0xdb1c111f,0x3dc927bc,0xda650037}},	//   prir, _phró, claw_, عالي,
   {{0xb8f627bd,0xdb1c0211,0x6c0300af,0x777a0065}},	//   _हर_, _dhrò, _изяз, _potx,
   {{0xdcef0160,0x00000000,0x00000000,0x00000000}},	//   _tocă, --, --, --,
   {{0x9f8d008a,0x6b8e0069,0x00000000,0x00000000}},	//   nþá_, _ilbg, --, --,
   {{0x2bbe0569,0xb606011c,0xdb1c0284,0xbf0a0099}},	//   ्तवा, vošć, _ghrò, वरुन_,
   {{0x2906002f,0x777a0392,0x00000000,0x00000000}},	//   mboa_, _totx, --, --,
   {{0xb60600cd,0x2b5827be,0xa87b024b,0x42740421}},	//   tošć, _jarc_, _ואמר, егос,
   {{0x2b5827bf,0xa2c10af9,0x3218024e,0x25bf27c0}},	//   _marc_, _रुद्, éry_, boul_,
   {{0xe4a6174b,0xb606042a,0xc48600d4,0x5a170070}},	//   _орло, rošć, _олек, וקטן_,
   {{0xa3e72088,0xc05812ea,0xbf0a00a1,0x2d920027}},	//   _मंच_, мір_, वरून_, dhye_,
   {{0x0efb00dc,0x2b580fc2,0x3dc9010d,0xb6060124}},	//   ्रेस_, _narc_, wlaw_, pošć,
   {{0x3ceb27c1,0x9e34027a,0x5e5800af,0xf1bf0183}},	//   _pgcv_, керч, миря_, poá_,
   {{0x3dc9011e,0x637f0345,0xdb17002a,0xcdd80274}},	//   ulaw_, _fêns, roxí, дњу_,
   {{0x7d0227c2,0x7d0f27c3,0x2b58016e,0x3dc927c4}},	// [1e90] ñosa, _vecs, _barc_, rlaw_,
   {{0xdb1c01da,0xf4000831,0x00000000,0x00000000}},	//   _shrò, _এটার_, --, --,
   {{0xb50e0066,0x7d0f27c5,0xdb1c01a6,0x00000000}},	//   सराय_, _tecs, _phrò, --,
   {{0x645c00ea,0x25f227c6,0x00000000,0x00000000}},	//   ārij, ँदनी_, --, --,
   {{0x68ed024e,0x6cfa011d,0x201900c3,0x00000000}},	//   žado, _מפרס, nssi_, --,
   {{0x237c042a,0x7c2d27c7,0x00000000,0x00000000}},	//   _novj_, muar, --, --,
   {{0x7c2d27c8,0x2bbe20a3,0x7ac40202,0xfbbe00b8}},	//   luar, ्तरा, _асте, ्तरम,
   {{0x29060176,0xc8670382,0x00000000,0x00000000}},	//   cboa_, _отзи, --, --,
   {{0x38341837,0x25bf00af,0x68fb0027,0x25ad27c9}},	//   _интр, roul_, _ifud, rnel_,
   {{0x25ad27ca,0x69cb27cb,0xe2990274,0x27ff01a3}},	//   snel_, llge, зао_, _itun_,
   {{0x25ad27cc,0x7c2d27cd,0x00000000,0x00000000}},	//   pnel_, huar, --, --,
   {{0x7c2d27ce,0xa3cf0fbf,0x00000000,0x00000000}},	//   kuar, _वीर_, --, --,
   {{0x656b27cf,0xbcfb004f,0x80c80083,0xdb1c27d0}},	//   _ingh, _gnéi, রেন্, _skrí,
   {{0xdb1e00da,0x7c2d27d1,0x6d4d0159,0x442d27d2}},	//   ropë, duar, eeaa, mue_,
   {{0x442d27d3,0x2019027a,0x68fb030d,0x3c430228}},	//   lue_, assi_, _ofud, hīvā_,
   {{0x7c2d0079,0x6d4d0051,0x68fb073a,0x52740079}},	//   fuar, geaa, _nfud, _جاهز,
   {{0x2b5827d4,0x7c2d27d5,0x6aa8035d,0x442d0e15}},	// [1ea0] _parc_, guar, कप्र, nue_,
   {{0x2d920232,0xa3c100c0,0x68fb001c,0x291f023c}},	//   shye_, ूति_, _afud, _adua_,
   {{0x3ea60268,0xa9261108,0x27ff27d6,0x656b009e}},	//   _чинг, едел, _atun_, _ongh,
   {{0x442d27d7,0xb17b013c,0x7c2d27d8,0x00000000}},	//   kue_, rmåg, buar, --,
   {{0xc7c6110a,0xe80b009a,0x7d1627d9,0xa3c104bc}},	//   нски, सीला_, mays, ूता_,
   {{0x7d1627da,0x442d27db,0x656b27dc,0x290608cb}},	//   lays, due_, _angh, sboa_,
   {{0x442d27dd,0xbbbe0e61,0x00000000,0x00000000}},	//   eue_, ्तीक, --, --,
   {{0x7d160dc3,0x09e327de,0x7aee0051,0x442d27df}},	//   nays, _босн, _hgbt, fue_,
   {{0x442d27e0,0x39440282,0x00000000,0x00000000}},	//   gue_, _ibms_, --, --,
   {{0x7d160159,0x969609eb,0x656b001e,0x21200260}},	//   hays, _преш, _engh, _adih_,
   {{0x7d1627e1,0xd5af0036,0x7c2d27e2,0xbcfb000d}},	//   kays, _бс_, zuar, _inév,
   {{0x6e2e27e3,0xbbbe00b8,0xdce6021e,0x9c8700d5}},	//   dubb, ्तुक, _ankč, ničí,
   {{0x7d160381,0x442d27e4,0x7c2d27e5,0xf1a4010b}},	//   days, cue_, xuar, урэн,
   {{0x20190196,0xa3cb020c,0x7c2d27e6,0x00000000}},	//   rssi_, लतः_, vuar, --,
   {{0x656b0297,0x6f1527e7,0x6e2e27e8,0x5d6727e9}},	//   _yngh, razc, gubb, нтаз,
   {{0x7c22003c,0x7c2d27ea,0x40950037,0x00000000}},	//   ġorn, tuar, _للبر, --,
   {{0xb81c1556,0x6d4d07bd,0x00000000,0x00000000}},	// [1eb0] _निगम_, reaa, --, --,
   {{0x6e2e029d,0x7c2d1f30,0x3df527eb,0x7648008c}},	//   bubb, ruar, _изос, _opdy,
   {{0x442d06a2,0x6d4d0303,0x7dfc021e,0x00000000}},	//   zue_, peaa, _pčse, --,
   {{0x3c4300ea,0x7c2d27ec,0xfd1f0036,0xa91d008b}},	//   tīvā_, puar, _udì_, _možg,
   {{0x7c2d27ed,0xe10c02b5,0x442d27ee,0x8d8400af}},	//   quar, פּאָ, xue_, _суэд,
   {{0x442d27ef,0xb6a5081b,0xa3cf0035,0x3944010d}},	//   vue_, килл, _वीं_, _ebms_,
   {{0xead400c3,0x00000000,0x00000000,0x00000000}},	//   _борь, --, --, --,
   {{0x442d27f0,0x0565081e,0xa2c10edf,0x00000000}},	//   tue_, твин, _रुष्, --,
   {{0xe4320037,0x160d00ab,0x00000000,0x00000000}},	//   لفيد, _सबकर_, --, --,
   {{0x442d27f1,0x394f27f2,0xe1f90210,0x260e0099}},	//   rue_, legs_, мго_, णीही_,
   {{0x442d0122,0x2000002d,0x36750037,0xfbd200a5}},	//   sue_, _stii_, _جهاز, שתי_,
   {{0xdb1e27f3,0x656b27f4,0x0f0a02b4,0x00000000}},	//   ropé, _ungh, वर्स_, --,
   {{0x442d27f5,0x8edf00c8,0x2120023a,0x00000000}},	//   que_, _ব্লগ, _vdih_, --,
   {{0x7d160088,0xdb1c00ac,0x00000000,0x00000000}},	//   ways, _okrá, --, --,
   {{0x7d020b06,0x6da60923,0x7d161505,0x22470065}},	//   ñoso, вива, tays, _upnk_,
   {{0x12e802b5,0x320500a5,0xdd9227f6,0x00000000}},	//   _אַפּ, mply_, جور_, --,
   {{0xa91d01cc,0x2bf627f7,0x7d16034d,0x6721022f}},	// [1ec0] _možd, тябр, rays, _odlj,
   {{0x6e2e27f8,0x7d1627f9,0xaf0a0037,0x8c4327fa}},	//   pubb, says, _تقدم_, рефе,
   {{0x7d1600a2,0x00000000,0x00000000,0x00000000}},	//   pays, --, --, --,
   {{0x637e0355,0xdb1701ef,0x00000000,0x00000000}},	//   _záně, roxá, --, --,
   {{0xe947006c,0x25780168,0x00000000,0x00000000}},	//   ئرمی, _gély_, --, --,
   {{0xe81307b5,0x00000000,0x00000000,0x00000000}},	//   _डबरा_, --, --, --,
   {{0x6ae00083,0x98b2027d,0x00000000,0x00000000}},	//   _প্রো, ıyı_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c00b8,0x00000000,0x00000000,0x00000000}},	//   _zkrá, --, --, --,
   {{0xf36627fb,0x27f900e0,0xa91d27fc,0x00000000}},	//   ттин, _ésna_, _požg, --,
   {{0xd625183b,0x79801857,0x00000000,0x00000000}},	//   _معني, _komw, --, --,
   {{0x316d0922,0xfbdf00e9,0x00000000,0x00000000}},	//   ñez_, _apêl_, --, --,
   {{0x60d60067,0x94760079,0x00000000,0x00000000}},	//   _czym, _جداا, --, --,
   {{0x547b0122,0x9f52021e,0x6d4627fd,0x32661403}},	//   _קטגו, _juyè_, _abka, _атив,
   {{0x63a80312,0x2bec00b4,0xdb060355,0x236e034d}},	//   midn, _अंजू_, ámýc, _infj_,
   {{0xa91d0187,0x7bc727fe,0x7e650009,0x62881019}},	//   _kože, _skju, _vrhp, mydo,
   {{0xdb1c27ff,0x62882800,0xa91d2801,0xfbd90214}},	// [1ed0] _skrá, lydo, _jože, едај_,
   {{0xa91d2802,0x4ea71999,0x61ed2803,0x8f5502ce}},	//   _može, _арма, _hial, _свої,
   {{0x61ed2804,0x75220926,0x7980099e,0x00000000}},	//   _kial, _odoz, _bomw, --,
   {{0x60cd01a8,0xafdb08c8,0xdb1c00d5,0x629a0065}},	//   _kyam, stød, _vkrá, izto,
   {{0xa3c202cb,0xa91d264f,0x6d5d0a32,0x61ed2805}},	//   ंवा_, _nože, _iasa, _mial,
   {{0x6d5d2806,0x75222807,0x61ed2808,0x60cd0371}},	//   _hasa, _adoz, _lial, _myam,
   {{0x6d5d2809,0xe5a5280a,0x27ec0122,0x3f8100b8}},	//   _kasa, лики, _didn_, _mohu_,
   {{0x61ed09c3,0x6d5d280b,0xa91d063c,0xe4590ece}},	//   _nial, _jasa, _bože, ежи_,
   {{0x6d5d280c,0x60cd280d,0xa91d01f2,0x69c9010d}},	//   _masa, _nyam, _vožd, _ikee,
   {{0x6d5d280e,0x2bd90b47,0x752206a2,0x490b000c}},	//   _lasa, _बीमा, _edoz, ारको_,
   {{0x61ed280f,0x60cd018e,0x7980030d,0x60d62810}},	//   _bial, _ayam, _yomw, _szym,
   {{0x6d5d2811,0x60cd2107,0x3cef00ab,0x6389055c}},	//   _nasa, _byam, _अलगे_, _bênê,
   {{0x44292812,0x343902b5,0x7bc52813,0x3f810097}},	//   _ía_, _נײַע, kohu, _bohu_,
   {{0x94740071,0x6d5d2814,0x443f2815,0x64592816}},	//   _خدما, _aasa, mtu_, _iswi,
   {{0x6d5d0483,0x61ed2817,0xa2ca0cf1,0xc2c503ec}},	//   _basa, _fial, _सुप्, _حيثي,
   {{0x5bbe0099,0x61ed2818,0x69c9006f,0xed572819}},	//   ्त्व, _gial, _nkee, лос_,
   {{0x443f18f9,0x6d5d1b0f,0x644b281a,0xbcfb0176}},	// [1ee0] ntu_, _dasa, _jpgi, _anés,
   {{0x443f281b,0x6d5d04e6,0xa09b0070,0x69c9281c}},	//   itu_, _easa, _נייט, _akee,
   {{0x443f281d,0x6da6049f,0x69db0037,0xee3700af}},	//   htu_, _бина, _bhue, _йнэ_,
   {{0x69db02d7,0x6d5d281e,0x644b08c8,0x27ec0223}},	//   _chue, _gasa, _opgi, _sidn_,
   {{0xa2ca111b,0x443f281f,0xbcfb0138,0x657b00be}},	//   _सुन्, jtu_, _enés, djuh,
   {{0x6d5d088d,0xdb1c01b4,0x7c2b2820,0xfbb82821}},	//   _zasa, _skræ, ágre, _आदिम,
   {{0x6d5d2822,0x63a80528,0xbb3b02b5,0xb8eb0d53}},	//   _yasa, vidn, _רעלי, _रु_,
   {{0x6d5d0510,0xa91d00cb,0x7df5010b,0x2bbe035d}},	//   _xasa, _pože, _sąsk, ्तका,
   {{0x61ed0514,0x7bdc2823,0x20e3112b,0x63a8013c}},	//   _rial, _khru, _गणेश_, tidn,
   {{0xa91d082d,0x61ed2824,0x2d822825,0x7f5e01ef}},	//   _vože, _sial, _loke_, _napq,
   {{0x61ed0464,0x60cd0ac8,0x443f2826,0x63a82827}},	//   _pial, _syam, atu_, ridn,
   {{0x62881826,0x3f812828,0x7bc5002f,0x98a400a8}},	//   rydo, _sohu_, zohu, _hamı_,
   {{0x6d5d2829,0x629a282a,0x61ed282b,0x7bc50054}},	//   _rasa, szto, _vial, yohu,
   {{0x6d5d282c,0x60cd000e,0xa91d023a,0x98a90067}},	//   _sasa, _vyam, _kožc, żać_,
   {{0xcddb282d,0x6d44282e,0x2d82282f,0x12fb00a5}},	//   ења_, ffia, _boke_, _אהוב,
   {{0x6d5d003c,0x2d582830,0x645900e9,0x5d5503e6}},	//   _qasa, лись_, _yswi, јкат,
   {{0x6d5d2831,0x5b152832,0x7bdc0094,0x7bc51e61}},	// [1ef0] _vasa, имат, _bhru, tohu,
   {{0x6d5d2833,0x7bdc2834,0x9d150083,0x69c92835}},	//   _wasa, _chru, িলেন_, _skee,
   {{0x6d5d2836,0x443f0291,0x7bdc006b,0xaa551a33}},	//   _tasa, ztu_, _dhru, рвеш,
   {{0x6d5d09c3,0xbcfb1bea,0x25fb05e7,0x6440017b}},	//   _uasa, _enér, _लंबी_, ktmi,
   {{0x443f024e,0xb8fd0c57,0x998700b5,0x7c87002d}},	//   xtu_, _डर_, énő_, _суне,
   {{0x7d0d2837,0x8ae71112,0x7bdc09c3,0x321e0035}},	//   lbas, _бібл, _ghru, ksty_,
   {{0x7d0d01ed,0x01d60033,0xdb05191b,0x61fc01ef}},	//   obas, _সংসদ, rnhä, írll,
   {{0x443f2838,0x14252839,0x7c2d283a,0x7bdc0314}},	//   ttu_, адим, orar, _zhru,
   {{0x99840082,0x443f283b,0x765a00e9,0xa2ca0edf}},	//   _القو, utu_, _esty, _सुब्,
   {{0x395f283c,0x443f283d,0x25a6283e,0x657b03a6}},	//   _haus_, rtu_, _emol_, sjuh,
   {{0x395f283f,0x65952840,0xe10a1e46,0x7d0d108c}},	//   _kaus_, _кажу, кенд_, kbas,
   {{0x443f2841,0x9f4900fb,0x7c2d2842,0x29350070}},	//   ptu_, _stað_, krar, סאָן_,
   {{0x395f2843,0x7d0d0f0a,0x2d82008b,0x6459002f}},	//   _maus_, dbas, _roke_, _uswi,
   {{0x395f0189,0xa2e52844,0x765a0297,0x442d2845}},	//   _laus_, _колд, _ysty, mre_,
   {{0xeab000c8,0xdee62846,0xa3c202cb,0x7c2d01d7}},	//   _কর্ম, рови, ंवर_, erar,
   {{0x7bdc2847,0x442d01d3,0x7d0d2848,0x395f2849}},	//   _shru, ore_, gbas, _naus_,
   {{0x442d284a,0x7c2d284b,0x6d44284c,0x6db7011c}},	// [1f00] nre_, grar, rfia, pćan,
   {{0x442d284d,0x3160284e,0x7d0d01a8,0x8b2601e0}},	//   ire_, _haiz_, abas, рдже,
   {{0x442d284f,0x7d0d2850,0x7c2d1de4,0x2d8201f4}},	//   hre_, bbas, arar, _toke_,
   {{0xd9461c80,0x395f2851,0x442d1fbb,0x7c2d2852}},	//   реди, _caus_, kre_, brar,
   {{0x395f0221,0x7c2d0043,0x442d01b4,0x31602853}},	//   _daus_, crar, jre_, _maiz_,
   {{0x442d1b99,0xa50e02e4,0x0eba0324,0x7df52854}},	//   dre_, सर्च_, _उखाड, _sąsi,
   {{0xd5ba010c,0x395f0221,0xe8fa0043,0x660303e6}},	//   кси_, _faus_, _алб_, опја,
   {{0x442d2855,0x6f1c2856,0x316006a2,0x8574027a}},	//   fre_, harc, _naiz_, слих,
   {{0x57ea2857,0x442d03d0,0x6fc600a1,0x765a0067}},	//   _адам_, gre_, लकां, _wsty,
   {{0x07a31400,0x46a601d3,0x395f0189,0x883b00a5}},	//   _даун, _казв, _zaus_, _בתמו,
   {{0x64402858,0x321e06fe,0x6f1c2859,0xaf370609}},	//   stmi, usty_, darc, یرست,
   {{0x442d285a,0x6f17285b,0x044607c1,0x395f006f}},	//   bre_, _sexc, _ведн, _xaus_,
   {{0x442d15f9,0x6f1c285c,0x2fc70023,0xdcef00ea}},	//   cre_, farc, _ưng_, ādīt,
   {{0x7c2d285d,0x533300af,0xa91d285e,0xa2c1035d}},	//   vrar, _дешт, _moža, _रुक्,
   {{0x31600716,0x7d0d285f,0xbe882860,0x22570911}},	//   _faiz_, tbas, асте_, _نجيب_,
   {{0xdd982861,0x527b0d85,0x00000000,0x00000000}},	//   ашу_, _ינוא, --, --,
   {{0x7d0d2862,0xdce600d8,0x395f2863,0x7c2d2864}},	// [1f10] rbas, _mokė, _raus_, urar,
   {{0x7c2d0065,0x6f1c2865,0x395f2866,0x7d0d2867}},	//   rrar, carc, _saus_, sbas,
   {{0x395f2868,0x7d0d0801,0x2bbe2869,0x442d00b5}},	//   _paus_, pbas, ्तजा, zre_,
   {{0x442d286a,0xa91d10ec,0x395f006d,0x7c2d286b}},	//   yre_, _boža, _qaus_, prar,
   {{0x395f006d,0x4dda00a5,0x67d503e6,0x9f400392}},	//   _vaus_, _תחרו, боду, _guió_,
   {{0x442d286c,0xa91d00ac,0x6747010b,0x61f80107}},	//   vre_, _doža, рэдз, _ouvl,
   {{0xa6c9247f,0x395f006f,0x361800d8,0x442d0103}},	//   ылка_, _taus_, ацыю_, wre_,
   {{0xa2c100a1,0x6f1c286d,0xa3cf00a1,0x91fc013a}},	//   _रुग्, zarc, _वीज_, tvān,
   {{0x442d286e,0x7f8b01c2,0x291d0269,0x2bbe14ab}},	//   ure_, _hüqu, mawa_, ्तचा,
   {{0x442d03d0,0x291d00a7,0x316002c2,0x61f800cd}},	//   rre_, lawa_, _saiz_, _buvl,
   {{0x442d006c,0x6f1c286f,0xa2ca00a1,0xe6b30609}},	//   sre_, varc, _सुद्, _بلاگ,
   {{0x442d2870,0x291d2871,0x568c02b5,0xd00a2872}},	//   pre_, nawa_, _שטאַ, леме_,
   {{0x6ad4046c,0x7dfc0359,0xa4d401e0,0x00000000}},	//   _थर्र, _pčso, _доці, --,
   {{0x291d2873,0xe8192874,0xafe6110a,0xdb1e1da9}},	//   hawa_, नीया_, согл, kopá,
   {{0x291d2875,0xe3b00088,0x2d96037c,0xc7d600a5}},	//   kawa_, _غره_, брас, מושי_,
   {{0x6da32876,0x6f1c2877,0x291d2878,0xdb1e0097}},	//   писа, sarc, jawa_, dopá,
   {{0x6f1c2879,0x291d287a,0x249f1f20,0xdd8f0037}},	// [1f20] parc, dawa_, nzum_, روك_,
   {{0xc91023e3,0xa3dd0127,0x7c2b01ef,0x3b18007a}},	//   ार्म_, _थीम_, ágra, _qerq_,
   {{0x25ad287b,0xdb07006c,0xa91d02a7,0x00000000}},	//   kiel_, ámár, _soža, --,
   {{0x291d287c,0xa91d06fe,0x3866287d,0x38cb0df3}},	//   gawa_, _poža, tvor_, گامی_,
   {{0x25ad016f,0x3946287e,0x6d56287f,0xb5fc035f}},	//   diel_, rfos_, meya, _irġi,
   {{0x6d562880,0x9b960037,0xaa0800b5,0xbb860037}},	//   leya, _الست, _نعرے_, _الآي,
   {{0x25ad0261,0x291d2881,0xf09f0036,0xdb1c07c0}},	//   fiel_, bawa_, zzà_, _okrú,
   {{0xd9430272,0x2d800298,0x25ad2882,0xa91d023a}},	//   _неси, njie_, giel_, _toža,
   {{0x76432883,0xf8dc007c,0x61f8011c,0x09e3027a}},	//   atny, _बरिय, _suvl, _хотн,
   {{0x5c5b02b5,0x388e0029,0x6d562884,0x00000000}},	//   נדיק, _vērā_, heya, --,
   {{0xa91d0e6a,0x25ad0c7c,0xcb130397,0x6d56027c}},	//   _možn, biel_, הלת_, keya,
   {{0x25ad2885,0xa91d00b8,0x7df5010b,0x00000000}},	//   ciel_, _ložn, _mąst, --,
   {{0x2d800173,0x6d5600f8,0x23e60823,0x7df500c7}},	//   djie_, deya, _лікв, _ląst,
   {{0x291d006a,0xdbf101c0,0xa91d2886,0x92940dee}},	//   zawa_, _příl, _nožn, _малц,
   {{0x65620d6c,0x291d2887,0xfdc40084,0x04b700b5}},	//   _kaoh, yawa_, वकूफ, _نھیں_,
   {{0x6d562888,0x2d800031,0xe3b80510,0x00000000}},	//   geya, gjie_, lnı_, --,
   {{0x2129046a,0xe7ba06fe,0x4dd40037,0x65622889}},	// [1f30] _idah_, ेवाप, ستفس, _maoh,
   {{0xdea403c5,0x291d288a,0xe3b8242d,0x25ad288b}},	//   _کیفی, wawa_, nnı_, ziel_,
   {{0x291d288c,0x9f8400ab,0xcae30084,0x6d56288d}},	//   tawa_, töö_, केंड_, beya,
   {{0x6ab90907,0x291d0054,0xe3b800a8,0xd7f100cc}},	//   _आशीर, uawa_, hnı_, _sĩ_,
   {{0xf7701c0c,0x291d288e,0xa2ca0ebd,0x25ad288f}},	//   کان_, rawa_, _सुस्, viel_,
   {{0x291d2890,0x25ad19c1,0x776100a8,0xdb150260}},	//   sawa_, wiel_, _qalx, _ekzò,
   {{0x25ad0c43,0x291d2891,0x1995010b,0x66e20036}},	//   tiel_, pawa_, _давя, моша,
   {{0x5589002d,0xdff900b4,0x7d1f0055,0x6562055c}},	//   рбим_, ंदाद_, naqs, _caoh,
   {{0x25ad2892,0x2ed62893,0x76432894,0xb17b2895}},	//   riel_, _धर्त, stny, rmål,
   {{0x2129046a,0x42252896,0x25ad2897,0x249f2898}},	//   _adah_, одов, siel_, rzum_,
   {{0x80d100c8,0x6d562899,0x25ad289a,0x2009289b}},	//   সেম্, yeya, piel_, _atai_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d56289c,0x10a300af,0x00000000,0x00000000}},	//   veya, диян, --, --,
   {{0x2d990176,0xaab919b7,0x6d56289d,0x753b01b7}},	//   _alse_, _आशंक, weya, lguz,
   {{0x59c90567,0x2d800626,0xa91d0a3c,0x6d56289e}},	//   िकार, tjie_, _rožn, teya,
   {{0x753b289f,0xef240069,0x00000000,0x00000000}},	//   nguz, _biżà_, --, --,
   {{0x8c431da6,0x6d5628a0,0x3b8628a1,0xae1a0066}},	// [1f40] мете, reya, олаг, _फौरन_,
   {{0xa91d28a2,0x2d9900a5,0x6d5628a3,0x09d20099}},	//   _božo, _else_, seya, तत्य,
   {{0xe8fa28a4,0xa91d02dd,0x6d5628a5,0x69cb28a6}},	//   але_, _vožn, peya, foge,
   {{0x69cb038d,0xf1ca112b,0xfd120037,0x7d1f00a8}},	//   goge, रविन, _تجد_, caqs,
   {{0x386d2314,0x7d0428a7,0xa91d08b7,0xbcfb0118}},	//   _crer_, mcis, _tožn, _kaén,
   {{0x7c24184f,0x7d0428a8,0x394d008c,0x81c20831}},	//   msir, lcis, _ebes_, ্গি_,
   {{0x69cb28a9,0x41ca035d,0x7c2425ea,0x29000453}},	//   boge, रवास, lsir, ñias_,
   {{0x69cb28aa,0x7d0407d6,0x386d0107,0x0d970070}},	//   coge, ncis, _frer_, ַכים_,
   {{0x7c240b56,0xc31e0083,0xdb1e01b4,0x7d0428ab}},	//   nsir, _দাবি_, ropæ, icis,
   {{0x926a28ac,0x779200bf,0x7c2428ad,0x2bbf022e}},	//   арма_, _زیبا, isir, ्वया,
   {{0xe3b828ae,0x200928af,0x7dfc0260,0x8afb0070}},	//   rnı_, _stai_, _dčsk, יליז,
   {{0x96330eb9,0xa19412ea,0x3f9a00ec,0x7d040207}},	//   _ініц, даюч, _alpu_, jcis,
   {{0x78a228b0,0x48b80083,0x5064021d,0x2bbf035d}},	//   nzov, _জরুর, мтра, ्वमा,
   {{0x69cb02c9,0x09b728b1,0xc05800d4,0x7d0400ea}},	//   zoge, _अद्य, цію_, ecis,
   {{0x69cb0273,0x21291d2b,0x442628b2,0xddab002d}},	//   yoge, _tdah_, _hvo_, атал_,
   {{0x7c2428b3,0x212900e7,0x442604e0,0x752008c7}},	//   fsir, _udah_, _kvo_, namz,
   {{0x44260009,0x7c241b82,0x69cb28b4,0x1b1f0033}},	// [1f50] _jvo_, gsir, voge, _পাবে_,
   {{0x09b3134b,0x63ba01ae,0x69cb01a8,0x78a201ba}},	//   ंच्य, nntn, woge, dzov,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44260537,0x7d040036,0x7c2428b5,0xceb2016b}},	//   _ovo_, ccis, bsir, _טיי_,
   {{0x1869174b,0x7d1d28b6,0x6c790070,0x442628b7}},	//   сали_, _iess, _האָפ, _nvo_,
   {{0x7d1d28b8,0x69cb28b9,0xbdf80df3,0x80c80033}},	//   _hess, soge, _دریا_, রেক্,
   {{0x44261eb8,0x29dc28ba,0x69cb28bb,0xa2ca28bc}},	//   _avo_, mían_, poge, _सुल्,
   {{0xc48502f3,0x29dc28bd,0xf1c00097,0x44260051}},	//   злик, lían_, čák_, _bvo_,
   {{0x7d1d28be,0x93790037,0x442428bf,0xe3b128c0}},	//   _mess, مصدر_, gsm_, فرد_,
   {{0xf8ae0a86,0x29dc28c1,0x798902e6,0xf7700037}},	//   _حکم_, nían_, _hoew, _لام_,
   {{0x442628c2,0x799b28c3,0x216a210e,0x798928c4}},	//   _evo_, _kluw, бини_, _koew,
   {{0x7d1d17e3,0x85040312,0x44260069,0xbcfb00f8}},	//   _ness, _قومن, _fvo_, _saén,
   {{0xb4fa0122,0x764b010b,0x92b5042c,0x798928c5}},	//   _הפני, žnyč, تحکا, _moew,
   {{0x7c2403d0,0x2245011e,0x6dac027d,0x7d1d00fe}},	//   vsir, ptlk_, rşam, _aess,
   {{0x7d1d02c9,0x29dc0caa,0x78a200ac,0x6d4f0211}},	//   _bess, dían_, zzov, _bbca,
   {{0x7d1d1d84,0x7c2428c6,0xb88300b8,0x6d4f0176}},	//   _cess, tsir, _klíč, _cbca,
   {{0x7d1d28c7,0x7d0428c8,0xe31900e2,0x212228c9}},	// [1f60] _dess, rcis, _điể, makh_,
   {{0x6d4f0176,0xa01b0086,0x29dc0453,0x799b28ca}},	//   _ebca, pyör, gían_, _aluw,
   {{0x4efb0052,0x61e41c26,0x7c2428cb,0xc3320122}},	//   _להיו, _khil, ssir, תוב_,
   {{0xe9d20312,0xd7fa28cc,0x7c2428cd,0x00000000}},	//   رغا_, бук_, psir, --,
   {{0x29dc0f56,0x61e409c3,0x799b01cb,0x79890118}},	//   bían_, _mhil, _dluw, _doew,
   {{0xc7a309ea,0x29dc0f56,0x78a228ce,0x07a328cf}},	//   ничк, cían_, rzov, начн,
   {{0x4426064b,0xdb1e01ae,0x7d1d25e8,0x4e7a0070}},	//   _svo_, ropä, _yess, מאַצ,
   {{0x2abb0122,0x44260df4,0x79890b88,0x00000000}},	//   _המלא, _pvo_, _goew, --,
   {{0x3a3a003c,0xa5070274,0x752002ff,0x3cfd00b4}},	//   lupp_, чења_, ramz, लखते_,
   {{0xe44f0082,0x6f1e0506,0x44260345,0x00000000}},	//   اضي_, _nepc, _vvo_, --,
   {{0x61e409c3,0x44241585,0x2bbf1856,0xaabe178c}},	//   _bhil, ssm_, ्वता, ्थिक,
   {{0x61e428d0,0x44260093,0xc10800af,0xb88300fe}},	//   _chil, _tvo_, зэре_, _flíč,
   {{0x7d1d28d1,0xa91d28d2,0x6ab90d00,0x61e428d3}},	//   _ress, _božj, _आश्र, _dhil,
   {{0x7d1d28d4,0x6f1e023a,0x29dc0042,0x4abe01d1}},	//   _sess, _cepc, xían_, ्थाव,
   {{0x7d1d28d5,0x29dc2675,0xd3e50e3a,0x61e4009d}},	//   _pess, vían_, _تقوی, _fhil,
   {{0x61e428d6,0xbcfb0042,0xdcef00ec,0x9f5300f6}},	//   _ghil, _gaél, _ancā, _mixé_,
   {{0xa3d0045c,0x29dc27c2,0x6c5428d7,0x6ecd0517}},	// [1f70] वकप_, tían_, нкту, _दुरु,
   {{0x69c0022f,0x798928d8,0x799b1ebb,0x00000000}},	//   _ajme, _soew, _sluw, --,
   {{0x29dc116c,0x7d1d28d9,0xbb84004f,0x799b011e}},	//   rían_, _tess, علمي, _pluw,
   {{0x20e1022e,0x00000000,0x00000000,0x00000000}},	//   _नराध, --, --, --,
   {{0xa3cc238a,0xa3c10099,0x7a05005f,0x00000000}},	//   लवा_, ्कम_, _dėta, --,
   {{0x2d8b28da,0x21220118,0x79890118,0x00000000}},	//   _hoce_, zakh_, _woew, --,
   {{0x6b83008a,0x798928db,0xb8f428dc,0x29dc002a}},	//   öngu, _toew, _सु_, cíao_,
   {{0x6d4d06df,0x24090421,0xa2ad0fbf,0xa91d023a}},	//   nfaa, онии_, ुपस्, _možk,
   {{0xd4691c36,0x68fb0409,0x00000000,0x00000000}},	//   ципе_, _igud, --, --,
   {{0x61e4000e,0x69d901ae,0x9f5300f7,0x2d8b01ef}},	//   _shil, llwe, _fixé_, _loce_,
   {{0x61e428dd,0x0cba021a,0x00000000,0x00000000}},	//   _phil, _इश्म, --, --,
   {{0x67230ac8,0x2d8b28de,0x6f1e0139,0x00000000}},	//   lanj, _noce_, _sepc, --,
   {{0xfbbf0ac4,0x27ff00be,0x291f0310,0x81c20033}},	//   ्वाम, _juun_, _meua_, ্গল_,
   {{0x656928df,0x82350a86,0x61e40052,0xe29928e0}},	//   ldeh, _قربا, _whil, _мал_,
   {{0x61e401a6,0x2d8b003a,0x6d4d0855,0x29dc01ef}},	//   _thil, _boce_, ffaa, xíao_,
   {{0x672328e1,0x656928e2,0x291f01e8,0x68fb00f8}},	//   hanj, ndeh, _neua_, _ngud,
   {{0x644928e3,0x6723108a,0x2d8b28e4,0xbfc612e8}},	// [1f80] ntei, kanj, _doce_, _обик,
   {{0x67230528,0xd9b804cc,0x6d4d073a,0x2b430183}},	//   janj, ेक्ट, afaa, _ccjc_,
   {{0x67230496,0x6da6021d,0x644928e5,0x236702c6}},	//   danj, _жина, htei, _manj_,
   {{0x3a3a28e6,0x2d8b28e7,0xdce401f2,0x20000118}},	//   rupp_, _goce_, ldič, _kuii_,
   {{0x260300c8,0xdcb903ad,0xc7c60dbf,0xdb0e008a}},	//   _año_, _ещё_, мски, þjón,
   {{0x672318b0,0x31bb0b40,0xdce428e8,0x656928e9}},	//   ganj, _उद्ध, ndič, edeh,
   {{0xc34e0019,0x6e3c0138,0x45d428ea,0x2a35002d}},	//   _bổng_, nurb, нокс, _пэтр,
   {{0xc34e01a5,0x644928eb,0xe8190026,0x68fb28ec}},	//   _cổng_, ftei, _नौका_, _ggud,
   {{0x67230c4f,0x29e80095,0x13f401af,0x39440279}},	//   banj, _uşaq_, нзия, _icms_,
   {{0x672328ed,0x6e3c28ee,0x27e5009e,0xdb050225}},	//   canj, kurb, _ghln_, rihç,
   {{0xa2941958,0x644928ef,0x777a01a3,0xdb0e0c6f}},	//   хані, atei, _intx, _ambë,
   {{0x644928f0,0x20000103,0x6e3c008d,0x14af0099}},	//   btei, _buii_, durb, _जेवण,
   {{0x14e20ac4,0x2d8b000c,0x644928f1,0x7afc00cb}},	//   _परिण, _roce_, ctei, _ogrt,
   {{0x61ee016f,0x2000009e,0x6e3c0f00,0x00000000}},	//   _ďale, _duii_, furb, --,
   {{0x2bbf2177,0xfbbf0266,0xdb0e01f7,0x6e3c008d}},	//   ्वसा, ्वसम, _imbè, gurb,
   {{0x67230496,0xa2ad000c,0x236728f2,0x7d1603bc}},	//   zanj, ुपर्, _zanj_, gbys,
   {{0x2d8b28f3,0xf1bf024e,0x67230186,0x2000009e}},	// [1f90] _voce_, mná_, yanj, _guii_,
   {{0xf1bf033a,0x291f0443,0x23a00260,0xa3e40b54}},	//   lná_, _seua_, _fòje_, _भीम_,
   {{0x672302dd,0x6e3c28f4,0x644928f5,0xdb1c0097}},	//   vanj, curb, ztei, _ukrý,
   {{0xf1bf28f6,0x672328f7,0x777a01d7,0xa91d07e7}},	//   nná_, wanj, _antx, _koži,
   {{0x67230537,0xa91d02a7,0x64491097,0xdb0e00e0}},	//   tanj, _joži, xtei, _ombè,
   {{0xa3dd004e,0xf771004f,0x06b00033,0x23dd0066}},	//   _थीं_, طات_, _ছড়ি, _नींद,
   {{0x6723022e,0x92c20083,0xa91d00ac,0xe91900d4}},	//   ranj, ্ধু_, _loži, _нові_,
   {{0x644928f8,0x67230bc6,0xf1bf053d,0xdb0e0118}},	//   ttei, sanj, jná_, _ambè,
   {{0xf1bf05d3,0xa91d28f9,0x756800b5,0x2367003d}},	//   dná_, _noži, بینہ_, _panj_,
   {{0x437428fa,0x656902b1,0x00000000,0x00000000}},	//   вуют, sdeh, --, --,
   {{0xc34e00e8,0xfbd20122,0xb3450279,0x23670116}},	//   _tổng_, רתי_, _acçã, _vanj_,
   {{0xa91d05e2,0x569428fb,0x644928fc,0x672128fd}},	//   _boži, _шахт, ptei, _helj,
   {{0x25bf0043,0x02cf0066,0x660128fe,0x7e6501f4}},	//   mnul_, _सुरभ, _hulk, _ashp,
   {{0xa91d1851,0x395d28ff,0x66012900,0x2d8f19ee}},	//   _doži, hews_, _kulk, ögen_,
   {{0x660103ad,0xf1bf024e,0xe2992901,0x25bf00af}},	//   _julk, bná_, _хай_, onul_,
   {{0xf1bf0187,0xdd9214ac,0xdb0e2902,0xd9c90edf}},	//   cná_, دور_, _imbé, िकोट,
   {{0xdca308bb,0x7d162903,0x45da0070,0x7f5c0c6f}},	// [1fa0] гати, rbys, פֿלא, perq,
   {{0xa3c10953,0x67210d4c,0xf4010083,0x7d160297}},	//   ्कि_, _nelj, _এবার_, sbys,
   {{0x1b1f0083,0xdb1c0035,0x25bf0d5c,0xab680069}},	//   _পাশে_, _skró, knul_, _reżħ,
   {{0x6da601e0,0xd826083e,0xaa570079,0x00000000}},	//   _чима, едди, علنا_, --,
   {{0x1b1f00c8,0xa3c100db,0x67212904,0x660101a3}},	//   _পারে_, ्का_, _belj, _aulk,
   {{0x672102c6,0xf1bf2905,0xd7ef004f,0xe6662123}},	//   _celj, zná_, مكن_, етио,
   {{0xd2cf0084,0x67212906,0x2bbf0ac4,0x66010260}},	//   _सुलझ, _delj, ्वरा, _culk,
   {{0xa2ca2907,0x66012908,0x25bf2909,0xa967290a}},	//   _सुग्, _dulk, gnul_, _писа_,
   {{0x6d460526,0xf1bf290b,0xe73a0370,0x672100b5}},	//   _mcka, vná_, _неа_, _felj,
   {{0xc4530082,0xa91d0a65,0x25bf00af,0x777a0065}},	//   اضيع, _roži, anul_, _untx,
   {{0xf1bf0076,0x36360e3a,0x28b60066,0xe7370390}},	//   tná_, _سراس, _आइडि, _чех_,
   {{0x672117ee,0xa91d290c,0xf48401cb,0x00000000}},	//   _zelj, _poži, _لاتی, --,
   {{0x55770779,0xf1bf0076,0x6601290d,0x0cc40033}},	//   _רעדן_, rná_, _zulk, ্ধুত,
   {{0xf1bf024e,0xe47b1899,0x5334290e,0x6d460051}},	//   sná_, _מרדכ, _рект, _acka,
   {{0xf1bf024e,0x00000000,0x00000000,0x00000000}},	//   pná_, --, --, --,
   {{0x13d500c8,0x2bd900b4,0xcdd803fa,0xa3e40380}},	//   _হওয়, _बीजा, ењу_, _भीत_,
   {{0x41c421a0,0x2bbf112b,0xe7e301c0,0x00000000}},	// [1fb0] _حقيق, ्वला, गतमा_, --,
   {{0x7522021d,0x6d46290f,0x09c905f8,0x00000000}},	//   _leoz, _ecka, िक्य, --,
   {{0x67212910,0x75e50453,0x00000000,0x00000000}},	//   _relj, nózc, --, --,
   {{0xc9841150,0xdd1600a0,0x98b906e4,0x00000000}},	//   лучи, _päťd, млет_, --,
   {{0x66012911,0x67212912,0xa3d001c0,0xf7451403}},	//   _sulk, _pelj, वका_, вело,
   {{0x6d5f06c4,0x66012913,0xec360277,0x00000000}},	//   leqa, _pulk, _באשר_, --,
   {{0x67212914,0xbbbf0967,0x0cc40033,0x19ab2915}},	//   _velj, ्वीक, ্ধৃত, _етап_,
   {{0x6d5f0510,0xc65400e0,0x00000000,0x00000000}},	//   neqa, افيک, --, --,
   {{0x67212916,0x9f530955,0x57f515ae,0x25bf0043}},	//   _telj, _així_, _апат, rnul_,
   {{0x66012917,0x61bc022e,0xc6a72447,0xe2990274}},	//   _tulk, ोक्ष, _преи, дао_,
   {{0x0cde06bc,0xb2f400c3,0x2ca903d0,0x25fa0067}},	//   _मर्म, ляющ, hzad_, _ऊंची_,
   {{0xe2962918,0x7afa2919,0x00000000,0x00000000}},	//   таю_, _útte, --, --,
   {{0x2ca91269,0x6d5f012f,0x656b009e,0x00000000}},	//   jzad_, deqa, _iagh, --,
   {{0x656b0082,0x443f081b,0x752201a3,0x00000000}},	//   _hagh, muu_, _zeoz, --,
   {{0x443f0086,0x6d46011e,0xff070043,0x00000000}},	//   luu_, _pcka, теск_, --,
   {{0x656b003c,0xa91d0cc1,0xfce607b0,0xdde900d1}},	//   _jagh, _kožu, вобо, فرقه_,
   {{0x656b291a,0x443f291b,0xfc0310e3,0x6f020139}},	// [1fc0] _magh, nuu_, ипто, _şocu,
   {{0x656b009c,0x4e062294,0xaaba02fd,0x9f4c0421}},	//   _lagh, _изоб, ودار_, ödä_,
   {{0x443f0421,0x6a8601d3,0x91fc00ea,0xbea6291c}},	//   huu_, ължа, lvār, _ранк,
   {{0x443f291d,0x656b12d7,0x645911ad,0x3f8a00cd}},	//   kuu_, _nagh, _opwi, ljbu_,
   {{0x92bd00c8,0x91fc0029,0x443f1b65,0x6843291e}},	//   _আরো_, nvār, juu_, инца,
   {{0x6d44291f,0x244b08c8,0xeb9f1217,0x00000000}},	//   lgia, døm_, _støv_, --,
   {{0x25a400d7,0x64590107,0xacbb00a2,0xdce60107}},	//   thml_, _apwi, _jeûn, _makč,
   {{0x6d442920,0x7bde2921,0x443f0054,0xd5b70aeb}},	//   ngia, llpu, fuu_, ксы_,
   {{0x656b2922,0x443f0054,0x80e12923,0x91fc00ea}},	//   _dagh, guu_, _नरें, jvār,
   {{0x69c20009,0x91fc013a,0xb4e20437,0xa91d0124}},	//   lnoe, dvār, _धरी_, _dožu,
   {{0x656b1c8b,0xa1950036,0xbb3b00a5,0x752200f4}},	//   _fagh, ганч, ועיי, _teoz,
   {{0x80d10083,0x69c200e9,0x656b0069,0xe8192924}},	//   _সৃষ্, nnoe, _gagh, नीका_,
   {{0x04430bef,0x443f0160,0xe3af0220,0x00000000}},	//   _вечн, cuu_, صری_, --,
   {{0x64402925,0x656b2926,0x4fc40328,0x00000000}},	//   mumi, _zagh, асса, --,
   {{0x64402927,0xa3c10653,0x75e5006c,0x93fb0317}},	//   lumi, ्कर_, lóza, _קלוי,
   {{0x6d440133,0x46b500ab,0x7bde0051,0x00000000}},	//   ggia, _अइसह, elpu, --,
   {{0x64402928,0x3b55002d,0x5c750f8f,0x6d5f0510}},	// [1fd0] numi, лкар, ылат, reqa,
   {{0xbbbf0d53,0x765a0035,0xd24d00fd,0x5b1401e0}},	//   ्वेक, _opty, _بچی_, имут,
   {{0x64400657,0x6d4400e2,0x443f2929,0xb4cf012f}},	//   humi, bgia, zuu_, _षड्_,
   {{0x6440292a,0x443f00d7,0x99d10083,0xac1900af}},	//   kumi, yuu_, িষ্ক, _пому_,
   {{0x64400080,0x7c84292b,0x656b0874,0x9f5a0107}},	//   jumi, _куре, _ragh, _bipè_,
   {{0xb605292c,0x7d0d00f1,0x6440292d,0xfba70287}},	//   hláš, lcas, dumi, _गतिम,
   {{0x656b12d7,0x9967292e,0x7d0d0036,0x443f0103}},	//   _pagh, _итал, ocas, wuu_,
   {{0x4efc0052,0x443f0086,0xa91d0254,0x6440018e}},	//   ולוג, tuu_, _požu, fumi,
   {{0x6440292f,0x656b027a,0xa3c10d91,0xceb50160}},	//   gumi, _vagh, ्कल_, _deși_,
   {{0x443f2930,0x7c2d2931,0x7d0d0211,0x244b0c71}},	//   ruu_, isar, hcas, røm_,
   {{0xe29905a1,0x656b2932,0x6d44001e,0x443f2933}},	//   хан_, _tagh, ygia, suu_,
   {{0xe57003c7,0x64402934,0x7c2d2935,0x443f127d}},	//   _وطن_, bumi, ksar, puu_,
   {{0xad9b0391,0x64400e85,0x91fd02d4,0x7d0d2936}},	//   _miúd, cumi, tvār, dcas,
   {{0x442d2937,0x7c2d2938,0x442f2939,0x00000000}},	//   mse_, dsar, _ivg_, --,
   {{0xed5a0994,0xd5ac0332,0x442d293a,0x7c2f0176}},	//   нов_, _رہی_, lse_, _avcr,
   {{0x442d293b,0x7d0d0176,0x69c3006c,0x5d6700af}},	//   ose_, gcas, énel, лисм_,
   {{0x442d293c,0x7077004f,0x7c2f0036,0x6abe012f}},	// [1fe0] nse_, _مميز_, _cvcr, ्थ्र,
   {{0x442d293d,0x442f293e,0x6d4400e9,0x7d0d01ef}},	//   ise_, _mvg_, sgia, acas,
   {{0x6440293f,0x442d2940,0x8ad501c8,0x442f0009}},	//   zumi, hse_, аюцц, _lvg_,
   {{0x442d2941,0x9f5a02e9,0x2d9e00ea,0x7c2d2942}},	//   kse_, _sipè_, ītes_, bsar,
   {{0x64e20953,0x442d2943,0x69c22944,0xb4e20324}},	//   _परेश, jse_, rnoe, _धरे_,
   {{0x38cb0357,0x442d2945,0xb7d20083,0x64402946}},	//   رانی_, dse_, াষ্ট, vumi,
   {{0xfaa62947,0x7bcb2948,0xaab80e6f,0x49940e3a}},	//   _саво, égue, _आधिक, _پیشر,
   {{0x64402949,0xad9b0079,0x2fda0282,0xb8fa0831}},	//   tumi, _giúd, _lkpg_, _ডঃ_,
   {{0xd326294a,0x442d294b,0xb993004f,0x48e30be8}},	//   льни, gse_, _القب, _готв,
   {{0x6440294c,0xf366294d,0x3946294e,0x3254294f}},	//   rumi, утин, lgos_, авор,
   {{0x442d0052,0x7c2d0080,0xafdb0c61,0x454605bc}},	//   ase_, zsar, ktør, _مناق,
   {{0x39462950,0x7c2d1fb2,0x442f027a,0x64402951}},	//   ngos_, ysar, _fvg_, pumi,
   {{0x2b4a012f,0x442d2952,0xc5f3011d,0xdb1e0ec3}},	//   _ocbc_, cse_, _הדף_, nopó,
   {{0xa91d2953,0x6ed6193c,0x7d0d2954,0x672a05ee}},	//   _inže, _मुहु, wcas, nafj,
   {{0x7c2d2955,0x539b011d,0x98ad0116,0x59d40b35}},	//   wsar, _איגו, _rdeč_, धकार,
   {{0x63ba05d3,0x82331a7c,0xc27b0317,0xf12701e0}},	//   litn, _اروا, _טרוי, _сько,
   {{0x7d0d2956,0x69c302e1,0xdfd1063d,0x61ed2957}},	// [1ff0] rcas, énem, _ويب_, _ihal,
   {{0x212b2958,0x63ba0252,0x39461a84,0x798002d0}},	//   lach_, nitn, egos_, _anmw,
   {{0x7c2d2959,0x61ed295a,0x629a295b,0x3f81035f}},	//   ssar, _khal, nyto, _inhu_,
   {{0x212b295c,0x442d295d,0xa91d0009,0x61ed009f}},	//   nach_, yse_, _onže, _jhal,
   {{0x39490080,0x61ed111c,0x186907be,0x63ba0600}},	//   ļas_, _mhal, тали_, kitn,
   {{0x212b0094,0x629a00d8,0x442f0479,0x3946010b}},	//   hach_, kyto, _rvg_, agos_,
   {{0x212b295e,0x442d295f,0x69ca00f7,0x752901a3}},	//   kach_, wse_, éfec, taez,
   {{0x442d2960,0x629a1648,0x2bbf0e61,0x212b0035}},	//   tse_, dyto, ्वका, jach_,
   {{0x212b2961,0x291d08e1,0x63ba03c9,0x442d2962}},	//   dach_, mbwa_, fitn, use_,
   {{0x61ed0291,0x13a700ff,0x63ba067f,0xe7a901c0}},	//   _ahal, اندی_, gitn, _कतिप,
   {{0x61ed2963,0x212b2964,0xa2e50009,0x60cd0168}},	//   _bhal, fach_, ронд, _axam,
   {{0x442d2965,0x212b2966,0x76432967,0x61ed2968}},	//   pse_, gach_, muny, _chal,
   {{0x61ed2969,0x7643162d,0x2fda00d7,0x15f400d2}},	//   _dhal, luny, _pkpg_, _اسلح,
   {{0x629a290b,0x7fd60210,0x394621aa,0x74120088}},	//   byto, рімі, zgos_, _بووا,
   {{0x60cd296a,0x212b296b,0x7643296c,0x629a296d}},	//   _exam, bach_, nuny, cyto,
   {{0x61ed296e,0xd1ba0332,0x4ad90d00,0x3d20004e}},	//   _ghal, _جاتا_, _बुधव, बरें_,

   {{0x8c46296f,0x2a6a012f,0xafdb082b,0x76432970}},	// [2000] резе, _ssbb_, rtør, huny,
   {{0x69db2971,0x109b011d,0xafdb082b,0x207b0070}},	//   _akue, _סביב, stør, _יאפא,
   {{0x32070955,0x34e20632,0x76432972,0x7f3b0122}},	//   _juny_, _पर्द, juny, _בעיו,
   {{0x394601c8,0xeae602cb,0x8c461f39,0x26de010b}},	//   ugos_, _करीत_, _кеме, _ryto_,
   {{0x39462140,0xa91d03ab,0x8eb300d1,0x69c90051}},	//   rgos_, _požr, _همیش, _djee,
   {{0x81bd0080,0x39460020,0x69db00d7,0x7643018e}},	//   lsēt, sgos_, _ekue, funy,
   {{0x76432973,0xdb1701ef,0x56941f39,0x79800103}},	//   guny, xixé, сайт, _tnmw,
   {{0x6d5602e9,0xe5c603fa,0x59de0026,0x281603ec}},	//   nfya, јско, _फीचर, _نورس,
   {{0x88bd006a,0x212b2974,0x2fd801ff,0x2904217c}},	//   _jeśl, vach_, korg_, _igma_,
   {{0x26de01c0,0x61ed2975,0x212b0035,0x386901f4}},	//   _tyto_, _shal, wach_, çare_,
   {{0x212b2976,0x63ba2977,0x61ed2978,0x76432979}},	//   tach_, ritn, _phal, cuny,
   {{0x29dc1111,0x61ed00d7,0x969502c4,0x629a297a}},	//   mías_, _qhal, _уруш, ryto,
   {{0x7bdc0bec,0x212b297b,0x63ba04c3,0x29dc1111}},	//   _okru, rach_, pitn, lías_,
   {{0x212b297c,0x2d820f2f,0x644f0955,0xd83f053d}},	//   sach_, _anke_, àcie, _účet_,
   {{0x6728297d,0x61ed297e,0x29dc0b4c,0x212b297f}},	//   _medj, _thal, nías_, pach_,
   {{0xaada0084,0x61ed0054,0xdda80043,0xdce600ea}},	//   _भड़क, _uhal, атул_, _sakā,
   {{0x2fd82980,0xdce600ea,0x3f9301ed,0x6be50037}},	// [2010] borg_, _pakā, _toxu_, مكرم,
   {{0x6728029d,0xa3e619b7,0x69db0c71,0xfbd01c64}},	//   _nedj, पति_, _skue, وتل_,
   {{0x7bc52981,0x5a470677,0x68e900b5,0x2001010d}},	//   rnhu, рэза, _szed, _iihi_,
   {{0x76432982,0x29dc0b4c,0xbcfb01cb,0xa91d00fe}},	//   vuny, días_, _daér, _cožp,
   {{0xe7390192,0xa3e60fd0,0x68e00297,0x7c871bc0}},	//   гел_, पता_, _cymd, _туне,
   {{0x76430f1a,0x785a0080,0x21292983,0x29dc0f56}},	//   tuny, dāvā, _leah_, fías_,
   {{0xf7701b15,0x29dc0033,0x69c90223,0x77632984}},	//   بان_, gías_, _tjee, renx,
   {{0x76432985,0x2fd80120,0x20010c6f,0x1dc700e7}},	//   runy, zorg_, _lihi_, रचित,
   {{0xbee409a3,0x68e0001e,0x69d92986,0x764300d1}},	//   _गर्न_, _gymd, mowe, suny,
   {{0xe7842987,0x76432988,0x29dc05c9,0x320701f7}},	//   _мухо, puny, bías_, _puny_,
   {{0x6b952989,0xd57501c8,0xe1fa1d36,0x29dc0b4c}},	//   _mozg, _гуль, лго_, cías_,
   {{0x200900d7,0x69d90035,0xdcfd021e,0x13a7042c}},	//   _buai_, nowe, _ansč, انگی_,
   {{0xd24e03c5,0x2009028b,0x2fd80093,0x21290211}},	//   ونی_, _cuai_, torg_, _deah_,
   {{0x443f298a,0x200900d7,0xaad00035,0x69d9298b}},	//   mru_, _duai_, _तुझक, howe,
   {{0x69d90035,0xdee608bb,0x23651b88,0x394d0124}},	//   kowe, сови, melj_, _oces_,
   {{0x394d006d,0x290000d8,0xdce4003a,0x2fd8298c}},	//   _nces_, žiai_, ndić, sorg_,
   {{0x69d9004e,0x2009298d,0x6b95298e,0xad9b0079}},	// [2020] dowe, _guai_, _bozg, _siúc,
   {{0x68e001ff,0x443f298f,0x00000000,0x00000000}},	//   _rymd, iru_, --, --,
   {{0x4906004f,0x443f2990,0x29dc0391,0x386d2991}},	//   مواق, hru_, xías_, _aser_,
   {{0x5d860082,0x70530164,0x29dc0b06,0x69d90067}},	//   _الحل, _بنیا, vías_, gowe,
   {{0x67282889,0xdb0e01ef,0x236502a7,0x4c35002d}},	//   _pedj, _embá, kelj_, _мэрт,
   {{0x7bdc2992,0x29dc2993,0x0f7a0070,0xad9b0098}},	//   _ukru, tías_, ראַב, _tiúc,
   {{0x443f2994,0x2365080a,0x386d0225,0x9f5202d7}},	//   eru_, delj_, _eser_, _huyó_,
   {{0x29dc09ab,0x98a60012,0x29041b82,0x88840580}},	//   rías_, _либе, _ugma_, _ویان,
   {{0x443f2995,0x29dc0b4c,0x6b950225,0x9f5a027a}},	//   gru_, sías_, _yozg, _pipì_,
   {{0x29dc1111,0x236513bd,0x00000000,0x00000000}},	//   pías_, gelj_, --, --,
   {{0x4df807ba,0x2009104e,0x443f2996,0x225800c3}},	//   ंगाई_, _suai_, aru_, шины_,
   {{0x443f2997,0x25a608dd,0xeae600ab,0x00000000}},	//   bru_, _ulol_, _करैत_, --,
   {{0x443f0043,0x20092998,0x2365023a,0x6ac420af}},	//   cru_, _quai_, belj_, वपुर,
   {{0x33f61a31,0x69d92999,0x23651bd8,0x4fc700c3}},	//   _учес, zowe, celj_, ссма,
   {{0x6b95299a,0x69d90054,0xd35700a5,0x82330697}},	//   _rozg, yowe, _השוק_, _فريا,
   {{0x2009028b,0x6440299b,0xd13100d1,0x442601a8}},	//   _tuai_, ormi, _کمک_, _kwo_,
   {{0x20010478,0xb606012e,0x6602299c,0x6b9501b7}},	// [2030] _tihi_, lišć, _miok, _pozg,
   {{0x6ac41bc6,0x64400037,0x66021b6f,0x69d9299d}},	//   वपूर, irmi, _liok, wowe,
   {{0x69d9299e,0x3cde00a1,0x29dc299f,0xdd9500c7}},	//   towe, _कुठे_, víar_, _даны,
   {{0x19591482,0x127b02b5,0x442629a0,0x443f29a1}},	//   рады_, טאבע, _owo_, yru_,
   {{0x69d92737,0xf09f12c3,0x6d4f29a2,0xdb17002a}},	//   rowe, nyà_, _icca, lixí,
   {{0x01cf0083,0x645c0043,0x69d929a3,0xbcfb0118}},	//   রতিদ, ăril, sowe, _abég,
   {{0x442609d6,0x644029a4,0x80c000b4,0x86980382}},	//   _awo_, ermi, _लेने, йтът_,
   {{0x443f29a5,0x44260b55,0x84592325,0xb606012e}},	//   tru_, _bwo_, арот_, dišć,
   {{0x23651851,0x386d29a6,0x443f29a7,0xf1bf01ba}},	//   telj_, _user_, uru_, diá_,
   {{0x443f29a8,0xdb0e0093,0x44260107,0xe3b90dfc}},	//   rru_, _embæ, _dwo_, рбо_,
   {{0x6d5d114d,0x66020009,0x6d4f1e11,0x442629a9}},	//   _obsa, _fiok, _occa, _ewo_,
   {{0xe56e005f,0x443f29aa,0x659429ab,0x6602027a}},	//   _ўз_, pru_, _наху, _giok,
   {{0x442629ac,0x25bf00af,0x23650a66,0xeae629ad}},	//   _gwo_, miul_, pelj_, _कर्त_,
   {{0x6d5d29ae,0x6d4f01d3,0x3cdd0084,0x25bf002d}},	//   _absa, _acca, _खड़े_, liul_,
   {{0xf1bf0952,0x2d961402,0x00000000,0x00000000}},	//   biá_, орас, --, --,
   {{0x25bf0043,0x3dc9043d,0xf1bf1945,0x51f603fc}},	//   niul_, gnaw_, ciá_, _بستر,
   {{0xfce329af,0x752b29b0,0x249f29b1,0x248d0176}},	// [2040] дото, _megz, nyum_, nxem_,
   {{0x61e629b2,0x25bf00af,0x6d4f0027,0x248d0176}},	//   llkl, hiul_, _ecca, ixem_,
   {{0xed5a00c9,0x3dc9010d,0x00000000,0x00000000}},	//   _кон_, bnaw_, --, --,
   {{0xe9da2217,0xd37800cb,0xad5a010b,0x00000000}},	//   шке_, moće_, _трох_, --,
   {{0x25bf0043,0x999c00fd,0x25ad29b3,0x00000000}},	//   diul_, évő_, dhel_, --,
   {{0x44260232,0x207b0070,0xc7a3117a,0x38690132}},	//   _rwo_, יאנא, мичк, çara_,
   {{0x81c30033,0x7bce0223,0xd37800f4,0x3cde021a}},	//   ্তত_, _ijbu, noće_, _कुते_,
   {{0x2d920232,0x25ad29b4,0x7e9b02b5,0xad9b0037}},	//   njye_, ghel_, יסצו, _liún,
   {{0xa73a042c,0x938a29b5,0xd3780207,0x00000000}},	//   _نثار_, асна_, hoće_, --,
   {{0xa3e40722,0xb6060124,0x442602a2,0xd37800f4}},	//   _भीख_, tišć, _vwo_, koće_,
   {{0x86c6004f,0xcb130122,0xf1bf0a54,0xb7d700b5}},	//   _بيان, ולת_, tiá_, _بولا_,
   {{0x44260052,0xb60603fa,0x290000d8,0x25bf0043}},	//   _two_, rišć, žiau_, ciul_,
   {{0x4426070b,0xcf0000a8,0xf1bf00a0,0x25d900f8}},	//   _uwo_, əşən_, riá_, _اهنگ_,
   {{0x437400d1,0x61e60051,0xad9b0098,0x00000000}},	//   _رهبر, alkl, _ciún, --,
   {{0x3ea5006c,0x6d5d009e,0xf1bf014c,0x00000000}},	//   ált_, _pbsa, piá_, --,
   {{0x321e28c3,0xdb1701dd,0x51871783,0x463b016b}},	//   mpty_, rixí, _фука, יעלע,
   {{0x030e0299,0xe7bc29b6,0xa1f900b5,0xc19c00a5}},	// [2050] _सलाह_, ्चाप, _پڑھا_, _כשהי,
   {{0x09d31e18,0x1fa709ce,0x6ed6111a,0xda7b0382}},	//   तव्य, _фриг, _मुकु, ияе_,
   {{0xfd4700b5,0xaf010033,0x00000000,0x00000000}},	//   _ویسٹ_, ্রহণ_, --, --,
   {{0x2ca029b7,0x67ed1f51,0x09c5021a,0x00000000}},	//   byid_, dúja, लचेय, --,
   {{0xb17c0070,0x661a03d0,0xdb1e01f7,0x98f4010b}},	//   יטאר, _attk, kipè, мяшч,
   {{0x81c300c8,0x2d9929b8,0x6cfa0122,0x6d4d29b9}},	//   ্তি_, _hose_, _לפרס, lgaa,
   {{0xb90200ab,0x2d9929ba,0x67ed00b5,0x25bf00af}},	//   _नु_, _kose_, gúja, tiul_,
   {{0x6d4d29bb,0x2d9929bc,0x39150746,0x00000000}},	//   ngaa, _jose_, _хмар, --,
   {{0x81c30083,0x25bf0043,0x395f0107,0x661a0282}},	//   ্তা_, riul_, _ibus_, _ettk,
   {{0x2d9929bd,0x249f29be,0x752b1bb3,0x00000000}},	//   _lose_, ryum_, _wegz, --,
   {{0x69cb29bf,0x95cb0086,0x25bf002d,0x04fd0033}},	//   onge, _куда_, piul_, ীরের_,
   {{0x2ca029c0,0x6d4d29c1,0x69cb29c2,0xd3780009}},	//   yyid_, jgaa, nnge, voće_,
   {{0x69cb29c3,0x6d4d29c4,0x920b0461,0x261100e2}},	//   inge, dgaa, _सूरज_, _háo_,
   {{0xd9b8175f,0x6d4d29c5,0xa4fa00a5,0x2d990118}},	//   _अष्ट, egaa, _פלסט, _aose_,
   {{0x2d990232,0x59db0d53,0x8e8319b6,0x6d4d2193}},	//   _bose_, यकार, нгре, fgaa,
   {{0x6d4d0173,0x2d9901d3,0x76431ea7,0xa3b70437}},	//   ggaa, _cose_, irny, घोर_,
   {{0xdb1e29c6,0x6ac41856,0x7a0c0be2,0xad9b0098}},	// [2060] qipë, वप्र, _iğti, _tiún,
   {{0x395f29c7,0x6d4d29c8,0x656929c9,0x69cb29ca}},	//   _abus_, agaa, heeh, enge,
   {{0x2d9929cb,0x2ca00a7e,0x9f9b0122,0x98b00254}},	//   _fose_, syid_, _הסיפ, đači_,
   {{0x5f46006c,0x2d9901a3,0x3f9a29cc,0x00000000}},	//   _بنگل, _gose_, _hopu_, --,
   {{0xa3bd02cb,0x3f9a29cd,0x7d7b00a5,0xa3cb29ce}},	//   ीचा_, _kopu_, _הנכו, रचा_,
   {{0x261100e8,0xdb1e0118,0x644912c3,0x2d990010}},	//   _báo_, kipé, duei, _zose_,
   {{0x261100e8,0x2d990232,0x7bde022e,0xd5ba2626}},	//   _cáo_, _yose_, mopu, йси_,
   {{0x69c3006c,0x7d160118,0x9418195c,0x00000000}},	//   énet, ncys, ожит_, --,
   {{0x644929cf,0x764329d0,0xdce400c7,0xdcfd0160}},	//   guei, arny, keič, _insă,
   {{0x69c229d1,0xdc9b0070,0x7dfc0107,0x00000000}},	//   lioe, צייל, _včsy, --,
   {{0xe4d60357,0x6d4d1d8d,0xf77300a5,0x5ec10033}},	//   _کتاب, ygaa, _רקע_, _শুনে,
   {{0xfbc40083,0x69c229d2,0x925700c3,0x7bde02ee}},	//   ্তিত, nioe, чают_, hopu,
   {{0x64491010,0x7bde00c3,0xad9b0037,0x78a229d3}},	//   cuei, kopu, _diúl, nyov,
   {{0x2259004e,0xdce40009,0xa91d023a,0x69c201ed}},	//   ńska_, geič, _anžl, hioe,
   {{0x6d4d29d4,0xdb1e004f,0x7bde040b,0x69cb29d5}},	//   tgaa, cipé, dopu, ynge,
   {{0xdd9429d6,0x91e403fa,0x69c20065,0x00000000}},	//   насы, _поје, jioe, --,
   {{0x6d4d29d7,0x2d991628,0x113c00a5,0x69b000b4}},	// [2070] rgaa, _vose_, _התחל, ंसनी,
   {{0x6d4d29d8,0x2d9901d5,0x09c50099,0xbcfb00a2}},	//   sgaa, _wose_, लच्य, _abéc,
   {{0x2d9929d9,0xb4c90026,0x69c201ed,0x00000000}},	//   _tose_, _ईश्_, fioe, --,
   {{0x6ed6045c,0x69cb02fb,0x69c229da,0x26110023}},	//   _मुटु, unge, gioe, _ráo_,
   {{0xeab0006c,0x26110023,0x69cb29db,0x3f9a0118}},	//   نٹے_, _sáo_, rnge, _yopu_,
   {{0x66e529dc,0xdb2303fc,0x69da0132,0xfd1300b5}},	//   мола, _سوری, _íten, _تجھ_,
   {{0xe73001b2,0x69c3002a,0x69c20065,0x00000000}},	//   اصه_, énes, bioe, --,
   {{0x64490443,0x395f02b3,0xe7ed0387,0x387f0044}},	//   tuei, _ubus_, _चीरा_, _trur_,
   {{0x79890168,0x00000000,0x00000000,0x00000000}},	//   _inew, --, --, --,
   {{0x26110019,0x799b0223,0xad9b0079,0xf77029dd}},	//   _táo_, _houw, _siúl, _مام_,
   {{0x614629de,0x3f9a0a69,0x799b02d0,0x6449005f}},	//   мена, _ropu_, _kouw, suei,
   {{0x5ec10083,0x799b29df,0xdb1e29e0,0x7bde034d}},	//   _শুভে, _jouw, ripé, zopu,
   {{0x644929e1,0xafdb0185,0xad9b0132,0x799b02a2}},	//   quei, rrøn, _ciúm, _mouw,
   {{0x69c206a2,0x799b29e2,0xa2d80067,0x00000000}},	//   zioe, _louw, _नुक्, --,
   {{0xdee32515,0x5de600d8,0x0ef9010b,0xdb0e00f6}},	//   вори, джва, зэты_, _embû,
   {{0x69bf0fd1,0xd378012e,0x799b01f7,0xdb1c29e3}},	//   लोमी, moća_, _nouw, _imré,
   {{0x5f76028c,0x61e429e4,0xa5c6008d,0x7e65009e}},	// [2080] _قادر, _ikil, ljóð, _ephp,
   {{0xfaa629e5,0x78a208c7,0x00000000,0x00000000}},	//   мазо, vyov, --, --,
   {{0x7c36017b,0x81c300c8,0x799b29e6,0x1d0a0431}},	//   ssyr, ্তর_, _bouw, _мени_,
   {{0x7bde29e7,0x79890090,0x00000000,0x00000000}},	//   sopu, _cnew, --, --,
   {{0x79890069,0x69c201d7,0xd3780207,0x61e40a6b}},	//   _dnew, rioe, hoća_, _mkil,
   {{0xe6c9021a,0x7a0c002d,0x69c329e8,0x69c229e9}},	//   िपूज, _aşte, éner, sioe,
   {{0x6b9c29ea,0x799b0107,0x69c201b7,0x00000000}},	//   _iorg, _fouw, pioe, --,
   {{0x6b9c00b5,0x61e429eb,0x320e027a,0x799b2069}},	//   _horg, _nkil, _rufy_, _gouw,
   {{0x69c029ec,0x6b9c29ed,0xdb1c0118,0x236a2123}},	//   _imme, _korg, _amré, ојно_,
   {{0x6b9c1c98,0x61e4000e,0xf36622a9,0x889b00a5}},	//   _jorg, _akil, фтин, _ובמי,
   {{0xbcfb0037,0x6b9c14f9,0x00000000,0x00000000}},	//   _mbéa, _morg, --, --,
   {{0x6b9c09c3,0x61f629ee,0xad9b021d,0xc6930277}},	//   _lorg, _chyl, _piúm, _שאף_,
   {{0x6b9c0173,0x0cc90033,0x65620371,0x3cde012f}},	//   _oorg, _শর্ত, _iboh, _कुले_,
   {{0x6b9c27fe,0x61e429ef,0xa5c6003e,0xdb0e0176}},	//   _norg, _ekil, bjóð, _embú,
   {{0x69c029f0,0xa3bd0035,0xdd9b1474,0x3ced00d5}},	//   _omme, ीचर_, оша_, _šev_,
   {{0xc5f800ea,0x00000000,0x00000000,0x00000000}},	//   _spēj_, --, --, --,
   {{0x6b9c29f1,0x65620027,0x799b02a2,0x3c5800af}},	// [2090] _borg, _mboh, _rouw, митэ_,
   {{0x799b0260,0x69c029f2,0x6b9c29f3,0x61fd093a}},	//   _souw, _amme, _corg, lmsl,
   {{0xfd10006c,0x65620187,0x6b9c29f4,0x799b021e}},	//   اجہ_, _oboh, _dorg, _pouw,
   {{0x4c950bfe,0x9f5a00c3,0x6d4b0098,0x49b800f8}},	//   _зимс, _eipä_, ógad, واند_,
   {{0x6b9c29f5,0x2d8b027d,0x799b02a2,0x7e6200cd}},	//   _forg, _ince_, _vouw, _ćopi,
   {{0x69c029f6,0xdce401d6,0x656229f7,0x6b9c05f0}},	//   _emme, ldiğ, _aboh, _gorg,
   {{0x4ae401c8,0xdcfd010b,0x16a917f9,0x799b29df}},	//   _аўта, _posė, явки_, _touw,
   {{0x7bc529f8,0x6b9c29f9,0xc8c000a1,0xdce401d6}},	//   lihu, _zorg, _शेवट, ndiğ,
   {{0x443929fa,0x290d027a,0x6b9c29fb,0x4a08002d}},	//   és_, _igea_, _yorg, _цэрм_,
   {{0x61e429fc,0x422529fd,0xf77329fe,0x61f600fe}},	//   _skil, ндов, _جار_, _shyl,
   {{0x2d8b29ff,0x98a400af,0x00000000,0x00000000}},	//   _once_, _temă_, --, --,
   {{0x22590035,0xe29a0023,0xa91d00c7,0x68e9030d}},	//   ńsko_, _ngưu_, _požy, _kyed,
   {{0x6abd0ea3,0x3209067f,0xa5c60093,0x7bc51b68}},	//   ्पुर, _diay_, sjóð, kihu,
   {{0x2d8b0228,0x7bc5002f,0x656200ac,0x61fd12ba}},	//   _ance_, jihu, _zboh, amsl,
   {{0x24592a00,0x645b2a01,0x61f62a02,0x68e9030d}},	//   lèm_, ltui, _thyl, _lyed,
   {{0x657b2a03,0x32090019,0x61e4002f,0x62832a04}},	//   nduh, _giay_, _ukil, _irno,
   {{0xf3900019,0x8c43020a,0x68e900d1,0x6b9c2a05}},	// [20a0] _mảnh_, лете, _nyed, _porg,
   {{0x6abd2a06,0x7bc50010,0x657b2a07,0x62832a08}},	//   ्पूर, gihu, hduh, _krno,
   {{0x6b9c02c9,0x645b2a09,0xfaa3005f,0x7c292a0a}},	//   _vorg, htui, лафо, _çern,
   {{0x645b053e,0x6b9c03bc,0xe8fa2a0b,0x68e90103}},	//   ktui, _worg, пле_, _byed,
   {{0x6b9c2a0c,0x69da2a0d,0xd7e600d8,0x7bc504fb}},	//   _torg, _ítem, ніко, bihu,
   {{0x290d0176,0x62830566,0x6b9c23f4,0x00000000}},	//   _egea_, _orno, _uorg, --,
   {{0x56942a0e,0xfa670272,0x7c242a0f,0x61fd0093}},	//   тайт, _парк_, lpir, ymsl,
   {{0xd5b70862,0xf3900028,0x4ad9000c,0x657b043d}},	//   есь_, _cảnh_, _बुटव, gduh,
   {{0x62832a10,0xb8860314,0x645b2a11,0x65790211}},	//   _arno, _blíž, gtui, _dawh,
   {{0xdb17013b,0x00000000,0x00000000,0x00000000}},	//   rixç, --, --, --,
   {{0xf8bf00fb,0x62830a78,0x0bb700a5,0x645b2a12}},	//   _þér_, _crno, גלים_, atui,
   {{0x645b053e,0x7bc52a13,0x62832a14,0x656200ac}},	//   btui, zihu, _drno, _uboh,
   {{0xdce4027d,0x777a01a3,0x7bc5251e,0xf1c005fc}},	//   vdiğ, _katx, yihu, शोधन,
   {{0x2294004f,0x7c24008b,0x777a01ed,0xdcef0139}},	//   _للتس, dpir, _jatx, _lacă,
   {{0xfe70006c,0x777a2a15,0x0edb26c6,0x00000000}},	//   یدہ_, _matx, _मुखड, --,
   {{0x777a0065,0x00000000,0x00000000,0x00000000}},	//   _latx, --, --, --,
   {{0x3cfc02cb,0xdce401d6,0x7c242a16,0xd16401d3}},	// [20b0] लेले_, rdiğ, gpir, _същи,
   {{0x657b03fa,0xa91d2a17,0xe1ff2a18,0x3b54002d}},	//   zduh, _inži, lmó_, лкур,
   {{0xc3330122,0xdcef00af,0xdb1e0952,0x68e9008c}},	//   רוע_, _bacă, cipí, _syed,
   {{0x245902d0,0x7c240051,0xf1e106fe,0x7bc5135c}},	//   yèm_, bpir, नविन, sihu,
   {{0x777a2a19,0xf3900023,0x65792a1a,0xed600355}},	//   _batx, _rảnh_, _rawh, ížet_,
   {{0xf7711c51,0x777a0392,0x98a20226,0xf3900023}},	//   شات_, _catx, рише, _sảnh_,
   {{0xd91501c8,0x777a2a1b,0xf1e105f8,0x00000000}},	//   _адбы, _datx, नवान, --,
   {{0xd6ce004f,0x645b00c3,0xdb0e2a1c,0xb88600d5}},	//   تقى_, ttui, _albè, _slíž,
   {{0xad9b0079,0x777a2a1d,0x44240159,0x7a0c0448}},	//   _ciúi, _fatx, gpm_, _işta,
   {{0x645b11f6,0x5ed70083,0x777a01b7,0x20120103}},	//   rtui, _ধরনে, _gatx, _ruyi_,
   {{0x65792a1e,0x645b2a1f,0xdb1e0132,0xa91d023a}},	//   _tawh, stui, lipã, _anži,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75292a20,0x98a401c8,0x7c240118,0xad9b0098}},	//   mbez, _temą_, xpir, _giúi,
   {{0x6449001e,0x644600c5,0x43452a21,0x443d0bf7}},	//   mrei, škic, _рекв, _ivw_,
   {{0xed5a275d,0xd0072a22,0x64492a23,0xdee62a24}},	//   мов_, тере_, lrei, тови,
   {{0xd00f0332,0xb602008a,0x661c006c,0x752901ae}},	//   صلہ_, _þátt, _érke, nbez,
   {{0xff262a25,0x973c0254,0x64492a26,0xa3c507df}},	// [20c0] _импо, _hoće, nrei, _एषा_,
   {{0x64492a27,0x7c242a28,0x442f016e,0x660b0345}},	//   irei, rpir, _mwg_, _ligk,
   {{0x64492a29,0xf1c608d1,0x442f01e8,0x2d9e0248}},	//   hrei, _लगान, _lwg_, êtes_,
   {{0x6cc6081b,0x64492a2a,0xd00f0416,0xdb1c0079}},	//   _айма, krei, _دلی_, _imrí,
   {{0x442f0221,0x777a01d7,0xb8220033,0x00000000}},	//   _nwg_, _patx, _নিহত_, --,
   {{0xb17b013c,0xbcfb00e0,0x628112ba,0x00000000}},	//   llåt, _mbél, kvlo, --,
   {{0x1637004f,0x2b582a2b,0x660b08dd,0x442f0168}},	//   نسية_, _icrc_, _bigk, _awg_,
   {{0x64492a2c,0xd01a00c8,0x557401b8,0xe9a32a2d}},	//   frei, তীয়_, угит, _касп,
   {{0x64492a2e,0xa80600af,0xb8652a2f,0x660b053e}},	//   grei, _азал, _مالو, _digk,
   {{0x75c80355,0x00000000,0x00000000,0x00000000}},	//   tězs, --, --, --,
   {{0xd37700c7,0xf2040067,0x2611023a,0xf1f60067}},	//   тчы_, रगढ़_, _cšod_, ीगढ़_,
   {{0x64492a30,0x442f016e,0x973c0207,0x00000000}},	//   brei, _fwg_, _doće, --,
   {{0xe1ff0033,0xc05815d6,0x64492a31,0x6e22011c}},	//   rmó_, кір_, crei, _čoba,
   {{0x9f530955,0x261801a5,0x386916f6,0xe1ff02d7}},	//   _això_, _kéo_, çari_, smó_,
   {{0x4ea42a32,0x9f3401e0,0x2fcd0254,0x6e3c011e}},	//   арта, ресі, đeg_, gsrb,
   {{0x442f0189,0x261800e2,0x00000000,0x00000000}},	//   _ywg_, _méo_, --, --,
   {{0x69c30248,0x26182a33,0x9f4301f4,0x213901e9}},	// [20d0] ènem, _léo_, nojë_, mash_,
   {{0x8aa72a34,0x39db0066,0x2d9e000d,0x21392a35}},	//   кред, यक्ि, êter_, lash_,
   {{0x2618000d,0x00000000,0x00000000,0x00000000}},	//   _néo_, --, --, --,
   {{0xdd95247f,0x21390055,0x9f4301f4,0x00000000}},	//   _самы, nash_, kojë_, --,
   {{0x2486006d,0xf745167d,0xafdb01b4,0x9f430031}},	//   _nrom_, гело, gsøg, jojë_,
   {{0x442f01e8,0x26180019,0xdb07006c,0x64492a36}},	//   _rwg_, _béo_, _eljá, vrei,
   {{0xfc3f003e,0xcf940100,0xaa9412a2,0x2486011e}},	//   _hví_, יטס_, _кирч, _arom_,
   {{0x442f01e8,0x973c0009,0x248601bf,0x21390055}},	//   _pwg_, _roće, _brom_, jash_,
   {{0x75292a37,0x24862a38,0x213901e9,0x9f430031}},	//   rbez, _crom_, dash_, gojë_,
   {{0x64492a39,0x973c022f,0x75292a3a,0xe7b705f8}},	//   rrei, _poće, sbez, _अतिप,
   {{0x64492a3b,0x660b0430,0x248602a2,0x261800a2}},	//   srei, _tigk, _erom_, _géo_,
   {{0x248601f3,0x442f01a9,0x644600d8,0x628103c4}},	//   _from_, _twg_, škia, rvlo,
   {{0x3fc800bf,0x24862a3c,0xf53900a0,0x291f0283}},	//   ندسی_, _grom_, mať_, _mfua_,
   {{0xf53901ba,0x00000000,0x00000000,0x00000000}},	//   lať_, --, --, --,
   {{0xfc3f0176,0x1eaa00f3,0x261800cc,0x61ef0118}},	//   _aví_, راسي_, _xéo_, blcl,
   {{0x25ad2a3d,0xf53901ba,0x67380124,0x00000000}},	//   nkel_, nať_, zavj, --,
   {{0xb17b013c,0x5ed70033,0xed350144,0x80a500b5}},	// [20e0] rlåt, _ধরণে, рэсэ, _نمٹن,
   {{0xb34603e6,0x9f5e0086,0x25ad00ab,0xf53900a0}},	//   moçõ, ötä_, hkel_, hať_,
   {{0x25ad2a3e,0x3ea610ac,0x533602b5,0xa4f002e4}},	//   kkel_, _синг, רנען_, _चर्च_,
   {{0xf53900a0,0x3ea52a3f,0x1ad5012f,0x2ca90051}},	//   jať_, älte_, _दशरथ, byad_,
   {{0xe89417e0,0xf539124b,0x07a60ed2,0xc7c6150d}},	//   раль, dať_, ладн, лски,
   {{0xafdb0022,0x9f4301f4,0x61e62a40,0x21390055}},	//   rsøg, vojë_, hokl, zash_,
   {{0x6738108a,0xad9b1be9,0xa91d01f2,0x2486009e}},	//   ravj, _viúv, _anžu, _srom_,
   {{0x6d562a41,0xd49a1238,0x2d802a42,0x9f4301f4}},	//   ngya, еро_, ndie_, tojë_,
   {{0xa84a18dd,0x61e60029,0x2d8026d8,0x21392a43}},	//   _سلام_, dokl, idie_, vash_,
   {{0x9f4301f4,0x28d1007e,0x24860223,0x2618021d}},	//   rojë_, तपरि, _vrom_, _téo_,
   {{0x9f4301f4,0x213904a7,0xe81a0026,0xf53900a0}},	//   sojë_, tash_, _फंडा_, bať_,
   {{0x24862a44,0x25ad2a45,0x9f430055,0xd9f6021a}},	//   _trom_, ckel_, pojë_, ेषित_,
   {{0x21392a46,0x73c40d4f,0x5ff5002d,0x00000000}},	//   rash_, _پيغم, изму, --,
   {{0x2d8000d7,0x14d700a5,0x2a660035,0x21390031}},	//   edie_, _גודל_, łoby_, sash_,
   {{0x21392a47,0x00000000,0x00000000,0x00000000}},	//   pash_, --, --, --,
   {{0x6d56221a,0x61e61c26,0x21391505,0x7c292a48}},	//   ggya, cokl, qash_, _çerk,
   {{0xdfd5010b,0xeb4b039e,0x00000000,0x00000000}},	// [20f0] _вопы, ечек_, --, --,
   {{0x91fd0080,0xf539016f,0x2d80009e,0x00000000}},	//   stād, zať_, adie_, --,
   {{0x20d4064e,0x2ca920fb,0x9b68005f,0x25ad2a49}},	//   _نتیج, syad_, ышта_, ykel_,
   {{0xdb0e01ef,0x7aee0a8a,0x6e25009e,0x00000000}},	//   _ambó, _dybt, _ithb, --,
   {{0xf539124b,0xd5b100e2,0x3d3a00a5,0xa3c60825}},	//   vať_, _lúc_, _בגרס, ैचा_,
   {{0x2259004e,0x69ca1485,0x10380317,0xf62503b2}},	//   ński_, éfer, נטום_, адко,
   {{0x25ad007c,0xf539016f,0x39440a8a,0x00000000}},	//   tkel_, tať_, _fdms_, --,
   {{0xdb0e00ee,0x00000000,0x00000000,0x00000000}},	//   _embó, --, --, --,
   {{0x69cb2a4a,0x644600d8,0xf539016f,0x61e62a4b}},	//   mige, škin, rať_, vokl,
   {{0x69cb2a4c,0xf53901ba,0x25ad2a4d,0x386d1f26}},	//   lige, sať_, skel_, _iper_,
   {{0x27e72a4e,0xd6d10754,0x25b000b5,0xfbdd08b0}},	//   monn_, _بقا_, álló_, _मदनम,
   {{0x69cb2a4f,0x91e62a50,0x61e600c7,0x568a016b}},	//   nige, роме, uokl, _שטײַ,
   {{0x6e25004f,0x80c000b8,0x00000000,0x00000000}},	//   _athb, _लेखे, --, --,
   {{0x69cb2a51,0x753b2a52,0xdfd20037,0x61e6011e}},	//   hige, lauz, زيز_, sokl,
   {{0xa91d114d,0x443f2a53,0x63a3004a,0x09b500a1}},	//   _každ, lsu_, _ionn, ंसाठ,
   {{0x63a32a54,0x32da0122,0x27e7053f,0x1d261353}},	//   _honn, _שחקנ, honn_, рмам,
   {{0x63a32a55,0x2d801e4f,0x69cb0e45,0x27e72a56}},	// [2100] _konn, rdie_, dige, konn_,
   {{0x443f2a57,0x63a32a58,0x753b0200,0xeab20037}},	//   isu_, _jonn, hauz, يعا_,
   {{0x69cb2a59,0x973c0c0a,0x63a32a5a,0x386d03d0}},	//   fige, _noća, _monn, _aper_,
   {{0x443f2a5b,0x63a30037,0x88862a5c,0x69cb2a5d}},	//   ksu_, _lonn, илеж, gige,
   {{0x6eca0fcf,0x91fd00ea,0x443f1c90,0x76412a5e}},	//   _हेतु, ltāc, jsu_, _avly,
   {{0x63a32a5f,0x98a401c0,0x973c012e,0x443f02a7}},	//   _nonn, _země_, _boća, dsu_,
   {{0x69cb2a60,0xfaa60009,0x443f2a61,0x295601d3}},	//   bige, _таво, esu_, _възр,
   {{0xd3780a78,0x443f2a62,0x98a62a63,0x18a628fa}},	//   moći_, fsu_, _кибе, _кабм,
   {{0x2616006a,0x63a32a64,0xb0c50035,0xa91d11d7}},	//   _पूरी_, _bonn, _लेंग, _dažd,
   {{0x63a31762,0x79800232,0x27e70176,0x79822a65}},	//   _conn, _hamw, conn_, ldow,
   {{0x6d46114d,0x798018a6,0x63a30dd5,0xd5af17df}},	//   _odka, _kamw, _donn, _дс_,
   {{0x7c2601cc,0x31c72a66,0x753b137d,0x79800069}},	//   _otkr, рсов, cauz, _jamw,
   {{0x63a3026e,0xcfa72a67,0x79800090,0x846302fb}},	//   _fonn, ашви, _mamw, _дъще,
   {{0x63a32a68,0x44262a69,0x69cb2a6a,0x64422a6b}},	//   _gonn, _ito_, zige, _ivoi,
   {{0xc3fb0122,0x644017ad,0x7c262791,0x69cb01d5}},	//   _שלוש, lsmi, _atkr, yige,
   {{0x44262a6c,0xa91d28d2,0x42550332,0x63a32a6d}},	//   _kto_, _kaže, _انٹر, _zonn,
   {{0x61ed2a6e,0x63a30273,0x69cb2a6f,0xdb1e0421}},	// [2110] _ikal, _yonn, vige, kipä,
   {{0xa91d00d8,0x69d80248,0x69cb2a70,0x44262a71}},	//   _maže, éven, wige, _mto_,
   {{0x69cb2a72,0x79800a74,0x386d002d,0xa91d2676}},	//   tige, _bamw, _sper_, _laže,
   {{0x44262a73,0x443f2a74,0x64402a75,0x27e70359}},	//   _oto_, ysu_, ksmi, wonn_,
   {{0x44262a76,0xfd960122,0x61ed0054,0xe6cb008a}},	//   _nto_, _הדרך_, _mkal, _íbúð,
   {{0x64402a77,0x628a00e9,0xdb1e00be,0x753b08c7}},	//   dsmi, _orfo, gipä, wauz,
   {{0x44262a78,0x3f8102c2,0x64422a79,0x69cb2a7a}},	//   _ato_, _mahu_, _avoi, pige,
   {{0x81bd0ae0,0x63a32a7b,0x27e702e9,0xe5792a7c}},	//   spēj, _sonn, sonn_, узи_,
   {{0x27e70c1f,0x64402a7d,0x63a32a7e,0x69c9002f}},	//   ponn_, gsmi, _ponn, _imee,
   {{0x443f2a7f,0x61ed2a80,0x44262a81,0xd7fb2a82}},	//   rsu_, _akal, _dto_, _руб_,
   {{0x443f2a83,0x4426197d,0x63a32a84,0x69db0009}},	//   ssu_, _eto_, _vonn, _kjue,
   {{0x63a3018e,0x443f2a85,0x64402a86,0x00000000}},	//   _wonn, psu_, bsmi, --,
   {{0x628a02bf,0x644f2a87,0x3f810ce8,0x973c0254}},	//   _erfo, ácid, _bahu_, _moćn,
   {{0x61ed2a88,0x63ba2a89,0x7fd60409,0x23262a8a}},	//   _ekal, chtn, сімі, _лоши_,
   {{0xa91d13a6,0xdfcf00ad,0x65b50187,0x3f810506}},	//   _zaže, ريف_, _záha, _dahu_,
   {{0x973c0254,0x3d2800f8,0x68fb2a8b,0x00000000}},	//   _noćn, شتری_, _ozud, --,
   {{0x6da32832,0x79800051,0x68fb0103,0x00000000}},	// [2120] чита, _ramw, _nzud, --,
   {{0x69c92a8c,0xa3ca0f3d,0x79800a28,0x22590067}},	//   _amee, रोप_, _samw, ńsku_,
   {{0x3cfc0302,0x8e86004f,0x79800260,0x0a4a00c3}},	//   लेजे_, _الجه, _pamw, узей_,
   {{0xe93a07f8,0x8d562263,0x64402a8d,0xe9da0f78}},	//   اسات_, _уточ, ysmi, ыке_,
   {{0xa3e70302,0x79820035,0x69db0453,0x3f812a8e}},	//   पवा_, rdow, _djue, _yahu_,
   {{0x2d821e41,0x79822a8f,0x79800848,0xa91d00fe}},	//   _hake_, sdow, _wamw, _raže,
   {{0x798228c3,0x2d822a90,0xa91d2a91,0x79802a92}},	//   pdow, _kake_, _dažb, _tamw,
   {{0x6440038d,0xb8ce0083,0xa91d00d8,0xfad70122}},	//   tsmi, _ওই_, _paže, _הולך_,
   {{0x2d820052,0x44260132,0x64402a93,0x00000000}},	//   _make_, _qto_, usmi, --,
   {{0x61ed2a94,0xd37a0dc8,0x2d8200a5,0xa91d01a0}},	//   _skal, учи_, _lake_, _važe,
   {{0x44262a95,0xc7b300a5,0x9f8d00b8,0xd2f817d0}},	//   _wto_, _צבע_, uží_, ренц_,
   {{0xdb1c00fb,0x64402a96,0x44262a97,0x673a008d}},	//   _umræ, psmi, _tto_, _hetj,
   {{0x44262a98,0x3f81012f,0xafdb0c71,0x673a0086}},	//   _uto_, _pahu_, drør, _ketj,
   {{0x8233006c,0x661a2a99,0x62340fa7,0x43942a9a}},	//   _کروا, _kutk, _деку, _факс,
   {{0x25a62a9b,0x673a0861,0x61ed0124,0x09cf0033}},	//   _kool_, _metj, _tkal, িকতা,
   {{0x673a2a9c,0x61ed2a9d,0x7bdc035f,0x2d820b48}},	//   _letj, _ukal, _ajru, _cake_,
   {{0x21f90076,0x3f810614,0x2d822a9e,0x661a2a9f}},	// [2130] lého_, _tahu_, _dake_, _lutk,
   {{0x673a0c7c,0x69c911cc,0x7e7e0176,0xc7b800e2}},	//   _netj, _smee, _fspp, _nlđ_,
   {{0x21f9086d,0xa91d00d5,0x2d822aa0,0xdddc00f4}},	//   ného_, _ražb, _fake_, svrš,
   {{0xd378039a,0x25a6018d,0x725b0070,0xad9b0079}},	//   moću_, _nool_, רכאפ, _dhúc,
   {{0x21f90187,0x973c044d,0x673a2aa1,0xdcfd021e}},	//   hého_, _voćn, _betj, _kasč,
   {{0x21f9114d,0x2d820657,0x661a2aa2,0x9f4300ac}},	//   kého_, _zake_, _butk, kojí_,
   {{0x2d8219c6,0x2013007a,0xd37800f4,0x56920dec}},	//   _yake_, _mixi_, noću_, дајт,
   {{0x69c92aa3,0x25a62aa4,0x94252aa5,0x14250f68}},	//   _umee, _cool_, омие, одим,
   {{0x7c2d2aa6,0xe3b91456,0x57d50370,0xd3780207}},	//   npar, иби_, _доаѓ, hoću_,
   {{0x673a0296,0xd37800cd,0x387f01ed,0x37f9002d}},	//   _getj, koću_, _isur_, _тезэ_,
   {{0x56942aa7,0x27e00037,0x25a60f00,0xd6db1c4d}},	//   _нафт, éine_, _fool_, _ста_,
   {{0x25a62aa8,0x20130310,0x69d9033b,0x673a0051}},	//   _gool_, _aixi_, nnwe, _zetj,
   {{0x09a70302,0x64a52aa9,0x201301ed,0xdbc600be}},	//   _खवैय, _фала, _bixi_, mööb,
   {{0x2d822aaa,0x7c2d2aab,0x44072aac,0x25a60051}},	//   _sake_, dpar, _учеб, _zool_,
   {{0x442d2aad,0x764302c2,0x7c2d02a2,0x51f700b5}},	//   lpe_, nsny, epar, _ڈسٹر,
   {{0x201b2aae,0x6000013c,0x764300d7,0x8d66010b}},	//   _fuqi_, döme, isny, ўвае,
   {{0x90c30086,0x442d0c1f,0xfaf80080,0x7c2d2aaf}},	// [2140] _объе, npe_, _šī_, gpar,
   {{0x442d2ab0,0xdb1c02df,0x7a0c01c2,0xe81d0084}},	//   ipe_, _områ, _işti, _पढ़ा_,
   {{0x6da6280a,0x2d820052,0x65b50237,0xada6021d}},	//   _дина, _take_, _náho, _данл,
   {{0xa96a0369,0x673a2129,0x2d82006f,0x3ce5073f}},	//   рида_, _setj, _uake_, _झुके_,
   {{0xa3ca009a,0x673a2ab1,0x661a2ab2,0x7c2d2ab3}},	//   रोड_, _petj, _sutk, cpar,
   {{0x25a600b9,0xe79303fa,0x661a00c3,0x69d90345}},	//   _sool_, дишњ, _putk, anwe,
   {{0xd5ba2ab4,0x442d0173,0x25a606ae,0x673a01f4}},	//   иси_, epe_, _pool_, _vetj,
   {{0x21f92ab5,0x746a1b0a,0x7a0c0160,0x00000000}},	//   vého_, аров_, _oşti, --,
   {{0x7643012f,0x7c290bf4,0x00000000,0x00000000}},	//   asny, _çert, --, --,
   {{0x661a2ab6,0x21f9053d,0xe737002d,0x25a60f00}},	//   _tutk, tého_, _меу_, _wool_,
   {{0x25a62ab7,0x442d2ab8,0x74140e3a,0x4bfb0070}},	//   _tool_, ape_, _کوتا, שליס,
   {{0x21f9024e,0x7c2d2ab9,0xd46a2aba,0x65b500fe}},	//   rého_, ypar, _виде_, _jáhl,
   {{0x38662abb,0x65b52abc,0x9f4e0187,0x55d90070}},	//   ntor_, _záho, šným_, _פֿענ,
   {{0xb4c81e79,0x38662abd,0x9f5a02d0,0xa91d00d8}},	//   ोपी_, itor_, _sipò_, _maža,
   {{0x0ef30033,0xa187010b,0xa91d00f4,0x2013021d}},	//   ছেনঃ_, _дыпл, _laža, _vixi_,
   {{0xd378004e,0x65b50314,0xdd981d29,0xf8bc07df}},	//   leć_, _náhl, ошу_, ्छाय,
   {{0xa91d03fd,0xf1bf004f,0x3a2a0dc3,0x386601f4}},	// [2150] _naža, mhá_, _atbp_, jtor_,
   {{0x7c2d0ffe,0x66021c26,0xfc300037,0x2b4a099e}},	//   rpar, _lhok, ضحك_, _cdbc_,
   {{0x7a400082,0x38662abe,0x395f01ef,0x442d01ed}},	//   _rátá, etor_, _pcus_, zpe_,
   {{0x1959010b,0xa3ca06bc,0x7e7a02b5,0x4e7a02b5}},	//   сады_, रोत_, _פארז, _פארצ,
   {{0xf1b40122,0x69d90110,0xd8b801b2,0x00000000}},	//   וסף_, rnwe, يدها_, --,
   {{0xec3600a5,0xa91d123c,0x6fbb0026,0x31a200d5}},	//   _מאשר_, _daža, उसिं, _dózy_,
   {{0xc9772abf,0x6602034d,0xd3780207,0x00000000}},	//   _وارث, _bhok, deć_, --,
   {{0x66022ac0,0x3179004e,0x65b50334,0xdb0701f4}},	//   _chok, jesz_, _váho, _lojë,
   {{0x442d2ac1,0x38662ac2,0x660201cb,0x317900b5}},	//   upe_, ctor_, _dhok, desz_,
   {{0x65692ac3,0x75d3002d,0x7643010b,0x00000000}},	//   sfeh, văzu, psny, --,
   {{0x656902c9,0x65152ac4,0xdb0e008c,0x00000000}},	//   pfeh, _فوائ, _elbæ, --,
   {{0x442d2ac5,0x91fd0228,0x216a0eb1,0x00000000}},	//   ppe_, stān, щими_, --,
   {{0x66092ac6,0xbcfb00e0,0x43952ac7,0x00000000}},	//   mmek, _mbés, _надс, --,
   {{0x66092ac8,0x25bf0159,0x35d10066,0x1c1f00ab}},	//   lmek, lhul_, _तगड़, _बढ़ल_,
   {{0xa3b80833,0xbcfb000d,0x00000000,0x00000000}},	//   _ظاهر_, _obés, --, --,
   {{0xf1bf024e,0x3179004e,0x9c26075c,0x66092ac9}},	//   chá_, cesz_, здад, nmek,
   {{0x3a2a028b,0x90460037,0x1d072aca,0x6609064a}},	// [2160] _stbp_, _عنده, зети_, imek,
   {{0x0e662acb,0xa91d2acc,0xdb070031,0x66090f5e}},	//   _екон, _raža, _gojë, hmek,
   {{0x66092acd,0xa91d011c,0x00000000,0x00000000}},	//   kmek, _saža, --, --,
   {{0x38662ace,0x58861397,0x9f4a0187,0x7e9b00a5}},	//   ttor_, зыка, dobé_, _הסטו,
   {{0xd90d0609,0xc18d0070,0x660900be,0xbf5900e2}},	//   لیف_, יטאָ, dmek, _điếc_,
   {{0x38662acf,0x66022ad0,0xa91d0254,0xaa462ad1}},	//   rtor_, _shok, _važa, _негл,
   {{0x7bce2ad2,0xd378012e,0xad9b0079,0x660203d0}},	//   _imbu, već_, _mhún, _phok,
   {{0x9adb0122,0xbcfb0d2e,0x2ca02ad3,0x38662ad4}},	//   _החלט, _ibér, oxid_, ptor_,
   {{0x6d4b0037,0xa91d0254,0x00000000,0x00000000}},	//   ógai, _kažn, --, --,
   {{0xad9b0019,0x644f2ad5,0x00000000,0x00000000}},	//   _nhún, ácia, --, --,
   {{0x66020088,0xd3780124,0xdcfd0228,0x25bf009e}},	//   _thok, reć_, _masā, bhul_,
   {{0x80ab00c8,0xa91d15d7,0x7bce0042,0xf1bf0355}},	//   _চেষ্, _lažn, _lmbu, uhá_,
   {{0xbcfb2ad6,0x26090e04,0x44200043,0xf1bf00d5}},	//   _océa, ागरी_, _îi_, rhá_,
   {{0xad9b00e8,0x03a3145f,0xefc82ad7,0x00000000}},	//   _chún, _пичо, пуск_, --,
   {{0xad9b0079,0x33fb0277,0x00000000,0x00000000}},	//   _dhún, _ההגנ, --, --,
   {{0x22f70122,0x7bce2ad8,0xdda8002d,0x00000000}},	//   _מזון_, _ambu, птул_, --,
   {{0xa91d010b,0x6285008d,0xdcfd013a,0x00000000}},	// [2170] _bažn, _áhor, _basā, --,
   {{0x09b5112b,0xbcfb0312,0x00000000,0x00000000}},	//   ंस्य, _ccéa, --, --,
   {{0xa91d01c8,0xfe242ad9,0x00000000,0x00000000}},	//   _dažn, _пьян, --, --,
   {{0x7bce2ada,0x6aaa022a,0x00000000,0x00000000}},	//   _embu, äffa, --, --,
   {{0x2d992adb,0x76480055,0x00000000,0x00000000}},	//   _inse_, _avdy, --, --,
   {{0xbcfb004f,0xab8401af,0x65620176,0xbcb600a5}},	//   _gcéa, _пуск, _acoh, _חפשו_,
   {{0x66092adc,0x00000000,0x00000000,0x00000000}},	//   tmek, --, --, --,
   {{0x2d892add,0x6d5f046a,0x75fe01f4,0x9f4a2ade}},	//   ndae_, ngqa, tëza, robé_,
   {{0x66092adf,0x91fd0080,0x61ef2ae0,0x44390815}},	//   rmek, rtāl, docl, ès_,
   {{0x63aa001e,0xe3b10037,0xe79501df,0x00000000}},	//   _cofn, ئرة_, _تارک, --,
   {{0x91e62ae1,0x2d99053e,0xafdb008c,0x2d890345}},	//   доне, _onse_, rsøl, kdae_,
   {{0xa91d2ae2,0x44b51cae,0x61ef2ae3,0x00000000}},	//   _mažo, _обес, gocl, --,
   {{0xa3ca0d00,0xa91d012e,0x2d890b88,0x00000000}},	//   रोह_, _lažo, ddae_, --,
   {{0x6b872524,0x2d890298,0x63aa00e9,0x3fcc0033}},	//   _najg, edae_, _gofn, লক্ষ,
   {{0xa91d022f,0x248d2ae4,0x394d0124,0x61ef2ae5}},	//   _ražn, lvem_, _odes_, bocl,
   {{0x5bb6052f,0xbcfb004f,0x26160035,0x394d00e0}},	//   ःस्व, _scéa, _पंछी_, _ndes_,
   {{0xdcfd0080,0xa91d0a78,0x6446011c,0x3fe6174b}},	// [2180] _pasā, _pažn, škiv, _ожив,
   {{0x394d2ae6,0x2d992ae7,0x973c0506,0x657b021d}},	//   _ades_, _ense_, _voćk, heuh,
   {{0xa91d01cc,0x00000000,0x00000000,0x00000000}},	//   _važn, --, --, --,
   {{0xe8fa2ae8,0xa91d1eef,0x00000000,0x00000000}},	//   оле_, _dažo, --, --,
   {{0x6d442ae9,0xdb1c0a8a,0x394d2aea,0x00000000}},	//   maia, _omrø, _ddes_, --,
   {{0x62832648,0x6d442ae9,0xc5f8083f,0x394d0086}},	//   _osno, laia, ुष्य_, _edes_,
   {{0xd90d0332,0x5a5501d3,0xba232aeb,0x00000000}},	//   لیہ_, _пъту, _адск, --,
   {{0x1dde0035,0x77b412c3,0x6d442aec,0x394d021e}},	//   नचित, _màxi, naia, _gdes_,
   {{0x186a0819,0x69c20051,0x00000000,0x00000000}},	//   _фази_, mhoe, --, --,
   {{0x6d4401d7,0xa91d012e,0x69c21060,0x926a0f88}},	//   haia, _lažl, lhoe, орма_,
   {{0x6d440f1a,0x973c00cb,0x452a00af,0xc7d7011d}},	//   kaia, _noći, _джен_, _קובי_,
   {{0x85061b15,0x2251033a,0x69c22aed,0xad9b0037}},	//   _قوان, ázka_, nhoe, _chúl,
   {{0x6d442aee,0xbcfb01ef,0x22590067,0x3c24013b}},	//   daia, _acén, ąska_, _növ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x05b20026,0xafdb01e0,0x6d440952,0x6b872aef}},	//   _जवाब, lsøk, faia, _rajg,
   {{0xa91d0080,0x6d442af0,0xe3b80225,0x00000000}},	//   _ražo, gaia, lkı_, --,
   {{0xafdb0a8a,0x2d8903bc,0x261600ab,0x75fe0055}},	// [2190] nsøk, rdae_, _पूछी_, hëzo,
   {{0x2d89053e,0xe3b805f9,0x09d70099,0x3c242af1}},	//   sdae_, nkı_, ढच्य, _döv_,
   {{0x6d442af2,0x657b022e,0x248d00b8,0x160e22c7}},	//   baia, yeuh, zvem_, ागार_,
   {{0xd5a627f6,0x27e00098,0x2d990160,0x69c22af3}},	//   _صف_, éinn_, _unse_, ghoe,
   {{0xe7eb009a,0x6b872af4,0x6d4f0176,0xe3b801d6}},	//   टवला_, _tajg, _idca, kkı_,
   {{0xd7c80413,0x65bc000d,0xa91d00d5,0x9665081b}},	//   وونه_, _réha, _zažl, екке,
   {{0x65bc00e0,0x00000000,0x00000000,0x00000000}},	//   _séha, --, --, --,
   {{0x69c22af5,0x91fd0029,0xff1800a5,0x65b500ac}},	//   choe, stāj, וקות_, _káhi,
   {{0xa9240187,0x799b2af6,0x6000013c,0xd7fb0200}},	//   _úžas, _inuw, dömn, _дуж_,
   {{0xf7701144,0xa3ca2af7,0x6560004f,0xb6050187}},	//   _نام_, रोल_, agmh, dnáš,
   {{0xeb9200c2,0xe2992af8,0x79890118,0x00000000}},	//   אָר_, чан_, _kaew, --,
   {{0xdb07008a,0x7d1d2af9,0x56b60070,0xcb12011d}},	//   _hljó, _ngss, _אפען_, טלי_,
   {{0xbcfb2afa,0x6d440183,0x79890118,0xb143010b}},	//   _scén, vaia, _maew, ынял,
   {{0x6d441051,0x443d012f,0x75292afb,0x7d1d0176}},	//   waia, _iww_, lcez, _agss,
   {{0xdee32afc,0x64492afd,0x670f2afe,0xa91d0254}},	//   гори, lsei, ाधिक_, _pažl,
   {{0x973c0207,0xdca62aff,0x00000000,0x00000000}},	//   _voći, наби, --, --,
   {{0x64492b00,0x6d440cd3,0x443d00d7,0x6b56004f}},	// [21a0] nsei, raia, _jww_, فضائ,
   {{0x7c2b2b01,0x6d442b02,0x64492b03,0x799b08c7}},	//   ígra, saia, isei, _anuw,
   {{0x6d4402c2,0x443d2b04,0xc0a900bf,0x69c2001e}},	//   paia, _lww_, _فایل_, thoe,
   {{0xdca60610,0x68462b05,0x3940004f,0x201a2b06}},	//   _зами, енда, úis_, _hipi_,
   {{0x69c22b07,0x79892b08,0xad1b00a5,0x201a023c}},	//   rhoe, _daew, _מוכר, _kipi_,
   {{0x64492b03,0x69c22b09,0xc7a31a1c,0x61e40254}},	//   dsei, shoe, личк, _ljil,
   {{0x201a012f,0x644b014e,0x69c203bc,0xa91d00cd}},	//   _mipi_, _avgi, phoe, _zažm,
   {{0x38cb064e,0x9f4a033a,0x75fe00da,0xa91d008b}},	//   _کافی_, dobí_, rëzo, _lažj,
   {{0x69c02b0a,0xdb07008a,0x394600f8,0x91fd0029}},	//   _ilme, _fljó, maos_, stāk,
   {{0xa3ca0755,0x61e40657,0xe1fb0ebd,0x61f60409}},	//   रों_, _ajil, ृष्ण_, _akyl,
   {{0xe3b8008f,0x443d010d,0x9696004b,0x26c70035}},	//   rkı_, _eww_, _яраш, czno_,
   {{0x39460159,0x644902c9,0x442f2b0b,0x26891328}},	//   naos_, bsei, _ftg_, _زخمي_,
   {{0x442f0159,0x443d0051,0xe3b80225,0x00000000}},	//   _gtg_, _gww_, pkı_, --,
   {{0x6d4f0024,0xdecb0043,0x69c003d0,0x41d20253}},	//   _sdca, публ_, _llme, दोबस,
   {{0xdb1e0042,0x3946198d,0x65bc00f6,0x3a2d0207}},	//   hipó, kaos_, _jého, _čepo_,
   {{0x61e40031,0x7a4706fe,0x00000000,0x00000000}},	//   _gjil, _létá, --, --,
   {{0x6ad90066,0x39462b0c,0xa01b0ef0,0x00000000}},	// [21b0] भप्र, daos_, rvös, --,
   {{0x69c02b0d,0xe8000e04,0x61fd2b0e,0xdb15002a}},	//   _alme, _लीला_, llsl, _alzá,
   {{0x32090023,0x2904002f,0xb7b500e2,0x2a780027}},	//   _khay_, _azma_, _lịc, _cprb_,
   {{0x28d200be,0x24860009,0x201a08c7,0x394601ef}},	//   _देहि, _osom_, _zipi_, gaos_,
   {{0x69c0009e,0x201a0176,0x50b30e61,0x00000000}},	//   _dlme, _yipi_, ुनिष, --,
   {{0x2d8b00c8,0x9a872b0f,0x69c02b10,0x79890118}},	//   _hace_, _публ, _elme, _waew,
   {{0x644b00d7,0x3946002a,0x973c0207,0xdb070184}},	//   _svgi, baos_, _noću, _kojí,
   {{0x64492b11,0x2d8b2b12,0x28d2252b,0x644f00cd}},	//   tsei, _jace_, _देवि, šcim,
   {{0x752907e5,0x2d8b0ca0,0x291f0176,0xa8150036}},	//   rcez, _mace_, _igua_, _адаш,
   {{0x61f62b13,0x64492b14,0x7bc500e2,0xb7b500e2}},	//   _skyl, rsei, nhhu, _dịc,
   {{0x13090086,0xa2e508d9,0x32090159,0x9f8f02b1}},	//   ьной_, тонд, _bhay_, _süß_,
   {{0x2d8b2b15,0x201a067f,0x32092b16,0x442f2b17}},	//   _nace_, _sipi_, _chay_, _ttg_,
   {{0x9f4a024e,0x64460009,0x442f2b18,0x7bd701ed}},	//   sobí_, škir, _utg_, kixu,
   {{0x61fd0051,0x2b4308b7,0x00000000,0x00000000}},	//   alsl, _nejc_, --, --,
   {{0x201a2b19,0x2d8b0027,0xdb0715d8,0x61e42b1a}},	//   _vipi_, _bace_, _bojí, _tjil,
   {{0xc6920319,0xd9bd1e82,0xdb0702d7,0x291f00e2}},	//   סאן_, ्फोट, _cojí, _ngua_,
   {{0x201a2b1b,0x2d8b0228,0xab6628cc,0x7bd72b1c}},	// [21c0] _tipi_, _dace_, квал, fixu,
   {{0x291f0083,0xa2c51cce,0x6d4b008d,0xdb1500ac}},	//   _agua_, ानप्, ógar, _slzá,
   {{0x68fb00c8,0xcf570052,0x0f5700c2,0x2d8b2b1d}},	//   _ayud, _בבית_, _ביים_, _face_,
   {{0x68fb0b3e,0x2d8b01d5,0x7a4700fd,0x29d500ac}},	//   _byud, _gace_, _sétá, sťan_,
   {{0x28d200b4,0x39462b1e,0x2d80002d,0x00000000}},	//   _देशि, raos_, meie_, --,
   {{0x291f01ef,0x2d8b2b1f,0x00000000,0x00000000}},	//   _egua_, _zace_, --, --,
   {{0xfaa32b20,0x69262b21,0x2d8b02d7,0x68e90138}},	//   _каро, _амба, _yace_, _exed,
   {{0xa2c52b22,0x5e5702b5,0x24862b23,0x69c00f5e}},	//   ानन्, דיקע_, _psom_, _ulme,
   {{0x68fb011e,0xe8f70009,0x7afc0282,0x39440409}},	//   _gyud, _алт_, _hyrt, _iems_,
   {{0x32090159,0x3944093a,0x2d802b24,0x00000000}},	//   _shay_, _hems_, heie_, --,
   {{0x59b604bc,0xe3af0bdf,0x2d800173,0xd7ef004f}},	//   _अकार, تري_, keie_, _بكل_,
   {{0xb6d902b5,0x2486006f,0xa5da0ae7,0x00000000}},	//   _אַנט, _tsom_, _غبار_, --,
   {{0x2d8b2b25,0x00000000,0x00000000,0x00000000}},	//   _race_, --, --, --,
   {{0x040d00e2,0x39442b26,0x00000000,0x00000000}},	//   _mườn, _lems_, --, --,
   {{0x2d8b2b27,0x32090028,0x39442b28,0xdb0e01f4}},	//   _pace_, _thay_, _oems_, _dobë,
   {{0x60b500b5,0x32090159,0x21200118,0x00000000}},	//   _ممبئ, _uhay_, _ggih_, --,
   {{0x1df80328,0x7afc0183,0x7bd701ef,0x28d2018d}},	// [21d0] теты_, _ayrt, tixu, _देलि,
   {{0xe1ff2b29,0x1ae700c8,0x09bd11b5,0xad9b0037}},	//   lló_, _করবে_, ्फ्य, _mhúi,
   {{0x68fb2b2a,0x2d8b2b2b,0xc9590037,0x65b500ac}},	//   _syud, _tace_, فلاش_, _záhu,
   {{0xe1ff006c,0xa91d2b2c,0x68fb08dd,0x7afc0d51}},	//   nló_, _kaži, _pyud, _dyrt,
   {{0x3da401c8,0x040d01a5,0x7c220037,0xdb0e0107}},	//   _трэб, _cườn, íort, _lobè,
   {{0xa91d00d8,0x040d0019,0x66e50409,0x69d800f6}},	//   _maži, _dườn, лола, éver,
   {{0xf7702b2d,0x39442b2e,0x25af0009,0xa91d18cc}},	//   تان_, _fems_, _pogl_, _laži,
   {{0x7f450024,0xad9b026e,0x39442b2f,0x291f034d}},	//   _lehq, _bhúi, _gems_, _ugua_,
   {{0x7afc00da,0xad9b004f,0x9868006c,0x588400d8}},	//   _zyrt, _chúi, _لینے_, _выха,
   {{0xa91d2b30,0x69d92b31,0xd774042c,0xad9b0079}},	//   _naži, liwe, _نامع, _dhúi,
   {{0x216a2b32,0x61462b33,0xd5752b34,0xdb0e0031}},	//   нини_, лена, _буль, _robë,
   {{0x69d92b35,0x6000013c,0xcf8900a5,0x9f4a0097}},	//   niwe, römm, _מט_, dobá_,
   {{0x753b2b36,0xa91d00ac,0xd24e0220,0x00000000}},	//   mbuz, _baži, ينی_, --,
   {{0x645b2b37,0x69d90088,0xe1ff02d7,0x00000000}},	//   mrui, hiwe, aló_, --,
   {{0xd36e1c64,0x3ebe008a,0x69d92b38,0xe1ff2b39}},	//   _رهي_, átt_, kiwe, bló_,
   {{0x3f8c00ac,0x1c1c04bc,0x69d90054,0x753b0051}},	//   ždu_, _भूजल_, jiwe, nbuz,
   {{0x39442b3a,0x2d802b3b,0x645b2b3c,0xd00f00b5}},	// [21e0] _rems_, reie_, nrui, زلہ_,
   {{0x3ea61964,0x7c3600d7,0x39442b3d,0x00000000}},	//   _биог, rpyr, _sems_, --,
   {{0x645b0037,0x29022b3e,0x7c362b3f,0x7bcb0055}},	//   hrui, _ška_, spyr, ëgua,
   {{0xa91d14a6,0x91fd0029,0x645b11ad,0x08c6002d}},	//   _zaži, stāv, krui, лбен,
   {{0x6d4600ea,0xd7fa02c4,0x00000000,0x00000000}},	//   _ieka, нук_, --, --,
   {{0x91fd0080,0x6d462b40,0x645b2b41,0xa63400d4}},	//   ltāt, _heka, drui, анкі,
   {{0x6d461cad,0xf1c1024e,0xad9b0079,0x645b0223}},	//   _keka, ášky_, _shúi, erui,
   {{0x54542b42,0x645b2b43,0x040d01a5,0x6d462b44}},	//   авит, frui, _tườn, _jeka,
   {{0xa2d909a8,0x6b8e10a2,0x645b0d35,0x79822b45}},	//   _फेब्, _kabg, grui, meow,
   {{0x1ae70b52,0x6d460fe2,0x42740beb,0x7c262b46}},	//   _করতে_, _leka, агос, _mukr,
   {{0xd37700c7,0xb34503e6,0x75fe0031,0x28130118}},	//   учы_, _seçã, hëzi, _اولس,
   {{0x6d462b47,0x645b137b,0xd2572b48,0xf1a702c4}},	//   _neka, brui, ыць_, урон,
   {{0x645b2b49,0x6e25012f,0xa91d00d8,0xf8c404bc}},	//   crui, _suhb, _paži, वनिय,
   {{0xa3e80939,0x53342b4a,0x92942b4b,0x69d92b4c}},	//   _यदि_, _тект, _вакц, ziwe,
   {{0xdd9b0f2a,0x44260657,0xa91d2b4d,0x7c262b4e}},	//   нша_, _huo_, _važi, _aukr,
   {{0x6d462b4f,0x442600d8,0x628a2b50,0x7c262b51}},	//   _ceka, _kuo_, _isfo, _bukr,
   {{0xa3e800b4,0x6298025c,0x79820118,0x41c40c26}},	// [21f0] _यदा_, _hrvo, deow, _دقيق,
   {{0xf1bf00b8,0x7c26010b,0x69d800a2,0x00000000}},	//   lká_, _dukr, èven, --,
   {{0x3f8302c4,0x44262b52,0x69d92b53,0x00000000}},	//   meju_, _luo_, tiwe, --,
   {{0x195900c7,0x8937004f,0x6d462b54,0x75220054}},	//   тады_, اعضا, _geka, _ngoz,
   {{0x44260a93,0x69d92b55,0x98a52b56,0x3158016b}},	//   _nuo_, riwe, риле, רידן_,
   {{0x65b50076,0xd2461168,0x6298006c,0x7bd501ae}},	//   _náhr, _ون_, _orvo, _umzu,
   {{0x6d462b57,0xf40a0033,0x00000000,0x00000000}},	//   _yeka, রদার_, --, --,
   {{0x44260dc3,0x64420103,0xf77301df,0x7c260103}},	//   _buo_, _bwoi, _گار_, _yukr,
   {{0x629803ad,0x05a60086,0x44262b58,0x58d50012}},	//   _arvo, рвый_, _cuo_, _тоат,
   {{0xf7731d05,0xe2990202,0x645b2b59,0x67210254}},	//   _دار_, вао_, rrui, _uglj,
   {{0x645b2407,0x59b90d2a,0x3f832b5a,0x629800f4}},	//   srui, _आवार, deju_, _crvo,
   {{0x645b1e7e,0x6298011c,0x947900af,0x628a008c}},	//   prui, _drvo, _аску_, _dsfo,
   {{0x03a52b5b,0x628a2b5c,0x62980120,0x04450382}},	//   _вило, _esfo, _ervo, _телн,
   {{0x6d461221,0x91fd0029,0xbcfb0079,0x88ba0070}},	//   _seka, tuāc, _gcéi, דזשי,
   {{0x6d462b5d,0x4426012f,0x7c262b5e,0x00000000}},	//   _peka, _zuo_, _sukr, --,
   {{0xf1bf114d,0x65b5016f,0x67170518,0x25ad2b5f}},	//   cká_, _záhr, धेयक_, njel_,
   {{0x0b462b60,0xd7c500a1,0x6d462b61,0xa91d0207}},	// [2200] инан, वसाच, _veka, _kažu,
   {{0x75fe00da,0x91fd0029,0x6d462b62,0xdb0e0139}},	//   rëzi, grāf, _weka, _dobî,
   {{0x6d462b63,0xa91d2b64,0xa9262b65,0x25bf2b66}},	//   _teka, _mažu, адел, kkul_,
   {{0x25ad2b67,0xd37800cd,0x6d46095f,0x25bf0207}},	//   jjel_, miće_, _ueka, jkul_,
   {{0xd378124d,0xe8940de9,0x83fd00b5,0xa96702fb}},	//   liće_, саль, ntős, рича_,
   {{0x91fd0ae0,0xd90d0a86,0x75220036,0xf1bf0355}},	//   ntār, ریل_, _sgoz, zká_,
   {{0x44260133,0x4b7b02da,0x6442006a,0xd3780129}},	//   _suo_, _שאלו, _swoi, niće_,
   {{0x2d92142f,0xbcfb004f,0x442602fb,0xa3d30722}},	//   ndye_, _scéi, _puo_, सोस_,
   {{0xa4d400d8,0x98bd0067,0xa91d00f4,0x91fd0228}},	//   сопі, tawą_, _sažv, ktār,
   {{0x62980912,0xa5070274,0xd3780207,0x61e60345}},	//   _prvo, шења_, kiće_, enkl,
   {{0xe7e3009a,0x3f8300d8,0xf1bf0bca,0x25ad02c4}},	//   कचरा_, veju_, tká_, bjel_,
   {{0x44262b68,0x28db0fbf,0x64420035,0xd378011c}},	//   _tuo_, _मेडि, _twoi, diće_,
   {{0xe3af2292,0xdb0e01d6,0x75d3004f,0xf1bf00ac}},	//   سری_, _albü, _بينا, rká_,
   {{0xf1bf0076,0xd3780124,0x245700af,0x33f315dc}},	//   ská_, fiće_, _ташь_, _وسوس,
   {{0x3f832b69,0x3dc92b6a,0x245200b5,0x00000000}},	//   reju_, thaw_, _انڈس, --,
   {{0x3dc9010d,0x3f832b6b,0xa91d07e7,0x82330911}},	//   uhaw_, seju_, _zažu, _بروا,
   {{0x91fd0029,0x3f832b6c,0x26e22b6d,0x3b552b6e}},	// [2210] stās, peju_, गपुर_, йкар,
   {{0x3dc9006f,0x60c02b6f,0xd37800cd,0x00000000}},	//   shaw_, ømme, biće_, --,
   {{0x6e950082,0x200310ec,0xad9b2b70,0x00000000}},	//   _الجا, mlji_, _bhút, --,
   {{0x6286004e,0xdb0e0138,0x999800af,0xad9b0312}},	//   łkow, _albó, икхт_, _chút,
   {{0x9f5101c0,0x18210cea,0xb4e50067,0x22590067}},	//   hozí_, मदेव_, _नशे_, ąski_,
   {{0x26e200a1,0xdb1c009e,0x68190260,0x9f4a0176}},	//   गपूर_, _flrà, _kňdi, llbò_,
   {{0x7c2d013b,0x7bc72b71,0x25bf0523,0x75fe0031}},	//   lqar, _ilju, tkul_, hëzu,
   {{0x59f903ad,0x3940008a,0xa2c5112b,0x6b8500d7}},	//   _себя_, ðist_, ानस्, lehg,
   {{0x7bc702dd,0x38600014,0x26c1016f,0x7c2d2b72}},	//   _klju, àirt_, šho_, nqar,
   {{0xd6db1917,0x68e40037,0x25bf022e,0x00000000}},	//   _ите_, úide, skul_, --,
   {{0x57fa016b,0x200300f4,0x00000000,0x00000000}},	//   _עלעו, dlji_, --, --,
   {{0xd3780b16,0xad9b0079,0x930d0225,0x00000000}},	//   viće_, _mhús, _ışık, --,
   {{0x7bc70282,0x34ab004f,0x61e62b73,0xe3ae0384}},	//   _olju, _جداً_, rnkl, _еб_,
   {{0x65691b4a,0xd378011c,0x6d4b0093,0x9f580031}},	//   lgeh, tiće_, ðgan, morë_,
   {{0xed5a0f94,0xada620b6,0x6da60665,0x75fe01f4}},	//   лов_, бавл, бива, rëzv,
   {{0xd3780280,0x65692b74,0xb146002d,0xdb1200a2}},	//   riće_, ngeh, _унил, _égér,
   {{0x7bc700cb,0x200305e2,0x9f5801f4,0x69d800f7}},	// [2220] _blju, blji_, norë_, èvem,
   {{0x65bc02e1,0x7f86004f,0xbb4a00f8,0xd378012e}},	//   _véhi, _الدن, الان_, piće_,
   {{0x16170084,0x387f01d7,0xdb0e021e,0x262700f4}},	//   दगार_, _apur_, _albò, _uđoh_,
   {{0x27e90037,0xdb1c01ff,0xdce400f4,0x7bc700b5}},	//   éann_, _omrö, lgič, _elju,
   {{0x28d221b2,0xfbd100b5,0xb4d6046c,0x28db1140}},	//   _देखि, ستے_, _सधे_, _मेदि,
   {{0xab270011,0x207b025a,0x00000000,0x00000000}},	//   _гора_, ראסא, --, --,
   {{0x7bde2b75,0x65692b76,0x8f9b00a5,0x2a35010b}},	//   mipu, fgeh, טיסי, _мэтр,
   {{0x7bde10cd,0x69cb2b77,0x65692b78,0x7434002d}},	//   lipu, chge, ggeh, ониф,
   {{0xc34a2b79,0x41cc06fe,0x387f009e,0xdb0e0183}},	//   ляне_, ासनस, _gpur_, _mobí,
   {{0x7bde01ca,0x32540c9f,0x2bfa021a,0xdcef00ea}},	//   nipu, овор, ्तिं_, _sacī,
   {{0x200304c3,0xd5af2b7a,0xc2050067,0xa2a80099}},	//   vlji_, _ес_, रतलब_, टमध्,
   {{0x645d0f56,0x7bde00d1,0x6fcb027d,0x69c22b7b}},	//   ásic, hipu, _müce, nkoe,
   {{0x7bde00bf,0x2bfa0096,0x20030478,0x644f0138}},	//   kipu, ्तां_, tlji_, ácit,
   {{0x75fe0031,0x02a61b96,0x7bde023c,0xe29a00e2}},	//   rëzu, _грим, jipu, _trư_,
   {{0x7bde2b7c,0x63770122,0x91fd0029,0xe3af2b7d}},	//   dipu, _הגוף_, trād, _سرو_,
   {{0x1ae70083,0x7c2d2b7e,0x7bc707e7,0x7bde0345}},	//   _করলে_, tqar, _slju, eipu,
   {{0x7bc72209,0x61ed02c4,0x20030121,0x22ae0095}},	// [2230] _plju, _ijal, plji_, dəki_,
   {{0xad9b004f,0x7c2d1952,0x61ed2b7f,0x7bde09e7}},	//   _chúr, rqar, _hjal, gipu,
   {{0x387f2b80,0x61ed008d,0x7c2d0c6f,0xbcfb2b81}},	//   _spur_, _kjal, sqar, _acét,
   {{0x39492b82,0xdb0e0160,0x7bde0298,0x69c21472}},	//   úas_, _bobâ, aipu, gkoe,
   {{0x7c2d01ef,0x27e92b83,0x61ed2b84,0xdd9800af}},	//   qqar, éano_, _mjal, _ушэ_,
   {{0x61ed023a,0xad9b0312,0x7bc72b85,0x98481ac5}},	//   _ljal, _thús, _ulju, сяца_,
   {{0x61ed2b86,0x3ffc0070,0x65692b87,0xa01b033b}},	//   _ojal, אפגע, tgeh, rwöh,
   {{0xe4592070,0x61ed2b88,0x9f5801f4,0x8beb0083}},	//   ажи_, _njal, torë_, _কঠিন_,
   {{0x65692b89,0x69c901ed,0xb3c9002d,0x00000000}},	//   rgeh, _ilee, илиз_, --,
   {{0x61ed2b8a,0xa3d30953,0x394f008a,0xd7fb2b8b}},	//   _ajal, सों_, lags_, _суб_,
   {{0xf7701144,0x69c92601,0x61ed2b8c,0x9f580031}},	//   _سال_, _klee, _bjal, sorë_,
   {{0x059613cf,0x216a08a6,0x9f58014c,0x386000cd}},	//   _وانگ, шими_, moré_, šire_,
   {{0x61ed2b8d,0xdb0e00a0,0x9f58000d,0x3f930065}},	//   _djal, _robí, loré_, _baxu_,
   {{0xee3a2b8e,0xd9b609f9,0x61ed0861,0x69c22b8f}},	//   инг_, _अक्ट, _ejal, zkoe,
   {{0x61ed2b90,0x80db00c8,0xdce404c3,0x9f5800a2}},	//   _fjal, _যুদ্, rgič, noré_,
   {{0x61ed2b91,0x2251024e,0x80662b92,0x6da32b93}},	//   _gjal, ázku_, _движ, миса,
   {{0x7bde2b94,0xd3780254,0x394f2b95,0x3f9300d5}},	// [2240] tipu, lića_, dags_, _faxu_,
   {{0x69db2b96,0x69c92b97,0x81ac0033,0x00000000}},	//   _amue, _alee, _গতি_, --,
   {{0x7bde2b98,0xd3780254,0x8eb3006c,0xdb1502d0}},	//   ripu, nića_, _ہمیش, _jozè,
   {{0x7bde2b99,0x7ae30037,0x09060043,0xdca61052}},	//   sipu, únta, опен, _дами,
   {{0x69c22b9a,0x91fd00ea,0xdb15000d,0xd3780207}},	//   rkoe, duāl, _lozè, hića_,
   {{0x69c22b9b,0xa09b0317,0xd378011c,0x56940009}},	//   skoe, יינט, kića_, закт,
   {{0x394f2b9c,0xeb9100c2,0x3a2a011e,0xd378011c}},	//   bags_, _אָן_, _uubp_, jića_,
   {{0x69c904f4,0xd3780254,0x00000000,0x00000000}},	//   _glee, dića_, --, --,
   {{0x6b990098,0xb7e6290a,0x249d099e,0x38660f00}},	//   _éagó, _джак, _crwm_, quor_,
   {{0x61ed2b9d,0xd37800cb,0x9f58000d,0x7de500c7}},	//   _sjal, fića_, boré_, rėsi,
   {{0x69c90086,0xd378011c,0x67280124,0xc7b300a5}},	//   _ylee, gića_, _igdj, _קבע_,
   {{0x20180055,0x1aec0831,0x00000000,0x00000000}},	//   emri_, _করাই_, --, --,
   {{0xc95302b8,0xa5070d28,0x80db0461,0x3a2402d7}},	//   ומר_, _деца_, _पेशे, _mimp_,
   {{0x4255006c,0xcf27004f,0xd378011c,0x00000000}},	//   _کنٹر, ترحي, bića_, --,
   {{0xcddb2b9e,0x61ed0093,0x25a60051,0x91fd00ea}},	//   ања_, _tjal, _knol_, grāc,
   {{0xc7b80009,0x61ed00ac,0x7bdc034d,0xad9b0098}},	//   _lođ_, _ujal, _amru, _chúp,
   {{0x61fd0138,0x7e67006d,0xbcfb2b9f,0x00000000}},	// [2250] mosl, sujp, _acér, --,
   {{0x61fd1550,0xaac700f3,0x69c90191,0x7a330024}},	//   losl, يتان, _slee, _aħta,
   {{0x69c92ba0,0x8ae702ce,0xaa95004f,0x394f09af}},	//   _plee, ціал, ثلاث, tags_,
   {{0xbcfb01ba,0x3a240160,0x00000000,0x00000000}},	//   _dcér, _cimp_, --, --,
   {{0x394f2ba1,0x9aa500b5,0x69c9152b,0xe739029f}},	//   rags_, _کمزو, _vlee, бел_,
   {{0x61fd2ba2,0x2904001e,0x00000000,0x00000000}},	//   hosl, _dyma_, --, --,
   {{0x61fd2187,0x2bfa01d1,0x6fc201ba,0x91fd0029}},	//   kosl, ्तरं_, _dôch, tuāl,
   {{0xd37801cc,0x69c9022e,0x2129104e,0xd90e006c}},	//   vića_, _ulee, _ngah_, ئیے_,
   {{0x478b0086,0x61fd2ba3,0xdb1c0523,0x00000000}},	//   _всем_, dosl, _elrä, --,
   {{0x63b8006d,0x394d2ba4,0xd3780254,0x25a601ef}},	//   _covn, _hees_, tića_, _enol_,
   {{0x88bd0083,0x394d2ba5,0x6b95123c,0x9f4e00b8}},	//   _অধিক, _kees_, _mazg, áním_,
   {{0x61fd2ba6,0xd3782ba7,0x394d0421,0x6b950065}},	//   gosl, rića_, _jees_, _lazg,
   {{0x394d2ba8,0xd9bd0083,0x64a52ba9,0x2d89143f}},	//   _mees_, _আগাম, _хала, deae_,
   {{0x43750779,0x394d2baa,0x443f2bab,0x78a600fb}},	//   _זײַן_, _lees_, mpu_, _ákve,
   {{0x443f2bac,0x6012008a,0x61fd00ee,0xc332100a}},	//   lpu_, væmd, bosl, _אוו_,
   {{0x394d0221,0xc8bd2bad,0x62832bae,0x63b80506}},	//   _nees_, ्नाट, _ipno, _zovn,
   {{0xdd8f1b15,0x28db00b4,0xafe600af,0x6b951bfa}},	// [2260] دوق_, _मेलि, _ноил, _bazg,
   {{0x3a240260,0x443f2baf,0x600001ff,0x2bc10099}},	//   _simp_, ipu_, röms, _शकणा,
   {{0x394d17b0,0xc7b8011c,0xdb0e00d5,0x00000000}},	//   _bees_, _rođ_, _bobá, --,
   {{0xa96a0c06,0x394d2bb0,0xf1cc2bb1,0x3f8a2bb2}},	//   сида_, _cees_, ासिन, lebu_,
   {{0x394d2139,0x7bc5006d,0x443f2568,0x186703f5}},	//   _dees_, bkhu, jpu_, зачи_,
   {{0x3f982bb3,0x6d44010b,0x628301bf,0x6e26010d}},	//   ndru_, lbia, _opno, _hikb,
   {{0x63b80076,0x3a240012,0xd9462bb4,0x2bc100a1}},	//   _rovn, _timp_, _неви, _शकता,
   {{0x394d0626,0x6fcb033e,0x3f8a2bb5,0x6d4401a3}},	//   _gees_, _müca, hebu_, nbia,
   {{0x61fd2bb6,0x443f010d,0x6b951008,0xd49700af}},	//   vosl, gpu_, _yazg, прэ_,
   {{0x3f8a0124,0x6027000d,0xdb0e00ac,0x883b00a5}},	//   jebu_, hémè, _zobá, _לתמו,
   {{0x394d0189,0x63b800e2,0x7d062bb7,0x00000000}},	//   _yees_, _vovn, _lyks, --,
   {{0x394d01e8,0x25a6001e,0x3f980228,0x00000000}},	//   _xees_, _unol_, edru_, --,
   {{0x61fd15d8,0x64a32bb8,0x859b00a5,0x77bd0310}},	//   rosl, _паца, _לשאו, _tèxt,
   {{0xb7bd0043,0x61fd2bb9,0x00000000,0x00000000}},	//   _puţi, sosl, --, --,
   {{0x6b951851,0x61fd2bba,0xddd02bbb,0x64400c7c}},	//   _razg, posl, _šeši, lpmi,
   {{0x6d442bbc,0x00000000,0x00000000,0x00000000}},	//   gbia, --, --, --,
   {{0x394d2bbd,0x6e260345,0x7de500c7,0x660208c7}},	// [2270] _rees_, _dikb, dėst, _mkok,
   {{0xfe6e07e4,0xbca40037,0x60cf04d4,0x7d060282}},	//   دگی_, عملي, ınmı, _dyks,
   {{0xa3cd0084,0x6d442bbe,0x7bc5069d,0x394d2bbf}},	//   रसत_, bbia, rkhu, _pees_,
   {{0x394d0221,0x3ebe2bc0,0x6602251e,0x00000000}},	//   _qees_, ätte_, _nkok, --,
   {{0x394d2bc1,0x315802b5,0xa91d00d5,0x6b950116}},	//   _vees_, ליאן_, _obže, _tazg,
   {{0x394d250a,0x66022bc2,0x6d4f2bc3,0x7de50031}},	//   _wees_, _akok, _heca, rėsu,
   {{0x6d4f1690,0x99672bc4,0x00000000,0x00000000}},	//   _keca, _нтал, --, --,
   {{0x7c2706b3,0x84592bc5,0x6d4f2bc6,0x6e3800b5}},	//   _hijr, орот_, _jeca, _évbe,
   {{0x855400bf,0x6add29ce,0x6f0900b8,0xb4c70d41}},	//   ریور_, _मधुर, řech, ईने_,
   {{0x6d4f2bc7,0x443f2bc8,0x00000000,0x00000000}},	//   _leca, rpu_, --, --,
   {{0x7c2f0012,0x6d5d1554,0x2bae00a1,0xa18a2031}},	//   _lucr, _odsa, घाता, обна_,
   {{0x443f2bc9,0x6d4f2bca,0x798b00e9,0x3f8a2bcb}},	//   ppu_, _neca, negw, webu_,
   {{0x66092bcc,0xeb0a00b4,0xc4fb00d1,0x661b2bcd}},	//   mlek, _वर्त_, _اعضا_, mmuk,
   {{0x6d4f0051,0x661b2bce,0x7d062bcf,0x443d2bd0}},	//   _aeca, lmuk, _ryks, _itw_,
   {{0x6d4f2bd1,0x442f2bd2,0x3f8a2bd3,0xd0070c8d}},	//   _beca, _hug_, rebu_, фере_,
   {{0x44272bd4,0x6d4f2bd5,0x7e610093,0x443d2bd6}},	//   _hin_, _ceca, álpa, _ktw_,
   {{0x6d442bd7,0x442f2bd8,0xfce3015a,0x6d4f0aed}},	// [2280] rbia, _jug_, вото, _deca,
   {{0x8bf10083,0x7d0600d8,0x7c2f00a2,0x6d5d03d0}},	//   _জীবন_, _vyks, _ducr, _edsa,
   {{0x442f2bd9,0x6eb50d53,0x66091b2a,0x7d062bda}},	//   _lug_, _उपयु, klek, _wyks,
   {{0x6d4f2bdb,0x661b00d7,0x442f00af,0xc8ca0286}},	//   _geca, jmuk, _oug_, يوان_,
   {{0x442f0189,0xa3cd2207,0x443d006d,0x645d0187}},	//   _nug_, रसा_, _ntw_, ásil,
   {{0x44272bdc,0xb8d60f09,0x66092bdd,0x00000000}},	//   _nin_, _छप_, elek, --,
   {{0x8b230cf9,0x34b800c0,0xd6d0004f,0x442f06b5}},	//   _адре, ेन्द, طقة_, _aug_,
   {{0xd5b00514,0x6609082b,0x661b11e9,0x442f2bde}},	//   افة_, glek, gmuk, _bug_,
   {{0x442f2bdf,0x92ea0033,0x443d0312,0x00000000}},	//   _cug_, _মরে_, _ctw_, --,
   {{0xa3d8006a,0x394600d8,0xe8d7011d,0x443d2be0}},	//   ठों_, lbos_, _חומר_, _dtw_,
   {{0x44272be1,0xbcfb0248,0x66092be2,0xb7d70987}},	//   _din_, _idée, blek, _تولا_,
   {{0x44272be3,0x7dc3007c,0x442f0395,0xf6690037}},	//   _ein_, _tõsi, _fug_, _رحمه_,
   {{0x29f80c21,0x39462be4,0xf77100b5,0x442f2be5}},	//   mčad_, ibos_, _جاۓ_, _gug_,
   {{0x44272be6,0x6d4f203f,0x9f4301f4,0x6600150c}},	//   _gin_, _seca, mijë_, lomk,
   {{0x7c2f0fcb,0x442f033b,0x7c270051,0x9f580176}},	//   _sucr, _zug_, _rijr, corí_,
   {{0x44272be7,0x442f0189,0xa01b033b,0x29f800cd}},	//   _zin_, _yug_, gwör, nčad_,
   {{0x44272be8,0x6d4f2be9,0x00000000,0x00000000}},	// [2290] _yin_, _veca, --, --,
   {{0x2fc700e8,0x44272bea,0x60c0022a,0x660900b5}},	//   _ông_, _xin_, ämme, zlek,
   {{0x6d4f2beb,0x798b2bec,0xf09f0176,0x00000000}},	//   _teca, tegw, lvà_, --,
   {{0x3866001e,0x6d5d01b4,0x6eae000c,0x7f5502d7}},	//   fror_, _udsa, ीहरु, lazq,
   {{0xdd3a0052,0x52ca0253,0x660903e0,0x798b0010}},	//   _מערכ, ानुस, vlek, regw,
   {{0xe7392bed,0x2d992bee,0xa69500ed,0x7dd108c8}},	//   чек_, _hase_, ериј, _dåse,
   {{0x4427134c,0x2d992bef,0x442f2bf0,0x27e9011c}},	//   _rin_, _kase_, _sug_, đan_,
   {{0x44272bf1,0xfc3f004f,0x9f5801ba,0x38662bf2}},	//   _sin_, _tríd_, vorí_, bror_,
   {{0x66092bf3,0x661b0388,0x44270cdb,0x91fd013a}},	//   rlek, rmuk, _pin_, trān,
   {{0xe3b10514,0xe8bd02e4,0x44272bf4,0x66092bf5}},	//   ارة_, ्नीच, _qin_, slek,
   {{0x44272bf6,0x2d992bf7,0x0394010b,0x00000000}},	//   _vin_, _oase_, трыя, --,
   {{0x442f01a9,0x2d992bf8,0x44272bf9,0x7dca00d5}},	//   _tug_, _nase_, _win_, _rýso,
   {{0x44272bf9,0x2ec801c0,0x30752bfa,0x443d0a5a}},	//   _tin_, रन्त, курс, _utw_,
   {{0x44272bfb,0xd01221a0,0x2d990a8c,0xe456016b}},	//   _uin_, الس_, _aase_, _טינט_,
   {{0x2d990dc5,0xf8bd000c,0x394600d8,0x91e62bfc}},	//   _base_, ्नुप, ybos_, _поке,
   {{0x2d992bfd,0xdb1c0248,0x7dca00ac,0x00000000}},	//   _case_, _forê, _výso, --,
   {{0xa3c302cb,0x3dd202c7,0x2d992bfe,0x8fa62626}},	// [22a0] _एका_, rhyw_, _dase_, _запе,
   {{0x61e60d6f,0xfc3f0082,0x395f2bff,0x320200ac}},	//   likl, _dtí_, _adus_, loky_,
   {{0x160f00b1,0x6600002f,0x41b30118,0xc3210033}},	//   ातार_, yomk, _شمیر, পুরি_,
   {{0x61e62c00,0x39462c01,0x2d992c02,0x38661124}},	//   nikl, ubos_, _gase_, tror_,
   {{0xe8942246,0x3f9a2c03,0x98a32bfc,0xa92700d4}},	//   таль, _kapu_, лице, ніше_,
   {{0x6d562c04,0x2d990e6a,0x38662c05,0x2d800b88}},	//   laya, _zase_, rror_, lfie_,
   {{0x3f9a2c06,0x66000791,0xdb1c01f4,0xd90d00b5}},	//   _mapu_, tomk, _morë, میہ_,
   {{0x6d562c07,0xceb30052,0x3949008a,0x3f9a0029}},	//   naya, ריה_, ðast_, _lapu_,
   {{0x61e62c08,0x18670370,0x29f800f4,0x00000000}},	//   dikl, _пати_, rčad_, --,
   {{0x6d5611e9,0xb3460279,0x7dca0093,0xb3560df3}},	//   haya, diçõ, _sýsl, ریبا_,
   {{0x6d561292,0x6b811e70,0x61e62c09,0xd25701e0}},	//   kaya, _ölge, fikl, нця_,
   {{0x6d562bab,0x25bd035f,0xab64027d,0x7c360055}},	//   jaya, _gowl_, ldüğ, kqyr,
   {{0x7dca0076,0x6d562c0a,0x1ae700c8,0x2ca02c0b}},	//   _výsl, daya, _করছে_, jvid_,
   {{0x6fcb0095,0x2d9900af,0x200501ba,0x31602c0c}},	//   _gücl, _sase_, ôli_, _ediz_,
   {{0x2d99142f,0x2d802c0d,0xdb1c00da,0xdb152c0e}},	//   _pase_, ffie_, _dorë, _pozí,
   {{0x6d5621ea,0x32530133,0xb3460279,0x3ebe013c}},	//   gaya, _свър, biçõ, ätta_,
   {{0xdb150187,0xacf82c0f,0xa91d232f,0x9f5801f7}},	// [22b0] _vozí, енту_, _obža, borà_,
   {{0xdb1c2c10,0x9f5801f7,0xe7e201c0,0x00000000}},	//   _korè, corà_, कोमा_, --,
   {{0x6d561d02,0x2003010b,0x3a752c11,0x2d9900be}},	//   baya, moji_, тлер, _tase_,
   {{0x20032c12,0x6d5601cb,0x9f580132,0x91fd00ec}},	//   loji_, caya, porã_, krām,
   {{0xcf2701cb,0x7dda0355,0xdb1c00e0,0x83fd00b5}},	//   _ترکي, růst, _lorè, rtőz,
   {{0x66e51129,0x61e62c13,0x200300c7,0x00000000}},	//   кола, zikl, noji_, --,
   {{0x34c9210a,0x9f58021d,0x00000000,0x00000000}},	//   िन्द, norá_, --, --,
   {{0x20030054,0x00000000,0x00000000,0x00000000}},	//   hoji_, --, --, --,
   {{0x61e60568,0x22402c14,0x20032c15,0x91fd02d4}},	//   vikl, _čika_, koji_, grām,
   {{0xad9b21ae,0x20032c16,0x799b002f,0xd75918dd}},	//   _skúl, joji_, _hauw, _آلات_,
   {{0x6d560247,0x3f9a2c17,0x27e700fb,0x799b2c18}},	//   yaya, _rapu_, minn_, _kauw,
   {{0xe3b1064e,0x6d560118,0x27e72c19,0xb3460279}},	//   ارک_, xaya, linn_, tiçõ,
   {{0x61e62c1a,0x32020187,0x3f9a2c1b,0xc95200a5}},	//   rikl, roky_, _papu_, סמך_,
   {{0xb3460370,0x6d5609df,0x2003108a,0x799b2c1c}},	//   riçõ, waya, goji_, _lauw,
   {{0x6d562c1d,0x0cbc00b4,0xb34603e6,0xa3d62207}},	//   taya, ोन्म, siçõ, _सतत_,
   {{0x27e7004a,0xdce40c99,0x799b2c1e,0x69cb02a2}},	//   hinn_, ngić, _nauw, jkge,
   {{0x7e7c1cc4,0x61e42c1f,0x3f9a0225,0x200319f6}},	// [22c0] strp, _imil, _tapu_, boji_,
   {{0x6d562c20,0x80db00c8,0xfaa62c21,0x9f4a05c9}},	//   saya, _যুক্, казо, robó_,
   {{0x799b2c22,0x6d562c23,0x27e72c24,0x81f70416}},	//   _bauw, paya, dinn_, _سفیر_,
   {{0x5e5700c2,0x2b4d02c4,0xe8ea0183,0x186a0279}},	//   _ביטע_, _đece_, ммед_, дади_,
   {{0xf7720642,0x27e7008a,0x7641010b,0x61e40054}},	//   لاغ_, finn_, _atly, _mmil,
   {{0x27e72c25,0xda661c2d,0x6a86021d,0xf0930317}},	//   ginn_, _لاري, _илга, ינד_,
   {{0x61e42c26,0xbcfb2c27,0xd6cf0ad9,0x7dc3007c}},	//   _omil, _idéa, يقه_, _tõst,
   {{0x6b9c2c28,0xd87600b5,0x69cb01ae,0xd378011c}},	//   _harg, _لائب, ckge, mići_,
   {{0xb4be0712,0xb4cc2c29,0x6b9c2c2a,0x02ca2c2b}},	//   ीने_, रने_, _karg, ान्न,
   {{0x69c02c2c,0x61e42055,0x27e701a6,0x799b0035}},	//   _home, _amil, cinn_, _zauw,
   {{0xa3e304cc,0x6b9c2c2d,0xd6c4064e,0xa3c30006}},	//   _नगर_, _marg, _حمای, _एकर_,
   {{0x6b9c2c2e,0xdb1c1498,0x386901a0,0x00000000}},	//   _larg, _coré, šare_, --,
   {{0x20030bc5,0xdb15002a,0xdb1c14e1,0xd3780009}},	//   toji_, _mozá, _doré, hići_,
   {{0xbcfb004f,0xd378042a,0xa3e10c67,0x60c0013c}},	//   _ndéa, kići_, नोद_, ämma,
   {{0xd3780129,0x20032c2f,0xdd9b005f,0x9e0700d4}},	//   jići_, roji_, мша_, вчал,
   {{0x69c02c30,0xd3780254,0xdb1c0118,0x20032c31}},	//   _nome, dići_, _goré, soji_,
   {{0x32090c86,0xa3d607b5,0x799b0223,0x78a20009}},	// [22d0] _ikay_, _सता_, _rauw, jvov,
   {{0x6b9c2140,0xfc3f2675,0xd3780506,0xe8120066}},	//   _carg, _cría_, fići_, _ढीला_,
   {{0x6b9c2c32,0x69c001e4,0x799b067f,0x656200a0}},	//   _darg, _bome, _pauw, _odoh,
   {{0xfc3f01ef,0x644201a3,0x27e7033b,0x645b0298}},	//   _ería_, _otoi, winn_, ysui,
   {{0x27e72c33,0x26c70297,0x69cb0c7c,0x6b9c0044}},	//   tinn_, wyno_, rkge, _farg,
   {{0x629805e2,0x628a01b4,0xd378011c,0x656200e0}},	//   _osvo, _opfo, bići_, _adoh,
   {{0x27e72c34,0x69c02c35,0x64422c36,0xd3780009}},	//   rinn_, _fome, _atoi, cići_,
   {{0x27e72c37,0x69c02c38,0x09ca0083,0xd8b7006c}},	//   sinn_, _gome, লোবা, _لگتا_,
   {{0x6b9c027d,0x3f9101d7,0x753b2c39,0xad9b00a0}},	//   _yarg, kezu_, rcuz, _akúk,
   {{0x6b9c0176,0x69c00a75,0x645b2c3a,0x3a2d2c3b}},	//   _xarg, _zome, rsui, _hiep_,
   {{0x645b2c3c,0x42261a24,0xdb1c0bb0,0x64422c3d}},	//   ssui, лдов, _poré, _etoi,
   {{0x9f4e0076,0xa06a2c3e,0x7dca0334,0xcb1200a5}},	//   čník_, нама_, _výsk, מלי_,
   {{0x6fcb01ae,0xa91d00d8,0x629801f7,0x3a2d0051}},	//   _küch, _pažy, _esvo, _miep_,
   {{0xdee61d30,0x3a2d01e4,0x83350070,0x00000000}},	//   гоги, _liep_, _גאַס_, --,
   {{0xe7f6018d,0xdb1c01cb,0x00000000,0x00000000}},	//   ेवता_, _toré, --, --,
   {{0xd3782c3f,0x6b9c2c40,0xa01b006c,0x68fb00a8}},	//   vići_, _sarg, gtöb, _oxud,
   {{0x69c003d0,0x3b8602ee,0x6b9c2c41,0xb88600b8}},	// [22e0] _rome, ллаг, _parg, _kníž,
   {{0x69c01c33,0xd378011c,0x6b9c2c42,0x00000000}},	//   _some, tići_, _qarg, --,
   {{0x69c02c43,0x68fb043f,0x7dca0093,0xc3320122}},	//   _pome, _axud, _lýsi, צוא_,
   {{0x6b9c272d,0xd3780c0a,0xbcfb2c44,0x9f580443}},	//   _warg, rići_, _idén, forç_,
   {{0x2d922c45,0x1754111d,0x6fcb02c9,0xd3780c99}},	//   meye_, авля, _büch, sići_,
   {{0x6fcb02c9,0x78a20187,0x69c00122,0xd37800cd}},	//   _rück, rvov, _wome, pići_,
   {{0x64422c46,0xb4cc1371,0xa2630023,0x36d40036}},	//   _stoi, रन्_, _quố, ройр,
   {{0x2d922c47,0xa2a200dc,0xa5342c48,0x62980051}},	//   neye_, गिस्, шнич, _rsvo,
   {{0x98a32c49,0x7c2e2c4a,0xf746263b,0x3f9110a2}},	//   _лите, _kibr, _безо, yezu_,
   {{0x7c2e2c4b,0x2d9204fb,0xdcef00cd,0x00000000}},	//   _jibr, heye_, šeće, --,
   {{0x0586027a,0x2d920010,0x3f910254,0x8646004b}},	//   _булм, keye_, vezu_, _снеж,
   {{0xf65100f5,0x6fcb033b,0xbbc10380,0x00000000}},	//   _گئے_, _züch, _शक्क, --,
   {{0x7c2e0a24,0x3f91011c,0x50642c4c,0x2d922c4d}},	//   _oibr, tezu_, йтра, deye_,
   {{0x40340c65,0x00000000,0x00000000,0x00000000}},	//   серс, --, --, --,
   {{0x62980f44,0xddab2c4e,0x00000000,0x00000000}},	//   _usvo, нтал_, --, --,
   {{0x7c2e004f,0x442e2c4f,0xb88601ba,0x32092c50}},	//   _aibr, _hif_, _zníž, _ukay_,
   {{0x442e048c,0x3b552c51,0x7c2e0065,0x3a2d02a2}},	// [22f0] _kif_, икар, _bibr, _riep_,
   {{0x7c2e002a,0x00000000,0x00000000,0x00000000}},	//   _cibr, --, --, --,
   {{0x7c2e2c52,0x2d922c53,0x15f600b4,0x3a2d0e54}},	//   _dibr, beye_, ुकार_, _piep_,
   {{0xd37800cd,0x6fcb02b1,0x2d920225,0x00000000}},	//   miću_, _süch, ceye_, --,
   {{0xd378011c,0xbcfb000d,0x99840395,0x00000000}},	//   liću_, _idéo, _simţ_, --,
   {{0xdcfd0ae0,0x7c2e2c54,0xf7712087,0x442e0536}},	//   _lasī, _gibr, زات_, _nif_,
   {{0x45d50cac,0xd378011c,0x3a2d0023,0x00000000}},	//   ицит, niću_, _tiep_, --,
   {{0x6d4d0244,0xb88600b8,0x446529fd,0x6e371505}},	//   nbaa, _sníž, авив, _muxb,
   {{0x851f1fe0,0x6d4d2c55,0xe45600d8,0x442e029e}},	//   मेंट_, ibaa, ажы_, _bif_,
   {{0x29f803c9,0x6d4d0107,0x2d922c56,0x98170037}},	//   nčan_, hbaa, zeye_, _إبرا,
   {{0x629e18f2,0x6d4d06ba,0x25af012f,0x2d922c57}},	//   _špor, kbaa, _tngl_, yeye_,
   {{0x78a92c58,0xe7eb11b5,0xd3780254,0x10a60340}},	//   _krev, _झगडा_, diću_, аимн,
   {{0x6d4d2c59,0x442e2c5a,0x78a90065,0x21a30421}},	//   dbaa, _fif_, _jrev, циям,
   {{0xfe46036e,0xd378012e,0x00000000,0x00000000}},	//   инго, fiću_, --, --,
   {{0xed5a1cf7,0x2d92269e,0xdbcf01ba,0x69d90345}},	//   ков_, teye_, bľúb, khwe,
   {{0x3860044d,0x20562bfa,0x6d4d053e,0x78a92c5b}},	//   širi_, _ктор, gbaa, _orev,
   {{0x2d922c47,0xd00f0332,0x64490065,0x00000000}},	// [2300] reye_, سلہ_, npei, --,
   {{0x2d922c5c,0x6d4d073a,0x79892c5d,0xd37800cd}},	//   seye_, abaa, _abew, biću_,
   {{0x7f5c2c5e,0xeb972c5f,0x6d4d001c,0x78a92c60}},	//   marq, рих_, bbaa, _arev,
   {{0xa96a2c61,0x22511840,0x6d4d0345,0x973c00cd}},	//   тида_, ázky_, cbaa, _maće,
   {{0x3860004f,0x913b02b5,0x78a92c62,0x7c2e0282}},	//   éir_, דענק, _crev, _tibr,
   {{0x78a90bcc,0x7f5c039f,0xe6662123,0x6f09027d}},	//   _drev, narq, атио, şece,
   {{0x442e2c63,0x78a92c64,0xd9100919,0x64490051}},	//   _rif_, _erev, _کیش_, epei,
   {{0x69d92699,0x7dd8004f,0x442e2c65,0x78a91097}},	//   chwe, _físe, _sif_, _frev,
   {{0x030b07ba,0x2e3c008a,0xdb1c0a17,0xd37800f4}},	//   _सुबह_, _líf_, _morí, ziću_,
   {{0x66e62c66,0x2b580310,0x442e2c67,0x00000000}},	//   _коза, _jerc_, _qif_, --,
   {{0xe7370086,0x6d4d0298,0x442e2a5a,0x29f8011c}},	//   _тех_, ybaa, _vif_, nčao_,
   {{0xd3780a78,0x92570421,0x00000000,0x00000000}},	//   viću_, шают_, --, --,
   {{0x909807b4,0x92b60083,0x7dd12c68,0x10740352}},	//   авят_, ছনে_, _såso, оляю,
   {{0x92170722,0x7f5c0473,0xd378011c,0x2b58009e}},	//   _धीरज_, garq, tiću_, _nerc_,
   {{0x6d4d2c69,0x29f81b76,0x4ea42c6a,0x6e2f0176}},	//   tbaa, včan_, орта, _picb,
   {{0xcdd80202,0xd378011c,0xdb1c0183,0x00000000}},	//   ању_, riću_, _corí, --,
   {{0xdce606a8,0x6d4d0136,0x7f5c2c6b,0xd90400d1}},	// [2310] _bakı, rbaa, barq, _آی_,
   {{0x6d4d03c4,0x6c6a00b5,0x2b580395,0xd37800cd}},	//   sbaa, اللہ_, _cerc_, piću_,
   {{0x1eab0773,0xfc3f1111,0x6d4d03c4,0xe0df0036}},	//   _شادي_, _trío_, pbaa, lzò_,
   {{0x7dd801c0,0xf99316e6,0x6ec401c0,0x64490328}},	//   _píse, تبط_, रहरु, ypei,
   {{0x2d8b006d,0x98a52c6c,0x3a380069,0xf74500b6}},	//   _ibce_, силе, _eurp_, бело,
   {{0xc88428ae,0x69d90b13,0xc60f021a,0x78a90124}},	//   dağı_, shwe, ात्य_, _vrev,
   {{0x5a4400d8,0x00000000,0x00000000,0x00000000}},	//   _мэта, --, --, --,
   {{0x78a92c6d,0xdce80035,0x00000000,0x00000000}},	//   _trev, śląs, --, --,
   {{0xdce60723,0xcdb80122,0x6fcb0095,0x9f8f027d}},	//   _yakı, שפחה_, _hücu, _güç_,
   {{0xa3e10755,0x395d2c6e,0x3cff004e,0xe29903fa}},	//   नों_, laws_, _रखने_, гао_,
   {{0x64492c6f,0x2d8b2c70,0x11d6004f,0x7c250079}},	//   spei, _obce_, متحد, imhr,
   {{0x64492c71,0x9f5100b5,0xc88400a8,0xd9f70ec5}},	//   ppei, kozó_, bağı_, ंचित_,
   {{0xc88406d3,0x7f5c0a39,0x53a50043,0xd4692c72}},	//   cağı_, tarq, _галб, _силе_,
   {{0x395d0189,0x248f00d7,0xd91a100a,0x7dca008d}},	//   haws_, _ipgm_, טורל, _lýst,
   {{0x7f5c0473,0x6fd00301,0xdb1c1e15,0x6012003e}},	//   rarq, _häck, _porí, næmi,
   {{0x25bf01cb,0xdce6027d,0xbcfb00d5,0xad9b008d}},	//   njul_, _sakı, _edém, _ljúf,
   {{0x2b5800b5,0x395d0221,0xdb0e0097,0x7f5c014c}},	// [2320] _perc_, daws_, _dobý, parq,
   {{0x66092c73,0x25bf139f,0x2f561368,0x00000000}},	//   hoek, hjul_, _утис, --,
   {{0x4e1a0416,0xdce60225,0x6fd0013c,0x66092c74}},	//   _متحد_, _vakı, _läck, koek,
   {{0xb86600f3,0x29f800cd,0x9f4a0051,0xc8840448}},	//   ماتو, rčao_, dibé_, yağı_,
   {{0x1cba036b,0xc7c6071d,0xdce60723,0x06e50083}},	//   _صاحب_, йски, _takı, _পুলি,
   {{0x3a382c75,0x9ad6010b,0x7dca00ac,0x29f80207}},	//   _turp_, _любі, _výsu, pčao_,
   {{0xe0df07e5,0x91fd0228,0x00000000,0x00000000}},	//   zzò_, nsāc, --, --,
   {{0x6fd02c76,0x200a012f,0xd6d901e0,0xa2c6022e}},	//   _bäck, hobi_, шті_, ाहस्,
   {{0x200a2c77,0xdb1c0392,0x29f80a66,0x656f2c78}},	//   kobi_, _horà, nčam_, ócha,
   {{0x249d0107,0x6fd001ff,0xc88400c1,0x200a0183}},	//   _dswm_, _däck, rağı_, jobi_,
   {{0x660902e6,0x91fd00ea,0x51f900d4,0x200a08b7}},	//   boek, krāt, иною_, dobi_,
   {{0x38600c99,0x09ca0033,0x7dd1008c,0x00000000}},	//   širu_, লোরা, _påsm, --,
   {{0x2ed1060a,0x200a2c79,0x63bc2c7a,0x6fd00282}},	//   सन्त, fobi_, örns, _gäck,
   {{0x3fe70033,0x03a300af,0x2cad00d5,0x00000000}},	//   পক্ষ, _ничо, _šedo_, --,
   {{0xd35b0bed,0xe246211b,0x6fd0033b,0x00000000}},	//   _גדול, _اختي, _mäch, --,
   {{0x395d0221,0x720700b5,0x6fd0033b,0x3ebf0124}},	//   xaws_, _دفعہ_, _läch, ćut_,
   {{0xf1f8064e,0x71f80ad9,0x320b004e,0x91a90023}},	// [2330] _دعوت_, _دروس_, mocy_, _giá_,
   {{0x6fd002c9,0x66090a75,0x61ef2c7b,0xad9b07c0}},	//   _näch, zoek, licl, _akút,
   {{0x6fb500d1,0xad270416,0xfbd00037,0xfc3f00ee}},	//   _همکا, _گردو, رتك_, _krík_,
   {{0x7dd10022,0x6fcb2c7c,0x39152447,0x7dd80138}},	//   _måsk, _vücu, омер, _vísc,
   {{0x6d5f1505,0x7dca05d3,0x9ccb021f,0x89340037}},	//   maqa, _výst, _сына_, أعما,
   {{0x6d5f0024,0x395d006d,0x6fd0013c,0x61ef2c7d}},	//   laqa, saws_, _räck, hicl,
   {{0x7ac41346,0x6fd01193,0x66091908,0x2ca900be}},	//   _есте, _säck, toek, lvad_,
   {{0xa2d71604,0x59f90086,0xe6190370,0xa3e10066}},	//   मनस्, _тебя_, јди_, नोई_,
   {{0x22470703,0x7bc72c7e,0x38600037,0x44390132}},	//   _stnk_, _koju, áirt_, ês_,
   {{0xdb1c2c7f,0x6d5f0103,0xd26507b0,0x66092c80}},	//   _horá, haqa, окой, soek,
   {{0xdb1c006c,0x2ca92c81,0x59dd007c,0x2bde0099}},	//   _korá, hvad_, _मतार, फोटा,
   {{0x249d0221,0x6fd0013c,0x61ef2c82,0x00000000}},	//   _tswm_, _täck, gicl, --,
   {{0x200a046a,0x34942c83,0xa01b00fd,0x2bfb012f}},	//   tobi_, _нацр, rtön, ्वां_,
   {{0x34b201ca,0x23292c84,0x973c0009,0x25e50af6}},	//   _آموز, _коли_, _kaća, जोरी_,
   {{0x443f2c85,0x61ef0602,0x200a087c,0xbea32c86}},	//   lqu_, bicl, robi_, марк,
   {{0x63a32c87,0xdd921d05,0x657b2c88,0xa01b2c89}},	//   _hann, بور_, nguh, ltöl,
   {{0x63a32c8a,0xe2060907,0x7bc70187,0x443f0024}},	// [2340] _kann, रवीण_, _boju, nqu_,
   {{0xad9b2c8b,0x3ce00009,0xf1bf0042,0x443f00a2}},	//   _skút, rziv_, nmán_, iqu_,
   {{0x63a32c8c,0x3f982c8d,0x6d5f2c8e,0x5fb70122}},	//   _mann, meru_, baqa, _והיא_,
   {{0x63a32c8f,0xdb1c2c90,0x8d7608cf,0x6fd0033b}},	//   _lann, _corá, _بادا, _säch,
   {{0x91a00023,0x63a30282,0xdb1c00ac,0x29f80009}},	//   _chỉ_, _oann, _dorá, lčak_,
   {{0x3f982c91,0x6d442c92,0x3cff0035,0x466a0ade}},	//   neru_, lcia, _रखते_, арим_,
   {{0xd90d006c,0xdb1c0037,0xfa672c93,0x6d442c94}},	//   نیہ_, _forá, _марк_, ocia,
   {{0x6d44028b,0x39420006,0x63a302e6,0x26c00254}},	//   ncia, _üks_, _aann, ćio_,
   {{0x63a32c95,0x6d442c96,0x3f982c97,0x22492c98}},	//   _bann, icia, keru_, _čaka_,
   {{0x3f980b56,0x69c20136,0x63a32c99,0x7dd12c9a}},	//   jeru_, ljoe, _cann, _påsk,
   {{0x63a32c9b,0x61ef08fe,0x3f982c9c,0x29f80009}},	//   _dann, ticl, deru_, jčak_,
   {{0x63a31861,0x7dd10282,0x69c22c9d,0x00000000}},	//   _eann, _gåsh, njoe, --,
   {{0x63a32c9e,0x3f982c9f,0xa3c300a1,0x3d190067}},	//   _fann, feru_, _एकच_, _दरें_,
   {{0xa3ce0066,0x6d462ca0,0x3f982ca1,0x80270037}},	//   _रवि_, _afka, geru_, ترجم,
   {{0x9f340185,0xbcfb03e6,0x6d5f1505,0x24400023}},	//   дері, _idéi, taqa, _hòm_,
   {{0x24400c1f,0x6560004f,0x63a31d33,0x7dd801ba}},	//   _kòm_, namh, _zann, _písa,
   {{0x61ed0537,0x3f982ca2,0x63a32ca3,0xad9b016f}},	// [2350] _imal, beru_, _yann, _skús,
   {{0x6d5f1505,0xdb1c2ca4,0x3f982ca5,0x7dd80093}},	//   saqa, _sorá, ceru_, _vísa,
   {{0xdd910082,0x61ed008b,0x5a352ab4,0x657b011e}},	//   _كود_, _kmal, чнет, yguh,
   {{0x6d4401d3,0xfe9a02b5,0x6d5f0069,0xf1bf2ca6}},	//   ccia, _פירמ, qaqa, zmán_,
   {{0x6d5d0029,0x65602ca7,0x61ed2ca8,0x2440021e}},	//   _iesa, damh, _mmal, _nòm_,
   {{0x6d5d2ca9,0xd7c80098,0x61ed0088,0x60c002e2}},	//   _hesa, يونه_, _lmal, ämmi,
   {{0x63a32caa,0x6d5d2cab,0x61ed2cac,0xdb1c2cad}},	//   _rann, _kesa, _omal, _torá,
   {{0x63a329fc,0x6d5d2cae,0xfb3401c8,0x61ed010d}},	//   _sann, _jesa, _інтэ, _nmal,
   {{0x6d5d2caf,0xb4d52cb0,0x3d190067,0xf1ba00e2}},	//   _mesa, सने_, _दरों_, _đơ_,
   {{0x61ed2cb1,0x6d5d2cb2,0x443f2cb3,0x3ea10031}},	//   _amal, _lesa, rqu_, _osht_,
   {{0x63a32cb4,0x443f02e1,0x3f982073,0x69db022e}},	//   _vann, squ_, veru_, _klue,
   {{0x63a32cb5,0x6d5d2cb6,0xdb1c054e,0x244002e9}},	//   _wann, _nesa, _foræ, _fòm_,
   {{0x63a32cb7,0xe20b008a,0x3ea101f4,0xe449004f}},	//   _tann, _slóð_, _asht_, _التى_,
   {{0xf8a501ca,0x69db2cb8,0x0454006c,0x61ed2cb9}},	//   _یک_, _llue, _آئند, _emal,
   {{0x6d5d2cba,0x7c3d2cbb,0x443d2cbc,0x68e20036}},	//   _besa, _ausr, _huw_, zzod,
   {{0xf0660525,0xf1bf0093,0x7c3500ea,0x29f800cd}},	//   _екип, nmál_, _aizr, rčak_,
   {{0x6d5d2cbd,0x3f982cbe,0x3ea101f4,0xdb1c01f4}},	// [2360] _desa, peru_, _esht_, _korç,
   {{0x6d442cbf,0x69db03ad,0xe81b0084,0x443d2cc0}},	//   scia, _alue, _पीला_, _muw_,
   {{0x69c20345,0x6d441f51,0xcf5700a5,0x69c901ed}},	//   tjoe, pcia, _מבית_, _boee,
   {{0x6d5d2cc1,0x443d012f,0x61ed0176,0x7bde0c6f}},	//   _gesa, _ouw_, _xmal, shpu,
   {{0x2d82013c,0xb4d500be,0x00000000,0x00000000}},	//   _icke_, सनो_, --, --,
   {{0x569400a4,0x69c20234,0x2ca200d7,0x6d5d2cc2}},	//   дакт, sjoe, _iskd_, _zesa,
   {{0x69db2cc3,0x6d5d2cc4,0x030b0066,0x6459007a}},	//   _flue, _yesa, _सुलह_, _awwi,
   {{0xe9a32b34,0x7c3d1051,0x660400a0,0x75e6010b}},	//   _пасп, _yusr, čiko, яўле,
   {{0x2816006c,0xdb1c00d0,0x65602cc5,0x2ca2023a}},	//   _فورس, _borç, ramh, _jskd_,
   {{0x65602cc6,0x46a62cc7,0x61ed0122,0x9f94073c}},	//   samh, _назв, _smal, _jää_,
   {{0xad9b0168,0x00000000,0x00000000,0x00000000}},	//   _okúp, --, --, --,
   {{0x39461423,0x2440009e,0x7ae100fd,0x443d099e}},	//   ncos_, _tòm_, _ülte, _fuw_,
   {{0x38662cc8,0xdb1c2cc9,0x39462cad,0x7dd800b8}},	//   nsor_, _forç, icos_, _písn,
   {{0x6d5d2b63,0x925700bf,0xa01b0093,0x2d820282}},	//   _sesa, _کشور_, mtök, _acke_,
   {{0x6d5d108b,0x7c3d01cc,0x9f4a00de,0xdb0501f4}},	//   _pesa, _susr, cibí_, rdhë,
   {{0x61ed18e4,0x42fb0122,0x7bdc029e,0x7c3d00c7}},	//   _umal, _להוס, _alru, _pusr,
   {{0x628809b3,0x25a61a07,0x6d5d2cca,0x7bdc0103}},	// [2370] ltdo, _maol_, _vesa, _blru,
   {{0x39462ccb,0x2d82033b,0x6e992ccc,0x6d5d0103}},	//   ecos_, _ecke_, _двор_, _wesa,
   {{0x61fd2ccd,0xdb5800c3,0xdd0c0035,0x20041d70}},	//   onsl, яют_, góło, émie_,
   {{0x61fd2cce,0x973c02c4,0x23c8000c,0xc33300a5}},	//   nnsl, _baćo, ाउँद, גוע_,
   {{0x07a52ccf,0xe7390279,0x00000000,0x00000000}},	//   далн, оел_, --, --,
   {{0xd7c9183b,0x443d0223,0x394602d7,0xdb1c017b}},	//   توته_, _ruw_, acos_, _borä,
   {{0x443d2cd0,0x64460093,0x56922123,0x25a60079}},	//   _suw_, íkin, вајт, _baol_,
   {{0x25a60874,0x63b80107,0x39462cd1,0x291f0065}},	//   _caol_, _anvn, ccos_, _tzua_,
   {{0xf1bf2cd2,0xdb1c0132,0xfc3f0176,0x443d0118}},	//   rmál_, _porç, _juí_, _quw_,
   {{0xa2a900b4,0x395f2cd3,0xf1bf0093,0x7dd802d7}},	//   टिल्, _heus_, smál_, _aísl,
   {{0xfc3f0037,0x395f01e4,0xa2e51b50,0x91fd00ec}},	//   _luí_, _keus_, фонд, trāp,
   {{0x25a609c3,0x6721025c,0x7763002a,0x7dd800d5}},	//   _gaol_, _izlj, lanx, _císl,
   {{0x395f2cd4,0x644b2cd5,0xdb1c2cd6,0x7f5e0176}},	//   _meus_, _utgi, _torç, _pepq,
   {{0x7dd801ba,0xe820164f,0x395f2cd7,0x61fd0223}},	//   _píso, यतया_, _leus_, ansl,
   {{0xe7e5007c,0x62880223,0x00000000,0x00000000}},	//   _कतना_, ctdo, --, --,
   {{0x26130279,0x395f2cd8,0xa6af0033,0xd6af0033}},	//   mãos_, _neus_, _কথাট, _কথায,
   {{0x39a601c8,0xfc3f0037,0x9f940421,0x00000000}},	// [2380] _jūsų_, _cuí_, _pää_, --,
   {{0x39a601c8,0x67210c21,0xafdb02ce,0x00000000}},	//   _mūsų_, _ozlj, spør, --,
   {{0x395f009e,0x776301f7,0x7dd103d0,0x00000000}},	//   _beus_, danx, _råsv, --,
   {{0xbcfb0176,0xfc3f0453,0x395f2cd9,0x9f4a0176}},	//   _adéu, _fuí_, _ceus_, libà_,
   {{0x5fd20755,0x395f0bb0,0x39460aca,0x1867151d}},	//   _हवाल, _deus_, rcos_, дачи_,
   {{0x25a62cda,0x2d802cdb,0x7a2300ab,0x9f580453}},	//   _saol_, lgie_, võte, moró_,
   {{0xc7b80028,0x69d800da,0xdb1c013c,0x61fd2cce}},	//   _vnđ_, ëves, _borå, ynsl,
   {{0x395f2cdc,0x746a2cdd,0x26130279,0x69d80029}},	//   _geus_, оров_, dãos_, īves,
   {{0x211d0f17,0xd49a01e0,0x00000000,0x00000000}},	//   _नरेश_, іри_, --, --,
   {{0x1b2100c8,0x395f2cde,0xf1bf0097,0x325400af}},	//   _বলতে_, _zeus_, rmám_, нвор,
   {{0xc7b302b8,0x261303e6,0xdb1c0c61,0xa01b2cdf}},	//   _שבע_, gãos_, _forå, stök,
   {{0x22ac00b8,0x3cff00ab,0xa01b008d,0x00000000}},	//   _věk_, _रखले_, ptök, --,
   {{0x7dd106d7,0x2ca0046a,0x61fd2ce0,0xd83802f6}},	//   _måst, jwid_, rnsl, _kič_,
   {{0x752201a3,0x7dd12ce1,0x2d800345,0x00000000}},	//   _izoz, _låst, egie_, --,
   {{0x40342ce2,0xfc3f0079,0xd838023a,0x660203d0}},	//   терс, _suí_, _mič_, _kjok,
   {{0x2d802ce3,0x66020176,0x386901a0,0xd83800f4}},	//   ggie_, _jjok, šari_, _lič_,
   {{0x395f0443,0xfc3f0023,0x2b4a05f5,0x6e26005f}},	// [2390] _reus_, _quí_, _bfbc_, _dhkb,
   {{0x395f2ce4,0xd8382ce5,0x7e7c01d7,0x7522002f}},	//   _seus_, _nič_, burp, _mzoz,
   {{0x20112ce6,0x395f0310,0xe1ff0831,0x7dd101ff}},	//   mozi_, _peus_, onó_, _båst,
   {{0x20112ce7,0x9f580453,0x66022ce8,0x1dd3074f}},	//   lozi_, boró_, _njok, _सवित,
   {{0x7b670d36,0x6e2d2ce9,0x3869004f,0xd83802c4}},	//   _отве, mmab, éar_, _bič_,
   {{0x48e00083,0x660200c3,0x907c016b,0x6e2d2cea}},	//   বপূর, _ajok, קטוי, lmab,
   {{0x395f1544,0x77630391,0xd8380187,0xe7362701}},	//   _teus_, ranx, _dič_, неш_,
   {{0x442c09a6,0xdcef2ceb,0x20112cec,0xd5b10206}},	//   emd_, _hacı, hozi_, افظ_,
   {{0x25e50302,0x201119c7,0x31602ced,0x601201b4}},	//   जोगी_, kozi_, _reiz_, kæmp,
   {{0x69d901bf,0x28be00be,0xe19000cc,0x28ac018d}},	//   lkwe, ्हरि, _cẳng_, चिरि,
   {{0xd24e07e4,0xb81b0035,0x69d92cee,0x201108a0}},	//   ینی_, _पीएम_, okwe, dozi_,
   {{0x69d92cef,0x7dd8024e,0xbbdc012f,0x66020031}},	//   nkwe, _písm, _यत्क, _gjok,
   {{0x7641121e,0xa3d51583,0x26130183,0xf9da0070}},	//   _huly, _подч, sãos_, פֿטל,
   {{0x7e7c2cf0,0x20112cf1,0x661b2cf2,0x7641018e}},	//   turp, gozi_, lluk, _kuly,
   {{0x442702c9,0xdee60b3b,0xfc3f0392,0x236500f4}},	//   _ihn_, хови, _orís_, malj_,
   {{0xd24e004f,0x76412cf3,0x6da30274,0x6e2d043d}},	//   _اني_, _muly, лиса, gmab,
   {{0x2011070b,0xfce3219f,0x921702b5,0x91fd0029}},	// [23a0] bozi_, гото, _אַזױ_, ksāj,
   {{0xfc3f004f,0x26e50083,0xdb0700e0,0x44270298}},	//   _arís_, _কখনো_, _kajè, _jhn_,
   {{0x661b2cf4,0x7dd10b87,0xdb1c01ba,0xd8380506}},	//   kluk, _påst, _horú, _rič_,
   {{0xceb30bed,0xdb1c01ba,0x69d911e9,0xf8661d67}},	//   _עיר_, _korú, gkwe, евдо,
   {{0x661b2cf5,0x23652cf6,0x6d3b00a5,0x442c2cf7}},	//   dluk, kalj_, _מתכנ, ymd_,
   {{0x76412cf8,0x442703bc,0x66022cf9,0x69d92cfa}},	//   _buly, _nhn_, _sjok, akwe,
   {{0xfc0302ef,0x3b0706e4,0x09e600d4,0x23652cfb}},	//   _спро, _зеро_, _зовн, dalj_,
   {{0x69d92cfc,0xe7f20461,0x7bce00ab,0x661b2cfd}},	//   ckwe, _अगवा_, _hobu, gluk,
   {{0x7bce2cfe,0xb4da0084,0x09e318d9,0xa01b02e2}},	//   _kobu, ठने_, _сотн, stöi,
   {{0x442709ba,0x7bce2cff,0x23652d00,0x224e01ed}},	//   _chn_, _jobu, galj_, _ptfk_,
   {{0xa3b102e4,0x7bce2d01,0x442c0120,0x201103ab}},	//   _ऑफर_, _mobu, rmd_, vozi_,
   {{0x79822d02,0xd2571ca4,0x44270065,0xdb0e017b}},	//   ngow, эць_, _ehn_, _inbä,
   {{0x20110418,0x9f580036,0xe1ff2d03,0xe3b200d1}},	//   tozi_, vorò_, rnó_, _مرغ_,
   {{0x7bce2d04,0x644f248d,0x09dd021a,0x44270341}},	//   _nobu, ície, _मत्य, _ghn_,
   {{0x20110010,0x6e2d0159,0xe28f0037,0x200400a0}},	//   rozi_, tmab, _هذي_, émia_,
   {{0x63aa2d05,0x20112d06,0xdda80012,0xdb1c021d}},	//   _hafn, sozi_, нтул_, _forú,
   {{0x7dd82d07,0x6e2d20d9,0x20112d08,0xa3e4021a}},	// [23b0] _získ, rmab, pozi_, _नता_,
   {{0x63aa00fb,0x7bce058d,0x64421e19,0x660000d7}},	//   _jafn, _cobu, _muoi, hnmk,
   {{0xa0360122,0x9f8f00ab,0xfc3f2d09,0x29d7027d}},	//   _שאתה_, _müü_, _prís_, _uçak_,
   {{0x65622d0a,0x9f58008a,0x77612984,0xdb0e0183}},	//   _neoh, lorð_, _selx, _robô,
   {{0x69d901bf,0x76412d0b,0x98a52d0c,0x991401e0}},	//   rkwe, _suly, тиле, льші,
   {{0x69d91296,0x62980136,0x63aa008a,0x3f83008a}},	//   skwe, _opvo, _nafn, ngju_,
   {{0x236500cd,0xf1c406fe,0xa3e426d4,0x69d92d0d}},	//   valj_, षामन, नसन_, pkwe,
   {{0xceb4168d,0xa2c40de8,0x7bce2d0e,0x44272d0f}},	//   ריק_, िमन्, _zobu, _shn_,
   {{0x661b0f1a,0x23652d10,0x64421e19,0xf8bf0187}},	//   rluk, talj_, _cuoi, _šéf_,
   {{0x9aa40332,0x7641018e,0x7dd80e06,0x91aa0067}},	//   _جمہو, _tuly, _písk, _जोड़े,
   {{0x386d2d11,0xd6db0086,0xb17b177c,0x661b2d12}},	//   _hver_, _эта_, rhån, pluk,
   {{0x99980029,0xa06a2d13,0x38691ada,0x23650207}},	//   _kurš_, мама_, šaru_, salj_,
   {{0x44272d14,0xd1320037,0x91a000e2,0x23650207}},	//   _thn_, شمس_, _chí_, palj_,
   {{0xb4bf02cb,0x3f83008d,0x29f818b0,0xb4cd04ef}},	//   ीही_, ggju_, nčar_, रही_,
   {{0x248d2d15,0x91a00023,0x6fd90211,0x00000000}},	//   ltem_, _thì_, _mìch, --,
   {{0x386d0052,0xbcfb000d,0x7bce0027,0x248d0067}},	//   _over_, _adéq, _sobu, otem_,
   {{0x248d2d16,0x7bce2d17,0x9f580093,0xe7f208a9}},	// [23c0] ntem_, _pobu, borð_, _अगला_,
   {{0x248d2d18,0x7dd80042,0xeafa0180,0x7bce2d19}},	//   item_, _mísi, ورات_, _qobu,
   {{0x386d01d3,0xdb1c009e,0x6f790070,0xb4cd0006}},	//   _aver_, _yorù, _אָרג, रहु_,
   {{0x7bce2d1a,0xe8fa00c3,0x248d06bb,0xfc3f01ef}},	//   _wobu, мле_, ktem_, _isín_,
   {{0xe8942246,0x7bce2d1b,0x6b87009e,0x79820067}},	//   уаль, _tobu, _fcjg, rgow,
   {{0x248d2d1c,0x25ad0e0e,0x386d00ee,0x79822d1d}},	//   dtem_, edel_, _dver_, sgow,
   {{0x386d0122,0x00000000,0x00000000,0x00000000}},	//   _ever_, --, --, --,
   {{0xd90d00e0,0x63aa008a,0xa01b00b5,0x7c3c064a}},	//   _کیه_, _safn, ltöt, _hirr,
   {{0x98a32d1e,0x64422d1f,0x248d2d20,0x18a3021d}},	//   _ките, _quoi, gtem_, _катм,
   {{0x7c3c0484,0x32020038,0x660d2d21,0x25ad0553}},	//   _jirr, enky_, čaka, adel_,
   {{0x386d2d22,0x51f92659,0x7c3c2d23,0xe81b0354}},	//   _zver_, енню_, _mirr, _पीटा_,
   {{0xcb1302b8,0x973c0124,0x64420023,0x91a000e2}},	//   ילת_, _naći, _tuoi, _phí_,
   {{0x248d01f7,0x6abf00a1,0xfc3f0176,0x7c3c01a6}},	//   ctem_, _एप्र, _asín_, _oirr,
   {{0x200500be,0xdb1c01cf,0x7c3c2d24,0x00000000}},	//   õli_, _forø, _nirr, --,
   {{0x929400d8,0x9f580093,0xb5fc0024,0x973c0506}},	//   _сайц, rorð_, _ewġe, _baći,
   {{0x7c3c2d25,0x325301d3,0x443c2d26,0x1b210033}},	//   _airr, _твър, _hiv_, _বললে_,
   {{0x443c2d27,0x7c3c2d28,0xdb050037,0xbddb00f7}},	// [23d0] _kiv_, _birr, rdhí, _lièg,
   {{0x7c3c2d29,0xe7bd0083,0x7c84015a,0x3b540d07}},	//   _cirr, _অত্য, јуте, икур,
   {{0x443c2d2a,0x3a750036,0x248d006c,0x7c3c1901}},	//   _miv_, улер, ztem_, _dirr,
   {{0xe7e51e79,0x443c18ee,0x973c003a,0x00000000}},	//   कसभा_, _liv_, _gaći, --,
   {{0x2003046a,0x851e046c,0x67d52d2b,0x7c3c2d2c}},	//   onji_, _परगट_, лоду, _firr,
   {{0x443c2d2d,0x00000000,0x00000000,0x00000000}},	//   _niv_, --, --, --,
   {{0x6e3d2b67,0x00000000,0x00000000,0x00000000}},	//   _kisb, --, --, --,
   {{0x248d0332,0x443c006d,0x0696004f,0x26c90a78}},	//   ttem_, _aiv_, انية_, ćao_,
   {{0x6e3d2d2e,0x25ad02df,0xb17b022a,0x84580677}},	//   _misb, rdel_, rhål, крэт_,
   {{0x248d2d2f,0x7dd800fb,0x6e3d2d30,0xb17b013c}},	//   rtem_, _vísi, _lisb, shål,
   {{0x200302dd,0x7d1d2d31,0x17f8004f,0x00000000}},	//   dnji_, _lyss, _شركة_, --,
   {{0x64b52087,0x6e3d2d32,0x248d2d33,0x5ed70033}},	//   _محتر, _nisb, ptem_, _ডেভে,
   {{0x443c2d34,0x7d1d0b88,0x20040132,0x00000000}},	//   _fiv_, _nyss, émio_, --,
   {{0x443c01b4,0xa2ab045c,0x75fe0029,0xedd61a95}},	//   _giv_, _जनप्, vīzi, گيرد,
   {{0xdee32d35,0x6e3d2d36,0xf3f0004f,0xe81b0084}},	//   бори, _bisb, _بأن_, _पीछा_,
   {{0x63a12d37,0xdca62d38,0x7c3c2d39,0x443c0124}},	//   leln, лаби, _sirr, _ziv_,
   {{0xa3d70f39,0x7c3c2d3a,0x443c006d,0x69ba0026}},	// [23e0] _सवा_, _pirr, _yiv_, _एफबी,
   {{0x35c50084,0xfc3f004f,0x3d0407b5,0x6e3d02b1}},	//   वाड़, _tsín_, _रखीं_, _eisb,
   {{0x7c3c16c9,0x78a92d3b,0x7d1d0345,0x61e42d3c}},	//   _virr, _asev, _eyss, _klil,
   {{0x63a12d3d,0x7cda00ea,0x8e7b0070,0xa01b2d3e}},	//   heln, _pārā, _אנטה, stöt,
   {{0xb4cd009a,0xd9171728,0x7c3c0484,0x63a12d3f}},	//   रहो_, льш_, _tirr, keln,
   {{0x62812d40,0x63a12d41,0xbddb000d,0xda661301}},	//   kulo, jeln, _pièg, _ماري,
   {{0x63a12d42,0x628100d7,0xab270aec,0x1ae600c3}},	//   deln, julo, _бора_, _совм,
   {{0x443c0d4b,0x45d40836,0xa01b2d43,0x2003003d}},	//   _siv_, роис, ntör, znji_,
   {{0x443c0189,0x69c02d44,0x02dc018d,0x09062d45}},	//   _piv_, _inme, मन्न, _спан,
   {{0x61e42d46,0x443c006f,0x644f0a54,0x63a12d47}},	//   _alil, _qiv_, ícia, geln,
   {{0x443c2d48,0xa01b2d49,0x7bde028b,0xd5af218b}},	//   _viv_, ktör, ikpu, _лс_,
   {{0x15462d4a,0xa01b0086,0x61e4009e,0x31c72d4b}},	//   _седм, ytös, _clil, усов,
   {{0x443c0189,0x20030254,0x6e3d2d4c,0xc10800af}},	//   _tiv_, tnji_, _risb, гэре_,
   {{0x53342d4d,0x62812d4e,0x7d1d2d4f,0x63a10124}},	//   _келт, bulo, _ryss, celn,
   {{0x62812d50,0x20030496,0x539b0122,0x9f3500d4}},	//   culo, rnji_, _ניהו, реві,
   {{0x5d550265,0x20030bde,0x7d1d1ab7,0x61e40211}},	//   ркат, snji_, _pyss, _glil,
   {{0x8f5500d1,0x20031d7d,0x6e3d2d51,0xad9b0093}},	// [23f0] _پنجش, pnji_, _visb, _hjúk,
   {{0x69c02d52,0x6d4d02a2,0x201a012f,0x6e3d00e0}},	//   _anme, scaa, _gkpi_, _wisb,
   {{0x973c00cd,0xa01b00c3,0xdd95005f,0x78a9030d}},	//   _kaću, stös, _каны, _ssev,
   {{0x63a12d53,0xdb070093,0x6e3d0345,0x78a92d54}},	//   zeln, _snjó, _uisb, _psev,
   {{0x79c904e8,0x62812d55,0x383507fa,0xf1bf1e15}},	//   _یوسف_, zulo, андр, lmás_,
   {{0x69c02d56,0x2449008d,0x2d84027d,0x7bde0110}},	//   _enme, _rúm_, _ömer_, ckpu,
   {{0x0f5800a5,0xbddb00a2,0xdb071dab,0xdb1c007e}},	//   ניהם_, _tièd, _kají, _korý,
   {{0x9f5801f4,0x660d008b,0x78a901e8,0x049500d8}},	//   tirë_, čako, _tsev, ароў,
   {{0x63a115bc,0xa78703c5,0x78a90b5e,0xdb0706fe}},	//   teln, _مشاو, _usev, _mají,
   {{0x62812d57,0x61e42d58,0xad9b00fe,0x661901cb}},	//   tulo, _slil, _bjúk, _wkwk,
   {{0x02062d59,0xc7c42d5a,0x973c01f2,0x212900d7}},	//   изон, _усти, _baću, _azah_,
   {{0x63a12d5b,0xdb0701c0,0xa3b50a40,0x3209008c}},	//   seln, _nají, _चोर_, _cjay_,
   {{0x7dd8000c,0x63a12d5c,0x3d04004e,0x62812d5d}},	//   _míst, peln, _रखें_, sulo,
   {{0x62812d5e,0x7dd8024e,0x2d990260,0x24520088}},	//   pulo, _líst, _abse_, _بنوس,
   {{0x316b006a,0xdb0702d7,0x2bc909b4,0x420a00af}},	//   bacz_, _bají, राना, _инко_,
   {{0x260b07a3,0x61e42d5f,0x3a2d00e2,0x00000000}},	//   ावटी_, _ulil, _nhep_, --,

   {{0xab660545,0xf1bf1d8a,0xa01b2d60,0x9f5800e0}},	// [2400] ивал, rmát_, rtör, hiré_,
   {{0xfbdf03bc,0x2cab01f7,0x8b2600d8,0x00000000}},	//   _stêr_, _dscd_, адзе, --,
   {{0x22470602,0xa01b2d61,0x0f7b016b,0x00000000}},	//   _junk_, ptör, _בריל, --,
   {{0x20182d62,0xf2960070,0x22470a8a,0x82960070}},	//   lori_, יכער_, _munk_, ידעס_,
   {{0x9f510279,0xc7c60370,0x69c00019,0x3a2d0118}},	//   lizá_, иски, _vnme, _dhep_,
   {{0x20182d63,0xdb07000c,0x7dd8008d,0x224000be}},	//   nori_, _zají, _vísu, _liik_,
   {{0xb76500d4,0x46670104,0xa5f82d64,0x2247014c}},	//   стій, арым_, леку_, _nunk_,
   {{0xd5b71cba,0x2018001e,0x3a3f0023,0x69c02d65}},	//   ась_, hori_, _giup_, _unme,
   {{0xad9b008a,0x20182d66,0x23670176,0x22470453}},	//   _sjúk, kori_, _benj_, _aunk_,
   {{0x2bc900e7,0x9f580453,0xf743182f,0xf1bf00b5}},	//   राया, biré_, _дефо, ymás_,
   {{0x20182d67,0x0bb70122,0xa6ca004f,0x91fd0029}},	//   dori_, בלים_, _جوال_, ksāt,
   {{0xdb1c25ec,0x05830a7c,0x7dd81eae,0x3a2d0055}},	//   _horó, _душм, _míss, _xhep_,
   {{0x2edf012f,0x2bc90325,0x291f006d,0x20182d68}},	//   नन्त, रामा, _xyua_, fori_,
   {{0xb7f8114e,0x7a2300ab,0xfc3f00d5,0x764800fe}},	//   ्चिम_, võtm, _psím_, _kudy,
   {{0x22470024,0xdb1c04ac,0x5f1a26c6,0x6235029f}},	//   _gunk_, _moró, _मुद्_, _леку,
   {{0xaac701cb,0x5d7800c3,0x23672d69,0x7a3a00fe}},	//   یتان, ийся_, _zenj_, _důtk,
   {{0x61fd1942,0x4095004f,0xdb070187,0x00000000}},	// [2410] misl, _الخر, _vají, --,
   {{0x61fd2d6a,0x3a3f1371,0xdb0e00bf,0xcc250033}},	//   lisl, _siup_, _kabè, বদ্ধ_,
   {{0x24840255,0x2bc9175f,0xdb0e0260,0x291f0118}},	//   humm_, राबा, _jabè, _syua_,
   {{0x32190e7d,0x29d7045e,0x9f5802d7,0x3944013a}},	//   nosy_, _açar_, viré_, _cgms_,
   {{0x7dd80138,0xa8a700c3,0x76480067,0xdb0e0107}},	//   _víst, ррек, _audy, _labè,
   {{0xf77121a0,0x7648004e,0xab841e38,0x9f582d6b}},	//   سات_, _budy, _муск, tiré_,
   {{0x3a3f0034,0x61fd2d6c,0x2ca9016e,0x3a2d055c}},	//   _tiup_, kisl, lwad_, _thep_,
   {{0x61fd2d6d,0x644f2d6e,0x23670124,0x2d8908c7}},	//   jisl, ício, _senj_, ngae_,
   {{0x20182d6f,0x2240007c,0x799b011e,0x7bd52d70}},	//   yori_, _riik_, _ibuw, _kozu,
   {{0x53c90a9f,0x60dd0298,0xdb0e0107,0x22472d71}},	//   угом_, dysm, _babè, _punk_,
   {{0x20182d72,0x216a005c,0x7a23007c,0x442e2d73}},	//   vori_, лини_, võtj, _dhf_,
   {{0x442e0093,0x61fd2d74,0x78bb2d75,0x2bc9021a}},	//   _ehf_, gisl, _kruv, राडा,
   {{0x20182d76,0x63c200b8,0x442e2d77,0x799b089b}},	//   tori_, ávní, _fhf_, _mbuw,
   {{0xd91a0122,0xe8df0019,0xb4e30a44,0x90d5010b}},	//   רושל, _ngọn_, ननी_, іцяч,
   {{0xe29900af,0x20182d78,0x799b2d79,0xdee32d7a}},	//   _сай_, rori_, _obuw, пори,
   {{0x20182d7b,0xfbdf01a5,0xa2c408b0,0x2291006c}},	//   sori_, _quên_, िमर्, mák_,
   {{0xbddb0248,0x7bd501d6,0x2ca9011e,0x6e2f009e}},	// [2420] _sièc, _bozu, gwad_, _dhcb,
   {{0xbddb02e1,0x9f861018,0x20180510,0x6faa03fa}},	//   _pièc, _угод, qori_, _свог_,
   {{0xfe722d7c,0x6c33004f,0xdb0e0118,0x7bd52d7d}},	//   _عدد_, أفلا, _kabé, _dozu,
   {{0xed3600af,0xa2d8021a,0x78bb2d7e,0xed5a02fb}},	//   _гэгэ, महत्, _bruv, _щом_,
   {{0xd7fa059d,0xdb1c2d7f,0x6d46011e,0x25f60026}},	//   лук_, _poró, _igka, एफसी_,
   {{0x2bc9074f,0xa09b0319,0x229100b5,0x78bb2d80}},	//   राणा, ריסט, kák_, _druv,
   {{0x22912d81,0xf76f2d82,0x61fd273b,0x00000000}},	//   ják_, راو_, yisl, --,
   {{0x545402ef,0xfbc90567,0x61fd0391,0x6e242d83}},	//   овит, राथम, xisl, nlib,
   {{0x61fd0076,0x7bd50be2,0x6d46010d,0x92a80035}},	//   visl, _yozu, _mgka, _małż,
   {{0xb2742d84,0x4adc0808,0x03f80274,0x42742349}},	//   олош, _यथाव, рној_, огос,
   {{0x61fd124b,0x7648010d,0x17570d85,0xdb9b1804}},	//   tisl, _uudy, _הסבר_, נסטר,
   {{0xd46a00c9,0x64460093,0x6d462d85,0x6e240009}},	//   _биде_, íkis, _ngka, jlib,
   {{0xdb0705f6,0x682d00a0,0x05c500b4,0xdb0e00fe}},	//   _majá, súde, वारब, _dabé,
   {{0x61fd2d86,0x22912d87,0x6d460103,0x6abc0211}},	//   sisl, bák_, _agka, _orrf,
   {{0x7bd52d88,0x61fd2d89,0x8c000033,0xdd9b2d8a}},	//   _rozu, pisl, ্তান_, лша_,
   {{0x6e242d8b,0xbcfb006c,0x4cd10033,0x7bd52d8c}},	//   glib, _idéz, _সেগু, _sozu,
   {{0xe1ff2d8d,0x7bd50095,0x76421476,0x7bf904d9}},	// [2430] mió_, _pozu, _mioy, анар_,
   {{0xe1ff2d8e,0x2bc90c03,0x6e24018e,0xdb1c0d2e}},	//   lió_, राधा, alib, _enrí,
   {{0x7bd50009,0xa1150088,0x6e2400fe,0xfc3f00ee}},	//   _vozu, _دوکت, blib, _kríz_,
   {{0xe1ff0955,0x78bb2d8f,0xa2ab09b4,0x3ebe035b}},	//   nió_, _pruv, _जनस्, ætte_,
   {{0x7c840ebc,0xeab0006c,0xe0df0107,0x2bc902b4}},	//   _нуре, وٹے_, nyò_, रादा,
   {{0x2bcb0036,0x8bcb00af,0x229100b5,0xd2461301}},	//   _сумо_, _сымб_, yák_, _ين_,
   {{0x99852149,0xdddc082d,0x7522030d,0x00000000}},	//   _ولسو, lurš, _ayoz, --,
   {{0x649928a1,0x22912d90,0x78bb2d91,0x91a90023}},	//   атор_, vák_, _truv, _nhà_,
   {{0xe1ff2d92,0x13e92d93,0xb4e32188,0x764200e0}},	//   dió_, имий_, नने_, _dioy,
   {{0x22912d87,0xdb0e17b8,0x22510187,0xe2910037}},	//   ták_, _sabé, ízko_, وذج_,
   {{0x2329263c,0xe29900ed,0xd5ae00bf,0xd1ca03fa}},	//   рони_, шан_, رفی_, алне_,
   {{0xe1ff2d94,0xbba602e4,0x22911055,0x36340037}},	//   gió_, _ऑस्क, rák_, _فرنس,
   {{0x22912d95,0x661b02ee,0x66092d96,0x00000000}},	//   sák_, mouk, mnek, --,
   {{0xa2e51a24,0x3eb8011c,0x645904fb,0x661b2d97}},	//   _молд, tvrt_, _itwi, louk,
   {{0xdb1c008a,0xe1ff0083,0x7f430b7d,0x6609000e}},	//   _norð, bió_, держ, onek,
   {{0xe1ff2d98,0x644b070b,0x64432d99,0x660917eb}},	//   ció_, _kugi, _hini, nnek,
   {{0x644322fb,0x656b0332,0x6e240f1a,0x4425239a}},	// [2440] _kini, _megh, rlib, oll_,
   {{0x9f580082,0x644b2d9a,0xdb070332,0xdb1c008a}},	//   oirí_, _mugi, _sajá, _borð,
   {{0x44252d9b,0x9d462d9c,0x644b2d9d,0x661b2d9e}},	//   ill_, _менд, _lugi, kouk,
   {{0xa92607c1,0xdddc0c99,0x656b2d9f,0x661b00c3}},	//   одел, burš, _negh, jouk,
   {{0x644b2da0,0x76420118,0xdce6023a,0x9f43008d}},	//   _nugi, _rioy, _kekč, mhjá_,
   {{0x64432da1,0xdb1c0093,0x660901d7,0xe1ff00b5}},	//   _nini, _forð, enek, zió_,
   {{0x644b00d8,0x656b0f1c,0x645904fb,0x98a300c7}},	//   _augi, _begh, _atwi, _ąją_,
   {{0x44252da2,0xd49a1e9f,0x644b19d3,0xe1ff0443}},	//   ell_, аро_, _bugi, xió_,
   {{0x644300a7,0xe1ff0831,0x644b2da3,0x656b2da4}},	//   _bini, vió_, _cugi, _degh,
   {{0x64432da5,0x644b2da6,0x986800b5,0xa2f401e0}},	//   _cini, _dugi, _نیچے_, зпоч,
   {{0xe1ff0831,0xe3b801d6,0x661b2da7,0x644b01ed}},	//   tió_, llık_, bouk, _eugi,
   {{0x64430938,0x644b2da8,0x656b0345,0x44252da9}},	//   _eini, _fugi, _gegh, all_,
   {{0xe1ff0033,0xe3b801d6,0x64430dc5,0x62812daa}},	//   rió_, nlık_, _fini, arlo,
   {{0x64432dab,0xd2500082,0xe1ff0955,0xbddb12c3}},	//   _gini, _كنت_, sió_, _cièn,
   {{0x2bc90930,0x3a262dac,0x2ee50093,0xbddb00e0}},	//   रासा, klop_, álf_, _dièn,
   {{0x63a82dad,0x66002dae,0x644b0526,0x64432daf}},	//   ledn, nimk, _yugi, _zini,
   {{0x62880083,0x64432db0,0x7dd80453,0x25d71804}},	// [2450] ludo, _yini, _vísp, קומן_,
   {{0xa2be111a,0xdddc0121,0x661b03d0,0x00000000}},	//   षिप्, rurš, zouk, --,
   {{0x66002db1,0x67ef0b3e,0x00000000,0x00000000}},	//   kimk, _højg, --, --,
   {{0xdb1c008e,0x2bc900b8,0x66000355,0xda78093e}},	//   _vorð, राहा, jimk, іях_,
   {{0x44252db2,0x998d016f,0x656b2db3,0x66002db4}},	//   yll_, _tiež_, _regh, dimk,
   {{0x63a80254,0x644b2db5,0x656b0036,0x27c700c3}},	//   jedn, _rugi, _segh, ющег,
   {{0xfbd20052,0x644b2db6,0x64432db7,0x64590035}},	//   _אתם_, _sugi, _rini, _stwi,
   {{0x2bc90e1d,0xd5c500dc,0x3a260176,0x7dd103d0}},	//   रावा, वाइज, clop_, _påsy,
   {{0x6443081a,0x656b2db8,0xdb07021d,0x5a44002d}},	//   _pini, _vegh, _enjô, _цэра,
   {{0x656b2db9,0x682d00a0,0x66092dba,0xe2852dbb}},	//   _wegh, búda, snek, плои,
   {{0x44250090,0xdce60107,0x00000000,0x00000000}},	//   rll_, _rekč, --, --,
   {{0x644b2dbc,0x64432dbd,0xe2962dbe,0x00000000}},	//   _tugi, _wini, чаю_, --,
   {{0x64432dbf,0x63a80274,0x7bc701e4,0x645905a8}},	//   _tini, bedn, _onju, _utwi,
   {{0x63a80a69,0x62881298,0xdfd20372,0x00000000}},	//   cedn, budo, ريز_, --,
   {{0xf1bf0082,0x62882cad,0xe7f30006,0x3ebe0093}},	//   mlán_, cudo, _अतना_, ítt_,
   {{0x7bc71221,0xed640187,0x67ef01b4,0x6d4b2dc0}},	//   _anju, drží_, _højd, žgan,
   {{0xdca32dc1,0x32020187,0x00000000,0x00000000}},	// [2460] нати, miky_, --, --,
   {{0x46bd073f,0xa0970319,0x6600048f,0x32020097}},	//   ्माह, _צדיק_, zimk, liky_,
   {{0x3ce6290b,0x34a81cce,0xca7500d8,0x3fdb00a5}},	//   šov_, _कन्द, дучы, _הקיב,
   {{0x8c462b60,0x3202024e,0x63a8004e,0x7bc701a8}},	//   _неме, niky_, zedn, _enju,
   {{0xd7c700a1,0x39402dc2,0x2bc923db,0xe8942dc3}},	//   लांच, äis_, राशा, фаль,
   {{0xdb0e09ab,0xe3b801d6,0x9f582dc4,0x7bc70124}},	//   _habí, rlık_, nirà_, _gnju,
   {{0xfaa32dc5,0x63a82dc6,0xa01b1193,0xfbc90edf}},	//   _паро, vedn, krön, रारम,
   {{0xceb300a5,0x682d0079,0xbb430c46,0xf64f00f8}},	//   תיה_, rúda, _ческ, دئو_,
   {{0x66002883,0x32020097,0x67ef008c,0x18671de4}},	//   rimk, diky_, _bøjd, _нати_,
   {{0x62882dc7,0x6600002f,0x61e60298,0x00000000}},	//   tudo, simk, ekkl, --,
   {{0x63a82dc8,0xa75b0122,0x3202031d,0x9f582dc9}},	//   redn, _הדבר, fiky_, dirà_,
   {{0xdb0e0311,0x628801b4,0x63a82dca,0xb05b01ff}},	//   _nabí, rudo, sedn, nväg,
   {{0x68e22dcb,0x62882dcc,0x2fda01f7,0x7a2300ab}},	//   nyod, sudo, _bopg_, mõtt,
   {{0xf1bf2dcd,0x2d9c00b5,0xa01b00b5,0xe47b016b}},	//   clán_, ővel_, ltöz, _פרוכ,
   {{0x24520019,0xaaab00dc,0xa3b50c57,0xdb0e0168}},	//   _hâm_, _टैंक, _चोट_, _babí,
   {{0xe3b806d0,0x3ebe003e,0xdb0e08cb,0x67ef008c}},	//   ldı_, ætta_, _cabí, _iøje,
   {{0x61ed2dce,0x67ef054e,0x9f582dcf,0xfbc9007e}},	// [2470] _ilal, _høje, birà_, रालम,
   {{0xe3b806d0,0xd6ec0026,0x9f5807e5,0x68e22dd0}},	//   ndı_, जनाथ_, cirà_, dyod,
   {{0x20031977,0x24520028,0x61ed2dd1,0xbd0202a2}},	//   miji_, _lâm_, _klal, _éénm,
   {{0x20032dd2,0x9f582dd3,0xa95401e0,0x00000000}},	//   liji_, mirá_, екці, --,
   {{0x9f580453,0x61ed2dd4,0x67ef0a8a,0x00000000}},	//   lirá_, _mlal, _løje, --,
   {{0x20032dd5,0x7bc705ca,0xb8d513ab,0x32020097}},	//   niji_, _unju, _जन_, ziky_,
   {{0xdce60029,0x9f581c98,0xb8d4007c,0xe7360a22}},	//   _iekā, nirá_, _छै_, меш_,
   {{0x200325d0,0xb9c507f6,0xe4592701,0x3e5800d5}},	//   hiji_, _تقري, ожи_, _učte_,
   {{0x69c92dd6,0xdcfd008f,0xf1bf2dd7,0x200305e2}},	//   _inee, _kası, tlán_, kiji_,
   {{0x61ed22a8,0x20032dd8,0x69c901e8,0x24520019}},	//   _alal, jiji_, _hnee, _dâm_,
   {{0x20032dd9,0x32020076,0x61ed2dda,0x69db2ddb}},	//   diji_, tiky_, _blal, _koue,
   {{0x471a00c2,0x69db1010,0x7e690129,0xd6d80086}},	//   _וועג, _joue, ćepl, _эту_,
   {{0x25091c04,0x69db2ddc,0x057400bc,0x2bb2021a}},	//   _برای_, _moue, _ساند, ीयमा,
   {{0xdcfd0723,0xdb0e0aaf,0xdce60029,0x69db0248}},	//   _nası, _sabí, _nekā, _loue,
   {{0x9f582ddd,0x50432dde,0x69c92ddf,0x67ef008c}},	//   rirà_, терб, _onee, _gøje,
   {{0x69db2386,0x61ed2de0,0x69c901a8,0x00000000}},	//   _noue, _glal, _nnee, --,
   {{0x20030759,0xdcfd008f,0x24520019,0x9f58027a}},	// [2480] biji_, _bası, _xâm_, pirà_,
   {{0x20031851,0x9f582de1,0x69c92de2,0xe50e051d}},	//   ciji_, birá_, _anee, ापति_,
   {{0x69db2de3,0x9f581111,0xfc3f0138,0xdce602d4}},	//   _boue, cirá_, _asís_, _dekā,
   {{0x79a311b9,0xef1701c8,0x0906107b,0xa9670a87}},	//   врше, _імя_, мпен, дица_,
   {{0x7a23007c,0xe3b806d3,0xe9ff0019,0xd6cf00d1}},	//   võtt, ydı_, _giận_, یقه_,
   {{0x68e22de4,0xb05b013c,0x69c9018e,0xe3b800a8}},	//   ryod, sväg, _enee, xdı_,
   {{0x7a2300ab,0x69db000d,0x24522de5,0x7bdc0079}},	//   tõtt, _foue, _sâm_, _ioru,
   {{0x69db2de6,0xc88301d6,0x200315d7,0x67ef03d0}},	//   _goue, üğü_, ziji_, _røje,
   {{0x7bdc2de7,0xe3b800a8,0xdb0e021d,0xdcfd00a3}},	//   _koru, tdı_, _fabã, _yası,
   {{0x88bd004e,0x7bdc03d0,0x00000000,0x00000000}},	//   _myśl, _joru, --, --,
   {{0xe3b80092,0x200305e2,0x7bdc2de8,0x61ed2de9}},	//   rdı_, viji_, _moru, _plal,
   {{0x245200e8,0xd25701c8,0x9f580473,0xdb1c01ff}},	//   _tâm_, ьць_, virá_, _inrä,
   {{0x20030496,0x60f81482,0xdb0e0107,0x00000000}},	//   tiji_, дняя_, _labà, --,
   {{0x9f582dea,0xa2be0808,0x67ef08c8,0x00000000}},	//   tirá_, षिद्, _tøje, --,
   {{0x61ed0453,0xc7b801f2,0xe7e6007c,0xdb15021e}},	//   _tlal, _mađ_, _कवना_, _gazè,
   {{0x63b81217,0x20031851,0x9f582deb,0x61ed034d}},	//   _havn, siji_, rirá_, _ulal,
   {{0x69db0248,0x22980416,0x629a2dec,0xad9b0093}},	// [2490] _roue, lék_, ltto, _djúp,
   {{0x63b802dd,0x7bdc2ded,0xfe710164,0x69c92dee}},	//   _javn, _coru, _مگر_, _snee,
   {{0x69db2def,0xdb0e2df0,0xdcfd027d,0x229800b5}},	//   _poue, _cabà, _vası, nék_,
   {{0x7bdc0107,0xc3330d85,0xdb0e0132,0x629a0421}},	//   _eoru, דוע_, _sabã, itto,
   {{0x18692374,0x07a5097c,0x69db00f6,0xdb1c0282}},	//   чали_, еалн, _voue, _anrä,
   {{0x7bdc2df1,0x63b81123,0x212900d7,0xdb072df2}},	//   _goru, _navn, _myah_, _majú,
   {{0xd6d10c9e,0x26c10311,0x48ff0864,0x00000000}},	//   اقع_, ího_, _शेरो_, --,
   {{0x7bdc01d6,0x2298006c,0x9998010b,0x917a00e2}},	//   _zoru, dék_, _durų_, _mẫu_,
   {{0x7bdc08a1,0x21292df3,0x5436006c,0x63b80a8a}},	//   _yoru, _nyah_, کرٹر, _bavn,
   {{0xf6e72b92,0x2bd20099,0x629a0282,0x63b80139}},	//   _оцен, साया, ftto, _cavn,
   {{0x63b82df4,0xdb15024e,0x21292883,0xe9ff01a5}},	//   _davn, _bazé, _ayah_, _giản_,
   {{0xbbdc0084,0x22492df5,0x70cb2df6,0xe8200380}},	//   _मक्क, _ciak_, ामूल, मकथा_,
   {{0x64a501c8,0x629a0086,0x2bd20099,0x25ad07bd}},	//   _чала, atto, सामा, meel_,
   {{0x212916ab,0x25ad2df7,0x63b808c8,0xdb0e017b}},	//   _dyah_, leel_, _gavn, _inbö,
   {{0x5f1a02e4,0x6da62217,0xada600c3,0x76b300a8}},	//   _मुख्_, нива, навл, _bəyə,
   {{0x7bdc2df8,0x25ad0a45,0x2249011e,0xc1ba07f6}},	//   _soru, neel_, _giak_, _رابط_,
   {{0x7bdc1342,0x76b30095,0x248d2df9,0x1de100b4}},	// [24a0] _poru, _dəyə, nuem_, _नवरत,
   {{0xa09b00c2,0x7bdc01c2,0x25ad0c7c,0x1f662659}},	//   _צייט, _qoru, heel_, _яком,
   {{0x386d0118,0x79a62dfa,0x88bd004e,0x7bdc008a}},	//   _awer_, ерле, _wyśl, _voru,
   {{0x60c42dfb,0xd910042c,0x386d15b1,0xdb0e026e}},	//   _krim, لیز_, _bwer_, _cabá,
   {{0x25ad152b,0x7bdc2dfc,0x317b00a5,0x229800b5}},	//   deel_, _toru, פרסמ, zék_,
   {{0x229803fc,0xdb0e0176,0xe7c70066,0x60c425e8}},	//   yék_, _tabà, लागप, _mrim,
   {{0x63b802dd,0x629a0211,0x386d2dfd,0x2cb2001e}},	//   _ravn, xtto, _ewer_, lwyd_,
   {{0x63b82dfe,0x7af2027d,0x60c42dff,0xaa43021d}},	//   _savn, ıktı, _orim, _бесл,
   {{0x248d2e00,0x2cb20297,0x224910b9,0x60c401cb}},	//   guem_, nwyd_, _riak_, _nrim,
   {{0xa87b0052,0x22980332,0x224927a6,0xa01b06ed}},	//   _מאמר, ték_, _siak_, tröm,
   {{0x60c42e01,0x05662e02,0x21290ac8,0x7c3e0036}},	//   _arim, _звен, _syah_, impr,
   {{0x60c42e03,0x6e260159,0x229800b5,0x629a0234}},	//   _brim, _nkkb, rék_, rtto,
   {{0x60c41886,0x629a2e04,0xd5af27f6,0x229800fd}},	//   _crim, stto, _دفن_, sék_,
   {{0x2cb2001e,0x60c42e05,0x00000000,0x00000000}},	//   dwyd_, _drim, --, --,
   {{0x443e2e06,0x2249046a,0x6e26012f,0x60c42e07}},	//   mmt_, _tiak_, _bkkb, _erim,
   {{0x60c42e08,0x644a2e09,0x7c3e1c98,0x442c2e0a}},	//   _frim, _hifi, empr, lld_,
   {{0x644a2e0b,0x2cb2001e,0x212901cb,0x442c2e0c}},	// [24b0] _kifi, gwyd_, _uyah_, old_,
   {{0xdb0e171c,0x62880036,0xdb1507c0,0x644a007a}},	//   _sabá, ordo, _enzý, _jifi,
   {{0x442c2e0d,0x67ef08c8,0x59bf021a,0x19b90bfc}},	//   ild_, _nøja, _एफआर, дуль_,
   {{0x443e033b,0x644a008d,0xf1bf1534,0x00000000}},	//   hmt_, _lifi, dlák_, --,
   {{0x644a04d6,0x25ad0d26,0x7ae500c3,0x67d501e0}},	//   _oifi, veel_, syht, коду,
   {{0x644a2e0e,0x660201d5,0x07a504bf,0x6e2d2e0f}},	//   _nifi, _amok, такн, llab,
   {{0x79a700d8,0x25ad2e10,0xdb0e2e11,0x00000000}},	//   _прае, teel_, _tabá, --,
   {{0x6e2d0dc3,0x2bc900b8,0x66021980,0x442c2e12}},	//   nlab, राका, _cmok, eld_,
   {{0x8cc4004e,0x6e2d0052,0x25ad11cc,0x62882e13}},	//   रियो, ilab, reel_, erdo,
   {{0xd6db002d,0xf1bf00d5,0xd7f82e14,0x00000000}},	//   _нте_, lláh_, _пух_, --,
   {{0x60c40feb,0x6e2d2e15,0x25ad0b88,0x6d5d2e16}},	//   _srim, klab, peel_, _ofsa,
   {{0x442c01e4,0x443e0110,0xd70d00b4,0x20112206}},	//   ald_, amt_, िपीठ_, enzi_,
   {{0x248d2e17,0xe3ae1b0a,0xdd92103b,0xa879016b}},	//   quem_, _кб_, یوس_, ואָר,
   {{0x60c42e18,0x65692e19,0x6e2d1167,0x644a01d5}},	//   _vrim, lbeh, elab, _gifi,
   {{0x91fd0029,0x6e2d2e1a,0x7a380172,0x2d962e1b}},	//   mpān, flab, líte, крас,
   {{0x6e2d2e1c,0xa6e901a5,0x65692e1d,0x644a01d5}},	//   glab, _trươ, nbeh, _zifi,
   {{0x7a382ac4,0x60c42e1e,0x1d071761,0xa3e50099}},	// [24c0] níte, _urim, вети_, _नवा_,
   {{0xdca3195a,0x2bd2052b,0x2cb2001e,0x6e2d2e1f}},	//   рафи, साधा, rwyd_, alab,
   {{0xee3a2e20,0xeb972e21,0x7c3e037d,0xdce40009}},	//   _оно_, тих_, rmpr, mbič,
   {{0x7c662e22,0x6e2d2e23,0xa96a0036,0x442708c7}},	//   _لاسل, clab, фида_, _lkn_,
   {{0x443e2e24,0x442c2e25,0x26c501d7,0xdce4011c}},	//   ymt_, yld_, _arlo_, obič,
   {{0x66022e26,0x656901ba,0x62880523,0xc8650037}},	//   _smok, ebeh, yrdo, اطني,
   {{0x644a2e27,0xa3d500c0,0x7bce2e28,0x764b2e29}},	//   _rifi, हान_, _inbu, _bigy,
   {{0x644a2e2a,0x44270159,0x6adb0033,0x23690009}},	//   _sifi, _akn_, _যেকো, _đaja_,
   {{0x41d60567,0xd94319b3,0x7a38006c,0x644a1c5b}},	//   धानस, _вети, gíte, _pifi,
   {{0x442c0052,0x38662e2b,0x6e2d0fdf,0x67ef0a8a}},	//   uld_, mpor_, zlab, _højn,
   {{0x442c04e2,0x443e039b,0x764b0332,0xd5af1208}},	//   rld_, rmt_, _figy, _кс_,
   {{0x66022e2c,0xfc3f099e,0xe4a62e2d,0x764b0090}},	//   _umok, _apíl_, _арко, _gigy,
   {{0x644a0cd4,0x7bce0296,0x443e0176,0x00000000}},	//   _tifi, _onbu, pmt_, --,
   {{0x6e2d026e,0x00000000,0x00000000,0x00000000}},	//   wlab, --, --, --,
   {{0x6e2d14d4,0x20110009,0xd3780035,0xdbdc0093}},	//   tlab, rnzi_, mać_, _ráðl,
   {{0xb283004b,0x51870f8f,0x6e2401d7,0x7bce2e2e}},	//   _тышк, _рука, goib, _anbu,
   {{0x31792e2f,0x5d5421be,0xe3b8013b,0x00000000}},	// [24d0] masz_, ркут, llıq_, --,
   {{0x317900f5,0xa3d51fb4,0x6e2d2e30,0xd3780035}},	//   lasz_, हाय_, slab, nać_,
   {{0xf09f2e31,0x16220653,0x78a901ba,0xe3b80095}},	//   ltà_, मवार_, _spev, nlıq_,
   {{0xa01b0093,0xf1bf021d,0x75f500d5,0xd378263f}},	//   fsög, ndá_, _káze, hać_,
   {{0xd378004e,0xf09f2e32,0xa3c82e33,0xbddb00f6}},	//   kać_, ntà_, _लोभ_, _bièv,
   {{0xf09f027a,0xe7392e34,0xdb1c0345,0xd3780067}},	//   ità_, нел_, _marê, jać_,
   {{0x17f30302,0xd378006a,0x9f510033,0x31792130}},	//   _अतीव_, dać_, lizó_, kasz_,
   {{0x26c501cc,0xe3b80095,0xa2d6164f,0x442700fe}},	//   _vrlo_, dlıq_, यमन्, _skn_,
   {{0x65692e35,0x75f501c0,0x78a90187,0x9f5100de}},	//   rbeh, _náze, _upev, nizó_,
   {{0x7a382e36,0x7c2528b0,0x2cb900d7,0xd3780035}},	//   ríte, nohr, _mssd_, gać_,
   {{0x420a15de,0xf09f02fb,0x7a380c5d,0xa91d0254}},	//   енно_, età_, síte, _udžb,
   {{0x28c709b4,0x7a3800b5,0x09b10033,0xf1bf021d}},	//   लिपि, píte, ছাকা, gdá_,
   {{0x7c252e37,0xdb1c2e38,0x03a51126,0x44270088}},	//   kohr, _carê, _било, _tkn_,
   {{0x25bd001e,0x66092e39,0xd3780035,0x00000000}},	//   _hawl_, liek, cać_, --,
   {{0x44252e3a,0x249f008d,0x539a00a5,0x932400f8}},	//   mol_, ltum_, _ניקו, _پرون,
   {{0x44252e3b,0x66090080,0xe1f200bf,0x25bf2e3c}},	//   lol_, niek, _دست_, ndul_,
   {{0xa3c80cea,0xf09f0176,0x2cb900fe,0x00000000}},	// [24e0] _लोड_, ctà_, _cssd_, --,
   {{0x442502c7,0x249f2e3d,0xeb972e3e,0x2d99009e}},	//   nol_, itum_, лиу_, _ecse_,
   {{0xdee62101,0xfbc90e3b,0x7f9b0122,0xc9862d0c}},	//   _сони, राजम, _אביז, гули,
   {{0x44252e3f,0xd3780035,0x249f2e40,0x200a00a8}},	//   hol_, zać_, ktum_, libi_,
   {{0x44252e41,0x7a1c00b8,0xdbd200be,0x7c252e42}},	//   kol_, jčte, _küüs, bohr,
   {{0x44252e43,0x2ca004ca,0xbddb021e,0xa01b0093}},	//   jol_, mtid_, _chèf, rsög,
   {{0x44252e3f,0x09a900c8,0x2ca02e44,0x38662e45}},	//   dol_, ওয়া, ltid_, spor_,
   {{0xd3780755,0x200a06d3,0x249f008d,0x9634052c}},	//   wać_, hibi_, ftum_, јниц,
   {{0x44250297,0x249f2e46,0xd378004e,0x77940220}},	//   fol_, gtum_, tać_, _نیشا,
   {{0x3a261516,0x44252413,0x200a00d7,0xe3b800a8}},	//   loop_, gol_, jibi_, tlıq_,
   {{0xd3780035,0x25bf007a,0x53342e47,0x66092e48}},	//   rać_, bdul_, рент, biek,
   {{0xf09f0133,0xe3b80095,0xd378004e,0x2ca0007c}},	//   ttà_, rlıq_, sać_, ktid_,
   {{0x44252e49,0x3dc0001e,0xf1bf00ac,0xfc3f00d5}},	//   bol_, ddiw_, rdá_, _spím_,
   {{0x44252e4a,0xf09f2e4b,0xc3560133,0x682d0752}},	//   col_, rtà_, _съдъ, túdi,
   {{0xf09f2e4c,0x3a2603c4,0xa36f01ba,0x7c250501}},	//   stà_, koop_, äčši, vohr,
   {{0x270e01c2,0xf09f0176,0x9f510453,0x443c1f8b}},	//   _mən_, ptà_, tizó_, _hhv_,
   {{0x9f4100da,0x1ae20083,0x200a2e4d,0x7c250393}},	// [24f0] _kohë_, _গেলে_, bibi_, tohr,
   {{0x320b0052,0x66092e4e,0x41c300dc,0x9f510453}},	//   licy_, ziek, षयवस, rizó_,
   {{0xa3d52e4f,0xddd001d6,0x9e352e50,0x28c700b8}},	//   हात_, _çeşi, _венч, लिभि,
   {{0x44252e51,0x320b0035,0xdb1c2e52,0x4c950210}},	//   zol_, nicy_, _marè, _кимс,
   {{0x44252e53,0x2ca000e9,0x25bd0051,0xdb1c021e}},	//   yol_, ctid_, _rawl_, _larè,
   {{0xc5ed00b4,0x6609004e,0x25bd001e,0xba77097f}},	//   जस्य_, wiek, _sawl_, _مارت,
   {{0xec360052,0x66092e54,0x44252e55,0x2bd20907}},	//   _כאשר_, tiek, vol_, सारा,
   {{0x249f2e56,0x44252e57,0x270e0095,0xc4850424}},	//   ttum_, wol_, _dən_, алик,
   {{0x44252e58,0x25bf2e59,0x47d50987,0x443c0d24}},	//   tol_, rdul_, _پيار, _bhv_,
   {{0x66092e5a,0x442500e9,0x78bb2e5b,0x7a382e5c}},	//   siek, uol_, _isuv, míta,
   {{0x249f2e5d,0xc5d50131,0x216a0adb,0x64412e5e}},	//   stum_, _віль, кини_, rmli,
   {{0x44250297,0x249f0093,0xb05b013c,0xdb1c00e0}},	//   sol_, ptum_, rvän, _darè,
   {{0x200a00a8,0x04670043,0xdb1c01f4,0xb05b01ff}},	//   tibi_, _стем, _parë, svän,
   {{0x88bd006a,0x248d2e5f,0x44252e60,0xb4fa00a5}},	//   _wyśw, mrem_, qol_, _בפני,
   {{0x645b00c8,0x200a2e61,0x52752192,0xdb1c2e62}},	//   lqui, ribi_, _тулу, _varë,
   {{0xdd922e63,0x06af00c8,0x8e5502ce,0x4d6600d8}},	//   تور_, কিপি, стрі, ркав,
   {{0x248d2e64,0x645b2e65,0xed570c95,0x245b0345}},	// [2500] nrem_, nqui, роу_, _jêm_,
   {{0x907b00c2,0x307b0122,0x2ca00e45,0x272201ba}},	//   _שטיי, _שאינ, rtid_, nčné_,
   {{0x2ca02e66,0x703b0332,0xdb1503e6,0x78bb03a6}},	//   stid_, _جسٹس_, _razã, _asuv,
   {{0x705303c5,0x7ae31535,0xc33200a5,0xb05b013c}},	//   _دنیا, änta, חוב_, kväl,
   {{0x270e0095,0xdb1c2e67,0x3a260a81,0x61e42e68}},	//   _sən_, _maré, roop_, _moil,
   {{0xb2270093,0xdb072e69,0x248d2e6a,0x18670274}},	//   _klæð, _cajó, drem_, шаљи_,
   {{0x645b0d9a,0x5b3500d8,0xdb05033b,0xdb150183}},	//   equi, _гэту, gehä, _vazã,
   {{0xe5c62462,0x248d2e6b,0x61e42e6c,0x443c011e}},	//   рско, frem_, _noil, _shv_,
   {{0x7a380168,0x918300e2,0x69c02e6d,0xdb1c00e0}},	//   cíta, _nếu_, _iame, _sarè,
   {{0x69c22e6e,0xdb1c02e9,0x53e600af,0x245b0345}},	//   ldoe, _parè, рциа, _dêm_,
   {{0x78a22e6f,0x4b7b02b5,0x248d2e70,0x443c055c}},	//   ltov, כטיג, arem_, _vhv_,
   {{0x61e40094,0x248d2e71,0x69c22e72,0x69c00e6d}},	//   _coil, brem_, ndoe, _jame,
   {{0x78a20097,0x69c02e73,0x645b2e74,0x61e42e75}},	//   ntov, _mame, cqui, _doil,
   {{0xf7780069,0xdb070107,0x00000000,0x00000000}},	//   _jeħ_, _majò, --, --,
   {{0x61e4148b,0x69c00012,0x34b60c67,0x9e0712fa}},	//   _foil, _oame, _अनुद, ачал,
   {{0x5d552e76,0x78a22e6f,0xdb0506d7,0x69c02e77}},	//   скат, ktov, nehå, _name,
   {{0x78a22e78,0xbddb00f7,0x69c200e9,0xd7c60099}},	// [2510] jtov, _bièr, ddoe, लयाच,
   {{0x6fb504e8,0xeb930206,0x7a382e79,0x61e402d7}},	//   _امدا, تظر_, víta, _zoil,
   {{0xdb152e7a,0xcf920122,0x69c001d0,0x645b1e6e}},	//   _bazá, _צטט_, _bame, zqui,
   {{0x69c02e7b,0xc9872e7c,0xd7c80088,0x61e401ed}},	//   _came, ружи, یونه_, _xoil,
   {{0xa3c60302,0xf09402b5,0xf1bf00b5,0x645b02d7}},	//   उया_, ַנק_, llás_, xqui,
   {{0x645d2e7d,0xe8f800d8,0x248d0811,0x67f40176}},	//   ísim, шлі_, vrem_, _pàja,
   {{0xc66802cc,0x69c02e7e,0x657b0dc3,0x7a382e7f}},	//   ашње_, _fame, tauh, síta,
   {{0x248d2e80,0x69c02e81,0xff1802b8,0x32090159}},	//   trem_, _game, יקות_, _nmay_,
   {{0x32f70095,0x61e40341,0xf1bf01ba,0x78a22e82}},	//   məyə_, _roil, hlás_, ctov,
   {{0x61e42e83,0x69c01be6,0x248d2e84,0x32090159}},	//   _soil, _zame, rrem_, _amay_,
   {{0x645b00c9,0x61e42e85,0x69c00565,0xdb1c2e86}},	//   squi, _poil, _yame, _paré,
   {{0x245b0370,0xa06a2e87,0x248d2e88,0x682d0079}},	//   _têm_, лама_, prem_, rúdu,
   {{0x61e402e1,0x7056004f,0x68fc00a8,0x201a021d}},	//   _voil, إنسا, _ərdo, _pjpi_,
   {{0x7afe2e89,0x76aa01c2,0x51f600d1,0x64590118}},	//   yzpt, _həya, _گستر, _iuwi,
   {{0x2295004f,0x6459007a,0x52850037,0x61e42e8a}},	//   _العس, _huwi, _البك, _toil,
   {{0x78a2114d,0x64592e8b,0x51f60e3a,0x8cc42e8c}},	//   ytov, _kuwi, _دستر, रिलो,
   {{0x22830723,0x78a2024e,0x64592e8d,0x32f700a8}},	// [2520] lık_, xtov, _juwi, dəyə_,
   {{0x69c0245b,0x628101f2,0x78a20478,0x7e690124}},	//   _same, oslo, vtov, ćepr,
   {{0x6281165e,0xcf570122,0xdcef0029,0x7d0925d2}},	//   nslo, _לבית_, _vecā, _žest,
   {{0xe8fa0104,0x78a21622,0x5ca60012,0x65792e8e}},	//   лле_, ttov, _лимб, _newh,
   {{0x69c22e8f,0xb3b70253,0x17540d13,0x9f4100e0}},	//   rdoe, _असंख, овля, _rohé_,
   {{0x69c019c6,0x78a20bca,0xab2a2e90,0x6283040b}},	//   _wame, rtov, _бога_, _ovno,
   {{0x69c02e91,0x78a22e92,0x76aa0095,0x75f50355}},	//   _tame, stov, _bəya, _sáza,
   {{0x78a22e93,0x2283027d,0x6459067f,0x8a0602d5}},	//   ptov, dık_, _buwi, _узбе,
   {{0x62832e94,0x98b50461,0x7a3800b5,0x62812e95}},	//   _avno, _आईएए, líto, eslo,
   {{0x64592e96,0x9f410118,0x00000000,0x00000000}},	//   _duwi, _wohé_, --, --,
   {{0x02a30ebb,0x00000000,0x00000000,0x00000000}},	//   прям, --, --, --,
   {{0x22402e97,0xa3c800ab,0x00000000,0x00000000}},	//   _chik_, _लोर_, --, --,
   {{0x25b700d1,0x75f500ac,0x224000f8,0x9f4100a0}},	//   _دهند_, _kázn, _dhik_, _dlhý_,
   {{0x765a2e98,0xb4e404ef,0xb4d40099,0x26cc00cd}},	//   _kuty, नही_, हमी_, _krdo_,
   {{0xa3d50726,0x0cd12e99,0x2283027d,0x32f700a8}},	//   हार_, सम्म, cık_, yəyə_,
   {{0x5ebb0083,0x75f500b8,0xf1bf00b5,0x76aa00a8}},	//   _উপদে, _lázn, rlás_, _xəya,
   {{0xc4b622c7,0x13ac0033,0xae0213ab,0x00000000}},	// [2530] _अनोख, _কোয়, रोइन_, --,
   {{0x26cc2e9a,0x3a2d0173,0x442e012f,0x60cd19df}},	//   _ordo_, _skep_, _jkf_, _iram,
   {{0x1dc40240,0xbddb02e9,0x60cd0ce9,0x442e00ee}},	//   _लोकत, _chèc, _hram, _mkf_,
   {{0x60cd2e9b,0x777a01ed,0xdb1c0312,0x67ef008c}},	//   _kram, _aetx, _anró, _tøjk,
   {{0x26cc2e9c,0x75f500d5,0x2283027d,0x777a0a8a}},	//   _ardo_, _bázn, zık_, _betx,
   {{0x765a2d1a,0x26cc0bc6,0x62812e9d,0x60cd2e9e}},	//   _buty, _brdo_, yslo, _mram,
   {{0x7bd52e9f,0x4e0d0066,0xe73900c3,0xcf940070}},	//   _inzu, _सगाई_, шек_, לטס_,
   {{0x7d092ea0,0x60cd2ea1,0x291f0221,0x26c70169}},	//   _þess, _oram, _txua_, rvno_,
   {{0xa3d50af6,0x6aa52ea2,0x41dd0ea3,0xf1dd012f}},	//   हाल_, lthf, यानस, यानन,
   {{0x98170dd2,0x228301d6,0x7bc500bf,0x777a01d7}},	//   _ابرا, tık_, ndhu, _getx,
   {{0x60cd2ea3,0xe9ff0019,0x28c70722,0x765a018c}},	//   _aram, _nhẫn_, लिवि, _guty,
   {{0x60cd2ea4,0x75f50237,0x64592ea5,0x6aa52ea6}},	//   _bram, _zázn, _tuwi, ithf,
   {{0x04c90d4f,0x62812ea7,0x316d20d9,0x24191667}},	//   _خوشي_, sslo, ñeza_, _коды_,
   {{0x628307c0,0x3dc203d0,0x3f9e018d,0xae02021a}},	//   _tvno, _sakw_, ütu_, रोईन_,
   {{0x60cd2ea8,0xe2992725,0x22402ea9,0xd34700d1}},	//   _eram, _тай_, _thik_, _دیده_,
   {{0x60cd2eaa,0x7bd502c9,0xdd1c0187,0x61fd033b}},	//   _fram, _anzu, rážc, chsl,
   {{0x60cd0065,0xdca30e75,0xac0a0279,0x640200e0}},	// [2540] _gram, мати, анаа_, _رژیم,
   {{0x91a6006c,0x7bc52eab,0x602600d4,0x79890090}},	//   _اچھے_, gdhu, _єдна, _adew,
   {{0x2bce02cb,0x75f52eac,0x34b613a0,0x1c391303}},	//   _होणा, _názo, _अन्द, сять_,
   {{0xa3d5056a,0xf1dd022e,0x41dd0ea3,0x7bd5054b}},	//   हाँ_, यायन, यायस, _enzu,
   {{0x2db70122,0x7989001e,0x636600b8,0x7a38006c}},	//   _ולכן_, _ddew, nční, síto,
   {{0x7a380d42,0xdb1c054d,0x75f500ee,0x00000000}},	//   píto, _harí, _bázo, --,
   {{0xf1ca0d53,0x26c30124,0x41dd0355,0x41ca0e61}},	//   ियान, _šjor_, यामस, ियास,
   {{0x2bce04cc,0x95ca2ead,0x63660355,0x00000000}},	//   _होता, рука_, kční, --,
   {{0xdb1c2eae,0xa3d5020d,0xe9ff0019,0x75fc006c}},	//   _marí, हां_, _hiến_, _néze,
   {{0xe9ff0028,0xdb1c01ef,0x765a01a8,0xc34a0328}},	//   _kiến_, _larí, _tuty, ияне_,
   {{0x60cd2eaf,0x6fde2eb0,0x75f500fd,0x00000000}},	//   _sram, मानं, _gázo, --,
   {{0x60cd2eb1,0x442e012f,0xe9ff00e2,0x00000000}},	//   _pram, _wkf_, _miến_, --,
   {{0x845a0279,0x00000000,0x00000000,0x00000000}},	//   _трет_, --, --, --,
   {{0x24860124,0x05a601c0,0xe9ff00e2,0xe3a413cf}},	//   _ivom_, क्रब, _phẫn_, _رشتی,
   {{0x226301ba,0xdb1c002a,0x15ee00ab,0xe29710b4}},	//   ľské_, _barí, _जवार_, _дај_,
   {{0x442c2eb2,0x2d582eb3,0xc333134d,0x02fb0397}},	//   lod_, жить_, _קוק_, _כלומ,
   {{0xa80201d6,0xdb1c0b4c,0x60cd2eb4,0x00000000}},	// [2550] şıyo, _darí, _uram, --,
   {{0x442c2eb5,0xe9ff0028,0x6d5a00a8,0xbddb01da}},	//   nod_, _biến_, _ştat, _dhèa,
   {{0x20112eb6,0xdb1c039f,0x7bc501f4,0x75f500d5}},	//   mizi_, _farí, rdhu, _bázl,
   {{0x248601cc,0x442c2eb7,0x20112eb8,0x6aa5001e}},	//   _ovom_, hod_, lizi_, rthf,
   {{0x442c2eb9,0x7e62219c,0x6e2d0553,0x8dda00a5}},	//   kod_, _čopi, moab, _הקרק,
   {{0x20112eba,0x7bd5033b,0x6e2d01ed,0x00000000}},	//   nizi_, _unzu, loab, --,
   {{0x442c2ebb,0xea63006c,0x69a600b4,0x00000000}},	//   dod_, _آپری, _टॉकी, --,
   {{0x20112ebc,0x9f580036,0x764227d2,0x644812ba}},	//   hizi_, nirò_, _choy, emdi,
   {{0x442c0297,0x201104f7,0x588400d8,0x764200e0}},	//   fod_, kizi_, _жыха, _dhoy,
   {{0x442c149b,0x20110a78,0x24861b89,0x6e2d00cc}},	//   god_, jizi_, _dvom_, hoab,
   {{0x20112ebd,0x232908d9,0xdb070097,0x248600f4}},	//   dizi_, сони_, _objí, _evom_,
   {{0x27340037,0x75fc00f6,0x00000000,0x00000000}},	//   súnú_, _péze, --, --,
   {{0xb81f009a,0x442c2ebe,0xa01b02c9,0x455a0bed}},	//   _बदाम_, bod_, rsön, _הכנס,
   {{0x7fd50131,0x76492c7c,0x442c0987,0x20110b69}},	//   місі, lmey, cod_, gizi_,
   {{0xdb1c2ebf,0x2d8000af,0xdee601e0,0x00000000}},	//   _parí, taie_, чови, --,
   {{0x661b0f67,0xee3a00d8,0x764901d6,0xe1ff2ec0}},	//   nnuk, ёна_, nmey, chó_,
   {{0xdb1c2ec1,0x2011194a,0x2d802ec2,0xd34700d1}},	// [2560] _varí, bizi_, raie_, _دیگه_,
   {{0x2d802ec3,0x76492ec4,0x5ebb0033,0x7a3801ef}},	//   saie_, hmey, _উপরে, rítm,
   {{0xdb1c00ee,0x05bd00a1,0x7a3800b5,0xd5bd01d1}},	//   _tarí, ्याब, sítm, ्याज,
   {{0xc8c702e4,0x442c2ec5,0xdb1c2ec6,0x98a62ec7}},	//   लिंट, zod_, _parâ, зиде,
   {{0x442c121e,0x64430187,0xdb1c0279,0xed5200d1}},	//   yod_, _ohni, _barã, _سپس_,
   {{0xe9ff0028,0x26090084,0xdb0e00b8,0x6d3b00a5}},	//   _tiến_, ़ोसी_, _zabý, _לתכנ,
   {{0x248601cc,0x8c432ec8,0x8cc40026,0xb4d40096}},	//   _svom_, _чере, रिको, हम्_,
   {{0xd49a0dde,0xceb30122,0x442c00e9,0xcb370070}},	//   бро_, גיה_, wod_, _זאלי_,
   {{0x442c2ec9,0x38c80bb4,0x7d042eca,0x2902013c}},	//   tod_, _بازی_, nzis, _åka_,
   {{0x6e2d1945,0x64430341,0xa2f400d4,0x442c0159}},	//   zoab, _chni, дпоч, uod_,
   {{0x64480029,0x20112ecb,0xa1950f16,0xe4da0df3}},	//   rmdi, vizi_, манч, _گوشت_,
   {{0x442c2ecc,0xd25701c8,0x2486044d,0xbbc80167}},	//   sod_, яць_, _tvom_, रयुक,
   {{0x442c2ecd,0x20112ece,0x6443009e,0x00000000}},	//   pod_, tizi_, _fhni, --,
   {{0x1ae200c8,0x7d040035,0x442c009f,0xdb0e00de}},	//   _গেছে_, dzis, qod_, _jabó,
   {{0x63ba2676,0x53332ecf,0x2be0175f,0x20112ed0}},	//   metn, _пешт, नाना, rizi_,
   {{0x63ba067b,0x629a2ed1,0x67ef01b4,0x753d0035}},	//   letn, muto, _højt, ższe,
   {{0x629a2ed2,0x9f58027a,0x7d040409,0x76aa013b}},	// [2570] luto, rirò_, gzis, _səyl,
   {{0x7a38126b,0xf0450609,0xa2d0012f,0x629a08c7}},	//   líth, _تعبی, धिप्, outo,
   {{0x3f8301cc,0xdb1c12c3,0x9f580036,0x53ae0517}},	//   maju_, _carà, pirò_, ज्यश,
   {{0x3f832ed3,0x391500c3,0x63ba006c,0x7aea01ff}},	//   laju_, ммер, hetn, äfta,
   {{0x63ba2ed4,0x48ab107a,0x2bce012f,0x25e00d91}},	//   ketn, стем_, _होवा, कानी_,
   {{0xfe7000f8,0x63ba17ee,0x629a2ed5,0xdb1c0392}},	//   _جدی_, jetn, kuto, _farà,
   {{0x2ca92ed6,0x629a2ed7,0x7649027d,0x661b0553}},	//   ltad_, juto, tmey, tnuk,
   {{0x629a130f,0x7bc72ed8,0x644300fe,0x3f830e31}},	//   duto, _haju, _shni, haju_,
   {{0x2ca92ed9,0x764901d6,0x7bc72eda,0x3f83287d}},	//   ntad_, rmey, _kaju, kaju_,
   {{0x3f8301cc,0x386d2edb,0xdb1c2edc,0x7bc70107}},	//   jaju_, _iter_, _hará, _jaju,
   {{0x7bc72edd,0x3f8301cc,0x629a2ede,0x0cba00df}},	//   _maju, daju_, guto, _उन्म,
   {{0x7bc70e9c,0x2ca92edf,0xdb0e2ee0,0xa91d00cd}},	//   _laju, ktad_, _kabò, _adži,
   {{0xa3c80f9f,0x629a2ee1,0x2be0166b,0x53a52ee2}},	//   _लोक_, auto, नामा, _жалб,
   {{0x63ba18b0,0x3f83235b,0xad9b0176,0xdb0e0042}},	//   cetn, gaju_, _llúd, _xabó,
   {{0xe9ff00e8,0x67ef01b4,0xa5c60067,0xbea32ee3}},	//   _nhắn_, _højs, _wróż, карк,
   {{0x51561578,0xee3a1112,0x3ce001e8,0x386d00f6}},	//   _отпу, іна_, txiv_, _oter_,
   {{0xbc6a0d93,0x3f832ee4,0x7bc72ee5,0x2ca92ee6}},	// [2580] زمان_, baju_, _baju, gtad_,
   {{0x3f832ee7,0x60c42ee8,0x7d042ee9,0xdb1c0443}},	//   caju_, _isim, rzis, _parà,
   {{0xdb1c2eea,0xfbd10332,0xe9ff0019,0x09e60c0d}},	//   _bará, ھتے_, _chắn_, можн,
   {{0x63ba2eeb,0xdb1c1423,0xad9b0037,0x25ad2eec}},	//   zetn, _cará, _clúd, jfel_,
   {{0x307a02b5,0xdb1c2eed,0xdb0e01f7,0x61fd0031}},	//   קאַנ, _dará, _cabò, ërli,
   {{0x60c4000e,0x38cb03fc,0xdb0e021e,0xdb1c0176}},	//   _msim, غانی_, _dabò, _tarà,
   {{0xa3c81033,0x25ad2eee,0x63ba0169,0xe81f0324}},	//   _लोग_, ffel_, vetn, _बदरा_,
   {{0xdb1c2eef,0x60c42ef0,0x629a2ef1,0xfc3f00ac}},	//   _gará, _osim, vuto, _upír_,
   {{0x63ba2ef2,0x7bc72ef3,0x60c41815,0x75fc2ef4}},	//   tetn, _yaju, _nsim, _céza,
   {{0x42742ef5,0xdb1c2ef6,0xb05b033b,0xa3d50084}},	//   нгос, _zará, hwäc, हाग_,
   {{0x63ba2ef7,0x3f830537,0x629a010d,0x65c602f2}},	//   retn, vaju_, uuto, _обжа,
   {{0x629a2ef8,0x63ba0bd1,0x74130609,0x27ec00d5}},	//   ruto, setn, _یونا, _hodn_,
   {{0x3f830a78,0xc5f30122,0x2fda01ef,0x798002d0}},	//   taju_, _בדף_, _bnpg_, _memw,
   {{0x629a2ef9,0x67ef01b4,0xbbc80067,0x7a3800b5}},	//   puto, _højr, रयोक, síth,
   {{0x3f830537,0x60c42efa,0xa01b01ff,0x7bc70dfa}},	//   raju_, _esim, lsök, _raju,
   {{0x2ca92efb,0x7bc72efc,0x3f831e1a,0x79802efd}},	//   ttad_, _saju, saju_, _nemw,
   {{0xe81f017a,0x64582efe,0x3f830254,0x7bc72eff}},	// [2590] _बदला_, _kivi, paju_, _paju,
   {{0x2ca92f00,0x41dd112b,0x2c64013c,0x9f4500b5}},	//   rtad_, यावस, _död_, óló_,
   {{0x2ca92f01,0x62882f02,0x386d11cc,0x23a61fb4}},	//   stad_, nsdo, _ster_, _खानद,
   {{0x64582f03,0xa91d2f04,0xceb202b5,0x7bc7000e}},	//   _livi, _leže, _גיט_, _waju,
   {{0x7bc72f05,0x9f58004f,0x6d5d0008,0x645802c4}},	//   _taju, mhrá_, _igsa, _oivi,
   {{0xf7450043,0x07a206c2,0x75fc01ef,0xb05b2f06}},	//   нело, гашн, _réza, lväs,
   {{0x25ad0012,0x49bb00bf,0x75f500b5,0x199500d8}},	//   tfel_, _وارد_, _házi, _павя,
   {{0xcf5801f3,0x6b850ce8,0x649917d0,0xad9b2f07}},	//   ובות_, lahg, птор_, _flúe,
   {{0x64582f08,0x7a3801dd,0x25ad0d04,0x386d0139}},	//   _bivi, xíti, rfel_, _uter_,
   {{0x87d40088,0xc747017e,0x38a92f09,0x75f500d5}},	//   _لغما, _قضاي, múr_, _mázi,
   {{0x61ed002d,0xa91d008b,0x798004fb,0x25ad033b}},	//   _boal, _deže, _yemw, pfel_,
   {{0x25e000a1,0x64582f0a,0x69cb08f3,0x60c4003a}},	//   काणी_, _eivi, ndge, _psim,
   {{0xe9ff00e8,0x3f812f0b,0x69c90159,0x61ed01b7}},	//   _nhận_, _behu_, _maee, _doal,
   {{0x7a382f0c,0x6d5d13d6,0x6b85012f,0x64582f0d}},	//   ríti, _agsa, jahg, _givi,
   {{0x6e290187,0x6288009e,0xa3c81604,0xa3dc0354}},	//   čebn, csdo, _लोट_, डार_,
   {{0x64582f0e,0x60c42f0f,0x69c90159,0x91fd0029}},	//   _zivi, _tsim, _naee, spār,
   {{0xdd8f18dd,0x60c42f10,0xf65202b5,0x1c461c80}},	// [25a0] صول_, _usim, רצן_, енам,
   {{0x61ed04ce,0x26c500d4,0x69c90176,0x69cb1192}},	//   _zoal, _oslo_, _aaee, edge,
   {{0xdb1c0370,0x8f9b0070,0x2c520107,0x69cb02a2}},	//   _març, _ציטי, _jņdi_, fdge,
   {{0xa9261309,0x4911018d,0x69cb0479,0x5fde0e61}},	//   ндел, _देहो_, gdge, मावल,
   {{0x27fe022e,0x02db06fe,0xb05b01ff,0x27ec02a7}},	//   _pltn_, यमुन, lvär, _podn_,
   {{0x2d8200d7,0xfaa62f11,0x69db01ed,0x69cb0345}},	//   _heke_, _паго, _enue, adge,
   {{0x79802104,0x8f9b02b5,0x7bdc2f12,0x2d822f13}},	//   _temw, ליסי, _inru, _keke_,
   {{0x64582f14,0xc1ca08d1,0xd49a0210,0x49110b35}},	//   _sivi, ियोग, про_, _देवो_,
   {{0x76590297,0xdb1c2f15,0x64582f16,0x2d822f17}},	//   _diwy, _barç, _pivi, _meke_,
   {{0xa01b06d7,0x61ed2f18,0x66e62f19,0x2d822f1a}},	//   rsök, _soal, _поза, _leke_,
   {{0x64582993,0xa3d50084,0x61ed0139,0xa91d0612}},	//   _vivi, हाज_, _poal, _veže,
   {{0x2d822f1b,0x62882f1c,0xb05b01ff,0xdb050079}},	//   _neke_, rsdo, dvär, nfhá,
   {{0x61ed2f1d,0xa91d02f6,0x64582f1e,0x62880408}},	//   _voal, _teže, _tivi, ssdo,
   {{0xdb1c2f1f,0x00000000,0x00000000,0x00000000}},	//   _garç, --, --, --,
   {{0x2d820107,0x00000000,0x00000000,0x00000000}},	//   _beke_, --, --, --,
   {{0xbddb02e1,0xe9ff01a5,0x7bdc01ae,0x8ccd00dc}},	//   _thèm, _phận_, _anru, सिलो,
   {{0x76aa01c2,0x2d822181,0x5d550265,0x3f8100d5}},	// [25b0] _dəyi, _deke_, ткат, _tehu_,
   {{0xb603016f,0xb606011c,0xfe710647,0xf1bf178f}},	//   čšin, lešć, _نگر_, leá_,
   {{0x2013009f,0x22490118,0x62a400d5,0x25a60160}},	//   _imxi_, _khak_, _úroč, _ocol_,
   {{0xe9ff0019,0x38a92f20,0x2d820051,0xbcfb00a2}},	//   _thận_, túr_, _geke_, _agée,
   {{0x69cb0e54,0x4911046c,0x28f801e0,0xf09f01f7}},	//   rdge, _देशो_, нець_, nuà_,
   {{0x38a92f21,0x673a0298,0x00000000,0x00000000}},	//   rúr_, _bytj, --, --,
   {{0x38a90037,0x3d1500a1,0xa91d0168,0x2001009e}},	//   súr_, _नेते_, _bežc, _mlhi_,
   {{0xa91d0b16,0x9b582701,0xb60600cb,0x660d01ba}},	//   _vežb, _чист_, ješć, ďako,
   {{0xc482005f,0xdb1c06d3,0xf1bf016f,0x65692f22}},	//   алык, _parç, deá_, rceh,
   {{0x75f5024e,0x00000000,0x00000000,0x00000000}},	//   _názv, --, --, --,
   {{0xf1dd0429,0xfbd20122,0x41dd0099,0x5694081b}},	//   यांन, בתי_, यांस, _бахт,
   {{0x2249142f,0x15151d13,0xbddb00e0,0x7a3800b5}},	//   _chak_, _идея, _dhèk, sítv,
   {{0x2d822f23,0xd9e30083,0x28c72450,0x22490118}},	//   _reke_, _মতাম, लिटि, _dhak_,
   {{0x35a70299,0x2d822f24,0x395f0159,0xe2990a7c}},	//   _गाड़, _seke_, _lgus_, _жак_,
   {{0x2d822f25,0x8e8300af,0xf77200a5,0x2be01e82}},	//   _peke_, игре, שקל_, नासा,
   {{0xc6920bed,0xf1bf004f,0x395f009e,0x00000000}},	//   יאל_, ceá_, _ngus_, --,
   {{0xb05b022a,0x25b201d6,0xd24f0c74,0x6c360a42}},	// [25c0] rvär, _öyle_, _بني_, نفرا,
   {{0x395f17e7,0xd00f0bdf,0x0e662f26,0xb05b2f27}},	//   _agus_, _ولي_, _икон, svär,
   {{0x76aa0095,0xbad500d8,0x2d820044,0x387f00e0}},	//   _təyi, ліцы, _teke_, _awur_,
   {{0x20182f28,0xb33c0484,0x60d62f29,0x75f500ac}},	//   liri_, ngħa, _krym, _zázv,
   {{0xf1aa1b8f,0x8b6603c7,0x18670610,0x25e00963}},	//   _कानन, _لازم, вачи_, कासी_,
   {{0xe9ff0028,0x20182f2a,0xf1e40084,0x6d462f2b}},	//   _phản_, niri_, गाड़_, _izka,
   {{0x1ae3036c,0xcac72f2c,0x2ca00c7c,0x86c311cf}},	//   _корм, _игре_, luid_, ليون,
   {{0x7c3e2f2d,0x20182f2e,0xbddb0107,0xdb1500ac}},	//   llpr, hiri_, _chèh, _jazý,
   {{0x20182f2f,0xb606042a,0x69d3024e,0x2ca02f30}},	//   kiri_, vešć, ádež, nuid_,
   {{0x25e0065a,0x20182eb8,0x9f5a01f7,0xe9ff0023}},	//   काही_, jiri_, _alpí_, _thản_,
   {{0x201819d3,0xd5a403fc,0x25bf2f31,0xdd2f0355}},	//   diri_, _ملای, beul_, měťo,
   {{0x7a382140,0xdb150187,0x2ca0007c,0x25bf00af}},	//   pítu, _nazý, kuid_, ceul_,
   {{0x20182f32,0x66022f33,0xb6060009,0x3eba2f34}},	//   firi_, _ilok, rešć, _appt_,
   {{0x20182f35,0xdb1703e6,0x3eba012f,0xc95300a5}},	//   giri_, nexã, _bppt_, ימר_,
   {{0x66022f36,0xbe88171d,0x6d4601d7,0xb6060124}},	//   _klok, ксте_, _azka, pešć,
   {{0x443e2f37,0x60d600da,0xe3b000b5,0xd35700a5}},	//   llt_, _frym, _خرچ_, _בשוק_,
   {{0x20182f38,0x60d62f39,0x2ca02f3a,0xf09f0036}},	// [25d0] biri_, _grym, guid_, quà_,
   {{0x629a0176,0x20182f3b,0x61fd000b,0x25bf00af}},	//   orto, ciri_, lksl, zeul_,
   {{0x443e2f3c,0x9999081b,0x497503fa,0x41aa00b4}},	//   ilt_, екет_, глес, _कामस,
   {{0x443e02c9,0x61fd2f3d,0x7c3e2f3e,0x32192f3f}},	//   hlt_, nksl, alpr, nisy_,
   {{0x69342f40,0xa91d2237,0x2be02f41,0x3f870132}},	//   анцу, _beža, नाशा, _ônus_,
   {{0x66022f42,0x7e65012f,0x16a90665,0x00000000}},	//   _alok, _kuhp, евки_, --,
   {{0x7a380332,0xe7360336,0x2be00683,0x25bf00af}},	//   gíts, леш_, नारा, teul_,
   {{0x20182f43,0xe51400be,0x15452f44,0x61fd0051}},	//   ziri_, _तेहि_, лейм, jksl,
   {{0x644a004f,0x629a2f45,0x20180b69,0xe45900af}},	//   _bhfi, erto, yiri_, нжи_,
   {{0x66020086,0x3fce0083,0xede0018d,0x249f00be}},	//   _elok, _রক্ষ, _पच्छ, ruum_,
   {{0x66022f46,0xa2d0035d,0x20182f47,0x7a38002a}},	//   _flok, धिष्, viri_, mítr,
   {{0x20181b68,0x443e2f48,0x00000000,0x00000000}},	//   wiri_, alt_, --, --,
   {{0x20182f49,0x25e004aa,0x657b2f4a,0x629a2f4b}},	//   tiri_, कारी_, mbuh, arto,
   {{0x5ebb0083,0x0492004f,0x443e011e,0x23292f4c}},	//   _উপজে, _الوح, clt_, _поли_,
   {{0x20182f4d,0x4427028b,0x657b011c,0x539a00a5}},	//   riri_, _ijn_, obuh, _טיסו,
   {{0x20182f4e,0x61fd2f4f,0x657b011e,0x2ca000ab}},	//   siri_, cksl, nbuh, tuid_,
   {{0x248d2f50,0xfce30cf9,0x271f2088,0x2be000b8}},	// [25e0] nsem_, бото, यपुर_, नाला,
   {{0x6d4600b8,0x207b0070,0xb05b033b,0x20180031}},	//   _vzka, _ראיא, nwäl, qiri_,
   {{0xdb1c01ef,0x23a600a1,0x657b067f,0x9eaa1b50}},	//   _harú, _खासद, kbuh, _явна_,
   {{0x533602b5,0x3f8a2f51,0x248d2f52,0x6e9b00a5}},	//   אנען_, labu_, ksem_, _אבטח,
   {{0x81ce0083,0xddc40035,0x248d00b8,0x443e2f53}},	//   রাপ_, rmiń, jsem_, ylt_,
   {{0x67d42f54,0xdb152f55,0x66022f56,0x57b3005f}},	//   року, _cazó, _slok, йбіт,
   {{0x66022f57,0x25e00af6,0x6e240553,0x443e08c8}},	//   _plok, काली_, onib, vlt_,
   {{0x7bce2f58,0x3f8a2f59,0x629a01ba,0x657b2487}},	//   _habu, habu_, vrto, gbuh,
   {{0xa91d068b,0x248d00b5,0x660212ba,0x7a382f5a}},	//   _teža, gsem_, _vlok, síts,
   {{0x443e2f5b,0x7bce0e46,0x78a21d13,0x4394052c}},	//   ult_, _jabu, muov, јанс,
   {{0x7bce2f5c,0x81ce0083,0x629a0d35,0x3f850093}},	//   _mabu, রান_, urto, ðlum_,
   {{0x7bce2f5d,0x25e000a1,0xdb1c0079,0x443e2f5e}},	//   _labu, काळी_, _barú, slt_,
   {{0x78a207e5,0x644a0160,0x491a021a,0xdb1c2f5f}},	//   nuov, _thfi, _मेमो_, _carú,
   {{0x7bce2f60,0xcbbf0033,0xbcfb0098,0x00000000}},	//   _nabu, _উচ্ছ, _ngéa, --,
   {{0x32190f86,0xa91d2f61,0xb7db0070,0x68f90067}},	//   pisy_, _nežn, עקלי, zywd,
   {{0x821500b5,0x7bce067f,0x05da0066,0x78a22f62}},	//   _خوبص, _aabu, _मोमब, kuov,
   {{0x3f8a0657,0x7bce2d06,0x69c22f63,0xbcfb2f64}},	// [25f0] babu_, _babu, deoe, _afér,
   {{0x5d542f65,0x26e40035,0xa91d01ba,0x6e24030d}},	//   скут, _कपूर_, _bežn, anib,
   {{0xdb150f56,0x7bce0228,0x5e470037,0xe7fa0a90}},	//   _razó, _dabu, _مضحك, ्सना_,
   {{0x65622f66,0x248d2f67,0xdb150138,0xd36600e0}},	//   _ngoh, ysem_, _sazó, _ژه_,
   {{0xa3d40066,0x22590355,0x00000000,0x00000000}},	//   हया_, írky_, --, --,
   {{0xb8cd00b1,0x96950d54,0xa695192f,0x248d008b}},	//   _कम_, ариш, ариј, vsem_,
   {{0x44270009,0x69c212ba,0x00000000,0x00000000}},	//   _rjn_, beoe, --, --,
   {{0x7bce2f68,0x6b870009,0x442700d7,0xf98800ff}},	//   _zabu, _hejg, _sjn_, _منفي_,
   {{0x81ce00c8,0xccf200c2,0xdb0501ae,0x7d0d002a}},	//   রাম_, ַכט_, gehö, nzas,
   {{0x3ea300da,0x798b2f60,0x248d2f69,0x6b87005f}},	//   kujt_, lagw, rsem_, _jejg,
   {{0x248d2f6a,0x23292632,0xfbcf0083,0xd6db2f6b}},	//   ssem_, тони_, রাপত, _ята_,
   {{0xdb0508f9,0xa06a2f6c,0xc1060037,0x7aea033b}},	//   behö, кама_, لوجي, äfti,
   {{0x3f8a2f6d,0x7d0d2f6e,0x00000000,0x00000000}},	//   tabu_, jzas, --, --,
   {{0x2bd5009a,0x661b00d8,0x8fa600c9,0x6609003c}},	//   _डोला, liuk, јаве, lhek,
   {{0x7bce028b,0x3f8a2f6f,0x539a00a5,0xa22500d1}},	//   _rabu, rabu_, _סיקו, _گروه,
   {{0x3f8a0054,0x75f50187,0x661b010b,0xa91d2f70}},	//   sabu_, _zázr, niuk, _režn,
   {{0xdca6135d,0xed5a00c9,0x7bce2f71,0x3b861a1c}},	// [2600] рази, тоа_, _pabu, илаг,
   {{0x7bce00d7,0x4f962f72,0x9b850c9e,0x64412f73}},	//   _qabu, _триу, مؤمن, nlli,
   {{0x64412f74,0xbf9b0100,0x661b2f75,0xa91d00ee}},	//   illi, _בייש, kiuk, _bežo,
   {{0x7bce2f76,0xe8fa2f77,0xdca6135b,0xbcfb006c}},	//   _wabu, кле_, _ками, _igén,
   {{0x7fe90164,0xe7e22f78,0x7d0d0035,0x660901cb}},	//   _شریف_, पालप, czas, dhek,
   {{0xa91d05e2,0x78a20009,0xdb17002a,0x481301e0}},	//   _težn, ruov, sexá, оміс,
   {{0x2cb2053e,0x29001b29,0xddc40029,0xe5c61353}},	//   ltyd_, šia_, rmiņ, аспо,
   {{0x88810332,0x64410086,0xa01b2f79,0xf64f2f7a}},	//   _کیون, elli, nsör, وئي_,
   {{0x07a61a90,0x75fc0107,0x64410345,0x186a01e0}},	//   _вазн, _jézi, flli, _рази_,
   {{0xf3662f7b,0xe9ff00e8,0x6908037a,0x6441011e}},	//   штин, _phần_, ırdı, glli,
   {{0x7bd902b5,0xa3c50067,0xdb1c008c,0x53342f7c}},	//   אַרק, उज़_, _carø, сент,
   {{0x9f58004f,0x64412f7d,0x66090054,0xd5b003c5}},	//   bhrú_, alli, chek, _رفت_,
   {{0x60020183,0x6a730069,0x00000000,0x00000000}},	//   _cômo, _iħfe, --, --,
   {{0xe9ff0028,0x54330118,0xfe731dbf,0x2005008a}},	//   _thần_, _ورور, قدر_, óli_,
   {{0x543902b5,0x798b2f7e,0x22940037,0x2cb20298}},	//   _געװא, yagw, _البس, etyd_,
   {{0x2cb203bc,0xb7fe0033,0x75fc000d,0xdcfd0160}},	//   ftyd_, ্চিত_, _bézi, _nesă,
   {{0x6b8701f4,0x7c8700c3,0x2cb20b88,0x00000000}},	// [2610] _pejg, рубе, gtyd_, --,
   {{0x60cd2f7f,0x81ce0083,0x3ea30031,0x798b0b13}},	//   _isam, রাণ_, pujt_, wagw,
   {{0xa91d0009,0xdce72f80,0xf09f0392,0x443c188e}},	//   _pežo, ılıd, lrà_, _mkv_,
   {{0xa2d70afa,0x00000000,0x00000000,0x00000000}},	//   यित्, --, --, --,
   {{0x4911004e,0x64412f81,0xe9ff01a5,0x98c72f82}},	//   _देखो_, ylli, _nhấn_, рсел,
   {{0x60cd0054,0x8d5a00a5,0x798b2f83,0x443c0345}},	//   _msam, _תכשי, sagw, _nkv_,
   {{0x66092f84,0xfeca0070,0x7bc52f85,0x661b24a5}},	//   thek, ָמפּ, mehu, tiuk,
   {{0xc4852f86,0x60cd0d5c,0x7bc52f87,0x5bc70e04}},	//   блик, _osam, lehu, _रघुव,
   {{0x999f0187,0xe9ff0019,0xf79500d8,0x661b010b}},	//   _chuť_, _chấn_, _газэ, riuk,
   {{0xf09f2f88,0x66092f89,0xf7700037,0x75f50b4c}},	//   drà_, shek, _قام_, _vázq,
   {{0xd7f818d9,0x60cd2f8a,0x7c220248,0xf09f0382}},	//   _тут_, _asam, éori, erà_,
   {{0x7bc501f4,0xf09f0176,0x64412f8b,0x00000000}},	//   hehu, frà_, slli, --,
   {{0x7e770069,0x798919c1,0x7bc52f8c,0xf09f0176}},	//   _atxp, _meew, kehu, grà_,
   {{0x4385004f,0x183502b5,0x7989030d,0x249f2f8d}},	//   _الثق, מאָל_, _leew, mrum_,
   {{0x60cd2f8e,0x7bc52f8f,0xf09f0310,0xd1380067}},	//   _esam, dehu, arà_, łą_,
   {{0x249f2f90,0x4d66137c,0x79890345,0x629c00ea}},	//   orum_, скав, _neew, šroc,
   {{0x61e42f91,0x1b150083,0x249f2f92,0xa01b01ff}},	// [2620] _inil, _তুলে_, nrum_, rsör,
   {{0x7bc52f93,0xf1bf004f,0x2cb2053e,0x61e400ac}},	//   gehu, nnán_, rtyd_, _hnil,
   {{0x34c40324,0x61e408dd,0x249f05f9,0x201a0159}},	//   _वन्द, _knil, hrum_, _impi_,
   {{0x61f61505,0x994a0037,0xc33200a5,0xf1bf2f94}},	//   _joyl, هلال_, הוב_, hnán_,
   {{0x2d802f95,0x98a31583,0x61f603d0,0x5e57016b}},	//   mbie_, зиче, _moyl, _ליטע_,
   {{0x249f2f96,0x2d802f97,0xdb1e2f98,0x2bb700b8}},	//   drum_, lbie_, lepí, _věcí_,
   {{0xfaa32449,0x05240083,0x66740df3,0x661900d5}},	//   _наро, _পরের_, زگار, _bmwk,
   {{0xe5c60086,0xe9ff0019,0x443c0093,0xe4a6021d}},	//   сско, _phấn_, _skv_, броо,
   {{0x8cdb19b7,0x32ee00a8,0x249f2f99,0xbcfb01cb}},	//   नियो, məyi_, grum_, _ngél,
   {{0x61e42f9a,0xf09f02fb,0x2ca02f9b,0x79892f9c}},	//   _anil, vrà_, irid_, _zeew,
   {{0x249f0176,0x61f62f9d,0x60cd2f9e,0x2d800345}},	//   arum_, _boyl, _ssam, kbie_,
   {{0x64a605d8,0xf09f2f9f,0x201a07e5,0x7bc50051}},	//   _гада, trà_, _ampi_, zehu,
   {{0x7bc5002f,0x3394010b,0x443c2fa0,0xf1aa1365}},	//   yehu, _далё, _tkv_, _कारन,
   {{0x3e6e000c,0xf09f01d3,0x2ca0012c,0x61e4001e}},	//   _být_, rrà_, drid_, _enil,
   {{0xa3d5000c,0x61f62fa1,0x7afe0055,0x32b70079}},	//   ाएर_, _foyl, jypt, _هدية_,
   {{0x60cd2fa2,0x5fad06fe,0xf09f298d,0x2ceb00c3}},	//   _tsam, ञ्जल, prà_, льзо_,
   {{0x60cd2fa3,0x00000000,0x00000000,0x00000000}},	// [2630] _usam, --, --, --,
   {{0xbddb1f10,0x79892fa4,0x7b672fa5,0x00000000}},	//   _chèr, _seew, стае, --,
   {{0x2ca00006,0x7bc52fa6,0x7afe0044,0xb9950105}},	//   arid_, rehu, gypt, قلاب,
   {{0x80cc0083,0x7bc50a8a,0xf1c91604,0xdb1c008d}},	//   ামর্, sehu, िजिन, _farþ,
   {{0x7bc52fa7,0x5fde00b4,0x75fc00b5,0xdcfd0409}},	//   pehu, माचल, _jézu, _besą,
   {{0x4cba0070,0xbddb00f7,0x798901a8,0x249f2fa8}},	//   _דזשו, _thès, _weew, vrum_,
   {{0x41aa2fa9,0x79890159,0x320900d0,0x05da0067}},	//   _कालस, _teew, _olay_, _मोहब,
   {{0xf1d90299,0xb05b01ae,0x32ee00a8,0xa91d0a4c}},	//   _बोलन, swäh, cəyi_, _ježk,
   {{0xdb1e002d,0x61f60282,0x2409081b,0xa3d529ad}},	//   cepâ, _royl, инии_, ाएल_,
   {{0x32092faa,0x249f2fab,0x61e42fac,0x61f60448}},	//   _alay_, rrum_, _snil, _soyl,
   {{0x81ce0083,0x320901f7,0xf1bf2fad,0x2d8017cc}},	//   রাস_, _blay_, rnán_, ybie_,
   {{0x2d8b2fae,0x249f028b,0xcad60122,0x201a0176}},	//   _nece_, prum_, קורת_, _smpi_,
   {{0xa06a2faf,0x05741026,0x628e00b5,0x00000000}},	//   рага_, _راند, ábor, --,
   {{0xee3f01ba,0x61f6012f,0x320905dd,0x3a2d0124}},	//   _aký_, _woyl, _elay_, _ljep_,
   {{0x32090107,0xa91d0168,0x82360312,0x61f62fb0}},	//   _flay_, _bežk, _وربا, _toyl,
   {{0x3d150ccf,0x2d8b2fb1,0x00000000,0x00000000}},	//   _नइखे_, _cece_, --, --,
   {{0x2d8b0274,0xbddb00f7,0xee371112,0x2d801116}},	// [2640] _dece_, _chèq, іну_, rbie_,
   {{0xeb9a0b3a,0x2ca02fb2,0x8b2600d8,0x41aa04aa}},	//   риж_, rrid_, одзе, _काँस,
   {{0x2d8b0382,0xf1bf00b5,0x7d1b003d,0x6ac6097f}},	//   _fece_, knál_, _žust, تقام,
   {{0xa3d5006a,0xfce62fb3,0x752f004e,0x2d8b2c7c}},	//   ाएँ_, _домо, żczy, _gece_,
   {{0x7afe00d5,0x00000000,0x00000000,0x00000000}},	//   sypt, --, --, --,
   {{0xec340609,0x2d8b002d,0xdb1e021d,0x00000000}},	//   _روزگ, _zece_, repâ, --,
   {{0x491a0632,0xdb1c01f4,0x02a81746,0x41aa0835}},	//   _मेरो_, _mbrë, _कमेन, _कांस,
   {{0x16370082,0x7ae10332,0xd5b72830,0xf1bf2fb4}},	//   يسية_, _álta, ось_, gnál_,
   {{0xa3d5006a,0x79822fb5,0x6fca00a1,0x69dd07a6}},	//   ाएं_, mbow, ाजां, _ósea,
   {{0x2240006c,0x78a20124,0x7c2e0124,0x25da00be}},	//   _akik_, mrov, _jjbr, _खोरी_,
   {{0x32092fb6,0xe73a01e0,0x2a64023c,0x00000000}},	//   _play_, _теж_, _kimb_, --,
   {{0x80ac0299,0x6010022a,0x78a215d8,0x00000000}},	//   _जमशे, _jämf, orov, --,
   {{0xd2580a93,0x2d8b2fb7,0xf9930d85,0x78a21321}},	//   юць_, _rece_, ורר_, nrov,
   {{0x32090159,0x600b00ab,0xb4d60a90,0x78a200c7}},	//   _wlay_, _sümb, ाटी_, irov,
   {{0x28d109b4,0x2d8b0393,0xed8b03fa,0x657900f7}},	//   _दैनि, _pece_, исак_, _éché,
   {{0xdb1c01ae,0x31352fb8,0x2a64008c,0x00000000}},	//   _darü, _нейр, _nimb_, --,
   {{0x2d8b2fb9,0x69c60093,0x3169006c,0x7c2b2fba}},	// [2650] _vece_, _ókey, _igaz_, égro,
   {{0x78a20e42,0x9f58008a,0x26de2fbb,0x3a3f01a0}},	//   drov, skrá_, _orto_, _skup_,
   {{0x81ce0083,0xa91d02c6,0x78a22fbc,0x2d8b0124}},	//   রার_, _težk, erov, _tece_,
   {{0x2a64028b,0x3f910254,0x78a22fbd,0xdb1c0138}},	//   _cimb_, lazu_, frov, _aaró,
   {{0x78a20097,0xdb1c2fbe,0xdb150279,0x26de2fbf}},	//   grov, _baró, _razõ, _arto_,
   {{0xf7711b31,0xa91d2fc0,0xa3da05dc,0xdb1c01dd}},	//   رات_, _ježi, _ढोल_, _caró,
   {{0x78a200ac,0xf4200033,0x26de02a7,0x1ab40b00}},	//   arov, নকার_, _crto_, _обря,
   {{0xa91d10a5,0xc4852fc1,0xdce40035,0x7bd52fc2}},	//   _leži, плик, ecię, _hazu,
   {{0x629c043f,0xdb1c18b5,0xf1bf2fc3,0x799b030d}},	//   áron, _abrè, rnál_, _iduw,
   {{0xa91d2fc4,0xe7b500b4,0xb68600b5,0x442e021d}},	//   _neži, _आउटप, _کھول_, _cjf_,
   {{0x7bd52fc5,0x3f9101a3,0xf7700372,0x386d0a8a}},	//   _mazu, dazu_, _شال_, _huer_,
   {{0xdb1c0035,0x06c30083,0xad9b1529,0x00000000}},	//   _zaró, ্মদি, _flúi, --,
   {{0xa91d03c9,0xad9b0037,0x386d02d7,0x442e023a}},	//   _beži, _glúi, _juer_, _fjf_,
   {{0x2ca9022e,0x386d01e9,0x316901ed,0xdb1c0260}},	//   duad_, _muer_, _egaz_, _marò,
   {{0x25ad00e9,0x6d4f0453,0xdee32695,0x78a200ee}},	//   ogel_, _azca, нори, zrov,
   {{0x386d0173,0x799b00bf,0x75fc0118,0xe9ff00e2}},	//   _ouer_, _nduw, _hézr, _thẹn_,
   {{0x7bd52fc6,0xed5703e6,0x602600af,0x00000000}},	// [2660] _bazu, зот_, _ндиа, --,
   {{0x7bd50012,0x91a800b5,0x3f910223,0x60c40371}},	//   _cazu, _انکے_, cazu_, _ipim,
   {{0xf1bf0187,0x7bd52fc7,0x00000000,0x00000000}},	//   znám_, _dazu, --, --,
   {{0xdb1c0392,0x25ad0009,0x386d2be5,0x38c802fd}},	//   _barò, jgel_, _buer_, قاتی_,
   {{0x2d922fc8,0x79820035,0xdb1c2fc9,0xdce40035}},	//   maye_, rbow, _paró, ycię,
   {{0x386d2fca,0x2d922fcb,0x25ad2fcc,0x799b0176}},	//   _duer_, laye_, egel_, _eduw,
   {{0xdb1c0300,0x386d033b,0x60020183,0x00000000}},	//   _varó, _euer_, _cômi, --,
   {{0x78a22fcd,0x25ad2fce,0x2d922fcf,0x386d033b}},	//   prov, ggel_, naye_, _fuer_,
   {{0x386d0176,0x7bd52fd0,0xb4d621fe,0x98a32fd1}},	//   _guer_, _yazu, ाटे_, _пите,
   {{0x2d920010,0x6d46028b,0xd776004f,0xdb1c259e}},	//   haye_, _myka, _رائع, _abré,
   {{0xa91d2fd2,0x600b01c2,0x2d922fd3,0x60c42fd4}},	//   _reži, _nüma, kaye_, _apim,
   {{0xb05b0110,0xe7e0073f,0xa91d02a7,0x00000000}},	//   hwät, _गोता_, _seži, --,
   {{0x2d922f59,0x463b0070,0x3f912fd5,0x92cc0033}},	//   daye_, _פעדע, tazu_, রমে_,
   {{0x545300d4,0xf48700e0,0x644f13dd,0x60100523}},	//   _звіт, _راهی, ïcit, _nämd,
   {{0x7bd51851,0x645a00fb,0x7c3e1384,0x69c001ba}},	//   _razu, mmti, dopr, _obme,
   {{0x443e2fd6,0x2d920232,0xfbd301cb,0x6d4603bc}},	//   lot_, gaye_, کتر_, _byka,
   {{0x423802da,0xa91d10ec,0x7bd52fd7,0x443e2583}},	// [2670] _מנהל_, _teži, _pazu, oot_,
   {{0x443e2fd8,0xf09202da,0x442c2fd9,0x69c0033b}},	//   not_, _שני_, nnd_, _abme,
   {{0x2d922fda,0x7bd50043,0x64480349,0x442c2fdb}},	//   baye_, _vazu, ildi, ind_,
   {{0xa2a400c0,0x7bd52f10,0x2d9201d5,0xdb1c2fdc}},	//   _किन्, _wazu, caye_, _parò,
   {{0x443e2fdd,0xddc40dac,0x89370082,0x386d0370}},	//   kot_, lmiş, أعضا, _quer_,
   {{0xd3660082,0x443e0080,0x7c3e2fde,0xf7450171}},	//   _له_, jot_, copr, мело,
   {{0x443e2fdf,0x6e2d2fe0,0xddc4008f,0x69dd07a6}},	//   dot_, onab, nmiş, _óseo,
   {{0x6e2d2fe1,0x442c2e12,0x644811cc,0x386d0a1a}},	//   nnab, end_, eldi, _tuer_,
   {{0x629802fb,0xdb1c0093,0x442c008a,0x69cb2fe2}},	//   _avvo, _harð, fnd_, mege,
   {{0x443e2fe3,0x69d92fe4,0x69cb16be,0x2d922206}},	//   got_, ldwe, lege, zaye_,
   {{0x81d70083,0xdb1c008a,0x2d92251e,0xd1ca1c36}},	//   সান_, _jarð, yaye_, олне_,
   {{0x69d90b19,0x644806a2,0x442c2fe5,0x645a0479}},	//   ndwe, aldi, and_, amti,
   {{0x20040370,0x6e2d001e,0x2fca009e,0x51550dd0}},	//   êmio_, dnab, tebg_, етру,
   {{0x443e2fe6,0x2d922fe7,0x81ce0083,0x6e2d0024}},	//   cot_, waye_, রাই_, enab,
   {{0x7f430086,0x2d922fe8,0x7c3e19be,0x69cb2fe9}},	//   верж, taye_, vopr, kege,
   {{0x6e2d2fea,0x76492feb,0xfce60009,0xd6cf03d0}},	//   gnab, nley, мобо, ттi_,
   {{0x7c3e2fec,0x2d922fe8,0x60c41982,0x69d900e5}},	// [2680] topr, raye_, _upim, ddwe,
   {{0x6d460187,0x2d922fed,0x7e6600d7,0x69d90345}},	//   _vyka, saye_, _wikp, edwe,
   {{0x600b007c,0x76492fee,0x62811b71,0x6d460035}},	//   _kümn, kley, nplo, _wyka,
   {{0x69cb2fef,0x6b8e06a2,0x443e2ff0,0x6d462ff1}},	//   gege, _webg, zot_, _tyka,
   {{0x443e2ff2,0x442c2cce,0x8d770088,0x2fc1028b}},	//   yot_, ynd_, _تاپا, _ybhg_,
   {{0x8cdb00b4,0x6e242ff3,0x656b027a,0x69d90298}},	//   निरो, liib, _aggh, adwe,
   {{0x443e2ff4,0xdb1c008a,0x69cb2ff5,0x6b6300d8}},	//   vot_, _garð, bege, _акра,
   {{0xd49a0de3,0xceb30122,0x442c2ff6,0x765b0159}},	//   оро_, דיה_, wnd_, gmuy,
   {{0x443e2ff7,0x7d040273,0x64a303e6,0x26c5018d}},	//   tot_, nyis, вања, _eplo_,
   {{0x442c2ff8,0x6e2d2ff9,0x656b2b28,0x9f5a0031}},	//   und_, znab, _eggh, _copë_,
   {{0x443e2ffa,0x442c2ffb,0xe57a01c8,0xa91d0293}},	//   rot_, rnd_, _дзе_, _dežu,
   {{0x443e2ffc,0x20ca02e4,0x7d040086,0x84ea186e}},	//   sot_, िबंध, kyis, _وفاق_,
   {{0x6e242ffd,0x92be0033,0xdb1e194e,0x62810298}},	//   diib, ঁটে_, lepä, aplo,
   {{0x764001ef,0x69cb2ffe,0xdb1e0279,0x443e0c6f}},	//   lomy, zege, cepç, qot_,
   {{0x15f20026,0x69cb2fff,0x81d70033,0x69d9016e}},	//   _आचार_, yege, সাব_, ydwe,
   {{0x76403000,0xddc40463,0xc3330122,0x6e24010d}},	//   nomy, rmiş, _שוק_, giib,
   {{0xd904042c,0x69cb3001,0xdc550166,0xe9ff055c}},	// [2690] _ئی_, vege, евањ, _chẽn_,
   {{0x69cb3002,0x6e2d3003,0x9f890093,0x764901fb}},	//   wege, snab, _góðu_, zley,
   {{0x69cb3004,0x76403005,0x7649027d,0x6e24030d}},	//   tege, komy, yley, biib,
   {{0xdb1c008a,0x7640004e,0xdddd0035,0x7d0404fb}},	//   _varð, jomy, _wisł, byis,
   {{0xf1c1018d,0x69d93006,0x9996006c,0x7d16004e}},	//   ष्यन, rdwe, رپور_, czys,
   {{0x78ab03c4,0x9f5a0260,0xd76300b5,0x3e75017b}},	//   rugv, _bopè_, نچای, _kåt_,
   {{0x76493007,0x69cb3008,0xcb440279,0x00000000}},	//   tley, pege, _ахти, --,
   {{0xb8d500c8,0x6ec20066,0x76402ed0,0xf1c1022e}},	//   _জন_, _लहसु, gomy, ष्मन,
   {{0x3e75022a,0x76493009,0xe7e0074f,0xf1bf0079}},	//   _låt_, rley, _गोवा_, dfá_,
   {{0x7649300a,0x62810b0d,0x37071c20,0x7c25300b}},	//   sley, tplo, _очев, nihr,
   {{0x7649300c,0x3e75013c,0xc7d600a5,0x0ece0067}},	//   pley, _nåt_, _רועי_, _हैंड,
   {{0x6281300d,0x7d160067,0xf676016b,0xdcef0228}},	//   rplo, yzys, _װײסט_, _cecī,
   {{0x05960580,0x644301ed,0xa3b718da,0x70ca01c0}},	//   _سانگ, _tkni, _छाप_, िबेल,
   {{0x25bf300e,0x3e75014e,0x6609177e,0x62810523}},	//   lful_, _båt_, lkek, pplo,
   {{0x6e240273,0x846402fb,0x00000000,0x00000000}},	//   tiib, _ръце, --, --,
   {{0x7d0403ad,0xee3a02ce,0x6441300f,0xa2a43010}},	//   tyis, їна_, loli, _कित्,
   {{0x4425148b,0xdca31c1b,0xbc6a0427,0x25bf07ee}},	// [26a0] oil_, лати, سمان_, iful_,
   {{0x7d16006a,0x44253011,0x6e243012,0xf1c1012f}},	//   rzys, nil_, siib, ष्ठन,
   {{0x34bd021a,0x387f3013,0xa3b704ef,0xad9b08bf}},	//   ्बुद, _atur_, _छान_, _clús,
   {{0x64413014,0x4425134c,0x7d0401d5,0xf99212de}},	//   holi, hil_, pyis, ابا_,
   {{0x64413015,0x25bf016e,0x4973010b,0x00000000}},	//   koli, dful_, уліс, --,
   {{0x44253016,0x64413017,0xf09300a5,0x00000000}},	//   jil_, joli, ננו_, --,
   {{0x64413018,0x0cd00437,0x76403019,0xa3b30722}},	//   doli, _हनुम, tomy, टलन_,
   {{0xdb1e00ab,0x4425301a,0xd90d00b5,0xcb67010b}},	//   repä, eil_, _ڈیم_, _часе_,
   {{0xddde0080,0xf8d407b5,0x20d60207,0xdb1e2119}},	//   _atpū, _धनिय, nžić_, sepä,
   {{0x4425301b,0x64410297,0x600b0463,0x7640018c}},	//   gil_, goli, _cüml, somy,
   {{0x53342f19,0xa3b601c0,0xdb1c301c,0x60d6301d}},	//   тент, ङ्ग_, _obrí, _asym,
   {{0x4425066a,0xad9b0176,0x6609301e,0x3e750a8a}},	//   ail_, _llúr, ckek, _råt_,
   {{0xc05b00d4,0xf1bf0079,0x2906301f,0x27fe3020}},	//   зів_, rfá_, nyoa_, _kotn_,
   {{0x44253021,0x64413022,0xdb1c0b06,0x20d60254}},	//   cil_, coli, _abrí, džić_,
   {{0x9f3403d0,0x80c40033,0xdd9500d8,0x00000000}},	//   гері, শিষ্, кавы, --,
   {{0xb05b0523,0xe7e70775,0x629a190f,0x931200fd}},	//   ktäg, _टोना_, msto, _لوڈش,
   {{0x629a3023,0x61ed3024,0xd2f8006c,0x301500d8}},	// [26b0] lsto, _inal, _رکھا_, _адпр,
   {{0x600b3025,0x629a02ee,0x00000000,0x00000000}},	//   _kümm, osto, --, --,
   {{0xd01100f5,0x61ed3026,0xe9d90035,0x7c253027}},	//   _ملک_, _knal, _paź_, rihr,
   {{0x64413028,0x629a3029,0xdbd7073c,0xe8090fbf}},	//   zoli, isto, _sääs, वस्थ_,
   {{0xdbd7087a,0x4425302a,0xfd960bed,0x6441302b}},	//   _pääs, yil_, _בדרך_, yoli,
   {{0x629a25e5,0x442501c2,0x2ca90523,0x25bf0f00}},	//   ksto, xil_, mrad_, wful_,
   {{0x629a0a78,0x4425302c,0xdb1c021d,0x66092933}},	//   jsto, vil_, _barõ, tkek,
   {{0x4425302d,0x2ca909c3,0x78a40254,0x6441302e}},	//   wil_, orad_, šiva, woli,
   {{0x629a016f,0x25bf1fc9,0xa3ac0099,0x00000000}},	//   esto, rful_, गलं_, --,
   {{0x69db0291,0x2b9c01c0,0x629a008a,0x64581d53}},	//   _haue, mácí_, fsto, _chvi,
   {{0x15b90409,0x2ca90187,0x6441302f,0x25bf0069}},	//   _жылы_, hrad_, roli, pful_,
   {{0x44253030,0x2ca93031,0x412a0d13,0x60d6008c}},	//   sil_, krad_, домо_, _psym,
   {{0x44253032,0x6606006c,0x69db033b,0x2fda0027}},	//   pil_, ökke, _maue, _papg_,
   {{0x7fd50804,0x69db3033,0x64a2031a,0x2ca93034}},	//   лісі, _laue, _таша, drad_,
   {{0xa0673035,0x629a3036,0x539a00a5,0x61ed0069}},	//   тара_, csto, _חיצו, _fnal,
   {{0x645801d2,0xf1bf3037,0x657b00d7,0x3ea506c9}},	//   _zhvi, lián_, ncuh, álta_,
   {{0x2ca90759,0x4cca0083,0xdd8f1062,0x3b960836}},	// [26c0] grad_, রিভু, زول_, вјет,
   {{0x61ed3038,0x62860c99,0x81ce0033,0xaf060369}},	//   _znal, ćkov, রাও_, _апол,
   {{0x69db01ae,0x00000000,0x00000000,0x00000000}},	//   _baue, --, --, --,
   {{0xa2a4020c,0x69db2ddc,0x2ca9007c,0xfaa300d8}},	//   _किस्, _caue, brad_, рацо,
   {{0x69db22dd,0xa96705f2,0xd7fa0395,0xe9ff055c}},	//   _daue, вица_, дуй_, _chằn_,
   {{0xbcfb0332,0x3f983039,0x629a303a,0xdb2100a0}},	//   _egés, naru_, ysto, štát,
   {{0x48ee006a,0x59dd303b,0x629a303c,0x5b3500af}},	//   _आपको_, _नोकर, xsto, _бэту,
   {{0x7bdc303d,0xe5c6303e,0x3f98303f,0x76593040}},	//   _haru, тско, haru_, _chwy,
   {{0x260300c8,0x3f9802d4,0x7bdc0a12,0x629a3041}},	//   _años_, karu_, _karu, wsto,
   {{0x7bde2069,0x629a3042,0x7bdc3043,0x61ed011c}},	//   ndpu, tsto, _jaru, _snal,
   {{0x7bdc3044,0x81dc00c8,0x629a3045,0xddcd00d5}},	//   _maru, ঠান_, usto, blaň,
   {{0x7bdc3046,0xa5263047,0x3f933048,0xe8df00e2}},	//   _laru, _имед, _sexu_, _uyển_,
   {{0x629a3049,0x3f98304a,0xf1bf304b,0x9f4600e2}},	//   ssto, faru_, bián_, _đoá_,
   {{0x629a0313,0xf1bf002a,0xb4be07b5,0xc953024b}},	//   psto, cián_, ँझी_, שמש_,
   {{0x5f94304c,0x81ce0083,0xc43400b5,0xbcfb0118}},	//   рист, রাজ_, _لکھت, _ngér,
   {{0x2ca9304d,0x7bdc304e,0x61ed304f,0xdda80043}},	//   trad_, _aaru, _unal, ктул_,
   {{0x68e23050,0x7bdc08a0,0xdb1c0176,0x5d5514a1}},	// [26d0] jvod, _baru, _abrà, укат,
   {{0x7bdc3051,0x600b0092,0x9b950b8d,0x69db3052}},	//   _caru, _mümk, الات, _saue,
   {{0xba740037,0xca7400ce,0x69db3053,0xb4ce073f}},	//   لانت, لانغ, _paue, शबु_,
   {{0xc3330052,0xb05b06d2,0x2ca901ba,0x601001ff}},	//   בוע_, städ, prad_, _jämn,
   {{0x80d93054,0x7bdc3055,0x7659001e,0x621c0070}},	//   मिटे, _faru, _rhwy, וואק,
   {{0x7bdc3056,0x6010022a,0x38bb0298,0xed58010b}},	//   _garu, _lämn, rêr_, _шоў_,
   {{0x8cdb00dc,0xaa673057,0xa2a4022e,0x7659016e}},	//   निको, _атак, _किष्, _phwy,
   {{0x7bdc1075,0x3f982577,0x6010013c,0xb4ce0084}},	//   _zaru, zaru_, _nämn, शबू_,
   {{0x7bdc3058,0x291901ff,0x245900a2,0xddde0160}},	//   _yaru, _åsa_, hème_, _lupş,
   {{0x6b950254,0xa2a40026,0x87d718dd,0x22490118}},	//   _jezg, _किश्, _جغرا, _akak_,
   {{0x3f983059,0xe7f01fb4,0xf1bf219d,0x6b95305a}},	//   varu_, चारा_, rián_, _mezg,
   {{0xa3e3065a,0x7999046a,0x3f98305b,0x6b950088}},	//   _पोर_, naww, waru_, _lezg,
   {{0x425500af,0x00000000,0x00000000,0x00000000}},	//   ртэт, --, --, --,
   {{0x6b952a9f,0x705607f6,0x2a6d033b,0x6002021d}},	//   _nezg, انسا, _lieb_, _cômp,
   {{0xdb1c114d,0x6da60439,0x3f98305c,0x04560037}},	//   _obrá, лива, raru_, _حلوة_,
   {{0x7bdc305d,0x3f98305e,0x2bc60035,0x22490118}},	//   _saru, saru_, र्ना, _gkak_,
   {{0x6b95305f,0x1bea021d,0x3f983060,0x629c0bca}},	// [26e0] _bezg, ндаи_, paru_, árov,
   {{0xb05b00c3,0xd0f700a5,0xdb1c3061,0x00000000}},	//   ttäe, _עמית_, _abrá, --,
   {{0x81d70083,0x2a6d035f,0x6b950395,0x09e61f62}},	//   সার_, _bieb_, _dezg, ложн,
   {{0x7bdc3062,0x02b60070,0xe94700b5,0xad9b00ee}},	//   _waru, טלעך_, گرمی, _ulúp,
   {{0x7bdc3063,0xa3b300a1,0x69c23064,0x00000000}},	//   _taru, टला_, rfoe, --,
   {{0xd6da0b46,0xa2a41451,0x68e20282,0x600b00a8}},	//   ети_, _किल्, rvod, _cümh,
   {{0x96f8027a,0x394d00a5,0xfd500023,0x2a6d021d}},	//   тейт_, _eyes_, _nghẹ, _fieb_,
   {{0xa5bd010b,0x00000000,0x00000000,0x00000000}},	//   liųj, --, --, --,
   {{0x27ef000c,0x62830009,0x75fc00fd,0x00000000}},	//   ální_, _atno, _kézz, --,
   {{0xd90d0088,0x1cbb0070,0x22490a8a,0x00000000}},	//   _تیه_, עמיע, _skak_, --,
   {{0x2bc60d91,0xa6862afc,0xfbc600b8,0xe9ff0019}},	//   र्या, _след, र्यम, _chặn_,
   {{0x54e61d05,0xa2d50066,0xf1bf0097,0xdb05033b}},	//   _مستق, _बनर्, ciál_, pfhö,
   {{0x75d31902,0xbf0d0de8,0x00000000,0x00000000}},	//   _دينا, सन्न_, --, --,
   {{0x2bc60266,0xddd015d7,0xfbc60ea3,0xc5bc0033}},	//   र्मा, _češk, र्मम, _অফটপ,
   {{0x6e950cd0,0x66023065,0xe1ff00b5,0x00000000}},	//   рибу, _kook, tmód_, --,
   {{0x66020006,0xfc240083,0x62881674,0x2459000d}},	//   _jook, বকোষ_, mpdo, rème_,
   {{0x82340609,0x2bc6175f,0x200100ab,0xfbab3066}},	// [26f0] _دروا, र्भा, _tohi_, етей_,
   {{0x66020052,0x6fb2004e,0x60cd11e9,0xbd68037c}},	//   _look, _जाएं, _ipam, урсе_,
   {{0xdddc00cb,0xf09f0176,0x00000000,0x00000000}},	//   sprš, lsà_, --, --,
   {{0x6602030d,0x2bc60d1f,0xfde905e7,0x394d3067}},	//   _nook, र्बा, _ऑफिस_, _pyes_,
   {{0x02d10355,0x0ff8006c,0x26cc02d7,0x6b953068}},	//   _तन्न, _شعیب_, _apdo_, _tezg,
   {{0x60cd3069,0x6010306a,0x80ad021a,0xd70503d0}},	//   _mpam, _näml, _जिने, изли,
   {{0x6602306b,0xe571004f,0xc9870812,0x00000000}},	//   _book, يطة_, _бузи, --,
   {{0x7aea01b4,0x6602306c,0x1b1e0033,0x7bc50223}},	//   æfte, _cook, _বুকে_, lfhu,
   {{0xf1bf0076,0x84590132,0x6602306d,0xc7d902fb}},	//   riál_, крот_, _dook, _имах_,
   {{0x291d08c7,0xe4c80079,0x00000000,0x00000000}},	//   mzwa_, ابين_, --, --,
   {{0xfbd20122,0x60cd01cb,0x85b90043,0x2d9b0031}},	//   חתי_, _apam, _алес_, kaqe_,
   {{0x016607b4,0xb34501f7,0x86220088,0x998f00c7}},	//   икно, _alçà, _وکيل, mogų_,
   {{0x291d306e,0xe0d701d3,0x2018099e,0x69c901a8}},	//   nzwa_, авя_, thri_, _mbee,
   {{0x249f306f,0x6e2600d7,0x66023070,0x68e90118}},	//   msum_, _smkb, _zook, _mred,
   {{0x44d60755,0x2d96019e,0x249f3071,0x66020103}},	//   _zł_, ирас, lsum_, _yook,
   {{0x0d863072,0x68e93073,0x249f00be,0x7e6f02d7}},	//   рлан, _ored, osum_, _cicp,
   {{0x249f3074,0x0c261a09,0xfce308d9,0x8fa60beb}},	// [2700] nsum_, аман, оото, _капе,
   {{0x69c90273,0x81d70033,0x60101b7a,0x515b00a5}},	//   _abee, সাঃ_, _kämm, _בכפו,
   {{0xdef901c8,0xf1eb0299,0xf778003c,0x69c9073a}},	//   _быў_, _जोड़_, _naħa_, _bbee,
   {{0x68e924ec,0x69c92cd7,0xb05b013c,0xda65004f}},	//   _bred, _cbee, ptäc, ماني,
   {{0x68e92e7b,0x60103075,0x3e7c0023,0x7e641c37}},	//   _cred, _lämm, _hít_, mmip,
   {{0xb8ce3076,0xb8fe0299,0x44270dc3,0x66023077}},	//   _कि_, _तन_, _nmn_, _sook,
   {{0x68e93078,0x7aa3034b,0xfaa33079,0x2bc604e9}},	//   _ered, _мирз, _маро, र्णा,
   {{0x68e92bf2,0x2d80307a,0x35f4307b,0x3e7c01c0}},	//   _fred, ncie_, спир, _mít_,
   {{0xfbc60355,0x68e9307c,0x2bc603de,0x3e7c307d}},	//   र्थम, _gred, र्था, _lít_,
   {{0x5fb2009a,0xe3b80ec4,0x4427307e,0x2a7800be}},	//   _जागल, lnız_, _cmn_, _kurb_,
   {{0x2d80307f,0x68e9076e,0x660200be,0x3e7c00e2}},	//   kcie_, _zred, _took, _nít_,
   {{0x2bc60567,0x2ca00006,0x2d80004e,0xfbc6112b}},	//   र्ता, ksid_, jcie_, र्तम,
   {{0x6010017b,0x442705be,0x25a63080,0x00000000}},	//   _täml, _fmn_, _idol_, --,
   {{0x2d80004e,0x24863081,0x3e7c0019,0x2ca000ab}},	//   ecie_, _itom_, _bít_, dsid_,
   {{0xf09f3082,0x442c3083,0x6d4f3084,0x00000000}},	//   ssà_, mid_, _syca, --,
   {{0x442c3085,0x518703c6,0xef190035,0x131700a5}},	//   lid_, _тука, ąż_, _כחול_,
   {{0x60cd3086,0x442c3087,0x7e6f0160,0x00000000}},	// [2710] _upam, oid_, _vicp, --,
   {{0x442c3088,0x7e7702d7,0x46a707b5,0x1fa708ce}},	//   nid_, _tuxp, _गिलह, _триг,
   {{0x68e90fd5,0x2bc60567,0x25a63089,0x7e6400e0}},	//   _sred, र्धा, _odol_, bmip,
   {{0x68e9308a,0x6448308b,0x442c308c,0x2d80027a}},	//   _pred, hodi, hid_, ccie_,
   {{0x442c308d,0x2ca0308e,0x2486006d,0xb9c4004f}},	//   kid_, csid_, _ntom_, تقني,
   {{0x6e2d308f,0x68e93090,0xe7393091,0x2bc60e61}},	//   liab, _vred, лел_, र्दा,
   {{0x442c3092,0x7d0d3093,0x2a783094,0x68e93095}},	//   did_, lyas, _gurb_, _wred,
   {{0x249f006d,0x68e91b2f,0xdb160037,0x6e2d3096}},	//   tsum_, _tred, _ócái, niab,
   {{0x68e902dd,0x7d0d3097,0x2d993098,0x442c3099}},	//   _ured, nyas, _mese_, fid_,
   {{0x64481bfc,0x249f309a,0x6e2d309b,0x2d99309c}},	//   godi, rsum_, hiab, _lese_,
   {{0x249f309d,0x8c1a0122,0x2d800035,0x7d0d309e}},	//   ssum_, רותי, ycie_, hyas,
   {{0x2d99309f,0x442c30a0,0x22162f19,0x249f0207}},	//   _nese_, aid_, сфор, psum_,
   {{0x442c30a1,0x442730a2,0xddc6011c,0x644830a3}},	//   bid_, _tmn_, _nikš, bodi,
   {{0x7d0d1d33,0x661b012f,0x644830a4,0xc8790225}},	//   dyas, lhuk, codi, _muş_,
   {{0x81bf00c8,0x2d9930a5,0xddc6010b,0x600b00a8}},	//   ীয়_, _bese_, _aikš, _nümu,
   {{0xf2d202b5,0x2ca0007c,0xdb170279,0x2d990300}},	//   _זעה_, tsid_, nexõ, _cese_,
   {{0x2d99043f,0x2d8030a6,0x7d0d006c,0x6e3600d8}},	// [2720] _dese_, rcie_, gyas, rnyb,
   {{0xe7e7007c,0x80ad0edf,0x2d800035,0x2ca00a47}},	//   _टोला_, _जिते, scie_, rsid_,
   {{0x2ca000ab,0x2d80042f,0x6e2d30a7,0x2d990031}},	//   ssid_, pcie_, biab, _fese_,
   {{0x6e2d30a8,0x442c30a9,0x753d0035,0x2d99053e}},	//   ciab, zid_, ższy, _gese_,
   {{0x28f830aa,0xdb1e006c,0x661b01cb,0x91bb00a5}},	//   рель_, lepü, dhuk, רמני,
   {{0xf09300a5,0xc87930ab,0x00000000,0x00000000}},	//   לנד_, _duş_, --, --,
   {{0x64480888,0x24860fdb,0x07a300ed,0x09e62f26}},	//   vodi, _stom_, чајн, _ловн,
   {{0x442c30ac,0xd5ba30ad,0x661b02b3,0xf1bf00b5}},	//   wid_, уск_, ghuk, riák_,
   {{0x442c30ae,0x38cb03c5,0xa3b30099,0x07a60009}},	//   tid_, _مالی_, टलं_, _газн,
   {{0x6e2d30af,0x3e41010b,0x248600ac,0x79820067}},	//   ziab, mėte_, _vtom_, lcow,
   {{0x644830b0,0x95ca00d4,0x78a20523,0x51f9093e}},	//   rodi, _була_, lsov, анню_,
   {{0x442c0ccf,0x26de30b1,0x661b0657,0xdb1e0035}},	//   sid_, _isto_, chuk, lepó,
   {{0x644830b2,0x2d990dc6,0x442c30b3,0x248601ff}},	//   podi, _rese_, pid_, _utom_,
   {{0x2d9930b4,0x442c2ea2,0x3f9a00e7,0x7d0d0883}},	//   _sese_, qid_, _cepu_, vyas,
   {{0x533330b5,0x2d9930b6,0xdef80bbc,0x59c8083f}},	//   _нешт, _pese_, быт_, रभार,
   {{0x7d0d30b7,0x31350812,0x443c0a8a,0x00000000}},	//   tyas, _мейр, _hjv_, --,
   {{0x2d9930b8,0x6e2d30b9,0x443c1505,0xdb9930ba}},	// [2730] _vese_, riab, _kjv_, ивач_,
   {{0x224b30bb,0x6e2d30bc,0x2d9930bd,0x7d0d30be}},	//   lock_, siab, _wese_, ryas,
   {{0x7d0d30bf,0x2d9930c0,0x6a730069,0x3ad50a42}},	//   syas, _tese_, _aħfr, تياز,
   {{0x224b0107,0x13e10033,0xddc600ea,0x78a20051}},	//   nock_, বায়, _tikš, fsov,
   {{0x26de01b7,0x6e3d30c1,0x7d0d00a8,0x2bc60efa}},	//   _asto_, _ijsb, qyas, र्हा,
   {{0x6d5d00ea,0x186930c2,0x00000000,0x00000000}},	//   _izsa, шали_, --, --,
   {{0x661b00d1,0xb05b0086,0x2a660221,0x6fac0026}},	//   thuk, ytän, bmob_, _जयसू,
   {{0xc48530c3,0x34a903fa,0x060930c4,0x7bd730c5}},	//   олик, авио_, рник_, lexu,
   {{0x2bc6164f,0x26de00c8,0xfbc60931,0xe3b10125}},	//   र्वा, _esto_, र्वम, ورد_,
   {{0x661b30c6,0x42c90a80,0x799b03bc,0x00000000}},	//   shuk, агон_, _heuw, --,
   {{0xd7f801a5,0x3f9a0478,0xb05b0086,0x290f30c7}},	//   _khăn_, _repu_, ttän, lyga_,
   {{0xb68600b5,0xd5dd0067,0x00000000,0x00000000}},	//   _بھول_, _मसिज, --, --,
   {{0x03a5027a,0xb05b30c8,0x00000000,0x00000000}},	//   _дило, rtän, --, --,
   {{0xb05b30c9,0x799b022e,0x248d0af9,0x6e3d0c6f}},	//   stän, _leuw, mpem_, _ajsb,
   {{0xdee330ca,0x7bd70139,0x248d0132,0x3f6a0ef3}},	//   мори, dexu, lpem_, риво_,
   {{0xe1ff1111,0x799b033b,0xd7f80023,0x78a400f4}},	//   lmón_, _neuw, _nhăn_, šivi,
   {{0xad6600bf,0x3f9a30cb,0xafe630cc,0x00000000}},	// [2740] زاره, _tepu_, _допл, --,
   {{0x6b561956,0x61e630cd,0xc1050594,0x78a20009}},	//   отех, ldkl, _روپي, vsov,
   {{0x61e4134c,0x2bc6143a,0xe6b800b4,0xfbc60355}},	//   _kail, र्षा, _इमेज, र्षम,
   {{0xd7f80019,0x3eb830ce,0x78a230cf,0xdcfd00c7}},	//   _chăn_, murt_, tsov, _nesė,
   {{0xe89417e0,0x2d92203d,0xc7ba00d8,0x6b9e0159}},	//   чаль, mbye_, аёй_, papg,
   {{0x76aa2b05,0xacd900c2,0x2cb20297,0xb0b20006}},	//   атив_, _פֿרי, mryd_, _जिनग,
   {{0x26de0036,0x7bce009f,0xa01b00c3,0x28da0067}},	//   _qsto_, _ibbu, mpöt, _मैरि,
   {{0x78ad01cc,0x6b9c30d0,0x2bc601c0,0x2bd80066}},	//   šava, _herg, र्रा, ड़वा,
   {{0x07a60390,0x6b9c007c,0xdb070107,0x7aee08b7}},	//   _маан, _kerg, _adjè, _hrbt,
   {{0x6b9c30d1,0x3eb800da,0x136a224a,0xdb1c0279}},	//   _jerg, kurt_, ишни_, _acré,
   {{0x61e430d2,0x26de0009,0x4b7b0070,0x04fa0033}},	//   _bail, _usto_, יטיג, ইনের_,
   {{0x61e430d3,0x201a1f26,0x6b9c0282,0x00000000}},	//   _cail, _alpi_, _lerg, --,
   {{0x61e430d4,0x660f00a6,0x6b9c00e5,0x7bce0103}},	//   _dail, öcke, _oerg, _obbu,
   {{0xcbd500c8,0x3eb830d5,0x6b9c30d6,0x224b055c}},	//   _হচ্ছ, furt_, _nerg, sock_,
   {{0xdd9b2264,0x61e430d7,0x93cb00b5,0x3ea500b5}},	//   иша_, _fail, _خانہ_, élt_,
   {{0x61e430d8,0x3ead086d,0x7bce0484,0x2cb200e9}},	//   _gail, čet_, _abbu, fryd_,
   {{0x2fd830d9,0x6b9c30da,0xc05b02ce,0x40352695}},	// [2750] berg_, _berg, _він_, _неис,
   {{0xa2a4018d,0x6b9c30db,0x61e406a2,0x69c00197}},	//   _किञ्, _cerg, _zail, _acme,
   {{0x6b9c30dc,0x0a6b30dd,0x23c20534,0xb05b00c3}},	//   _derg, арди_, _शानद, ntäm,
   {{0x69c00ea5,0x9f410097,0x2cb200e9,0x6b9c2069}},	//   _ccme, _nahé_, bryd_, _eerg,
   {{0x6b9c30de,0x6d5d2143,0xa2a100e7,0xd9450279}},	//   _ferg, _uzsa, _कौन्, џели,
   {{0x6b9c30df,0x3abb00bf,0xa69504bf,0x66e50009}},	//   _gerg, _پاسخ_, приј, зока,
   {{0x09c20083,0x4e0f0026,0x29020176,0x199530e0}},	//   োয়া, _सवाई_, _àkan_, _навя,
   {{0xd6ce004f,0x6b9c06a2,0x6b8500e9,0xbcfb00e0}},	//   اقي_, _zerg, lchg, _izéb,
   {{0x6d4301ae,0x69d930e1,0x61e430e2,0x6b9c0a21}},	//   ßnah, mewe, _rail, _yerg,
   {{0x69d930e3,0x942200c3,0x6b850523,0x61e403e9}},	//   lewe, емье, nchg, _sail,
   {{0x81e500c8,0xef20004e,0xc7c40d13,0xb05b013c}},	//   নান_, ążki_, _юсти, rtäl,
   {{0xb05b06d7,0x614603e6,0x628a02d7,0xcb12016b}},	//   stäl, зема, _dtfo, גלט_,
   {{0x61e430e4,0xf99200a5,0x61e630e5,0x26c7003d}},	//   _vail, ערך_, rdkl, ltno_,
   {{0xb4d70f39,0xdff5010b,0xa06a005f,0x00000000}},	//   ाबी_, мясь, сага_, --,
   {{0x63a130e6,0x61e430e7,0x26c702dd,0x69d930e8}},	//   maln, _tail, ntno_, kewe,
   {{0x261830e9,0x2cb2053e,0xbc760037,0x61e40719}},	//   _léon_, tryd_, كهرب, _uail,
   {{0x69d90a75,0x224000e0,0xee3701e0,0x721b00a5}},	// [2760] dewe, _ijik_, їну_, _לוקח,
   {{0x63a130ea,0x26c70496,0xdce60029,0x3eb80527}},	//   naln, ktno_, _iekļ, purt_,
   {{0x6b9c0a2e,0x9f9700a5,0xc9862aff,0x78b90051}},	//   _verg, _מדיה_, пули, euwv,
   {{0x69d90b3c,0xe8fa30eb,0x32090019,0x63a130ec}},	//   gewe, йле_, _xoay_, haln,
   {{0x63a10169,0x6b9c0f1a,0xc5c30083,0x41c106fe}},	//   kaln, _terg, ্যাপ, ष्टस,
   {{0x63a10bc6,0xfaa630ed,0x25a00a69,0x7e7e30ee}},	//   jaln, _наго, _žil_, _kupp,
   {{0x7c2e30ef,0x69d91a4f,0x8c1b0122,0xbb4300c3}},	//   _imbr, bewe, _פולי, _зерк,
   {{0x44f40f28,0xbb3b02b8,0xda100066,0xb4d71365}},	//   дпис, _העלי, _ावित_, ाबू_,
   {{0x63a130f0,0x1dce022e,0x81e50033,0xaa430036}},	//   faln, ह्यत, নাম_, _четл,
   {{0xb05b03ad,0x22810093,0x32090211,0x7e7e0523}},	//   ttäm, _bók_, _soay_, _oupp,
   {{0x316030f1,0xe1d902ce,0xae1c0066,0xd5af1309}},	//   _aziz_, одні_, नसान_, _пс_,
   {{0x63a100ab,0xb05b00c3,0x250b0416,0xa19412ea}},	//   aaln, rtäm, _گرمی_, наюч,
   {{0xd6250082,0xf1a4010b,0xb05b30f2,0x7c2e30f3}},	//   _تعلي, эрэн, stäm, _ombr,
   {{0x63a130f4,0x00000000,0x00000000,0x00000000}},	//   caln, --, --, --,
   {{0x442e30f5,0x628a30f6,0x69d930f7,0x998600d5}},	//   _imf_, _utfo, yewe, dnož_,
   {{0xc33300a5,0x2bcf022e,0x433b00a5,0x7e7e0b41}},	//   _רוק_, स्ना, _לעוב, _dupp,
   {{0x69d900ee,0x5d55027a,0xb4ca00ab,0xb05b30c8}},	// [2770] vewe, фкат, _ऊहो_, ntäk,
   {{0x69d930f8,0xf778007a,0x7e7e0b3e,0x6f030176}},	//   wewe, _daħk_, _fupp, _ànco,
   {{0x34d90311,0xd7f801a5,0x6b8501ae,0x442e30f9}},	//   _भन्द, _chăm_, rchg, _mmf_,
   {{0xf1bf30fa,0x63a130fb,0x7c2e30fc,0x6b85033b}},	//   ngá_, zaln, _embr, schg,
   {{0x7e7e07e5,0x37e5073e,0xed51026b,0x69d916a3}},	//   _zupp, долг, _شھر_, rewe,
   {{0x69d930fd,0xf7710118,0x78ad0506,0x00000000}},	//   sewe, پات_, šavo, --,
   {{0x63a1108a,0xb05b0086,0x69d90103,0x00000000}},	//   valn, ttäj, pewe, --,
   {{0x6010022a,0x26c7068b,0x63a10035,0x00000000}},	//   _hämt, rtno_, waln, --,
   {{0x26c702c6,0xf2b60033,0xb4d7046c,0x00000000}},	//   stno_, _জনগণ, ाबे_, --,
   {{0x52a930fe,0x6010013c,0xb05b00c3,0x7d020421}},	//   овом_, _jämt, stäj, äosi,
   {{0x63a130ff,0x2bcf0c67,0x387f02e6,0xfbcf3100}},	//   raln, स्या, _huur_, स्यम,
   {{0x63a13101,0x387f3102,0x7e7e3103,0x600b00be}},	//   saln, _kuur_, _rupp, _sümp,
   {{0x7e7e3104,0xe44e3105,0x63a13106,0xa5bd00d8}},	//   _supp, _аж_, paln, siųs,
   {{0x2281008a,0x2bcf0e68,0xa2d80f09,0x387f03c4}},	//   _tók_, स्मा, _फैक्, _muur_,
   {{0x41c60035,0x2240022e,0x00000000,0x00000000}},	//   _वापस, _tjik_, --, --,
   {{0x25bf3107,0x316001ed,0x00000000,0x00000000}},	//   ngul_, _tziz_, --, --,
   {{0xdca33108,0xed5700c9,0x387f002f,0x7e7e3109}},	// [2780] кати, дот_, _nuur_, _wupp,
   {{0x8d630086,0x7e7e310a,0xf1bf2fba,0xbcfb00b5}},	//   твуе, _tupp, biás_, _széc,
   {{0x78a90133,0x78ad264f,0x0e66310b,0x53cf0b35}},	//   _avev, šavl, _окон, त्यश,
   {{0x387f310c,0xd378011c,0x8b650427,0x81e50033}},	//   _buur_, meće_, رالم, নাথ_,
   {{0xd3780b16,0x02da08b6,0xb4d70387,0x00000000}},	//   leće_, _बन्न, ाबो_, --,
   {{0xd7f801a5,0x387f152b,0x368a01e0,0x6d46009f}},	//   _thăm_, _duur_, осин_, _ixka,
   {{0x6a8303e6,0x660b0b3e,0xd37800f4,0x7e66005f}},	//   _алса, _bogk, neće_, _khkp,
   {{0x973c03fd,0x25bf04f6,0xd5b000b5,0x3ced0124}},	//   _neće, ggul_, اہش_, _ševi_,
   {{0xe3ce0028,0x47c603fa,0x442e1606,0x7c3e310d}},	//   _dựng_, _обав, _pmf_, onpr,
   {{0x7863002d,0x7c3e1b04,0x25bf0395,0x00000000}},	//   _акуз, nnpr, agul_, --,
   {{0x0bb70052,0xd37803fd,0xe2f801e0,0x625d021d}},	//   ולים_, jeće_, чені_, béol,
   {{0xd3780a78,0x442e2955,0x00000000,0x00000000}},	//   deće_, _wmf_, --, --,
   {{0x442e310e,0x00000000,0x00000000,0x00000000}},	//   _tmf_, --, --, --,
   {{0x6562273b,0xdb1c310f,0x8ca20035,0x7c3e0223}},	//   _izoh, _acrí, गठनो, jnpr,
   {{0xe6dc007c,0x660b006d,0x7687027d,0x443e3110}},	//   _मनोज, _yogk, _kıya, mnt_,
   {{0x645a0297,0xf1d001a5,0x6010033b,0x80da0461}},	//   llti, _hạng_, _sämt, _पैके,
   {{0x443e01a6,0x2d58093c,0xf4bc0083,0x645a0051}},	// [2790] ont_, дить_, _অনুব, olti,
   {{0x443e3111,0x00000000,0x00000000,0x00000000}},	//   nnt_, --, --, --,
   {{0x443e3112,0xf1c60302,0xf1d00028,0x387f007c}},	//   int_, _वामन, _mạng_, _suur_,
   {{0x443e02c9,0xdb1c0037,0xf1d00019,0x321903bc}},	//   hnt_, _gcrí, _lạng_, nksy_,
   {{0x625d3113,0x7e6d3114,0xa3be1f57,0x00000000}},	//   véol, mmap, इला_, --,
   {{0xd3660833,0xb90727bd,0x81d30083,0x7e6d3115}},	//   _مه_, _बन_, _হোম_, lmap,
   {{0x7ac42695,0x2aa82705,0x65620371,0x443e3116}},	//   _исте, _отто_, _azoh, dnt_,
   {{0x443e3117,0xceb40100,0x645a0a8d,0x387f3118}},	//   ent_, דיק_, elti, _tuur_,
   {{0x2bcf052b,0xa95401e0,0x2ca90f3a,0x25bf3119}},	//   स्था, _акті, nsad_, rgul_,
   {{0x6932006c,0x443e1aee,0xd3780254,0x73050431}},	//   _حکمر, gnt_, zeće_, епоз,
   {{0xf1d001a5,0x656201b7,0x2d8b0207,0x973c0207}},	//   _dạng_, _ezoh, _ofce_, _peće,
   {{0x443e311a,0x2bcf111a,0xfbcf0bad,0x2ca9018d}},	//   ant_, स्ता, स्तम, ksad_,
   {{0xa1550133,0x973c0254,0xd378011c,0xa116183b}},	//   върш, _veće, veće_, روست,
   {{0xdb1c0082,0x201e2919,0xdee6081b,0x628407e7}},	//   _scrí, óti_, ноги, _čiov,
   {{0xd378011c,0x601001ff,0x00000000,0x00000000}},	//   teće_, _säms, --, --,
   {{0x2018311b,0x7e6d0430,0x00000000,0x00000000}},	//   skri_, gmap, --, --,
   {{0x15f20084,0xd3780254,0xfe43311c,0xc7a500b5}},	// [27a0] _अफसर_, reće_, унто, _پڑ_,
   {{0xaf9a0086,0x248200a0,0xd37800cd,0x25af037b}},	//   _этих_, íkmi_, seće_, _ldgl_,
   {{0x3f98311d,0x2bc625de,0xfbc60577,0xe8030f8a}},	//   mbru_, र्गा, र्गम, लाना_,
   {{0x644302c4,0x2d96311e,0xda650037,0x0f370070}},	//   _ljni, _ярос, ناني, _טריט_,
   {{0x443e311f,0x00000000,0x00000000,0x00000000}},	//   ynt_, --, --, --,
   {{0xb05b03ad,0x6e243120,0xf6e6002d,0x2bc60577}},	//   ttäi, lhib, ецин, र्खा,
   {{0x8c433121,0xd6d73122,0x765b0831,0x443e10db}},	//   _сере, еты_, fluy, vnt_,
   {{0xcfe90033,0xa3d23123,0xfaf700a5,0x443e3124}},	//   খায়_, ह्न_, _אצלי_, wnt_,
   {{0x290200da,0x7d040042,0x3219012f,0xd9431c89}},	//   _çka_, nxis, vksy_, _бети,
   {{0xe8d70122,0x443e3125,0x3d080461,0x69c20b0d}},	//   _אומר_, unt_, _सपने_, lgoe,
   {{0xa195021f,0x443e06c6,0xf1d000e2,0x00000000}},	//   канч, rnt_, _vạng_, --,
   {{0x765b0083,0x69c23126,0x2bc704e9,0x7bde3127}},	//   cluy, ngoe, _लाभा, hepu,
   {{0x6e24000e,0x7bde09dc,0xf1d00023,0x66060093}},	//   dhib, kepu, _tạng_, ökku,
   {{0xb05b0086,0x6010013c,0xe8031282,0xb8030534}},	//   htäv, _sämr, लाया_, लायम_,
   {{0x2cab3128,0x69c20298,0x00000000,0x00000000}},	//   _svcd_, kgoe, --, --,
   {{0x6e243129,0x09d50083,0x2ca9312a,0xddc4013b}},	//   ghib, _সোনা, tsad_, rliş,
   {{0xd9041144,0xe803000c,0x2ca90159,0xdb1c0067}},	// [27b0] _ای_, लामा_, usad_, _obró,
   {{0x7bde312b,0x7e6d312c,0x2d89002a,0x2bd80035}},	//   gepu, smap, scae_, ड़गा,
   {{0x2ca9312d,0xa3d21bb5,0x1eab0c74,0x6e240103}},	//   ssad_, ह्य_, _عادي_, bhib,
   {{0x6e24312e,0xdb1c01ef,0x6fcd0b35,0x3ced0207}},	//   chib, _abró, द्रू, _ševu_,
   {{0x6010312f,0x260400c0,0x9f5a0260,0x2bd8046c}},	//   _kämp, वानी_, _anpè_, ड़खा,
   {{0xec3500c2,0xa3d229ad,0x7bde0012,0x69c201a3}},	//   _יאָר_, ह्म_, cepu, agoe,
   {{0xf4c200c8,0x765b0225,0x00000000,0x00000000}},	//   ্টোব, tluy, --, --,
   {{0x60103130,0x64470bc6,0x00000000,0x00000000}},	//   _lämp, čjim, --, --,
   {{0xe1ff0035,0x5a4400af,0x68e20118,0x00000000}},	//   lmów_, _сэра, cwod, --,
   {{0xa93403e6,0x00000000,0x00000000,0x00000000}},	//   _сеуш, --, --, --,
   {{0x23292258,0x23c20b54,0xfbc60d34,0x2bc603de}},	//   фони_, _शारद, र्टम, र्टा,
   {{0x7aea01b4,0x65951fde,0x7bde0067,0x00000000}},	//   æfti, _раду, zepu, --,
   {{0xddc4030a,0xc2432dbe,0xbcfb00fd,0x00000000}},	//   jmiš, рняк, _szén, --,
   {{0x66091f39,0xd2b900fd,0x00000000,0x00000000}},	//   ljek, _قابض_, --, --,
   {{0x6e243131,0x601000a6,0x64410523,0x69d20e6f}},	//   thib, _dämp, mnli, ण्डी,
   {{0x63a33132,0x68e20297,0x7bd501ae,0x661b3133}},	//   _henn, ywod, _abzu, nkuk,
   {{0x644106ba,0x602601c8,0x62833134,0x63a33135}},	// [27c0] onli, _адпа, _huno, _kenn,
   {{0xd3780b16,0x62833136,0x64413137,0x00000000}},	//   leća_, _kuno, nnli, --,
   {{0x81e50b52,0x63a303d0,0xb05b03ad,0x26043138}},	//   নার_, _menn, ttäv, वामी_,
   {{0x63a33139,0x6283313a,0x644101ae,0x7bde09e7}},	//   _lenn, _muno, hnli, sepu,
   {{0xe3a7040d,0x69c2313b,0x6283010d,0x6609313c}},	//   _پر_, rgoe, _luno, djek,
   {{0x63a3313d,0x8d7700b5,0x64410a75,0xb05b0086}},	//   _nenn, _جاپا, jnli, stäv,
   {{0x29000012,0xc5eb0083,0x973c00cb,0x6283313e}},	//   ţia_, কানা_, _beća, _nuno,
   {{0xd3780470,0x6441313f,0x661b00a7,0xbb430009}},	//   jeća_, enli, gkuk, _теск,
   {{0x63a33140,0x62830159,0xd3780254,0x70dc00a1}},	//   _benn, _auno, deća_, यबोल,
   {{0x63a33141,0x62833142,0xe7c905e7,0x2bc600a9}},	//   _cenn, _buno, _रायप, र्चा,
   {{0x63a304ca,0x62830012,0xddc402f0,0x42751065}},	//   _denn, _cuno, zmiš, лгос,
   {{0x9f410097,0x27ec0f00,0x644104d5,0x00000000}},	//   _nahá_, _hadn_, anli, --,
   {{0x63a33143,0xc05b02ce,0xa3d40036,0xd7c900db}},	//   _fenn, дів_, _болч, _रामच,
   {{0x63a33144,0x44253145,0xe44f0647,0x00000000}},	//   _genn, chl_, _وضو_, --,
   {{0x63a83146,0x628300af,0x64580029,0x80d60033}},	//   madn, _guno, _ikvi, দিষ্,
   {{0x63a80252,0x33770122,0x78ad0254,0x2bc61856}},	//   ladn, _בתוך_, šavi, र्घा,
   {{0x63a30273,0x61ed08dd,0xa1340d4f,0x23cf06fe}},	// [27d0] _yenn, _iaal, _پريش, त्वद,
   {{0x61ed3147,0x63a80d5c,0xddc43148,0x06d90033}},	//   _haal, nadn, rmiš, থিতি,
   {{0x61ed3149,0xfe6e0e3a,0x00000000,0x00000000}},	//   _kaal, تگی_, --, --,
   {{0x61ed314a,0x63a8314b,0xc3330122,0xa3d922c7}},	//   _jaal, hadn, סוף_, _डॉन_,
   {{0x61ed2ed8,0x64582dd2,0x394900c9,0x6609029d}},	//   _maal, _okvi, ças_, vjek,
   {{0x973c03fa,0xa3d20907,0xab9400d4,0xd3780254}},	//   _seća, _हॉल_, _вирі, zeća_,
   {{0x63a3314c,0x973c042a,0x64411217,0x27fe00e2}},	//   _renn, _peća, vnli, _dntn_,
   {{0x2bcf0380,0x61ed314d,0x6283314e,0x3a2602a2}},	//   स्रा, _naal, _runo, chop_,
   {{0x7e7d314f,0x6283300c,0x69cc024e,0x661b3150}},	//   _misp, _suno, ílež, rkuk,
   {{0x62833151,0x7bc53152,0x66090a55,0x63a83153}},	//   _puno, nghu, sjek, gadn,
   {{0xc5d502ce,0x61ed0273,0x63a33154,0xbcfb006c}},	//   _біль, _baal, _venn, _szél,
   {{0x63a33155,0x7e7d3156,0x260400fa,0x62833157}},	//   _wenn, _nisp, वाणी_, _vuno,
   {{0x61ed0223,0x04c80037,0x63a33158,0xa24800b5}},	//   _daal, _لوني_, _tenn, ٹیکل_,
   {{0x62833159,0xf7780484,0x34b200d1,0xd37800cd}},	//   _tuno, _taħt_, _اموز, seća_,
   {{0x7e7d315a,0xb05b315b,0x6d5d0381,0x61ed027d}},	//   _bisp, kräf, _aysa, _faal,
   {{0xc6920c37,0x61ed315c,0xfce60798,0x69c9006f}},	//   מאל_, _gaal, лобо, _ncee,
   {{0xdd8f0c36,0x4d6600d8,0xad9b00d5,0xbcfb00e0}},	// [27e0] سول_, укав, _poúr, _nyéd,
   {{0x309b0bed,0x69c90043,0x6d5d0107,0xab2a315d}},	//   _רשימ, _acee, _dysa, ноза_,
   {{0x61ed001c,0x68e9315e,0xb05b1193,0x9f4100d5}},	//   _yaal, _ased, rtät, _tahá_,
   {{0xb05b02c9,0x63a8008b,0x290601d7,0x7e7d315f}},	//   stät, zadn, txoa_, _gisp,
   {{0x522d02b5,0x00000000,0x00000000,0x00000000}},	//   וואַ, --, --, --,
   {{0x68e90009,0xcaa60037,0xdd3b0070,0x2c05012f}},	//   _dsed, _مصري, _װעלכ, राणं_,
   {{0x63a83160,0xd5e200e2,0x3a263161,0x00000000}},	//   vadn, _phò, phop_, --,
   {{0xa281004e,0xe4e602ce,0xb05b3162,0x44b40036}},	//   łość_, гіон, ntär, абис,
   {{0x61ed0223,0x394603fa,0xd5e200cc,0x00000000}},	//   _raal, _снаг, _chó, --,
   {{0x61ed3163,0x250700b5,0x00000000,0x00000000}},	//   _saal, ارٹی_, --, --,
   {{0x63a83164,0x2604114e,0x61ed3165,0xb05b01ff}},	//   radn, वादी_, _paal, ktär,
   {{0x63a83166,0x64a63167,0xf8c808b0,0x387e02a7}},	//   sadn, _бада, _रमाय, _hitr_,
   {{0x63a80129,0x7e7d3168,0x61ed3169,0xb5fd02c4}},	//   padn, _risp, _vaal, rmšt,
   {{0x4394316a,0x61ed316b,0xf1bf0082,0x7e7d02e9}},	//   _такс, _waal, chán_, _sisp,
   {{0x61ed316c,0x5f94316d,0x3e41010b,0x248600c3}},	//   _taal, сист, lėti_, _huom_,
   {{0x92b3083a,0x6fd6316e,0x387e316f,0x6d5d00ee}},	//   _احوا, म्बू, _litr_, _pysa,
   {{0x7e7d0080,0x3e4100d8,0xc047042c,0x527c016b}},	// [27f0] _visp, nėti_, _مخدو, _אנהא,
   {{0x7e7d3170,0x25a6001e,0x6d5d053d,0x00000000}},	//   _wisp, _leol_, _vysa, --,
   {{0xb05b1535,0xe8030d00,0x78bc0029,0x7e7d035f}},	//   träf, लासा_, _ārva, _tisp,
   {{0x973c025c,0x3e4100d8,0x636f00b5,0x6d5d0051}},	//   _pećn, kėti_, lóné, _tysa,
   {{0x05260033,0x387e0523,0x00000000,0x00000000}},	//   মপুর_, _bitr_, --, --,
   {{0x3e4100d8,0x25a9008b,0x973c02c4,0xe73905a1}},	//   dėti_, _žal_, _većn, кел_,
   {{0x7ceb0523,0x00000000,0x00000000,0x00000000}},	//   _förå, --, --, --,
   {{0x25a6066a,0x9b581edd,0x22492181,0x24863171}},	//   _ceol_, _сист_, _njak_, _buom_,
   {{0x68e93172,0xf1bf0037,0xf7780024,0x00000000}},	//   _used, thán_, _daħq_, --,
   {{0x391400af,0x224908eb,0x8938002d,0x00000000}},	//   _умур, _ajak_, _спус_, --,
   {{0x2a6d3173,0x69cc000c,0x2a7f0a4e,0x63bc008a}},	//   _kheb_, _हामी, _kiub_, órna,
   {{0xd57517e0,0x323607e5,0x2001011e,0x3e41010b}},	//   _куль, рхос, _anhi_, bėti_,
   {{0x224901ed,0xddde0160,0x20130dfa,0x00000000}},	//   _djak_, _lupţ, _boxi_, --,
   {{0xa06a01c8,0xfaf800ea,0xe3b93174,0x00000000}},	//   тага_, _šīm_, _рбк_, --,
   {{0xdee63175,0x43750070,0x31693176,0x9ac70024}},	//   шови, _דײַן_, _ezaz_, _jiċħ,
   {{0x644f0248,0x224901f4,0x9ac7009f,0x3dd9016e}},	//   écif, _gjak_, _miċħ, _cbsw_,

   {{0xa2a10026,0xc0e60265,0x2bca005f,0xcd060210}},	// [2800] कीर्, _топк, клап_, шпай,
   {{0xb05b3177,0xd00f0037,0x00000000,0x00000000}},	//   stär, _يلي_, --, --,
   {{0x394d3178,0x395f067f,0xe6d407b5,0xf1d31371}},	//   _axes_, _ayus_, _दहेज, ध्वन,
   {{0xb05b0446,0x2efa0747,0x2a6d3179,0x5fd20761}},	//   träg, _irpf_, _cheb_, द्रल,
   {{0x260400dc,0x386c0097,0xd946002d,0x25a6317a}},	//   वासी_, _phdr_, шеди, _reol_,
   {{0x25a6004f,0xdca3049f,0x6843257f,0x98560043}},	//   _seol_, _фари, онча, штеш,
   {{0x973c0254,0x6f1c016e,0x03ee0033,0x00000000}},	//   _većo, nyrc, জামী_, --,
   {{0xb05b0f8e,0x6b6301e0,0x00000000,0x00000000}},	//   präg, _єкта, --, --,
   {{0x87da0148,0x6f1c00e9,0x386c063c,0x00000000}},	//   _لباس_, hyrc, _thdr_, --,
   {{0xbcfb006c,0x3e41010b,0x00000000,0x00000000}},	//   _szék, rėti_, --, --,
   {{0x2338021f,0xb6cb00b5,0x05ea00af,0x20130160}},	//   упны_, _لانے_, _афли_, _roxi_,
   {{0xd37700d8,0x25dd0907,0xd25800d4,0x00000000}},	//   шчы_, _कॉपी_, иця_, --,
   {{0x0494317b,0x66021852,0x625d00a2,0xfbc70387}},	//   _التح, _inok, déot, _लालम,
   {{0x04db025a,0x00000000,0x00000000,0x00000000}},	//   _סקול, --, --, --,
   {{0x6f1c0297,0xfda703fa,0x59d7317c,0x6602317d}},	//   gyrc, ијам, ण्डर, _knok,
   {{0x30a72365,0xdd98178e,0x9e040009,0xe37b011d}},	//   _кров, ишу_, очул, _ברור,
   {{0x25dd02e4,0xb05b013c,0xbcfb0118,0x6602023c}},	// [2810] _कॉफी_, träd, _syéb, _mnok,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x19b900af,0x6602317e,0xb05b0f8e,0x00000000}},	//   гуль_, _onok, rräd, --,
   {{0x2a6d0221,0x4975039e,0x9f430055,0x66020103}},	//   _qheb_, блес, hejë_, _nnok,
   {{0x26de21a4,0x8cf400d8,0xe80329ce,0x00000000}},	//   _apto_, _дзяц, लाला_, --,
   {{0x1d1600a5,0x6602317f,0x3dc9010d,0xb8ff051d}},	//   _הקשר_, _anok, lgaw_, _तह_,
   {{0x2a7f104e,0x7e6f008c,0x6dbb0067,0x00000000}},	//   _tiub_, _khcp, ałał, --,
   {{0xb8cd00c8,0x3dc90f3a,0x26de0453,0xf1c600b4}},	//   _কম_, ngaw_, _dpto_, _वाइन,
   {{0x81d60033,0xe4592503,0x629a01bf,0x00000000}},	//   _সফল_, лжи_, epto, --,
   {{0x9b4400f5,0x68fb0291,0x981401ca,0x66023180}},	//   _انہو, _irud, _وبلا, _enok,
   {{0x68fb0187,0xe7193181,0x00000000,0x00000000}},	//   _hrud, _حيات_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26040587,0x850500d1,0x291d3182,0x6f1c00e9}},	//   वारी_, _دوشن, nywa_, wyrc,
   {{0x3cfe0355,0xe3b80225,0x656b0069,0x33950037}},	//   _čtv_, lkın_, _izgh, _الغز,
   {{0xfbcd0033,0x22590051,0xd7f100e2,0x44270185}},	//   রজাত, bosk_, _mã_, _iln_,
   {{0x0d863183,0x44273184,0xe3b800a8,0xdcfd0457}},	//   слан, _hln_, nkın_, _adsı,
   {{0x61e63185,0x00000000,0x00000000,0x00000000}},	// [2820] mekl, --, --, --,
   {{0x69db0831,0x61e63186,0x44273187,0x3dc9010d}},	//   _abue, lekl, _jln_, agaw_,
   {{0x44273188,0xfc3f0955,0x25ad3189,0x68fb318a}},	//   _mln_, _avís_, kael_, _arud,
   {{0x68fb318b,0x61e60723,0x80cb00c8,0xb3460279}},	//   _brud, nekl, িবর্, leçõ,
   {{0x25ad001e,0xddcd2ceb,0x8d7608cf,0x656f00a0}},	//   dael_, llaş, _دادا, ýchl,
   {{0x5fdb0127,0x7e64318c,0x66022a5e,0x00000000}},	//   म्पल, llip, _snok, --,
   {{0xddcd0463,0x61e601d6,0x7e64318d,0x260413ab}},	//   nlaş, kekl, olip, वाली_,
   {{0x61e6318e,0x7e640dc3,0x291d0035,0x7afc02b1}},	//   jekl, nlip, bywa_, _irrt,
   {{0x2bcf009a,0x68fb318f,0x61e63190,0xa9263191}},	//   स्का, _grud, dekl, _удал,
   {{0xddcd01d6,0x7c3e1b39,0x60c600d7,0xe82400b5}},	//   klaş, nipr, dukm, _بذری,
   {{0x5c5b02b5,0x2bf700a5,0x7bdc3192,0x00000000}},	//   רדיק, זמין_, _mbru, --,
   {{0xad9b00c9,0xcb1300a5,0x7e64022f,0xc0cb0cc7}},	//   _anún, ללת_, jlip, луге_,
   {{0x661d00c3,0xdb070055,0x44270381,0x00000000}},	//   öske, _pejë, _fln_, --,
   {{0xa2c00af9,0x3dc90159,0x629a3193,0x973c0207}},	//   _विप्, wgaw_, ppto, _nećk,
   {{0x443e0f00,0x543b02b5,0x644f0248,0x643b02b5}},	//   mit_, _געגא, écie, _געגנ,
   {{0x645a0228,0x7bdc3194,0x61e63195,0x7e640dc3}},	//   loti, _abru, cekl, glip,
   {{0x973c02c4,0x7bdc009e,0x644800b9,0x68e400a8}},	// [2830] _bećk, _bbru, ondi, çidl,
   {{0x443e3196,0x645a3197,0x64483198,0x3dc90430}},	//   nit_, noti, nndi, sgaw_,
   {{0x64483199,0x207c0070,0xdb0501ef,0x973c0207}},	//   indi, _גאזא, pahí, _dećk,
   {{0x443e319a,0x7e64319b,0x1df90086,0xc1b7319c}},	//   hit_, clip, _темы_, _अयोग,
   {{0x443e319d,0x65620027,0x00000000,0x00000000}},	//   kit_, _nyoh, --, --,
   {{0x62980912,0x443e319e,0x63aa00fb,0x645a1669}},	//   _otvo, jit_, _nefn, joti,
   {{0xa3be0f39,0x645a319f,0x6562043d,0x628a00c7}},	//   ेलन_, doti, _ayoh, _nufo,
   {{0xe61903f5,0x68fb0fe2,0x6e2d31a0,0x644831a1}},	//   рди_, _trud, nhab, endi,
   {{0x4427035d,0x644831a2,0x645a0097,0x68fb31a3}},	//   _pln_, fndi, foti, _urud,
   {{0x443e31a4,0xddcd0723,0x63aa0297,0x2bcc00a1}},	//   git_, ylaş, _cefn, ालया,
   {{0x63aa02c7,0x27e731a5,0xdb1c004f,0x69cb31a6}},	//   _defn, menn_, _scrú, ogge,
   {{0x69cb1034,0x443e31a7,0x6448000e,0x60c622be}},	//   ngge, ait_, andi, tukm,
   {{0xe3ae31a8,0x61e631a9,0x6e2d31aa,0x21240079}},	//   _об_, rekl, dhab, ámh_,
   {{0x442c31ab,0x645a31ac,0x27e731ad,0x63aa31ae}},	//   chd_, coti, nenn_, _gefn,
   {{0x26c731af,0xa3d20141,0x61e631b0,0x764931b1}},	//   nuno_, _हॉट_, pekl, oney,
   {{0xddcd0644,0x22b50029,0x27e731b2,0x6e2d31b3}},	//   rlaş, māk_, henn_, ghab,
   {{0x7e6431b4,0x81d30083,0x22b50029,0x27e702e9}},	// [2840] rlip, _হোক_, lāk_, kenn_,
   {{0x27e731b5,0xddcd05f9,0x09b425de,0xebe300ca}},	//   jenn_, plaş, ुल्य, моуп,
   {{0x27e7021e,0x0aea0036,0x22b50029,0xd24f0416}},	//   denn_, рдей_, nāk_, _سنی_,
   {{0xe8fa28a4,0x443e31b6,0x6e2d31b7,0xddcd0043}},	//   иле_, zit_, chab, rmaţ,
   {{0x644831b8,0x645a31b9,0x443e31ba,0x3ead0a78}},	//   yndi, yoti, yit_, ćete_,
   {{0x7bdc31bb,0x27e731bc,0x645a31bd,0x76490298}},	//   _ubru, genn_, xoti, eney,
   {{0x443e31be,0x645a011c,0xdcf60463,0x26c731bf}},	//   vit_, voti, mayı, guno_,
   {{0xdcf60dac,0x443e31c0,0x62980223,0x22b50228}},	//   layı, wit_, _rtvo, dāk_,
   {{0x443e31c1,0x645a31c2,0x6298011c,0x27e70359}},	//   tit_, toti, _stvo, benn_,
   {{0x644831c3,0x186a0133,0x443e15f7,0x68ed31c4}},	//   undi, _тази_, uit_, çade,
   {{0x443e0b73,0x1bfb02b5,0x2bcf0d00,0x26c731c5}},	//   rit_, בליב, स्टा, cuno_,
   {{0x443e31c6,0x442c028b,0xd378011c,0xa2c00099}},	//   sit_, shd_, neći_, _विठ्,
   {{0x443e31c7,0xda7b0052,0x645a31c8,0x51840171}},	//   pit_, ינטר, poti, дура,
   {{0xddcd31c9,0xc05b01e0,0x764000d8,0x22b50029}},	//   dmaš, рім_, limy, bāk_,
   {{0x6e2d31ca,0x69cb31cb,0x973c0c99,0x539b0d85}},	//   thab, ygge, _beći, _דיוו,
   {{0x2bdd0ed1,0x27e70260,0xfbdd0ea3,0xd3780254}},	//   न्ना, zenn_, न्नम, jeći_,
   {{0xd37801cc,0x6e2d31cc,0xacf831cd,0x00000000}},	// [2850] deći_, rhab, онту_, --,
   {{0x1c050243,0x6e2d04f7,0x26c731ce,0xad9b0279}},	//   राइल_, shab, yuno_, _inúm,
   {{0x764931cf,0x764031d0,0xce59027f,0x27e7021e}},	//   yney, kimy, _ганц_, venn_,
   {{0x7c3c028b,0x26c7002f,0x682f008c,0x00000000}},	//   _emrr, vuno_, _kødg, --,
   {{0x27e731d1,0x8cc200dc,0x22b50029,0x22a7006c}},	//   tenn_, _लियो, zāk_, zők_,
   {{0xf8070a71,0x26c700e9,0x443c023a,0x00000000}},	//   ючен, tuno_, _nmv_, --,
   {{0x27e731d2,0x2a660cca,0xd378011c,0x26c70124}},	//   renn_, blob_, beći_, uuno_,
   {{0x060931d3,0x22b50228,0x7c250207,0x22a700b5}},	//   сник_, vāk_, lkhr, vők_,
   {{0x27e731d4,0xe4d6004f,0x26c70159,0x764931d5}},	//   penn_, كويت_, suno_, rney,
   {{0x26c70f3a,0x8707004f,0x22a7006c,0x22b500ea}},	//   puno_, _وبال, tők_, tāk_,
   {{0x2bdd0ceb,0xfbdd0517,0x1dcb00dc,0x625d000d}},	//   न्या, न्यम, िलात, téop,
   {{0x22b50ae0,0x2c6d1840,0x26f9004e,0x443c31d6}},	//   rāk_, _vždy_, ्मीर_, _emv_,
   {{0x443c0210,0x48fe0d4e,0x22b50228,0x22a700fd}},	//   _fmv_, लियो_, sāk_, sők_,
   {{0xd3780254,0x2bdd31d7,0xb4fa00a5,0x66190069}},	//   zeći_, न्मा, _לפני, _howk,
   {{0x644131d8,0x973c0254,0x0e6a0037,0x78a90103}},	//   mili, _peći, مصري_, _lwev,
   {{0xa2c00433,0xe1ff0f56,0xb2ba00a5,0x79891da1}},	//   _वित्, llón_, _המקר, _ngew,
   {{0x973c01cc,0x6c860180,0x6e2431d9,0xd3780254}},	// [2860] _veći, سلام, rkib, veći_,
   {{0x61f631da,0x6e2431db,0x79890103,0x764001b5}},	//   _hayl, skib, _agew, zimy,
   {{0xd3780470,0x61f631dc,0xdcf604d4,0x62970300}},	//   teći_, _kayl, rayı, _éxod,
   {{0x644131dd,0x98a030ec,0x00000000,0x00000000}},	//   hili, šič_, --, --,
   {{0x644131de,0x201a31df,0x61f631e0,0xd3780a78}},	//   kili, _kopi_, _mayl, reći_,
   {{0x442531e1,0x64410054,0xb05b01ae,0xd3780254}},	//   jkl_, jili, hrän, seći_,
   {{0x644131e2,0x4425028b,0xd3780506,0xa2c02218}},	//   dili, dkl_, peći_, _विध्,
   {{0xa3d90f3d,0x443c0a8a,0xf77200b5,0x61f61af2}},	//   ड्स_, _smv_, واں_, _nayl,
   {{0x76400d29,0x682f0a8c,0xbcfb13cf,0xb05b10c0}},	//   rimy, _bødd, _nyél, drän,
   {{0xa2c00d34,0x644131e3,0x3949002a,0x682f11cb}},	//   _विद्, gili, úase_, _rødg,
   {{0x61f6043d,0x644f02e1,0x46a3280a,0xe7b300b5}},	//   _bayl, écia, _захв, _سمند,
   {{0xb05b022a,0x7ae101ae,0xbba800b4,0x443c31e4}},	//   grän, _älte, गरुक, _wmv_,
   {{0xe1ff31e5,0x682f1b99,0x216731e6,0xa3d40183}},	//   blón_, _fødd, ятог, _жолч,
   {{0x6e3d0069,0x201a00e9,0xe1ff0138,0xbddb0118}},	//   _smsb, _copi_, clón_, _njèr,
   {{0x629c05d3,0x33db00a5,0xb05b1890,0x61f600a8}},	//   írod, _החוד, brän, _fayl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32090c86,0xbcfb0332,0xc1bc0122,0x91bc0122}},	// [2870] _inay_, _azér, _המחש, _המחי,
   {{0x201a016e,0xa3c500b4,0x682f08c8,0x320900e2}},	//   _gopi_, एलए_, _køde, _hnay_,
   {{0x998900b8,0x61f60448,0x3a2612ba,0x682f00d4}},	//   íkům_, _yayl, fkop_, _jøde,
   {{0x682f054e,0x3a260dc3,0x41bf0380,0xf1bf178c}},	//   _møde, gkop_, ्लिस, ्लिन,
   {{0xa3be31e7,0xbcfb006c,0xf8ae006c,0x64410644}},	//   ेला_, _ezér, لکل_, yili,
   {{0xd3780c99,0x66e52519,0x00000000,0x00000000}},	//   leću_, дока, --, --,
   {{0x3209027d,0xe81e020d,0x682f1f8b,0xf1bf1cce}},	//   _onay_, _बकरा_, _rødd, ्लान,
   {{0x644102c7,0xc7440082,0xdb0701c0,0x27e000f4}},	//   wili, عضوي, _její, đina_,
   {{0x3d00111e,0x280800b8,0xdb0721db,0x7bca31e8}},	//   रिये_, átní_, _mejí, ófug,
   {{0x61f600a8,0x32090c47,0xe7b50e3a,0xdb071c5b}},	//   _sayl, _anay_, _آماد, _lejí,
   {{0x644131e9,0x61f61a68,0xb05b15e5,0x1b1f00c8}},	//   rili, _payl, trän, _যেতে_,
   {{0x2bdd0e96,0xfbdd0355,0xd3780c0a,0xdb0e03e6}},	//   न्ता, न्तम, jeću_, _bebê,
   {{0x64411fd9,0xd3780254,0x2c740282,0xb05b31ea}},	//   pili, deću_, läde_, rrän,
   {{0x682f2b6f,0x23290dde,0xdee600c3,0x2d99008c}},	//   _føde, _моли_, моги, _afse_,
   {{0xa06731eb,0x61f631ec,0xfbcc06fe,0x682f0a8a}},	//   фара_, _tayl, ालसम, _gøde,
   {{0x7bc30093,0x00000000,0x00000000,0x00000000}},	//   ónun, --, --, --,
   {{0x201a31ed,0xac8631ee,0x2ca0008c,0x22400178}},	// [2880] _topi_, дгал, upid_, _imik_,
   {{0x25dd0930,0x3a2d00f6,0x00000000,0x00000000}},	//   क्ती_, _alep_, --, --,
   {{0x2bdd01c0,0x248702d0,0x63bc0cb2,0xfbdd00b8}},	//   न्धा, _minm_, órni, न्धम,
   {{0xa2c00e6f,0xfaf80029,0x1d0a0183,0x25af008c}},	//   _विस्, _šīs_, _деми_, _negl_,
   {{0x249d006d,0x3a2631ef,0x08970037,0x2bc7073f}},	//   _ntwm_, rkop_, وضوع_, _लाचा,
   {{0x2bdd0ca4,0x0ee2210a,0xfbdd0af6,0x68ed0279}},	//   न्दा, _पहाड, न्दम, çada,
   {{0xdb83049f,0x3a2631f0,0x00000000,0x00000000}},	//   _агри, pkop_, --, --,
   {{0x26c031f1,0x2487003b,0x44f4316d,0xe5c60145}},	//   čio_, _ainm_, епис, фско,
   {{0x25af0036,0x83fc00cd,0x05bf0380,0x682f0a8c}},	//   _degl_, hođe, _एयरब, _dødb,
   {{0x83fc029d,0xd378011c,0xa2b20761,0x224000fd}},	//   kođe, zeću_, _आबद्, _amik_,
   {{0xd6cf0071,0x78a20124,0x972600d1,0x00000000}},	//   _نقل_, lpov, _تفاو, --,
   {{0xc7b80a78,0x64a600d8,0x78a20051,0x7afa0093}},	//   _dođe_, _жада, opov, _áttu,
   {{0xd37800cd,0x7c2e31f2,0x2a640168,0x00000000}},	//   veću_, _olbr, _mkmb_, --,
   {{0x656f01ae,0x00000000,0x00000000,0x00000000}},	//   üche, --, --, --,
   {{0x5f9408ae,0x83fc0254,0x442e09c5,0x2d8b0284}},	//   тист, gođe, _ilf_, _pgce_,
   {{0x41e71112,0x3209011e,0xddc40067,0x00000000}},	//   _ціка, _unay_, enił, --,
   {{0x5c750086,0x6fd70026,0x7bde033b,0x78a21321}},	// [2890] елат, _बापू, ffpu, jpov,
   {{0x83fc0f44,0x78a20076,0x9f4c024e,0x3a2d03c9}},	//   bođe, dpov, ždá_, _slep_,
   {{0xb5fd31f3,0x00000000,0x00000000,0x00000000}},	//   loše, --, --, --,
   {{0xdb1c31f4,0xd37b0070,0x2cc40448,0x8c490225}},	//   _acró, קראט, ürdü_, _başö,
   {{0x5d851062,0xb5fd1851,0x442e013a,0x9f430176}},	//   _سلسل, noše, _olf_, lejà_,
   {{0x442e00d7,0x25af0f0a,0x2c050035,0x59d100b4}},	//   _nlf_, _segl_, राओं_, _हावर,
   {{0xa2c0112b,0x7b640328,0xa3d900b4,0x00000000}},	//   _विष्, _атте, _डॉग_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c02e9,0x2240028b,0x26040ca1,0xb5fd0009}},	//   _adrè, _rmik_, वाजी_, joše,
   {{0xa2c0017f,0xb5fd0169,0x7af50035,0xdb0e31f5}},	//   _विश्, doše, _kszt, _bebè,
   {{0x442e0a8a,0x31690457,0x25af0a8a,0x00000000}},	//   _dlf_, _ayaz_, _tegl_, --,
   {{0x34951b5d,0x83fc0a78,0xc7b80254,0xe60e005f}},	//   _задр, vođe, _vođe_, _ёд_,
   {{0x660b1c04,0x659403fa,0xb5fd055f,0x2bff046c}},	//   _ingk, _рачу, goše, ईयां_,
   {{0x26c702fb,0x7af5006c,0x95cc0095,0x05740416}},	//   orno_, _oszt, _çərç, _شاند,
   {{0xdee30af5,0xbcfb006c,0x260400a1,0xe29a0019}},	//   лори, _szép, वाची_, _trưa_,
   {{0x2612112b,0xe7df0026,0x9f5831f6,0x83fc0254}},	//   थायी_, प्तप, ndré_, rođe,
   {{0x61e40291,0x7af500b5,0xed5731f7,0xe80201c0}},	// [28a0] _ibil, _aszt, еот_, लयमा_,
   {{0x799b030d,0x3ec50448,0xa7fc0225,0x4d6331f8}},	//   _afuw, üstü_, _akın, укув,
   {{0x4fd70779,0x7fd700c2,0xe7c900c4,0x660b31f9}},	//   _אויב_, _אויס_, _राजप, _ongk,
   {{0x78a20124,0x660b0118,0x00000000,0x00000000}},	//   tpov, _nngk, --, --,
   {{0x61e40657,0x2bdd31fa,0x7af5006c,0x67d431fb}},	//   _mbil, न्हा, _eszt, волу,
   {{0x660b253e,0xb05b081b,0x25dd0d00,0x7c2e31fc}},	//   _angk, yräm, क्सी_, _ulbr,
   {{0x78a20bec,0x61e40ce9,0x799b0103,0xad9b008d}},	//   spov, _obil, _ffuw, _snúi,
   {{0xdb0e31fd,0x00000000,0x00000000,0x00000000}},	//   _odbú, --, --, --,
   {{0x2bdd021a,0x973c0009,0x54540dee,0x69c00176}},	//   न्वा, _pećs, квит, _idme,
   {{0xccf30122,0x660b072e,0x26c7210c,0x88bb00a5}},	//   רכז_, _engk, brno_, _מזמי,
   {{0x6fd71782,0xdb0e0152,0x07a303d0,0x61e40069}},	//   _बाबू, _bebé, _сахн, _bbil,
   {{0x5ab70779,0x7e660159,0xb5fd00f4,0x2904023a}},	//   עלכע_, _nkkp, toše, _krma_,
   {{0x442e0022,0x64a331fe,0xdb0e0300,0x00000000}},	//   _tlf_, _бача, _debé, --,
   {{0xb5fd04c3,0xdb07006c,0x442e0533,0x61e431ff}},	//   roše, _lejá, _ulf_, _ebil,
   {{0xc0ab0df3,0xa3d90e04,0x69c01b89,0x2baf0433}},	//   _کابل_, _डॉट_, _odme, टरसा,
   {{0xdb0e00e0,0x00000000,0x00000000,0x00000000}},	//   _gebé, --, --, --,
   {{0x8bc711d0,0xf1bf3200,0x61ef0a21,0x6d4000f4}},	// [28b0] есед, nkám_, mecl, _žmar,
   {{0x69c03201,0x61e43202,0x61fd02ce,0x00000000}},	//   _adme, _zbil, ldsl, --,
   {{0x8f35231f,0xb5fd00f4,0xdb0700fd,0x00000000}},	//   _ренц, nošc, _bejá, --,
   {{0x61fd1ba9,0xf99000e0,0x68ed3203,0x61ef3204}},	//   ndsl, مبه_, çado, necl,
   {{0xd36601ca,0x7e6d3205,0xdb0700de,0xdb050079}},	//   _چه_, mlap, _dejá, ibhé,
   {{0xd36600bf,0x7e6d3206,0xfc3f008e,0x76420159}},	//   _نه_, llap, _stíf_, _amoy,
   {{0x8f9c02b5,0x644f00a2,0x316c0067,0x00000000}},	//   ליגי, écim, ędzi_, --,
   {{0x24993207,0x7e6d006c,0x59d80fd1,0xda0900e0}},	//   ísmo_, nlap, _डायर, _تيره_,
   {{0x25dd0567,0xe89500d8,0x9f4a0443,0x78bb002f}},	//   क्षी_, _разь, rebé_, _uvuv,
   {{0x7e6d3208,0x61e4027a,0x00000000,0x00000000}},	//   hlap, _sbil, --, --,
   {{0x13a70987,0x6fdf0026,0xe6c70c74,0x26dc0237}},	//   ونکی_, _पॉइं, _ستاي, ctvo_,
   {{0x660b20fb,0x61ef0088,0x60dd3209,0xa6960319}},	//   _ungk, gecl, ftsm, _סכנה_,
   {{0x463a00c2,0x7e6d00ea,0x54e50066,0x85b80647}},	//   _קענע, dlap, _कहिए_, _سانس_,
   {{0x25dd0567,0x6a781c02,0x160900c4,0xb5fd02c4}},	//   क्री_, mífe, वाकर_, bošc,
   {{0x60dd320a,0x998f00d8,0x61e4320b,0x1f591a24}},	//   atsm, nigų_, _tbil, ешть_,
   {{0x61e40bc6,0xe8d10084,0x7e6d0cca,0xc6920070}},	//   _ubil, _समूच, glap, שאן_,
   {{0x0d862857,0x6a78002a,0x3e5a0355,0x00000000}},	// [28c0] тлан, nífe, jďte_, --,
   {{0xe0b7168d,0x9f5a01f4,0xbbcc01c0,0xfce3136c}},	//   _שליט_, _japë_, ालेक, рофо,
   {{0xe9da00c3,0x3daa00c3,0x3ea60009,0xcb0a0698}},	//   дке_, _окно_, _шинг, بيان_,
   {{0x98a6320c,0x831a02b5,0x60c90c99,0x01b00033}},	//   виде, וועז, šeme, _কাঁদ,
   {{0x83fc0009,0x00000000,0x00000000,0x00000000}},	//   hođa, --, --, --,
   {{0x6b9c0132,0x00000000,0x00000000,0x00000000}},	//   _ufrg, --, --, --,
   {{0x8c4305c2,0xddcd002d,0xcf9300a5,0x27ee00e9}},	//   _тере, noaş, סטה_, refn_,
   {{0xd49a0009,0xceb3011d,0x656b0b3e,0x35f41199}},	//   мро_, ביה_, _bygh, упир,
   {{0x26dc0888,0x29040043,0x61ef0526,0xd9100416}},	//   stvo_, _urma_, vecl, _دیش_,
   {{0xa84a0493,0x1e1f2218,0xf1bf1534,0x00000000}},	//   _غلام_, _यक्ष_, rkám_, --,
   {{0x0bb70d85,0x83fc011c,0x1db20325,0x7d060345}},	//   כלים_, gođa, जरात, _lrks,
   {{0x61bf021a,0x27e90254,0x6443320d,0xe5a6002d}},	//   ्लेष, đane_, _emni, _риди,
   {{0x61fd320e,0x6a7801ef,0x041e0033,0xdb050079}},	//   rdsl, cífe, যোগী_, rbhé,
   {{0xdb050093,0x61ef00f6,0x60dd0147,0xa4b700a5}},	//   rahú, secl, rtsm, _ילדה_,
   {{0x7e6d320f,0xb5fd3210,0xf1bf00b5,0x69d33211}},	//   tlap, loša, nkák_, _डाली,
   {{0x64483212,0x2d8f01b4,0x64430035,0xfda40274}},	//   lidi, øge_, _zmni, ијум,
   {{0x23b60299,0x3d0d004e,0xb5fd0029,0xd7d20722}},	// [28d0] _आजाद, समें_, noša, _सांच,
   {{0x7e6d01c8,0x64483213,0x00000000,0x00000000}},	//   slap, nidi, --, --,
   {{0x68e93214,0xe0df027a,0xeab00118,0x7e6d3215}},	//   _sped, ltò_, قعن_, plap,
   {{0x64483216,0xe1ff3217,0x6e36024e,0x628d0069}},	//   hidi, ndó_, chyb, _jiao,
   {{0x6e2d3218,0xe0df1fc7,0x89a800d4,0xd7e902ee}},	//   mkab, ntò_, тків_, емле_,
   {{0x628d3219,0xb5fd0029,0x64480107,0x656b23f4}},	//   _liao, doša, jidi, _rygh,
   {{0x6448321a,0x80d3021a,0x366902e0,0x81cb0083}},	//   didi, भूते, нако_, র্য_,
   {{0xc7b80f44,0x83fc0a78,0x6e2d321b,0x6a781e97}},	//   _vođa_, vođa, nkab, tífe,
   {{0x6448321c,0x629c0391,0x9f4300c3,0x6e2d1855}},	//   fidi, íron, lejä_, ikab,
   {{0x6448321d,0xe576004b,0x628d009e,0x81cb0033}},	//   gidi, ызы_, _aiao, র্ম_,
   {{0x23290036,0x6e2d321e,0x05130033,0x7e6408c7}},	//   хони_, kkab, িনের_, yoip,
   {{0xd7df04bc,0x628d321f,0x82360df3,0xe7df09b4}},	//   प्रच, _ciao, اردا, प्रप,
   {{0x64483220,0x656b2b66,0x7d090254,0x6e2d0523}},	//   bidi, _uygh, _šesn, dkab,
   {{0xddc401c0,0x9f430086,0xad9b01ef,0x661b3221}},	//   dliš, kejä_, _laúd, ljuk,
   {{0xd5b7045c,0x7529006c,0x3ebe008a,0xd00700af}},	//   _इजाज, lyez, étt_, ыере_,
   {{0x661b0f1a,0x81cb0083,0x6e2d1c3f,0x628d3222}},	//   njuk, র্ব_, gkab, _giao,
   {{0x75293223,0x753b3224,0xddc41001,0x2fba0012}},	// [28e0] nyez, nzuz, gliš, _пынэ_,
   {{0x6e2d08c3,0xbc6a0c36,0x661b00ab,0x1c0e0354}},	//   akab, رمان_, hjuk, साइल_,
   {{0x6e460192,0x49ca144b,0x6e2d3225,0x7e64034d}},	//   _бенз, елен_, bkab, poip,
   {{0x64483226,0xb05b01ff,0xddc403c9,0x661b01a8}},	//   zidi, tsäg, bliš, jjuk,
   {{0x28f80b7d,0xad9b016f,0x627c0035,0x3c2400a8}},	//   тель_, _vnút, _głoś, _dövr_,
   {{0x7d043227,0xb8dc007c,0xb5fd0029,0xdb0e00fe}},	//   mvis, _आब_, voša, _hebí,
   {{0x64483228,0xa3d707a3,0xfaa30bfe,0xdb0e00ee}},	//   vidi, िलन_, _гасо, _kebí,
   {{0xb5fd0080,0xceb30122,0x6448001e,0x7d0400be}},	//   toša, זיה_, widi, ovis,
   {{0x81cb00c8,0x7d0402df,0x3ce03229,0x2a6601e8}},	//   র্ড_, nvis, ntiv_, moob_,
   {{0xb5fd0029,0x2a6600a7,0x5c370070,0x7d04322a}},	//   roša, loob_, ָרטן_, ivis,
   {{0xd7930082,0x7ae90c99,0xddc4053d,0xe2150f99}},	//   _المخ, _ćetk, zliš, амны,
   {{0x6448322b,0x3ce010dd,0x2a66322c,0x6676006c}},	//   sidi, ktiv_, noob_, _صدار,
   {{0x7d04322d,0xa2c0142a,0xe1ff322e,0xc5f30122}},	//   jvis, _विक्, rdó_, _לדף_,
   {{0xe0df07e5,0x2a66006f,0x682f0b3e,0x9f530024}},	//   rtò_, hoob_, _nødl, _paxà_,
   {{0xd904040d,0xf8d1051d,0x27fe00d7,0x9f340185}},	//   _کی_, _सम्प, _matn_, бері,
   {{0xddc4003d,0x00000000,0x00000000,0x00000000}},	//   tliš, --, --, --,
   {{0xdb0e0caa,0x5bcb0274,0x682f008c,0x7d04322f}},	// [28f0] _debí, ећег_, _bødl, gvis,
   {{0xad9b130f,0x224b3230,0x6e2d3231,0x63ba3232}},	//   _saúd, lick_, skab, natn,
   {{0x09bc0083,0x7d043233,0x81cb0083,0x1a65006c}},	//   _ইউজা, avis, র্ণ_, لیسی_,
   {{0x63ba3234,0xdb07013c,0x98a919be,0xdb68002d}},	//   hatn, _rejä, šač_, урул_,
   {{0x212b3235,0x63ba27a6,0x61ff007a,0x3ce00043}},	//   nych_, katn, _maql, ctiv_,
   {{0x63ba0470,0xc7b80009,0x2ca9017b,0x224b3236}},	//   jatn, _dođo_, mpad_, hick_,
   {{0x63ba1cb0,0x224b3237,0xa2c004aa,0x2ca93238}},	//   datn, kick_, _विग्, lpad_,
   {{0x06090e60,0x212b016f,0x81cb0033,0xf6252dfa}},	//   тник_, kych_, র্ত_, рдио,
   {{0xe6160f99,0x63ba3239,0x680b0080,0x7d0020d9}},	//   рды_, fatn, _pēdē, _ámst,
   {{0x212b323a,0x63ba323b,0x13090086,0x661b014e}},	//   dych_, gatn, вной_, sjuk,
   {{0x35f51470,0x75290107,0x9f4c00a0,0x5fdc00b4}},	//   _впер, syez, ždú_, _बाबल,
   {{0x61ff0069,0x224b323c,0x7d04059c,0x64580a8a}},	//   _caql, gick_, yvis, _ejvi,
   {{0xd176323d,0x63ba005d,0xae000ccf,0x25ad323e}},	//   рыны, batn, _लोगन_, mbel_,
   {{0x7d04323f,0x98a00a78,0x645d02e1,0x03a5002d}},	//   vvis, šić_, ésid, _тико,
   {{0xc44700f5,0x6d5d0510,0x71a63240,0x9f53002a}},	//   _لیکن_, _axsa, _кайз, _paxá_,
   {{0x7d043241,0x3ce00484,0xfbb20033,0x27e000cd}},	//   tvis, ttiv_, _চাইত, đini_,
   {{0x212b006a,0x1c463242,0xeb9a05ac,0x6834009e}},	// [2900] cych_, анам, виз_, _làda,
   {{0x629e1ec0,0x69db0083,0x3ce03243,0xda0b0099}},	//   _époc, _acue, rtiv_, _सोबत_,
   {{0x3ce0273a,0x68fb3244,0x683401a6,0x00000000}},	//   stiv_, _asud, _nàda, --,
   {{0x09e63245,0x7d043246,0x09060b78,0x25ad01e4}},	//   родн, pvis, ипен, jbel_,
   {{0x63ba0388,0xb5fd3247,0x7d043248,0x2a6600be}},	//   yatn, tošn, qvis, roob_,
   {{0x25ad3249,0x69db0300,0xd90d0416,0x5694324a}},	//   ebel_, _ecue, عیل_, бакт,
   {{0x63ba07c4,0x212b004e,0x9f5812c3,0x27fe0044}},	//   vatn, zych_, ndrà_, _vatn_,
   {{0x2c0a02cb,0x27e90a78,0x63ba324b,0xddcd012e}},	//   _होतं_, đana_, watn, zmaž,
   {{0x63ba1298,0xb5fd0124,0x98a318cd,0x15e20ca1}},	//   tatn, pošn, _мите, क्षर_,
   {{0x3cf908a9,0x212b324c,0x6834009e,0xb05b191b}},	//   _उनसे_, vych_, _fàda, nrät,
   {{0x212b0755,0x25ad324d,0xdb1701ef,0x00000000}},	//   wych_, bbel_, taxé, --,
   {{0x2ca9324e,0x058609d0,0x212b324f,0x63ba3250}},	//   ypad_, _кулм, tych_, satn,
   {{0x224b3251,0x63ba005d,0x92580382,0x00000000}},	//   rick_, patn, раят_, --,
   {{0x212b3252,0xf1a70387,0x63ba0024,0x104b1303}},	//   rych_, _क्रन, qatn, тями_,
   {{0xe29700c9,0x25dd0299,0xc05802ce,0x645d3253}},	//   _кај_, क्की_, рія_, ésie,
   {{0x2ca90345,0xdda8002d,0xdd9402ee,0x682f0a8a}},	//   tpad_, итул_, жаты, _rødm,
   {{0xdb050082,0x63b8006d,0xb5fd3254,0x682f0a8a}},	// [2910] rbhí, _kevn, došl, _sødm,
   {{0x0ba700c7,0x2ca901bf,0xdd11009f,0xb05b02b1}},	//   ршам, rpad_, _iżże, träu,
   {{0x2ca90371,0xdb1500b5,0x68e2018d,0xddc40067}},	//   spad_, _kezé, etod, nniś,
   {{0x6298007b,0x63b801c0,0x2ca901ff,0x3a242e0f}},	//   _muvo, _levn, ppad_, _comp_,
   {{0x20012379,0xa3b60ca1,0xb05b02b1,0x290901ef}},	//   _kahi_, जरा_, sräu, íaa_,
   {{0x81dd00c8,0x63b801e0,0x9f5800de,0x7bdc0079}},	//   ড়ি_, _nevn, ldrá_, _gcru,
   {{0x26c13255,0xad9b03e6,0x62983256,0xab0400be}},	//   ého_, _gaúc, _nuvo, _ööpä,
   {{0xa2c00d00,0x200118ad,0xcf580bed,0x9f580033}},	//   _विज्, _lahi_, יבות_, ndrá_,
   {{0x81dd00c8,0x68fb3257,0x25ad3258,0x7bdc0103}},	//   ড়া_, _usud, rbel_, _ycru,
   {{0xc6e70a55,0x200103cb,0x224901a3,0x6298010b}},	//   _відп, _nahi_, _amak_, _buvo,
   {{0xd6db0202,0x2a7f0221,0x63b80359,0x9f5a027a}},	//   _шта_, _khub_, _devn, _capì_,
   {{0xf595004f,0x81cb0083,0x62983259,0x00000000}},	//   _الإج, র্স_, _duvo, --,
   {{0x2001325a,0x66ea00a8,0x7bc72a40,0xdb1500ac}},	//   _bahi_, _təkc, _odju, _dezé,
   {{0x2249325b,0xb21b008d,0x8fa317a3,0xa8790070}},	//   _emak_, lmæl, заре, טאָר,
   {{0x9e5a027a,0xdb1c0187,0x200100d0,0x00000000}},	//   граф_, _odrá, _dahi_, --,
   {{0x2a7f006d,0xb05b01ae,0x7bc7325c,0xdb0e00ac}},	//   _nhub_, tsäc, _adju, _nebá,
   {{0x3a240d35,0x6298033b,0x66ea00a8,0x68e20523}},	// [2920] _romp_, _zuvo, _məka, xtod,
   {{0xd37e011c,0xddcd0067,0x69d90051,0x999f0160}},	//   šćem_, gnał, egwe, _pluş_,
   {{0xb05b325d,0x5f06325e,0x3a24217f,0x9f5a0260}},	//   rrät, _узна, _pomp_, _enpò_,
   {{0xa2c00026,0xb05b013c,0x68e2325f,0x9acb00b5}},	//   _विघ्, srät, ttod, ادلہ_,
   {{0xa3d70f9f,0xdb0e01ef,0xb05b01ff,0xb5fd0506}},	//   िला_, _debá, prät, rošl,
   {{0xdca30aec,0x5a963260,0x6c360df3,0xc5e50083}},	//   _хари, _граф, _افسا, _খোলা_,
   {{0xfe1c11b5,0x63b83261,0xb5fd0254,0x3d0000be}},	//   _पचास_, _revn, pošl, रिके_,
   {{0xb8ce0b52,0x60c40254,0x63b808b7,0xf1bf00b5}},	//   _কি_, _ovim, _sevn, nkát_,
   {{0x62983262,0x63b80237,0xdb05027b,0x00000000}},	//   _suvo, _pevn, zahü, --,
   {{0x96ba3263,0x22493264,0x932600b5,0x62860051}},	//   _буду_, _smak_, مرجن, emko,
   {{0xe696004f,0x60c4005f,0xd5af3265,0x00000000}},	//   _الصد, _avim, _нс_, --,
   {{0xe7170052,0x80dd00c8,0x3cf90311,0xfbde0033}},	//   _לחבר_, যবস্, _उनले_, ড়িত,
   {{0x645d0473,0x067b0070,0xdb1500b5,0x857600b5}},	//   ésic, _ענדל, _vezé, _ادائ,
   {{0xdb1c01b4,0x25de221c,0x629800ea,0x234800d1}},	//   _idræ, _गाडी_, _tuvo, _پستی_,
   {{0xfbde0083,0x644a3266,0x9f3401e0,0xadbd010b}},	//   ড়াত, _imfi, пері, кавi,
   {{0x6602007c,0x2001023c,0x22493267,0x6a780453}},	//   _jaok, _wahi_, _umak_, dífo,
   {{0x20013268,0x61ed190b,0x6e260118,0xd7c80099}},	// [2930] _tahi_, _ibal, _dokb, रणाच,
   {{0x44e2008a,0xb6060274,0x81cb0083,0x09b3012f}},	//   ið_, lašć, র্শ_, ुण्य,
   {{0x99990812,0x60c4005f,0x2a7f0211,0x00000000}},	//   акет_, _zvim, _phub_, --,
   {{0x66023269,0x2a7f01e8,0x4975002d,0x27ec326a}},	//   _naok, _qhub_, олес, _abdn_,
   {{0x61ed326b,0x7bc300fb,0xa9690274,0x69d9326c}},	//   _mbal, ónus, јила_, rgwe,
   {{0xbcfb0248,0x16a9326d,0x27e90009,0xdb050079}},	//   _exéc, авки_, đano_, abhá,
   {{0xe73918eb,0x4639326e,0xb21b0093,0xdb1c008c}},	//   рей_, ичия_, tmæl, _adræ,
   {{0xe7f5004e,0x79e7006c,0xb5fd0a69,0x998600cd}},	//   _इसका_, _دورہ_, mošk, skoš_,
   {{0xb5fd1851,0x845903e6,0xd838021e,0x998d00f4}},	//   lošk, ирот_, _flč_, _fleš_,
   {{0x61ed09d6,0x72c5002d,0x00000000,0x00000000}},	//   _abal, обоз, --, --,
   {{0x60c4326f,0xfbd202b8,0x7c270009,0x61ed018e}},	//   _svim, ותי_, _mojr, _bbal,
   {{0x7c2701f4,0x290d3270,0xe5ef00c3,0x77610160}},	//   _lojr, _krea_, äkää, _ixlx,
   {{0x644f02e1,0x61ed01f7,0xd7e0046c,0x629e000d}},	//   écis, _dbal, _नामच, _épon,
   {{0x22590523,0x61ed3271,0x660201a0,0xdfd20037}},	//   ansk_, _ebal, _zaok, بيس_,
   {{0xa3a93272,0x81b90083,0xb5fd011c,0x44273273}},	//   गुण_, _চার_, jošk, _ion_,
   {{0x44273274,0xee373275,0x78a901c0,0xb5fd0097}},	//   _hon_, онс_, _otev, došk,
   {{0x4427069d,0x0c262626,0xec4a0086,0x9c260265}},	// [2940] _kon_, оман, азал_, одад,
   {{0x44273276,0x61ed3277,0x6e260051,0x00000000}},	//   _jon_, _zbal, _wokb, --,
   {{0x4427105d,0xb5fd2648,0x290d3278,0x7c270067}},	//   _mon_, gošk, _area_, _dojr,
   {{0x44273279,0x38c802fd,0x7bc3003e,0x00000000}},	//   _lon_, ماتی_, ónur, --,
   {{0x290d1ab8,0xa88a0714,0x442700c3,0xb05b327a}},	//   _crea_, айда_, _oon_, isän,
   {{0x4427327b,0x764b0297,0xb8f204e9,0x7c270345}},	//   _non_, _amgy, _वि_, _gojr,
   {{0xab2a0021,0xd838022f,0xd6d00037,0x290d09c5}},	//   _това_, _vlč_, رقة_, _erea_,
   {{0x44270f46,0x290d01ef,0x25bf327c,0xcf9300a5}},	//   _aon_, _frea_, gaul_, וטו_,
   {{0x4427327d,0x25eb0ccf,0xe4e602ce,0x290d00af}},	//   _bon_, _अउरी_, ційн, _grea_,
   {{0x4427327e,0x44e200fb,0x61ed2329,0x660208c7}},	//   _con_, rð_, _sbal, _waok,
   {{0xe7f7009a,0xd25100bf,0x4427327f,0x2be20099}},	//   ंजरा_, فند_, _don_, _पाना,
   {{0xe80201c0,0x92580421,0x00000000,0x00000000}},	//   लयका_, жают_, --, --,
   {{0x44273280,0xc21800d4,0x2689026e,0xb60600cd}},	//   _fon_, ією_, _اخلي_, rašć,
   {{0x44273281,0x9f4c05d3,0xdb1e0279,0xddcd0067}},	//   _gon_, ždý_, rapê, znań,
   {{0x764b0297,0xb6060129,0x62353282,0x61ed009e}},	//   _ymgy, pašć, _неку, _tbal,
   {{0x44273283,0xc7b8003a,0x61ed3284,0x443e011e}},	//   _zon_, _dođi_, _ubal, lht_,
   {{0x44273285,0x2d8f0446,0x645a3286,0xe04b00d1}},	// [2950] _yon_, äge_, onti, _نشده_,
   {{0x645a3287,0xb5fd00ac,0xfbab004b,0x44273288}},	//   nnti, tošk, ртай_, _xon_,
   {{0x682f008c,0x443e02b1,0xdefb00c7,0x00000000}},	//   _kødv, iht_, _тып_, --,
   {{0x290d0043,0xb5fd108a,0xf9c700d4,0x7b6401d3}},	//   _prea_, rošk, іщен, фтуе,
   {{0xf99016e6,0x8d873289,0x00000000,0x00000000}},	//   نبه_, _фунд, --, --,
   {{0x290d0043,0x7c3e033b,0x09340037,0x2be20099}},	//   _vrea_, chpr, برمج, _पाया,
   {{0x4427328a,0x2d9e0160,0x00000000,0x00000000}},	//   _ron_, _ştei_, --, --,
   {{0x44270147,0x682f177c,0x645a19a6,0x443e033b}},	//   _son_, _nødv, enti, eht_,
   {{0x60c90124,0xb5fd00ec,0x00000000,0x00000000}},	//   šemj, noši, --, --,
   {{0x443e01f3,0x442701e9,0x00000000,0x00000000}},	//   ght_, _qon_, --, --,
   {{0x4427328b,0xdb0e01ae,0xa82200d1,0x65620168}},	//   _von_, _gebä, _سکون, _exoh,
   {{0x645a328c,0xfc3f2556,0xb5fd23d9,0x442700a5}},	//   anti, _stíl_, koši, _won_,
   {{0x4427328d,0xfbcb022e,0x443e04e6,0x645a01e8}},	//   _ton_, ाणाम, bht_, bnti,
   {{0x443e328e,0x9f5a0382,0xb05b328f,0xc7b800cd}},	//   cht_, _papà_, ssän, _pođi_,
   {{0xe7ed134b,0x25bd0159,0xfbd2006c,0xdb1e0055}},	//   च्या_, _kewl_, ہتا_, rapë,
   {{0x9f4b00b5,0xc7b800cd,0x00000000,0x00000000}},	//   áját_, _vođi_, --, --,
   {{0xdb1c0279,0x62960159,0x229a00ea,0xb5fd3290}},	// [2960] _gerê, _iiyo, _rīki_, goši,
   {{0x62960848,0x7e760298,0x62840211,0x9f580031}},	//   _hiyo, slyp, _hhio, nerë_,
   {{0xeb97046e,0x62963136,0xfbe21604,0x4f9b00a5}},	//   чих_, _kiyo, _पाठम, _לביצ,
   {{0xdb1c01f4,0x9f580031,0x628700b8,0x83fc0009}},	//   _herë, herë_, ňkov, rođi,
   {{0x645a3291,0x62840094,0x62963292,0x6e241476}},	//   ynti, _mhio, _miyo, mjib,
   {{0x18673293,0x62962014,0x9f580031,0x00000000}},	//   пачи_, _liyo, jerë_, --,
   {{0x81d400c8,0xe3c30083,0xf1be0b35,0x8f9b0317}},	//   স্য_, ্ভাব, ्णान, זיצי,
   {{0x645a3294,0x62963295,0x6e3600c7,0xaad10355}},	//   wnti, _niyo, nkyb, _हितक,
   {{0x6d440133,0xa3d700a1,0x69c2022e,0xa4f80105}},	//   nzia, िलं_, maoe, تکار_,
   {{0x81b900c8,0x7bde03be,0x644f000d,0x53343296}},	//   _চাই_, ngpu, écip, деот,
   {{0x6284004a,0x62963297,0xe41a01ba,0x645a038e}},	//   _bhio, _biyo, _kľúč, rnti,
   {{0x443e071f,0x62843298,0xa77b0070,0xf3630144}},	//   sht_, _chio, _פראפ, этын,
   {{0x62963299,0x62840874,0x6d440221,0xdb150168}},	//   _diyo, _dhio, jzia, _rezí,
   {{0x6d44329a,0xc9530052,0xc05b2327,0x9f580055}},	//   dzia, תמש_, сім_, cerë_,
   {{0x6284003b,0x9f5a0831,0xb17b01b4,0x08770070}},	//   _fhio, _papá_, dgåe, פעלט_,
   {{0x33770052,0x6296329b,0x443c0019,0xdb1e00f7}},	//   _מתוך_, _giyo, _hlv_, capé,
   {{0xddcd0a78,0x7e6d0043,0x8d770037,0xdb1c0392}},	// [2970] glaš, roap, سارا, _herè,
   {{0xb5fd329c,0x629604fb,0xdb1c0260,0x7a330448}},	//   roši, _ziyo, _kerè, _içti,
   {{0x3cf91db6,0x6296329d,0x682f08c8,0x69c200e9}},	//   _उनके_, _yiyo, _mødt, faoe,
   {{0xddcd329e,0xdb1c01f7,0x69c20345,0x00000000}},	//   blaš, _merè, gaoe, --,
   {{0x8c3b02c9,0x443c329f,0x998401c0,0x23dd0bdd}},	//   _auße, _olv_, _domů_, _मालद,
   {{0x66ea0095,0xe8f800d8,0x443c0298,0xddc400f4}},	//   _təkl, ялі_, _nlv_, moiš,
   {{0x7d0d32a0,0x2be20380,0x26190066,0x00000000}},	//   lvas, _पाता, भाली_, --,
   {{0x443c32a1,0x00000000,0x00000000,0x00000000}},	//   _alv_, --, --, --,
   {{0x7d0d32a2,0x799b011e,0x629632a3,0x3a8400d8}},	//   nvas, _iguw, _riyo, _чырв,
   {{0x629632a4,0x628432a5,0x42c932a6,0xdb1c0107}},	//   _siyo, _shio, огон_, _berè,
   {{0xb05b022a,0xcfe30083,0x629630be,0x6d4432a7}},	//   rsäl, য়ান, _piyo, zzia,
   {{0x5eac0083,0x1c0a02cb,0xc7b80254,0x443c32a8}},	//   _ছিলে, _होईल_, _dođu_, _elv_,
   {{0xd0120332,0xdb1c00da,0xdb1e1bea,0x660932a9}},	//   پلز_, _perë, rapé, mdek,
   {{0x40950b12,0x660932aa,0xddcd011c,0xdb1c0176}},	//   ерст, ldek, vlaš, _ferè,
   {{0xdee332ab,0x6284009c,0xdb1c32ac,0x644132ad}},	//   кори, _thio, _verë, mhli,
   {{0x6d4406a2,0x799b32ae,0x7c3c0159,0xa3a92df6}},	//   tzia, _nguw, _slrr, गुर_,
   {{0x2be2022e,0x7d0d32af,0x00000000,0x00000000}},	// [2980] _पादा, gvas, --, --,
   {{0x6d4432b0,0x26c703ab,0x660900c3,0x7e6900cd}},	//   rzia, ksno_, hdek, čepa,
   {{0x7d0915b5,0x25de11b5,0x7d0d0421,0xf0930d85}},	//   _šest, _गाली_, avas, _שנת_,
   {{0xddcd00ea,0xceb302b8,0x8c480095,0xa2d532b1}},	//   plaš, _שיר_, _başç, _भिन्,
   {{0x81cb0083,0x61e432b2,0x201a012f,0x81d40033}},	//   র্ক_, _mcil, _knpi_, স্থ_,
   {{0x76aa32b3,0x9f5802e9,0x645d00f7,0x7a1e0160}},	//   отив_, terè_, ésil, _bătâ,
   {{0x6441060e,0x8c3b02c9,0x61e40009,0x66ea00a8}},	//   dhli, _fußb, _ocil, _təkm,
   {{0x81d40083,0x660932b4,0x60c900f4,0xa3b025d8}},	//   স্ত_, gdek, šemi, टुन_,
   {{0x6ad30083,0x69c00029,0x998d0187,0xb7bc00ea}},	//   _সহযো, _ieme, _pleť_, _loģi,
   {{0x69c032b5,0x29040024,0x644132b6,0x61e432b7}},	//   _heme, _isma_, ghli, _acil,
   {{0x69c00f1a,0x39460138,0x78a00371,0x27fc00e2}},	//   _keme, lzos_, _humv, mevn_,
   {{0x78a00232,0x51870210,0x2904010d,0x682f10db}},	//   _kumv, дуга, _ksma_, _føds,
   {{0x69c01201,0x394632b8,0x656f01ae,0xe5a30e9f}},	//   _meme, nzos_, ücht, _ричи,
   {{0x644102c9,0x69c032b9,0xbe05006c,0xdb0e002a}},	//   chli, _leme, کورٹ, _debú,
   {{0xfe730a72,0x9f4107e5,0xdb1c01f7,0x326702fb}},	//   ندر_, _xchè_, _feré, _отив,
   {{0x69c032ba,0xdb15024e,0xe50801a5,0x27e90a78}},	//   _neme, _nezá, _kỷ_, đani_,
   {{0xa2da20ab,0xddc40a4c,0x61fd02d4,0x78a00010}},	// [2990] पूर्, bliž, mesl, _numv,
   {{0x61fd32bb,0x3209067f,0x244002d0,0x4ea70819}},	//   lesl, _haay_, _fòme_, _орма,
   {{0x3ce915b5,0x69c032bc,0x290400d1,0x7d0d1e1f}},	//   stav_, _beme, _asma_, svas,
   {{0xfe3500c2,0x61fd32bd,0xdb05178d,0x78a00010}},	//   _נאָך_, nesl, nché, _bumv,
   {{0x69c008d7,0xadd602b8,0x290401a2,0x3209011e}},	//   _deme, _אורח_, _csma_, _maay_,
   {{0xa3b000be,0x69c032be,0x61fd00d5,0x682f1f8b}},	//   टुम_, _eeme, hesl, _røds,
   {{0x69c032bf,0x7bc532c0,0x645d3113,0x660928e9}},	//   _feme, mahu, ésim, tdek,
   {{0x69c010fb,0x7bc532c1,0xd90e006c,0xf1db0066}},	//   _geme, lahu, جیے_, _भागन,
   {{0x66090a99,0x644132c2,0x00000000,0x00000000}},	//   rdek, thli, --, --,
   {{0xc984292e,0x69c032c3,0x7bc50b04,0x61e40037}},	//   _руси, _zeme, nahu, _scil,
   {{0x69c032c4,0x3a3f0051,0x32090260,0x35b500d4}},	//   _yeme, _klup_, _baay_, _збер,
   {{0xcb1200c2,0x61fd0136,0x683412c3,0x6a780473}},	//   אלט_, gesl, _ràdi, tífi,
   {{0x7bc518ad,0x78a0006d,0x25b90093,0x68340176}},	//   kahu, _xumv, ðslu_, _sàdi,
   {{0x6a781d2b,0xf8b20122,0x3a2d32c5,0x7bc532c6}},	//   rífi, רשם_, _loep_, jahu,
   {{0xdb1c2e79,0x3a3f32c7,0x5e96004f,0x61fd32c8}},	//   _teré, _olup_, فلسط, besl,
   {{0xa3d70066,0x61e40e31,0x2be20099,0x66ea00a8}},	//   िलक_, _ucil, _पाहा, _səkk,
   {{0x409632c9,0xc692168d,0x7afb0129,0x69c032ca}},	// [29a0] _прот, ראן_, _ćuta, _reme,
   {{0x69c00ec0,0x7bc532cb,0x6cd30037,0x290400d5}},	//   _seme, gahu, اقلا, _rsma_,
   {{0x69c01201,0x224032cc,0x3a2d0345,0x00000000}},	//   _peme, _klik_, _boep_, --,
   {{0xc986190a,0x4ad10099,0x0f571804,0x9fb80033}},	//   нули, _हिरव, _טיים_, _জায়গ,
   {{0xa3cf0bdd,0x7bc532cd,0x69c00031,0x3a2d0345}},	//   षणा_, bahu, _veme, _doep_,
   {{0x26dc32ce,0x394632cf,0x7bc532d0,0x66ea00a8}},	//   tuvo_, rzos_, cahu, _həki,
   {{0x8c1b00c2,0x316c004e,0x81cb0083,0x78a001d5}},	//   _צולי, ędzy_, র্ট_, _wumv,
   {{0x3a3f0bde,0x9b1700a5,0x7c2e32d1,0xddd100c7}},	//   _glup_, _אחלה_, _hobr, _įgūd,
   {{0x7c2e32d2,0x61fd32d3,0xb21b08c8,0xc7b80207}},	//   _kobr, vesl, llæg, _anđe_,
   {{0xb8060332,0xb05b022a,0x224032d4,0x733808ce}},	//   _سکتے_, rsäk, _alik_, дзор_,
   {{0xb21b221b,0x7c2e09c8,0x224032d5,0x1de10864}},	//   nlæg, _mobr, _blik_, _फालत,
   {{0x64a62dc5,0xe5080028,0xb0a50084,0x60dd127d}},	//   _зада, _tỷ_, _गंदग, tusm,
   {{0xdb0532d6,0x61fd0c7d,0x7bc52eb4,0xe5080019}},	//   rché, resl, yahu, _uỷ_,
   {{0x7c2e32d7,0x3209010d,0xdb05026e,0x61fd00a8}},	//   _nobr, _waay_, sché, sesl,
   {{0xb5fd0bc6,0x60dd00ab,0xddc40035,0x61fd00b5}},	//   pošt, susm, bliż, pesl,
   {{0x442e02c0,0xa2d5000c,0x7bc50054,0xb21b01b4}},	//   _hof_, _भित्, wahu, dlæg,
   {{0x5c75081b,0x3a2d053e,0x3d1b0035,0x25f3021a}},	// [29b0] влат, _roep_, नमें_, ्जती_,
   {{0xddeb01ca,0xe1ff32d8,0x7c2e1adb,0x60cd0371}},	//   _کرده_, leó_, _cobr, _ivam,
   {{0x7c2e0b9a,0x7bc532d9,0x2be202d1,0xfbe232da}},	//   _dobr, rahu, _पारा, _पारम,
   {{0x7bc50991,0x442e32db,0xe1ff02d7,0x60cd32dc}},	//   sahu, _lof_, neó_, _kvam,
   {{0x7bc50f3a,0xbddb0443,0x8d8432dd,0xe0df027a}},	//   pahu, _elèc, _бурд, nuò_,
   {{0x81cb0b52,0xbddb2870,0x442e03d0,0x60cd0027}},	//   র্চ_, _flèc, _nof_, _mvam,
   {{0x1c0a3123,0x6e2f023a,0x683400f1,0xddcd0067}},	//   _होटल_, _kocb, _nàdu, miał,
   {{0x7c2e2ab5,0x60cd011c,0xb9070831,0x00000000}},	//   _zobr, _ovam, _বন_, --,
   {{0xe1ff006c,0x98f40041,0x442e32de,0x3ceb0176}},	//   deó_, _مثلا, _bof_, _jqcv_,
   {{0x442e00e9,0x22400044,0xddcd0035,0x9f580036}},	//   _cof_, _slik_, niał, ferì_,
   {{0x60cd00ab,0xb21b32df,0x22400035,0x33f40409}},	//   _avam, klæd, _plik_, учыс,
   {{0x6b9a0093,0x81cb0033,0x6e2f009e,0x355201cb}},	//   _útge, র্ঘ_, _nocb, انیز,
   {{0xf1bf006c,0xa5092b21,0x7e6900cd,0xdd010355}},	//   pján_, _цела_, čepl, čtět,
   {{0x03a20c06,0xd4790070,0x7afb0009,0x628f0345}},	//   _кишо, _קאַל, _ćutn, amco,
   {{0xe45602b5,0x60cd32e0,0x660b011e,0x00000000}},	//   _ביסט_, _evam, _kagk, --,
   {{0xb17b013c,0x28d20b54,0x660b0069,0x224001e0}},	//   mgån, _सिलि, _jagk, _ulik_,
   {{0xed570610,0x660b32e1,0xada332e2,0xdca31d80}},	// [29c0] вот_, _magk, раул, иати,
   {{0x21370070,0x1c1c007c,0x660b24ec,0x14d40099}},	//   _סטיל_, नाइल_, _lagk, _दिसण,
   {{0x9f480086,0x8b96280a,0x403b32e3,0x2b39002d}},	//   ähän_, трач, _חגיג, няцэ_,
   {{0x660b03a2,0xb21b32e4,0xd8380124,0x281300fd}},	//   _nagk, rlæg, _miče_, یونس,
   {{0x61f600da,0xd94607b0,0x7c2e32e5,0x7e660051}},	//   _mbyl, ъеди, _tobr, _ijkp,
   {{0xddcd004e,0x98730eb9,0x7d0401d5,0x7c2e00cd}},	//   ciał, аліц, mwis, _uobr,
   {{0x442000e8,0x7d0432e6,0x660b32e7,0x442e32e8}},	//   _đi_, lwis, _bagk, _rof_,
   {{0x442e32e9,0x261932ea,0xb17b01ff,0xddcd00ac}},	//   _sof_, भागी_, dgån, plať,
   {{0x18a62dc5,0x2ca60082,0x57ea0279,0x660b32eb}},	//   _разм, íodh_, _одам_, _dagk,
   {{0xdb1c01ef,0x6a780d9b,0x68340176,0xd83820dc}},	//   _lerí, rífu, _pàdu, _biče_,
   {{0x60cd32ec,0x7d0432ed,0x442e0223,0x9f5802d7}},	//   _svam, hwis, _vof_, ferí_,
   {{0x7d0432ee,0xddcd0035,0x9f580453,0xd8380207}},	//   kwis, ział, gerí_, _diče_,
   {{0x442e32ef,0x628f01e4,0x6e2f32f0,0x660008c7}},	//   _tof_, rmco, _rocb, memk,
   {{0x660032f1,0x6e2f0023,0x2440021e,0xe1ff02d7}},	//   lemk, _socb, _fòma_, seó_,
   {{0x9259049f,0x6738006c,0x9f5301ef,0xbcfb0176}},	//   _пакт_, nyvj, _raxó_, _txék,
   {{0x6d0e083f,0xd2580043,0x30a732f2,0x6aa1002a}},	//   सिंग_, _аць_, _иров, _élfi,
   {{0xd90407e4,0x2d5803ad,0xebc703fa,0x50670409}},	// [29d0] _بی_, вить_, вљен, _атна,
   {{0x764232f3,0x5fb71db1,0x2259057f,0x61f60355}},	//   _lloy, _अभिल, lisk_, _zbyl,
   {{0x9f3503d0,0xddcd004e,0x98b800ea,0x0ba40dc8}},	//   _сені, riał, _ārā_, ршум,
   {{0x225902df,0x629e0248,0x7f3a0319,0xddcd0035}},	//   nisk_, _épou, _נערו, siał,
   {{0x4dda02da,0xdb1c2ec6,0xbd6b0274,0x00000000}},	//   _אחרו, _cerâ, _црне_, --,
   {{0xd3660a42,0x764232f4,0x660b32f5,0xb8cb060a}},	//   _هه_, _aloy, _sagk, _गढ_,
   {{0x660b132a,0xf0940070,0x00000000,0x00000000}},	//   _pagk, בנס_, --, --,
   {{0x2bcb2f41,0xf50932f6,0x3eb300e2,0xda0b007c}},	//   ाणका, енил_, _mtxt_, _सोचत_,
   {{0x22591e54,0xdb050079,0x03a527eb,0xb05b02b1}},	//   disk_, ichí, липо, lsäu,
   {{0x2c1c0035,0x58871ac5,0x76420107,0x660b0298}},	//   नाएं_, _рыба, _eloy, _wagk,
   {{0x7d0432f7,0x2259177c,0xc7350a86,0x660b32f8}},	//   zwis, fisk_, _حفاظ, _tagk,
   {{0x225902df,0x764205a4,0xd83800cb,0x7d040035}},	//   gisk_, _gloy, _viče_, ywis,
   {{0x5156005f,0x51550183,0x00000000,0x00000000}},	//   утну, атру, --, --,
   {{0xdb1c32f9,0xdee632fa,0xc5e30084,0xd83802f0}},	//   _serí, логи, _गाँठ_, _tiče_,
   {{0xdb1c32fb,0x00000000,0x00000000,0x00000000}},	//   _perí, --, --, --,
   {{0x25ad32fc,0x6d4101c2,0x7d0432fd,0x200c18a8}},	//   ncel_, _əlav, twis, ždi_,
   {{0xdb1c32fe,0x0d8632ff,0x00000000,0x00000000}},	// [29e0] _verí, улан, --, --,
   {{0x7d043300,0x66000076,0xc0063301,0x629e0443}},	//   rwis, zemk, _спок, _èpoc,
   {{0xdb1c3302,0x91a93303,0x41b80026,0x68fb011e}},	//   _terí, _hoá_, _आभास, _apud,
   {{0x66ea01c2,0x61e60703,0x9f583304,0x98a60036}},	//   _məkt, ngkl, merà_, гиде,
   {{0x9f5807e5,0xc7b800cd,0xbddb00e0,0xed36002d}},	//   lerà_, _anđa_, _klèn, _сэнэ,
   {{0xdcfd0029,0x6d4800a8,0xbddb0118,0xd37e0124}},	//   _uzsā, _ədal, _jlèn, šćim_,
   {{0xf1ba0028,0x9f5807e5,0x66003305,0xb5fd3306}},	//   _đơn_, nerà_, temk, tošp,
   {{0x7e643307,0x9634316d,0xfb1b011d,0xb05b01ff}},	//   nnip, рниц, _אולמ, lsät,
   {{0x3d170243,0x896613ad,0x9f580382,0xa3cf00e7}},	//   निये_, _скаж, herà_, षणं_,
   {{0x261900a1,0xb05b3308,0x64430211,0x545402fb}},	//   _मोठी_, nsät, _clni, рвот,
   {{0x225902df,0x7e643309,0xa3e50cc5,0xb893004f}},	//   tisk_, knip, _फार_, _اللع,
   {{0x9f580382,0xbb3b0070,0x6443151c,0xdb050132}},	//   derà_, געטי, _elni, lchã,
   {{0x225902df,0xf1bf006c,0x25f30963,0xc6930319}},	//   risk_, lják_, ्जरी_, _האף_,
   {{0x225902df,0x43940009,0xdb1e02d7,0x7afc07e7}},	//   sisk_, _калс, zapá, _oprt,
   {{0x645a330a,0x213901f4,0x22592895,0xb05b330b}},	//   miti, sysh_, pisk_, dsät,
   {{0x442c330c,0x443e330d,0x7e64011e,0x31660009}},	//   ljd_, lkt_, gnip, _žoze_,
   {{0xdc5511b9,0x28c61fe0,0x26c1006c,0x5d9900d8}},	// [29f0] авањ, रीमि, ához_, ткаў_,
   {{0x645a330e,0x443e330f,0x2ca90024,0xe7e016d3}},	//   niti, nkt_, rqad_, _नागप,
   {{0x443e3310,0xcb550202,0xdb0e01ae,0xdb1c0310}},	//   ikt_, јвећ, _gebü, _cerà,
   {{0xdb1c0370,0x645a3311,0x39153312,0x20033313}},	//   _serã, hiti, имер, leji_,
   {{0x628d111c,0x645a3314,0xfc3f0037,0x443e3315}},	//   _mhao, kiti, _dtír_, kkt_,
   {{0x443e04ce,0x7c3e3316,0x645a3317,0xccf200a5}},	//   jkt_, ckpr, jiti, _וכך_,
   {{0xfc3f3318,0x645a3319,0xdb1c03e6,0xaa9500d4}},	//   _guía_, diti, _verã, _вивч,
   {{0x6e2d331a,0x443e331b,0xceb41899,0xea63006c}},	//   njab, ekt_, זיק_, _اپری,
   {{0x645a331c,0x7bc70464,0xdb1c03e6,0x6d4d331d}},	//   fiti, _keju, _terã, nzaa,
   {{0x69cb1173,0x6448331e,0xdb1c2cad,0x7bc7331f}},	//   lage, ghdi, _herá, _jeju,
   {{0x20033320,0x60dd0d35,0x38ab0249,0x32020501}},	//   deji_, ersm, _hør_, teky_,
   {{0x628d3321,0x69cb3322,0x7bc73323,0x9f580382}},	//   _chao, nage, _leju, verà_,
   {{0x645a3324,0x628d1093,0x9f583325,0x2003042a}},	//   biti, _dhao, derá_, feji_,
   {{0x443e08f9,0x69cb3326,0x9f583327,0x6d4d3328}},	//   ckt_, hage, terà_, dzaa,
   {{0x628d0014,0x7e561018,0x69cb3329,0x38ab0249}},	//   _fhao, атац, kage, _lør_,
   {{0x628d02a8,0x9f58332a,0xa0a60336,0x6da300af}},	//   _ghao, rerà_, _каид, жита,
   {{0x69cb332b,0x64860093,0xb05b1535,0x753b0010}},	// [2a00] dage, iðin, tsät, nyuz,
   {{0x9f5807e5,0xdb1c0037,0x765b043d,0x0c23290e}},	//   perà_, _aerá, hiuy, омун,
   {{0xb05b06d2,0x9f58332c,0x7c3e0051,0x2e3c0093}},	//   rsät, berá_, rkpr, _lífi_,
   {{0x645a332d,0x9f5808c0,0x38ab177c,0x644800da}},	//   ziti, cerá_, _bør_, zhdi,
   {{0x764900e0,0x3940332e,0x443e01e0,0x645a0273}},	//   dhey, áis_, ykt_, yiti,
   {{0x26dc0274,0x645a332f,0x2c1c004e,0xf1bf006c}},	//   trvo_, xiti, नाओं_, tják_,
   {{0x69cb3330,0x645a3331,0x12e00083,0x3940010b}},	//   bage, viti, _বন্দ, šis_,
   {{0x26190fd1,0x38ab1953,0x69cb3332,0x20033333}},	//   _मोदी_, _før_, cage, zeji_,
   {{0x38ab0022,0x645a3334,0xd9431964,0x644819f4}},	//   _gør_, titi, _дети, thdi,
   {{0x628d009c,0x9f5801ba,0x443e1715,0x7e690124}},	//   _shao, zerá_, ukt_, čepi,
   {{0x645a3335,0x443e3336,0xd5af0112,0x7afb0009}},	//   riti, rkt_, _мс_, _ćutk,
   {{0x443e0161,0x645a3337,0x64483338,0xdb1c0042}},	//   skt_, siti, shdi, _xerá,
   {{0x645a2ce7,0x9f580370,0x68e4004a,0xc05b00d4}},	//   piti, verá_, àidh, вів_,
   {{0x02a61dc2,0x60c4046a,0x69cb3339,0xc05b00d4}},	//   _крим, _dwim, zage, тім_,
   {{0x628d1093,0x69cb333a,0x44f0333b,0x28c623f0}},	//   _thao, yage, là_, रीति,
   {{0x7bc70f1a,0x69cb0183,0xb05b00c3,0x2003023c}},	//   _seju, xage, tsäs, seji_,
   {{0x7bc7005d,0xdb05290b,0x44f0333c,0x629f0248}},	// [2a10] _peju, dchá, nà_, _époq,
   {{0xdb1c0f56,0x69cb333d,0x6d4d0120,0x6aa0009e}},	//   _será, wage, rzaa, _aimf,
   {{0x69cb333e,0xc7b80124,0x6486008d,0x15f80d1f}},	//   tage, _anđo_, yðin, ्जार_,
   {{0xceb2012b,0xe0df0036,0xbddb0359,0x6d4d0051}},	//   _מיט_, orò_, _klèm, pzaa,
   {{0xdb1c333f,0xe9d800d8,0x798000e9,0xa3d62218}},	//   _verá, ркі_, _cymw, िणा_,
   {{0x44f00392,0xdb050037,0xb8cf018d,0xfd96024b}},	//   dà_, achá, _ऐं_, _לדרך_,
   {{0x76493340,0xdb1c0f2d,0x61ed0096,0xb9e701e0}},	//   they, _terá, _ocal, _візи,
   {{0x81cc0083,0x7c3502c4,0x683d0443,0x38ab01b4}},	//   _লাভ_, _hozr, _mèdi, _tør_,
   {{0x648600fb,0x7980001e,0xf80700d4,0xf1bf00d5}},	//   rðin, _gymw, _вчен, dbá_,
   {{0xe0df07e5,0x61ed2127,0x7649034d,0x60c404fb}},	//   drò_, _acal, shey, _rwim,
   {{0x78a90033,0x9f5812c3,0xe0df027a,0x60c43341}},	//   _huev, merç_, erò_, _swim,
   {{0x78a13342,0x66ea00a8,0x44f00392,0xa91d00ee}},	//   _hilv, _təkr, bà_, _tyžd,
   {{0x78a93343,0x25bf3344,0xf6743345,0xfc3f3346}},	//   _juev, mbul_, _بالخ, _ruín_,
   {{0x78a90831,0xf1bf0279,0x25bf3347,0x7e7d0260}},	//   _muev, abá_, lbul_, _aksp,
   {{0x7ae5007c,0xddcb011c,0xe0df027a,0xf1bf00b5}},	//   juht, _šiša, arò_, bbá_,
   {{0x25bf0723,0x64413348,0xf8a500bf,0x290d3349}},	//   nbul_, lkli, _يک_, _osea_,
   {{0x78a90b52,0x6441334a,0xa3ae073f,0x1c46005f}},	// [2a20] _nuev, okli, _कलम_, бнам,
   {{0xeb9a0036,0xdd8f197c,0x09d000a1,0x3212010d}},	//   гиз_, رول_, हण्य, _hayy_,
   {{0xdb1c334b,0x7c3528f9,0xb09b0122,0x6441334c}},	//   _merç, _dozr, _תייר, ikli,
   {{0xd9100164,0x64411ca0,0xdb1e194e,0x281900b5}},	//   ویز_, hkli, vapä, یفنگ_,
   {{0x78a905c9,0x6441334d,0x78a11cdb,0xda1d046c}},	//   _cuev, kkli, _bilv, फाजत_,
   {{0x78a10ae0,0x44f0334e,0xaad10437,0xfc44006c}},	//   _cilv, và_, _हिचक, _بھرپ,
   {{0x61b80084,0x56941195,0x6aa00312,0x644109e1}},	//   _आभूष, оакт, _timf, dkli,
   {{0x44f0334f,0xc8e00299,0xbb3b02b5,0x44b400d4}},	//   tà_, _निपट, _געלי, обис,
   {{0xdb1c0279,0x7afb011c,0x3ebf0124,0x28d20067}},	//   _berç, _ćuti, ćuti_, _सिटि,
   {{0x44f03350,0x61ed3351,0xe0df07e5,0x15ea00dc}},	//   rà_, _scal, vrò_, _टावर_,
   {{0x6d4101c2,0xd764006c,0x533402c1,0x44f00392}},	//   _əlaq, _بنای, цент, sà_,
   {{0x64410173,0x3ea2004e,0xe0df07e5,0x78a13352}},	//   akli, _nikt_, trò_, _zilv,
   {{0xdb1c0086,0xf5960037,0xa3d4058f,0x683d0260}},	//   _herä, _الشج, _долч, _sèdi,
   {{0x64413353,0xdb1c3354,0xe0df07e5,0x61ed0035}},	//   ckli, _gerç, rrò_, _wcal,
   {{0x62350369,0x7c3512ad,0xc0580131,0xce6b3355}},	//   _меку, _rozr, сія_, град_,
   {{0x4caa0083,0xe0df027a,0x61ed013b,0xddcd0124}},	//   _চৌধু, prò_, _ucal, slaž,
   {{0x7c35016f,0x3ea23356,0xdd94004b,0x00000000}},	// [2a30] _pozr, _dikt_, заты, --,
   {{0x4d9815eb,0x9f5a2b01,0x2d823357,0x99ba0033}},	//   скую_, _capó_, _dyke_, ুলোক,
   {{0x78a93358,0x25a60183,0xa91d0a66,0x00000000}},	//   _suev, _ogol_, _izži, --,
   {{0x78a13359,0x3a240183,0x7e990ef2,0x7ae5335a}},	//   _silv, _cnmp_, _خنجر_, ruht,
   {{0xbcfb335b,0x7c870705,0x78a1335c,0x7ae518af}},	//   _exér, _гуве, _pilv, suht,
   {{0x8aa702f3,0xdb1c022a,0xe739224c,0xdd31004e}},	//   _град, _berä, иел_, zęśc,
   {{0x81d40b52,0x6486003e,0xa6b40033,0x2249335d}},	//   স্ট_, rðil, _টিউট, _olak_,
   {{0x25a60069,0xb05b02b1,0x62560097,0x00000000}},	//   _cgol_, lpäd, lšov, --,
   {{0x78a1335e,0x893704e8,0x6441335f,0x3212028b}},	//   _tilv, _اعزا, tkli, _rayy_,
   {{0x22493360,0xf9903345,0x99480037,0x26191ca8}},	//   _alak_, _سبق_, _الكل_, _मोरी_,
   {{0x64413361,0xdb1c02c9,0x22493362,0xb21b04f2}},	//   rkli, _gerä, _blak_, rlæn,
   {{0x81e200c8,0x28e004eb,0x64413363,0x28c60e61}},	//   ন্ন_, _निमि, skli, रीवि,
   {{0xa2d523db,0xdb1c0370,0xbddb0359,0x22490116}},	//   _भिक्, _terç, _elèk, _dlak_,
   {{0x22493364,0xe7ed0387,0x3ea215ed,0x2d820b88}},	//   _elak_, च्चा_, _sikt_, _ryke_,
   {{0x2013012f,0x032500d4,0x7d1d0051,0x8fa318cd}},	//   _daxi_, _єдин, _arss, даре,
   {{0x00e616e2,0x3f8400ea,0xdcf72135,0x00000000}},	//   _джин, āmu_, ुबंध_, --,
   {{0x3ea2013c,0x2cb90345,0xb5fd00ac,0x00000000}},	// [2a40] _vikt_, _ctsd_, jnšm, --,
   {{0x62863365,0x2a7f0a4e,0xc8e00066,0x24400211}},	//   llko, _akub_, _निबट, _còmh_,
   {{0x6da607c1,0x3ea200ea,0xe7ed05f7,0x2440009e}},	//   _мина, _tikt_, च्छा_, _dòmh_,
   {{0xdb1c017b,0x00000000,0x00000000,0x00000000}},	//   _nerå, --, --, --,
   {{0xa3e902cb,0x15e300c4,0xa96a0009,0x00000000}},	//   यला_, _गाजर_, шида_, --,
   {{0xd6da3366,0xdb1c0086,0x6f1e00ee,0x20130065}},	//   ати_, _perä, _krpc, _xaxi_,
   {{0x27e00723,0x81e20083,0xdca30923,0x2a7f0118}},	//   ğin_, ন্য_, _цари, _fkub_,
   {{0x91e60bc1,0xdb1c02c9,0x27e004d4,0xa5341d9f}},	//   _कागज_, _verä, şin_, знич,
   {{0xd4062294,0x28c6018d,0x746a3367,0x00000000}},	//   ояни, रीशि, иров_, --,
   {{0x81e20083,0x69c23368,0xdb1c00c3,0xb35400d4}},	//   ন্ম_, lboe, _terä, зкош,
   {{0x22493369,0x28c60567,0x683d01f7,0x68e40079}},	//   _plak_, रीरि, _cèdu, áidf,
   {{0x64a6336a,0x69c20120,0x68e2023c,0x00000000}},	//   _дада, nboe, orod, --,
   {{0x2249336b,0x1a9b00c2,0x2beb25de,0x62560187}},	//   _vlak_, ייטע, _चालू_, yšov,
   {{0x9f5a02e9,0x62863118,0x6e260282,0x741400f8}},	//   _rapò_, alko, _ankb, _روبا,
   {{0xd838008b,0x69c20b0d,0x2ca301e4,0x38b00284}},	//   _moč_, kboe, _rijd_, _làr_,
   {{0x2cb90526,0x68e2336c,0x2249336d,0xa91d0355}},	//   _ptsd_, krod, _ulak_, _lyža,
   {{0xa3ae2450,0x5d5506c2,0x6b9a008d,0xfbab2374}},	// [2a50] _कला_, чкат, _útgj, атей_,
   {{0x68e2336e,0x64dd00a1,0xd838008b,0xb5fd082d}},	//   drod, _मिसळ, _noč_, miše,
   {{0x625600ac,0xb5fd336f,0x656400d5,0x00000000}},	//   ršov, liše, _žihl, --,
   {{0xc33302b5,0x69c2152b,0x244002d0,0x68e2016e}},	//   ווע_, gboe, _dòmi_, frod,
   {{0x2ca304ce,0x68e2004e,0x62560187,0x38b00284}},	//   _tijd_, grod, pšov, _càr_,
   {{0xd7fb00af,0x7d0d3370,0x9f58027a,0x38b0009e}},	//   руд_, mwas, ffrè_, _dàr_,
   {{0x3ffc00c2,0x44290028,0xe7393371,0x7d0d3372}},	//   יפגע, _đa_, сей_, lwas,
   {{0x68e22d5b,0xecdf004e,0x38b0009e,0xdb170042}},	//   brod, _फटाफ, _fàr_, saxó,
   {{0xdb0502bf,0x81e200c8,0x83fc042a,0x7d0d3373}},	//   schä, ন্ড_, ziđe, nwas,
   {{0xd8380009,0x7d0d067f,0x78bb021d,0x28e022c7}},	//   _goč_, iwas, _ituv, _निति,
   {{0x59cf0517,0x3ce90189,0x7d0d3374,0x5884010b}},	//   _हजार, huav_, hwas, _цыта,
   {{0x64c510ab,0x7d0d01a8,0x80b30083,0x83fc0254}},	//   _فيصل, kwas, _জিজ্, viđe,
   {{0x271c0023,0x66093375,0xbddb3376,0xe56e027a}},	//   _ảnh_, meek, _glèi, _чз_,
   {{0x66093377,0xdb15033b,0xbddb0107,0xa879016b}},	//   leek, _bezü, _klèw, מאָר,
   {{0x44273378,0xe29a3379,0x00000000,0x00000000}},	//   _inn_, _лак_, --, --,
   {{0x6f1e00cb,0xb5fd0009,0x7c270118,0x6609337a}},	//   _vrpc, biše, _anjr, neek,
   {{0x7d0d01a2,0x28e000b4,0x78bb0027,0x229b02d4}},	// [2a60] gwas, _निधि, _ntuv, _cūku_,
   {{0x69db0453,0x8b960eee,0x6609337b,0xac831858}},	//   _adue, преч, heek, егул,
   {{0x103b00a5,0x69c219c1,0xd83800d5,0x291f2cee}},	//   _הגיע, tboe, _roč_, _arua_,
   {{0xdca60ea6,0x200a337c,0x2018337d,0x44270211}},	//   _нами, lebi_, ldri_, _lnn_,
   {{0x4427337e,0x291f004f,0x69c22c59,0xb05b007c}},	//   _onn_, _crua_, rboe, späe,
   {{0xe8160084,0x68e2337f,0x69c209a6,0x200a26b4}},	//   _धोखा_, rrod, sboe, nebi_,
   {{0xa91d024e,0x7bdc0034,0x1c0202e4,0xa09b0070}},	//   _vyža, _idru, _रॉयल_, זיסט,
   {{0x44273380,0x81e20b52,0x54b81583,0xbddb0118}},	//   _ann_, ন্ত_, огия_, _dlèw,
   {{0x7bce0464,0x48e3117a,0x291f01f4,0x44273381}},	//   _kebu, _потв, _grua_, _bnn_,
   {{0xb5fd0254,0x200a022f,0x7bce00d1,0x2b0000ab}},	//   više, jebi_, _jebu, _ईहाँ_,
   {{0x67bb00a5,0xf3660dba,0x212000e0,0x442700cc}},	//   _המבק, ятин, _arih_, _dnn_,
   {{0x44270bd1,0x7bce3382,0x3ce9006d,0xb5fd0478}},	//   _enn_, _lebu, yuav_, tiše,
   {{0x3ce9006f,0xbddb0107,0xba57016b,0x7bdc1aa5}},	//   xuav_, _klèv, לסטו_, _odru,
   {{0x7bce3383,0xb5fd18b0,0xc05800d8,0x4427053e}},	//   _nebu, riše, піс_, _gnn_,
   {{0x212002c4,0xff042698,0x54330416,0x81e20033}},	//   _erih_, нятн, _سرور, ন্ধ_,
   {{0xb5fd3384,0x7d0d3385,0x7bdc00d7,0x00000000}},	//   piše, twas, _adru, --,
   {{0xf1c3009a,0x7bce3386,0x6256010b,0xdcef00ea}},	// [2a70] _व्यन, _bebu, ršot, _izcī,
   {{0x81e200c8,0xfbab00c7,0x6609276d,0xe0df02d0}},	//   ন্দ_, стай_, zeek, ryòd_,
   {{0x29040176,0x78bb0c7d,0x3ce90221,0x7ac4002d}},	//   _apma_, _stuv, suav_, есче,
   {{0xdb15024e,0xfd1f01a5,0x61ef00cc,0x320b3387}},	//   _sezó, _trì_, ngcl, necy_,
   {{0x9f510831,0xdb050079,0xdb1502d7,0x00000000}},	//   pezó_, nchú, _pezó, --,
   {{0x7bce3388,0x66093389,0xdb1502d0,0x6fbf0096}},	//   _gebu, week, _dezò, ्रिं,
   {{0x660909d6,0xb5fd0009,0xdb050079,0xac940dde}},	//   teek, lnši, hchú, _чарш,
   {{0x7e6d338a,0x7bdc338b,0x7bce1f55,0x291f338c}},	//   nnap, _zdru, _zebu, _trua_,
   {{0x660902e6,0x5fbf052b,0x81cc0083,0x14dd00a1}},	//   reek, ्राल, _লাল_, _मिळण,
   {{0x68e40514,0x66091c85,0x7e6d338d,0x6f05023a}},	//   áide, seek, hnap, _ophc,
   {{0xe29a338e,0xc7b200a5,0x44270023,0x7e6d338f}},	//   жан_, _סבא_, _vnn_, knap,
   {{0xd9ff0d00,0x2001012f,0x1fc60026,0x21200009}},	//   ोजित_, _abhi_, वर्ड, _prih_,
   {{0x7e6d3390,0x68eb02b3,0xd4350037,0x4427055c}},	//   dnap, nugd, _يعتب, _tnn_,
   {{0x67210c99,0xa91d0187,0xe80009b1,0x28e0018d}},	//   _krlj, _lyžo, ल्पा_, _निसि,
   {{0x7bce3391,0xa0a30fc5,0x7bc5009e,0x10a33392}},	//   _rebu, тард, dbhu, тирн,
   {{0x7bce203f,0x7ae5003a,0x7bdc00b8,0x6721011c}},	//   _sebu, drht, _sdru, _mrlj,
   {{0x6aae3393,0x7bce012f,0x62843394,0x2bb207b5}},	// [2a80] _subf, _pebu, _ikio, _जलदा,
   {{0x1daa1ea9,0x672100f4,0xfce30b25,0xdb150260}},	//   _कलकत, _orlj, тофо, _rezò,
   {{0x3cea0084,0x28e0017f,0xaaba132d,0x00000000}},	//   _चमके_, _निहि, زدار_, --,
   {{0x1bf00084,0x7bce3395,0x53360070,0x00000000}},	//   _चावल_, _webu, ונען_, --,
   {{0x7bce3396,0x83fc0009,0x644f00ea,0x6284023c}},	//   _tebu, hiđa, īcij, _mkio,
   {{0x7bdc01cc,0x67210506,0x59cc01c0,0x888400ff}},	//   _udru, _brlj, ारहर, ریان,
   {{0x2bc421b2,0x68e40079,0xb17b0542,0x28e0074f}},	//   _ल्या, áidb, ngår, _निवि,
   {{0x44201a24,0x1514145f,0x7c3c03e9,0x672100cd}},	//   _şi_, едия, _horr, _drlj,
   {{0x7c3c3397,0x6d441096,0xd838011c,0x04170033}},	//   _korr, nyia, _liči_, তানী_,
   {{0x03f803fa,0x62840054,0x7c3c01d7,0xdb1c0c61}},	//   чној_, _akio, _jorr, _berø,
   {{0x7c3c3398,0x6fbf25de,0xbddb0260,0x672100f4}},	//   _morr, ्रसं, _klèt, _grlj,
   {{0x7c3c3399,0x81e20083,0x63ad339a,0x68ed010b}},	//   _lorr, ন্স_, _şant, žodž,
   {{0x61fd0093,0xbddb0118,0x7c3c03bc,0x00000000}},	//   rfsl, _mlèt, _oorr, --,
   {{0x7c3c330b,0xb5fd0124,0x628401ed,0x75220027}},	//   _norr, miša, _ekio, _iroz,
   {{0xe800134b,0x9f5f0723,0x7522024e,0x7e6d339b}},	//   ल्या_, _ürün_, _hroz, tnap,
   {{0x443c339c,0x7e64010d,0x752200f4,0xd8380207}},	//   _hov_, giip, _kroz, _diči_,
   {{0x443c339d,0x7e6d339e,0x660200d1,0x7c3c0147}},	// [2a90] _kov_, rnap, _mbok, _borr,
   {{0x7c3c339f,0xe3b8008f,0x6f0501a5,0x6fc000a1}},	//   _corr, ncı_, _tphc, वडणू,
   {{0x443c33a0,0xda7b0036,0x7c3c33a1,0x30780037}},	//   _mov_, ояд_, _dorr, _تحية_,
   {{0x60cd15ab,0x443c33a2,0x752233a3,0xddeb0833}},	//   _kwam, _lov_, _oroz, _برده_,
   {{0x7c3c33a4,0xa80301d6,0x6e3d011e,0x20cd33a5}},	//   _forr, _çıkt, _iosb, nži_,
   {{0x7c3c33a6,0x672103fd,0x60cd33a7,0x660233a8}},	//   _gorr, _prlj, _mwam, _abok,
   {{0x394933a9,0xddc4108a,0x60cd018e,0x98bf00d0}},	//   šas_, lniš, _lwam, ırım_,
   {{0x83fc1269,0x7c3c33aa,0x752201a0,0x629d02c4}},	//   viđa, _zorr, _broz, jmso,
   {{0x443c0c9a,0x6e3d33ab,0xd7fb33ac,0x752200f6}},	//   _bov_, _mosb, _муж_, _croz,
   {{0x443c1020,0x20cd33ad,0x7c3c33ae,0x672100cb}},	//   _cov_, dži_, _xorr, _trlj,
   {{0x60cd33af,0x13a704e8,0x443c33b0,0x63ad33b1}},	//   _awam, بندی_, _dov_, _şans,
   {{0x23bf0d1f,0xd83800cb,0x60cd2107,0xf08900a5}},	//   _श्रद, _riči_, _bwam, _הנ_,
   {{0x752233b2,0x1bf00302,0xc56b006c,0xddc4008b}},	//   _groz, _चालल_, _بحال_, jniš,
   {{0x6aa933b3,0xddc4068b,0x653a02b5,0x661b1605}},	//   _lief, dniš, _מענד, lduk,
   {{0x44f90c1f,0x661933b4,0x1e9633b5,0x752212ad}},	//   lè_, _kawk, ерар, _zroz,
   {{0x661b33b6,0x6284002f,0x443c006f,0xb17b33b7}},	//   nduk, _ukio, _zov_, rgår,
   {{0x60cd018e,0xfce33066,0x44f902e9,0x6e3d001e}},	// [2aa0] _gwam, лото, nè_, _dosb,
   {{0x443c01a9,0x315702b5,0x7e7b00cb,0x7c3c33b8}},	//   _xov_, _ניין_, čupa, _qorr,
   {{0x7c3c33b9,0xb5fd0c99,0x6e3d33ba,0x201a012f}},	//   _vorr, ziša, _fosb, _iapi_,
   {{0x661b33bb,0x7ae33345,0xddc402c6,0x2bb21119}},	//   jduk, ánta, bniš, _जलवा,
   {{0x44f902e9,0x6aa90b0d,0x661b0273,0xdb1e00be}},	//   jè_, _dief, dduk, lapü,
   {{0x98a303fe,0x76491857,0xb5fd02a7,0x661b029c}},	//   гиче, ekey, viša, eduk,
   {{0x443c01a9,0x09e602ce,0x78a833bc,0x75221342}},	//   _rov_, _повн, _vidv, _sroz,
   {{0x752233bd,0x443c33be,0x661b043d,0x6aa9027a}},	//   _proz, _sov_, gduk, _gief,
   {{0x443c0189,0xc8ca0833,0x661933bf,0x7d1b0132}},	//   _pov_, _روان_, _dawk, _áust,
   {{0x60cd3069,0x61f60602,0x443c01e8,0x07a61958}},	//   _rwam, _acyl, _qov_, _зазн,
   {{0x443c33c0,0x2c02012f,0xcf120083,0xddc4008b}},	//   _vov_, र्यं_, হমুদ_, zniš,
   {{0xb5fd33c1,0x764933c2,0x75220453,0x201a08dd}},	//   lišn, ckey, _troz, _aapi_,
   {{0x81a900c8,0x443c33c3,0x3946006c,0x26190084}},	//   খুন_, _tov_, nyos_, _मोटी_,
   {{0xddc40500,0x201a33c4,0x20cd0bc6,0xc5690206}},	//   vniš, _capi_, rži_, _تحمل_,
   {{0x201a33c5,0xddd433c6,0x6e3d03bc,0x141b00a5}},	//   _dapi_, _šaša, _posb, _מוגב,
   {{0xddc433c7,0x6d1c0cf1,0x60cd33c8,0x9f5a0260}},	//   tniš, निंग_, _twam, _rapô_,
   {{0x30a7311e,0x313533c9,0x22ac00b8,0x60cd01d5}},	// [2ab0] _пров, _репр, _věku_, _uwam,
   {{0xddc433ca,0xbbcb0099,0x201a33cb,0xb5fd011c}},	//   rniš, िरेक, _gapi_, jišn,
   {{0xb5fd01cc,0xcfb60122,0xddc410ec,0x99f500d8}},	//   dišn, _בלתי_, sniš, вялі,
   {{0x44f902e9,0xddc403ab,0xd8380207,0x201a01b7}},	//   yè_, pniš, _miču_, _zapi_,
   {{0xca7433cc,0x3eab021d,0x201a33cd,0x8c3b02b1}},	//   دالغ, _iict_, _yapi_, _fußp,
   {{0x66e533ce,0x6bd418dd,0x44f90359,0xd9421309}},	//   вока, _متفر, vè_, реши,
   {{0x6aa901ae,0x79c9004f,0xf7730919,0x3946067f}},	//   _tief, _يوسف_, داش_, ayos_,
   {{0x44f902e9,0xb5fd01f2,0x7bd700ac,0x39460118}},	//   tè_, jnšt, laxu, byos_,
   {{0x764933cf,0x661b33d0,0x3a2d0183,0xb5fd00cd}},	//   rkey, rduk, _inep_, bišn,
   {{0x7bd700e2,0x2d8b0223,0x3a3f0009,0x44f90359}},	//   naxu, _myce_, _houp_, rè_,
   {{0x201a1581,0x3a3f02e9,0x44f902d0,0x35f533d1}},	//   _rapi_, _koup_, sè_, _апер,
   {{0x201a16ab,0x216a33d2,0x44f933d3,0x3ce933d4}},	//   _sapi_, дими_, pè_, krav_,
   {{0x2124004f,0x9f58008d,0x6486008a,0xb5fd00ac}},	//   ímh_, rfrí_, gðis, lišo,
   {{0x3a3f1f3c,0x3ce90124,0xb05b0ef0,0x00000000}},	//   _loup_, drav_, spän, --,
   {{0xfc3f0bc8,0xe1ff33d5,0x201a33d6,0x7bd701ed}},	//   _luís_, mión_, _vapi_, daxu,
   {{0xe1ff33d7,0x201a000e,0x3376011d,0x3dc9043d}},	//   lión_, _wapi_, _בעצם_, gbaw_,
   {{0x201a272d,0xbea333d8,0xada600d8,0x3eab0110}},	// [2ac0] _tapi_, ратк, таал, _dict_,
   {{0xe1ff33d9,0xf1a7051d,0x224001ed,0x3eab0027}},	//   nión_, _गणतन, _hoik_, _eict_,
   {{0xb5fd0254,0x3a3f0260,0x8fa610b4,0x3eab00fe}},	//   višn, _boup_, _јане, _fict_,
   {{0x3a3f02e1,0x752402c4,0xc332011d,0x9f580176}},	//   _coup_, _šizm, יוב_, mfrà_,
   {{0x99dd0107,0xc7b800cd,0x3ea033da,0xee3700af}},	//   _alňs, _lađe_, mmit_, _рня_,
   {{0xdb1c0332,0x3ea033db,0x515b00a5,0xb7d80037}},	//   _kerü, lmit_, וכנו, روبا_,
   {{0xb5fd33dc,0x7c2e33dd,0xc7b80254,0x2c02012f}},	//   rišn, _inbr, _nađe_, र्णं_,
   {{0xeb9715dd,0x692600af,0x9f581c5b,0x6486008d}},	//   _рис_, _имба, leró_, yðis,
   {{0xb5fd0496,0x00000000,0x00000000,0x00000000}},	//   mišl, --, --, --,
   {{0xe1ff33de,0x9f580453,0xb5fd01ba,0x3ea00031}},	//   gión_, neró_, bišo, hmit_,
   {{0x2252053e,0x3a3f0051,0xd70a0210,0x25bd0090}},	//   _blyk_, _youp_, _інде_, _ffwl_,
   {{0xdb1c33df,0x550633e0,0xacbb00f7,0x752d0009}},	//   _heró, _ачка, _brûl, _šaze,
   {{0x81cc0083,0xe1ff07a6,0x7c2e33e1,0x00000000}},	//   _লাখ_, bión_, _onbr, --,
   {{0xe1ff33e2,0x14d700c2,0x6486008a,0xdb1c33e3}},	//   ción_, _יודל_, rðis, _berü,
   {{0x9f5800de,0x00000000,0x00000000,0x00000000}},	//   deró_, --, --, --,
   {{0x5bcb175f,0x320f0332,0x7c2e33e4,0x442e2b2e}},	//   िर्व, _úgy_, _anbr, _hnf_,
   {{0x5c751d99,0xc7b80124,0xcc991d77,0x2bc40bdd}},	// [2ad0] глат, _zađe_, евац_, _ल्हा,
   {{0x7ae32b39,0x3a2d33e5,0x3a3f33e6,0x00000000}},	//   ánto, _snep_, _soup_, --,
   {{0x3ea00122,0x7bd70069,0xdb1c033b,0x201133e7}},	//   bmit_, raxu, _gerü, mezi_,
   {{0x201133e8,0x3ce902c6,0x3ce6219e,0x442e33e9}},	//   lezi_, prav_, šova_, _lnf_,
   {{0x26de33ea,0x9f581c5b,0x7c2e00fe,0x442e00f6}},	//   _avto_, beró_, _fnbr, _onf_,
   {{0xe1ff33eb,0x201133ec,0x81d90033,0x628f00d5}},	//   xión_, nezi_, ালি_, hlco,
   {{0x27e906d0,0x8aa733ed,0x9f580036,0xb5fd33ee}},	//   ğan_, _арад, lerò_, bišl,
   {{0x27e933ef,0x442e01a2,0x1dd31b8f,0xa91d01ba}},	//   şan_, _anf_, तरित, _lyži,
   {{0xe1ff20d9,0xe80033f0,0x2ba7022e,0x27170095}},	//   tión_, ल्हा_, _कृता, _mənə_,
   {{0x7bd533f1,0x69d933f2,0x3ea000da,0x628f0051}},	//   _jezu, lawe, zmit_, elco,
   {{0x7bd533f3,0x3246005f,0x9f5807e5,0x38b90176}},	//   _mezu, генг, herò_, _hèr_,
   {{0xe1ff1175,0x69d90657,0xddd6024e,0x442e0260}},	//   sión_, nawe, chyň, _enf_,
   {{0x1ae0021a,0x6486008d,0xe1ff1f51,0x00000000}},	//   _पट्ठ, rðir, pión_, --,
   {{0x201133f4,0x69d933f5,0x9f5807e5,0x628f33f6}},	//   gezi_, hawe, derò_, alco,
   {{0x37d80083,0x2d8f01ae,0x69d933f7,0x9f580453}},	//   _সামর, ügen_, kawe, veró_,
   {{0x69d933f8,0xdb050037,0xfbcd0033,0x22990c8e}},	//   jawe, hchó, _লাগত, téke_,
   {{0x3ea00897,0x61e433f9,0x7bd533fa,0x628633fb}},	// [2ae0] rmit_, _idil, _bezu, moko,
   {{0x09cc0d53,0x62860273,0xdb1c006c,0xa3e90026}},	//   ार्य, loko, _terü, यलट_,
   {{0x27230d6f,0xdb1c0392,0x7bd533fc,0x8cb00035}},	//   _nın_, _aerò, _dezu, _अंको,
   {{0x248533fd,0x69d933fe,0x9f410453,0x9f580036}},	//   holm_, gawe, _echó_, berò_,
   {{0xdb1c1111,0x9f5800de,0xb5fd0506,0x09e32d9c}},	//   _peró, peró_, rišl, сочн,
   {{0x628633ff,0x7bd53400,0xddcd0035,0x7d1600e9}},	//   hoko, _gezu, chał, mwys,
   {{0xeb970c06,0x62863401,0x69d93402,0xdb1c0300}},	//   _бир_, koko, bawe, _veró,
   {{0x61e43403,0x60c43404,0x62863405,0x20113406}},	//   _ndil, _otim, joko, zezi_,
   {{0x60c40010,0x6d5b0009,0x38b90176,0x54543407}},	//   _ntim, _žuaz, _gèr_, ивит,
   {{0xe6440644,0x59cc0577,0x6aa23408,0x98a60009}},	//   ılış, ारकर, lmof, _сизе,
   {{0x60c43409,0x4394340a,0x2011340b,0x6286340c}},	//   _atim, ранс, vezi_, foko,
   {{0x2011340d,0xe45209b9,0x6286340e,0x61e4009e}},	//   wezi_, _گفتگ, goko, _cdil,
   {{0x2011340f,0x61e4001e,0xb7b500e2,0x855700b5}},	//   tezi_, _ddil, _mạn, _میٹر_,
   {{0x61e43410,0x9f5807e5,0x27170095,0xf5930037}},	//   _edil, verò_, _sənə_, _الهج,
   {{0x20113411,0xda0402e4,0x62861321,0xa91d0334}},	//   rezi_, रभात_, boko, _vyži,
   {{0x2449003e,0x9f58027a,0x20113412,0x7bd53413}},	//   _rúmi_, terò_, sezi_, _sezu,
   {{0xdb0501ae,0x3209010d,0x16d10af9,0xe6d10461}},	// [2af0] schü, _ibay_, _सब्ब, _सब्ज,
   {{0x69c03414,0x69d93415,0x9f5807e5,0x7642073a}},	//   _afme, wawe, rerò_, _looy,
   {{0x7bd53416,0x69d91ce2,0x8af91578,0x5b153417}},	//   _vezu, tawe, тнес_, рмет,
   {{0x7f3a02b5,0xd011006c,0x38b90107,0x7d1600e9}},	//   _סערו, _الگ_, _pèr_, bwys,
   {{0x80a402fd,0x65ab013b,0xe0df3418,0x67283419}},	//   _خمین, _möhü, nsò_, _ardj,
   {{0xe8001cce,0xb346027d,0x6286341a,0x98a503d0}},	//   ल्ला_, _kaçı, zoko, шиле,
   {{0xe739341b,0x76420b88,0x6286341c,0xdb050079}},	//   тей_, _booy, yoko, rchó,
   {{0x8aa40f23,0x2129341d,0xb5fd010b,0xb346027d}},	//   _груд, _orah_, mišk, _maçı,
   {{0xb5fd341e,0xf1c800b8,0x76420bf7,0xdb1c008d}},	//   lišk, ndář_, _dooy, _herð,
   {{0x320908dd,0x999f2e37,0x6286341f,0x290d0183}},	//   _abay_, _kluž_, woko, _ipea_,
   {{0x62863420,0x21291034,0xb5fd341e,0xe29a03fa}},	//   toko, _arah_, nišk, као_,
   {{0x21290088,0x543501df,0x00000000,0x00000000}},	//   _brah_, ارکر, --, --,
   {{0x161e3421,0x212900e0,0x2d8f033b,0xe44e0217}},	//   _मोटर_, _crah_, ügel_, _дж_,
   {{0x03a53422,0x9f58008a,0x25bf3423,0x53a50036}},	//   _кило, ferð_, lcul_, _калб,
   {{0x9f58008a,0x62863424,0x8fa63425,0xb5fd02a7}},	//   gerð_, poko, раве, jišk,
   {{0x25bf0388,0xb5fd3426,0x13da0083,0x64433427}},	//   ncul_, dišk, _দায়, _honi,
   {{0x64433428,0x21290a18,0x60c41b68,0xc7b8011c}},	// [2b00] _koni, _grah_, _utim, _lađa_,
   {{0x64433429,0x7d160173,0x25a0009e,0x00000000}},	//   _joni, rwys, _ùile_, --,
   {{0x6443342a,0x290d099e,0xb5fd00d8,0xe9da1c36}},	//   _moni, _apea_, gišk, вке_,
   {{0x644301ef,0x628700cb,0xa91d00d5,0x539a011d}},	//   _loni, čkog, _lyžu, דיעו,
   {{0x2ba702e4,0xd3780254,0x764203bc,0x82770070}},	//   केबा, maće_, _rooy, סענע_,
   {{0xdb1c00fb,0x6aa2342b,0x9866006c,0xb5fd342c}},	//   _ferð, smof, جیئے_, bišk,
   {{0xd6d7342d,0xdb1c00fb,0x290d06a2,0x00000000}},	//   аты_, _gerð, _epea_, --,
   {{0x7e7601a2,0x9634342e,0xd01f0083,0x960a010b}},	//   nnyp, сниц, দায়_, тэка_,
   {{0xd49a25ef,0xd90e0df3,0x993400b5,0xdb0e0a8a}},	//   кро_, _آیت_, _دہشت, _afbø,
   {{0x656f342f,0x3209010d,0x64433430,0x66e602ee}},	//   úcha, _sbay_, _coni, _вожа,
   {{0x0bb70052,0x64433431,0x6f09004e,0xc5e80083}},	//   ילים_, _doni, łecz, ক্ষা_,
   {{0x212903c9,0xd378042a,0x326702d6,0x99dd00d5}},	//   _prah_, jaće_, ртов, _koňa,
   {{0xdfdb0133,0xc6930122,0xd37800cb,0x64433432}},	//   къв_, _ואף_, daće_, _foni,
   {{0xe0df0036,0xd48f01e0,0x21290097,0x916900cc}},	//   rsò_, _єр_, _vrah_, _vừa_,
   {{0x09d70083,0xe0df3433,0x8cb0007c,0xb34600a8}},	//   _হাসা, ssò_, _अंजो, _qaçı,
   {{0xb5fd00d8,0x877b0070,0x3209010d,0x443e01ff}},	//   višk, דאלי, _ubay_, ljt_,
   {{0x644301d1,0x656d01ba,0x2d8f01b4,0xdbd10093}},	// [2b10] _yoni, _ľahk, æge_, _býðu,
   {{0xa80200a8,0x64433434,0xb5fd00d8,0x270e0095}},	//   çıla, _xoni, tišk, _kənd_,
   {{0xf2d30070,0xd3780009,0x95ff0033,0xe3b80448}},	//   ַעס_, baće_, ্যতম_, ydın_,
   {{0xdb1c064b,0xb5fd3435,0xc7b80254,0x270e00a8}},	//   _verð, rišk, _rađa_, _zəng_,
   {{0x645a046a,0x634a01c2,0xb5fd00d8,0x628d3436}},	//   khti, lənd, sišk, _mkao,
   {{0x89341062,0xb5fd0f27,0x1ed80416,0x60c201ef}},	//   تعما, miši, _حبیب_, _éome,
   {{0x81e200c8,0x6d4d3437,0x644327ba,0xb5fd0944}},	//   ন্ট_, lyaa, _roni, liši,
   {{0x64433438,0x80b800c8,0xe6192611,0xceb400a5}},	//   _soni, _অবস্, уди_, חיק_,
   {{0x6443263f,0x6d4d3439,0x25bf002d,0xb5fd343a}},	//   _poni, nyaa, rcul_, niši,
   {{0x6d4d0103,0x25bf343b,0x628d343c,0x645a343d}},	//   iyaa, scul_, _akao, ghti,
   {{0xd7950082,0x6443343e,0x7e6d0468,0xe1ff006c}},	//   _الاخ, _voni, kiap, ciók_,
   {{0xc049343f,0x425628a1,0x64433440,0x22993441}},	//   _אז_, стот, _woni, téka_,
   {{0xd378011c,0x64433442,0x2ba70099,0xc299002d}},	//   vaće_, _toni, केता, ртэц_,
   {{0x645a3443,0x10a60043,0xb5fd0cc2,0x6d4d0118}},	//   chti, сигн, diši, dyaa,
   {{0xd3780129,0x9345002d,0x00000000,0x00000000}},	//   taće_, _ынке, --, --,
   {{0x765b3444,0x7e6d3445,0x6d4d034d,0x00000000}},	//   nhuy, giap, fyaa, --,
   {{0x6da32526,0x6d4d3446,0xd378011c,0x799b1766}},	// [2b20] зита, gyaa, raće_, _nzuw,
   {{0x3ce02837,0xd3780c99,0xb0b50067,0xae0a00ab}},	//   rsiv_, saće_, ंदरग, _हउवन_,
   {{0x3ce03447,0x6d4d0034,0xff26174b,0xd3780124}},	//   ssiv_, ayaa, _умно, paće_,
   {{0x6d4d073a,0xeb971470,0xddcd0043,0xb5fd0c6e}},	//   byaa, щих_, rnaţ, biši,
   {{0xdd922499,0x2d8400f7,0x645a00c3,0x00000000}},	//   _روس_, _âme_, yhti, --,
   {{0x6e243448,0xb9000066,0x99dd0097,0x13af0033}},	//   ldib, _दब_, _voňa, চুয়,
   {{0x09d70083,0x2ba70fbf,0x6b633449,0x3952010b}},	//   _হারা, केदा, _екра, šys_,
   {{0x6e24344a,0xceb30122,0x645d00da,0xdb1c013c}},	//   ndib, היה_, ësin, _berö,
   {{0x7d04344b,0xb05b00c3,0x3eba125e,0x645a01e9}},	//   ntis, späi, _lupt_, thti,
   {{0x7bde2883,0x634a01c2,0x7d04344c,0x14b7004f}},	//   napu, yənd, itis, حديث_,
   {{0x80b20026,0x7d04344d,0x9f4500d0,0x539800d4}},	//   _इंजे, htis, ülü_, рвня_,
   {{0x645a01d2,0x7bde344e,0x7d042172,0x7ae327c2}},	//   shti, hapu, ktis, ánti,
   {{0x7bde05c8,0x68e2344f,0x6e243450,0xe3b8033e}},	//   kapu, nsod, ddib, ldım_,
   {{0x80b80083,0x634a0095,0x7bde2930,0xb5fd343a}},	//   _অবশ্, tənd, japu, viši,
   {{0x7bde3451,0x6fda00ab,0x7e6d3452,0xe3b8033e}},	//   dapu, _बजरं, tiap, ndım_,
   {{0xdceb3453,0x7d043454,0x3d140006,0x6e240008}},	//   žičk, ftis, _नईखे_, gdib,
   {{0x7d043455,0x69c23456,0x09d70831,0x00000000}},	// [2b30] gtis, dcoe, _হালা, --,
   {{0x7e6d3457,0xb5fd1ada,0x7bde3458,0x00000000}},	//   siap, riši, gapu, --,
   {{0xb5fd0129,0x7d043459,0x6e240cca,0x6d4d327c}},	//   mišv, atis, bdib, syaa,
   {{0xb5fd03ab,0x02fb016b,0x00000000,0x00000000}},	//   piši, רלאמ, --, --,
   {{0x64580083,0xab620092,0x7d04345a,0xe9d801c8}},	//   _olvi, _çünk, ctis, скі_,
   {{0xe9d90067,0x00000000,0x00000000,0x00000000}},	//   _weź_, --, --, --,
   {{0x07a211ca,0x70b50035,0x765b00e2,0x00000000}},	//   машн, ंदुल, thuy, --,
   {{0x245b1010,0x656f345b,0x79960067,0xb658010b}},	//   _même_, úcho, żywa, йшых_,
   {{0x1fa60761,0xe45916fb,0x69db00e9,0x81bf0033}},	//   _खण्ड, ижи_, _ieue, ইরা_,
   {{0xdb1c345c,0x69db345d,0x291f008c,0x99dd07c0}},	//   _verö, _heue, _isua_, _koňo,
   {{0x2c0b018d,0x7c251a07,0xf8ae0088,0xddcd023a}},	//   स्यं_, idhr, _شکه_, znaš,
   {{0x7d040093,0x7de6006c,0xdb1c027d,0x3eba00af}},	//   ytis, _késő, _terö, _rupt_,
   {{0x7bde0e89,0x3eba345e,0x69db01f7,0xe82001c0}},	//   yapu, _supt_, _meue, _यसमा_,
   {{0x9f580248,0x69db053e,0xdb050132,0x68e40079}},	//   lgré_, _leue, lchõ, áidi,
   {{0xe29a345f,0x75293460,0x1faa172a,0x7bde136b}},	//   _как_, lvez, ркви_, vapu,
   {{0x69db02bf,0xe1ff0035,0x7d0404d5,0x7bde3461}},	//   _neue, diów_, ttis, wapu,
   {{0x7bde3462,0x7d043463,0x1c463464,0x6e243465}},	// [2b40] tapu, utis, онам, rdib,
   {{0x76590297,0x212000bf,0xddcd0124,0x8b963466}},	//   _llwy, _isih_, rnaš, ореч,
   {{0x69db3467,0x9f0601b2,0x3bd500c3,0xa3da0066}},	//   _beue, _بوجو, яютс, ़रत_,
   {{0x201808a1,0x634a00a8,0x7c353468,0x7ff602fd}},	//   leri_, lənc, _enzr, _اسکا,
   {{0xdca616e2,0x69db3469,0xcaa5004f,0x7bde346a}},	//   _мами, _deue, أصلي, papu,
   {{0x2018346b,0xab2a24c8,0x7529006c,0x7659346c}},	//   neri_, _кога_, dvez, _alwy,
   {{0xf8bf04ce,0x69db01ae,0x7bdc346d,0x7659001e}},	//   _één_, _feue, _ieru, _blwy,
   {{0x7bdc346e,0xe3b80d6f,0x20181c69,0x765900e9}},	//   _heru, rdım_, heri_, _clwy,
   {{0x7bdc346f,0x20180a9c,0xd378012e,0xdb210421}},	//   _keru, keri_, daća_, ätös,
   {{0xddc42d5b,0x20183470,0x344a3471,0x3a24008c}},	//   jniž, jeri_, рчин_, _hamp_,
   {{0x7bdc203f,0x20183472,0x752905f5,0x76590297}},	//   _meru, deri_, avez, _flwy,
   {{0xbddb1f3c,0x6abc300e,0x7bdc3473,0x752908b7}},	//   _poèm, _murf, _leru, bvez,
   {{0xe3af006c,0x29063474,0xddcd00b8,0xdb150359}},	//   ٹری_, ntoa_, chař, _egzè,
   {{0x20183475,0xe3af006c,0x270e0095,0xfdd33010}},	//   geri_, عری_, _gənc_, तर्फ,
   {{0xcddb04bf,0x6abc00d7,0x212000e0,0x04200033}},	//   иња_, _nurf, _esih_, বাদী_,
   {{0x7bdc3476,0xb3bc0033,0x29060065,0x00000000}},	//   _aeru, _আজিজ, ktoa_, --,
   {{0x7bdc3477,0x20183478,0xb5fd00cb,0x386c0a8a}},	// [2b50] _beru, beri_, mišt, _omdr_,
   {{0xb5fd3479,0x2018347a,0x69db0310,0x7bdc347b}},	//   lišt, ceri_, _seue, _ceru,
   {{0x7bdc347c,0x7529347d,0x200100e9,0x6abc0079}},	//   _deru, zvez, _ichi_, _curf,
   {{0xb5fd1367,0x61fd10dd,0x81d90033,0x6abc347e}},	//   ništ, ngsl, ালক_, _durf,
   {{0x3ea903ad,0x7bdc347f,0x61fd0312,0xcfab02fd}},	//   mmat_, _feru, igsl, _حاکم_,
   {{0x7bdc2069,0x3ea93480,0xeafb042c,0xb5fd008b}},	//   _geru, lmat_, _پرست_, hišt,
   {{0x7bc515b4,0x69db3481,0x645d0031,0x7d19027b}},	//   mchu, _teue, ësim, şası,
   {{0xe9df064b,0xb5fd0956,0x20183482,0x7bdc3483}},	//   _þú_, jišt, zeri_, _zeru,
   {{0xb5fd3479,0x7bdc3484,0xd3783485,0x20183486}},	//   dišt, _yeru, vaća_, yeri_,
   {{0x200119c6,0x75290332,0x7bc53487,0xfdb80026}},	//   _nchi_, rvez, nchu, _अल्फ,
   {{0x7ae501f4,0x3ea92b63,0x7bc53488,0xd37802c4}},	//   nsht, kmat_, ichu, taća_,
   {{0x7bc50874,0x20182ed0,0x2c0b022e,0x3ce60097}},	//   hchu, weri_, स्तं_, šovi_,
   {{0x20183489,0x3ea91d11,0x55ba00a5,0xd378011c}},	//   teri_, dmat_, _המנו, raća_,
   {{0x7bc500ac,0xb5fd02c4,0x2ef800f6,0x394000c3}},	//   jchu, rišu, turf_, äisi_,
   {{0x437500c2,0x7bdc0feb,0x2018348a,0x634a00a8}},	//   _מײַן_, _reru, reri_, rənc,
   {{0x7bdc06b3,0x32190865,0x20010036,0xf1bf0138}},	//   _seru, cesy_, _echi_, ldán_,
   {{0x7bdc348b,0x2018348c,0x6abc348d,0xdd920957}},	// [2b60] _peru, peri_, _surf, روط_,
   {{0x8fa60c0d,0x201801f4,0xee3f07c0,0x68f90051}},	//   _напе, qeri_, _chýb_, duwd,
   {{0x7bdc348e,0x3a240159,0x68f901e4,0x501b00a5}},	//   _veru, _pamp_, euwd, _פוטו,
   {{0x7bdc348f,0xfc3f01dd,0xda65017e,0x290600c3}},	//   _weru, _xuíz_, واني, ttoa_,
   {{0x7bdc3490,0x29063491,0x6abc02b1,0x00000000}},	//   _teru, utoa_, _wurf, --,
   {{0x3a240088,0x6e260dc3,0xb5fd1321,0x7c5a0037}},	//   _wamp_, _hakb, zišt, _السر_,
   {{0x6e263492,0x29063493,0x98a40139,0xdc37016b}},	//   _kakb, stoa_, _armă_, _צאלט_,
   {{0xb8660a86,0xa5343494,0x6e260035,0x4b7b00a5}},	//   _کارو, днич, _jakb, _האלו,
   {{0xb5fd0672,0x5fbe0355,0xfc3f0138,0x04200033}},	//   višt, ्डाल, _ruíz_, বাসী_,
   {{0x3ea93495,0xe9ff00e2,0x6e263496,0x00000000}},	//   zmat_, _toản_, _lakb, --,
   {{0xb5fd0956,0x04fe0083,0xe9ff00e2,0x3ea93497}},	//   tišt, ্টের_, _hoạn_, ymat_,
   {{0x20011c2c,0x76bb00a5,0x3ea91505,0xf1bf0098}},	//   _schi_, _המאפ, xmat_, adán_,
   {{0xb5fd01cc,0x32191298,0x61fd3498,0x7bc5055c}},	//   rišt, resy_, rgsl, ychu,
   {{0x75223499,0xb5fd0207,0x04200033,0x00000000}},	//   _isoz, sišt, বাহী_, --,
   {{0xb5fd01c0,0xe9ff0019,0x9f3401e0,0x6e26349a}},	//   pišt, _loạn_, нері, _bakb,
   {{0x5f9400d4,0x5eb40a71,0x644a349b,0x7bc500e5}},	//   хист, ейст, _hofi, wchu,
   {{0x628f016f,0x644a002f,0x6e26349c,0xd8380107}},	// [2b70] moco, _kofi, _dakb, _onč_,
   {{0x5ba706a6,0x628f349d,0x200104be,0x09d50e61}},	//   през, loco, _uchi_, दर्य,
   {{0x7bc5349e,0xa134042c,0xe7a500ea,0x00000000}},	//   rchu, _قریش, ādīš, --,
   {{0x7bc5349f,0x7ae500da,0xe1ff34a0,0x6e260024}},	//   schu, rsht, ngó_, _gakb,
   {{0xa95402ce,0x08c40044,0xa3df0127,0x61ed237c}},	//   нкці, ебін, तरम_, _mdal,
   {{0xf77001ca,0x644a34a1,0x60cd0054,0x7ae50031}},	//   گاه_, _nofi, _mtam, psht,
   {{0x16a934a2,0x61ed34a3,0x628f0a04,0xab9500d4}},	//   овки_, _odal, koco, _циві,
   {{0x61ed34a4,0x60cd34a5,0x7c273455,0xe81f018d}},	//   _ndal, _otam, _hajr, _मघवा_,
   {{0x68e4004f,0x644a01f7,0x60cd01d0,0x628f0d9b}},	//   áidt, _bofi, _ntam, doco,
   {{0x61ed1760,0x644a001e,0x7c270069,0x55ff0033}},	//   _adal, _cofi, _jajr, ্যেক_,
   {{0x60cd288d,0x644a34a6,0x588401c8,0x672100cd}},	//   _atam, _dofi, _чыта, _uslj,
   {{0xd7f80139,0x00000000,0x00000000,0x00000000}},	//   _umăr_, --, --, --,
   {{0x2bfe0299,0x61ed34a7,0x160602e4,0x644a34a8}},	//   _लालू_, _ddal, _वॉटर_, _fofi,
   {{0x764b34a9,0x60cd34aa,0x644a00e9,0x61ed34ab}},	//   _hogy, _dtam, _gofi, _edal,
   {{0x442734ac,0x60cd34ad,0x764b012f,0x92e8004f}},	//   _ian_, _etam, _kogy, _فريق_,
   {{0x442734ae,0x68e90009,0x661b34af,0x764b08eb}},	//   _han_, _oved, neuk, _jogy,
   {{0x44270d51,0xfce30086,0x3cf5004e,0x7c2734b0}},	// [2b80] _kan_, кото, एंगे_, _bajr,
   {{0x44270122,0x61ed2f3f,0xb05b34b1,0xe1ff0098}},	//   _jan_, _zdal, spär, thóg_,
   {{0x442734b2,0x6fd406bb,0xe9ff01a5,0xe1ff34b3}},	//   _man_, _ब्यू, _soạn_, ciós_,
   {{0x442734b4,0xe1ff004e,0x7c2701a3,0x62980183}},	//   _lan_, chód_, _eajr, _êxod,
   {{0x44270023,0x09e334b5,0xe3e30083,0x7c270207}},	//   _oan_, точн, _মানব, _fajr,
   {{0x442734b6,0xb8e6018d,0x00000000,0x00000000}},	//   _nan_, _ईं_, --, --,
   {{0x69c9018e,0x644a34b7,0x628f34b8,0x7522030d}},	//   _ffee, _rofi, yoco, _ssoz,
   {{0x442734b9,0x661b0054,0x7c270067,0x764b00e5}},	//   _aan_, geuk, _zajr, _cogy,
   {{0x442734ba,0xe7cf09b8,0xd7cf2afe,0x628f34bb}},	//   _ban_, _स्वप, _स्वच, voco,
   {{0x442701f3,0x00000000,0x00000000,0x00000000}},	//   _can_, --, --, --,
   {{0x442734bc,0x60cd34bd,0x764b006c,0x68e9156f}},	//   _dan_, _stam, _fogy, _zved,
   {{0x44272543,0xc7b8011c,0x925800c3,0x667600fd}},	//   _ean_, _nađi_, дают_, _غدار,
   {{0x442734be,0xe1ff34bf,0xe80534c0,0x644a013b}},	//   _fan_, rgó_, _रामा_, _tofi,
   {{0x442734c1,0xa3df0567,0xd4c50037,0x00000000}},	//   _gan_, तरण_, _أغني, --,
   {{0x764b34c2,0x3f8534c3,0x00000000,0x00000000}},	//   _yogy, çlu_, --, --,
   {{0x61ed34c4,0x442734c5,0x13e30083,0x2cb8184f}},	//   _udal, _zan_, _মায়, _aird_,
   {{0x6e942252,0x442734c6,0x60cd34c7,0xe1ff0035}},	// [2b90] титу, _yan_, _utam, biór_,
   {{0x69c928e9,0x442734c8,0x4cc80033,0x229900b5}},	//   _sfee, _xan_, _লিখু, déki_,
   {{0x68e934c9,0x634a00a8,0x2ef400af,0xe945132d}},	//   _sved, zənn, _изэр, کرای,
   {{0x5ba4002d,0xdd910d93,0xdb0e00fd,0x37d80831}},	//   труз, _موج_, áján, _সাগর,
   {{0x7c2734ca,0xe6ed016f,0xcce7004f,0x00000000}},	//   _tajr, _väčš, _تسجي, --,
   {{0x07a51c2e,0xa15800a5,0x661b012f,0x00000000}},	//   налн, ובדה_, weuk, --,
   {{0x442734cb,0x661b012f,0x3eb934cc,0x2bae0803}},	//   _ran_, teuk, _kist_, झेदा,
   {{0x442734cd,0x5a341906,0xd0280033,0x2d9900c3}},	//   _san_, _инст, মায়_, _kyse_,
   {{0x68e934ce,0x3eb934cf,0xe5790086,0xeab001b2}},	//   _uved, _mist_, язи_, _ضعف_,
   {{0x3eb934d0,0x98ad02c4,0x442734d1,0x2d9934d2}},	//   _list_, _kreč_, _qan_, _myse_,
   {{0x442734d3,0xe29a34d4,0x3eb908dd,0x2d990249}},	//   _van_, зан_, _oist_, _lyse_,
   {{0x442734d5,0x80d40033,0x00000000,0x00000000}},	//   _wan_, _তিব্, --, --,
   {{0xdb1c022a,0x442714bc,0x634a00a8,0x00000000}},	//   _ifrå, _tan_, lənl, --,
   {{0x44270608,0x3eb9009e,0x98ad0207,0x6d40009e}},	//   _uan_, _aist_, _oreč_, _àmai,
   {{0x3eb902c9,0x66c7027d,0xa0a306d8,0x32290421}},	//   _bist_, _yıka, уард, ötyä_,
   {{0x3eb934d6,0x2d9934d7,0x00000000,0x00000000}},	//   _cist_, _byse_, --, --,
   {{0x61e634d8,0x0d8600af,0x626b00b8,0x6e9334d9}},	// [2ba0] makl, хлан, třov, القا,
   {{0x61e634da,0xa3df193c,0x3eb90223,0x4f2634db}},	//   lakl, तरि_, _eist_, _здоб,
   {{0x09d700c8,0xb3460279,0x20c60019,0x2d8f02b1}},	//   _হাজা, maçõ, _hôi_, üger_,
   {{0x2cb80446,0xb3460370,0x61e634dc,0x88e60c46}},	//   _wird_, laçõ, nakl, ежде,
   {{0xa3df0084,0xb4de007c,0x2d99008c,0x00000000}},	//   तरा_, _तबे_, _gyse_, --,
   {{0x20c601a5,0xd6da058f,0xeee700bf,0x69d00026}},	//   _môi_, пти_, _تغیی, _ड्री,
   {{0xf0930100,0x8ba30421,0x20c60019,0x61e634dd}},	//   אנג_, _бирж, _lôi_, kakl,
   {{0x9634010c,0x7e6434de,0x62840207,0x35461fff}},	//   тниц, nhip, _njio, ехов,
   {{0x61e62cf4,0x6d4428ab,0x06e000b4,0x20c60023}},	//   dakl, nxia, _गौरव_, _nôi_,
   {{0x54540cac,0x6d56028b,0x629634df,0x62870612}},	//   твот, iyya, _akyo, čkom,
   {{0xb3460279,0xd25111c0,0x61e634e0,0x66c70225}},	//   daçõ, لند_, fakl, _tıka,
   {{0xa75b00a5,0x20c60023,0x634a00a8,0xbddb0107}},	//   _מדבר, _bôi_, səno, _inèg,
   {{0x518434e1,0x7e641872,0x225903d0,0xc68f00b5}},	//   гура, dhip, rksk_, _اِن_,
   {{0xb34634e2,0x634a0095,0x7afe34e3,0x3eb91281}},	//   gaçõ, lənm, kupt, _sist_,
   {{0x5f95021d,0x61f401ff,0x2d990345,0x78ba02b1}},	//   тивт, ådlö, _syse_, _mitv,
   {{0x61e601d6,0x78ba34e4,0x7e64010d,0x439b00a5}},	//   cakl, _litv, ghip, _מבוג,
   {{0x3eb934e5,0x442c001e,0x3f9e0093,0x4f5800b5}},	// [2bb0] _vist_, odd_, ýtur_, وجہد_,
   {{0x645a34e6,0xb3460370,0xe8051b8f,0x3eb90120}},	//   nkti, caçõ, _राधा_, _wist_,
   {{0x442c311f,0x7c941c2d,0x7afe34e7,0x2d99053e}},	//   idd_, اشقا, gupt, _wyse_,
   {{0x7c3c0176,0x443c0223,0x78ba004b,0x200334e8}},	//   _enrr, _lnv_, _aitv, lgji_,
   {{0x6e3d01ae,0x26de34e9,0x20c60023,0x78ba0355}},	//   _insb, _awto_, _xôi_, _bitv,
   {{0xa3bc27c6,0x6e2d003e,0x7d0d34ea,0x200334eb}},	//   _अलग_, ldab, mtas, ngji_,
   {{0x7d0d34ec,0xddcd002d,0x81e70033,0xba770079}},	//   ltas, ciaţ, _পান_, _كارت,
   {{0x442c0297,0xb3460370,0x443c34ed,0x99d70098}},	//   edd_, zaçõ, _anv_, _سترا,
   {{0x7d0d190f,0x12bd0083,0xc4850ebb,0x28dd0066}},	//   ntas, _আবেদ, клик, नीशि,
   {{0x443c34ee,0x69d902b1,0x00000000,0x00000000}},	//   _cnv_, lbwe, --, --,
   {{0x61e634ef,0x7d0d34f0,0x20c60019,0xb3460279}},	//   takl, htas, _sôi_, vaçõ,
   {{0x27e734f1,0x7d0d34f2,0x443c34f3,0x442c001e}},	//   lann_, ktas, _env_, add_,
   {{0x6e2d2d1a,0xb3460370,0x61e634f4,0x443c34f5}},	//   ddab, taçõ, rakl, _fnv_,
   {{0x27e70082,0x6e3d34f6,0x2335021d,0x7d0d01b4}},	//   nann_, _ansb, _ахир, dtas,
   {{0xb3460370,0xafe32ad7,0xdee30e05,0x7d0d0036}},	//   raçõ, росл, иори, etas,
   {{0x20c600e8,0x27e734f7,0xdcf434f8,0x6d4406a2}},	//   _tôi_, hann_, žačk, txia,
   {{0xdbdf0093,0x6e3d34f9,0x7e64012f,0x7d0d34fa}},	// [2bc0] tíði, _dnsb, rhip, gtas,
   {{0x61e42395,0xe3b80716,0x3f9a1298,0x27e734fb}},	//   _heil, mdır_, _typu_, jann_,
   {{0xbddb34fc,0x61e434fd,0xe3b8037a,0x09e634fe}},	//   _poèt, _keil, ldır_, воен,
   {{0x6aa934ff,0x7afe3500,0x60c4000e,0x6abb13fb}},	//   _chef, rupt, _kuim, _ciuf,
   {{0x442c1973,0x61e43501,0x7d0d3502,0xe3b80463}},	//   ydd_, _meil, ctas, ndır_,
   {{0x27e73503,0xcee91c0c,0x61e43504,0x60c43505}},	//   gann_, _ترین_, _leil, _muim,
   {{0x8a06087b,0xb8c900ab,0xa7fc00d0,0x60c40079}},	//   _изве, _गी_, _alıc, _luim,
   {{0xfaa6216f,0x61e43506,0x442c0297,0x6abb027a}},	//   _рабо, _neil, wdd_, _giuf,
   {{0x27e73507,0x47e10083,0x09060798,0xd3780254}},	//   bann_, _নারী, _шпан, maći_,
   {{0x78ba0a45,0x6b9c3508,0xdb1c0248,0x27e70315}},	//   _uitv, _kyrg, _agré, cann_,
   {{0x442c02c7,0x7d0d3509,0x2c140026,0xa2790200}},	//   rdd_, ztas, न्यू_, ебну_,
   {{0xd37803fd,0x7d0d350a,0x443c0107,0x7ae3350b}},	//   naći_, ytas, _wnv_, ânti,
   {{0x60c41093,0x61e4350c,0x443c350d,0xd251006c}},	//   _cuim, _deil, _tnv_, لنگ_,
   {{0xa2ca02e4,0x2bfe114e,0x645d01f4,0xe5a3350e}},	//   _संप्, _लागू_, ësit, _тичи,
   {{0x61e4350f,0x200301f4,0x260f0f3d,0x3ce8046c}},	//   _feil, rgji_, थ्वी_, _चौबे_,
   {{0x68ed0274,0x7d0d09bd,0x61e43510,0x60c43511}},	//   šadi, ttas, _geil, _fuim,
   {{0x60c43512,0x27e71a22,0x16df14ab,0x7d0d3513}},	// [2bd0] _guim, yann_, _नब्ब, utas,
   {{0x7d0d3514,0x6aa93515,0xbbdd02e4,0x61e43516}},	//   rtas, _shef, यरेक, _zeil,
   {{0x7d0d3517,0xddc6004e,0x27e73518,0xda3500d8}},	//   stas, _dokł, vann_, лежы,
   {{0x27e73519,0xa2ca0127,0x6b9c0523,0x99d40c74}},	//   wann_, _संन्, _dyrg, لتها,
   {{0x69cb02c4,0xe9d800d8,0x27e7351a,0xee3f01ba}},	//   rcge, ткі_, tann_, _iný_,
   {{0xfa230083,0x6b9c351b,0x00000000,0x00000000}},	//   ফাইল_, _fyrg, --, --,
   {{0x27e7351c,0x12bd0083,0xe3b8008f,0x6aa904d5}},	//   rann_, _আব্দ, zdır_, _thef,
   {{0x27e7351d,0xddcd0080,0x060901af,0x9980351e}},	//   sann_, skaņ, хник_, žiš_,
   {{0x61e423ea,0xe6160c28,0x27e7351f,0x3a3f011e}},	//   _reil, уды_, pann_, _inup_,
   {{0x60c40244,0xe3e30083,0x61e43520,0x765b011e}},	//   _ruim, _মাহব, _seil, skuy,
   {{0x60c43521,0x91e61edd,0x656900b5,0x21291872}},	//   _suim, лоне, szeh, _asah_,
   {{0xe3b8013b,0x00000000,0x00000000,0x00000000}},	//   tdır_, --, --, --,
   {{0x61e43522,0x645d01d2,0x27e50009,0x00000000}},	//   _veil, ësis, _keln_, --,
   {{0xe3b80d6f,0x26c5113f,0x61e43523,0x99dd0184}},	//   rdır_, _kulo_, _weil, _koňs,
   {{0x61e43524,0x212900d7,0x26c500ee,0x99750067}},	//   _teil, _esah_, _julo_, nęło_,
   {{0xa2063525,0x6fd402b4,0x26c53526,0x60c43527}},	//   _спид, _ब्रू, _mulo_, _tuim,
   {{0x0eb9086c,0x4c862590,0x22400359,0xe3b80095}},	// [2be0] туры_, глав, _inik_, qdır_,
   {{0x6b9c03d0,0x00000000,0x00000000,0x00000000}},	//   _pyrg, --, --, --,
   {{0xd378011c,0x22400a81,0xfaa630ba,0xaae60079}},	//   taći_, _knik_, гажо, اسطو,
   {{0x3a2d0176,0x1efb0070,0x3ce8035d,0x2cb000c7}},	//   _caep_, _אלטע, _चौथे_, _žodį_,
   {{0xf99202e7,0xed570340,0xd37800cd,0xa2ca143a}},	//   حبا_, _боя_, raći_, _संभ्,
   {{0x3ea03528,0x66c70723,0xf7720332,0x26c5012f}},	//   llit_, _tıkl, یاں_, _bulo_,
   {{0x26c53529,0xb8eb051d,0xd378025c,0x224001b7}},	//   _culo_, _रू_, paći_, _onik_,
   {{0x7c2e0033,0x3ea00093,0x26c50dc3,0x09de0033}},	//   _habr, nlit_, _dulo_, _ডাকা,
   {{0xca75010b,0x634a01c2,0x7c2e352a,0x270e0095}},	//   _туры, məni, _kabr, _məni_,
   {{0x634a0095,0x2240352b,0x24520395,0x6fd40127}},	//   ləni, _anik_, _câmp_, _ब्लू,
   {{0x36061dbf,0x3ea0352c,0x26c5352d,0x0eb40099}},	//   _مواف, klit_, _gulo_, ंगाड,
   {{0x21b500d4,0xdbdf0093,0xa29512ea,0x645d0055}},	//   ийня, _líðu, рамі, ësir,
   {{0x667b02b5,0x463b0070,0x26c501a3,0x3ea0352e}},	//   _אטאק, _רעדע, _zulo_, dlit_,
   {{0x7c2e1942,0xa3df022e,0xe1ff0d2e,0x3e6700ab}},	//   _nabr, तरः_, chón_, _mõte_,
   {{0xe7f70387,0x634a0095,0x442e013c,0x316b2200}},	//   ीलता_, kəni, _iaf_, szcz_,
   {{0x2bdd012f,0x3ea0352f,0x442e00e9,0x7c2e0159}},	//   यर्थ, glit_, _haf_, _aabr,
   {{0x3cee006a,0x634a01c2,0x5c751ca9,0xbddb0310}},	// [2bf0] ेंगे_, dəni, алат, _anèc,
   {{0x442e3530,0x3ea03531,0x9f430355,0x3a3f3532}},	//   _jaf_, alit_, lají_, _snup_,
   {{0x2baa02cb,0xfbd01c64,0x3ea03533,0xb09c0070}},	//   _करणा, ستل_, blit_, _איזר,
   {{0x442e337c,0x7c2e009e,0x9f430355,0x00000000}},	//   _laf_, _eabr, nají_, --,
   {{0xd378011c,0xd9453534,0x00000000,0x00000000}},	//   maću_, рели, --, --,
   {{0x2c14073f,0x442e035f,0x46f52201,0x26c53535}},	//   न्दू_, _naf_, ачит, _pulo_,
   {{0xf77100bf,0x36691c56,0x290f023a,0x270e0095}},	//   غات_, како_, stga_, _yəni_,
   {{0x7c2e15b5,0xbb840082,0x2baa255b,0x7ae3002d}},	//   _zabr, _الفي, _करता, ântu,
   {{0x81eb0083,0x98b90f08,0x9f4300b8,0xad9b3536}},	//   মলা_, _алат_, dají_, _abúz,
   {{0x26c50188,0x7c2e01ef,0xf8b900bc,0x176b3537}},	//   _tulo_, _xabr, _شهاب_, _преп_,
   {{0x03a5059b,0xf868026e,0x53a50279,0xd37800f4}},	//   рино, _حملي_, ранб, kaću_,
   {{0x67b814ac,0xcb120122,0xd37800f4,0x2c640523}},	//   _صالح_, חלט_, jaću_, _möda_,
   {{0xd378011c,0x2c640282,0x00000000,0x00000000}},	//   daću_, _löda_, --, --,
   {{0x442e3538,0xad9b0037,0x270e0095,0x05a800d4}},	//   _gaf_, _gcúi, _səni_, _свій_,
   {{0x634a0095,0x7c2e0009,0xdee63539,0xa2a700a1}},	//   yəni, _rabr, роби, _टीव्,
   {{0xdbdf00fb,0x3f8c003c,0x3ea0353a,0xa2ca035d}},	//   _síðu, ħdu_, ulit_, _संत्,

   {{0x3ea0008a,0x7c2e353b,0x645c353c,0x442e353d}},	// [2c00] rlit_, _pabr, örig, _yaf_,
   {{0xa7fc036a,0x7c2e0be2,0x6e2f009e,0x2c640523}},	//   _alın, _qabr, _eacb, _böda_,
   {{0x62870097,0xf1a900f8,0x634a0095,0xbea62ccc}},	//   čkov, _لایه_, təni, _ванк,
   {{0xeb97353e,0x6286353f,0x2c64013c,0x3e7f0421}},	//   ших_, nnko, _döda_, rätä_,
   {{0x7c2e3540,0xa3e822d4,0x634a00a8,0x6e243541}},	//   _tabr, बरम_, rəni, meib,
   {{0x7d043542,0xceb40095,0x1957005f,0x634a00a8}},	//   muis, lmə_, рашы_, səni,
   {{0x7d043543,0xa2ca0785,0x00000000,0x00000000}},	//   luis, _संध्, --, --,
   {{0x2bd2009a,0x442e28ae,0x386503d0,0x634a013b}},	//   दुरा, _saf_, _ellr_, qəni,
   {{0x9f4301c0,0x7d043544,0x69340118,0x78b1008d}},	//   vají_, nuis, _دکار, ákvæ,
   {{0x62863545,0x6e2401ae,0xb7960274,0x3cfe01c0}},	//   enko, heib, _крећ, _लिने_,
   {{0x7d043546,0x1c0b08a9,0x4394338e,0x9f431dab}},	//   huis, स्टल_, санс, tají_,
   {{0x7d043547,0x442e0e91,0x00000000,0x00000000}},	//   kuis, _waf_, --, --,
   {{0x442e3548,0xe4d404e8,0x61f6001e,0x7d043549}},	//   _taf_, _اقتد, _ddyl, juis,
   {{0x7d04354a,0x6286299b,0x03770416,0x6aa2354b}},	//   duis, anko, احیت_, hlof,
   {{0x60d609b3,0x229201ba,0xe80e06d9,0xf0b400d4}},	//   _etym, háky_, _साना_, ійсь,
   {{0x2c64013c,0xdce6027d,0x5f94354c,0x00000000}},	//   _röda_, _aykı, цист, --,
   {{0xd90402fd,0x7d04354d,0xa2ca02b4,0xd378003a}},	// [2c10] _تی_, guis, _सूत्, raću_,
   {{0x80dd0083,0x38a91da9,0xd3780c99,0x00000000}},	//   _বিপ্, kúra_, saću_, --,
   {{0x5b151d91,0x7642030d,0x00000000,0x00000000}},	//   смет, _onoy, --, --,
   {{0x7d040382,0xe8f5004f,0x3d070026,0x00000000}},	//   buis, مستخ, िंदे_, --,
   {{0x3cfe006a,0x7d040cb3,0xb92707bc,0x8d842f44}},	//   _लिये_, cuis, рфей, _дурд,
   {{0xd3660286,0xf1bf00b5,0x26d90097,0x00000000}},	//   _فه_, ldás_, _čsob_, --,
   {{0x81bf0083,0x99861a8a,0x62860067,0xda35037c}},	//   েরি_, rdoš_, ynko, _левы,
   {{0x7c25354e,0x80dd0033,0x229200ac,0xf1bf00fd}},	//   lehr, _বিন্, báky_, ndás_,
   {{0x673a0b88,0xf09f01f7,0x00000000,0x00000000}},	//   _ertj, ntàs_, --, --,
   {{0xb46503ad,0x9865006c,0x81bf0083,0xba3d06fe}},	//   скол, _دیتے_, েরা_, _chův,
   {{0x2c19021a,0x673a0051,0x6e24354f,0x60d61140}},	//   न्यं_, _grtj, yeib, _stym,
   {{0x9980016f,0x201a00d7,0x628601d7,0x17680ddc}},	//   žiť_, _sbpi_, unko, _труп_,
   {{0xf6520122,0x7c25033b,0xd5480c26,0x62860533}},	//   _מצא_, kehr, _نجوم_, rnko,
   {{0x1c030ccf,0x753602b5,0x75293550,0x200c00ab}},	//   _लागल_, _לאנד_, mwez, üdi_,
   {{0x44253551,0x64433552,0xceb40095,0x81e70033}},	//   mel_, _inni, tmə_, _পার_,
   {{0x66093553,0x7d0403fe,0x752908c7,0x00000000}},	//   ngek, tuis, owez, --,
   {{0x6e243554,0x75290a75,0x291f006f,0xceb40095}},	// [2c20] reib, nwez, _npua_, rmə_,
   {{0x44253555,0x22920097,0x7c25033b,0xa3ab3556}},	//   nel_, váky_, gehr, _खरा_,
   {{0x7d040dfa,0x291f00c3,0x2018079a,0xe1ff00d5}},	//   suis, _apua_, mfri_, bkód_,
   {{0xa2ca1d78,0x44253557,0x22920187,0x7d043558}},	//   _संस्, hel_, táky_, puis,
   {{0x44253559,0x2baa0299,0x1fa8021a,0x64430086}},	//   kel_, _करवा, _गरुड, _onni,
   {{0xd90d0a86,0xbb461cba,0x38a9355a,0x22920187}},	//   ئیل_, _легк, túra_, ráky_,
   {{0xe80e065a,0xf1bf016f,0xf1c805f7,0xfaa600d8}},	//   _साठा_, ndár_, रखान, _гаво,
   {{0x44250244,0x6443355b,0x6609355c,0x673a022f}},	//   eel_, _anni, ggek, _vrtj,
   {{0x4425355d,0x8966355e,0xc96600d8,0x96170037}},	//   fel_, _укаж, _увай, صغير_,
   {{0xe8d700a5,0x290608c7,0x20cf00ec,0x00000000}},	//   _לומר_, muoa_, _bļin_, --,
   {{0xf743261f,0x2f380359,0x9f4a01cb,0xdc9b1804}},	//   _нефо, _nčg_, babé_, רייל,
   {{0x326710fe,0x644311e6,0x466900d4,0xbddb00e0}},	//   стов, _enni, _крім_, _anèn,
   {{0x4425355f,0x2018003c,0x75290371,0x00000000}},	//   bel_, ffri_, cwez, --,
   {{0x44252572,0x27ee0093,0x00000000,0x00000000}},	//   cel_, nafn_, --, --,
   {{0x447b0122,0x7c250355,0x00000000,0x00000000}},	//   _תנוע, vehr, --, --,
   {{0x7c25033b,0x2906023c,0x00000000,0x00000000}},	//   wehr, kuoa_, --, --,
   {{0x463b02b5,0xdc5503fa,0xdb1c0310,0xa7fc027d}},	// [2c30] נעמע, овањ, _agrà, _alım,
   {{0x61ef3560,0xba3d00b8,0x00000000,0x00000000}},	//   lacl, _lhůt, --, --,
   {{0x50d40332,0x212b0297,0x99d7004f,0x9f430453}},	//   _وزیر, lwch_, متشا, bajá_,
   {{0x44253561,0x61ef3562,0x9f43021d,0x2be90831}},	//   zel_, nacl, cajá_, খলেই_,
   {{0x44253563,0x212b001e,0x5fd00026,0xa3e804bc}},	//   yel_, nwch_, तुकल, बरा_,
   {{0x7e6d3564,0xb901007c,0x27ee00e9,0xf99002ed}},	//   lhap, _दऽ_, gafn_, ربن_,
   {{0x2bdf2088,0x44253565,0xb8d00fd1,0x66090c7c}},	//   _प्या, vel_, _टी_, tgek,
   {{0x44253566,0x0f7c00a5,0x7e6d0553,0x00000000}},	//   wel_, טרול, nhap, --,
   {{0x66093567,0xd7fb0009,0xdb1c00ee,0x75293568}},	//   rgek, _буе_, _igrá, uwez,
   {{0x212b001e,0x66093569,0x752901e4,0x4425000b}},	//   dwch_, sgek, rwez, uel_,
   {{0x4425356a,0x7e6d0553,0xe80e01c0,0x60dd0345}},	//   rel_, khap, _साता_, epsm,
   {{0x4425356b,0xe29a356c,0xd6ab028c,0x2f38021e}},	//   sel_, рам_, _صدام_, _rčg_,
   {{0xa4f70609,0x7e6d01cb,0x212b00e9,0x2f38023a}},	//   _اکبر_, dhap, gwch_, _sčg_,
   {{0x6443008a,0x316c0067,0x00000000,0x00000000}},	//   _unni, ądz_, --, --,
   {{0x7e6d0051,0x1fb5248f,0xe81b01d1,0x00000000}},	//   fhap, зстр, प्या_, --,
   {{0x7e6d2326,0x7bd502a2,0xf1bf01ef,0xaaa800ab}},	//   ghap, _afzu, meán_, _छींक,
   {{0x63a30297,0xf1bf004f,0xec7a17a3,0x6da32c61}},	// [2c40] _hynn, leán_, апа_, дита,
   {{0x0c2300c3,0x63a3356d,0xdb1c356e,0x6721011c}},	//   ммун, _kynn, _agrá, _oplj,
   {{0x49ca07c1,0xad9b0098,0x7e6d01cb,0x00000000}},	//   ален_, _scút, bhap, --,
   {{0x7e6d356f,0x09e30370,0x63a33570,0x00000000}},	//   chap, доцн, _mynn, --,
   {{0x63a33571,0xe80e22a7,0x522d016b,0x00000000}},	//   _lynn, _सादा_, טואַ, --,
   {{0x6e3601c8,0x7e643572,0x786f0a8a,0x00000000}},	//   ldyb, lkip, _løvf, --,
   {{0x7d1615d6,0x63a33573,0x61ef013b,0x00000000}},	//   ltys, _nynn, yacl, --,
   {{0x6e363574,0xf1bf004f,0x27ee008a,0x7bc701f4}},	//   ndyb, deán_, safn_, _zgju,
   {{0xceb302b8,0x7d163575,0x7afa003e,0x00000000}},	//   ויה_, ntys, _ættb, --,
   {{0x31e302cb,0x63a3001e,0xb8660e0c,0x81e70083}},	//   पर्ध, _bynn, _بارو, _পাই_,
   {{0x63a302c7,0x61ef3576,0xe3b8027d,0x7e640421}},	//   _cynn, tacl, ldız_, kkip,
   {{0x212b001e,0x63b50187,0x63a300e9,0x7d160409}},	//   twch_, ýzna, _dynn, ktys,
   {{0x26cc3577,0x61ef3578,0x00000000,0x00000000}},	//   _hudo_, racl, --, --,
   {{0x80dd0083,0x26cc01f4,0x212b001e,0x741311c0}},	//   _বিদ্, _kudo_, rwch_, _يونا,
   {{0x63a302c7,0x7e6d3579,0x8f34357a,0x64580036}},	//   _gynn, thap, мерц, _iovi,
   {{0x6458357b,0xa1950208,0x975700a5,0x00000000}},	//   _hovi, _найч, חילו_, --,
   {{0x629d2de1,0x26cc357c,0x6458357d,0x7e6d357e}},	// [2c50] moso, _ludo_, _kovi, rhap,
   {{0x6458357f,0x61ed3580,0x7e6d3581,0x2ba703fa}},	//   _jovi, _heal, shap, ојев,
   {{0x64582280,0x61ed0fef,0x26cc3582,0x60cd3583}},	//   _movi, _keal, _nudo_, _huam,
   {{0x75223584,0x60cd000e,0x7e6402ec,0x61ed3585}},	//   _opoz, _kuam, ckip, _jeal,
   {{0xcfbd0083,0x6d4b01ff,0x60cd3586,0x672100f4}},	//   _অভিন, ågad, _juam, _splj,
   {{0x61ed3434,0x64583587,0x26cc3588,0x60c50069}},	//   _leal, _novi, _budo_, _jihm,
   {{0x25a92518,0xad9b0037,0x26cc3589,0x60cd358a}},	//   _šal_, _gcúr, _cudo_, _luam,
   {{0x26cc358b,0x7c35358c,0xdb1c00b5,0x60cd009e}},	//   _dudo_, _hazr, _ugrá, _ouam,
   {{0x629d358d,0x63a3358e,0x656000e9,0x49040037}},	//   doso, _synn, gymh, _يوفق,
   {{0xf1bf0037,0x13090421,0x26cc0090,0x00000000}},	//   teán_, бной_, _fudo_, --,
   {{0x61ed358f,0x64583590,0xbddb0176,0x7c353591}},	//   _beal, _dovi, _anèm, _mazr,
   {{0xf1bf004f,0x629d3592,0x61ed3593,0x60cd0698}},	//   reán_, goso, _ceal, _buam,
   {{0xf1bf004f,0x61ed3594,0x15453471,0xf8cb0035}},	//   seán_, _deal, _хелм, ादिय,
   {{0x653a02b5,0x7c353595,0x645800ec,0x63a33596}},	//   _לענד, _nazr, _govi, _tynn,
   {{0x629d3597,0x61ed3598,0x1eaa01b2,0x69c90103}},	//   boso, _feal, ماري_, _ogee,
   {{0x786f0a8c,0x61ed0094,0xe81b0440,0x69c93599}},	//   _høvd, _geal, प्ता_, _ngee,
   {{0xf1bf004f,0x60cd359a,0x00000000,0x00000000}},	// [2c60] neál_, _guam, --, --,
   {{0x7e64359b,0xeb9a021d,0x61ed359c,0x7659359d}},	//   skip, биз_, _zeal, _lowy,
   {{0xe805227d,0x7d163291,0x6d4b013c,0xfe46359e}},	//   _राजा_, stys, ägar, _енно,
   {{0x7659004e,0x60cd006d,0x7d160282,0x9f4a02d7}},	//   _nowy, _yuam, ptys, nabí_,
   {{0x7c3500d7,0x63a60035,0x00000000,0x00000000}},	//   _fazr, ękni, --, --,
   {{0xb8f40f39,0x26cc0831,0x2bdb2a06,0x7d04359f}},	//   _सं_, _pudo_, मुदा, mris,
   {{0x7522096f,0xd6d71667,0x25c10095,0x661b35a0}},	//   _spoz, пты_, ərlə_, ffuk,
   {{0x80dd00c8,0xfaa300d4,0x7d0435a1,0x99890b67}},	//   _বিস্, _засо, oris, žaš_,
   {{0x645835a2,0x68e9001e,0x629d35a3,0xd49a3464}},	//   _povi, _gwed, voso, йро_,
   {{0x26cc00c9,0x7d040a32,0x61ed35a4,0xb5fd00ea}},	//   _tudo_, iris, _seal, rkša,
   {{0x61ed0006,0xe61a35a5,0x7d0435a6,0x60cd005d}},	//   _peal, _где_, hris, _suam,
   {{0x7d0435a7,0xbddb02d0,0xad9b0042,0xd377010b}},	//   kris, _enèj, _ocúp, ячы_,
   {{0xf4871328,0xe53400c3,0x64582442,0x386c06fe}},	//   _کانی, _цель, _tovi, _kldr_,
   {{0x7d0435a8,0x629d35a9,0x7e7d00d7,0x61e000d0}},	//   dris, soso, _smsp, ımla,
   {{0xda0d0953,0x7c351851,0x25af35aa,0x7d0435ab}},	//   _हालत_, _razr, _zzgl_, eris,
   {{0x7d0435ac,0x7c35011c,0x2a660009,0x60cd35ad}},	//   fris, _sazr, jkob_, _tuam,
   {{0x2249016f,0xe7cc018d,0x82340833,0x786f23f4}},	// [2c70] _inak_, ाशाप, _سريا, _høve,
   {{0xdfd10037,0xdb1c017b,0x00000000,0x00000000}},	//   _جيد_, _ogrä, --, --,
   {{0xaac710ad,0x7d0435ae,0x68e935af,0xde5901e0}},	//   ستان, aris, _swed, _дані_,
   {{0x7d180082,0x7d042190,0x68e90269,0x37e60033}},	//   éasá, bris, _pwed, _নাগর,
   {{0x26160006,0x3ea935b0,0x25a60118,0x20d3198f}},	//   _भउजी_, mlat_, _nyol_, _धूमध,
   {{0x3ea935b1,0x07a535b2,0x013800a5,0xc7a501e0}},	//   llat_, малн, פרות_, милк,
   {{0x224935b3,0x12c70083,0xb8f4111e,0x765920bc}},	//   _onak_, _শব্দ, _सू_, _powy,
   {{0xd87701ca,0x645c35b4,0x7afa008d,0x68e90345}},	//   _کارب, örin, _ætta, _twed,
   {{0xbddb0260,0x1dbf07df,0xdce400f4,0x00000000}},	//   _anèk, ्शित, rzić, --,
   {{0x224935b5,0x2a6d35b6,0x25a60359,0x3ea90421}},	//   _anak_, _hleb_, _dyol_, hlat_,
   {{0x3ea900d6,0x04ff0033,0xa22a110d,0x80dd0033}},	//   klat_, ্বের_, ожна_, _বিষ্,
   {{0x7d04008a,0x1fc50083,0xcfc50033,0x38b200af}},	//   yris, ্রাস, ্রান, râre_,
   {{0x66c7027d,0x3ea935b7,0xbbaa1e18,0x00000000}},	//   _fıkr, dlat_, _कर्क, --,
   {{0x80dd0b52,0x63850923,0x22493086,0x00000000}},	//   _বিশ্, _огла, _enak_, --,
   {{0xe29f008a,0x4f95002d,0x8fa30227,0x3ea935b8}},	//   boð_, ерту, варе, flat_,
   {{0xe1ff0501,0xecea1172,0x00000000,0x00000000}},	//   lkón_, ждал_, --, --,
   {{0x32d30028,0xe80e1782,0xbea3032f,0xd12f00d1}},	// [2c80] _hãy_, _साला_, татк, _نمي_,
   {{0x224935b9,0x3ac800a8,0x3ea9231e,0x25a2018d}},	//   _znak_, _aşpa_, alat_, ükli_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d041691,0x20d400be,0x3ea90310,0x2efa0027}},	//   pris, _käi_, clat_, _ivpf_,
   {{0x20d41c55,0xaac500f8,0x2bdf0af6,0xbdfb103b}},	//   _jäi_, رتمن, _प्वा, _برپا_,
   {{0xd6da35ba,0x3ea001ef,0xbddb0118,0x4c350043}},	//   оти_, loit_, _anèh, _пэст,
   {{0xf79301c8,0xdca319fa,0x32d300e2,0xdc37016b}},	//   кашэ, _рари, _nãy_, _קאלט_,
   {{0xa5340011,0x3ea035bb,0x786f08c8,0x00000000}},	//   енич, noit_, _røve, --,
   {{0x64c805f7,0x6d40063c,0x786f0a8a,0x224901ed}},	//   रदेश, _šmaj, _døvb, _rnak_,
   {{0x224935bc,0x83860409,0x80dd0033,0x3ea001ed}},	//   _snak_, дыме, _বিল্, hoit_,
   {{0xd37a2743,0x22490118,0x00000000,0x00000000}},	//   ючи_, _pnak_, --, --,
   {{0x05660012,0x32d30023,0x475900af,0x00000000}},	//   _овен, _dãy_, _эруя_, --,
   {{0x3ea92cfb,0xa2ca1729,0xd83802a7,0xf1ab00f8}},	//   vlat_, _संक्, _kač_, تاده_,
   {{0xdbf30463,0x9f4301ba,0x961d00ea,0x2906002a}},	//   _işçi, majú_, miņa, iroa_,
   {{0x442c35bd,0xd838011c,0xc0580823,0x32d30023}},	//   med_, _mač_, фія_, _gãy_,
   {{0x442c35be,0xd8380107,0x3ea90460,0xc1150fb4}},	//   led_, _chčz_, ulat_, _змиј,
   {{0x3ea935bf,0x442c001e,0x68e200ac,0x865b00a5}},	// [2c90] rlat_, oed_, jpod, קדמי,
   {{0x3ea935c0,0x6ab9021a,0x29061c7a,0xb5fd00ea}},	//   slat_, ेद्र, droa_, ekšl,
   {{0x2a6d006d,0x3ea935c1,0x9f4300a0,0x26de0051}},	//   _pleb_, plat_, hajú_, _ntto_,
   {{0x2bdf1119,0x442c35c2,0xfbdf0d53,0xdd140038}},	//   _प्रा, hed_, _प्रम, _súťa,
   {{0x442c35c3,0x26de02fb,0xd8380df4,0x6e2d002a}},	//   ked_, _atto_, _bač_, meab,
   {{0x442c35c4,0x7d0d35c5,0x6e2d0037,0x9f4301ba}},	//   jed_, muas, leab, dajú_,
   {{0x442c01f3,0xa2ca020c,0x7d0d35c6,0xc7a2208b}},	//   ded_, _संग्, luas, лишк,
   {{0xbb4801ca,0x6e2d35c7,0x442c013a,0x290601ef}},	//   _تلفن_, neab, eed_, broa_,
   {{0x442c35c8,0x79a70798,0x2bc3252c,0x7d0d35c9}},	//   fed_, _црве, _वृता, nuas,
   {{0xa2ca0f17,0xe451004f,0x442c35ca,0x3ea0028b}},	//   _संख्, اضة_, ged_, zoit_,
   {{0xe2860b46,0x4e0f2924,0x00000000,0x00000000}},	//   елни, िलाई_, --, --,
   {{0x7d0d0f1a,0x644a35cb,0xd83800ac,0x442c00be}},	//   kuas, _enfi, _zač_, aed_,
   {{0x442c35cc,0x764b006c,0x6e2d07a6,0x3e6e0093}},	//   bed_, _ingy, deab, _nýta_,
   {{0x442c24f4,0xa2ca25d8,0x2bdf1bc6,0xa06a00d8}},	//   ced_, _सूक्, _प्ला, чага_,
   {{0x62580183,0x00000000,0x00000000,0x00000000}},	//   _mãoz, --, --, --,
   {{0x6e2d35cd,0x7d0d0054,0x68fb35ce,0x00000000}},	//   geab, fuas, _ovud, --,
   {{0x628635cf,0x7d0d35d0,0x764b0159,0x68fb073a}},	// [2ca0] miko, guas, _mngy, _nvud,
   {{0x62860a0b,0x69db0831,0x68e20009,0xbca600f3}},	//   liko, _afue, vpod, رماي,
   {{0x961d0029,0x764b012f,0x09ba35d1,0x9f4301ba}},	//   ziņa, _ongy, ेश्य, zajú_,
   {{0xfce60109,0x628635d2,0x442c35d3,0x290635d4}},	//   _помо, niko, zed_, troa_,
   {{0xa967010e,0x442c0122,0xd83802c6,0xf09f0176}},	//   ница_, yed_, _pač_, iràn_,
   {{0x628635d5,0x290606a2,0x9f43016f,0x442c0122}},	//   hiko, rroa_, vajú_, xed_,
   {{0x442c0052,0x628635d6,0x7bce043d,0xe6660431}},	//   ved_, kiko, _igbu, етпо,
   {{0x442c35d7,0x628635d8,0x2906012f,0x9f4300a0}},	//   wed_, jiko, proa_, tajú_,
   {{0x442c35d9,0x628635da,0xdb1c0079,0xad9b0168}},	//   ted_, diko, _ngrú, _idúc,
   {{0x6aa20136,0x998000d8,0x9f4301ba,0x764b35db}},	//   loof, žių_, rajú_, _engy,
   {{0x442c35dc,0xdb1c0042,0x43940f68,0x00000000}},	//   red_, _agrú, танс, --,
   {{0x442c35dd,0x628635de,0x998900a0,0x3f85008e}},	//   sed_, giko, žať_, úlum_,
   {{0x442c0122,0x6e2d02ce,0x628f0051,0x7bdc0031}},	//   ped_, veab, rnco, _ofru,
   {{0x6aa21472,0xc0580208,0x41a501c0,0x7bce35df}},	//   hoof, ніс_, _गुणस, _ngbu,
   {{0x02a735e0,0x5334111d,0x62860a74,0xc90d01c0}},	//   _прим, _рейт, biko, _सम्म_,
   {{0x7d0d35e1,0x7bce011e,0x628635e2,0x7bdc35e3}},	//   tuas, _agbu, ciko, _afru,
   {{0x6e2d35e4,0x9f4a1438,0xbbeb0037,0x2bc3012f}},	// [2cb0] reab, rabá_, كرام_, वेना,
   {{0x6e2d35e5,0xf8b80023,0x22590009,0x00000000}},	//   seab, _nhĩ_, ljsk_, --,
   {{0x68fb0254,0x7afa008d,0x3944024b,0x7afc0a66}},	//   _svud, _ættl, _arms_, _cvrt,
   {{0x636b006c,0xd7f10023,0x2bd31746,0x63aa00a2}},	//   lönö, _sẽ_, _तलवा, _myfn,
   {{0x7d0d0036,0xb5fd00c7,0x6258021d,0x00000000}},	//   quas, ukšm, _pãoz, --,
   {{0x628635e6,0xf8b800cc,0x00000000,0x00000000}},	//   ziko, _chĩ_, --, --,
   {{0x764b0159,0x628601d5,0xdb15021e,0xa6950bfe}},	//   _pngy, yiko, _egzò, криј,
   {{0x628635e7,0xbddb0260,0x21290118,0x6edc08b7}},	//   xiko, _enèv, _opah_, _učbe,
   {{0xf9930e0c,0x383500af,0x628635e8,0x69c435e9}},	//   _صبر_, _инар, viko, žier,
   {{0x446535ea,0x2bb80992,0x58d40de3,0x290f35eb}},	//   твов, _अरमा, _софт, muga_,
   {{0xe29a35ec,0xfbd20052,0x63aa0297,0x78a30009}},	//   дан_, יתי_, _cyfn, monv,
   {{0x20012745,0x63aa016e,0x00000000,0x00000000}},	//   _adhi_, _dyfn, --, --,
   {{0x628635ed,0x290f0a47,0xa564004f,0x291d33e5}},	//   riko, nuga_, _مدون, ntwa_,
   {{0x291d0054,0x290f0553,0x78a302ee,0x00000000}},	//   itwa_, iuga_, nonv, --,
   {{0x63aa001e,0x8fa60265,0x290f35ee,0x00000000}},	//   _gyfn, таве, huga_, --,
   {{0x7bdc35ef,0x291d02e9,0x290f00ab,0xb146002d}},	//   _sfru, ktwa_, kuga_, _анил,
   {{0xc5f21899,0x6f0e0211,0x290f35f0,0x62840067}},	// [2cc0] ידן_, subc, juga_, _imio,
   {{0x290f35f1,0x1f66002d,0x2004010b,0x00000000}},	//   duga_, _аком, ėmis_, --,
   {{0x78a335f2,0x00000000,0x00000000,0x00000000}},	//   donv, --, --, --,
   {{0x290f01a8,0xc98615ae,0x00000000,0x00000000}},	//   fuga_, кули, --, --,
   {{0x6aa22541,0x78a303d0,0x290f00be,0x6fd9021a}},	//   roof, fonv, guga_, _मलमू,
   {{0x7afc0c21,0xa7fc037a,0xa3c30035,0x3a2435f3}},	//   _tvrt, _alır, ्शा_, _wbmp_,
   {{0x7c3c0f46,0x6d460124,0x3944021d,0x62840103}},	//   _iarr, _hrka, _wrms_, _omio,
   {{0x290f0198,0x7c3c35f4,0x7c3e35f5,0x3e6e0097}},	//   buga_, _harr, ldpr, _mýto_,
   {{0x7c3c35f6,0x291d004e,0x81d80033,0x08c635f7}},	//   _karr, ctwa_, িরা_, _абан,
   {{0x7c3c03cb,0xdb1c01a6,0x6d46023a,0xdb0e0160}},	//   _jarr, _sgrù, _mrka, _izbâ,
   {{0xd2510e3a,0x7c3c357e,0xd7a90722,0x64a30370}},	//   مند_, _marr, _चुपच, раќа,
   {{0x7c3c0291,0x6d4635f8,0xa77b0070,0x2ebe021a}},	//   _larr, _orka, _קראפ, ्दोत,
   {{0xd8380009,0x518416b8,0x316d0300,0x955300d1}},	//   _akči_, аура, áez_, _نخوا,
   {{0x8c080083,0x8cd60084,0x7c3c35f9,0x258400ea}},	//   র্তন_, _बढ़ो, _narr, rīlī_,
   {{0x54330a72,0xdef80043,0x443c0221,0x6d4635fa}},	//   _ضرور, кыт_, _iav_, _arka,
   {{0x443e35fb,0x443c35fc,0x3cfe1163,0xa2cb08b0}},	//   ldt_, _hav_, _लिखे_, _सूच्,
   {{0x443c0189,0x7c3c35fd,0x21290ac8,0x80dd0083}},	// [2cd0] _kav_, _barr, _upah_, _বিক্,
   {{0x443e35fe,0x290f070b,0x7c3c35ff,0x443c1665}},	//   ndt_, vuga_, _carr, _jav_,
   {{0x7c3c0955,0x443c01e8,0x6d463600,0x443e3601}},	//   _darr, _mav_, _erka, idt_,
   {{0x7c3c1093,0x443c3602,0x998400d8,0x66023603}},	//   _earr, _lav_, _namų_, _ndok,
   {{0x7c3c3604,0xe8df0019,0x443c3605,0x6d4600ee}},	//   _farr, _trọn_, _oav_, _grka,
   {{0x443c0ae0,0x7c3c3606,0x290f3607,0x7e6d3608}},	//   _nav_, _garr, ruga_, lkap,
   {{0x291d3609,0x290f360a,0x6d4601ba,0x46f400d8}},	//   stwa_, suga_, _zrka, ачыт,
   {{0x443e0120,0xc1e3360b,0x7c3c01a3,0x6d46017b}},	//   edt_, _क्लब_, _zarr, _yrka,
   {{0x9a840183,0x26140066,0x6e3d360c,0x66020069}},	//   _турл, _धारी_, _masb, _ddok,
   {{0x443c006f,0x7c3c1d75,0x649d12c3,0x6284360d}},	//   _cav_, _xarr, nèix, _smio,
   {{0x443c0189,0xf7700833,0x461500d1,0x7e6d00c3}},	//   _dav_, _وام_, _موار, kkap,
   {{0xe0c902b5,0x443e23b5,0x6d030096,0x6e3d360e}},	//   _זײ_, adt_, _लिंग_, _nasb,
   {{0x81ac0083,0x321e0035,0x2bc31371,0x3e6e00ee}},	//   কেন_, ęty_, वेता, _sýto_,
   {{0x40952846,0x443c360f,0x66020187,0x80dd0033}},	//   арст, _gav_, _zdok, _বিখ্,
   {{0x6e3d3610,0x6d46063b,0x9f580055,0x6aa90069}},	//   _basb, _srka, marë_, _okef,
   {{0x7c3c0291,0x7e6d3611,0xa3df00ab,0x6d460207}},	//   _sarr, gkap, धुर_, _prka,
   {{0x7c3c3612,0x261b0299,0x0c26150d,0x443c0189}},	// [2ce0] _parr, _यानी_, лман, _yav_,
   {{0x443c0d4b,0x7c3c035f,0x786f082b,0x6e3d00f1}},	//   _xav_, _qarr, _søvn, _easb,
   {{0x7c3c3613,0x645c1b43,0x16030099,0x629d00a2}},	//   _varr, örii, ळणार_, érog,
   {{0xe3c50083,0x998d0035,0x7c3c3614,0x6d460a23}},	//   _এভাব, _oceń_, _warr, _trka,
   {{0x7c3c3615,0x6abb0211,0x5886004b,0xbddb01f7}},	//   _tarr, _dhuf, лыка, _enès,
   {{0x61f6045e,0x60d6010d,0x6e2402fc,0x95f00033}},	//   _leyl, _muym, lfib, _টাইম_,
   {{0x6d443616,0xbddb01f7,0x2bc305a6,0x9f580031}},	//   lvia, _inèr, वेदा, darë_,
   {{0x443c3617,0x9b93004f,0xfaa63618,0x7ae33619}},	//   _sav_, _الفت, _сабо, ínte,
   {{0x6d4412c3,0xd9432dbb,0x443c361a,0x4427361b}},	//   nvia, _лети, _pav_, _bbn_,
   {{0xd5c006bb,0x443c0221,0x443e213d,0x7e6d361c}},	//   शेषज, _qav_, udt_, zkap,
   {{0x443e25cb,0x443c30bc,0x61f6033e,0x7e6d067f}},	//   rdt_, _vav_, _beyl, ykap,
   {{0x201a0024,0x673a003a,0x61f61008,0x442701ed}},	//   _acpi_, _istj, _ceyl, _ebn_,
   {{0x443c361d,0x6d44016f,0x9f510097,0x4427009e}},	//   _tav_, jvia, razí_, _fbn_,
   {{0x443c361e,0x60d6033e,0x00000000,0x00000000}},	//   _uav_, _duym, --, --,
   {{0xb4c2361f,0xe81c2e4f,0xb4c010a6,0x7e6d3620}},	//   ्दी_, _नाना_, ंगी_, tkap,
   {{0xe80e06bb,0x6e3d009f,0x4ea70804,0x7640183a}},	//   _साझा_, _qasb, урга, ndmy,
   {{0xb8042e4f,0x7d550036,0x5d550265,0x38bb03bc}},	// [2cf0] रणाम_, швах, шкат, lêre_,
   {{0x7e6d3621,0x673a00ab,0x9ed9029f,0xb5fd0009}},	//   skap, _ostj, _имот_, rkši,
   {{0x649d0443,0xd1b800b5,0x00000000,0x00000000}},	//   rèix, _لایا_, --, --,
   {{0x81f30083,0x61f600a8,0xbddb01f7,0xb4c20af9}},	//   _ঝাঁপ_, _xeyl, _enèr, ्दु_,
   {{0xc27c0070,0xa3ab0803,0x527c016b,0x2c760b3e}},	//   ערדי, _कुन_, ענדא, _sæde_,
   {{0x1bd43622,0x2bdb21b2,0x7d0d3623,0x41c7143a}},	//   _горя, मुखा, mras, रेयस,
   {{0x9f580031,0x9f430176,0x00000000,0x00000000}},	//   varë_, majó_, --, --,
   {{0x673a023a,0x0f5800a5,0x00000000,0x00000000}},	//   _dstj, ריהם_, --, --,
   {{0x9f5800da,0x7d0d01d6,0xb4c20534,0x4427055c}},	//   tarë_, nras, ्दू_, _pbn_,
   {{0x0325015a,0x291f01f7,0xddc400c7,0x61f600a3}},	//   адон, _iqua_, nkiš, _seyl,
   {{0x7d0d3624,0xe1ff004e,0x3a3f3625,0xe70b1c73}},	//   hras, nków_, _kaup_, _ستان_,
   {{0x80dd00c8,0x216a00d4,0x6d44010b,0x6146021f}},	//   _বিজ্, вими_, yvia, аема,
   {{0x34953626,0xe2973627,0x9f583628,0x44270023}},	//   _кадр, рая_, maré_, _tbn_,
   {{0xd4660202,0x6d4407e5,0x26cf0453,0xe5c4010b}},	//   _више_, vvia, _higo_, _усхо,
   {{0x26cf01d0,0x6e24027a,0x7d0d3629,0x00000000}},	//   _kigo_, tfib, eras, --,
   {{0x9f580176,0xe1ff0035,0x539a00a5,0xddc90693}},	//   naré_, dków_, _ביצו, _šošt,
   {{0x7d0d362a,0xac860c0d,0x291f006d,0x26cf02d7}},	// [2d00] gras, агал, _nqua_, _migo_,
   {{0x6441362b,0xd12f064e,0x26cf362c,0x0eb800a1}},	//   ndli, _کمی_, _ligo_, _आठवड,
   {{0x7d0d362d,0x64411d22,0xdddd006c,0x2abc00de}},	//   aras, idli, _első, híbe_,
   {{0x9f580a17,0x6da600d4,0x7d0d14bc,0x2240362e}},	//   jaré_, _вима, bras, _jaik_,
   {{0x44e9362f,0x7d0d3630,0x290003e6,0x9f58181f}},	//   _nº_, cras, éia_, daré_,
   {{0x20183631,0x37063632,0x3eb22f06,0x64410223}},	//   ngri_, ачив, llyt_, jdli,
   {{0x64410699,0x291f0036,0x26cf3633,0x9f580176}},	//   ddli, _equa_, _bigo_, faré_,
   {{0x644102c9,0x22400224,0x9f58181f,0xeb9700d4}},	//   edli, _naik_, garé_, _тис_,
   {{0xd5b73634,0x26cf1721,0x44e902d7,0x442509a2}},	//   ись_, _digo_, _cº_, ffl_,
   {{0xb4c0006a,0xb4c20d4e,0x2bc300ab,0x38bb03bc}},	//   ंगे_, ्दे_, वेवा, têre_,
   {{0x22403635,0x394600d8,0x3e75013c,0x9f583636}},	//   _baik_, lvos_, _låta_, baré_,
   {{0xc5f000c8,0x9f583637,0x64413638,0x38bb0b88}},	//   _টাকা_, caré_, adli, rêre_,
   {{0x22400fef,0x64d1012f,0x4425009e,0x00000000}},	//   _daik_, सदृश, bfl_, --,
   {{0x83f82b92,0x53340810,0x7d0d3639,0x27fc03db}},	//   _секс_, _гект, vras, navn_,
   {{0x06fd00b8,0x2240363a,0x00000000,0x00000000}},	//   žívá_, _faik_, --, --,
   {{0x27fc01b4,0x2c190099,0x2a640260,0x20181b37}},	//   havn_, _पाहू_, _nomb_, agri_,
   {{0xddc400cb,0xdb1c0035,0x6d40008b,0x66d5010b}},	// [2d10] tkiš, _ogró, _šmar, _iške,
   {{0xe1ff0035,0x9f58363b,0x61fd363c,0xa3aa363d}},	//   tków_, zaré_, lasl, _खडा_,
   {{0x291f0069,0x1da700ab,0x7d0d363e,0x7e9900fd}},	//   _squa_, _कुरत, sras, _مندر_,
   {{0x7d0d363f,0xa3e60567,0xde590402,0xdb1c0138}},	//   pras, युत_, _самі_, _agró,
   {{0x39490f56,0xf99011c0,0xd9453640,0x0dcb0370}},	//   ías_, وبه_, сели, _јуни_,
   {{0x26cf3641,0xb4c201c0,0xb4c03100,0xf8a8010b}},	//   _sigo_, ्दो_, ंगो_, авік_,
   {{0xb4c20311,0x61fd0291,0x9f583642,0x26cf3643}},	//   ्दै_, kasl, taré_, _pigo_,
   {{0x3ea902ee,0x2f980122,0x61fd00ea,0x20180124}},	//   noat_, יכון_, jasl, zgri_,
   {{0x26cf0caa,0x880718dd,0xc485081b,0x9f580747}},	//   _vigo_, _نظام, йлик, raré_,
   {{0x9f583644,0x26c40036,0x26cf08c7,0x66d502a7}},	//   saré_, ammo_, _wigo_, _aške,
   {{0x644119ea,0xe81c056a,0xa25b0132,0x9f583645}},	//   rdli, _नाता_, rmôn, paré_,
   {{0x27213646,0x6f153647,0x625a3648,0x7d0200c7}},	//   món_, duzc, урор_, šosi,
   {{0x272133d5,0xa5093649,0x5a9a025a,0x00000000}},	//   lón_, _села_, רשרא, --,
   {{0x645c1130,0x00000000,0x00000000,0x00000000}},	//   örit, --, --, --,
   {{0x2721043f,0xdee600cf,0xb21b08c8,0x3ea90298}},	//   nón_, соби, dhæf, foat_,
   {{0x2252014c,0x394600c7,0xbda60037,0x00000000}},	//   _unyk_, yvos_, محذو, --,
   {{0xed57364a,0x2721364b,0x2a64009e,0x00000000}},	// [2d20] бот_, hón_, _romb_, --,
   {{0xa3ab364c,0x00000000,0x00000000,0x00000000}},	//   कअप_, --, --, --,
   {{0xfbc3009a,0x2721364d,0xdb1c01f7,0xf1a901cb}},	//   वेलम, jón_, _agrò, _مایه_,
   {{0x2721364e,0x82d60070,0x7bd5005f,0xef220067}},	//   dón_, צונג_, _egzu, ążę_,
   {{0x19581385,0x186a364f,0xceb40095,0xa3e72874}},	//   ралы_, лади_, mlə_, बडा_,
   {{0xfce33650,0x27213651,0x6e360644,0xceb400a8}},	//   _хоро, fón_, leyb, llə_,
   {{0x27210f56,0xa3c93652,0x61e40139,0x61fd01fb}},	//   gón_, लेम_, _ofil, yasl,
   {{0x27fc008c,0xceb40095,0x20cf0024,0x3e6e06fe}},	//   savn_, nlə_, _ażil_, _býti_,
   {{0x2d803653,0xb5fd0029,0x61fd3654,0x99920035}},	//   nzie_, ekšs, vasl, żył_,
   {{0xd6d21e23,0xb8653655,0x27211111,0xf48400e0}},	//   _فقط_, _والو, bón_, تابی,
   {{0x272125ac,0xceb40095,0x61fd3656,0x61e9002a}},	//   cón_, klə_, tasl, ñelo,
   {{0x9c8700b8,0x41e400d8,0x290000c7,0x7afa008d}},	//   _kočá, зіра, šiau_, _ættu,
   {{0x61fd02dd,0x1da70380,0x00000000,0x00000000}},	//   rasl, _कुंत, --, --,
   {{0x2d800755,0x61e407c0,0x61fd3657,0x9f5a021d}},	//   dzie_, _efil, sasl, _iepê_,
   {{0x61e4001e,0x4fc433d2,0xddcf0139,0x7e662433}},	//   _ffil, зста, _bocş, _bokp,
   {{0x5f9428a1,0xa1951089,0x00000000,0x00000000}},	//   чист, _майч, --, --,
   {{0x272109ab,0x2d5800aa,0x628f2e65,0x7e6600d4}},	// [2d30] zón_, бить_, mico, _dokp,
   {{0xebc703fa,0x6f153658,0xf21f0324,0x27213659}},	//   бљен, puzc, _भाड़_, yón_,
   {{0x272101dd,0xb5fd24d4,0x7e660051,0xb21b0093}},	//   xón_, ljše, _fokp, rhæf,
   {{0xdb1f003e,0x7d16011e,0x2721365a,0x290f023a}},	//   _ávís, buys, vón_, trga_,
   {{0xae1a00c2,0xd5a6006c,0x786f008c,0xb5fd08b7}},	//   _דורכ, _آف_, _høvi, njše,
   {{0x2721069c,0xd7fb027a,0xd3660d47,0x628f0139}},	//   tón_, ууд_, _قه_, hico,
   {{0x628f1bfa,0x00000000,0x00000000,0x00000000}},	//   kico, --, --, --,
   {{0x2721184d,0xb4d10b35,0x628f19be,0xb5fd00ea}},	//   rón_, वद्_, jico, ekšr,
   {{0x628f0aca,0x6499365b,0x2721365c,0x786f008c}},	//   dico, итор_, són_, _løvi,
   {{0x2721116c,0x448909ce,0x61e4365d,0x6aab1ae5}},	//   pón_, рбон_, _sfil, logf,
   {{0x628f1423,0x320931dc,0x68e902c4,0xe7ef00a1}},	//   fico, _bday_, _hted, _घ्या_,
   {{0x628f365e,0xd5750f92,0xf1bf02d7,0xe297365f}},	//   gico, _муль, rfán_, жаю_,
   {{0x7e660159,0x2a3a0070,0xceb400a8,0xf1bf01ef}},	//   _rokp, בערמ, vlə_, sfán_,
   {{0x7e660009,0x201e3660,0x00000000,0x00000000}},	//   _sokp, üti_, --, --,
   {{0xceb40095,0x7e6608dd,0x64430139,0x2abc02d7}},	//   tlə_, _pokp, _iani, híba_,
   {{0x661b3661,0xee3a04bf,0x394d3662,0x2d803663}},	//   nguk, јна_, _ores_, tzie_,
   {{0x64433664,0x7fd63665,0xa3c30302,0xbc6624df}},	// [2d40] _kani, _міні, ्शक_, овак,
   {{0xa3bd0243,0x2d803666,0x6fde0026,0xceb4013b}},	//   _आरा_, rzie_, _मलिं, slə_,
   {{0x394d3667,0xe9da3668,0x6a863669,0x68e92e1e}},	//   _ares_, аке_, олжа, _ated,
   {{0x6443040c,0x2bdc00b4,0x9c8700b8,0x394d099e}},	//   _lani, _बलवा, _počá, _bres_,
   {{0x81ac00c8,0x394d366a,0xdb0700b8,0x59a50099}},	//   কের_, _cres_, _vyjá, गॅलर,
   {{0x6443366b,0xc1730122,0xb902366c,0xd90d00d1}},	//   _nani, וחד_, _नं_, ایل_,
   {{0x394d366d,0x8b231a31,0xe3a700d2,0xea5a04bf}},	//   _eres_, _одре, _آر_, _крај_,
   {{0x628f0042,0x6443366e,0x395d006d,0xba1a0037}},	//   xico, _aani, bxws_, _خيرا_,
   {{0x6443366f,0xd49a05a1,0xd90d042c,0x261b0324}},	//   _bani, иро_, _مین_, _यारी_,
   {{0x64433670,0x7d043671,0xe46a1099,0xa25b0183}},	//   _cani, isis, ршил_, rmôm,
   {{0x628f3672,0x7d043673,0x00000000,0x00000000}},	//   tico, hsis, --, --,
   {{0x7d043674,0xd37701c8,0x64430159,0xdb213675}},	//   ksis, ючы_, _eani, étét,
   {{0x628f3676,0x64433677,0x7c2e0036,0x6600028b}},	//   rico, _fani, _obbr, mamk,
   {{0x628f0aca,0x64433678,0x66003679,0x7d040009}},	//   sico, _gani, lamk, dsis,
   {{0x628f1417,0x44e0367a,0x7d04367b,0x81ac0033}},	//   pico, _hò_, esis, কেল_,
   {{0x644304c3,0x44e00c1f,0x7c2e367c,0x6600000e}},	//   _zani, _kò_, _abbr, namk,
   {{0xd9040ef5,0x5c75010c,0x7d0400a7,0x628d02c4}},	// [2d50] _جی_, плат, gsis, _imao,
   {{0x44e0367d,0x6600028b,0xfc33004f,0x64430be2}},	//   _mò_, hamk, بحر_, _xani,
   {{0x44e0367e,0x6600367f,0x68e93680,0x394d02d7}},	//   _lò_, kamk, _sted, _sres_,
   {{0x66001f1d,0x442e028b,0x7c2e3681,0x787d0260}},	//   jamk, _lbf_, _ebbr, _mève,
   {{0x66000ac8,0x44e002e9,0x81cd0033,0x22920693}},	//   damk, _nò_, শুর_, nška_,
   {{0x68e901ba,0x6d4f0088,0x3e7c00b8,0x48ab0200}},	//   _vted, _irca, _víte_, штем_,
   {{0xf7710fab,0x64433682,0x68e9004e,0xb902007c}},	//   عات_, _rani, _wted, _नू_,
   {{0x394d0aaf,0x44e03683,0x6600046a,0x442e0523}},	//   _tres_, _bò_, gamk, _abf_,
   {{0x64433684,0x44e03685,0x7982004e,0x6d4f011e}},	//   _pani, _cò_, czow, _jrca,
   {{0x629d3686,0x64433687,0x442e3688,0x44e03689}},	//   éron, _qani, _cbf_, _dò_,
   {{0xf1a9012b,0x229201c8,0xa3ab0084,0x00000000}},	//   _עס_, eška_, _कुश_, --,
   {{0x64430464,0xe29a368a,0x44e002e9,0x7d04368b}},	//   _wani, сам_, _fò_, ysis,
   {{0x2bb80c67,0x6443368c,0xbbb8000c,0x44e00019}},	//   _अर्थ, _tani, _अर्क, _gò_,
   {{0x7ae9368d,0x6443034d,0xf09f0310,0x787d00a2}},	//   _četn, _uani, dràs_, _fève,
   {{0xe7cb012f,0x1fb50377,0x00000000,0x00000000}},	//   ाधिप, дстр, --, --,
   {{0x7d04368e,0x3e6e008a,0x71a6368f,0x6d4f02a7}},	//   tsis, _nýtt_, _найз, _brca,
   {{0xe81c04bc,0xed573690,0x44e0298d,0x6d4f009e}},	// [2d60] _नाला_, пот_, _xò_, _crca,
   {{0x7d043691,0x320200ac,0xe05800d1,0x99dd00a0}},	//   rsis, laky_, _بیست_, _raňa,
   {{0x66001ea7,0x8ad600f3,0x2baf0066,0x7d040147}},	//   yamk, ستائ, _जुदा, ssis,
   {{0x32020187,0x7d043692,0xfaa312ea,0x1c1e00ab}},	//   naky_, psis, нахо, _पावल_,
   {{0x6d4f0156,0xbddb0118,0x7d040055,0x9f580392}},	//   _grca, _maèl, qsis, larà_,
   {{0x44e000e2,0xf7720079,0x79820035,0x91bb00a5}},	//   _rò_, فاع_, rzow, זמני,
   {{0xa3ab0f9c,0x44e03693,0x6d4f3694,0x9f580443}},	//   _कुल_, _sò_, _zrca, narà_,
   {{0x44e01bbf,0x32020187,0x7e64022e,0x09d10033}},	//   _pò_, jaky_, njip, াড়া,
   {{0x320200ee,0x6600028b,0x1dbe0edf,0xa3c90cea}},	//   daky_, ramk, ्धित, लेस_,
   {{0x69c00bc6,0x628d1093,0x66003695,0xa3e61140}},	//   _izme, _smao, samk, युं_,
   {{0xd25100bf,0x44e00260,0x9f580392,0x00000000}},	//   نند_, _wò_, jarà_, --,
   {{0xa75b00a5,0x44e03696,0x1dbe00e7,0x9f580443}},	//   _לדבר, _tò_, ्धात, darà_,
   {{0xc05b00d4,0x442e3697,0x290602c4,0x6ed629ce}},	//   бів_, _tbf_, nsoa_, _मंजु,
   {{0x26de3698,0x22921bd8,0x98bf00cd,0x9f580176}},	//   _kuto_, rška_, _vruć_, farà_,
   {{0xb5fd02dd,0x64583699,0xcfa40043,0x7ae9042a}},	//   ljša, _invi, ешти, _četo,
   {{0x81ac00c8,0x02a401c8,0x26de018c,0xbddb0176}},	//   কেই_, _прым, _muto_, _gaèl,
   {{0x2d580086,0xb5fd008b,0x442c369a,0x00000000}},	// [2d70] пить_, njša, ofd_, --,
   {{0xebc70274,0x9f580443,0x6d4f00f4,0x26de0328}},	//   пљен, barà_, _vrca, _outo_,
   {{0x2003369b,0x6448001e,0x629d369c,0xddc6021e}},	//   maji_, iddi, onso, _lakň,
   {{0x2003369d,0x6d4f0124,0x629d24ac,0x2ea80099}},	//   laji_, _trca, nnso, ककृत,
   {{0x1869059b,0x9f581ea3,0x64580a8d,0x6d4f00af}},	//   жали_, mará_, _onvi, _urca,
   {{0x26de369e,0x2003369f,0x9f580181,0x629d36a0}},	//   _buto_, naji_, lará_, hnso,
   {{0x47d00083,0x6d4d36a1,0x60df03da,0xa6c9167d}},	//   _স্বী, lvaa, _luqm, олка_,
   {{0x9f580152,0x6e2d36a2,0xa3c20440,0x442c01e4}},	//   nará_, nfab, ्धन_, efd_,
   {{0x6d4d1816,0x200336a3,0x320200ac,0x442c02d7}},	//   nvaa, kaji_, vaky_, ffd_,
   {{0xd7c801cb,0x200336a4,0xd90d006c,0x99dd00ac}},	//   _کومه_, jaji_, _میچ_, _kaňo,
   {{0x200336a5,0x06d70083,0x3e7c0093,0x26de36a6}},	//   daji_, _সবকি, _líta_, _guto_,
   {{0x64480a21,0x9f5836a7,0x60c50159,0x66d500c7}},	//   addi, jará_, _ahhm, _iško,
   {{0x9f580152,0x51550043,0x320236a8,0x76590298}},	//   dará_, нтру, raky_, _inwy,
   {{0x9f580443,0x20030054,0x320200d5,0x7649246a}},	//   tarà_, gaji_, saky_, ldey,
   {{0x4aad009a,0xa3c900c4,0x69db0069,0x752936a9}},	//   टकाव, लेश_, _ogue, ltez,
   {{0x9f5836aa,0x764936ab,0x00000000,0x00000000}},	//   gará_, ndey, --, --,
   {{0x752936ac,0xfbd200fd,0xe8df0019,0xdb0e00b8}},	// [2d80] ntez, چتا_, _trộn_, _vybí,
   {{0x7e7d36ad,0x69db1e60,0xfbd2250f,0x20030121}},	//   _elsp, _ague, نتا_, caji_,
   {{0x9f5821a4,0xaec636ae,0x6d4d36af,0x68fb0118}},	//   bará_, _обол, avaa, _awud,
   {{0x99dd024e,0x9f5836b0,0x290600c3,0x26de36b1}},	//   _daňo, cará_, tsoa_, _ruto_,
   {{0x644802c7,0x76491481,0x752936b2,0xa967052c}},	//   yddi, ddey, jtez, мица_,
   {{0xd6ea150d,0x2906043f,0x3ead008b,0x69db01d7}},	//   офил_, rsoa_, čete_, _egue,
   {{0x29060370,0x7bdc011e,0x786f0a8a,0x00000000}},	//   ssoa_, _igru, _røvt, --,
   {{0x20030657,0xc9560086,0x786f0a8a,0x00000000}},	//   zaji_, _отзы, _bøvs, --,
   {{0x69c036b3,0x6f1c36b4,0x200336b5,0x26de0118}},	//   _uzme, hurc, yaji_, _wuto_,
   {{0x26de01c0,0x9f582132,0x162000a1,0x64481e77}},	//   _tuto_, zará_, _यावर_, uddi,
   {{0xd62a0e8b,0x644836b6,0x200336b7,0x7d160c0b}},	//   _може_, rddi, vaji_, hrys,
   {{0x68e036b8,0x6f1c01ae,0x20030054,0x9f582314}},	//   _kumd, durc, waji_, xará_,
   {{0x20030657,0x9f580152,0x752936b9,0x629d1e2e}},	//   taji_, vará_, ctez, rnso,
   {{0x656f01ae,0xc058291f,0x7d1636ba,0x7bdc00d1}},	//   äche, міс_, drys, _ngru,
   {{0x9f582140,0x26c636bb,0xf41302b8,0xa29500d8}},	//   tará_, _khoo_, _ספק_, _пакі,
   {{0x7bdc0876,0x4ea407c1,0x7d1613dc,0x6d4d2b37}},	//   _agru, вруа, frys, tvaa,
   {{0x9f582132,0x20032f10,0xdd94021f,0xf1a4010b}},	// [2d90] rará_, paji_, ваты, _арэн,
   {{0x31560052,0x6d4d36bc,0x9f582132,0x60c50159}},	//   _ניתן_, rvaa, sará_, _uhhm,
   {{0x9f581fca,0x6f1c00af,0x224936bd,0x6d4d36be}},	//   pará_, curc, _kaak_, svaa,
   {{0x75290031,0x224900be,0x3a240160,0x6d4d02a2}},	//   ytez, _jaak_, _ccmp_, pvaa,
   {{0x224936bf,0x801809b9,0xf5480019,0xd90f0416}},	//   _maak_, _عزیز_, _nụ_, شیا_,
   {{0x22490051,0x7bdc0069,0x2b4301f7,0x00000000}},	//   _laak_, _ggru, _tsjc_, --,
   {{0x7afc001e,0x38c9006c,0x200100ab,0xcb690698}},	//   _gwrt, _ہائی_, _mehi_, _عمره_,
   {{0x26c636c0,0x06090f94,0x22492c55,0x752936c1}},	//   _choo_, чник_, _naak_, ttez,
   {{0xf5480028,0x2a7f0008,0x75290036,0x764936c2}},	//   _cụ_, _ilub_, utez, rdey,
   {{0x2a7f01a9,0xf54801a5,0x291d018e,0x336536c3}},	//   _hlub_, _dụ_, muwa_, евог,
   {{0xa3c90b4a,0x224936c4,0xe8d600a5,0x291d36c5}},	//   लें_, _baak_, _נוער_, luwa_,
   {{0xbbdc0953,0xe61001cb,0x25a00612,0x229203c9}},	//   _बल्क, _نشه_, _žile_, rško_,
   {{0x200101a3,0x787401f7,0x45220033,0x291d2206}},	//   _behi_, _sàvi, _বৈঠক_, nuwa_,
   {{0x6f1c36c6,0x03a505f2,0x2a6d36c7,0xd11c0581}},	//   turc, _пило, _loeb_, भूषण_,
   {{0xc7b20779,0x2baf2088,0x2a7f01c2,0x291d1047}},	//   ָבן_, _जुला, _olub_, huwa_,
   {{0x291d225e,0x9f5c2ea0,0x68330092,0x7d1636c8}},	//   kuwa_, _því_, lıdı, trys,
   {{0xafe62e50,0x291d002f,0xe3b80225,0xec7a02ee}},	// [2da0] _попл, juwa_, ngın_, ппа_,
   {{0x2a661bc5,0x64572cad,0x22490120,0xb21b01b4}},	//   wjob_, _óxid, _zaak_, nhæn,
   {{0x2a660024,0xddcd05e2,0x3ce50354,0x68e00069}},	//   tjob_, rkaš, _झूठे_, _sumd,
   {{0x09e636c9,0x2a7f36ca,0x394400e7,0xb90610b0}},	//   ходн, _club_, _psms_, ездк,
   {{0x291d36cb,0x2a662a86,0x3ea036cc,0xe2970070}},	//   guwa_, rjob_, mnit_, עכנט_,
   {{0x6d4636cd,0x3b0a1906,0x3ea036ce,0x7bdc36cf}},	//   _iska, _него_, lnit_, _ugru,
   {{0x61bd0026,0x3ea001f4,0x26c6006d,0xdca3034b}},	//   _ईर्ष, onit_, _phoo_, _сари,
   {{0x3ea036d0,0x291d2ed0,0x940500a8,0x26cd01ef}},	//   nnit_, buwa_, milə_, gmeo_,
   {{0x22490626,0x3ea036d1,0xb21b01cf,0x672a3315}},	//   _raak_, init_, fhæn, stfj,
   {{0xf54800e8,0x22490173,0x63860e8c,0x3ea036d2}},	//   _vụ_, _saak_, _néné, hnit_,
   {{0x7ae91b8d,0x26c636d3,0x224936d4,0xd76400f8}},	//   _četk, _thoo_, _paak_, _جنای,
   {{0x6d4636d5,0x09d40083,0xf5480019,0x7c3e36d6}},	//   _oska, _হ্যা, _tụ_, hepr,
   {{0x638602e1,0x22490a75,0x3ea00355,0x37d50033}},	//   _béné, _vaak_, dnit_, _স্পর,
   {{0x7c3e0532,0x660236d7,0x3ea00328,0x224903bc}},	//   jepr, _heok, enit_, _waak_,
   {{0x6d4636d8,0x9f3401e0,0xbfa8167d,0x224903c4}},	//   _aska, лері, етте_, _taak_,
   {{0x644a274d,0x20010118,0x6267234a,0x3ea036d9}},	//   _hafi, _wehi_, _سابق, gnit_,
   {{0xdb0e024e,0x61ed36da,0x64840284,0x6d4601ed}},	// [2db0] _rybá, _ifal, _còig, _cska,
   {{0x63861010,0x64840014,0xe81c0380,0x3ea036db}},	//   _géné, _dòig, _नागा_, anit_,
   {{0x6d4603cb,0xa3c20240,0x7f4500da,0x443e36dc}},	//   _eska, ्धि_, _ushq, iet_,
   {{0x443e36dd,0x644a36de,0x81ac00c8,0x291d36df}},	//   het_, _lafi, কেও_, tuwa_,
   {{0xd9451a56,0x61ed36e0,0x7c3e36e1,0x683305f9}},	//   тели, _mfal, bepr, yıdı,
   {{0x443e36e2,0xa3c236e3,0xe73927e9,0x291d36e4}},	//   jet_, ्धा_, дек_, ruwa_,
   {{0x443e0304,0x291d36e5,0x94240095,0x61ed00e9}},	//   det_, suwa_, _ötən_, _ofal,
   {{0x81ac0083,0x443e00c3,0x2f5c0070,0x291d067f}},	//   কেট_, eet_, לדונ, puwa_,
   {{0x443e36e6,0x644a0232,0x26cd36e7,0x999f023a}},	//   fet_, _bafi, rmeo_, _fauš_,
   {{0x443e0c66,0x3ea036e8,0x9b44006c,0x61ed36e9}},	//   get_, znit_, _جنہو, _afal,
   {{0x03a521be,0x644a36ea,0x53a536eb,0x70270033}},	//   тино, _dafi, танб, য়াজ_,
   {{0x7c3e004e,0x6833037a,0x638600f7,0xe1ff008d}},	//   zepr, sıdı, _séné, sjón_,
   {{0x443e36ec,0x638600f7,0x64840284,0x3ea00355}},	//   bet_, _péné, _bòid, vnit_,
   {{0x61ed0297,0x764b006c,0x66020009,0x644a04fb}},	//   _efal, _hagy, _zeok, _gafi,
   {{0xdee636ed,0x7c3e36ee,0x6386000d,0x3ea036ef}},	//   тоби, vepr, _véné, tnit_,
   {{0x940500a8,0x3ea00c6f,0x99dd007e,0x00000000}},	//   vilə_, unit_, _daňk, --,
   {{0x764b00f5,0x7c3e36f0,0x3ea036f1,0x644a276d}},	// [2dc0] _magy, tepr, rnit_, _yafi,
   {{0x3ea036f2,0x711b02b5,0x94050095,0x764b067f}},	//   snit_, _קויפ, tilə_, _lagy,
   {{0x290d0012,0x7c3e36f3,0x6d46004e,0x09ca0afa}},	//   _avea_, repr, _wska, िध्य,
   {{0x443e36f4,0x764b00f5,0x7c3e36f5,0x442700a2}},	//   zet_, _nagy, sepr, _lcn_,
   {{0x443e36f6,0x94050095,0x6d4636f7,0x442700e5}},	//   yet_, silə_, _uska, _ocn_,
   {{0x443e36f8,0x68ed0a39,0x660236f9,0x3cfb0354}},	//   xet_, íada, _seok, _लौटे_,
   {{0x443e02df,0x644a36fa,0x764b36fb,0x37d50083}},	//   vet_, _rafi, _bagy, _স্বর,
   {{0x443e36fc,0x6e2436fd,0x44270443,0xddc60107}},	//   wet_, ngib, _acn_, _lakō,
   {{0x7ae901cc,0x48e602ce,0x442736fe,0x443e0b73}},	//   _četi, _розв, _bcn_, tet_,
   {{0x443e27b5,0xe8c700af,0x644a36ff,0x545300c3}},	//   uet_, _агул_, _qafi, авьт,
   {{0x443e3700,0x8c1b00c2,0x261b02cb,0x61ed033b}},	//   ret_, וויי, _याची_, _pfal,
   {{0x443e3701,0x92580086,0x644a002f,0x44273702}},	//   set_, вают_, _wafi, _ecn_,
   {{0x443e3703,0x644a3704,0x44273705,0x3e7501ff}},	//   pet_, _tafi, _fcn_, _mått_,
   {{0x8438004f,0x443e00da,0x7414006c,0x1c1e13a0}},	//   _أكثر_, qet_, _صوبا, _पागल_,
   {{0x61fb008e,0x6aa23706,0x764b030d,0x00000000}},	//   ðuls, knof, _yagy, --,
   {{0x2ebf2177,0x6e243707,0x61ed36e0,0x62863708}},	//   ्षेत, ggib, _ufal, chko,
   {{0x51871112,0x6aa2189a,0xfd74002d,0xa3c20ca1}},	// [2dd0] _шука, dnof, алтэ, ्धव_,
   {{0x04140083,0x673a3709,0xfdc300b4,0x00000000}},	//   ত্রী_, _optj, _शरीफ, --,
   {{0xc61a0033,0x76400421,0x2cb302d7,0xdfd10413}},	//   থ্যা_, kemy, roxd_, _ديد_,
   {{0xb21b01b4,0xdea100fd,0x6aa20298,0x00000000}},	//   skæf, _ایری, gnof, --,
   {{0x7640370a,0x66ea0035,0x0d6402fb,0x8d870fb4}},	//   demy, _ręka, _кърм, _рунд,
   {{0xb4ac000c,0xfaf31015,0x66d5010b,0x17c90369}},	//   कको_, _نثر_, _iški, нгли_,
   {{0x3e750533,0x442700de,0x764b370b,0x7d0d370c}},	//   _fått_, _rcn_, _pagy, lsas,
   {{0x7bc72c14,0x3e75370d,0x25a01e85,0x6aa20036}},	//   _izju, _gått_, _žila_, cnof,
   {{0x764b0332,0xdd1206d3,0x9555004f,0x39b80043}},	//   _vagy, _müşt, اخبا, _алтэ_,
   {{0x7c25370e,0x6e2413a6,0x764b030d,0x9f5102d7}},	//   nghr, zgib, _wagy, nazó_,
   {{0xe29a12da,0x7c250079,0x6d440067,0x229200f4}},	//   еан_, ighr, zwia, lški_,
   {{0x7d0d370f,0xad9b08c0,0x9555028c,0x23780185}},	//   ksas, _reún, _مختا, ørja_,
   {{0xd5bb01c8,0x9f583710,0x229202f6,0x6484009e}},	//   _ўсе_, mbré_, nški_, _dòib,
   {{0x628600da,0x20cf0024,0xd3780067,0xe7f8018d}},	//   shko, _bżiq_, być_, ुरया_,
   {{0xe81b009a,0xe29a17e3,0xa3c90f3d,0x44e93711}},	//   _नयना_, _пак_, लेख_, _hú_,
   {{0x64413712,0x539a011d,0x26dd0118,0x44e9008e}},	//   leli, _ריקו, _jiwo_, _kú_,
   {{0xa3e70992,0x44e9008a,0x7d0d0269,0x62843713}},	// [2de0] _भला_, _jú_, gsas, _ilio,
   {{0x64412de7,0x44253714,0x7640004e,0x629d0187}},	//   neli, ngl_, zemy, érov,
   {{0x44e9004f,0x66093715,0x61e93716,0x6441002d}},	//   _lú_, kaek, žele, ieli,
   {{0xa3ab3717,0x64413718,0x200a3719,0xaaba03c5}},	//   _कुछ_, heli, labi_, ردار_,
   {{0x44e9064b,0xd378004e,0x6284002f,0x9f4100cc}},	//   _nú_, zyć_, _mlio, _nghê_,
   {{0x6441371a,0x7ae901cc,0x200a0269,0x2242003c}},	//   jeli, _četv, nabi_, hekk_,
   {{0x64410b0f,0xd6da0e8b,0x26dd02e9,0x764018f9}},	//   deli, нти_, _biwo_, temy,
   {{0x44e9371b,0x6441371c,0x60de00ec,0x151401af}},	//   _bú_, eeli, _lipm, адия,
   {{0x6441371d,0x49ca03fa,0x76400010,0x44e9371e}},	//   feli, _члан_, remy, _cú_,
   {{0x6441371f,0x6284000e,0x27f7000c,0x75203720}},	//   geli, _alio, čení_, rumz,
   {{0xd7ef004f,0x44e901ba,0x23ce00b4,0x00000000}},	//   _ركن_, _eú_, हेंद, --,
   {{0x8ccb0084,0x628400f1,0x75200054,0x7d0d3721}},	//   _तीनो, _clio, pumz, ysas,
   {{0x628401da,0xd3780067,0x00000000,0x00000000}},	//   _dlio, syć_, --, --,
   {{0x64413722,0x224d3723,0x62843724,0x200a3725}},	//   celi, žek_, _elio, gabi_,
   {{0x447b00c2,0xdfd51397,0x7d0d00d7,0x1ee700d1}},	//   _אנגע, ровы, wsas, اوری_,
   {{0x62843726,0x3ead3727,0x7d0d3728,0xe3131015}},	//   _glio, četo_, tsas, _ابوب,
   {{0xe2140ad9,0x200a3729,0xddc600c7,0xf1bf2e22}},	// [2df0] _طبيع, babi_, _pokš, rfás_,
   {{0x7d0d372a,0x320b0035,0xac770088,0x00000000}},	//   rsas, lacy_, دارش, --,
   {{0x62840086,0x9f510138,0x9f530a8a,0x7c250098}},	//   _ylio, razó_, _nexø_, rghr,
   {{0xa3c90fbf,0x7c250037,0xdb1c0031,0x639b0070}},	//   लेट_, sghr, _zyrë, עסאנ,
   {{0x4425001e,0x6441372b,0x66d5023a,0x7ae908b7}},	//   ygl_, yeli, _uški, _četu,
   {{0x07090413,0x7e6d007c,0x229218b0,0x26dd02d0}},	//   نيتي_, ljap, rški_, _siwo_,
   {{0x44e9372c,0xb5fd008b,0x26dd372d,0x00000000}},	//   _sú_, ljši, _piwo_, --,
   {{0x7f3c02b5,0x6441372e,0xb8eb0033,0xd8380107}},	//   געהו, weli, _রং_, _ebč_,
   {{0xc485192f,0xe8df0019,0x26c30029,0xa2c4112b}},	//   илик, _trốn_, ējo_, रतस्,
   {{0x99840082,0x7ae700da,0xa3c2022e,0x6284184f}},	//   _الكو, _kujt, ्धं_, _slio,
   {{0x6266372f,0x628403d0,0x200a3730,0x386a0176}},	//   авна, _plio, vabi_, _òbra_,
   {{0x44e90514,0xe29a35f7,0xc5d502ce,0x67233731}},	//   _tú_, там_, _кіль, munj,
   {{0x64413732,0x273100e8,0xa3c920d8,0x200a3733}},	//   peli, _hơn_, लेज_, tabi_,
   {{0xe3b000d1,0x69c9034d,0x00000000,0x00000000}},	//   _کره_, _mzee, --, --,
   {{0x67230f1a,0xb4c310aa,0x200a3734,0x6abb09d6}},	//   nunj, ्षी_, rabi_, _okuf,
   {{0x62840657,0x200a0269,0x320b024b,0x6aa90055}},	//   _ulio, sabi_, cacy_, _njef,
   {{0xb2bb0122,0x61e43735,0x614603e6,0xfde7141d}},	// [2e00] _במקר, _igil, _тепа, рдук_,
   {{0x6abb3736,0xf8a50647,0xc5d70033,0xf1bf3737}},	//   _akuf, _رک_, _সভাপ, ogán_,
   {{0x0b461747,0xa3c90099,0x6aa90044,0x7ae70207}},	//   рнен, लेच_, _bjef, _cujt,
   {{0x533600c2,0xb4c122d4,0x67230506,0xb4c30096}},	//   ינען_, ंतु_, dunj, ्षु_,
   {{0x656f01ae,0x68460009,0xe6da0093,0x3a260051}},	//   ächl, инда, ðsíð, rgop_,
   {{0x57f31c56,0x6abb030d,0x657b0159,0xfb2600d1}},	//   општ, _ekuf, dyuh, _پرسپ,
   {{0x273101a5,0x61e401ff,0x76aa0ce3,0xa7b83122}},	//   _cơn_, _ogil, ктив_, ылку_,
   {{0x66c5008a,0x61e400d1,0xfaa62c6a,0x2baf00c0}},	//   sókn, _ngil, _табо, _जुटा,
   {{0x320b3738,0x3e7c07c0,0x54b80382,0x661d05ee}},	//   vacy_, _cíti_, лгия_, óska,
   {{0x67230254,0x78ba005f,0x3d191604,0x7e6d0207}},	//   bunj, _uktv, _पिसे_, zjap,
   {{0x94730514,0x7ae03739,0x00000000,0x00000000}},	//   تديا, _kimt, --, --,
   {{0x48fd000c,0x9f61000d,0x7ae0009f,0x00000000}},	//   रीको_, _épée_, _jimt, --,
   {{0xe29801c8,0x64a63296,0x320b373a,0xe69302fd}},	//   раў_, _када, racy_, _بلند,
   {{0x61e40b92,0x69c00298,0x653b0317,0x7ae0093a}},	//   _egil, _myme, _סעוד, _limt,
   {{0xcebb03fa,0xa3b70416,0x69c00051,0xddc60035}},	//   вља_, _پاور_, _lyme, _nakł,
   {{0xdc0f0761,0x33db00a5,0x70270033,0x7ae0373b}},	//   ाण्ड_, _בחוד, য়েও_, _nimt,
   {{0x629d373c,0xe1ff2f21,0x7e6d02e2,0x0e08002d}},	// [2e10] miso, mbó_, rjap, рэси_,
   {{0x629d0119,0xfd4d0028,0x6abb0c71,0x91bc0122}},	//   liso, _khoả, _skuf, _במחי,
   {{0x69c00815,0x7ae0021d,0xbfab0043,0x00000000}},	//   _ayme, _bimt, _штие_, --,
   {{0x67232f59,0x69c0053e,0x9f4100e2,0x6d4b008d}},	//   vunj, _byme, _nghé_, ægas,
   {{0x27310028,0x69c0001e,0xc8790139,0x00000000}},	//   _sơn_, _cyme, _huşi_, --,
   {{0x672326fb,0x6c85004f,0x6d9e0069,0x00000000}},	//   tunj, _السم, _dħaħ, --,
   {{0x629d14d5,0x3e7c0355,0x7ae0373d,0x00000000}},	//   kiso, _síti_, _fimt, --,
   {{0xe518018d,0x9aa500bf,0x7ae000d8,0x6abb034d}},	//   _दिशि_, _امرو, _gimt, _ukuf,
   {{0x1fd4051d,0xddc6004e,0x69c0001e,0x787d0176}},	//   _दण्ड, _zakł, _gyme, _lèvi,
   {{0xd8740082,0x67230a78,0xb4c304eb,0x61e4373e}},	//   _والب, punj, ्षे_, _sgil,
   {{0xdb1c0248,0x7ae0006d,0x657b373f,0xf1d009b1}},	//   _pyré, _yimt, syuh, _सृजन,
   {{0x629d3740,0xeb3a0070,0x00000000,0x00000000}},	//   giso, נערש, --, --,
   {{0x68e10909,0x940c00a8,0x00000000,0x00000000}},	//   _kild, hidə_, --, --,
   {{0x03790a86,0x23293741,0x68e90118,0x629d2386}},	//   _محبت_, _боки_, _mued, aiso,
   {{0x629d3742,0x1eaa0312,0x00000000,0x00000000}},	//   biso, هاري_, --, --,
   {{0x629d2dd3,0x681b00ea,0x1ea911c0,0x6e3b02d7}},	//   ciso, lādē, لاقي_, _ñubl,
   {{0x68e9012f,0x6ab9009e,0x7ae0010b,0x64840284}},	// [2e20] _nued, dowf, _rimt, _mòin,
   {{0x7ae93743,0x7ae03744,0x22920009,0xcb6a03fa}},	//   _četr, _simt, ršku_, лазе_,
   {{0x6f63002d,0x6d4b003e,0x00000000,0x00000000}},	//   _евэз, ægar, --, --,
   {{0x68e9008c,0x7f3b02b5,0x69c000de,0x68e100e9}},	//   _bued, _געטו, _pyme, _aild,
   {{0x68e10185,0x7ae0006d,0x391300d4,0x9f5a0282}},	//   _bild, _vimt, змір, _depå_,
   {{0xb4c30433,0x69c00237,0x629d18f9,0xbcfb0093}},	//   ्षो_, _vyme, ziso, _bréf,
   {{0xd6d0211f,0x394d0391,0xbb86004f,0x78b807e5}},	//   وقت_, _eses_, _الأي, rovv,
   {{0xdd080038,0x5678186f,0x44f407be,0x629d3745}},	//   _môže, рбия_, опис, xiso,
   {{0x68e93746,0x68e109e1,0xc9aa00d8,0x6484009e}},	//   _gued, _fild, _свае_, _dòin,
   {{0x68e1008a,0x04662c51,0x629d016e,0x44fb02d7}},	//   _gild, стим, wiso, _dª_,
   {{0x629d3747,0x291901bc,0x00000000,0x00000000}},	//   tiso, _åsar_, --, --,
   {{0x68e10183,0x25a900cd,0xc8790395,0x00000000}},	//   _zild, _žale_, _ruşi_, --,
   {{0x629d3748,0x787d0c1f,0x68e10225,0xe1ff3749}},	//   riso, _sèvi, _yild, rbó_,
   {{0x68e101ef,0x629d374a,0xfd4d0019,0xc8790395}},	//   _xild, siso, _thoả, _puşi_,
   {{0x629d1834,0x66d500c7,0xe7f00067,0xe43700a5}},	//   piso, _iškr, _चलना_, _הרוח_,
   {{0x2a6400d7,0x443c09b3,0x9df91b50,0x7c2e0183}},	//   _nnmb_, _hbv_, рнат_, _acbr,
   {{0xe29f00fb,0x5c7505c7,0x66f100ec,0xa3c202d1}},	// [2e30] mið_, олат, _māka, ्धक_,
   {{0xe29f00fb,0x68e9374b,0x6ad10026,0xa3cf0864}},	//   lið_, _rued, तग्र, _शरम_,
   {{0xe80c0084,0x68e9374c,0xda7b1112,0x7bda0187}},	//   _सज़ा_, _sued, ляд_, _útul,
   {{0x68e90b52,0xe29f008a,0x66f10080,0x68e1374d}},	//   _pued, nið_, _nāka, _sild,
   {{0x68e9374e,0x68e1374f,0x3ea93750,0xa96913f9}},	//   _qued, _pild, mnat_, рила_,
   {{0xbcfb02e1,0x46f50150,0x68e11505,0xaf3401cb}},	//   _préf, очит, _qild, _بریت,
   {{0xe29f064b,0x68e13751,0x3ea93752,0xf77121a0}},	//   kið_, _vild, onat_, ظات_,
   {{0x3ea93753,0xb4c30066,0x68e13754,0xa3bc0066}},	//   nnat_, ्ष्_, _wild, _आड़_,
   {{0x68e10c61,0xe29f008a,0x94250395,0x394d00a5}},	//   _tild, dið_, омпе, _uses_,
   {{0x3ea93755,0x6d5d2d00,0xada300d5,0xa4d60200}},	//   hnat_, _mrsa, moúč, одњу_,
   {{0xe29f00fb,0x37ab3756,0x3ea93757,0x443c0345}},	//   fið_, _стан_, knat_, _dbv_,
   {{0x6d4f3758,0xe29f00fb,0x6d5d3759,0x442e0526}},	//   _osca, gið_, _orsa, _ecf_,
   {{0xa50907be,0x3ea901c0,0xbbc60e62,0x2056218b}},	//   _тела_, dnat_, _वर्क, отвр,
   {{0x39400095,0x00000000,0x00000000,0x00000000}},	//   çisi_, --, --, --,
   {{0x6d5d375a,0xafe30210,0x935800af,0xe3d70033}},	//   _arsa, дорл, _грыу_, _দ্রব,
   {{0x3ea9375b,0xd5f90070,0xbddb0107,0x00000000}},	//   gnat_, שפּר, _obèd, --,
   {{0x660b0332,0x3ce30120,0x648d0037,0x6d5d009e}},	// [2e40] _megk, _bijv_, _cúig, _crsa,
   {{0x85210b4a,0x3ea922be,0x660b375c,0xa7fc033e}},	//   _मिनट_, anat_, _legk, _anın,
   {{0x6d5d375d,0x6d4f375e,0xbddb23e2,0x3ea90159}},	//   _ersa, _esca, _abèd, bnat_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcfb375f,0x1958081b,0x3ea03760,0x82d70070}},	//   _créd, салы_, miit_, קונג_,
   {{0x3ea03761,0xd838025c,0xb4b30461,0x66f100ea}},	//   liit_, _omče_, झको_, _sāka,
   {{0xbcfb3762,0x443c0051,0x8cb904cc,0x00000000}},	//   _prég, _rbv_, ्तरो, --,
   {{0x3ea03763,0x7bce273a,0xbcfb00f7,0x9f58283e}},	//   niit_, _izbu, _fréd, laró_,
   {{0xe29f008d,0x442e00a2,0x2d800cdf,0x6484009e}},	//   við_, _pcf_, nyie_, _fòil,
   {{0x3ea91592,0x3ead15d7,0x7a400093,0xf7463379}},	//   znat_, četi_, _fátæ, _мезо,
   {{0xe29f064b,0xa3cf2516,0xbcfb216e,0x442e2348}},	//   tið_, _शरण_, _trég, _vcf_,
   {{0x442e0024,0x81af0083,0x00000000,0x00000000}},	//   _wcf_, _করব_, --, --,
   {{0xe29f064b,0x3ea900b8,0x3ea03764,0x443c0051}},	//   rið_, vnat_, diit_, _tbv_,
   {{0xe29f008a,0xf8ca0461,0x66d500d5,0xddcf0160}},	//   sið_, ितिय, _uškr, _locţ,
   {{0x3f850076,0xc05802ce,0x4fc40ed2,0xe29f0093}},	//   álu_, ція_, дста, pið_,
   {{0x64483765,0x3ea008dd,0xe298015a,0x442c3766}},	//   ledi, giit_, _мај_, lgd_,
   {{0x3ea93767,0x7bce3768,0x3f851587,0xf8ca0067}},	// [2e50] rnat_, _azbu, šlu_, िताय,
   {{0x64483769,0x442c237a,0x3e7c05ee,0x6d5d0124}},	//   nedi, ngd_, _sítt_, _vrsa,
   {{0x442c01e4,0x3ea9376a,0xa8010138,0x00000000}},	//   igd_, pnat_, _íñig, --,
   {{0x2011376b,0xbcfb376c,0x6448376d,0x6d5d022f}},	//   lazi_, _préd, hedi, _trsa,
   {{0x6d4f376e,0x6448376f,0x6d5d3770,0x6f153771}},	//   _usca, kedi, _ursa, lszc,
   {{0x64480537,0xbcfb02e1,0x20113772,0x1fdf0033}},	//   jedi, _crée, nazi_, _ব্যস,
   {{0x64483773,0x6d4d3774,0x3e7c05ee,0xf7730ae7}},	//   dedi, lwaa, _títt_, باش_,
   {{0x6e2d3775,0x20113776,0xbcfb0079,0x442c02a2}},	//   ngab, hazi_, _tréd, egd_,
   {{0x201118a6,0x6d4d3777,0x64483778,0x64a5338e}},	//   kazi_, nwaa, fedi, запа,
   {{0xa3cf3779,0x68fb011e,0x660b237e,0x2011377a}},	//   _शरद_, _itud, _wegk, jazi_,
   {{0x6d4d0069,0xe7f00461,0x395f0118,0x660b0118}},	//   hwaa, _चलता_, _hrus_, _tegk,
   {{0x6d4d377b,0x442c0a75,0x395f377c,0xbddb0118}},	//   kwaa, agd_, _krus_, _mbèb,
   {{0x7649030d,0x6448377d,0x3ea000b9,0x6f150035}},	//   meey, bedi, viit_, eszc,
   {{0x6448377e,0x7649073a,0x201101a8,0x6d4d377f}},	//   cedi, leey, gazi_, dwaa,
   {{0x6e2d02c9,0x3ea03780,0x66f100ea,0x3a3f02a7}},	//   fgab, tiit_, _māko, _obup_,
   {{0x7649001c,0x628f3781,0x6d4d1e7e,0x88d10033}},	//   neey, chco, fwaa, াদিক,
   {{0x20113782,0x9f580443,0x3ea03783,0x395f006d}},	// [2e60] bazi_, taró_, riit_, _nrus_,
   {{0x31370052,0x66f10029,0x3ea03784,0x62863785}},	//   _צריך_, _nāko, siit_, lkko,
   {{0x7649030d,0x307b0122,0x395f124f,0x68fb018e}},	//   keey, _האינ, _arus_, _atud,
   {{0x31603786,0x395f3787,0x66c5008d,0x7bce3788}},	//   _kriz_, _brus_, bóki, _vzbu,
   {{0x7649073a,0x442c3789,0x9f580453,0x67230009}},	//   deey, ygd_, paró_, ernj,
   {{0x644801dd,0x648d0098,0x75290065,0x00000000}},	//   xedi, _lúib, duez, --,
   {{0x7bce378a,0x68fb378b,0xa737004f,0xbb431b2e}},	//   _uzbu, _etud, كثير_, _перк,
   {{0xd90d0a86,0x2011000e,0x7649030d,0x6448001e}},	//   _چین_, zazi_, geey, wedi,
   {{0x64480723,0xd90d0594,0x7d16378c,0x75290065}},	//   tedi, _نین_, nsys, guez,
   {{0x6aa20054,0x6f150035,0x67230ce9,0x648401da}},	//   liof, yszc, brnj, _tòim,
   {{0x7649001c,0x6448378d,0x442c0120,0x20110054}},	//   beey, redi, rgd_, vazi_,
   {{0x2011378e,0xa25b0248,0x31600107,0x7d162f44}},	//   wazi_, plôm, _briz_, ksys,
   {{0x6448378f,0x7aee01e8,0x20113790,0xd62701e0}},	//   pedi, _lubt, tazi_, _хоче_,
   {{0x7d160cd9,0x62860051,0xe4d700f8,0xe5210355}},	//   dsys, akko, _فونت_, _मिति_,
   {{0x20113791,0x643b0122,0x543b0070,0x31600065}},	//   razi_, _העונ, _לעגא, _eriz_,
   {{0x8c090033,0x6d4d3792,0x59dc00b4,0x2011010a}},	//   _লাইন_, twaa, यधार, sazi_,
   {{0x6e2d3793,0x7d162357,0x20113794,0x6d4d0159}},	// [2e70] rgab, gsys, pazi_, uwaa,
   {{0x6d4d06ba,0x6e2d3795,0x787d00f7,0x224b0bf7}},	//   rwaa, sgab, _lèvr, leck_,
   {{0x81af00c8,0x6d4d3796,0x7649001c,0x628d0124}},	//   _করি_, swaa, yeey, _klao,
   {{0x225902df,0x7aee12c3,0x66f10029,0xfbd0004f}},	//   ndsk_, _dubt, _sāko, اتك_,
   {{0x6d4d046a,0x81df0083,0x2d4d00cd,0x224b02b1}},	//   qwaa, দুর_, _uže_, ieck_,
   {{0x81af0b52,0x7649001c,0x224b3797,0xccf200a5}},	//   _করা_, weey, heck_, _בכך_,
   {{0xe73917c7,0x7649073a,0x6aa200d5,0x44f2099e}},	//   цей_, teey, biof, _aâ_,
   {{0x61e90496,0xbcfb01ba,0x395f00d1,0x65640009}},	//   želj, _gréc, _trus_, _šiha,
   {{0xb3450370,0x395f3798,0x3944028b,0x09db0033}},	//   _opçã, _urus_, _gpms_, _ড্রা,
   {{0x7649073a,0x212b0187,0xdeff003c,0x628d3799}},	//   seey, duch_, ċċju_, _alao,
   {{0xdc380070,0x78a3379a,0x628d026e,0xa267004b}},	//   לאזט_, minv, _blao, _dėžę_,
   {{0x3160379b,0x628d184f,0x78a3379c,0xd29a01e0}},	//   _priz_, _clao, linv, ітні_,
   {{0x752904a5,0x628603ad,0x00000000,0x00000000}},	//   quez, rkko, --, --,
   {{0x62860006,0x92ae0083,0x78a316c9,0x648d0079}},	//   skko, কতে_, ninv, _dúic,
   {{0x1fb5379d,0x81df0083,0x224b379e,0x9f58003e}},	//   естр, দুল_, beck_, garð_,
   {{0x212b02c9,0xee3a01c8,0x628d184f,0xad9b0097}},	//   buch_, ўна_, _glao, _neús,
   {{0x6da30043,0x7afc023a,0x7aee11f0,0x78a3008c}},	// [2e80] вита, _strt, _subt, kinv,
   {{0x7aee006d,0x79820054,0x00000000,0x00000000}},	//   _pubt, vyow, --, --,
   {{0xbcfb1010,0x00000000,0x00000000,0x00000000}},	//   _préc, --, --, --,
   {{0x8b65004f,0x1e83379f,0x49ca15e1,0x00000000}},	//   عالم, _алюм, олен_, --,
   {{0x6aa237a0,0xd91000d1,0xb86500fd,0x7bc7008d}},	//   riof, ایط_, کانو, _eyju,
   {{0x7aee37a1,0x787d000d,0x6aa2254a,0xec1600fd}},	//   _tubt, _sèvr, siof, _زورد,
   {{0xfaa602ee,0x44f237a2,0x6f1a0098,0x00000000}},	//   _жаво, _sâ_, átch, --,
   {{0x7c3e0345,0xdb0e0035,0xdced0225,0x00000000}},	//   lfpr, _wybó, nyağ, --,
   {{0xfaa337a3,0xfbb00033,0xd44a0210,0x00000000}},	//   _рато, _করিত, оянд_, --,
   {{0x337403d6,0xb86637a4,0x224b0110,0x628d0284}},	//   егор, _تارو, weck_, _slao,
   {{0xe8ca00a1,0xd25101b2,0x628d37a5,0x224b0110}},	//   ितीच, هند_, _plao, teck_,
   {{0x68e800a5,0x6d4608c8,0x212b02b1,0x6d1e00b4}},	//   _hidd, _opka, tuch_, _पिंग_,
   {{0x68e837a6,0x224b191b,0x656f01ae,0xbcfb00a2}},	//   _kidd, reck_, ächt, _oréa,
   {{0x557700c2,0x68e804f0,0x212b37a7,0x3dcd003c}},	//   _קעגן_, _jidd, ruch_, _ġew_,
   {{0x68e82dee,0x212b01ae,0x6d462686,0x9f3403d0}},	//   _midd, such_, _apka, кері,
   {{0x68e8030d,0x645837a8,0x443e37a9,0x7ce90009}},	//   _lidd, _havi, lft_, _ažra,
   {{0x645837aa,0x7bca01ae,0xbcfb0037,0x61ed37ab}},	// [2e90] _kavi, üfun, _bréa, _igal,
   {{0xbcfb02e1,0x645837ac,0x443e02c9,0x68e82c9f}},	//   _créa, _javi, nft_, _nidd,
   {{0x645837ad,0x443e3695,0xbcfb0037,0x78a300c3}},	//   _mavi, ift_, _dréa, vinv,
   {{0x6458142f,0x69dd0187,0x656201b7,0x68e8013b}},	//   _lavi, _úsek, _oroh, _aidd,
   {{0xdb1c053d,0x78a337ae,0x61ed37af,0xbcfb0098}},	//   _vyrá, tinv, _mgal, _fréa,
   {{0xbcfb0082,0x68e80463,0x443e0a75,0x225e0029}},	//   _gréa, _cidd, jft_, ētki_,
   {{0x68e831ae,0x656232a3,0xf09402b8,0x61ed030d}},	//   _didd, _aroh, כנס_, _ogal,
   {{0x61ed37b0,0x443e0a75,0x68e8001e,0x64582933}},	//   _ngal, eft_, _eidd, _aavi,
   {{0x443e37b1,0x6458011c,0x7e7d0031,0xd8380260}},	//   fft_, _bavi, _mosp, _imčn_,
   {{0xe1fa04aa,0x645837b2,0x61ed37b3,0x68e837b4}},	//   ूर्ण_, _cavi, _agal, _gidd,
   {{0x645837b5,0x7ae9010b,0x53c900d4,0x69c90118}},	//   _davi, _kiet, ягом_, _hyee,
   {{0x60c524a1,0x7e7d37b6,0x443e0051,0x68e837b7}},	//   _akhm, _nosp, aft_, _zidd,
   {{0x7ae9114b,0x81e80033,0x00000000,0x00000000}},	//   _miet, মুন_, --, --,
   {{0x7ae937b8,0x61ed37b9,0x6d46022e,0x3439016b}},	//   _liet, _egal, _rpka, _זײַע,
   {{0xb4cb004e,0xf8b200a5,0x64430024,0x3f670812}},	//   लती_, אשם_, _ibni, ниро_,
   {{0x645811d7,0x7ae937ba,0x139a0122,0xf7720317}},	//   _zavi, _niet, _מבצע, נקן_,
   {{0x7e7d0097,0x69c90189,0xbcfb37bb,0x753b37bc}},	// [2ea0] _dosp, _nyee, _préa, ntuz,
   {{0x645837bd,0xe0d22087,0x6ab8045c,0x61ed0160}},	//   _xavi, _حزب_, इक्र, _zgal,
   {{0x7ae937be,0x69c9317e,0xa09b02b5,0xcb0901e0}},	//   _biet, _ayee, _זייט, дхід_,
   {{0x68e8054e,0xc3320122,0x7e7d37bf,0x7ae90029}},	//   _sidd, רוא_, _gosp, _ciet,
   {{0xe947006c,0x64430035,0x68e80523,0xbcfb0079}},	//   ٹرنی, _obni, _pidd, _tréa,
   {{0x7ae90b88,0x64430024,0x00000000,0x00000000}},	//   _eiet, _nbni, --, --,
   {{0x645837c0,0x7ae91e1e,0x7d0437c1,0x68e80527}},	//   _ravi, _fiet, lpis, _vidd,
   {{0x64582831,0xddcd02cc,0xd6d70733,0x61e937c2}},	//   _savi, ljaš, нты_, želi,
   {{0x1fdd37c3,0xe4a60dba,0xa90a00ad,0x68e8003c}},	//   _मण्ड, ерно, _ريال_, _tidd,
   {{0xd91b0052,0xddcd37c4,0x02c90ed1,0x443e01ae}},	//   _מומל, njaš, रत्न, uft_,
   {{0x443e37c5,0x64580200,0x645a079a,0x22950945}},	//   rft_, _vavi, rdti, виня,
   {{0x0cbe1cce,0x273a01f4,0x645837c6,0x656237c7}},	//   ्तुम, mën_, _wavi, _troh,
   {{0x273a00da,0x1a9b02b5,0xd25100bf,0x69c90221}},	//   lën_, ליטע, هنگ_, _xyee,
   {{0x7e7d0cc9,0xbcfb0107,0x21240037,0xe73100b5}},	//   _sosp, _brén, ámha_, _حصے_,
   {{0xd90400f5,0x7e7d1980,0x273a00da,0x6e670b00}},	//   _گی_, _posp, nën_, нтаж,
   {{0x61ed37c8,0x41de1b8f,0x00000000,0x00000000}},	//   _ugal, नेहस, --, --,
   {{0xd9041aa6,0x7ae937c9,0x273a00da,0x648d004f}},	// [2eb0] _دی_, _riet, hën_, _múin,
   {{0x7ae937ca,0x273a00da,0xe80201c0,0x387e37cb}},	//   _siet, kën_, रुमा_, _notr_,
   {{0x7ae937cc,0x273a01f4,0xb09c0070,0x69c90159}},	//   _piet, jën_, _מיזר, _syee,
   {{0xed5100f5,0x273a01f4,0x25a900d5,0x7d040176}},	//   _پھر_, dën_, _žalm_, bpis,
   {{0x7ae937cd,0xe8f80402,0x273a0120,0xddcd011c}},	//   _viet, елі_, eën_, bjaš,
   {{0x07a51362,0x26c60118,0x7ae937ce,0x273a0055}},	//   калн, _akoo_, _wiet, fën_,
   {{0x7ae937cf,0x273a01f4,0x648d008a,0x6b83013c}},	//   _tiet, gën_, _búin, ängd,
   {{0xdddd0080,0x386c0009,0xd90c006c,0xf1bf37d0}},	//   _nosū, _endr_, _کیو_, ngás_,
   {{0x648d004f,0xa2c50355,0x387e02a7,0x00000000}},	//   _dúin, रवन्, _fotr_, --,
   {{0xb4cb0fd1,0x76590298,0x273a0055,0x00000000}},	//   लते_, _wawy, bën_, --,
   {{0x7d0437d1,0x753b29e7,0x273a01f4,0x648d0079}},	//   zpis, stuz, cën_, _fúin,
   {{0xddcd011c,0x7d0437d2,0x753b0065,0x00000000}},	//   zjaš, ypis, ptuz, --,
   {{0xe29737d3,0x660937d4,0x00000000,0x00000000}},	//   тая_, mbek, --, --,
   {{0x910337d5,0xbcfb37d6,0x934537d7,0x26cd0138}},	//   рпре, _prén, _анке, lleo_,
   {{0xc05900d8,0x3f8c0187,0x64411e2e,0x00000000}},	//   хіў_, ádu_, mfli, --,
   {{0x7d0401cc,0xe3e802b5,0xbcfb30e9,0x2eeb0107}},	//   tpis, _אַפֿ, _créo, _cicf_,
   {{0x7bd502fb,0xdee337d8,0x273a01f4,0xe81400dc}},	// [2ec0] _azzu, роти, zën_, डरमा_,
   {{0x0cbe0953,0x7d04005d,0xbcfb2eef,0x2a6d0314}},	//   ्तेम, rpis, _trén, _aneb_,
   {{0x660903fa,0x91f620d8,0x26cd37d9,0x386c0097}},	//   kbek, _इलाज_, kleo_, _rndr_,
   {{0x273a00da,0x7d0437da,0xca75010b,0xd7f1055c}},	//   vën_, ppis, лучы, _bão_,
   {{0xdb0e01ff,0x660936a2,0x2a7f0359,0xc02f00e2}},	//   _nybö, dbek, _doub_, _điếu_,
   {{0x273a01d2,0xfc030072,0xd90d064e,0xb4cb0099}},	//   tën_, _впро, سیم_, लतो_,
   {{0xdca30439,0xddc402f6,0xd6da0dec,0x7529018e}},	//   _тари, njiž, мти_, erez,
   {{0x201837db,0x273a01d2,0x6b8308f9,0x3eb20086}},	//   hari_, rën_, änge, nnyt_,
   {{0x644137dc,0x273a00da,0xd9460202,0xa3e437dd}},	//   ffli, sën_, _јези, पेन_,
   {{0x201806b3,0x273a01f4,0x29061ec8,0x3eb20086}},	//   jari_, pën_, mpoa_, hnyt_,
   {{0x75290382,0xbddb0118,0x273a0031,0x5334010b}},	//   arez, _abèl, qën_, ыент,
   {{0xe5c60044,0x05730088,0x26cd2cad,0x201337de}},	//   _исло, _چاود, cleo_, _sexi_,
   {{0x26c437df,0x75290fdd,0x20180f93,0x05730088}},	//   momo_, crez, fari_, _ناود,
   {{0x201837e0,0x4ec40083,0x64a31294,0xf36637e1}},	//   gari_, ্দোল, _кача, _атин,
   {{0xbcfb00f7,0x78ad000d,0x14b13010,0x00000000}},	//   _préo, éavi, ीकरण, --,
   {{0xe8021b8f,0xceb80200,0x00000000,0x00000000}},	//   रुता_, вљу_, --, --,
   {{0x201819c6,0x3219189a,0x00000000,0x00000000}},	// [2ed0] bari_, masy_, --, --,
   {{0x32190e7d,0x26c40fc2,0x00000000,0x00000000}},	//   lasy_, homo_, --, --,
   {{0x26c437e2,0x00000000,0x00000000,0x00000000}},	//   komo_, --, --, --,
   {{0x3e0402fb,0x321907df,0x00000000,0x00000000}},	//   _вярв, nasy_, --, --,
   {{0x3ea937e3,0xbcfb1d85,0x26c437e4,0xf990004f}},	//   miat_, _krém, domo_, يبه_,
   {{0x3ea937e5,0x752937e6,0x475937e7,0x2bdb37e8}},	//   liat_, vrez, ерия_, _भरपा,
   {{0xb6a50a26,0x660937e9,0x2bc837ea,0x46a502fb}},	//   ликл, tbek, _ауто_, лакв,
   {{0x201837eb,0x752937ec,0x3ea937ed,0xcc14006c}},	//   zari_, trez, niat_, _مذہب,
   {{0x201837ee,0xd41526cb,0x59b70299,0x66091cc6}},	//   yari_, льны, _आखिर, rbek,
   {{0x130903ad,0x752937ef,0x201837f0,0x00000000}},	//   нной_, rrez, xari_, --,
   {{0x20180121,0x26cd0083,0x3eb203ad,0x644137f1}},	//   vari_, pleo_, ynyt_, rfli,
   {{0x32190118,0x201837f2,0x26c41e19,0xbcfb00f7}},	//   gasy_, wari_, como_, _prél,
   {{0x3ea937f3,0xe56e03fa,0x291d37f4,0x6441033b}},	//   diat_, _уз_, nswa_, pfli,
   {{0x03190082,0x50b50fa7,0x291f0054,0xbcfb000d}},	//   _كتبت_, ассу, _mvua_, _crém,
   {{0x201837f5,0x3ea937f6,0x7f19005f,0x00000000}},	//   rari_, fiat_, кіту_, --,
   {{0xe3b00413,0xbea30009,0x00000000,0x00000000}},	//   _بره_, баск, --, --,
   {{0xcbb00b52,0x201837f7,0x8d663122,0xa3e7111a}},	// [2ee0] _করেছ, pari_, ывае, _मृत_,
   {{0x201801e9,0x0dc709eb,0x7af501a3,0x26c408c7}},	//   qari_, улуй_, _buzt, zomo_,
   {{0xbea637f8,0x3ea937f9,0x26c40054,0x1bba0037}},	//   _банк, biat_, yomo_, رائع_,
   {{0x3ea937fa,0x648d0037,0x7b200187,0x00000000}},	//   ciat_, _súil, _náuš, --,
   {{0xa9670948,0x19580bbc,0x22920355,0x648401da}},	//   лица_, талы_, ušky_, _mòir,
   {{0x62960031,0xa3e400b4,0x32190067,0xbddb0107}},	//   ëzoj, पेड_, zasy_, _obèj,
   {{0x7af503cb,0x26c437fb,0x00000000,0x00000000}},	//   _guzt, tomo_, --, --,
   {{0x212001cc,0x7f3b02b5,0x212b001e,0x00000000}},	//   _ovih_, געקו, yrch_, --,
   {{0x948600af,0xa836006c,0x26c4321b,0x7ae237fc}},	//   гынд, _معاش, romo_, mmot,
   {{0xb993004f,0x26c43182,0x212b0187,0xb80a0037}},	//   _الكب, somo_, vrch_, _أيام_,
   {{0x32190375,0x61ea00a8,0x648400f1,0x9646005f}},	//   tasy_, əllə, _sòis, _бэлд,
   {{0x7bce03bc,0x64840284,0x925800c3,0x6b810176}},	//   _mybu, _còir, гают_, _àlge,
   {{0x32190e7d,0x3ea912c3,0xbcfb37fd,0x64840211}},	//   rasy_, viat_, _prém, _dòir,
   {{0x92b50083,0xc0581bda,0x859b0397,0xe3a400d1}},	//   ঝতে_, ліс_, _אשדו, _پشتی,
   {{0x321937fe,0xd36f083e,0x3ea9291b,0x7ae237ff}},	//   pasy_, _уч_, tiat_, kmot,
   {{0x5e5800d4,0x25a9040b,0x648401a6,0x00000000}},	//   лися_, _žali_, _tòis, --,
   {{0xbcfb00f6,0x7af501ed,0x69c603d0,0x00000000}},	// [2ef0] _trém, _suzt, _økeh, --,
   {{0xe1ff3800,0x7bce0a8c,0x7af501b7,0x00000000}},	//   lcó_, _bybu, _puzt, --,
   {{0x3ea93801,0x75eb006c,0x60c73802,0x29043803}},	//   piat_, _közü, mojm, _atma_,
   {{0x628f0051,0x291d04fb,0xe1ff1db8,0x4e790070}},	//   nkco, tswa_, ncó_, _סאָצ,
   {{0x22490703,0xc1d3021a,0x00000000,0x00000000}},	//   _mbak_, _सरोग, --, --,
   {{0x3169068f,0x60c701f4,0xf77112de,0x00000000}},	//   _mraz_, nojm, قاب_, --,
   {{0x96950f08,0x7ae21097,0xdd0e0225,0xddc6005f}},	//   ириш, bmot, _kışl, _inkš,
   {{0x31690755,0xada601ba,0x06850374,0xa5250432}},	//   _oraz_, slúž, ргин, амид,
   {{0x60c701f4,0xef190035,0x04190033,0x3a7427eb}},	//   kojm, ąży_, _দাবী_, _ултр,
   {{0x66f10080,0xbcfb00f7,0x60c70031,0xb4c10096}},	//   _sāku, _préj, jojm, ूते_,
   {{0xe29a2462,0x212001cc,0x798b001e,0x60c70031}},	//   ван_, _svih_, lygw, dojm,
   {{0x91e63804,0x31690183,0x6721023a,0x2001099e}},	//   ионе, _braz_, _ivlj, _afhi_,
   {{0x6f0502a8,0x7d090031,0xe8020355,0x75eb013b}},	//   _athc, _çesh, रुवा_, _dözü,
   {{0x661b342d,0x7ae200cd,0x60c70031,0x44fb021d}},	//   lauk, zmot, gojm, _iê_,
   {{0x44fb0626,0x7ae23805,0x237600d1,0x316901ed}},	//   _hê_, ymot, _نمود_, _eraz_,
   {{0x44fb01a5,0x661b3806,0x75eb037a,0x316902d0}},	//   _kê_, nauk, _gözü, _fraz_,
   {{0xb21b008c,0x394d0221,0x7bce00d7,0x31693807}},	// [2f00] rkæt, _npes_, _sybu, _graz_,
   {{0x44fb01a5,0x6e36001e,0x661b3808,0x00000000}},	//   _mê_, sgyb, hauk, --,
   {{0x44fb3809,0x66f10080,0xf1aa06bc,0x661b380a}},	//   _lê_, _māks, _चेतन, kauk,
   {{0x7bce0187,0x4fbb0d85,0x661b380b,0x6b8301ff}},	//   _vybu, _יציא, jauk, änga,
   {{0x672101f2,0x661b380c,0x7bce0035,0x44fb380d}},	//   _avlj, dauk, _wybu, _nê_,
   {{0x991500d8,0x628401a3,0x6aab009e,0x00000000}},	//   сьці, _loio, aigf, --,
   {{0xc1d3021a,0xe7e1007c,0x44fb0183,0x78aa380e}},	//   _सर्ग, गेला_, _aê_, rifv,
   {{0x44fb0019,0xe5c607be,0x628407e5,0x35462aca}},	//   _bê_, испо, _noio, ахов,
   {{0x44fb0183,0x00000000,0x00000000,0x00000000}},	//   _cê_, --, --, --,
   {{0x44fb380f,0x07a63810,0x75eb0463,0x629601a8}},	//   _dê_, _казн, _sözü, _alyo,
   {{0x31690355,0x62960282,0x00000000,0x00000000}},	//   _sraz_, _blyo, --, --,
   {{0x661b1c26,0x31693811,0x00000000,0x00000000}},	//   cauk, _praz_, --, --,
   {{0x60c701f4,0xe1ff3812,0x628f0051,0x660201ff}},	//   tojm, rcó_, rkco, _ifok,
   {{0xe1ff3813,0x6296030d,0x00000000,0x00000000}},	//   scó_, _elyo, --, --,
   {{0x443c0443,0xd4c5004f,0x60c73814,0x81e80083}},	//   _icv_, _اغني, rojm, মুল_,
   {{0x316903e6,0x60c701f4,0x629600ee,0x62843815}},	//   _traz_, sojm, _glyo, _goio,
   {{0x60c71793,0x44fb00e2,0x00000000,0x00000000}},	// [2f10] pojm, _xê_, --, --,
   {{0x70551c0c,0xcc7403fa,0x7d020079,0x00000000}},	//   _اندا, огућ, íosa, --,
   {{0x394d008d,0x443c0139,0x6a170037,0x00000000}},	//   _spes_, _mcv_, لبشر, --,
   {{0x7522012e,0x99d90037,0x443c00fe,0x3eb900ee}},	//   _ovoz, هواء_, _lcv_, _ujst_,
   {{0x661b3816,0x7afb00f4,0x00000000,0x00000000}},	//   vauk, _čutu, --, --,
   {{0x88c800d4,0x31580070,0x6d4f0176,0x44fb3817}},	//   алів_, יידן_, _ipca, _rê_,
   {{0xfbe50b52,0x44fb250a,0xbb85004f,0xab95004f}},	//   _প্রত, _sê_, _الزي, _الأغ,
   {{0xcfb800a5,0xbcfb3818,0x66f10228,0xd7f100cc}},	//   ילוי_, _préh, _sāks, _mãi_,
   {{0x661b3819,0x6aa90054,0x05680370,0xa3e4035d}},	//   rauk, _imef, ајќи_, पेस_,
   {{0x661b0080,0x44fb381a,0xbcfb0310,0x443c0183}},	//   sauk, _vê_, _créi, _ccv_,
   {{0x661b0086,0xbcfb0098,0xe6430644,0x6602009f}},	//   pauk, _dréi, şmış, _ffok,
   {{0xe29a0210,0x44fb381b,0xc7b200a5,0x6d5d381c}},	//   уам_, _tê_, _צבא_, _ossa,
   {{0xd6c600d1,0x7522381d,0x60de381e,0xbcfb026e}},	//   _امنی, _gvoz, _phpm, _fréi,
   {{0xbcfb0037,0x40951b96,0x443c00fe,0xa06a0200}},	//   _gréi, орст, _gcv_, ћава_,
   {{0xdfd2381f,0x6d5d3820,0xa0a332e2,0x1e9600af}},	//   سير_, _assa, чард, брар,
   {{0xed5a0a46,0xb21b01b4,0x6e3d0069,0xbea30f88}},	//   лоб_, skær, _ccsb, паск,
   {{0xa2c509b4,0x0c263821,0x4427028b,0x6b830301}},	// [2f20] रवर्, йман, _kdn_, ängn,
   {{0x6aa90054,0x442700f7,0x8db501e0,0x6abb021d}},	//   _amef, _jdn_, істі, _ajuf,
   {{0x6d5d3822,0x0b46046e,0x69db02d7,0x44270160}},	//   _essa, снен, _azue, _mdn_,
   {{0x320223ca,0xc332011d,0x66190345,0x201a0124}},	//   ncky_, לוב_, _newk, _hepi_,
   {{0xda65017e,0x442700cd,0x823b016b,0x2c8500fe}},	//   تالي, _odn_, רענצ, _bídě_,
   {{0xddcd00a8,0x6d44006d,0xc7b000b5,0x764b0160}},	//   ldaş, mtia, وڑا_, _abgy,
   {{0x6d443823,0x656b0139,0x9f580453,0xb8ff00be}},	//   ltia, _argh, mbró_, _धी_,
   {{0x44273824,0xddcd0463,0x7bdc176d,0x201a03c9}},	//   _adn_, ndaş, _izru, _lepi_,
   {{0x6d443825,0x661d008d,0xbcfb3826,0x9d4c03d0}},	//   ntia, ðska, _préi, есiн,
   {{0x201a034d,0xb4c2007c,0x6d443827,0x81ae0033}},	//   _nepi_, ंवे_, itia, কথা_,
   {{0x6d443828,0x0ec804bc,0x00000000,0x00000000}},	//   htia, लवाड, --, --,
   {{0x6d443829,0x4427099e,0xa6650987,0x00000000}},	//   ktia, _edn_, _وطنو, --,
   {{0xe29801c8,0xbcfb004f,0x752203c9,0x6d44006d}},	//   саў_, _tréi, _uvoz, jtia,
   {{0x443c0453,0x1394081b,0x6d5d01ed,0xbcfb021d}},	//   _ucv_, _милю, _rssa, _uréi,
   {{0x201a142f,0xddcd00a8,0x00000000,0x00000000}},	//   _depi_, fdaş, --, --,
   {{0x6448382a,0x201a02ee,0x00000000,0x00000000}},	//   lfdi, _eepi_, --, --,
   {{0x6d44382b,0x644812ba,0x00000000,0x00000000}},	// [2f30] gtia, ofdi, --, --,
   {{0x2caa0176,0x00000000,0x00000000,0x00000000}},	//   _cmbd_, --, --, --,
   {{0x69c01505,0xd9f90adb,0x6d44382c,0x00000000}},	//   _axme, анец_, atia, --,
   {{0xe80b0387,0x629d00cc,0x201a382d,0x00000000}},	//   सुना_, nhso, _zepi_, --,
   {{0x6d4f00d7,0x6d5d0345,0xa92400d4,0x2bdb04bc}},	//   _upca, _ussa, зділ, _भरवा,
   {{0x2003004e,0x656d0a23,0x18690370,0xd709382e}},	//   ncji_, _šaho, раки_, анке_,
   {{0x7d0d0044,0xbcfb0118,0x69c000fe,0x00000000}},	//   lpas, _préw, _exme, --,
   {{0x442702c2,0x6aa90054,0x7d0d382f,0x69b10066}},	//   _sdn_, _umef, opas, _आइपी,
   {{0x2003004e,0x7d0d3830,0x4427007b,0x00000000}},	//   kcji_, npas, _pdn_, --,
   {{0x395f3831,0x8d5c011d,0x03253832,0x00000000}},	//   _isus_, רכזי, одон, --,
   {{0x6d440291,0xddcd3833,0x68fb0421,0xbcfb00a2}},	//   ztia, ydaş, _huud, _grév,
   {{0x7d0d22be,0x201a00f8,0x68fb3834,0x6d440090}},	//   kpas, _sepi_, _kuud, ytia,
   {{0x7d0d0223,0x68fb194e,0x656b0079,0x442700cc}},	//   jpas, _juud, _urgh, _tdn_,
   {{0x68fb0006,0xa06a00d8,0x00000000,0x00000000}},	//   _muud, шага_, --, --,
   {{0xe29a3835,0x7d0d3836,0x68fb3837,0xaac901c0}},	//   _вай_, epas, _luud, िकाक,
   {{0x6d443838,0x629d3839,0x764900e9,0x35ce00be}},	//   ttia, chso, nfey, _हुड़,
   {{0x201a005d,0x7d0d383a,0x6d4401ef,0xddcd0095}},	// [2f40] _tepi_, gpas, utia, rdaş,
   {{0x3a3f01f7,0xd00a0274,0xd91000b5,0x0c260da3}},	//   _acup_, _њене_, ہیر_, імен,
   {{0x7d0d1a67,0xaec600af,0x2b3a0043,0x00000000}},	//   apas, _мбол, рязэ_, --,
   {{0x6d44383b,0x7bdc0187,0x2e6a0043,0x00000000}},	//   ptia, _vzru, _тимп_, --,
   {{0x18740131,0x7649001e,0xc98300c3,0xc7b800f4}},	//   згля, dfey, дущи, _međe_,
   {{0xbcfb383c,0x24870c1f,0x941e0095,0xf72a1bb1}},	//   _prév, _nonm_, bitə_, аций_,
   {{0xab27383d,0x7bdc383e,0x00000000,0x00000000}},	//   _мора_, _uzru, --, --,
   {{0xf526383f,0x649600af,0x7649016e,0xc7b80207}},	//   офон, _câin, gfey, _neđe_,
   {{0x20030035,0x22b600ea,0x2487021e,0x7e9b0317}},	//   ycji_, cāki_, _bonm_, יסקו,
   {{0x7afc3840,0x60c2004f,0x39461406,0xbcfb2b81}},	//   _kurt, _íomh, mtos_, _usée,
   {{0xc60601c8,0xa3e40035,0x31600260,0x7afc3841}},	//   _дзей, पें_, _asiz_, _jurt,
   {{0x7afc01e6,0x7d0d3842,0x929400d8,0x2a640107}},	//   _murt, ypas, даюц, _jamb_,
   {{0x39460aca,0x7afc1eb9,0x28df0edf,0xdb070093}},	//   ntos_, _lurt, _पीडि, _ólög,
   {{0x39460889,0x6ab708b0,0xc0cb325e,0xf8ca0066}},	//   itos_, _अद्र, руме_, ाकिय,
   {{0x14c704eb,0x09b70808,0xdefb061c,0x7afc3843}},	//   रकरण, _आख्य, рыг_, _nurt,
   {{0x3946123c,0xc3330122,0x539b0122,0x9df90be8}},	//   ktos_, _חוק_, _כיוו, снат_,
   {{0x7afc06a2,0x40870036,0x3ebe0093,0x20030067}},	// [2f50] _aurt, _дунб, étta_, pcji_,
   {{0x7afc3844,0x21390055,0x68fb02e2,0xa3cf0067}},	//   _burt, mush_, _ruud, _वुड_,
   {{0x68fb007c,0xdce40187,0x39460197,0x7afc10a7}},	//   _suud, cvič, etos_, _curt,
   {{0x7d0d3845,0x68fb0006,0x6738022f,0xbcfb3762}},	//   ppas, _puud, duvj, _brét,
   {{0xa9690202,0x2a6401f7,0xbcfb000d,0x21393846}},	//   сила_, _damb_, _crét, nush_,
   {{0x7afc3847,0xacfa0122,0xe9d800d8,0xbcfb0051}},	//   _furt, _להשכ, цкі_, _drét,
   {{0x7afc3848,0x2a660159,0xbcfb021d,0x649600af}},	//   _gurt, bdob_, _erét, _pâin,
   {{0xbcfb064b,0x213900da,0xba770ad9,0x395f006d}},	//   _frét, kush_, _باست, _tsus_,
   {{0x39463849,0x395f0ce8,0xc7b80200,0x76490978}},	//   ctos_, _usus_, _ređe_, rfey,
   {{0x7afc01d6,0x7649016e,0x656920b7,0x00000000}},	//   _yurt, sfey, rveh, --,
   {{0xc7b80009,0x61f100a8,0x270700e2,0x69c603d0}},	//   _peđe_, ədlə, _qđnd_, _øker,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24870359,0xd1760409,0x00000000,0x00000000}},	//   _tonm_, чыны, --, --,
   {{0xdce429e7,0x2ec4384a,0x03a5002d,0x648d0079}},	//   tvič, वक्त, _нило, _cúit,
   {{0x3946006c,0x66de01f4,0xdee6384b,0xbddb000d}},	//   ztos_, lëka, зови, _obès,
   {{0x90460088,0x2139384c,0x394600c7,0xe1ff0138}},	//   _کنده, bush_, ytos_, ldón_,
   {{0x7afc384d,0xd00f006c,0x6738022f,0xf53901ba}},	// [2f60] _surt, ئلہ_, zuvj, nuť_,
   {{0x7afc1d40,0xe1ff1111,0x00000000,0x00000000}},	//   _purt, ndón_, --, --,
   {{0xbcfb00f7,0x7afc00a8,0x6ffb011d,0xf53900ac}},	//   _brés, _qurt, _להיפ, huť_,
   {{0xbcfb00a2,0x37d10083,0x00000000,0x00000000}},	//   _prét, াধার, --, --,
   {{0x3946384e,0x649600f6,0x00000000,0x00000000}},	//   utos_, _bâil, --, --,
   {{0x98a334b5,0x7e6601ef,0x7afc08a3,0x22b60228}},	//   ниче, _hakp, _turt, māku_,
   {{0x2a643637,0xfbc30823,0x7afc384f,0xb8650bf5}},	//   _tamb_, _збро, _uurt, بانو,
   {{0x39460300,0xb9020083,0xdb1c0035,0xbddb0310}},	//   ptos_, _নং_, _wyró, _ibèr,
   {{0xf7f600b5,0xbcfb076c,0x7e663850,0x00000000}},	//   _فساد, _urét, _makp, --,
   {{0xb82700af,0x00000000,0x00000000,0x00000000}},	//   _ноуз_, --, --, --,
   {{0x62353851,0xf7890176,0x00000000,0x00000000}},	//   мену, reçà_, --, --,
   {{0x7e660159,0x0bb70d85,0xf53900d5,0x51872ad9}},	//   _nakp, ללים_, buť_, пуга,
   {{0x648d0037,0xcfaa0033,0x2259058c,0x5fd20066}},	//   _cúis, _খুলন, resk_, _दुबल,
   {{0x212d01c0,0xa3b400d4,0x65623852,0xfbbe06fe}},	//   šeho_, _облі, _isoh, ्थाम,
   {{0xc7b800e2,0x7e663853,0x00000000,0x00000000}},	//   _gdđt_, _bakp, --, --,
   {{0x443e3854,0x3ea03855,0x00000000,0x00000000}},	//   lgt_, ghit_, --, --,
   {{0x645a0036,0x7e663856,0x443e02a2,0x00000000}},	// [2f70] oeti, _dakp, ogt_, --,
   {{0x645a3857,0x443e3858,0x6728029d,0xa2c50567}},	//   neti, ngt_, _ovdj, रवक्,
   {{0x46cc0302,0xbcfb1010,0x443e3859,0x9e1500d4}},	//   ावाह, _prés, igt_, _одні,
   {{0xd36600bf,0x645a385a,0x629d0031,0x7c3e01e4}},	//   _یه_, heti, ëroh, agpr,
   {{0x645a385b,0xbddb021e,0x22b60228,0x6562007b}},	//   keti, _ebèr, cāku_, _nsoh,
   {{0x645a385c,0x443e0a75,0xbcfb0fce,0x00000000}},	//   jeti, jgt_, _frér, --,
   {{0xe7e8009a,0x645a385d,0xbcfb385e,0x656204fb}},	//   टेला_, deti, _trés, _asoh,
   {{0x443e385f,0x22b60029,0xa3e70569,0x672802a7}},	//   egt_, nākt_, _मृग_, _dvdj,
   {{0xdddd006a,0x3a2d0118,0x645a3860,0x00000000}},	//   _hasł, _idep_, feti, --,
   {{0x443e3861,0x7305020a,0x648d0037,0x3ea001f4}},	//   ggt_, мпоз, _rúis, zhit_,
   {{0xe1ff0b4c,0x9c8701c0,0x656200ee,0xd6ce03fc}},	//   rdón_, _začá, _esoh, طقی_,
   {{0xd5ae0a86,0x443e0a75,0x648d0037,0xe29703d4}},	//   افی_, agt_, _cúir, даю_,
   {{0x648d004f,0xd00a0009,0x00000000,0x00000000}},	//   _dúir, жеге_, --, --,
   {{0x645a3862,0x753b2d69,0x7e663863,0x00000000}},	//   ceti, muuz, _sakp, --,
   {{0x3ea03864,0x7e663865,0x96e101c0,0xff0700af}},	//   thit_, _pakp, _पठाउ, деск_,
   {{0x3d0205e7,0xdee30421,0x648d0098,0x00000000}},	//   _वंदे_, воси, _túis, --,
   {{0x3ea02af3,0x6fe7000d,0xc7b800f4,0x00000000}},	// [2f80] rhit_, técé, _međa_, --,
   {{0x3ea000da,0xc7b80254,0x62860bc6,0xb21b01b4}},	//   shit_, _leđa_, ljko, hjæl,
   {{0x307b0122,0x3ea00211,0xbea60036,0x290d01a3}},	//   _ואינ, phit_, _жанк, _atea_,
   {{0x645a3866,0xe9da0cc4,0x6286040b,0x3a2d0139}},	//   zeti, оке_, njko, _cdep_,
   {{0xbcfb2c27,0x443e0307,0x645a3867,0x22b60228}},	//   _fréq, ygt_, yeti, lāks_,
   {{0xf2bb0567,0x6e2400f1,0x645a3868,0x96f83869}},	//   _उद्घ, laib, xeti, пект_,
   {{0xc8c70312,0x290d0160,0x22b600ea,0x36d4386a}},	//   بوون_, _etea_, nāks_, нокр,
   {{0x6e24386b,0xcfc00083,0x645a386c,0x6443008c}},	//   naib, _ইরান, weti, _acni,
   {{0x645a386d,0xdddd0035,0x3a0900b5,0x2bbe0808}},	//   teti, _zasł, _رکنی_, ्थवा,
   {{0x443e386e,0x84e70037,0x7d7b016b,0xad9b00ee}},	//   ugt_, وفيق_, קריג, _sfúk,
   {{0xd6cf35b8,0x443e386f,0x6e2400a7,0x212900ac}},	//   _ат_, rgt_, kaib, _svah_,
   {{0x6e24128f,0x6b833870,0x443e0211,0x753b0273}},	//   jaib, ängi, sgt_, buuz,
   {{0x7c2e2c3f,0xd5e20084,0x65960071,0x6e243871}},	//   _odbr, _परिज, _تجار, daib,
   {{0xe3af3872,0x61f8010b,0x00000000,0x00000000}},	//   اری_, ьняў_, --, --,
   {{0xf363005f,0xceb40095,0x442e3873,0xdfd4010b}},	//   _атын, fiə_, _idf_, воры,
   {{0x7640055c,0xd5e20f0d,0x6e240608,0x656d0eac}},	//   ngmy, _पराज, gaib, _šahi,
   {{0x3d1a3874,0xbcfb000d,0x00000000,0x00000000}},	// [2f90] मीले_, _crép, --, --,
   {{0x61e00225,0x66de0031,0x442e00a2,0x22b60228}},	//   ümle, këko, _jdf_, sākt_,
   {{0x5a350b46,0x9f450421,0x3eb00079,0x290d024b}},	//   енет, älä_, últú_, _stea_,
   {{0x6e243875,0x6aa200e9,0x628d0183,0x00000000}},	//   caib, ghof, _joao, --,
   {{0xc7b80009,0x49b800d1,0x00000000,0x00000000}},	//   _ređa_, واهد_, --, --,
   {{0x2bbe05a6,0x442e055c,0xf09f0176,0x00000000}},	//   ्थशा, _ndf_, mpàs_, --,
   {{0xcb440432,0xe7393876,0xb9063877,0x7d0f02d7}},	//   _ихти, чей_, _यी_, _htcs,
   {{0x056503fa,0x6aa23878,0x32c400a8,0x61fb011c}},	//   евин, chof, kıya_, žulj,
   {{0x81b400c8,0xe57127f6,0x04b51d13,0x5a4400d8}},	//   _জুন_, اطب_, есня, _шэра,
   {{0x7c253879,0xb21b01b4,0x442e04fb,0xd8740bf5}},	//   nahr, sjæl, _cdf_, _لامب,
   {{0x032200af,0x889a00a5,0xe3b600af,0x00000000}},	//   лдэн, _צבעי, ебэ_, --,
   {{0x442e387a,0x753b0054,0xe80b018d,0x3ce60035}},	//   _edf_, puuz, सुरा_, _जीने_,
   {{0x349501c8,0xbddb0248,0x442e0a8a,0x00000000}},	//   _падр, _scèn, _fdf_, --,
   {{0x92c200c8,0x7c25033b,0x6e242d69,0x00000000}},	//   ্গে_, jahr, waib, --,
   {{0x6e24387b,0x00000000,0x00000000,0x00000000}},	//   taib, --, --, --,
   {{0xbcfb02e1,0x6441387c,0x6609387d,0x442e033b}},	//   _prép, lgli, ncek, _zdf_,
   {{0x7c2502bf,0xed5700c9,0x6441387e,0xee3700d8}},	// [2fa0] fahr, нот_, ogli, энт_,
   {{0x6441387f,0x7d040031,0x6e243880,0x00000000}},	//   ngli, rqis, saib, --,
   {{0x20183881,0x6e243882,0x64413883,0x2ef9009e}},	//   mbri_, paib, igli, _fisf_,
   {{0x44253884,0x2ebd112b,0x629d010b,0xfaa31401}},	//   hal_, ्कृत, ūrov, лахо,
   {{0x44253885,0x7d043886,0x7bc701f7,0xd83800fe}},	//   kal_, qqis, _exju, _alča_,
   {{0xfbd1006c,0x6aa23887,0x6cd60037,0x7c2e01b4}},	//   اتے_, shof, _أقسا, _udbr,
   {{0x442e3888,0x59dc0299,0xf0930122,0x32c40448}},	//   _rdf_, _बरकर, רנו_, zıya_,
   {{0x44253889,0x61e40124,0x2b5802d7,0x64413118}},	//   eal_, _ozil, _iprc_, egli,
   {{0x4425388a,0xd90e00ff,0x61e40069,0x00000000}},	//   fal_, _ایت_, _nzil, --,
   {{0x6441388b,0x442508a3,0x182800d1,0x33741523}},	//   ggli, gal_, _آقای_, вгор,
   {{0x61e4388c,0x5c370070,0xc61f0033,0x00000000}},	//   _azil, ערטן_, _ধারা_, --,
   {{0x4425388d,0x6441388e,0x7c25388f,0x25fa0026}},	//   aal_, agli, zahr, _उलटी_,
   {{0x44253890,0x6f1e0069,0x61e4007e,0x00000000}},	//   bal_, _awpc, _czil, --,
   {{0x44253891,0x32c401fb,0x00000000,0x00000000}},	//   cal_, rıya_, --, --,
   {{0x7ea3007c,0xdfd5325e,0xb4cc020d,0x61e43892}},	//   _lõpe, товы, लवी_, _ezil,
   {{0x7c25033b,0x6b8101f7,0x2ebd0355,0x32c401fb}},	//   wahr, _àlgi, ्केत, pıya_,
   {{0x661d00fb,0xa2ce3893,0x2d582698,0x201807e5}},	// [2fb0] ðski, सवर्, нить_, bbri_,
   {{0x6ac920ab,0xc60d1649,0x2d870254,0x00000000}},	//   िक्र, _सभ्य_, ćne_, --,
   {{0x212b01ae,0x2be60099,0x00000000,0x00000000}},	//   lsch_, _करणं_, --, --,
   {{0x44253894,0x00000000,0x00000000,0x00000000}},	//   zal_, --, --, --,
   {{0x212b3895,0x7e6d00d7,0x44253896,0x68fa3897}},	//   nsch_, mdap, yal_, _bitd,
   {{0x44253898,0x7e6d010d,0x212b033b,0x48cf0033}},	//   xal_, ldap, isch_, িগ্র,
   {{0x2bb80082,0x6d4d3899,0x23cf2c29,0x46a51761}},	//   _كافة_, ltaa, _सुंद, какв,
   {{0x7e6d1201,0x4425389a,0x6d4d02ea,0x6b831ca0}},	//   ndap, wal_, otaa, ängu,
   {{0x6d4d389b,0x644102bf,0x068200af,0x63a8389c}},	//   ntaa, tgli, ргын, ezdn,
   {{0xd90d00bf,0x97a7389d,0x68fa0523,0x6441389e}},	//   _هیچ_, _прел, _gitd, ugli,
   {{0x28b6009a,0x212b0479,0x6d4d0086,0x61e400b5}},	//   _अगति, esch_, htaa, _szil,
   {{0x6441001e,0xddc40043,0x6d4d389f,0x68fa0051}},	//   sgli, ndiţ, ktaa, _zitd,
   {{0x7afb00b5,0x67240009,0x7ae9009e,0x00000000}},	//   _miut, ćije, _mhet, --,
   {{0x442538a0,0x7e7d38a1,0xe3b938a2,0x7afb38a3}},	//   qal_, _ansp, _обл_, _liut,
   {{0x03a50714,0x212b012f,0x03a201e0,0x28a61371}},	//   _шико, asch_, _вищо, कोटि,
   {{0x6d4d0f04,0x7e6d043d,0x7afb005f,0x212b1bc9}},	//   ftaa, gdap, _niut, bsch_,
   {{0x6d4d18ad,0x00000000,0x00000000,0x00000000}},	// [2fc0] gtaa, --, --, --,
   {{0x7afb0133,0xeb9a0fc5,0x7e7d38a4,0xdd8f18dd}},	//   _aiut, миз_, _ensp, غول_,
   {{0x6d4d38a5,0x8fa638a6,0x0a4a01c8,0xc7b80009}},	//   ataa, _ране, дзей_, _ređo_,
   {{0x7afb162d,0x78a138a7,0x7ae938a8,0x769c00e0}},	//   _ciut, _allv, _chet, _réyo,
   {{0x6d4d0223,0x7afb149f,0x7ae901a6,0x7ceb01ae}},	//   ctaa, _diut, _dhet, dürf,
   {{0xf7720071,0x00000000,0x00000000,0x00000000}},	//   لاع_, --, --, --,
   {{0x6b830301,0x7afb38a9,0xd7ef15d6,0xb6c6027a}},	//   ängt, _fiut, ру_, ксий,
   {{0xe6cc045c,0x7afb38aa,0x3ce60461,0x68fa0b88}},	//   ावेज, _giut, _जीते_, _witd,
   {{0xceb30052,0x27e5022e,0xe9d738ab,0x7bdc02ee}},	//   ייה_, _ezln_, _акт_, _hyru,
   {{0xb4cc0299,0xb86502fd,0x68fa0136,0x00000000}},	//   लवे_, _مامو, _uitd, --,
   {{0xa29538ac,0x29042251,0x387e0012,0x83fc0c0a}},	//   гані, _huma_, _intr_, jeđe,
   {{0x290438ad,0x26c0010b,0x212b06d1,0x7bdc008c}},	//   _kuma_, čios_, tsch_, _myru,
   {{0xe2980a93,0x290438ae,0xe53410b0,0x212b033b}},	//   таў_, _juma_, _сель, usch_,
   {{0x2ebd021a,0x212b38af,0x2904214a,0x7ceb38b0}},	//   ्क्त, rsch_, _muma_, mürg,
   {{0x290438b1,0xff0403fe,0x7e6d010d,0xf1d3193c}},	//   _luma_, иятн, tdap, _धुरन,
   {{0x6d4d0086,0x2904053e,0x5f940212,0x26c602d7}},	//   ttaa, _ouma_, шист, _jjoo_,
   {{0x7e6d38b2,0xdef8061c,0x290438b3,0x6d4d013a}},	// [2fd0] rdap, тыр_, _numa_, utaa,
   {{0x7afb38b4,0x7ae938b5,0x80c10033,0x629d0345}},	//   _siut, _shet, _শীর্, lkso,
   {{0x6d4d38b6,0x50b838b7,0x7afb38b8,0xb5fd0478}},	//   staa, _جديد_, _piut, leše,
   {{0x6d4d005d,0x629d38b9,0x26c6002f,0x387e010b}},	//   ptaa, nkso, _njoo_, _antr_,
   {{0x290438ba,0x8d8438bb,0xd90f1a95,0x7d020079}},	//   _cuma_, _курд, زیا_, íost,
   {{0x98e5004f,0x7ae90122,0x6b830301,0xe8f801e0}},	//   دكتو, _whet, ängs, влі_,
   {{0x005802b8,0x224901d6,0x7afb005f,0x3a2438bc}},	//   דשות_, _ocak_, _tiut, _femp_,
   {{0xdb240514,0x69c9006f,0xd7560833,0x387e00f6}},	//   _úsái, _txee, اليت_, _entr_,
   {{0xb5fd124d,0x60d538bd,0xdced0124,0x59b738be}},	//   ješe, kozm, hvač, _अधिर,
   {{0x2a7f0d4b,0x224938bf,0x200101a5,0x348501db}},	//   _hnub_, _acak_, _nghi_, угог,
   {{0x94750148,0x6f03002a,0xe8190c03,0x00000000}},	//   ندگا, _énch, _न्या_, --,
   {{0xaad30af9,0x97a410ac,0x200138c0,0x63bc01ef}},	//   तविक, _трул, _aghi_, úrna,
   {{0x661b38c1,0x83fc00f4,0x00000000,0x00000000}},	//   mbuk, veđe, --, --,
   {{0x91032a25,0x55ba0122,0x629d0031,0x661b38c2}},	//   спре, _אמנו, ëror, lbuk,
   {{0x2d8f315b,0x3f9e024e,0xf8b20122,0x4f9538c3}},	//   ägen_, átu_, משך_, арту,
   {{0xdce40207,0x00000000,0x00000000,0x00000000}},	//   ović, --, --, --,
   {{0x83fc01cc,0x3f9e38c4,0x394d006f,0x661b002f}},	// [2fe0] ređe, štu_, _nqes_, ibuk,
   {{0xf06638c5,0xddc402c4,0x3a2438c6,0x753b0065}},	//   _скоп, gdiš, _semp_, iruz,
   {{0xeb9732e2,0xddd40067,0x7ceb00c1,0x00000000}},	//   лиф_, _łańc, dürd, --,
   {{0x7524027d,0x7bdc2fc4,0x094a38c7,0x753b0207}},	//   _çizg, _vyru, ечки_, kruz,
   {{0x38a2008a,0x5f760105,0x82d702b5,0x2a7f007a}},	//   _aðra_, _شاگر, נונג_, _dnub_,
   {{0x4b2610ee,0x2ee038c8,0x753b2f70,0x386c0103}},	//   _معرف, llif_, druz, _qadr_,
   {{0xd6d008cf,0x3a2438c9,0xc1e100b4,0x00000000}},	//   يقت_, _temp_, _नर्ग, --,
   {{0xa53401ee,0x2904000e,0x7d0602c4,0x6b83013c}},	//   анич, _tuma_, _kuks, ånge,
   {{0x2904010d,0x8836002d,0x7d0638ca,0x2bbe143a}},	//   _uuma_, _бэец, _juks, ्थका,
   {{0xd56301d3,0x7d060328,0x00000000,0x00000000}},	//   стъп, _muks, --, --,
   {{0x2ee00463,0x00000000,0x00000000,0x00000000}},	//   klif_, --, --, --,
   {{0x753b0036,0x81e90033,0x6e260a81,0x66e30d9e}},	//   bruz, _বলব_, _nekb, _лоха,
   {{0x753b21a4,0x629d0568,0xc05b02ce,0xb5fd0168}},	//   cruz, rkso, нів_, teše,
   {{0x6fd6074f,0xdced00cd,0xb4c1021a,0x00000000}},	//   _मुहू, tvač, ्कृ_, --,
   {{0xb5fd38cb,0x7d0638cc,0x6e2603d0,0x60d5088d}},	//   reše, _auks, _bekb, rozm,
   {{0x7d0638cd,0x2ee000d7,0x6e2000be,0x75220027}},	//   _buks, glif_, _õmbl, _kwoz,
   {{0xa3b800a1,0x6e261192,0x7ceb02b1,0x00000000}},	// [2ff0] _घेत_, _dekb, hüre, --,
   {{0x7d0638ce,0x20010036,0x661b00cd,0x7522030d}},	//   _duks, _ughi_, zbuk, _mwoz,
   {{0xdce401f2,0x70fa00a5,0x03e200e2,0x60fa00a5}},	//   zvić, _שהתח, _đuốn, _שהתק,
   {{0x660200d1,0x19b901c8,0x7ceb38cf,0xc33300a5}},	//   _ngok, куль_, würd, מוע_,
   {{0xa96938d0,0x645838d1,0x3ea90079,0xe9690421}},	//   тила_, _obvi, mhat_, талл_,
   {{0xe739144e,0x7c8710b0,0x3ea900b5,0x6602073a}},	//   век_, _суме, lhat_, _agok,
   {{0x07a538d2,0x752238d3,0x00000000,0x00000000}},	//   райн, _awoz, --, --,
   {{0x753b046f,0x7d0600a3,0x75220e91,0x3ea938d4}},	//   truz, _yuks, _bwoz, nhat_,
   {{0x661b124f,0x7e6f38d5,0x784700b5,0x2bd900ab}},	//   rbuk, _macp, _مضام, _बुता,
   {{0x753b38d6,0x66020291,0xb4c10ca1,0xdb2300b5}},	//   rruz, _egok, ्के_, _írój,
   {{0xe2860610,0x61e101c2,0x23cf0026,0x987a0070}},	//   ални, əlli, _सुखद, _שרעק,
   {{0x6d5d38d7,0x753b00cd,0x25b600d1,0x7c2708c8}},	//   _opsa, pruz, اهید_, _lejr,
   {{0x3ea938d8,0xcad60122,0x6e260051,0x75220107}},	//   dhat_, שורת_, _rekb, _gwoz,
   {{0x6e26022e,0x7d0638d9,0x7c2700b8,0x823600fd}},	//   _sekb, _ruks, _nejr, درگا,
   {{0x44271442,0x7d060703,0x6d5d38da,0x8c240083}},	//   _ien_, _suks, _apsa, _পালন_,
   {{0xa3ea009a,0x442738db,0x3ea938dc,0xee371400}},	//   _मरत_, _hen_, ghat_, инс_,

   {{0xcbe212eb,0x442738dd,0x0c260573,0xec4a18a4}},	// [3000] _বলেছ, _ken_, иман, кзал_,
   {{0x442738de,0x25ad0526,0xed57052a,0xac8338df}},	//   _jen_, izel_, роф_, огул,
   {{0x44270122,0x9f4c0421,0x3ea938e0,0x80a60416}},	//   _men_, ädä_, bhat_, _ممکن,
   {{0x4427124b,0x3ea938e1,0x4356016b,0x00000000}},	//   _len_, chat_, יסעל_, --,
   {{0x6d5d01d7,0x7c2738e2,0x7e6408c7,0x442738e3}},	//   _gpsa, _fejr, meip, _oen_,
   {{0x442738e4,0xb4c1000c,0x7e6438e5,0xddcd00af}},	//   _nen_, ्को_, leip, leaş,
   {{0xf727010b,0x00000000,0x00000000,0x00000000}},	//   ацый_, --, --, --,
   {{0x83fc025c,0x3ea038e6,0xdc2e0095,0xd0010831}},	//   jeđa, nkit_, _yığm, ্রয়_,
   {{0xe8fa38e7,0x6d443811,0xf8af006c,0xa9670714}},	//   _ала_, nuia, سکے_, _кита_,
   {{0x7ae238e8,0x442738e9,0x3ea900b5,0xed5700a5}},	//   llot, _cen_, zhat_, סביר_,
   {{0x44270304,0x480738ea,0x7ae20714,0x7b130069}},	//   _den_, _техн_, olot, _għud,
   {{0x442738eb,0x96fa2604,0x6b81014c,0x3ea90055}},	//   _een_, _شعار_, _álge, xhat_,
   {{0x442738ec,0x7ae20036,0x20d70037,0x75220027}},	//   _fen_, ilot, لتسج, _uwoz,
   {{0x44270c05,0x3ea9024b,0x3be60067,0x00000000}},	//   _gen_, what_, _करूँ_, --,
   {{0x442c38ed,0x3ea938ee,0xb5fd38ef,0x43430bfe}},	//   mad_, that_, meša, _дејв,
   {{0x442703cb,0x93fb00c2,0x2bda0f09,0x7c2738f0}},	//   _zen_, _בלוי, _भड़ा, _sejr,
   {{0x442701ca,0xa2d40026,0x3ea938f1,0x7ae238f2}},	// [3010] _yen_, णकर्, rhat_, dlot,
   {{0x442c38f3,0x644838f4,0x3ea938f5,0x7ae20526}},	//   nad_, ngdi, shat_, elot,
   {{0x7c27054e,0x81e90083,0x3ea938f6,0x3b550336}},	//   _vejr, _বলি_, phat_, скер,
   {{0x442c2583,0xdd910332,0x3ea01ba3,0x7ae22b26}},	//   had_, _فوج_, ckit_, glot,
   {{0x996730cc,0x777a06a2,0x8d87083e,0x6d5d38f7}},	//   ртел, _artx, _тунд, _upsa,
   {{0x6e2d38f8,0x442c0ccf,0x81e900c8,0xb5fd0c0a}},	//   laab, jad_, _বলা_, ješa,
   {{0x442c38f9,0xb5fd0bec,0x442736f3,0xccf200a5}},	//   dad_, deša, _ren_, _מכך_,
   {{0x442738fa,0x6e2d0273,0x442c38fb,0x25ad38fc}},	//   _sen_, naab, ead_, tzel_,
   {{0x442c38fd,0xddc6108a,0x83fc0009,0xf84b00af}},	//   fad_, _kakš, veđa, _ачей_,
   {{0x442c38fe,0x442701f4,0x6e2d38ff,0x3ea03900}},	//   gad_, _qen_, haab, zkit_,
   {{0xe29a07c3,0x44273901,0xc62600c8,0x4dde000c}},	//   ган_, _ven_, _যারা_, _कुनै_,
   {{0x44273902,0xddc63903,0x6e2d030d,0x64481192}},	//   _wen_, _lakš, jaab, agdi,
   {{0x83fc042a,0x6e2d3904,0x442700a5,0xc7b80009}},	//   ređa, daab, _ten_, _ređi_,
   {{0x7cf000ab,0xb5fd02c4,0x44273905,0x76490225}},	//   märg, ceša, _uen_, lgey,
   {{0x7e643906,0x628f0176,0xdbf100fe,0x00000000}},	//   teip, bjco, _břím, --,
   {{0x6e2d3907,0x76493908,0x539a02b8,0xb2261999}},	//   gaab, ngey, _תיקו, _умил,
   {{0x395f006d,0x3ea01e3a,0x62843909,0x7d26042c}},	// [3020] _npus_, rkit_, _inio, صفان,
   {{0x6296390a,0x3ea0390b,0x6d4416ac,0x3eb9390c}},	//   _hoyo, skit_, ruia, _emst_,
   {{0x6e2d001c,0x2d8f390d,0x629600f8,0x395f390e}},	//   baab, øger_, _koyo, _apus_,
   {{0x6296390f,0x442c3910,0xc5f20033,0x6b83013c}},	//   _joyo, zad_, ছুটা_, ånga,
   {{0x442c3911,0x6d442587,0x629604be,0x395f345d}},	//   yad_, quia, _moyo, _cpus_,
   {{0x7ae23912,0x442c3913,0x28f83066,0x307a02b5}},	//   slot, xad_, шель_, ראַנ,
   {{0x442c3914,0x7ae215d8,0xd6da001f,0x62843915}},	//   vad_, plot, лти_, _onio,
   {{0x442c179d,0xe6660de9,0x62963916,0x7cf001ff}},	//   wad_, стко, _noyo, färg,
   {{0x4ab900af,0xdcef0160,0x65690027,0x00000000}},	//   _туря_, _urcă, gweh, --,
   {{0x62843917,0x6aa20af9,0x3f780124,0x442c3918}},	//   _anio, lkof, _oču_, uad_,
   {{0x442c3919,0x6e2d001c,0x998d391a,0xdbe6000c}},	//   rad_, yaab, _ideš_, _करोड_,
   {{0x442c391b,0x7cf00523,0x65691ad9,0xd6270dee}},	//   sad_, lärd, bweh, _гоце_,
   {{0xb5fd391c,0x3946391d,0xa3b80066,0x62960118}},	//   peša, nuos_, _घेर_, _doyo,
   {{0x6e2d01a8,0x442c391e,0xb5040ebd,0x24f600af}},	//   waab, qad_, रदीप_, _учер,
   {{0x6e2d391f,0xdbf101c0,0xe45702b5,0x00000000}},	//   taab, _přím, _ליגט_, --,
   {{0x6296012f,0x7cf0038e,0x628400f1,0x00000000}},	//   _goyo, härd, _gnio, --,
   {{0x6e2d001c,0x38ab2b6f,0x998d00cb,0x6e940370}},	// [3030] raab, _høre_, _odeš_, читу,
   {{0x6e2d3904,0x39462dd3,0xa3cc004e,0x38ab054e}},	//   saab, duos_, _रखा_, _køre_,
   {{0xb5fd0c21,0x6296000e,0x395f0043,0x65690010}},	//   ješn, _yoyo, _spus_, zweh,
   {{0xdb0800b5,0x38ab23f4,0x00000000,0x00000000}},	//   álás, _møre_, --, --,
   {{0xc7b801cc,0x7d0d38a0,0x39463920,0x2bd90084}},	//   _među_, qqas, guos_, _बुरा,
   {{0x7cf0013c,0x61ed0054,0x07150036,0x58d40421}},	//   gärd, _mzal, офия, почт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61ed0ea8,0x66f2015a,0x6aa23921,0x0609261f}},	//   _ozal, мпју, ckof, шник_,
   {{0x76492cea,0xf993004f,0x1a680609,0x3946171c}},	//   rgey, _عبر_, _دینی_, cuos_,
   {{0x65693922,0x6296000d,0xd838023a,0xb72b052a}},	//   rweh, _soyo, _gdč_, _бюдж_,
   {{0x61ed3923,0x97a7171d,0x62960118,0x6266144b}},	//   _azal, _урал, _poyo, овна,
   {{0x38ab08c8,0x26dd04fb,0x00000000,0x00000000}},	//   _døre_, _ukwo_, --, --,
   {{0x7cf019ee,0x6296175d,0x6abb073a,0x00000000}},	//   läre, _voyo, _mmuf, --,
   {{0x03a53924,0x6284004e,0x5fdb0722,0x6aa9001e}},	//   _мило, _wnio, _मुहल, _llef,
   {{0x38ab0022,0x7cf006d2,0x61ed3925,0x2bd908a9}},	//   _gøre_, näre, _ezal, _बुला,
   {{0x62843926,0xb5fd3927,0xe1ff002a,0x00000000}},	//   _unio, nešo, meón_, --,
   {{0xe1ff0b4c,0x7cf00110,0x85f6016b,0xe5f6016b}},	// [3040] león_, häre, ַמעס_, ַזער_,
   {{0x7cf03928,0x6c860088,0x61e4027d,0x6abb1642}},	//   käre, غلام, _iyil, _amuf,
   {{0xbcfb1010,0x8b6a0086,0x7cf03929,0x643a02b5}},	//   _spéc, риев_, värd, שעענ,
   {{0x6aa9392a,0x3946392b,0xb5fd008b,0xd35a0070}},	//   _clef, tuos_, ješo, ידעל,
   {{0xe8fa0948,0x7ceb013b,0x788000ee,0x00000000}},	//   алд_, süra, _návä, --,
   {{0x98a3392c,0x7cf0013c,0x2d54007c,0x6aa2392d}},	//   миче, färe, mäe_, skof,
   {{0xf0930779,0xfaa600d8,0x7cf00282,0xda660413}},	//   ונג_, _даво, gäre, _واري,
   {{0x60dc005d,0xb5fd392e,0x963407c3,0x7e76029e}},	//   horm, rešn, чниц, ndyp,
   {{0xe60f026e,0x61e42292,0x6d560d32,0x60dc00b5}},	//   خشى_, _nyil, ntya, korm,
   {{0xb5fd125d,0x59c00632,0x81e90033,0x60dc0260}},	//   pešn, _शेयर, _বলল_, jorm,
   {{0x61ed392f,0x60dc3930,0xb5fd0009,0x15f800b4}},	//   _szal, dorm, lešl, _ुलकर_,
   {{0x2bbd00c0,0xddcd002d,0x6d560260,0x61e40027}},	//   ्पता, ndaţ, ktya, _byil,
   {{0x672d011c,0x61e404fb,0x00000000,0x00000000}},	//   ćaje, _cyil, --, --,
   {{0x6ab71e82,0x60dc0282,0xf8bc00dc,0x61ed0187}},	//   _आग्र, gorm, ्चिय, _vzal,
   {{0x09b709b1,0x788001ba,0xb4e600a1,0xcebb0274}},	//   _अध्य, _závä, पती_, аља_,
   {{0x645a3931,0x9d1521f5,0x73f9016b,0x00000000}},	//   lfti, здач, _פּסו, --,
   {{0x61ed3932,0x5fdb3933,0xbddb01f7,0x60dc00ee}},	// [3050] _uzal, _मुरल, _acèr, borm,
   {{0x645a3934,0xbcfb0312,0x00000000,0x00000000}},	//   nfti, _bpéa, --, --,
   {{0xd7df00a1,0x7cf002b1,0x00000000,0x00000000}},	//   _पुढच, färb, --, --,
   {{0x9fbf00ac,0x00000000,0x00000000,0x00000000}},	//   nčím_, --, --, --,
   {{0x0dc80370,0xa92400d4,0x6aa901f4,0x6728035f}},	//   _дури_, дділ, _vlef, _awdj,
   {{0x7cf03935,0x27953936,0x645a01e4,0x2bbd0355}},	//   täre, зшир, jfti, ्पदा,
   {{0x6562011e,0x24890019,0x291d02d0,0xb6a500af}},	//   _apoh, _đam_, spwa_, зийл,
   {{0x32090028,0x212900d1,0x6abb01d5,0x645a3937}},	//   _ngay_, _owah_, _umuf, efti,
   {{0x60dc027d,0x645a00e9,0x98ad00ee,0xb5fd0097}},	//   yorm, ffti, _ipeľ_, rešo,
   {{0x3209043d,0xe71901cb,0x00000000,0x00000000}},	//   _agay_, _هيئت_, --, --,
   {{0x65623938,0x3a2d0122,0x60dc3939,0x2905043d}},	//   _epoh, _keep_, vorm, _iila_,
   {{0x216a01d3,0x2905393a,0x3a2d012c,0x00000000}},	//   бими_, _hila_, _jeep_, --,
   {{0x290519c6,0xb7bc0ae0,0x00000000,0x00000000}},	//   _kila_, _reģi, --, --,
   {{0x2d5400ab,0xf99200a5,0x68e10069,0x3a2d0282}},	//   väe_, תרך_, _jkld, _leep_,
   {{0x2905393b,0xd00f1c51,0xa3b80099,0x212900f8}},	//   _mila_, الف_, _घेऊ_, _ewah_,
   {{0x539a0122,0x60dc393c,0x3a2d012f,0xf7720070}},	//   _ליצו, sorm, _neep_, עקן_,
   {{0x60dc03a2,0xa1130037,0xdb0d00a0,0xbcfb0079}},	// [3060] porm, _كويت, ľkým, _spéa,
   {{0x290532e1,0x6d56393d,0xf8a50609,0xb17b0317}},	//   _nila_, rtya, _شک_, _פטיר,
   {{0x6d56393e,0x309b0122,0xeaaf00b5,0xda0a0037}},	//   stya, _השימ, گٹن_, مياه_,
   {{0x7ceb393f,0xf1e100ab,0x2905081b,0xed5a083e}},	//   büro, _गुड़_, _aila_, _лом_,
   {{0x29053940,0x6e2401a8,0x3a2d3941,0xbefa05e7}},	//   _bila_, mbib, _deep_, ्दीन_,
   {{0x290501d2,0x6e243942,0x7ceb0448,0xbab601cb}},	//   _cila_, lbib, nürl, _کمرب,
   {{0x36d40847,0x29050c86,0x56943943,0x38cb0416}},	//   мокр, _dila_, дайт, حانی_,
   {{0x6d441e7b,0x7c2e3944,0xa91d00fe,0xb4e40354}},	//   oria, _hebr, _bržd, _भीड़_,
   {{0x29053945,0xd943001f,0x9c830116,0x7ceb3946}},	//   _fila_, _пети, ščet, kürl,
   {{0x29050ec0,0x6d443947,0xb4e60ac4,0x691c027d}},	//   _gila_, iria, पते_, rçeğ,
   {{0x7ceb01d6,0x645a1be1,0x6d443948,0x995600ea}},	//   dürl, rfti, hria, kļūt_,
   {{0xa3bd0035,0x29053949,0x6d44010b,0x28bc022e}},	//   _इधर_, _zila_, kria, ्चवि,
   {{0x867b0052,0x518703fa,0x6d4406df,0xc50a0037}},	//   _לראו, чуна, jria, _اتصل_,
   {{0x6d44394a,0x200c025c,0xbcfb0b06,0x7ceb027d}},	//   dria, ždin_, _apén, gürl,
   {{0x443c07e5,0xdce40009,0x712702fd,0x442e021d}},	//   _idv_, jviđ, _کربل, _ief_,
   {{0x442e00fb,0x6e240269,0xdce40a78,0xbcfb0138}},	//   _hef_, gbib, dviđ, _asép,
   {{0x7c2e394b,0x2715013a,0x1df8021f,0x6d44394c}},	// [3070] _bebr, _māna_, зеты_, gria,
   {{0xd01100d2,0xa2c5021a,0x3a2d394d,0xddcd26f9}},	//   _جلد_, ाचक्, _seep_, gdaš,
   {{0xdced0a78,0x7c2e394e,0x7c290c99,0x3a2d394f}},	//   hvać, _debr, _đerd, _peep_,
   {{0x29053950,0x6d443951,0x3f570095,0x442e3952}},	//   _sila_, bria, mçu_, _lef_,
   {{0x29050b04,0x6d440132,0x3f5700a8,0x442e0051}},	//   _pila_, cria, lçu_, _oef_,
   {{0x7c2e3953,0x3a2d16df,0x442e3954,0x26f722c7}},	//   _gebr, _weep_, _nef_, ुद्र_,
   {{0x29052ce4,0xb8f50299,0x3f573955,0x00000000}},	//   _vila_, _हद_, nçu_, --,
   {{0xaa580202,0x7c2e3956,0xa91d0009,0x7c250037}},	//   _нису_, _zebr, _arže, lbhr,
   {{0x29050238,0x442e0fbc,0x7cf0013c,0x38b000f1}},	//   _tila_, _bef_, lära, _bàrd_,
   {{0xb5fd3957,0x442e06e4,0x38ab0044,0x2ee9033b}},	//   lešk, _cef_, _føra_, hlaf_,
   {{0x62030669,0xa91d0956,0x2ee9046a,0x765b0010}},	//   ətlə, _drže, klaf_, pfuy,
   {{0x7c250a32,0x7d070a75,0x7ceb0644,0x442e3958}},	//   hbhr, _lijs, dürm, _eef_,
   {{0x7ceb3959,0x27e001d6,0x443c0116,0xe44e01af}},	//   türl, ğine_, _fdv_, _иж_,
   {{0x7d070223,0x1dd808a9,0x3ce30024,0x442e1441}},	//   _nijs, _भुगत, _nkjv_, _gef_,
   {{0x7c2e395a,0xdee6395b,0x4425395c,0x9103395d}},	//   _rebr, дови, mbl_, тпре,
   {{0x7c2e395e,0xb5fd025c,0xd12f00b5,0x7d0f340b}},	//   _sebr, ješk, طمہ_, _bucs,
   {{0xed5700c9,0x6d44395f,0x7c2e3960,0x3f570279}},	// [3080] мот_, uria, _pebr, açu_,
   {{0x10a63961,0x7d0702c4,0x6e243962,0x6d443963}},	//   _цион, _cijs, sbib, rria,
   {{0xdced02c4,0xd83802a7,0x2ee90345,0xddcd00f4}},	//   zvać, _joče_, blaf_, rdaš,
   {{0x6d443964,0x7d0f3965,0x20180036,0x7d070223}},	//   pria, _fucs, lcri_, _eijs,
   {{0x26cd0200,0x7c2e3966,0x7d07023a,0xd838063b}},	//   dneo_, _tebr, _fijs, _loče_,
   {{0xfbd905e7,0xab2a01d3,0x7d070051,0x2bd900b4}},	//   _बुकम, _мога_, _gijs, _बुका,
   {{0xfc033967,0x443c00f7,0x8c430274,0xd83808b7}},	//   _апро, _rdv_, _јесе, _noče_,
   {{0x6b83054e,0x442e3968,0x26cd0036,0x200700a0}},	//   ænge, _sef_, gneo_, _únie_,
   {{0x443c025c,0xa91d00cb,0x75390069,0x672d00cd}},	//   _pdv_, _prže, _cvwz, ćaja,
   {{0x442e0031,0x83fc00cd,0xdced0207,0x2d8200f4}},	//   _qef_, leđi, rvać, _mrke_,
   {{0x442e3969,0xf7720037,0x7eb101e0,0xa91d1405}},	//   _vef_, _جاء_, _håpe, _vrže,
   {{0xe5c611b9,0x38ab01cf,0x4b3700a5,0x2d8200f4}},	//   _осло, _jørn_, ורטל_, _orke_,
   {{0xa30800f5,0x26c4396a,0xa91d008b,0x44250036}},	//   _کرتے_, mimo_, _trže, bbl_,
   {{0x39460bb0,0xd8380009,0x7ceb396b,0x25b000d0}},	//   iros_, _foče_, türm, ıllı_,
   {{0x7d0701e4,0x2d82396c,0x4fc434db,0x7d0f0051}},	//   _rijs, _arke_, вста, _sucs,
   {{0x26c4396d,0x3f811851,0x3946396e,0x3f573955}},	//   nimo_, _vrhu_, kros_, rçu_,
   {{0x2fdf0035,0xb5fd008b,0xa2dc0af6,0x9b9501cb}},	// [3090] ług_, vešk, नवर्, کلات,
   {{0x26c42922,0x3f81024e,0x26cd0009,0xebc70274}},	//   himo_, _trhu_, zneo_, мљен,
   {{0x38ab0022,0xf99001cb,0x26c400d8,0x92c30083}},	//   _børn_, یبه_, kimo_, ্তী_,
   {{0x26c401c8,0x7d0701e4,0x6738022f,0xdd950aeb}},	//   jimo_, _wijs, dsvj, _замы,
   {{0x26c4396f,0x39461721,0xe1ff006c,0xae1a00a5}},	//   dimo_, gros_, deók_, _מורכ,
   {{0x7cf01a17,0xa3c00380,0x99d400d1,0x7b671d13}},	//   lärn, ूपा_, ختما, _отбе,
   {{0x83fc02c4,0xc87800c1,0x5b143970,0x63650160}},	//   beđi, _dağ_, _амст, _mγnc,
   {{0x394609ab,0x3ea93971,0xb5fd0d5c,0x26c43972}},	//   bros_, nkat_, leši, gimo_,
   {{0x26cd3973,0x6d4d145d,0x2f150533,0xf5053974}},	//   rneo_, nuaa, _låg_, нзио,
   {{0xb5fd3975,0xd8380b16,0x7e6d0037,0x97a700af}},	//   neši, _poče_, heap, _орел,
   {{0x3ea93976,0x26c43977,0xc2c6004f,0x7e6d27df}},	//   kkat_, bimo_, فيدي, keap,
   {{0x26c43978,0x7cf0022a,0x442500d7,0x61460aec}},	//   cimo_, järn, sbl_, нема,
   {{0x6d4d00d7,0x7e6d00af,0xc878033e,0xb5fd00cd}},	//   juaa, deap, _yağ_, keši,
   {{0xb5fd029d,0x0ef83979,0x6d4d397a,0x2f15093a}},	//   ješi, ंग्स_, duaa, _båg_,
   {{0x7ea3007c,0xb4bd02cb,0x645c0443,0xb4cb0253}},	//   _lõpu, ीची_, òrie, रची_,
   {{0x20180160,0x7eaa024e,0x3ea9397b,0x39460409}},	//   scri_, _výpo, gkat_, yros_,
   {{0x291f0221,0xac86397c,0x6d4d397d,0xf1bf0138}},	// [30a0] _ntua_, нгал, guaa, lbán_,
   {{0x39460370,0x26c428c2,0xb5fd02c4,0x21200069}},	//   vros_, zimo_, geši, _itih_,
   {{0x291f397e,0x2d8f15e8,0x205700a5,0x1fb5010b}},	//   _atua_, äger_, _אייל_, _асяр,
   {{0x39461423,0x26c42140,0x2d821269,0x3ea9397f}},	//   tros_, ximo_, _trke_, ckat_,
   {{0x26c43980,0xf539016f,0x83fc0254,0x2d820009}},	//   vimo_, jsť_, ređi, _urke_,
   {{0x39461430,0x20070443,0x672d0254,0x6e363981}},	//   rros_, _únic_, ćajn, layb,
   {{0xcb673982,0x2d8023bb,0x37060f9e,0x00000000}},	//   _паре_, lvie_, нчив, --,
   {{0x6e3601a2,0x2d800036,0x224000e0,0x00000000}},	//   nayb, ovie_, _ndik_, --,
   {{0x26c43983,0x7ae2005b,0x2d803984,0xceb300a5}},	//   rimo_, moot, nvie_, טיה_,
   {{0x26c43985,0x22400cfb,0x6e360159,0x7ae21994}},	//   simo_, _adik_, hayb, loot,
   {{0x26c43986,0x3ea93987,0x00000000,0x00000000}},	//   pimo_, ykat_, --, --,
   {{0x7ae23988,0x7ceb0448,0x2d8000d5,0x00000000}},	//   noot, türk, kvie_, --,
   {{0x64a635f7,0x6e360097,0x7eaa0187,0x2a64028b}},	//   _пада, dayb, _výpl, _mbmb_,
   {{0x2bd93989,0x2ed9364c,0x92c30083,0x0cc40033}},	//   _बुझा, भक्त, ্তে_, ্তুত,
   {{0x7e6d2491,0x3ea9398a,0xdfd400d8,0x7ae2398b}},	//   teap, tkat_, горы, koot,
   {{0x6d4d1e0d,0x6e360159,0x00000000,0x00000000}},	//   tuaa, gayb, --, --,
   {{0x3ea9398c,0x628d000e,0xdce4004e,0x7ae2398d}},	// [30b0] rkat_, _inao, zwią, doot,
   {{0x3ea9398e,0x6d4d0051,0x2f1501ff,0x7e6d03d0}},	//   skat_, ruaa, _tåg_, seap,
   {{0xb5fd398f,0x6e363990,0x6d4d005b,0xceb400a8}},	//   reši, bayb, suaa, bhə_,
   {{0xa91d02c4,0x7ae202ea,0x629f007a,0x60c70223}},	//   _arža, goot, _joqo, lijm,
   {{0x628d3991,0xb2260a8a,0x6d4d0223,0x00000000}},	//   _mnao, _hjææ, quaa, --,
   {{0xf7451f6a,0xf771028c,0x83fc0009,0x00000000}},	//   веко, لاب_, leđu, --,
   {{0xa91d2dd2,0xd7fb00af,0xadfb00ab,0x00000000}},	//   _drža, чуд_, ्शकन_, --,
   {{0x629f009f,0x7cf00282,0x7ae20223,0x7ceb0a21}},	//   _noqo, härl, coot, düri,
   {{0x7cf00523,0x00000000,0x00000000,0x00000000}},	//   kärl, --, --, --,
   {{0xb4bd02cb,0x628d0860,0x27e03992,0xb4cb0099}},	//   ीचे_, _anao, şina_, रचे_,
   {{0x2120011c,0x68e33993,0x394f3994,0xdce60409}},	//   _stih_, mond, lugs_, _erkė,
   {{0x68e301a8,0x83fc00cb,0x00000000,0x00000000}},	//   lond, jeđu, --, --,
   {{0x645c0443,0xd8380009,0x6a3a00a5,0x00000000}},	//   òric, _hoča_, וגרפ, --,
   {{0x64a23995,0x68e33996,0x628d0310,0x6e360159}},	//   _ваша, nond, _enao, wayb,
   {{0x7e563997,0x7ae23998,0xafe600aa,0xa3d5021a}},	//   ктац, yoot, товл, _सखि_,
   {{0x68e33999,0x661b399a,0xfe43294d,0xd83800ee}},	//   hond, ncuk, инсо, _moča_,
   {{0x212000d7,0xec7a1578,0xe0da03fa,0x7ae233ee}},	// [30c0] _utih_, мпа_, _ови_, voot,
   {{0x31370052,0x21370070,0x2d80399b,0x68e30065}},	//   _שנים_, _שטיל_, rvie_, jond,
   {{0x83fc0200,0x7ae2399c,0xfe46399d,0x661b00d7}},	//   beđu, toot, _инно, kcuk,
   {{0x753b04c3,0x0a67015a,0x4420002d,0x68e30051}},	//   ksuz, врши_, _și_, eond,
   {{0x68e3399e,0x7ae2399f,0x386532b2,0x672100ec}},	//   fond, root, _bblr_, _atlj,
   {{0x68e339a0,0x91bb0122,0x48d00033,0x7524027d}},	//   gond, ומני, িত্র, _çizi,
   {{0xb8ea0953,0x98a303fa,0x7cf0038e,0x2a7d006d}},	//   _लग_, рије, närm, bdwb_,
   {{0xfaa339a1,0x38b0009e,0x7d1b0042,0xcb670043}},	//   _касо, _dàra_, _éusc, _шасе_,
   {{0xa91d39a2,0x628d009e,0x0906010b,0x00000000}},	//   _trža, _rnao, _апан, --,
   {{0x68e30e12,0xd83802c4,0xb5fd0506,0x7cf0017b}},	//   cond, _foča_, ješu, kärm,
   {{0xd8380009,0x7cf0013c,0x925900af,0x62350f16}},	//   _goča_, värl, нант_, лену,
   {{0xa91d0254,0x02a72c61,0x6aa0082b,0xd7ef0037}},	//   _mržn, тром, _jomf, _بكم_,
   {{0x61f6004e,0xc6490037,0xe5720ae7,0xc05b01e0}},	//   _czyl, _أجمل_, _خطا_, мів_,
   {{0x290c02e9,0x75220371,0x00000000,0x00000000}},	//   _jida_, _itoz, --, --,
   {{0x290c39a3,0xcfa4002d,0x403400c3,0x629f007a}},	//   _mida_, ашти, ресс, _toqo,
   {{0x628d000e,0x68e30a75,0x325502f3,0x6b8102d7}},	//   _unao, zond, _свир, _álgi,
   {{0x83fc0a78,0x68e339a4,0x00000000,0x00000000}},	// [30d0] ređu, yond, --, --,
   {{0x6adb04aa,0xb5fd0274,0x290c39a5,0x4fc70409}},	//   यक्र, mešt, _nida_, _асма,
   {{0x68e304ce,0xddc400d8,0x6aa0021d,0x00000000}},	//   vond, reiš, _bomf, --,
   {{0x7b642526,0x68e31516,0x61ed0273,0x6aa039a6}},	//   ртфе, wond, _kyal, _comf,
   {{0x68e339a7,0xb5fd3262,0x290c39a8,0x4a4401e0}},	//   tond, nešt, _bida_, рнів,
   {{0x290c021d,0x394f008c,0x645800d7,0x61ed39a9}},	//   _cida_, rugs_, _ncvi, _myal,
   {{0xf0940100,0xdce4004e,0x57a403fa,0x61ed018e}},	//   ינס_, jwię, ишћа, _lyal,
   {{0x68e339aa,0x7cf00f67,0xe579079d,0xf77000d1}},	//   sond, järj, ези_, تاه_,
   {{0x68e31010,0xb5fd03fd,0x61ed00ff,0x7e7d39ab}},	//   pond, ješt, _nyal, _masp,
   {{0x290c01d7,0x68e30510,0x38ab10db,0xd8380116}},	//   _gida_, qond, _mørk_, _toča_,
   {{0x7e7d00af,0x7afb39ac,0x7ae90118,0x00000000}},	//   _oasp, _khut, _kket, --,
   {{0x7e7d39ad,0xe29a328c,0x290c0254,0x61ed01a8}},	//   _nasp, хам_, _zida_, _byal,
   {{0xfdbe0083,0x7afb39ae,0x60c50176,0x78a139af}},	//   _আড্ড, _mhut, _bmhm, _kolv,
   {{0xdddd004e,0x4385004f,0x61ed02d0,0xf0d500d8}},	//   _obsł, _ملتق, _dyal, аўсю,
   {{0x2b180437,0x61ed0273,0x7afb39b0,0x6d5d009f}},	//   _बंधु_, _eyal, _ohut, _aqsa,
   {{0x7ea3007c,0x7eb117ad,0x00000000,0x00000000}},	//   _sõpr, _påpa, --, --,
   {{0x0d860409,0x7e7d013a,0x7c35088a,0x61ed39b1}},	// [30e0] ылан, _dasp, _bezr, _gyal,
   {{0x7cf039b2,0xddc605d3,0x7e7d0037,0x7ae939b3}},	//   märk, _takž, _easp, _aket,
   {{0x5f760833,0x290c39b4,0x69db01ef,0x6aa007e7}},	//   _صادر, _rida_, _axue, _pomf,
   {{0x290c39b5,0xe9da35ea,0xbae502ce,0xbddb0392}},	//   _sida_, нке_, ацій, _idèn,
   {{0x644339b6,0x7afb39b7,0x290c39b8,0x78a139b9}},	//   _odni, _dhut, _pida_, _bolv,
   {{0x7e7d39ba,0xa91d219c,0x7ae9005f,0x7afb01ed}},	//   _zasp, _tržn, _eket, _ehut,
   {{0x69dc004e,0xf6e60dee,0x3ea2017b,0x00000000}},	//   _śred, лцин, _kokt_, --,
   {{0x7afb184f,0x1ab8164f,0xa91d0207,0x290c0088}},	//   _ghut, _आतिथ, _kržl, _wida_,
   {{0x45d409ea,0xbcfb004f,0x78a10009,0x290c0044}},	//   ропс, _spéi, _folv, _tida_,
   {{0xb5fd39bb,0xb8650416,0x7ea3007c,0x63a80c61}},	//   vešt, _نامو, _lõpp, tydn,
   {{0x61ed046a,0x7d0e0107,0x00000000,0x00000000}},	//   _syal, _mibs, --, --,
   {{0x7d0e007a,0xb5fd1a8a,0xd83802a7,0x00000000}},	//   _libs, tešt, _kočo_, --,
   {{0x7e7d39bc,0xe53400c3,0xf486010b,0x7d0e0211}},	//   _rasp, _тель, _буйн, _oibs,
   {{0x26c6006f,0x7e7d0228,0x64580207,0x00000000}},	//   _hmoo_, _sasp, _ucvi, --,
   {{0x3ea202a2,0x387e39bd,0x80b62135,0xa3cb39be}},	//   _bokt_, _matr_, _उतरे, _रेप_,
   {{0x4ea439bf,0x7d0e009e,0xb5fd39c0,0x00000000}},	//   бруа, _aibs, pešt, --,
   {{0x3ce1065a,0x7e7d0274,0xdd9400c3,0x7afb016e}},	// [30f0] कवले_, _vasp, баты, _rhut,
   {{0x7e7d39c1,0x80d30083,0x27e00355,0x7d0e099e}},	//   _wasp, _দীর্, řiny_, _cibs,
   {{0x7f9502c4,0x7afb01a6,0x7e7d0984,0x78a112ba}},	//   _танх, _phut, _tasp, _rolv,
   {{0x78a139c2,0xa3c300b8,0x8f9a0319,0xfc4500b5}},	//   _solv, náší_, _סירי, _چھاپ,
   {{0x6e2d39c3,0x78a139c4,0x3cea023a,0xd90f132d}},	//   mbab, _polv, _fkbv_, سیا_,
   {{0x6e2d39c5,0x07a501d3,0x6b83013c,0x6f0f39c6}},	//   lbab, иалн, ångs, _hicc,
   {{0x78a139c7,0x7afb39c8,0x64470453,0xd838023a}},	//   _volv, _thut, ójim, _točn_,
   {{0x75452e2d,0x26c600ee,0x6f0f0024,0x69db01ed}},	//   аниз, _cmoo_, _jicc, _txue,
   {{0x6f0f027a,0x6d4d39c9,0x78a139ca,0x69db01ed}},	//   _micc, nraa, _tolv, _uxue,
   {{0x99d41d05,0x2a7f0221,0x7eaa024e,0x6f0f027a}},	//   _اتفا, _haub_, _výpi, _licc,
   {{0x2a7f01e8,0xf7990a86,0x6d4d299b,0x00000000}},	//   _kaub_, _جناب_, hraa, --,
   {{0x6f0f39cb,0x6d4d3517,0x7cf0306a,0x2ca302c4}},	//   _nicc, kraa, tärk, _lojd_,
   {{0x2a7f01e8,0x644e002a,0x7ceb027b,0x00000000}},	//   _maub_, óbic, nürs, --,
   {{0x2a7f0221,0x6d4d39cc,0x752939cd,0x79890069}},	//   _laub_, draa, mpez, _mrew,
   {{0x6d4d39ce,0x6f0f36c1,0x7d0e0a8c,0x7eb10044}},	//   eraa, _bicc, _ribs, _våpn,
   {{0xddc6006a,0x6e2d39cf,0x6f0f0382,0x6d4d1b37}},	//   _takż, gbab, _cicc, fraa,
   {{0x6f0f39d0,0x6d4d39d1,0x395f0221,0x752901ed}},	// [3100] _dicc, graa, _nqus_, npez,
   {{0x8c461129,0x7eb103d0,0x00000000,0x00000000}},	//   реже, _håpl, --, --,
   {{0x79890118,0x6f0f244b,0x6d4d39d2,0x6e2d39d3}},	//   _arew, _ficc, araa, bbab,
   {{0x2a7f01e8,0x6d4d39d4,0x7eb8081d,0x8b2301e0}},	//   _caub_, braa, _bípe, ідче,
   {{0x394039d5,0x798939d6,0x7d0e01e8,0x2a7f39d7}},	//   éis_, _crew, _tibs, _daub_,
   {{0x6f040284,0x79890035,0x7cf000c3,0x00000000}},	//   lmic, _drew, käri, --,
   {{0xd6da39d8,0xd90d09b9,0xbb4339d9,0x276801cb}},	//   кти_, ریم_, _мерк, اشتی_,
   {{0x443a1075,0x6f040284,0x2f1c006c,0xb4de07df}},	//   _žp_, nmic, _míg_, थक्_,
   {{0x7989099e,0xd83802a7,0xbddb0118,0x6f040767}},	//   _grew, _hočm_, _ndèl, imic,
   {{0xf8aa0084,0x2a7f0189,0xd4061583,0x1beb007c}},	//   _कविय, _zaub_, ияни, _जुडल_,
   {{0x6f0401cc,0xdddd0029,0x28b90043,0x7eb8021d}},	//   kmic, _pasū, _сутэ_, _zípe,
   {{0xf2c739da,0x20cd01c8,0x6f040129,0x6d4d0298}},	//   рсон, džia_, jmic, yraa,
   {{0x6f0f01d3,0x6f0433ee,0x857601df,0xf8aa02b4}},	//   _ricc, dmic, _خدائ, _कवाय,
   {{0x3d1a0992,0x6d4d0244,0x6f0f0382,0xd838021e}},	//   _बढ़े_, vraa, _sicc, _alčz_,
   {{0x6f0f39db,0x04040083,0x6d4d01bf,0xd83801a0}},	//   _picc, _শ্রী_, wraa, _meč_,
   {{0x6d4d39dc,0x5eb42294,0x38b900f6,0xd8380a0b}},	//   traa, ойст, _ière_, _leč_,
   {{0x2a7f39dd,0x6e2d02c2,0x672d00cb,0x6d4d39de}},	// [3110] _raub_, rbab, ćaji, uraa,
   {{0x6d4d39df,0x6f0f39e0,0x2a7f006f,0xfbab00af}},	//   rraa, _wicc, _saub_, ктей_,
   {{0x2a7f0d4b,0x6d4d39e1,0x2ef20345,0x20070211}},	//   _paub_, sraa, blyf_, _àni_,
   {{0x6e950082,0x6d4d0136,0x38b90248,0x2a7f0221}},	//   _الحا, praa, _mère_, _qaub_,
   {{0xdced003a,0xd838011c,0xf1bf002a,0xda781346}},	//   svađ, _beč_, nzá_, рях_,
   {{0x7ceb045e,0x2d8b005f,0x31e40831,0x00000000}},	//   rürs, _irce_, নেকশ, --,
   {{0x2a7f0189,0xddcd023a,0x473800d8,0x79890298}},	//   _taub_, ndaž, ачыў_, _wrew,
   {{0x798939e2,0x7cf02933,0x2d8b00ee,0x24890457}},	//   _trew, väri, _krce_, _şam_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f040cc1,0x7cf039e3,0x8b0800b8,0x98480043}},	//   zmic, täri, pořá, _вяца_,
   {{0x752939e4,0x130a00c3,0x74070033,0x00000000}},	//   spez, лной_, োর্ট_, --,
   {{0xfbd20122,0x75290a11,0x2d8b0139,0x00000000}},	//   לתי_, ppez, _orce_, --,
   {{0xd4690798,0x00000000,0x00000000,0x00000000}},	//   _биле_, --, --, --,
   {{0x7cf01fa0,0xd7f100e2,0x00000000,0x00000000}},	//   päri, _kỹ_, --, --,
   {{0xf4120052,0x2d8b0453,0x38b9000d,0xa91d02a7}},	//   _צפה_, _arce_, _gère_, _bržk,
   {{0xe3b039e5,0x16040461,0xd7f100e2,0x932439e6}},	//   _تره_, शेवर_, _mỹ_, _برون,
   {{0xbea31728,0x25bf39e7,0xa3cb0084,0xddea00f8}},	// [3120] чатк, nzul_, _रेत_, ارزه_,
   {{0xc5f20319,0xed5739e8,0xfcaa0088,0xeb9a1574}},	//   לדן_, соф_, دارو_, лиз_,
   {{0x7f860082,0xd8380902,0x9f5e00c3,0xdee60ddc}},	//   _الجن, _reč_, ätä_, _гони,
   {{0xba1600c8,0x93bc002d,0x7cf01cb8,0x00000000}},	//   ার্ড_, mbăt, järv, --,
   {{0x2fd70416,0xd83839e9,0x00000000,0x00000000}},	//   _نوید_, _peč_, --, --,
   {{0xd7fa1a24,0x3ea70012,0x52a502e4,0x48e301d3}},	//   луй_, _într_, _ऑक्स, почв,
   {{0xd83839ea,0xf1bf006c,0x6d56121e,0x7c3e39eb}},	//   _več_, zzá_, luya, mapr,
   {{0xc6f80274,0x00000000,0x00000000,0x00000000}},	//   јних_, --, --, --,
   {{0x20cd02c4,0xe9da0aec,0xd83802a7,0x00000000}},	//   džin_, _ска_, _teč_, --,
   {{0x443839ec,0x38b939ed,0xb86603c5,0x7c290009}},	//   úr_, _père_, _دارو, _đerk,
   {{0xd25103c5,0x6d5639ee,0x7e76008e,0x2cb839ef}},	//   وند_, huya, keyp, _mlrd_,
   {{0x6d5639f0,0x7c3e39f1,0xddcd002d,0x46a30714}},	//   kuya, hapr, neaţ, _нахв,
   {{0x9c83108a,0x7cf001ae,0xe1ff0079,0x41e7010b}},	//   ščit, läru, afón_, сіна,
   {{0x7c3e39f2,0xc0c839f3,0x9a290023,0x6d5639f4}},	//   japr, бусе_, _mươi_, duya,
   {{0x2d8b17ee,0xaab80f9c,0xbcfb02e1,0x38ab0a8a}},	//   _srce_, _आतंक, _opér, _tørv_,
   {{0xd25100f5,0x3ea000da,0xff070131,0x38ab0c71}},	//   _کچھ_, gjit_, сягн, _hørt_,
   {{0x9c3916b8,0x38ab01b4,0x2249195f,0xdd940409}},	// [3130] ипат_, _kørt_, _idak_, паты,
   {{0x645a39f5,0xbcfb00f7,0xd99900b5,0x00000000}},	//   ngti, _apér, ینات_, --,
   {{0x443e002d,0x38ab008c,0x68ea0345,0xbcfb008e}},	//   iat_, _mørt_, dofd, _spés,
   {{0x443e39f6,0x6d5639f7,0x2d8b0207,0xa91d0207}},	//   hat_, buya, _trce_, _hrži,
   {{0x443e39f8,0x5d33006c,0x99672d9c,0x7cf000be}},	//   kat_, _رہائ, стел, värv,
   {{0x443e39f9,0x02c600a1,0xac1839fa,0x00000000}},	//   jat_, _लग्न, _гору_, --,
   {{0x443e39fb,0x3eb90093,0x00000000,0x00000000}},	//   dat_, _klst_, --, --,
   {{0x645a39fc,0x224900f8,0xa5250183,0x00000000}},	//   egti, _ndak_, омид, --,
   {{0x443e39fd,0x99d4004f,0x66751a95,0x00000000}},	//   fat_, _فتكا, مدکر, --,
   {{0xe4c502ce,0x20cd00d8,0x7aeb39fe,0x00000000}},	//   ійни, džio_, logt, --,
   {{0xe29a005f,0x7cf000c3,0x7eb801ef,0x3eb90051}},	//   аан_, märt, _lípa, _olst_,
   {{0xae090bc1,0xa91d0009,0x443e02ee,0x7c3e0541}},	//   वधान_, _arži, aat_, zapr,
   {{0x443e39ff,0xe5a50eee,0x672d011c,0x38ab10db}},	//   bat_, _фили, ćaju, _ført_,
   {{0x443e3a00,0x6ab5046c,0xbf0209b1,0x53a50079}},	//   cat_, ंसुर, लग्न_, _ومشك,
   {{0xa91d3a01,0x7c3e3a02,0x3f8c0097,0x2249009f}},	//   _drži, vapr, ídu_, _fdak_,
   {{0x765b3a03,0x93bc002d,0x6d56018e,0xa91d0b43}},	//   nguy, rbăt, tuya, _erži,
   {{0x27e00723,0x62963a04,0xed5a06a9,0x7cf00523}},	// [3140] ğini_, _inyo, роз_, kärt,
   {{0x6296006d,0x27e03a05,0x62843a06,0x62863a07}},	//   _hnyo, şini_, _haio, ldko,
   {{0x7c3e27c3,0x62842741,0x3ea61499,0x220400e0}},	//   rapr, _kaio, _динг, bèhé_,
   {{0x443e3a08,0x62863a09,0x7c3e3a0a,0x6d563a0b}},	//   zat_, ndko, sapr, puya,
   {{0x6284130f,0x443e3a0c,0x7c3e3a0d,0x88e60a2b}},	//   _maio, yat_, papr, ожде,
   {{0x5fcf02e4,0x443e3a0e,0xd8380a66,0xceb400a8}},	//   _हेडल, xat_, _koči_, lkə_,
   {{0x443e3a0f,0x6d442cbf,0x99490035,0x7c3c0159}},	//   vat_, lsia, góły_, _ierr,
   {{0x7c3c3a10,0x6e240b06,0x9a2901a5,0x356a3a11}},	//   _herr, ncib, _tươi_, арон_,
   {{0x443e3a12,0x7c3c03ad,0xd8380116,0x2715013a}},	//   tat_, _kerr, _loči_, _bāns_,
   {{0x62963a13,0x443e1599,0x6286213d,0x6d443a14}},	//   _anyo, uat_, edko, isia,
   {{0x7c3c00da,0x62843a15,0x6d44104e,0x43943a16}},	//   _merr, _baio, hsia, чанс,
   {{0x443e3a17,0x212900d7,0x7c3c01d7,0x6d4402ee}},	//   sat_, _ptah_, _lerr, ksia,
   {{0x443e3a18,0x7792006c,0x69c201e4,0x6d440221}},	//   pat_, _ریکا, nzoe, jsia,
   {{0x443e3886,0x8438004f,0xc05b03d0,0x62963a19}},	//   qat_, _اكثر_, шім_, _enyo,
   {{0x2249046a,0x6d443a1a,0x6d463789,0x27231008}},	//   _tdak_, esia, _avka, _kına_,
   {{0x76403a1b,0x62842314,0x99840024,0x443c3a1c}},	//   namy, _gaio, _bemż_, _hev_,
   {{0x7c3c3a1d,0x443c3a1e,0xa91d05e2,0x6d44010d}},	// [3150] _berr, _kev_, _trži, gsia,
   {{0x7c3c3a1f,0x2d893a20,0x76400232,0xd8380009}},	//   _cerr, rvae_, hamy, _foči_,
   {{0x7c3c0cc8,0x443c3a21,0x7eaa024e,0x6d44005b}},	//   _derr, _mev_, _výpr, asia,
   {{0x0f7a00c2,0x7cf0315b,0x6d44006d,0x7055103b}},	//   _פארב, wärt, bsia, _بنگا,
   {{0x6b8e035f,0xdb0500b5,0x78a807c0,0x76400027}},	//   _erbg, gyhá, _bodv, damy,
   {{0x443c0221,0x7c3c3a22,0x3f810031,0x88c801e0}},	//   _nev_, _gerr, _kshu_, олів_,
   {{0xe7390086,0x4e1f14ab,0xda35021f,0x29071bd8}},	//   щей_, _भलाई_, _невы, rmna_,
   {{0x7c3c0291,0x76401815,0x7c253a23,0x7d1d3389}},	//   _zerr, gamy, lchr, _kuss,
   {{0x7d1d3a24,0x6284238c,0x7cf000c3,0x79800051}},	//   _juss, _raio, märr, _gsmw,
   {{0x443c01a9,0x7d1d3a25,0x6aa90a75,0x628406a2}},	//   _cev_, _muss, _hoef, _saio,
   {{0x7d1d046f,0x62840036,0x6d443a26,0x443c3a27}},	//   _luss, _paio, zsia, _dev_,
   {{0x6d443a28,0x27230a21,0x443c0024,0x7c2514a0}},	//   ysia, _gına_, _eev_, hchr,
   {{0x361a0100,0x5ec30083,0x62863a29,0x443c3a2a}},	//   _הונד, ্কাই, rdko, _fev_,
   {{0x6abb0176,0x6284023c,0x7e6f2a4b,0xd83802a7}},	//   _lluf, _waio, _abcp, _poči_,
   {{0x64413a2b,0x7d1d3a2c,0xdfd2004f,0x6e3d3a2d}},	//   mali, _auss, رير_, _besb,
   {{0x6d440006,0x7d1d3a2e,0x7d150080,0x64413a2f}},	//   tsia, _buss, _aizs, lali,
   {{0x6d443a30,0x6e3d3a31,0x6e240b4c,0x443c3a32}},	// [3160] usia, _desb, rcib, _yev_,
   {{0x6e2413fb,0x443c006d,0x6d441651,0xd8380b67}},	//   scib, _xev_, rsia, _toči_,
   {{0xd8380254,0x6d443a33,0x76403a34,0x6e3d3a35}},	//   _uoči_, ssia, yamy, _fesb,
   {{0x64413a36,0x7c3c009f,0xe80f0387,0x13ae0083}},	//   hali, _werr, ाधना_, _ছেড়,
   {{0x442700e9,0xe0df01f7,0x00000000,0x00000000}},	//   _ofn_, cròs_, --, --,
   {{0x64413a37,0x6f1e0169,0x69c204ce,0x81be0083}},	//   jali, _kupc, rzoe, _আশা_,
   {{0xf0930122,0xa3cb20d8,0xc796005f,0x76403a38}},	//   תנו_, _रेल_, ярды, tamy,
   {{0x443c3a39,0x69cd112b,0xfa672705,0x61e401ef}},	//   _sev_, _देवी, _наск_, _oxil,
   {{0x64413a3a,0x443c01e8,0x764004fb,0x44270298}},	//   fali, _pev_, ramy, _bfn_,
   {{0x64413a3b,0x443c0221,0x76403a3c,0xd49a1b81}},	//   gali, _qev_, samy, сри_,
   {{0x443c006f,0x81aa00c8,0x61e4002a,0x764004fb}},	//   _vev_, _গেল_, _axil, pamy,
   {{0x443c006d,0x64410196,0x0cb90066,0x32670421}},	//   _wev_, aali, _इत्म, чтов,
   {{0x64413a3d,0x443c3a3e,0x2d820009,0xfbc40033}},	//   bali, _tev_, _nske_, ্থিত,
   {{0x7d1d3a3f,0x64a301c8,0xf1b0026e,0x6e3d31bd}},	//   _russ, _пача, اءَ_, _sesb,
   {{0x61e43a40,0x2d823a41,0x7f941098,0x6e3d0118}},	//   _exil, _aske_, нарх, _pesb,
   {{0x33db00a5,0x7d1501fb,0x672700fd,0x00000000}},	//   _לחוד, _sizs, _éjje, --,
   {{0x3d170084,0x7c253a42,0xd8380207,0x7b0300be}},	// [3170] _भूखे_, tchr, _hoču_, nõue,
   {{0xad9b0831,0x3f81006d,0xc1bc00a5,0x6e2201ef}},	//   _azúc, _tshu_, _למחש, ñobr,
   {{0x2d820c1f,0x7d15006c,0x09aa0083,0x7c253a43}},	//   _eske_, _vizs, _খেলা, rchr,
   {{0x7c253a44,0x7d1d1c47,0x64413a45,0xc33300a5}},	//   schr, _tuss, zali, תוף_,
   {{0x64413a46,0x6f1e00cd,0xd838146c,0x3cf100ee}},	//   yali, _zupc, _loču_, _tkzv_,
   {{0x64410095,0x20cd00f4,0x9ce700fd,0x00000000}},	//   xali, džik_, _روزے_, --,
   {{0x64413a47,0x238c01c0,0x6aa93a48,0x66e53a49}},	//   vali, _něj_, _toef, мока,
   {{0x64413a4a,0x2bd300ab,0x00000000,0x00000000}},	//   wali, _धेया, --, --,
   {{0x26c301c8,0xc6480037,0x3eab00ac,0x44273a4b}},	//   ėjo_, سجيل_, _moct_, _pfn_,
   {{0xa91d0a69,0x3a3f32c5,0xf3491566,0x00000000}},	//   _držt, _heup_, опол_, --,
   {{0x68e40079,0x2242003c,0x4ac4021a,0x290500ee}},	//   éide, takk_, लोकव, _ihla_,
   {{0x64413a4c,0x291f0054,0x35b52c0f,0xe29a3a4d}},	//   sali, _kuua_, _обер, цам_,
   {{0xf6520397,0x200100d7,0x44273a4e,0x291f00be}},	//   _יצא_, _azhi_, _tfn_, _juua_,
   {{0x6ada0e61,0xd8380009,0x6441013b,0x29190118}},	//   _भद्र, _foču_, qali, _ésau_,
   {{0xdce4003c,0x291f00ab,0x29050284,0x00000000}},	//   stiċ, _luua_, _mhla_, --,
   {{0x61f60086,0x61e401a3,0x00000000,0x00000000}},	//   _tyyl, _txil, --, --,
   {{0xf1bf3a4f,0x65693a50,0x3eab0090,0x00000000}},	// [3180] lcán_, nteh, _doct_, --,
   {{0x31570779,0x24870c1f,0xec771b17,0x9bd6002d}},	//   _קיין_, _janm_, мпу_, мцеш,
   {{0x24870c1f,0x9a8602ee,0x224001a2,0x38b000f1}},	//   _manm_, дулл, _keik_, _màrt_,
   {{0x2120104e,0x2d820009,0x38b0009e,0x2487021e}},	//   _kuih_, _tske_, _làrt_, _lanm_,
   {{0x397a0125,0xdce40129,0xa3d40d1f,0x3946010b}},	//   تصاد_, ltič, _सेन_, usos_,
   {{0x3a2637fa,0x2120028b,0x22400093,0x248702d0}},	//   scop_, _muih_, _leik_, _nanm_,
   {{0x39463a51,0xdce40496,0xdb832701,0x212000e0}},	//   ssos_, ntič, _игри, _luih_,
   {{0x81c400c8,0x38c803c5,0x2d80331b,0xf5263a52}},	//   _এখন_, _کاری_, owie_, мфон,
   {{0x78663a53,0x248702d0,0xe5c600c3,0x95d800c3}},	//   _оказ, _banm_, ьско, ядит_,
   {{0xdce402dd,0x090300af,0x7eb10044,0xd838023a}},	//   ktič, _апун, _håpt, _poču_,
   {{0xb865042c,0x6d5600d7,0x24870260,0x366a00af}},	//   _سالو, hrya, _danm_, _мажо_,
   {{0x21200034,0x929401c8,0x6d560703,0x00000000}},	//   _buih_, ваюц, krya, --,
   {{0x24870c1f,0xf1bf00de,0xf5b60e0c,0x21200118}},	//   _fanm_, acán_, _تصاد, _cuih_,
   {{0xfd4f0019,0x6602138c,0x2d800067,0x00000000}},	//   _triế, _izok, dwie_, --,
   {{0xc58800e8,0x46b20d2a,0x22400839,0x00000000}},	//   _hồ_, _जवाह, _feik_, --,
   {{0xe5020066,0x3869011c,0x6e360298,0x00000000}},	//   _रीति_, đari_, gbyb, --,
   {{0xfd1f1e19,0x2d800088,0x00000000,0x00000000}},	// [3190] _quì_, gwie_, --, --,
   {{0xc5880019,0x22400051,0x00000000,0x00000000}},	//   _mồ_, _zeik_, --, --,
   {{0xc5880019,0x50d4017e,0x3a3f0107,0xa2a30569}},	//   _lồ_, _جزير, _peup_, गाप्,
   {{0x527c0070,0x6f06009e,0x29050211,0x66020103}},	//   ַנוא, _ghkc, _shla_, _ozok,
   {{0x5e5602b5,0x3949004f,0x6602007b,0x00000000}},	//   _אירע_, éas_, _nzok, --,
   {{0xb06600c3,0x7ceb02b1,0x00000000,0x00000000}},	//   _ikää, hürz, --, --,
   {{0x66023a54,0x26cf0132,0x7ceb3a55,0x20cd00f4}},	//   _azok, _pmgo_, kürz, ržih_,
   {{0xc5880019,0xf4060033,0x291f00ab,0x65692ce0}},	//   _bồ_, োডার_, _tuua_, tteh,
   {{0xa2a3021a,0xa3d40243,0x22403a56,0x98751f67}},	//   गान्, _सेब_, _reik_, _плац,
   {{0x6f0d01ae,0x65693a57,0xa2cd0380,0x29050168}},	//   hmac, rteh, दोस्, _uhla_,
   {{0x65693a58,0x6f0d3a59,0xccf20122,0xc6a70012}},	//   steh, kmac, רכי_, _орди,
   {{0x87b602b5,0xe7b60070,0x00000000,0x00000000}},	//   _אלעס_, _אהער_, --, --,
   {{0x463a0779,0xa3d40006,0xf1bf0037,0x67210124}},	//   _זענע, _सेठ_, scán_, _hulj,
   {{0x67213a5a,0x73e50133,0x30750086,0x7f5c0510}},	//   _kulj, _полз, кусс, turq,
   {{0x9103320c,0xf85200a0,0x61e200ac,0x6f0d3a5b}},	//   упре, ížiť_, _žold, fmac,
   {{0x67213a5c,0x2d800035,0xdce400ac,0x6d560090}},	//   _mulj, twie_, rtič, trya,
   {{0xdce41851,0x6721003c,0xf3890019,0x60d53a5d}},	// [31a0] stič, _lulj, _hả_, bizm,
   {{0xdce4103a,0x9f861112,0x60d525ea,0x6f0d3298}},	//   ptič, _згод, cizm, amac,
   {{0x26df0c0a,0x103b0122,0x6e461f6a,0x395d01e4}},	//   knuo_, _מגיע, _пенз, euws_,
   {{0xe60700ad,0x7c3b0506,0x6da6224a,0x7eb103d0}},	//   _مش_, _đure, _зима, _dåps,
   {{0xd6d00a86,0x7ae33a5e,0xb0d700ab,0xda650037}},	//   یقت_, énta, _डगमग, ضاني,
   {{0x98a30573,0x67213290,0x67d409eb,0x38b90107}},	//   личе, _bulj, колу, _fèrm_,
   {{0x66023a5f,0xfce3341b,0x38b000f1,0x00000000}},	//   _szok, _соро, _bàrr_, --,
   {{0x67210c21,0x26df003a,0x7d1b0176,0x60d53a60}},	//   _dulj, gnuo_, _èusc, zizm,
   {{0xe8ca0043,0x00000000,0x00000000,0x00000000}},	//   _егал_, --, --, --,
   {{0x07a600d8,0x6721007a,0x38b0009e,0x7ceb02b1}},	//   _пазн, _fulj, _eàrr_, würz,
   {{0xf38900e8,0x67210069,0x6f0d3a61,0x92591fb1}},	//   _cả_, _gulj, ymac, мант_,
   {{0x26df0124,0x95ca010e,0x00000000,0x00000000}},	//   cnuo_, _нула_, --, --,
   {{0x66020027,0xe0df0392,0x672107e7,0x290e01f7}},	//   _uzok, bsòl_, _zulj, omfa_,
   {{0x645c3a62,0x13f40382,0x00000000,0x00000000}},	//   órid, _изля, --, --,
   {{0x6f0d01ae,0xbddb0118,0xf38900e2,0x00000000}},	//   tmac, _ndèr, _gả_, --,
   {{0x25e700a1,0x752208c7,0x00000000,0x00000000}},	//   _जखमी_, _kuoz, --, --,
   {{0x20cd0009,0x7522010b,0x988300a0,0x00000000}},	// [31b0] dživ_, _juoz, víľu_, --,
   {{0x6f0d3a63,0x26df012e,0x00000000,0x00000000}},	//   smac, znuo_, --, --,
   {{0xc4d302b5,0xf3890019,0x00000000,0x00000000}},	//   נגע_, _xả_, --, --,
   {{0x67213a64,0x76420453,0xddd00009,0x59d223e3}},	//   _rulj, _neoy, šešt, _देहर,
   {{0x67213a65,0x41b30af9,0x7982010d,0x26df0207}},	//   _sulj, ुनिस, gwow, vnuo_,
   {{0x3ea93a66,0x67213a67,0xdb230148,0x9dd600a5}},	//   ljat_, _pulj, _موسی, _יורק_,
   {{0x26df011c,0x07a53a68,0xf0940070,0x00000000}},	//   tnuo_, тайн, טנס_, --,
   {{0x59d21fb4,0xf1b30026,0x41b3022e,0x75220ecf}},	//   _देवर, ुनान, ुनास, _buoz,
   {{0xceb4168d,0x39153a69,0x26df00cb,0xf38900e2}},	//   טיק_, _амар, rnuo_, _sả_,
   {{0x26df044d,0x67212190,0x75220051,0x249c0139}},	//   snuo_, _tulj, _duoz, _cnvm_,
   {{0x77900088,0x3ea9022e,0x26df0506,0x3fdc0033}},	//   _هیوا, kjat_, pnuo_, _ধর্ষ,
   {{0x3ea9007a,0xe2973a6a,0x6d5f0c6f,0xf3890023}},	//   jjat_, ваю_, kuqa, _vả_,
   {{0xcb1200c2,0x3ea93a6b,0x20d600d4,0xf48601cb}},	//   ילט_, djat_, вівс, رایی,
   {{0xf38901a5,0x3ea90176,0x00000000,0x00000000}},	//   _tả_, ejat_, --, --,
   {{0xddca0035,0x10a30212,0xa0a3005f,0x64433a6c}},	//   łoży, ширн, шард, _ieni,
   {{0x394d00fe,0x20cd010b,0xa2a3018d,0x00000000}},	//   _oves_, džiu_, गाण्, --,
   {{0xd83e0097,0xa7fc0448,0xe0d200f8,0x00000000}},	// [31c0] áčka_, _acıl, _نزد_, --,
   {{0x64430464,0x3ea90421,0x00000000,0x00000000}},	//   _jeni, ajat_, --, --,
   {{0x394d04a5,0x7eb827c2,0x90e507a9,0xaa460f8c}},	//   _aves_, _lípi, _حسين, веел,
   {{0x6443245b,0x79820035,0x656b0024,0xdb2100fd}},	//   _leni, twow, _oqgh, átás,
   {{0xa2a300b4,0x3eab0187,0x4a530804,0x256b03d0}},	//   गात्, žitá_, ркіс, jøl_,
   {{0x644301f4,0x79820035,0xfce60c06,0x00000000}},	//   _neni, rwow, _рого, --,
   {{0xf6e62b4b,0x00000000,0x00000000,0x00000000}},	//   кцин, --, --, --,
   {{0xd6d7342d,0x7e6400bf,0x7b0300be,0x1beb00ab}},	//   кты_, ngip, lõun, _जुटल_,
   {{0x64433a6d,0x7ae200d5,0x2d9202e9,0x75220036}},	//   _beni, mnot, nvye_, _quoz,
   {{0x64433a6e,0xd90e0609,0xe7ed3893,0x3cf80009}},	//   _ceni, _بیت_, _चुका_, _jkrv_,
   {{0x7d1c3a6f,0x64433a70,0x9f4f037a,0x39491bd8}},	//   _mirs, _deni, ünüz_, šast_,
   {{0x7ae23a71,0x394d3a72,0x7d1c3a73,0x64433a74}},	//   nnot, _yves_, _lirs, _eeni,
   {{0xb35609b9,0x7d1c0223,0x00000000,0x00000000}},	//   ریکا_, _oirs, --, --,
   {{0x64433a75,0x00000000,0x00000000,0x00000000}},	//   _geni, --, --, --,
   {{0x64483a76,0x442e01a2,0x251b0100,0x3ea93a77}},	//   madi, _iff_, _קווא, tjat_,
   {{0x7d1c060e,0x442c00e0,0x41b500b5,0xaf3400d1}},	//   _airs, lcd_, _ممبر, شرفت,
   {{0x644306a8,0x7ae2086d,0x3ea93753,0x5c75081b}},	// [31d0] _yeni, dnot, rjat_, ллат,
   {{0x3e530028,0x64433a78,0x628f0223,0x64483a79}},	//   ệt_, _xeni, ldco, nadi,
   {{0x442e3a7a,0x5a351a1c,0xfc30211f,0xa2c706fe}},	//   _mff_, гнет, تحق_, ासप्,
   {{0x64483a7b,0x941502b5,0x628f04f4,0xcb090fda}},	//   hadi, אַנד_, ndco, ريشن_,
   {{0x7d1c0052,0x442e0052,0x64483a7c,0x69cd0cc5}},	//   _firs, _off_, kadi, _देखी,
   {{0x64483a7d,0x7c340de9,0x6f1d0345,0x6e2d09c6}},	//   jadi, _верх, _hisc, lcab,
   {{0xab843a7e,0xccf20122,0xb8eb0243,0x8af90095}},	//   _кутк, _לכך_, _लत_, _atəş,
   {{0x6e2d3a7f,0xb5fd0029,0x7ae21377,0x38b900e0}},	//   ncab, egša, cnot, _mèri_,
   {{0x6d4d3a80,0x64480183,0x6f1d3a81,0xc867066d}},	//   nsaa, fadi, _misc, _атеи,
   {{0x64483a82,0x6f1d3a83,0x644301f4,0x6d4d3a84}},	//   gadi, _lisc, _qeni, isaa,
   {{0x64433a85,0x32460c06,0x628f0223,0x2cb10207}},	//   _veni, ленг, fdco, _mozd_,
   {{0x64433a86,0x68ed0082,0x6d4d3a87,0x6f1d3a88}},	//   _weni, éadf, ksaa, _nisc,
   {{0x64433a89,0x645c1423,0x64483a8a,0x442c3a8b}},	//   _teni, óric, badi, bcd_,
   {{0x6f1d0082,0x64430249,0x6d4d053e,0xa3d42207}},	//   _aisc, _ueni, dsaa, _सेव_,
   {{0x1fb5254c,0xd36e004f,0x7d1c01ef,0xbd0201ef}},	//   астр, _فهو_, _rirs, ñémo,
   {{0x6d4d053e,0x63bc0c61,0x7d1c3a8c,0xd6d90035}},	//   fsaa, ørne, _sirs, nił_,
   {{0xed5700c9,0x7ae228d2,0x7e643a8d,0x7d1c00bf}},	// [31e0] лот_, vnot, rgip, _pirs,
   {{0x6f1d3a8e,0x28b80632,0x7ff6004f,0x7ae23a8f}},	//   _eisc, _अवधि, _مسجا, wnot,
   {{0x7d1c3a90,0x7ae23a91,0xad9b00de,0xf4250083}},	//   _virs, tnot, _ayúd, _মজার_,
   {{0x64480912,0x7d1c033b,0xeafa01b2,0x1dd50099}},	//   zadi, _wirs, ررات_, _ठेवत,
   {{0x7d1c3a92,0x2d8402e1,0x99dd01ba,0xd83800ee}},	//   _tirs, _ème_, _peňa, _anča_,
   {{0x7ae23a93,0x64483a94,0x2cb108b7,0x7d1c01da}},	//   snot, xadi, _gozd_, _uirs,
   {{0x64483a95,0x9cd702b8,0xe3a721a0,0xa2c701c0}},	//   vadi, _עולה_, _ار_, ासम्,
   {{0x64483a96,0x65aa0274,0x6f1d0d9a,0xe6660185}},	//   wadi, етог_, _xisc, утко,
   {{0x64483a97,0xceb3011d,0x442c3a98,0x00000000}},	//   tadi, מיה_, tcd_, --,
   {{0x65603a99,0x33742e14,0x297b016b,0xe9d73a9a}},	//   rumh, агор, _אטמא, _ску_,
   {{0x64483a9b,0x442c00e0,0xd6d90035,0x442e3a9c}},	//   radi, rcd_, bił_, _vff_,
   {{0x64483a9d,0x291e3a9e,0x6d4d0345,0x26110825}},	//   sadi, _hita_, ysaa, देही_,
   {{0x6f1d32b0,0x291e3a9f,0x64483aa0,0x442e3aa1}},	//   _risc, _kita_, padi, _tff_,
   {{0x64481505,0x43940382,0x93f5013b,0x00000000}},	//   qadi, _вакс, çəcə, --,
   {{0x291e3aa2,0x40340421,0x889b016b,0x628d009e}},	//   _mita_, сесс, עבלי, _taao,
   {{0x6d4d3aa3,0x291e3aa4,0xf1a7107b,0x35d90066}},	//   tsaa, _lita_, _брон, _बेड़,
   {{0x6d4d013a,0x2d580352,0x2cb10009,0x272a3aa5}},	// [31f0] usaa, лить_, _pozd_, _lùn_,
   {{0x6d4d3aa6,0x6e2d3aa7,0x291e2379,0x5fd60035}},	//   rsaa, scab, _nita_, _डेवल,
   {{0x6d4d3aa8,0x6f1d3aa9,0x711a0d85,0xbc071583}},	//   ssaa, _tisc, _שותפ, учай,
   {{0x6f1d004f,0x291e3aaa,0x69cb3236,0x224b01ff}},	//   _uisc, _aita_, tzge, nack_,
   {{0x18693aab,0x68450009,0x4ab6018d,0x291e3aac}},	//   вали_, анла, _अकरव, _bita_,
   {{0xd6d9004e,0x2d991111,0x272a0023,0xbebb0345}},	//   wił_, _irse_, _bùn_, _diëe,
   {{0x291e3aad,0xa3d400b4,0x00000000,0x00000000}},	//   _dita_, _सेल_, --, --,
   {{0xca480514,0x272a00f1,0x291e3aae,0x2b5c0355}},	//   _ملفه_, _dùn_, _eita_, ávce_,
   {{0x291e3aaf,0x7afb3ab0,0x00000000,0x00000000}},	//   _fita_, _ikut, --, --,
   {{0xa50903fa,0x04b5195c,0xd6d90035,0x67d508d9}},	//   ђена_, рсия, sił_, _козу,
   {{0x645c03e6,0x7afb030d,0xd6d90067,0x7ae90185}},	//   ória, _kkut, pił_, _kjet,
   {{0x95d900c3,0xb60503ab,0x8c1a00a5,0x60d7026e}},	//   _идет_, _pišč, כותי, _amxm,
   {{0x261106bc,0x7afb0657,0x7ae901f4,0xd176005f}},	//   देशी_, _mkut, _mjet, шыны,
   {{0x7ae9029d,0x6ac239f2,0x7eb801f7,0x99dd0168}},	//   _ljet, _शत्र, _lípt, _leňo,
   {{0x7afb39a7,0x2d99300e,0x7ae90355,0x32090107}},	//   _okut, _arse_, _ojet, _ezay_,
   {{0x5de60dee,0x7ae90055,0x7afb3ab1,0xb6051704}},	//   ажба, _njet, _nkut, _tišč,
   {{0xf8c5112b,0x1c460721,0xa2a30edf,0x30760009}},	// [3200] वसाय, инам, गार्, _кунс,
   {{0x7ae93ab2,0x91bb00a5,0x3b960274,0x00000000}},	//   _ajet, _סמיי, ијет, --,
   {{0x0c7900c7,0x2d8b0382,0x8fa63ab3,0x60dc05dd}},	//   ысты_, _esce_, _тане, mirm,
   {{0x2bda02cb,0x291e3ab4,0x78a1021e,0x60dc033e}},	//   _येणा, _sita_, _anlv, lirm,
   {{0xa2c701d1,0x7ae9029d,0x3f9a3485,0x7eb808bf}},	//   ासत्, _djet, _hrpu_, _dípt,
   {{0xa2d60864,0x60dc3ab5,0x7afb001c,0xd8f700d4}},	//   मोत्, nirm, _ekut, анії_,
   {{0x291e3ab6,0x3cf50099,0x7ae90031,0x69d600b4}},	//   _vita_, ्तरे_, _fjet, _मेरी,
   {{0x12c100c8,0x7ae903b4,0x7eb8006c,0x60dc3ab7}},	//   _উদ্দ, _gjet, _típu, hirm,
   {{0x291e3ab8,0x2bda00a1,0xa2aa0808,0xe4a61108}},	//   _tita_, _येता, टान्, арно,
   {{0xd49a13a1,0x291e002d,0xdd010009,0xe90500cc}},	//   три_, _uita_, đuće, _tượ,
   {{0x60dc027b,0x92953ab9,0x224b3aba,0x00000000}},	//   dirm, банц, tack_, --,
   {{0x63ba3abb,0x81c300ea,0xdbd40098,0x00000000}},	//   rytn, ņēmi, _núío, --,
   {{0x60dc3abc,0x20b4045c,0xd5340a86,0x63ba00d5}},	//   firm, ुसंध, _افتخ, sytn,
   {{0x7c3b0129,0x26c6006d,0x55bb00a5,0x224b02b1}},	//   _đuro, _hloo_, _במדו, sack_,
   {{0x23270500,0xb5e800c8,0xd43702b5,0xc5e80033}},	//   _који_, _পরিচ, _דרוק_, _পরিপ,
   {{0xa2d600b4,0x60dc01a6,0x61ed01d7,0x67280118}},	//   मोद्, airm, _txal, _mudj,
   {{0x60dc0453,0x67280124,0x7ae93abd,0x32090225}},	// [3210] birm, _ludj, _rjet, _uzay_,
   {{0x7afb0865,0x7ae9029d,0x60dc3abe,0x67280223}},	//   _skut, _sjet, cirm, _oudj,
   {{0x443e02c9,0x68f83abf,0x7ae90031,0x7d0e0069}},	//   ibt_, dovd, _pjet, _dhbs,
   {{0x21290ac8,0x8f9a00a5,0x66e80355,0x00000000}},	//   _kuah_, _עירי, děko, --,
   {{0x7ae93ac0,0x212900e7,0x7c871b50,0x224901ed}},	//   _vjet, _juah_, _куве, _meak_,
   {{0xe8f83ac1,0x67283ac2,0x443e00d7,0xb4d50066}},	//   алі_, _budj, jbt_, _सगे_,
   {{0x7ae9071f,0xdced0187,0x8aa73ac3,0x7b0300be}},	//   _tjet, ntač, _крад, nõuk,
   {{0x7afb0af0,0x7ae93ac4,0x443e3ac5,0x645c0093}},	//   _ukut, _ujet, ebt_, órin,
   {{0x60dc00a8,0x2eaa0070,0x00000000,0x00000000}},	//   yirm, רשפּ, --, --,
   {{0x7af90051,0x60dc01ef,0xdced00ac,0x7b2c027b}},	//   lowt, xirm, ktač, _oğul,
   {{0x80ab0c67,0xdced0009,0x60dc00c1,0x67283ac6}},	//   ञाने, jtač, virm, _gudj,
   {{0x21291201,0x1b7a0070,0x799b027c,0xe1ff0138}},	//   _buah_, נטרע, _kruw, rgón_,
   {{0x60dc3ac7,0x443e022a,0x22493176,0xd36e00f8}},	//   tirm, bbt_, _deak_, وهی_,
   {{0x7af93ac8,0xdce40009,0x753b3ac9,0x00000000}},	//   howt, mtić, mpuz, --,
   {{0xe29a1646,0xbea62399,0x60dc3aca,0x4f953acb}},	//   _бай_, бавк, rirm, орту,
   {{0xc2463acc,0x2a6d01e8,0x60dc3acd,0x00000000}},	//   _уник, _nceb_, sirm, --,
   {{0x6da309b5,0x60dc3ace,0x62863acf,0x93bc00af}},	// [3220] пита, pirm, meko, scăt,
   {{0x30860037,0x00000000,0x00000000,0x00000000}},	//   _الدف, --, --, --,
   {{0x202900a0,0x799b0027,0x04da016b,0x00000000}},	//   átiť_, _aruw, נקעל, --,
   {{0x799b3ad0,0x24850110,0xdce40207,0x67280207}},	//   _bruw, helm_, ktić, _rudj,
   {{0x6728029d,0x6f043ad1,0x38cb00d1,0xdce40009}},	//   _sudj, mlic, گانی_, jtić,
   {{0x62863ad2,0x799b00e0,0x67283ad3,0x00000000}},	//   heko, _druw, _pudj, --,
   {{0x68f80484,0x38cb02fd,0x62863ad4,0x6f042c7b}},	//   rovd, دانی_, keko, olic,
   {{0x2bb5009a,0x6286029d,0x6f0402c9,0xa5343ad5}},	//   ंहरा, jeko, nlic, онич,
   {{0x645c0370,0x6f043ad6,0x62863ad7,0xceb40095}},	//   ório, ilic, deko, mməd_,
   {{0x6728006c,0x6f0401ae,0x2129046a,0x443e033b}},	//   _tudj, hlic, _ruah_, ubt_,
   {{0x6f043ad8,0x443e3ad9,0x236500f4,0x22493ada}},	//   klic, rbt_, gulj_, _peak_,
   {{0xd5a402fd,0x62860b3c,0xbc1b0070,0xe2f901e0}},	//   _ولای, geko, טויש, ремі_,
   {{0x6f043adb,0x7ae32b83,0xc05b00d4,0x6f1600ac}},	//   dlic, énti, лів_, dmyc,
   {{0xf6170122,0xd3a624c1,0x2eb30bad,0x22493adc}},	//   _החדש_, _грип, ीस्त, _weak_,
   {{0x6f043add,0xf4870919,0x62863ade,0x6722034d}},	//   flic, _دانی, beko, _kioj,
   {{0x6f043adf,0x21293ae0,0x66020273,0x645800e2}},	//   glic, _tuah_, _kyok, _hdvi,
   {{0xdced3ae1,0xd04e00a8,0x22640097,0x67220384}},	// [3230] stač, hibə, šské_, _mioj,
   {{0x644a3ae2,0x660200d5,0x0ba702ee,0x00000000}},	//   _jefi, _myok, йшем, --,
   {{0x6f04325c,0x6602001c,0x6d46009f,0x799b027c}},	//   blic, _lyok, _ewka, _sruw,
   {{0x799b3ae3,0x99990b25,0xdea10118,0x6602030d}},	//   _pruw, икет_, _تیری, _oyok,
   {{0x64580169,0xd8250204,0x66023ae4,0x00000000}},	//   _odvi, одли, _nyok, --,
   {{0x47590021,0x62863ae5,0x98a2029f,0xdce40009}},	//   ария_, zeko, дише, vtić,
   {{0xe7390086,0x66023ae6,0x62863ae7,0x16a91218}},	//   шей_, _ayok, yeko, ивки_,
   {{0x2ee90297,0x64580b93,0x628601a3,0x66023ae8}},	//   nnaf_, _advi, xeko, _byok,
   {{0x62863ae9,0x644a1b5f,0xb88301ba,0x785b00ea}},	//   veko, _befi, _príč, tāvē,
   {{0x6f043aea,0x753b3aeb,0xdce400cd,0x644a1904}},	//   zlic, rpuz, rtić, _cefi,
   {{0x62863aec,0xdce40a78,0x6498004b,0xc20900a5}},	//   teko, stić, стыр_, _סה_,
   {{0x24850dbc,0x64583aed,0x672202d7,0x00000000}},	//   selm_, _edvi, _gioj, --,
   {{0x34953aee,0x412a0f9e,0x644a01ef,0xe56e0036}},	//   _мадр, рого_, _fefi, _юз_,
   {{0x644a37c5,0xa06a04bf,0x6ab625de,0x7e7d01ae}},	//   _gefi, јава_, _अक्र, _absp,
   {{0x64413aef,0x6f0402bf,0x68e4004f,0x62863af0}},	//   mbli, tlic, éidi, peko,
   {{0xee3a3af1,0x752302c9,0xf4120122,0x20040228}},	//   рна_, _hinz, _קפה_, āmi_,
   {{0x6f043af2,0x764b006c,0x5d6a10be,0x75233af3}},	// [3240] rlic, _megy, ризм_, _kinz,
   {{0x764b0332,0x64413af4,0x75233af5,0x7c650037}},	//   _legy, nbli, _jinz, كامل,
   {{0x61fb0484,0x75233af6,0x25bf028b,0xfb8a0009}},	//   żult, _minz, hyul_, рбек_,
   {{0x764b3af7,0x7c291505,0x59db0354,0xbebb0298}},	//   _negy, _şert, _मेहर, _hiën,
   {{0x67223af8,0x44270103,0x7c2d0098,0x00000000}},	//   _rioj, _ogn_, íorú, --,
   {{0x764b0185,0x44273af9,0x25bf0f3a,0x25fd0066}},	//   _aegy, _ngn_, dyul_, _लड़ी_,
   {{0x752b0009,0x764b1123,0x68ed0037,0x64413afa}},	//   _augz, _begy, éada, dbli,
   {{0x35b41d6b,0x644a3afb,0x44270f0a,0xd04e0095}},	//   збир, _sefi, _agn_, ribə,
   {{0xd04e01c2,0x94aa2dc1,0x2db702b5,0x2cb8007c}},	//   sibə, атна_, ַלטן_, _kord_,
   {{0x75233afc,0x2cb802df,0x7c3b02c4,0x64413afd}},	//   _cinz, _jord_, _đurk, gbli,
   {{0x2cb83afe,0x44273aff,0x644a0093,0x764b00b5}},	//   _mord_, _dgn_, _vefi, _fegy,
   {{0x752302bf,0x04fc00c8,0x4427008c,0x26cd3b00}},	//   _einz, ীদের_, _egn_, cheo_,
   {{0x64413b01,0x75233b02,0x66de00ea,0x2cb803bc}},	//   bbli, _finz, lūko, _oord_,
   {{0x2cb803d0,0x64580022,0x44270282,0x644a0207}},	//   _nord_, _udvi, _ggn_, _uefi,
   {{0x5f940036,0x00000000,0x00000000,0x00000000}},	//   мирт, --, --, --,
   {{0x442702a2,0x7e7d195f,0x00000000,0x00000000}},	//   _zgn_, _qbsp, --, --,
   {{0x2cb83b03,0x7523159c,0x00000000,0x00000000}},	// [3250] _bord_, _yinz, --, --,
   {{0x75233b04,0x44270051,0xf1bf02d7,0x2cb83b05}},	//   _xinz, _xgn_, scás_, _cord_,
   {{0xfe70006c,0xd0f80324,0x00000000,0x00000000}},	//   عدہ_, ंकरण_, --, --,
   {{0x6ffa00a5,0x00000000,0x00000000,0x00000000}},	//   _להתפ, --, --, --,
   {{0x6441001e,0x98a50210,0x2cb83b06,0x673a0282}},	//   ybli, зиле, _ford_, _attj,
   {{0x3eb93b07,0x23ca0efa,0x752b3b08,0x00000000}},	//   _host_, ानाद, _rugz, --,
   {{0x3eb91d8b,0x44273b09,0x26cd3b0a,0x8ae701e0}},	//   _kost_, _rgn_, theo_, _діал,
   {{0xc987093b,0x75231cf5,0x4427013a,0xa7fc0448}},	//   _музи, _sinz, _sgn_, _acıs,
   {{0x3eb90052,0x9555004f,0x644106c3,0x764b006c}},	//   _most_, أخبا, tbli, _vegy,
   {{0xe733004f,0x3eb900a5,0x64413b0b,0x26cd02d7}},	//   _قصص_, _lost_, ubli, sheo_,
   {{0xe29a3b0c,0xf770004f,0x3eb93b0d,0x7aeb0019}},	//   бан_, _لان_, _oost_, ongt,
   {{0x29073b0e,0x75233b0f,0x64413b10,0x3eb90228}},	//   llna_, _winz, sbli, _nost_,
   {{0x2611045c,0x59bd0ac4,0x44270d9a,0x75233b11}},	//   देखी_, ्निर, _tgn_, _tinz,
   {{0x97423b12,0x659a1899,0x859a00a5,0x057400f8}},	//   šćen, _לינק, _לשנו, _زاهد,
   {{0x3f57048c,0x3eb93b13,0x273101ba,0x8fa3315d}},	//   għu_, _bost_, _ján_, наре,
   {{0x63bc017b,0x7e6d2988,0x27310093,0x3eb93b14}},	//   ärne, ggap, _mán_, _cost_,
   {{0x2731128e,0x2ee000b9,0x62960cca,0x4d66010b}},	// [3260] _lán_, riif_, _iayo, якав,
   {{0x6296383a,0x273100e2,0x3dd20067,0x00000000}},	//   _hayo, _oán_, rzyw_, --,
   {{0x3eb93b15,0x62963b16,0x09c41371,0x26dd01a8}},	//   _fost_, _kayo, वन्य, _omwo_,
   {{0x2cb80122,0x3eb93b17,0x2fc50c71,0xfe4200b5}},	//   _word_, _gost_, ølge_, _سکری,
   {{0xe894311c,0x62963b18,0x200e0124,0x2cb83913}},	//   даль, _mayo, šlić_, _tord_,
   {{0x273100e8,0x6d56022e,0x62963b19,0x25a03b1a}},	//   _bán_, msya, _layo, _šilo_,
   {{0xd6da2830,0x273101a5,0x6d56022e,0xaa462dc1}},	//   йти_, _cán_, lsya, _невл,
   {{0x7c3b1269,0x27313b1b,0x987802c6,0x62963b1c}},	//   _đuri, _dán_, _išči_, _nayo,
   {{0x6d563b1d,0x7ae23b1e,0xa3d40324,0x49ca0763}},	//   nsya, miot, _सेज_, _улан_,
   {{0x7ae23b1f,0x629600a7,0x38c80416,0x2731104b}},	//   liot, _aayo, _باری_, _fán_,
   {{0x62963b20,0x6d560ec0,0x78a8221b,0xd91b02b5}},	//   _bayo, hsya, _indv, _פובל,
   {{0xddc40029,0x629601a2,0x78ba021d,0xf6d6103b}},	//   maiņ, _cayo, _hotv, _عزاد,
   {{0x64a63b21,0x62962487,0x3eb93b22,0x78ba0097}},	//   _нада, _dayo, _rost_, _kotv,
   {{0x760b00c2,0x7ae230af,0xc8be3b23,0x3eb90036}},	//   _פּאַ, hiot, ्सिट, _sost_,
   {{0x3eb93b24,0x62963b25,0x20050093,0x78ba3b26}},	//   _post_, _fayo, æli_, _motv,
   {{0x62963b27,0x7ae201ed,0x00000000,0x00000000}},	//   _gayo, jiot, --, --,
   {{0x7e6d3b28,0xa2aa3b29,0xad9b219d,0x00000000}},	// [3270] rgap, टार्, _azúr, --,
   {{0x2a7f028b,0xb0350340,0x62963499,0xddd600fd}},	//   _sbub_, _юнош, _zayo, ggyő,
   {{0xa3e202e4,0x62960186,0x316c0035,0x00000000}},	//   _नेम_, _yayo, ądze_, --,
   {{0x6d563b2a,0xd8380359,0x27313b2b,0xd6c6186e}},	//   bsya, _afč_, _rán_, _شق_,
   {{0x78ba0009,0x273100cc,0xa91d005f,0x00000000}},	//   _botv, _sán_, _apža, --,
   {{0x27310237,0xf77129fe,0x00000000,0x00000000}},	//   _pán_, ناب_, --, --,
   {{0xb9050084,0x78ba00ac,0x690d0042,0x00000000}},	//   _पग_, _dotv, búen, --,
   {{0x7ae23b2c,0x78a801b4,0x2a7f012f,0xe55903fa}},	//   ciot, _endv, _ubub_, ојој_,
   {{0x62963b2d,0x782706ca,0xbbdd1e18,0x2d9f00ac}},	//   _rayo, _فعال, _मधुक, _šuej_,
   {{0x62963b2e,0x27313b2f,0x78ba0526,0xddc43426}},	//   _sayo, _tán_, _gotv, ngiš,
   {{0x68e3032b,0x6abb0088,0xb4cd052f,0x6aa903d0}},	//   mind, _kouf, _रती_, _knef,
   {{0x91e6315d,0x6abb00f6,0x00000000,0x00000000}},	//   доме, _jouf, --, --,
   {{0x6abb00f6,0x00000000,0x00000000,0x00000000}},	//   _mouf, --, --, --,
   {{0x62963b30,0xf99200a5,0x6abb00a2,0x92de0033}},	//   _wayo, דרך_, _louf, তকে_,
   {{0x62963b31,0x1eaa02fd,0x6aa912ba,0x2ec90569}},	//   _tayo, ياري_, _onef, रसूत,
   {{0x68e33b32,0x7ae201ef,0x7c290139,0x00000000}},	//   hind, xiot, _şerp, --,
   {{0x7ae23b33,0x00000000,0x00000000,0x00000000}},	// [3280] viot, --, --, --,
   {{0x6aa91dfb,0x6d563b34,0x3cfa004e,0x69c20054}},	//   _anef, rsya, ्तें_, vyoe,
   {{0x68e33b35,0xb4fa02b5,0x6abb00f7,0x7ae23b36}},	//   dind, קלער, _bouf, tiot,
   {{0x6d56011e,0x78ba0097,0x6abb3b37,0x00000000}},	//   psya, _sotv, _couf, --,
   {{0x68e33b38,0x78ba06fe,0x7ae23b39,0xe8fa0f08}},	//   find, _potv, riot, олд_,
   {{0x68e33b3a,0x7ae327c2,0x6aa93b3b,0x97a63b3c}},	//   gind, éntr, _enef, дрил,
   {{0xf76f0071,0x2a7d01e8,0xad9b006c,0x7ae2081b}},	//   لاي_, bfwb_, _nyúj, piot,
   {{0x6abb00a2,0x656d01ba,0x00000000,0x00000000}},	//   _gouf, _ťaha, --, --,
   {{0x68e33b3d,0x99dd00ee,0x78ba021d,0x00000000}},	//   bind, _beňu, _totv, --,
   {{0x68e33b3e,0x6abb0355,0x78a82c68,0x7b2c0139}},	//   cind, _zouf, _undv, _eşue,
   {{0x98ad0207,0x00000000,0x00000000,0x00000000}},	//   _steć_, --, --, --,
   {{0x25a90169,0xe76900fd,0x00000000,0x00000000}},	//   _šale_, _رحمن_, --, --,
   {{0x98a40160,0x471b025a,0x00000000,0x00000000}},	//   _gumă_, _וואג, --, --,
   {{0x660f01ae,0x3cfa0035,0x00000000,0x00000000}},	//   ücke, ्तों_, --, --,
   {{0xcebb0274,0x2cad00f4,0x00000000,0x00000000}},	//   оља_, _đed_, --, --,
   {{0x68e33b3f,0x00000000,0x00000000,0x00000000}},	//   zind, --, --, --,
   {{0x68e33b40,0x9d153b41,0xa3e21ef5,0xdcfd00ec}},	// [3290] yind, едач, _नेत_, _apsā,
   {{0x6abb1afc,0x68e33b42,0xee3f00a0,0xa2c70099}},	//   _souf, xind, _iným_, ासक्,
   {{0xa2d61bc6,0xf09200a5,0x6abb3b43,0x00000000}},	//   मोक्, _גני_, _pouf, --,
   {{0x68e33b44,0x6fae000c,0x00000000,0x00000000}},	//   wind, ीहरू, --, --,
   {{0x13ca0907,0xb5fd02c4,0x690d01ef,0x66e80355}},	//   ानुभ, ngšt, búel, něku,
   {{0x7b0300ab,0x3f87021d,0x00000000,0x00000000}},	//   tõus, _ânus_, --, --,
   {{0x68e33b45,0x6abb3b46,0x98a400af,0x00000000}},	//   rind, _touf, _sumă_, --,
   {{0x68e33b47,0x6aa902d7,0xf1ca00ee,0x00000000}},	//   sind, _unef, _hráš_, --,
   {{0x68e304be,0x3209010d,0x00000000,0x00000000}},	//   pind, _nyay_, --, --,
   {{0x974201cc,0x68e33687,0x00000000,0x00000000}},	//   šćan, qind, --, --,
   {{0x32091a22,0x28ac252b,0xe29a1813,0x2905007a}},	//   _ayay_, चारि, пан_, _ikla_,
   {{0xd0550095,0xdce401d6,0xe29a3b41,0x63bc01ff}},	//   mizə, ktiğ, чам_, ärna,
   {{0x25e600dc,0xa2d600b4,0xf1e000b4,0x26cf3b48}},	//   _जेपी_, मोग्, _पेशन, _ilgo_,
   {{0x657b08c7,0x26050067,0x00000000,0x00000000}},	//   mtuh, _हुयी_, --, --,
   {{0x657b3b49,0x3f1603e6,0x394d0107,0x99dd00fe}},	//   ltuh, еќат, _lwes_, _keňs,
   {{0x52760369,0x670f04aa,0x00000000,0x00000000}},	//   _чуку, ातिक_, --, --,
   {{0x25790c1f,0x7c3b0095,0x657b3b4a,0x2bec0083}},	// [32a0] nèl_, _şura, ntuh, _করেই_,
   {{0xe189132d,0xfa150033,0x00000000,0x00000000}},	//   _آئين_, িশাল_, --, --,
   {{0x2252010d,0x612b007a,0x25793b4b,0x00000000}},	//   _keyk_, _iżla, hèl_, --,
   {{0x657b11e9,0x68e100e5,0x29053b4c,0x00000000}},	//   ktuh, _amld, _akla_, --,
   {{0x28ac06bb,0x28be0461,0x19943b4d,0x62843b4e}},	//   चालि, ्सलि, таля, _mbio,
   {{0x26cf2140,0x257902e9,0xd90d03c5,0x657b011e}},	//   _algo_, dèl_, قیق_, dtuh,
   {{0x5694225d,0x662500a8,0x62843b4f,0x6d443b50}},	//   вайт, ərkə, _obio, lpia,
   {{0xd6d70086,0x2905021e,0x20d400be,0x25790951}},	//   еть_, _ekla_, _häid_, fèl_,
   {{0x63a3002a,0x88860b46,0x6d443b51,0xa9672a7c}},	//   _arnn, _плаж, npia, _пита_,
   {{0x20d400ab,0x6d4400c7,0x00000000,0x00000000}},	//   _jäid_, ipia, --, --,
   {{0x6284009e,0xdce40207,0xe2f90185,0x00000000}},	//   _bbio, ntiđ, дені_, --,
   {{0x28a400ab,0x00000000,0x00000000,0x00000000}},	//   _गोति, --, --, --,
   {{0x6eba0af6,0xe298010b,0xc68f00b5,0x00000000}},	//   _एकजु, хаў_, _دِن_, --,
   {{0x2ec90266,0x62840051,0xb5fd02c4,0xe8170067}},	//   रस्त, _ebio, rgšt, धेका_,
   {{0x442e3b52,0x43943a69,0x00000000,0x00000000}},	//   _igf_, _райс, --, --,
   {{0xdce401d6,0x6e9400af,0xceb4013b,0x00000000}},	//   ttiğ, лису, smən_, --,
   {{0xb8160083,0x8c670036,0x6d443b53,0x00000000}},	// [32b0] াশিত_, етед, gpia, --,
   {{0x629d3b54,0x62840035,0x00000000,0x00000000}},	//   ldso, _zbio, --, --,
   {{0x37e50083,0x6d4400e7,0xdce40225,0x00000000}},	//   _পুনর, apia, stiğ, --,
   {{0x25790c1f,0x7b2c01d6,0x29050187,0x394d010d}},	//   yèl_, _ağus, _skla_, _pwes_,
   {{0x7bc50b0e,0x09bd021a,0x802703fc,0x6f0d3b55}},	//   syhu, ्नेय, _ترکم, mlac,
   {{0x6f0d3b56,0x25790c1f,0x013832e3,0x00000000}},	//   llac, vèl_, ערות_, --,
   {{0x628f0a1e,0x6f0d04e6,0xb0660282,0x00000000}},	//   keco, olac, _hjää, --,
   {{0x25793b57,0x442e08c8,0xd0550095,0x6f0d3b58}},	//   tèl_, _agf_, rizə, nlac,
   {{0x629d001e,0x98a400c7,0x6f0d0051,0x394d01cb}},	//   ddso, _sumą_, ilac, _uwes_,
   {{0x6f0d3b59,0xa3e2007c,0x257902e9,0x66e70107}},	//   hlac, _नेह_, rèl_, _bèkè,
   {{0x657b3b5a,0x6f0d3b5b,0x25fd0722,0x443c002a}},	//   stuh, klac, _लडकी_, _dfv_,
   {{0x2d4f006a,0x81dd0083,0x6f0d01ba,0x02cc112b}},	//   kże_, _তুই_, jlac, ासेन,
   {{0x69d93b5c,0x76493b5d,0x6f0d3b5e,0x00000000}},	//   nzwe, mbey, dlac, --,
   {{0x442e033b,0x614310be,0x6f0d3b5f,0x672b0055}},	//   _ggf_, рера, elac, _higj,
   {{0xb4cd0907,0x6d44001e,0x2252010d,0x44210023}},	//   रसी_, wpia, _teyk_, _àh_,
   {{0x628f2fe9,0x76491008,0x4374052c,0x7b2c00a8}},	//   ceco, nbey, _сушт, _oğur,
   {{0xed5700c9,0xf65202b5,0x65690cca,0x672b3b60}},	// [32c0] кот_, יצן_, nreh, _migj,
   {{0x6f0d148b,0x672b01d2,0xa3c80243,0xb8210084}},	//   alac, _ligj, लैक_, मधाम_,
   {{0x6f0d3b61,0xd8380254,0x7989002f,0x78ae0392}},	//   blac, _jače_, _apew, _òbvi,
   {{0x6d440945,0xd946294d,0xa96a0210,0x6f0d0341}},	//   ppia, веди, дида_, clac,
   {{0xd9100164,0xda65063d,0x69d90051,0xdce400f4}},	//   میر_, طاني, gzwe, stiđ,
   {{0x8c433b62,0x65693b63,0x7d070118,0x7b2c0395}},	//   _вере, dreh, _gkjs, _eşua,
   {{0xfce327e9,0x20d400ab,0x00000000,0x00000000}},	//   _торо, _käib_, --, --,
   {{0x25a93b64,0x6f0407a6,0x2ef2016e,0x00000000}},	//   _šala_, noic, nnyf_, --,
   {{0x80d300c8,0x628f3b65,0x65693b66,0x672b054f}},	//   _সদস্, veco, greh, _digj,
   {{0x394621a4,0xdce43b67,0x81b80033,0x6f0d3b68}},	//   mpos_, krič, চনা_, zlac,
   {{0xdced0129,0x39461406,0xd4971397,0x6f0d3b69}},	//   stać, lpos_, тры_, ylac,
   {{0x290e001e,0xdce40169,0x20d400be,0x00000000}},	//   llfa_, drič, _näib_, --,
   {{0x628f3b6a,0x629d3b6b,0x6f0d0506,0x6f0400d7}},	//   reco, rdso, vlac, doic,
   {{0x394609ab,0xa2c700b8,0xdce433a5,0xd3a6002d}},	//   ipos_, ासङ्, frič, _арип,
   {{0x4fc43b6c,0x6f0d3b6d,0xdce40009,0xd838003d}},	//   аста, tlac, grič, _gače_,
   {{0x6f0d01a6,0xb27500c3,0x3d953b6e,0x0b140033}},	//   ulac, _слиш, либр, িদুল_,
   {{0x6f0d3b6f,0x27383b70,0x1be80d2a,0xddc60359}},	// [32d0] rlac, _lén_, _टेबल_, _lekņ,
   {{0xdce4055f,0x2605007c,0xe7e3007c,0x00000000}},	//   brič, _हँसी_, _कइला_, --,
   {{0x6f0d3b71,0x27380019,0x09bd0b35,0x273102a7}},	//   plac, _nén_, ्न्य, _kšne_,
   {{0x69d902c9,0x25a607c0,0x6f0401ef,0x6d5d0160}},	//   tzwe, _orol_, coic, _tvsa,
   {{0x998515f4,0x39460e5b,0xe9ab00ce,0xa9690009}},	//   التو, gpos_, بدان_, хила_,
   {{0xd91400d8,0x69d93b72,0x27383b73,0x660b008c}},	//   адчы, rzwe, _bén_, _rygk,
   {{0x66e5002d,0x27380082,0xe81e1ef5,0x69d902b1}},	//   лока, _cén_, येला_, szwe,
   {{0x6569006c,0x386904d4,0x3946006d,0x25a60088}},	//   treh, şar_, bpos_, _brol_,
   {{0x273801e4,0x3a3f0176,0x672b0055,0x76491008}},	//   _eén_, _ifup_, _vigj, rbey,
   {{0x7b2c0716,0x65693b74,0x27383b75,0xd8380124}},	//   _uğur, rreh, _fén_, _pače_,
   {{0x03260b5e,0x42ea3b76,0x25a60225,0x00000000}},	//   лдон, емно_, _erol_, --,
   {{0x6d4102dd,0x65693b77,0x61463b78,0x216a02ce}},	//   _član, preh, лема, ними_,
   {{0x7d050031,0xca7a0070,0xd4690043,0x09b5016b}},	//   kohs, ענשט, _зиле_, נפֿט_,
   {{0xdce43b79,0x27380118,0x19b600a5,0x00000000}},	//   trič, _yén_, אפשר_, --,
   {{0x2d993b7a,0xf4560319,0x2d8b3b7b,0x22590065}},	//   _asse_, _עיקר_, _apce_, bask_,
   {{0x944200b5,0x00000000,0x00000000,0x00000000}},	//   _پھین, --, --, --,
   {{0x6f04053f,0x3dc90430,0xac86005f,0xceb400a8}},	// [32e0] roic, gyaw_, лгал, lmək_,
   {{0xdce4129f,0x6ea4193c,0x5b3600af,0x00000000}},	//   prič, _चोरु, гэду, --,
   {{0x2d9900c9,0xe7e30429,0x3dc9010d,0x160a0066}},	//   _esse_, _केला_, ayaw_, _हुनर_,
   {{0x39460159,0xa3c80084,0x316004c3,0x2d860279}},	//   tpos_, लैट_, _kviz_, çoes_,
   {{0x9f060332,0xaa570c74,0xb277016b,0x8277016b}},	//   _لوگو, الها_, רענג_, רענע_,
   {{0x307a02b5,0xceb4013b,0xfce60279,0x00000000}},	//   גאַנ, kmək_, _сого, --,
   {{0xb8ec0299,0x39463b7c,0xf72a002d,0x2d8002d4}},	//   _लव_, spos_, нций_, ltie_,
   {{0x3ea03b7d,0x27383b7e,0x25a62314,0x96341761}},	//   ndit_, _vén_, _prol_, шниц,
   {{0x2d803b7f,0xb8ea0083,0xe8fa0f7e,0x00000000}},	//   ntie_, _লগ_, _зла_, --,
   {{0x27383b80,0x3ea03b81,0x394400ee,0x4d7b016b}},	//   _tén_, hdit_, _itms_, עריע,
   {{0xa923053d,0x39440a4e,0x31600395,0xd25100f8}},	//   ížen, _htms_, _aviz_, يند_,
   {{0x57fb0122,0x25a63b82,0x2d803b83,0x26cd02d7}},	//   _אלבו, _trol_, ktie_, ckeo_,
   {{0x22593b84,0xf1ab0037,0x2d800345,0x00000000}},	//   rask_, راحه_, jtie_, --,
   {{0xe7b60033,0x31600260,0x224000e0,0x00000000}},	//   জনীয, _dviz_, _efik_, --,
   {{0x443e036d,0x00000000,0x00000000,0x00000000}},	//   mct_, --, --, --,
   {{0x3dc90159,0xe29f05ee,0xea00055c,0x00000000}},	//   tyaw_, boða_, _arập_, --,
   {{0xdc551b78,0x7d1c009e,0x645a01a3,0x3ef8002d}},	// [32f0] ивањ, _bhrs, oati, унтэ_,
   {{0x443e3b85,0x7d1c009e,0x28a40067,0x00000000}},	//   nct_, _chrs, _गोलि, --,
   {{0x5a352f26,0x2d803b86,0x7d1c0211,0x3dc9010d}},	//   анет, atie_, _dhrs, syaw_,
   {{0x645a3b87,0x3dc90159,0x64a60099,0x2d80009e}},	//   hati, pyaw_, _कोसळ, btie_,
   {{0x2d803b88,0x629f1787,0x50b80a86,0xbebb1192}},	//   ctie_, _maqo, _شدید_, _diët,
   {{0x645a3b89,0xb4c31782,0x20d400ab,0x315800a5}},	//   jati, _एके_, _käia_, ניון_,
   {{0x645a3b8a,0x98a5013a,0x985401e0,0x00000000}},	//   dati, _cilā_, стіш, --,
   {{0x443e002d,0x05653b8b,0x16a90086,0xb4cd0067}},	//   ect_, авин, твии_, रस्_,
   {{0x645a0010,0x63410080,0xe61907e5,0x0576004f}},	//   fati, _mēne, ъди_, لمية_,
   {{0xc4823b8c,0x7aeb3b8d,0x645a3b8e,0x3ea03b8f}},	//   ольк, ligt, gati, zdit_,
   {{0x29073b90,0x69cb3b91,0x86c500f8,0xe3b600af}},	//   mona_, lyge, _پيشن, абэ_,
   {{0x29073b92,0xceb401c2,0x7aeb3b93,0xf7703b94}},	//   lona_, rmək_, nigt, _رام_,
   {{0x443e0298,0xa91d010b,0x00000000,0x00000000}},	//   bct_, _apži, --, --,
   {{0x645a3b95,0x03a50a55,0x29073b96,0xd83802a7}},	//   cati, _вико, nona_, _kača_,
   {{0xb21b054e,0xd8380254,0x7aeb043d,0x7e5616ed}},	//   lfæl, _jača_, kigt, итац,
   {{0x29070008,0xe5190efd,0x3ea03b97,0x59c5175f}},	//   hona_, _नीति_, udit_, वहार,
   {{0x7aeb0626,0x3ea03b98,0xee373b99,0xbebb0298}},	// [3300] digt, rdit_, рну_, _riët,
   {{0x2d803b9a,0xb4c300ab,0x29073b9b,0xfbd211cf}},	//   rtie_, _एको_, jona_, يتا_,
   {{0x2d803b9c,0xa7fc0092,0xad9b002a,0x765b011e}},	//   stie_, _adın, _axúd, kauy,
   {{0x645a3b9d,0x2d803b9e,0x201a01b7,0xdbd000d5}},	//   zati, ptie_, _izpi_, nžér,
   {{0x6926002d,0x3b06008c,0x660f01ae,0xbebb0b88}},	//   амда, rooq_, ückl, _viët,
   {{0x29070955,0x645a3b9f,0x6d463ba0,0xd8380168}},	//   gona_, xati, _itka, _bača_,
   {{0x645a3a79,0xe0b702b5,0x030606bc,0x38cb00ff}},	//   vati, ילסט_, रवाह_, خانی_,
   {{0x645a3ba1,0x79b7006c,0xf10201c0,0xbebb2069}},	//   wati, _چھوڑ_, लकुद_, _hiër,
   {{0x29071810,0x386501d5,0x443e030d,0x4af900af}},	//   bona_, _fdlr_, tct_, _сэря_,
   {{0x29073ba2,0x7982008c,0x6aa23ba3,0x6aa03ba4}},	//   cona_, mtow, ldof, _hamf,
   {{0x645a3ba5,0xb4d60437,0x443e3ba6,0x92592349}},	//   rati, _सती_, rct_, лант_,
   {{0x645a3ba7,0x6d460a78,0x6aa2081f,0xd05c00a8}},	//   sati, _otka, ndof, mirə,
   {{0xc05b0a55,0x7982006a,0x645a3ba8,0x201a01b7}},	//   ків_, ntow, pati, _azpi_,
   {{0x645a0e72,0x41e802fb,0x92e70831,0x00000000}},	//   qati, рфюм_, বকে_, --,
   {{0x251b02b5,0x64580080,0x6d462686,0x79823ba9}},	//   _שווא, _ievi, _atka, htow,
   {{0x64583baa,0x7982004e,0x6d460298,0x6aa0023c}},	//   _hevi, ktow, _btka, _namf,
   {{0x29073bab,0x040b0033,0xbebb0051,0x00000000}},	// [3310] yona_, হেদী_, _siës, --,
   {{0x40950082,0xd05c0095,0x64583bac,0xa11500e0}},	//   _الدر, kirə, _jevi, _دوخت,
   {{0xd00800c9,0x2907290a,0x7aeb3481,0x66d50097}},	//   _веќе_, vona_, tigt, _láka,
   {{0xb4c302e4,0xd05c0095,0x290c00a7,0x68e8001e}},	//   _एक्_, dirə, _akda_, _amdd,
   {{0x29073bad,0x7aeb3bae,0x18690217,0x66d50097}},	//   tona_, rigt, гали_, _náka,
   {{0x64583baf,0x7aeb3bb0,0x270f0d91,0x973c022f}},	//   _nevi, sigt, ात्र_, _grćk,
   {{0x29073bb1,0x79820035,0x4758010b,0x65620328}},	//   rona_, atow, арыя_, _avoh,
   {{0x29073bb2,0x20d403ad,0x6fba035d,0x98a50160}},	//   sona_, _näin_, _उपसं, _bilă_,
   {{0x7ae93bb3,0x273801a5,0x64582172,0x29070b5b}},	//   _imet, _lĩnh_, _bevi, pona_,
   {{0x04b50421,0xa91d010b,0x6aa03bb4,0x64580225}},	//   ссия, _apžv, _zamf, _cevi,
   {{0x7ae902c6,0xd6db0274,0x65600719,0xd90c00b5}},	//   _kmet, _итд_, asmh, _جیو_,
   {{0x78a1362b,0x6aa00176,0x98a50160,0x7afb314a}},	//   _halv, _xamf, _filă_, _jjut,
   {{0x45450071,0x68e80297,0x64a53bb5,0x78a10a09}},	//   _انتق, _ymdd, _гала, _kalv,
   {{0x7afb2209,0x05b8064e,0x6ac400ab,0x64583bb6}},	//   _ljut, _خدمت_, _वक्र, _gevi,
   {{0x66d50076,0x7ae93bb7,0x96db0311,0x64410160}},	//   _záka, _omet, _बताउ, mcli,
   {{0x7982004e,0x7afb3bb8,0x63120033,0x00000000}},	//   ytow, _njut, _সংকট_, --,
   {{0x05a700b4,0x00000000,0x00000000,0x00000000}},	// [3320] कटिब, --, --, --,
   {{0x7ae93bb9,0x7afb3bba,0x6441243e,0x6aa03bbb}},	//   _amet, _ajut, ncli, _samf,
   {{0x7ae90036,0x7e7d00ee,0x7afb00f4,0xa0c60118}},	//   _bmet, _fcsp, _bjut, _نيکو,
   {{0x76591973,0xdbd0053d,0x644100ee,0x291e0124}},	//   _newy, _užív, hcli, _shta_,
   {{0xe3a707a8,0x78a10029,0x6d463bbc,0x3320035f}},	//   _کر_, _balv, _utka, _mhix_,
   {{0x7982004e,0x7ae93bbd,0xd05c0095,0x6cd60206}},	//   rtow, _emet, tirə, _اقسا,
   {{0x64583bbe,0x79823bbf,0xf0930122,0x76590173}},	//   _revi, stow, פנה_, _bewy,
   {{0x64583bc0,0xd6d71ac5,0xe81e0461,0x3ea2014e}},	//   _sevi, йты_, येगा_, _jakt_,
   {{0x7ae328e9,0x3ea23bc1,0x78a100fd,0x00000000}},	//   ënte, _makt_, _falv, --,
   {{0x78a13bc2,0xd49a1056,0x7afb008b,0xe73a00af}},	//   _galv, ури_, _zjut, _беж_,
   {{0x387e19c6,0xa686001f,0x20d400c3,0x2418037c}},	//   _ictr_, _глед, _päin_, роны_,
   {{0x60c50034,0x6443008a,0x7659053e,0x33200160}},	//   _sohm, _efni, _gewy, _chix_,
   {{0x64583bc3,0xa6a900d2,0x673a0051,0x612001ff}},	//   _tevi, _خالق_, _hutj, köld,
   {{0x64a317f9,0x273800e8,0x673a3bc4,0xd8380409}},	//   _нача, _cũng_, _kutj, _mačo_,
   {{0x273801a5,0x673a0443,0xdfd41ad4,0x3ea214aa}},	//   _dũng_, _jutj, поры, _bakt_,
   {{0xfbdf0083,0x273801a5,0x2bac0567,0x00000000}},	//   _বুঝত, _vĩnh_, घटना, --,
   {{0x60c53bc5,0x628d010d,0x673a01f4,0xe1670413}},	// [3330] _tohm, _ibao, _lutj, _ادبي,
   {{0x7ae93bc6,0x273801a5,0xbcfb00f7,0x7afb3bc7}},	//   _smet, _tĩnh_, _evén, _sjut,
   {{0x3ea23bc8,0x9e353b41,0x7afb003c,0x00000000}},	//   _fakt_, _менч, _pjut, --,
   {{0x644102d7,0xdddd00fe,0x00000000,0x00000000}},	//   zcli, _absť, --, --,
   {{0x78a103ad,0x5d790070,0x1a680df3,0x628d0079}},	//   _palv, _דאָק, صیلی_, _mbao,
   {{0xd90f04e8,0x6d4d1255,0xe8f8093e,0xd8380168}},	//   ریا_, mpaa, блі_, _dačo_,
   {{0x78a13bc9,0x940500a8,0x628d0183,0x6d4d3bca}},	//   _valv, belə_, _obao, lpaa,
   {{0x7ae93bcb,0x7afb0470,0x645c008d,0x78a11e7e}},	//   _umet, _ujut, ðrin, _walv,
   {{0x78a13bcc,0xe5a50de6,0x00000000,0x00000000}},	//   _talv, ципи, --, --,
   {{0x33653121,0x5fc902e4,0xaf010083,0x98f70416}},	//   овог, रहाल, ্ষিণ_, _اثرا,
   {{0x2ca30332,0x64413bcd,0x76590345,0x00000000}},	//   _majd_, rcli, _tewy, --,
   {{0x64413bce,0x6b85001e,0xc5d51112,0xc0490319}},	//   scli, ithg, _міль, _יז_,
   {{0x80b50083,0x3ea23bcf,0x628d009e,0xe60e0d6e}},	//   ুসন্, _rakt_, _dbao, _цд_,
   {{0x2ca30fa0,0xceb400a8,0x273102a7,0x3ea209f0}},	//   _najd_, hmət_, _kšno_, _sakt_,
   {{0x3ea23bd0,0x973c042a,0x27380019,0x7ce90095}},	//   _pakt_, _prći, _vũng_, _görə,
   {{0xee3f008d,0xa3e222c7,0x6d4d0345,0x00000000}},	//   _snýr_, _नेट_, fpaa, --,
   {{0x6d4d2700,0xceb40095,0x2ca3007a,0x3ea23bd1}},	// [3340] gpaa, dmət_, _bajd_, _vakt_,
   {{0x2a7f012f,0x00000000,0x00000000,0x00000000}},	//   _acub_, --, --, --,
   {{0xeb9a3bd2,0x00000000,0x00000000,0x00000000}},	//   рие_, --, --, --,
   {{0x094a05c2,0x673a0176,0xb4d60efa,0x6d4d0051}},	//   ачки_, _rutj, _सत्_, bpaa,
   {{0x673a0691,0x00000000,0x00000000,0x00000000}},	//   _sutj, --, --, --,
   {{0x765d008a,0x6f1603d0,0x83fc011c,0x673a12a9}},	//   ðsyn, llyc, lađe, _putj,
   {{0xd6da3bd3,0xcb670012,0xf40700fd,0x66dc3bd4}},	//   ити_, _маре_, _آؤ_, _léke,
   {{0x83fc0a78,0x758a3bd5,0xbddb0176,0x00000000}},	//   nađe, асов_, _ofèl, --,
   {{0xc6f700d8,0x6b600079,0x7c3900b5,0x66d5008d}},	//   ўных_, _fágá, _ábrá, _tákn,
   {{0x394901dd,0x673a01f4,0x00000000,0x00000000}},	//   íase_, _tutj, --, --,
   {{0xc7a60012,0x00000000,0x00000000,0x00000000}},	//   _фиек, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a63537,0x1611009a,0x66d505d3,0xe29800d8}},	//   _мада, _डुपर_, _záko, цаў_,
   {{0x7ce90095,0x00000000,0x00000000,0x00000000}},	//   _törə, --, --, --,
   {{0xceb40095,0x67223bd6,0x7ce03bd7,0x40342d7a}},	//   ymət_, _khoj, _körf, дерс,
   {{0x66d50076,0x25a90e31,0x83fc011c,0x6f163bd8}},	//   _nákl, _šali_, gađe, glyc,
   {{0x3f9e0093,0x00000000,0x00000000,0x00000000}},	// [3350] ætur_, --, --, --,
   {{0x6d4d3bd9,0x2001006d,0x7b3700f4,0xfbab00af}},	//   rpaa, _txhi_, _oćut, итей_,
   {{0x6d4d1c61,0xb5fd01a0,0x6b85011e,0x6d40000d}},	//   spaa, maše, uthg, _éman,
   {{0xb5fd108a,0x6d4d00c3,0x6b85016e,0x00000000}},	//   laše, ppaa, rthg, --,
   {{0x31793bda,0xdce7045e,0xceb400a8,0x2b58007e}},	//   nusz_, şlıc, rmət_, _ewrc_,
   {{0xe7390a46,0x67223bdb,0xb5fd3bdc,0x9d1802fb}},	//   бек_, _ahoj, naše, _моят_,
   {{0x6722327c,0xd378012e,0x7b64218b,0x00000000}},	//   _bhoj, juć_, _отте, --,
   {{0x6f0d3bdd,0x31790d7f,0x612b0069,0x67223bde}},	//   noac, kusz_, _iżlu, _choj,
   {{0xa2bf057c,0x80cc0387,0x7ce002b1,0xe5710037}},	//   षान्, _सकले, _dörf, رطة_,
   {{0x66d5114d,0xdced0076,0x6f0d01a2,0xb5fd00cd}},	//   _zákl, krač, hoac, jaše,
   {{0x7ce0022a,0x6602012f,0xd378011c,0xb5fd01f2}},	//   _förf, _exok, guć_, daše,
   {{0xf8bd00c8,0xbddb021e,0xdced08b7,0x612000b5}},	//   _অতিথ, _afèm, drač, kölc,
   {{0x171a00c2,0xe2971397,0xdc183272,0x83fc00cd}},	//   _פונע, чая_, _थर्ड_, vađe,
   {{0xb5fd03c9,0xdced0097,0x6729081b,0x612002b1}},	//   gaše, frač, lmej, wölb,
   {{0x2467006c,0x7ce03bdf,0x60230368,0x00000000}},	//   _című_, _hörg, едра, --,
   {{0xee3a3be0,0x660f033b,0x7ce03be1,0x00000000}},	//   сна_, ückw, _körg, --,
   {{0x83fc0a78,0x7ce03be2,0x6f163be3,0x127b016b}},	// [3360] rađe, _jörg, rlyc, _האפע,
   {{0xdced00ac,0x7ce0008a,0xb88601ba,0x83fc011c}},	//   brač, _mörg, _kríž, sađe,
   {{0x6f0d1a71,0xfb8a0009,0x00000000,0x00000000}},	//   boac, сбек_, --, --,
   {{0xdce40254,0x00000000,0x00000000,0x00000000}},	//   krić, --, --, --,
   {{0x98ac013a,0x15eb021a,0x00000000,0x00000000}},	//   _aidā_, _जेलर_, --, --,
   {{0xdce4011c,0x2b5824f7,0x6c361c2d,0x98a50409}},	//   drić, _twrc_, _رفرا, _kilę_,
   {{0xb8f40d4e,0x272100a0,0x25af099e,0x00000000}},	//   _हक_, zóne_, _argl_, --,
   {{0xb8d30f8a,0x35b40091,0xfaa33be4,0xd3780124}},	//   _जो_, дбир, _пасо, vuć_,
   {{0x186a3be5,0x00000000,0x00000000,0x00000000}},	//   _гази_, --, --, --,
   {{0x656f004f,0xb4d60f09,0x07a60e60,0xc7a60352}},	//   ácha, ससे_, _назн, _низк,
   {{0x67223be6,0x224d01a3,0x6f0d3be7,0xb5fd00cd}},	//   _thoj, ñeko_, yoac, vaše,
   {{0x660206a2,0xdced39a2,0x7ce001ff,0xd7ef0037}},	//   _txok, vrač, _förg, _حكم_,
   {{0x7ce03be8,0xb5fd3be9,0xdb0e0031,0x6f0d00af}},	//   _körd, taše, _arbë, voac,
   {{0xdced0d77,0x33580012,0x00000000,0x00000000}},	//   trač, _дакэ_, --, --,
   {{0xbebb00da,0xb5fd068b,0x6f0d3bea,0x7ce006d2}},	//   _dhën, raše, toac, _mörd,
   {{0x7ce0022a,0x59be0456,0x290e0088,0x00000000}},	//   _lörd, ्हार, hofa_, --,
   {{0x6f0d3beb,0xdd94010b,0x98a5004b,0x00000000}},	// [3370] roac, наты, _eilę_, --,
   {{0xa1150037,0x290e0009,0x81e60033,0xb5fd0009}},	//   _زوجت, jofa_, _বুক_, lašc,
   {{0x6ce401e0,0x6f0d023c,0x00000000,0x00000000}},	//   хіте, poac, --, --,
   {{0x386c0118,0x2ee000e9,0xb5fd0124,0x00000000}},	//   _addr_, chif_, našc, --,
   {{0x7ce00ef0,0x00000000,0x00000000,0x00000000}},	//   _börd, --, --, --,
   {{0x008a02b5,0xdce40207,0x00000000,0x00000000}},	//   ַרפֿ, vrić, --, --,
   {{0x7ce00644,0x917a00cc,0x00000000,0x00000000}},	//   _dörd, _mất_, --, --,
   {{0xdce40506,0xb5fd3bec,0x31690160,0x00000000}},	//   trić, jašc, _ovaz_, --,
   {{0x7ce03bed,0x2d893bee,0xb5fd0506,0x2a6d0183}},	//   _förd, ntae_, dašc, _ideb_,
   {{0x7ce006d0,0x67293bef,0xbddb0107,0xf8d10066}},	//   _görd, smej, _afèk, _तकिय,
   {{0xf7702087,0x47d50aaa,0x31690950,0xdced00d5}},	//   _مان_, _تيار, _avaz_, hraď,
   {{0xbebb00da,0x25a900cb,0xa2840580,0xdce40207}},	//   _shën, _šalu_, ریخو, prić,
   {{0x3ea901ff,0x7ce001ae,0xe5a51fff,0x917a00e2}},	//   ddat_, _höre, _цили, _bất_,
   {{0xda20009a,0xbddb0107,0x7ce03bf0,0x00000000}},	//   _बरसत_, _efèk, _köre, --,
   {{0x25ad00be,0x00000000,0x00000000,0x00000000}},	//   lvel_, --, --, --,
   {{0x3f680095,0xf41200a5,0x290e0cc2,0xef1a0823}},	//   rğu_, _שפה_, zofa_, іма_,
   {{0xbebb00da,0x394d006f,0x83fc0009,0xacca3b62}},	// [3380] _thën, _ntes_, mađa, огаз_,
   {{0xdd8f00f3,0x25ad00fd,0x3ea600ea,0x2ee008c7}},	//   شوم_, ivel_, žot_, shif_,
   {{0x4f260de3,0x66dc01c0,0x26dd0273,0x25ad00be}},	//   _одоб, _léka, _olwo_, hvel_,
   {{0x83fc00cd,0xd838023a,0x657b0421,0x00000000}},	//   nađa, _tačk_, kuuh, --,
   {{0xd00f0357,0xa2bf0eff,0x290e3bf1,0xe8940352}},	//   _ملی_, षात्, tofa_, еаль,
   {{0x83fc0254,0x394d0176,0x7e643bf2,0x7ce00225}},	//   hađa, _dtes_, laip, _böre,
   {{0xb906065a,0xd8380254,0x394d3bf3,0x778a00a8}},	//   _पत_, _jači_, _etes_, _təxm,
   {{0x356a399d,0x290e3bf4,0x7e643bf5,0x00000000}},	//   орон_, sofa_, naip, --,
   {{0x66dc0118,0xa534051a,0x38cb00fd,0x00000000}},	//   _céka, ннич, _ڈالی_, --,
   {{0x7ce0315b,0x38cb0332,0x7ae23bf6,0xe0df02e9}},	//   _före, _والی_, lhot, npòt_,
   {{0x7ce03bf7,0xc1c706fe,0x7e640468,0x25ad021d}},	//   _göre, रङ्ग, kaip, avel_,
   {{0x83fc01cc,0xeb9102b5,0x9f980093,0x657b010d}},	//   gađa, אָך_, _ráða_, buuh,
   {{0x6d440221,0x660f033b,0x3ea90282,0x51843bf8}},	//   jqia, ückt, vdat_, кура,
   {{0x78a8005f,0x0ef90035,0x7ce0027d,0x301501ee}},	//   _jadv, ्क्स_, _yöre, едгр,
   {{0x7ae2022e,0x644a035f,0x3ea903c4,0x83fc0254}},	//   khot, _iffi, tdat_, bađa,
   {{0xb5fd15d7,0x62840037,0x22490225,0x443c3bf9}},	//   laša, _gcio, _ufak_, _hgv_,
   {{0x629d3bfa,0x78ba201e,0x3ea93bfb,0x7ae20118}},	// [3390] meso, _ontv, rdat_, dhot,
   {{0xb5fd18b0,0x78a815ce,0x628f0069,0x2d893bfc}},	//   naša, _nadv, lfco, rtae_,
   {{0x3a7532dc,0x443c3bfd,0x394d01f7,0x630400fd}},	//   елер, _mgv_, _stes_, _سویل,
   {{0x78ba0009,0x7ce0013c,0x628f027a,0xdbdc008d}},	//   _antv, _röre, nfco, ráða,
   {{0x644a3bfe,0x7ce02b73,0x672d00a0,0x78a83bff}},	//   _offi, _söre, ňajk, _badv,
   {{0x8d5a02b8,0xf7710c74,0xb17c011d,0x629d3c00}},	//   _מכשי, هاب_, קטור, heso,
   {{0x7ce006d7,0x629d3c01,0x7ae23c02,0xb5fd0207}},	//   _förb, keso, bhot, daša,
   {{0x644a3c03,0x7ae23c04,0xbcfb01c0,0xdb07008a}},	//   _affi, chot, _svéh, _frjá,
   {{0x443c3c05,0x83fc0207,0x00000000,0x00000000}},	//   _bgv_, vađa, --, --,
   {{0x25ad3c06,0x6284199f,0x7ce03c07,0x46db0722}},	//   rvel_, _scio, _töre, _बतकह,
   {{0x39893c08,0x6abb3c09,0xb4bf0099,0xa349010b}},	//   lús_, _knuf, _ंची_, язна_,
   {{0x629d3c0a,0x644a0dc5,0x660f033b,0x66dc00e0}},	//   geso, _effi, ücks, _téka,
   {{0xa4d502ce,0x39893c0b,0x443c0132,0x83fc00cd}},	//   _поді, nús_, _fgv_, rađa,
   {{0x64a23c0c,0x628b013c,0xbebb0031,0x3cfb0067}},	//   _баша, _ögon, _dhëm, ्वों_,
   {{0x629d3c0d,0x39893c0e,0x65693a29,0x6d4f2c0c}},	//   beso, hús_, lseh, _atca,
   {{0x629d3c0f,0xbea33c10,0x62840506,0x76490225}},	//   ceso, ласк, _ucio, ncey,
   {{0x7e643c11,0x65693c12,0x558928ae,0x1d261403}},	// [33a0] raip, nseh, _çığı, емам,
   {{0x6abb0090,0x3157016b,0x67390024,0x00000000}},	//   _anuf, _ריין_, _liwj, --,
   {{0x7ae23c13,0x7e643c14,0x27211d8a,0x78a8010b}},	//   thot, paip, zóna_, _radv,
   {{0xca260665,0x69c201a3,0xb21b0093,0x38720160}},	//   нфли, txoe, mfær, _țară_,
   {{0x7ae23c15,0xb21b221b,0x00000000,0x00000000}},	//   rhot, lfær, --, --,
   {{0x97a63c16,0x7ae23c17,0x3d1800ab,0x00000000}},	//   ерил, shot, _बीचे_, --,
   {{0x7a363410,0x629d01d2,0x7ae23c18,0xf76f12f4}},	//   _bütü, yeso, phot, ماي_,
   {{0x39893c19,0x91b30067,0x00000000,0x00000000}},	//   bús_, इटमै, --, --,
   {{0x948600af,0xb5fd3c1a,0x1a9b0070,0x8cc400b4}},	//   нынд, taša, _צימע, रापो,
   {{0xdce40a23,0x629d001c,0x00000000,0x00000000}},	//   ksič, weso, --, --,
   {{0xb5fd3c1b,0x629d3c1c,0xbebb0031,0x6ee300be}},	//   raša, teso, _shëm, _hõbe,
   {{0xb5fd0254,0x15eb007c,0x2a660159,0x925800c3}},	//   mašn, _जेकर_, naob_, нают_,
   {{0x443c13dd,0x00000000,0x00000000,0x00000000}},	//   _tgv_, --, --, --,
   {{0x644a3c1d,0x98a70009,0x6add021a,0x00000000}},	//   _uffi, ćići_, _मत्र, --,
   {{0xb5fd1851,0x629d3c1e,0x70d100ab,0x98ac005f}},	//   našn, peso, _सकील, _gidą_,
   {{0x629d01f4,0x539b00a5,0xc6130033,0x612000c3}},	//   qeso, _זיהו, াইরা_, löll,
   {{0x781d0084,0xb27400c3,0x66dc3c1f,0x00000000}},	// [33b0] _फर्क_, _слыш, _léko, --,
   {{0x6abb2069,0xb5fd011c,0x612000c3,0x7ae00282}},	//   _snuf, kašn, nöll, _almt,
   {{0xb5fd10d1,0xf09200a5,0x00000000,0x00000000}},	//   jašn, _דני_, --, --,
   {{0xb5fd01cc,0xf41302b5,0xd83800cd,0x61203c20}},	//   dašn, אפע_, _jaču_, höll,
   {{0xa9a507fa,0x61203c21,0x6d4f00b5,0x00000000}},	//   тилд, köll, _utca, --,
   {{0x66d50093,0x398906ee,0x6aa908c7,0xa9b40118}},	//   _jákv, rús_, _waef, الوژ,
   {{0x39890890,0x255d02d0,0x66e51285,0x3f47018d}},	//   sús_, wňl_, кока, _jõu_,
   {{0x65693c22,0x6abb034d,0x291c0183,0x00000000}},	//   tseh, _unuf, alva_, --,
   {{0xd3780035,0xd6ce0037,0x80d10067,0x7ce0017b}},	//   erć_, تقي_, _सकूं, _höra,
   {{0x656901ae,0x66d50093,0x8cc4111a,0xb5fd0506}},	//   rseh, _nákv, रायो, bašn,
   {{0xd8380009,0x656937e9,0x25a60260,0x3f4700ab}},	//   _baču_, sseh, _esol_, _nõu_,
   {{0x7c3a008d,0x614600af,0x05210033,0x65693c23}},	//   _útre, кема, নদের_, pseh,
   {{0xe73003c7,0x8cc40026,0xb5fd00d5,0x00000000}},	//   _اصل_, रामो, mašo, --,
   {{0xfd660019,0xb21b3c24,0x6d402128,0x26cf005f}},	//   _thuầ, tfær, _émai, _hogo_,
   {{0x2d990107,0x26cf0067,0x00000000,0x00000000}},	//   _apse_, _kogo_, --, --,
   {{0xf772168d,0x26cf0370,0xe3b00934,0x3329003c}},	//   יקל_, _jogo_, _دره_, _ghax_,
   {{0xb21b0909,0x26cf2190,0x22400159,0xa2bf0e68}},	// [33c0] lgæn, _mogo_, _igik_, षार्,
   {{0x26cf01ef,0x811600b5,0xb21b0093,0x317b1804}},	//   _logo_, _جذبا, pfær, _קרימ,
   {{0x3eab0122,0x5f0600d8,0xc61e0026,0x6ee300ab}},	//   _fact_, _азна, _पर्य_, _sõbe,
   {{0x68e1013c,0x26cf3c25,0x5b3500af,0x00000000}},	//   _alld, _nogo_, гэчу, --,
   {{0x092a1c64,0x66dc0118,0x6296030d,0x00000000}},	//   وستي_, _dékl, _mbyo, --,
   {{0x3f9a012f,0x7ce0013c,0x3ea03c26,0xb5fd0009}},	//   _kppu_, _föra, leit_, tašn,
   {{0x7ce0013c,0xa3c3053d,0x08d5010b,0x61200093}},	//   _göra, yšší_, ыцця, völl,
   {{0x81e800c8,0xeb0d052b,0x3ea03c27,0x20d400ab}},	//   _যখন_, िकृत_, neit_, _käis_,
   {{0xd946271c,0x66d50076,0xe4e601c8,0x26cf3c28}},	//   _рези, _náku, вінн, _dogo_,
   {{0x3ea002c9,0x70d10006,0x80d10461,0x6296073a}},	//   heit_, _सकेल, _सकें, _abyo,
   {{0x06863c29,0x3ea02307,0x83fc0b16,0x26cf0f84}},	//   _аген, keit_, rađo, _fogo_,
   {{0x26cf3c2a,0x8cc4111a,0x00000000,0x00000000}},	//   _gogo_, राडो, --, --,
   {{0x394433a9,0xdb210332,0x316d0248,0x55060384}},	//   _jums_, ítés, éez_, _ичка,
   {{0x394433a9,0xab651544,0x62960273,0x224001ed}},	//   _mums_, ngüí, _ebyo, _egik_,
   {{0xd8380080,0x60181583,0xdb0e0183,0x7b183c2b}},	//   _taču_, воря_, _arbí, níus,
   {{0x26cf0391,0xb5fd3c2c,0x2a640118,0xf1ee0067}},	//   _xogo_, kašl, _nemb_, _चेक़_,
   {{0x9f3403d0,0x1df83122,0x394401ef,0x00000000}},	// [33d0] реті, веты_, _nums_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea002c9,0x66d50187,0x644f0067,0x645a02b1}},	//   beit_, _záku, ścig, ibti,
   {{0x2d800012,0x394400ea,0x48d20033,0xeb0d0099}},	//   buie_, _bums_, ়ফোর, िकेत_,
   {{0xadf002cb,0x26cf3c2d,0xeab006ee,0xddcd0067}},	//   _घेऊन_, _rogo_, تعل_, ngaż,
   {{0x9b4503c7,0x7ce00301,0x8cc40035,0x7bc3018d}},	//   _منسو, _hörn, राणो, änus,
   {{0x26cf3c2e,0x7ce03c2f,0x0b8800ed,0x612001ff}},	//   _pogo_, _körn, _исти_, följ,
   {{0xbb84004f,0x394401f7,0x05a901e0,0x00000000}},	//   _خلفي, _fums_, евий_, --,
   {{0x8883006c,0xeb1f0099,0xb5fd1384,0x04451d91}},	//   _نیشن, बतीत_, rašo, лепн,
   {{0x3ea002c9,0x645e007c,0x70d20e04,0x7b18002a}},	//   zeit_, _õpil, _हवेल, bíus,
   {{0x26cf1c9e,0x69d93c30,0x7b18002a,0xdce400ea}},	//   _togo_, lywe, cíus, nsiā,
   {{0x645a011e,0xe1ff27c2,0x73e21303,0x02de012f}},	//   abti, raón_, союз, मसेन,
   {{0x69d92107,0x765b0010,0x3ea03c31,0xcb121804}},	//   nywe, mbuy, veit_, מלט_,
   {{0x3ea002c9,0x657b08c7,0x00000000,0x00000000}},	//   weit_, mruh, --, --,
   {{0x3ea01c47,0xdee603f5,0xba2002e4,0x7ce0008a}},	//   teit_, гови, _बर्फ_, _börn,
   {{0xeabe0083,0x7e550011,0xceb40095,0x6da611d0}},	//   _আত্ম, итуц, lməz_, либа,
   {{0x3ea03c32,0xb21b01b4,0x518503e6,0x657b3c33}},	// [33e0] reit_, ngæl, _куќа, nruh,
   {{0x3ea03c34,0x69d93c35,0x44272ddb,0xb5fd0009}},	//   seit_, dywe, _kzn_, vašl,
   {{0x7ce0013c,0x78ae0132,0x2d803c36,0x28c70efa}},	//   _förn, _óbvi, suie_, लानि,
   {{0x62863c37,0x298a2701,0x20d400ab,0x657b1e28}},	//   ngko, еско_, _täis_, kruh,
   {{0xf54800e8,0xceb30317,0x2d802939,0x69d900e9}},	//   _mục_, _פיש_, quie_, gywe,
   {{0x6f043c38,0xf54801a5,0x37aa1e47,0xb5fd0c8c}},	//   lnic, _lục_, етин_, rašl,
   {{0x6f043c39,0x6d463c3a,0x442700c7,0xebe63c3b}},	//   onic, _huka, _nzn_, _совп,
   {{0x6f043c3c,0x6d463c3d,0xa3c90825,0x69d900d5}},	//   nnic, _kuka, ोहन_, bywe,
   {{0x6d46141d,0x44270095,0x1a063c3e,0x6f043c3f}},	//   _juka, _azn_, _спам, inic,
   {{0x6d463c40,0x6f043c41,0x6aa23c42,0x778a013b}},	//   _muka, hnic, leof, _bəxt,
   {{0x6d462f9e,0xd49715eb,0x9259383f,0x6f041394}},	//   _luka, уры_, кант_, knic,
   {{0x6f0405e2,0xf54801a5,0x51871517,0x6aa20098}},	//   jnic, _cục_, луга, neof,
   {{0x6f040690,0xf5480028,0x2710020d,0x6d463c43}},	//   dnic, _dục_, ावीर_, _nuka,
   {{0x6f043c44,0xf3f50118,0x00000000,0x00000000}},	//   enic, اتیک, --, --,
   {{0x6d462129,0x6f0401a2,0x40353c45,0x3cfa1140}},	//   _auka, fnic, ревс, ोचने_,
   {{0x6d463c46,0xf5480023,0x6f043c47,0xf3c900f8}},	//   _buka, _gục_, gnic, _جبهه_,
   {{0x70552292,0x6d4603c3,0x644f004e,0x8cf500d8}},	// [33f0] _پنجا, _cuka, ście, азац,
   {{0xeb0d0d00,0xbcfb000d,0x65620027,0x00000000}},	//   िक्त_, _avér, _mwoh, --,
   {{0x6f040252,0x6d463c48,0x6e953c49,0xfff90a86}},	//   bnic, _euka, _кину, _شکست_,
   {{0x6b9c022e,0x7ce001ff,0xdced0254,0x3f8300f8}},	//   _dprg, _föro, krać, muju_,
   {{0x3f833c4a,0x7ce03c4b,0x6d463c4c,0x09d80033}},	//   luju_, _göro, _guka, _দেবা,
   {{0xd3660cd1,0x26181163,0xe9b80332,0x69d90626}},	//   _وه_, _पड़ी_, انوں_, rywe,
   {{0x3f830464,0x69d9027a,0x6d463c4d,0x3f9101d7}},	//   nuju_, sywe, _zuka, ntzu_,
   {{0x6d4601d6,0x657b1cc5,0x2b4d0355,0x6562007b}},	//   _yuka, truh, _čech_, _bwoh,
   {{0xb5fd023a,0xc9870431,0xdced0009,0x6d4601ed}},	//   mašk, _љуби, grać, _xuka,
   {{0x6f0405e2,0x63b83c4e,0x3f830b79,0x81cb0083}},	//   znic, _brvn, kuju_, লনা_,
   {{0x3f830a78,0x78a33c4f,0x657b3c50,0x63aa0176}},	//   juju_, menv, sruh, _csfn,
   {{0xdced0bec,0xb5fd0759,0x3f830254,0x659500af}},	//   brać, našk, duju_, _ваду,
   {{0x6f040121,0x62863c51,0x614602d5,0x78c400b5}},	//   vnic, rgko, рега, _átvé,
   {{0x6d463c52,0x6f04006a,0x412a08a6,0x78a33c53}},	//   _ruka, wnic, того_, nenv,
   {{0xf5480028,0x52763af1,0xa06738ab,0xb5fd03ab}},	//   _tục_, _купу, раса_, kašk,
   {{0xb5fd068b,0x66d50187,0xdb0e006c,0x539a00a5}},	//   jašk, _zákr, _orbá, _ייצו,

   {{0xee3a19f8,0x7ce0022a,0x78a30223,0x5d6a01f5}},	// [3400] тна_, _förl, kenv, тизм_,
   {{0x6f040690,0x6d463c54,0x3f833c55,0xccc30421}},	//   snic, _vuka, buju_, обуй,
   {{0x6f043c56,0x307b0122,0x3f8300cd,0x78a33c57}},	//   pnic, _באינ, cuju_, denv,
   {{0x6d463c58,0xb5fd04c3,0xe9da081b,0x2ee93c59}},	//   _tuka, gašk, кке_, chaf_,
   {{0x7ce03c5a,0x26cd022f,0x64430035,0x6aa20098}},	//   _hörm, djeo_, _ogni, reof,
   {{0x78a33c5b,0x1d0a0b32,0xdced0254,0x2ee0028b}},	//   genv, _реги_, vrać, lkif_,
   {{0xe3a701ca,0x96f80423,0xfaa603d0,0xb5fd080a}},	//   _بر_, лект_, _каво, bašk,
   {{0x64433c5c,0xe72f0d93,0xd6d700c3,0xdced0c99}},	//   _agni, وصي_, иты_, trać,
   {{0x3f830a78,0x645e00be,0x78a30110,0xf548055c}},	//   zuju_, _õpik, benv, _bụa_,
   {{0x63b8000c,0x83fc011c,0x6f0900cd,0x30c10033}},	//   _prvn, lađi, čeci, _উত্স,
   {{0x66e6144b,0x7ce001ff,0xbddb01cb,0x00000000}},	//   _кожа, _rörl, _ngèn, --,
   {{0x3f83042a,0x32672313,0xdced011c,0x96ba00b5}},	//   vuju_, штов, prać, _جائز_,
   {{0xbddb12c3,0xf8da0066,0x7d1c0393,0xe4e600d4}},	//   _agèn, _बकाय, _okrs, _війн,
   {{0x3f833c5d,0x3d100035,0x64a32324,0x00000000}},	//   tuju_, ़कों_, _мача, --,
   {{0x4384004f,0x53351d1f,0x2ee9001e,0x644f004e}},	//   _العق, _лект, thaf_, ścic,
   {{0x2fcd01cc,0x3f830a78,0x78a33c5e,0x643b00a5}},	//   ćeg_, ruju_, zenv, _בעונ,
   {{0x7ce000b5,0xb5fd02c6,0x3f830254,0x71f80987}},	// [3410] _törl, vašk, suju_, _پريس_,
   {{0x7ce0022a,0x2ee9046a,0x3f8300cd,0xa2bf0d1f}},	//   _förm, shaf_, puju_, षाक्,
   {{0x7ce00d6f,0xb5fd08b3,0x78a316de,0x01340037}},	//   _görm, tašk, venv, _بعيد,
   {{0x83fc00cd,0x00000000,0x00000000,0x00000000}},	//   gađi, --, --, --,
   {{0x6dc8081b,0x78a33c5f,0x00000000,0x00000000}},	//   _кырг_, tenv, --, --,
   {{0xf74503fa,0x31580122,0xac193c60,0x28c70067}},	//   беко, סיון_, _богу_, लाधि,
   {{0x3a8715eb,0x78a33c61,0x48781112,0xb5fd01a0}},	//   _вызв, renv, рсія_, maši,
   {{0x78a32ce4,0xb5fd3c62,0xfc4a0037,0x7e6d3c63}},	//   senv, laši, _tríú_, naap,
   {{0x78a33c64,0x28c7170c,0xdb0e0fb5,0x2cb100ee}},	//   penv, लादि, _urbá, _kazd_,
   {{0x7e6d2656,0x644401d6,0xb5fd3c65,0x26cd0124}},	//   haap, _şiir, naši, sjeo_,
   {{0x7ce006d7,0xc1d00355,0x7e6d3c66,0xc2c60037}},	//   _börj, सङ्ग, kaap, ميدي,
   {{0x47353c67,0xc0491804,0x63530160,0x778a013b}},	//   _унес, _טז_, _rănd, _təxr,
   {{0xb5fd3c68,0x29073c69,0x63530139,0x00000000}},	//   kaši, onna_, _sănd, --,
   {{0x6443010b,0x270c00b8,0xb5fd011c,0x00000000}},	//   _ugni, měna_, jaši, --,
   {{0x1fb53312,0xa35516e6,0x29073c6a,0x63530395}},	//   остр, _اختص, inna_, _băne,
   {{0xe9ff01a5,0xf5480019,0x7e6d0159,0x701600db}},	//   _ngắn_, _mụn_, gaap, _दुःख_,
   {{0xb5fd1321,0x270c0355,0x63530160,0xed57027a}},	// [3420] faši, něna_, _dăne, йот_,
   {{0xbc6a0372,0xad9b01ef,0xee373b99,0x2d92053e}},	//   امان_, _axús, сну_, rtye_,
   {{0xaf0a0041,0x3ea62682,0xbea60b78,0x2cb100ee}},	//   _مقدم_, _линг, _ланк, _dazd_,
   {{0x29073c6b,0x7ce03c6c,0x26180099,0x00000000}},	//   enna_, _körk, _पडली_, --,
   {{0x83fc0a78,0xceb40095,0xb5fd18cc,0xdce40035}},	//   rađi, mdə_, baši, esią,
   {{0xceb40095,0x7ce00cba,0x7c3a00d5,0x83fc00cb}},	//   ldə_, _mörk, _útro, sađi,
   {{0xd83802a7,0x00000000,0x00000000,0x00000000}},	//   _obče_, --, --, --,
   {{0xceb40250,0x29070514,0x973c0c21,0x69b007ba}},	//   ndə_, anna_, _opće, _आईपी,
   {{0xceb30122,0x1dc80edf,0x2d8002d7,0x7bde0bbc}},	//   ליה_, रमित, nrie_, lypu,
   {{0xe9d703d0,0x2d803c6d,0x628d004f,0x92c50083}},	//   _уку_, irie_, _scao, _এতে_,
   {{0xceb401c2,0xd6cf2f7c,0x3cf00461,0x4c9b016b}},	//   kdə_, _ет_, _इतने_, נשטע,
   {{0x1dc80e61,0x7ae23c6e,0x2d8000e7,0x00000000}},	//   रमात, nkot, krie_, --,
   {{0x7e6d081b,0x656f004f,0x644f004e,0xceb40095}},	//   vaap, ácht, ścia, ddə_,
   {{0x7ae23c6f,0x23b00096,0x2d803c70,0x7e6d3436}},	//   hkot, _जनपद, drie_, waap,
   {{0x7e6d3c71,0xb4e40026,0xb5fd0124,0x92590714}},	//   taap, नसी_, vaši, _кайт_,
   {{0x7ce0022a,0x25ec0084,0x3f730254,0x00000000}},	//   _förk, आईपी_, rću_, --,
   {{0x7ce005f9,0x29073c72,0xb5fd0506,0x7e6d00be}},	// [3430] _görk, ynna_, taši, raap,
   {{0x5c750409,0x6d4d028b,0x291e0159,0x3f730207}},	//   ілет, rqaa, _nkta_, pću_,
   {{0xb5fd3c73,0x2d803c74,0x28c70440,0x930b0033}},	//   raši, arie_, लासि, রতীপ_,
   {{0x291e3c75,0x2d800043,0xceb400a8,0x00000000}},	//   _akta_, brie_, cdə_, --,
   {{0x6845081b,0x60d701ed,0xb5fd093f,0x00000000}},	//   онла, _koxm, paši, --,
   {{0x83fc042a,0x6eea016f,0xfe73006c,0x92c50083}},	//   lađu, _výbe, _بدھ_, _এতো_,
   {{0x28da07b5,0x2aa00107,0xddc4010b,0xa6c910a4}},	//   _बकरि, _bčbč_, maiš, илка_,
   {{0xe57905f2,0xba770148,0x83fc011c,0x96b90274}},	//   ази_, _داست, nađu, руку_,
   {{0x7ae90723,0x4ae400d8,0x7afb00f9,0x00000000}},	//   _ilet, _эўра, _imut, --,
   {{0xceb40095,0xdced022f,0x69c60124,0x60d70069}},	//   zdə_, ksač, _škeg, _noxm,
   {{0x7ae93c76,0x130a0086,0xceb400a8,0x33f501e0}},	//   _klet, иной_, ydə_, ючис,
   {{0xdb1c02e1,0x7afb009f,0xceb4013b,0x92f63c77}},	//   _arrê, _jmut, xdə_, ічні,
   {{0x7ce0022a,0x6353002d,0x60d7310c,0x1a9a0070}},	//   _förh, _bănc, _boxm, סישע,
   {{0x7ae93c78,0x7ae23c79,0xa06725a0,0x00000000}},	//   _llet, zkot, жара_, --,
   {{0x48e10ccf,0x7ae90f67,0xceb40095,0x7afb09d6}},	//   _कवनो_, _olet, tdə_, _omut,
   {{0xbebb00da,0x7ce026be,0x83fc00f4,0x00000000}},	//   _shër, _törk, gađu, --,
   {{0xceb40669,0x163602b5,0x2c260033,0x2d803c7a}},	// [3440] rdə_, ַנער_, _বলেই_, urie_,
   {{0x2d803c7b,0x7ae93c7c,0x69b0004e,0xd83e0187}},	//   rrie_, _alet, _आईबी, íčka_,
   {{0xa09b02b5,0x7ae93c7d,0x7ae23c7e,0xb5fd00cd}},	//   _דייט, _blet, tkot, mašu,
   {{0x2d80275f,0x639a0070,0xdce400cd,0xb5fd08b7}},	//   prie_, יסענ, ksić, lašu,
   {{0xdb21006c,0x7ae902c4,0xbebb0031,0x6120008d}},	//   ítás, _dlet, _thër, sölu,
   {{0x7ae93c7f,0x7afb3c80,0xb5fd00c7,0x3a2d0207}},	//   _elet, _emut, našu, _dzep_,
   {{0x7ae93c81,0xd90d09b9,0x3f68013b,0xf76f0413}},	//   _flet, دیل_, nşu_, ناي_,
   {{0x7c2e3c82,0x47330088,0x00000000,0x00000000}},	//   _izbr, وريز, --, --,
   {{0x290003e6,0xe4a609a5,0xf77200b5,0x9f9f00a2}},	//   éias_, орно, ساں_, réée_,
   {{0xb5fd0009,0x07a62746,0xb4e40127,0x644f0067}},	//   jašu, _мазн, नसे_, ścin,
   {{0x2b44008c,0x28c7060a,0xb6cc027b,0x66dc00e0}},	//   _kimc_, लारि, çüsü, _séku,
   {{0xfc4600b8,0x79820067,0x612000b5,0x00000000}},	//   šího_, orow, zölt, --,
   {{0xc64907f8,0xdb1c01e9,0x00000000,0x00000000}},	//   _اجمل_, _arrë, --, --,
   {{0x7c2e0097,0x7ce01366,0x00000000,0x00000000}},	//   _ozbr, _föri, --, --,
   {{0x291c0043,0x79823c83,0x270c0355,0x3e6b0279}},	//   iova_, hrow, něno_, ишан_,
   {{0xa3c91fe0,0x79823c84,0x9f050037,0x98a50409}},	//   ोहर_, krow, أورو, _filė_,
   {{0xdd9400d8,0x61200332,0x83fc0a78,0x3d940b46}},	// [3450] маты, tölt, rađu, митр,
   {{0x7ae91217,0xb5fd0254,0x79820035,0x83fc012e}},	//   _slet, mašt, drow, sađu,
   {{0xf09235d9,0x291c3c85,0xb5fd0254,0xddc4010b}},	//   _אני_, dova_, lašt, raiš,
   {{0x79820035,0x5338016b,0xae1c0e6f,0x00000000}},	//   frow, ַנגן_, _भुवन_, --,
   {{0xb5fd0129,0x79823c86,0x291c3c87,0x19ab03d0}},	//   našt, grow, fova_, ртеп_,
   {{0x291c3c88,0x3ea93c89,0xf5480023,0x4dda00a5}},	//   gova_, leat_, _cụm_, _החשו,
   {{0xf771004f,0x7ae93c8a,0x27210187,0x6eea00ac}},	//   ءات_, _tlet, zónu_, _hýba,
   {{0x7afb070b,0x7ae93c8b,0x3ea93c8c,0xdce4004e}},	//   _umut, _ulet, neat_, dsię,
   {{0xe81b3c8d,0x291c3c8e,0x64470169,0xb5fd030a}},	//   _पुरा_, bova_, žjim, jašt,
   {{0x2249005d,0xceb400a8,0xb5fd0009,0xa3c900dc}},	//   _agak_, llət_, dašt, ोहल_,
   {{0x644f004e,0x2a6d006f,0x394d3c8f,0x3ea90421}},	//   ścio, _keeb_, _hues_, keat_,
   {{0x39453c90,0xe29a1172,0x00000000,0x00000000}},	//   _hils_, щам_, --, --,
   {{0x2a6d006d,0x3ea90328,0x25ab00e0,0x21330023}},	//   _meeb_, deat_, _خداي_, _bhxh_,
   {{0xd47902b5,0x2a6d01e8,0x55ba0122,0x3d150035}},	//   _האַל, _leeb_, _למנו, तकों_,
   {{0xb5fd3c91,0xa3cc0433,0xe0160084,0x394d3c92}},	//   rašu, रमण_, _दुखद_, _lues_,
   {{0xc7b202b5,0x2a6d006f,0x27211c02,0x394d0b88}},	//   עבן_, _neeb_, móns_, _oues_,
   {{0x6da30cd0,0x25ad3c93,0x272101dd,0x394d000d}},	// [3460] нита, nwel_, lóns_, _nues_,
   {{0xdb1c00f7,0x6d2303fa,0x291c0031,0xd7bd0930}},	//   _irré, едуз, xova_, ्माच,
   {{0xeb9a1917,0x6132054e,0x6ecc000c,0x270500ea}},	//   сие_, ræld, हादु, lēnu_,
   {{0x2a6d01a9,0x79820035,0x3f8a043d,0xa3be0066}},	//   _ceeb_, trow, mubu_, ीमत_,
   {{0x291c2f6e,0x3f983c94,0x25ad01e4,0x2a6d0107}},	//   tova_, ltru_, jwel_, _deeb_,
   {{0x394d12c3,0xdb07008a,0xddcd0225,0xed571098}},	//   _dues_, _brjó, lbaş, _хор_,
   {{0x3f981a24,0x7c2e3c95,0x2a6d006f,0x48733c96}},	//   ntru_, _uzbr, _feeb_, ردوس,
   {{0x291c3c97,0x7982004e,0x7d1e3c98,0x4ad009b1}},	//   sova_, prow, lops, _सचिव,
   {{0x39453c99,0x291c0a78,0x394d0176,0x994a104b}},	//   _fils_, pova_, _gues_, _طلال_,
   {{0x3f8a3998,0x39453c9a,0xb5fd01a0,0x2721002a}},	//   kubu_, _gils_, vašt, fóns_,
   {{0x7ce006d7,0x2a6d0189,0xdced003c,0x27210042}},	//   _förv, _yeeb_, ntaġ, góns_,
   {{0x2a6d01a9,0x69c036e8,0xdb0e0310,0x7d1e00ee}},	//   _xeeb_, _krme, _arbú, hops,
   {{0xe29800d8,0x67223c9b,0x37ae0033,0xd6cf0098}},	//   чаў_, _ikoj, _কপির, _حقن_,
   {{0xb5fd31f1,0xa63b0122,0x2721002a,0x20130118}},	//   rašt, _הגדר, bóns_, _pxxi_,
   {{0x7d1e3c9c,0x37de0033,0x2721002a,0x6722073a}},	//   dops, _ভেতর, cóns_, _kkoj,
   {{0xb5fd0a16,0xdb1501ef,0x00000000,0x00000000}},	//   pašt, _orzá, --, --,
   {{0xceb40669,0xd9c6009a,0x628f00d7,0x63480355}},	// [3470] vlət_, लमोट, mgco, _věnu,
   {{0x3ea93c9d,0x6eea024e,0x2a6d01e8,0x394d00f7}},	//   seat_, _výba, _seeb_, _rues_,
   {{0x2a6d006d,0x3ea93c9e,0x7b640e75,0x9be4010b}},	//   _peeb_, peat_, етче, ніцк,
   {{0x394d0083,0x39450443,0x2a6d0221,0x628f3c9f}},	//   _pues_, _sils_, _qeeb_, ngco,
   {{0x27213612,0x6f0d2940,0x394d0815,0x394500ea}},	//   zóns_, mnac, _ques_, _pils_,
   {{0xa3cc0311,0x394d0248,0x6d5d06a2,0xa3be000c}},	//   रमा_, _vues_, _itsa, ीमा_,
   {{0x2a6d3ca0,0xceb40095,0x25ad0024,0x69c03ca1}},	//   _teeb_, mlər_, wwel_, _erme,
   {{0x6d473ca2,0xceb40095,0x6d4f3ca3,0x6458054e}},	//   _hija, llər_, _kuca, _afvi,
   {{0xa2d1112b,0x6d473ca4,0x6d4f0043,0xe7d20066}},	//   धान्, _kija, _juca, _थपथप,
   {{0x7ce01c3e,0xceb40095,0x6f0d3ca5,0x272101dd}},	//   _föru, nlər_, hnac, tóns_,
   {{0x6d4f3ca6,0x7ce0006c,0x7e7d3ca7,0xd90c04cd}},	//   _luca, _törv, _odsp, _دیو_,
   {{0x6d5d3ca8,0x27210391,0xdced0644,0x7e6f00d5}},	//   _otsa, róns_, yrağ, _necp,
   {{0xceb401c2,0x6d5d006f,0x23600a78,0x6f0d0d5c}},	//   klər_, _ntsa, _čije_, dnac,
   {{0x6d470184,0x69b006bb,0x67293ca9,0x7e7d008c}},	//   _nija, _आईसी, llej, _adsp,
   {{0x614329af,0x6d5d3caa,0xe29a3cab,0xceb40095}},	//   тера, _atsa, _дай_, dlər_,
   {{0x6f0d3cac,0x6d4f3cad,0x7cf20a8a,0x3f8a3cae}},	//   gnac, _buca, _kærg, rubu_,
   {{0x3f983caf,0x442702c7,0x6d4f3cb0,0xceb40095}},	// [3480] stru_, _hyn_, _cuca, flər_,
   {{0x3e6c00e8,0x6e2b02c9,0x44273cb1,0x6f0d3cb2}},	//   ết_, ügba, _kyn_, anac,
   {{0x7d1e0a0b,0x6d471221,0x6d4f1d2b,0xdced01cc}},	//   rops, _dija, _euca, građ,
   {{0x44273cb3,0x673b004e,0x7d1e040a,0xdced027d}},	//   _myn_, jmuj, sops, prağ,
   {{0xceb401c2,0x6d473cb4,0x44273cb5,0x67293cb6}},	//   blər_, _fija, _lyn_, dlej,
   {{0x6f04034d,0x765903bc,0x764b018e,0x644f0067}},	//   liic, _afwy, _aggy, ścij,
   {{0x67290033,0x44273cb7,0xb8d63cb8,0x6288010b}},	//   flej, _nyn_, _जस_, ėdoj,
   {{0xd6d0004f,0x2cb83cb9,0x6d4f0831,0x7ce0008a}},	//   اقة_, _hard_, _yuca, _vöru,
   {{0x948600af,0x7ce0022a,0x2cb812f1,0x69c00043}},	//   мынд, _fört, _kard_, _urme,
   {{0x6f0d004e,0x764b01a8,0x442701ff,0xa2d1021a}},	//   znac, _eggy, _byn_, धाभ्,
   {{0x44270297,0x7ce00ed4,0x6ef1054e,0x2cb8035f}},	//   _cyn_, _hörs, _håbe, _mard_,
   {{0x4427001e,0x96632c86,0xceb400a8,0x2cb800f6}},	//   _dyn_, _акце, zlər_, _lard_,
   {{0x6f04009e,0xceb400a8,0xdced011c,0x290e3cba}},	//   diic, ylər_, zrađ, onfa_,
   {{0x44273cbb,0x6d4f3cbc,0x7ce01e2e,0xd5af00e0}},	//   _fyn_, _ruca, _mörs, _خفه_,
   {{0x6d4f3cbd,0x44273cbe,0xe8df0023,0xceb4013b}},	//   _suca, _gyn_, _cuộn_, vlər_,
   {{0x6d473cbf,0x6d4f00cd,0x672000e6,0x2cb803c4}},	//   _sija, _puca, nomj, _aard_,
   {{0xceb40095,0x506702fb,0x9df93cc0,0x6d4f013b}},	// [3490] tlər_, _отна, чнат_, _quca,
   {{0x6f0d3cc1,0x2cb83cc2,0x798b0010,0xf5480019}},	//   snac, _card_, vugw, _bụi_,
   {{0xceb40669,0x6d473cc3,0x6720022f,0x673b0035}},	//   rlər_, _vija, komj, ymuj,
   {{0x7ce03cc4,0x6d473cc5,0xceb400a8,0x2a660159}},	//   _börs, _wija, slər_, gbob_,
   {{0x67203cc6,0xa9691c80,0x2cb83cc7,0x6d5d3789}},	//   domj, чила_, _fard_, _utsa,
   {{0xa3be2869,0x2cb83cc8,0x798b3cc9,0x3eb906d1}},	//   ँटा_, _gard_, rugw, _hast_,
   {{0x6729007c,0xddc60029,0xac94005f,0x25a63b4f}},	//   tlej, _iekš, _шарш, _apol_,
   {{0x7ce03cca,0xe9ff00e2,0x4427099e,0x3eb9023a}},	//   _förs, _ngần_, _ryn_, _jast_,
   {{0x442702ce,0x7ce03ccb,0x7cf2054e,0x672901b4}},	//   _syn_, _tört, _færd, rlej,
   {{0x644e1269,0x67bb250f,0x44270173,0x67293ccc}},	//   žbin, _واضح_, _pyn_, slej,
   {{0xc2090122,0x232a0c98,0x67293ccd,0xf77000b2}},	//   _פה_, зони_, plej, _نان_,
   {{0x7af90463,0xbebb01f4,0x2a7f0024,0x3eb91aa5}},	//   _çatı, _skën, _jdub_, _nast_,
   {{0x44273cce,0x35a50382,0xe5a50714,0x7cf21923}},	//   _wyn_, _чалг, _чили, _hære,
   {{0x7cf201b4,0x3eb90051,0x26dd3ccf,0xddc6003d}},	//   _kære, _aast_, _howo_, _nekš,
   {{0x6ee300ab,0x9fc7027a,0x8fa30153,0x7cf20044}},	//   _lõbu, нгра_, ларе, _jære,
   {{0x6eea0076,0x26dd00bf,0x3eb93cd0,0xe1ff0138}},	//   _výbo, _jowo_, _cast_, mbón_,
   {{0x6f04009e,0x7cf22b6f,0x395f0221,0x62960010}},	// [34a0] riic, _lære, _ntus_, _icyo,
   {{0x6f04009e,0x26dd0118,0xdd8f0041,0x3eb93cd1}},	//   siic, _lowo_, صوم_, _east_,
   {{0x3eb9222d,0x61e63cd2,0x395f01cb,0xe29f0093}},	//   _fast_, lykl, _atus_, liða_,
   {{0x3eb93cd3,0x395f3cd4,0x7cf20249,0xd00f00b5}},	//   _gast_, _btus_, _særd, _چلی_,
   {{0x2cb83cd5,0xe8941112,0xda631783,0x7ce0013c}},	//   _tard_, валь, увчи, _dörr,
   {{0x3eb93cd6,0x7cf20c71,0xf5480023,0x6ef101b4}},	//   _zast_, _bære, _tụi_, _våbe,
   {{0x09d800c8,0x25a60e6a,0x7ce0022a,0x7cf2054e}},	//   _দেখা, _spol_, _förr, _værd,
   {{0x8f9b1899,0x61e601c8,0xfd4d0023,0xbb431fd8}},	//   ליצי, kykl, _nghị, _беск,
   {{0x60de053e,0x26dd00f8,0x55063cd7,0xd25100d1}},	//   _oopm, _dowo_, ечна, یند_,
   {{0xdb1501ae,0x644d0644,0x61e6010b,0x62960371}},	//   _erzä, _şair, dykl, _acyo,
   {{0xccf30052,0x7cf2008c,0x3ea00223,0x00000000}},	//   רכת_, _gære, kfit_, --,
   {{0xf1bf0334,0x26dd01cb,0xa3b102b4,0x78ba00fd}},	//   tvá_, _gowo_, _ऑनर_, _hatv,
   {{0x3eb93cd8,0x250b00b5,0x78ba0f04,0x395f0345}},	//   _rast_, _کرنی_, _katv, _xtus_,
   {{0x3135204b,0x3eb9053e,0x75210310,0x7cf20044}},	//   тегр, _sast_, colz, _lærb,
   {{0x3ea03cd9,0x3eb90122,0x78ba3cda,0xdb1c01ef}},	//   ffit_, _past_, _matv, _arrí,
   {{0x78ba3cdb,0x7cf23cdc,0x00000000,0x00000000}},	//   _latv, _nærb, --, --,
   {{0x61e615b3,0x7d25006c,0x3eb93cdd,0x00000000}},	// [34b0] cykl, نفرن, _vast_, --,
   {{0x645a1de8,0x3eb93cde,0xdbd100be,0x00000000}},	//   ncti, _wast_, püüg, --,
   {{0x3eb93cdf,0x7cf20c61,0x7d051008,0x00000000}},	//   _tast_, _bærb, rihs, --,
   {{0xc01c0019,0x9980027d,0x0f7a016b,0x63a502b1}},	//   _lược_, çiş_, _קארב, _ähne,
   {{0x442b0023,0x78ba0027,0x6606008e,0x26dd00e0}},	//   ́c_, _batv, úkkl, _rowo_,
   {{0x78ba0160,0x315800a5,0x7cf211cb,0x00000000}},	//   _catv, עיון_, _pære, --,
   {{0x8aa70a93,0x61e63ce0,0xac1801e0,0xd8b80037}},	//   _прад, zykl, _зору_, عدها_,
   {{0x78a401cc,0x645a0043,0x2a7f0510,0x7cf21217}},	//   điva, ecti, _udub_, _være,
   {{0x7ce03ce1,0x23600a78,0x940b00a8,0xa2c520af}},	//   _körp, _čija_, əcə_, ियन्,
   {{0x78ba3ce2,0x61e63ce3,0xc01c0023,0x25bf053e}},	//   _gatv, vykl, _cược_, rvul_,
   {{0x6abb02c9,0xc6e70a55,0x4ac602e4,0xc01c0019}},	//   _kauf, _підп, _रोडव, _dược_,
   {{0x29073ce4,0x78ba3ce5,0xe1ff3ce6,0x61e600c7}},	//   lina_, _zatv, rbón_, tykl,
   {{0x399b0279,0x6abb012f,0x95e9006c,0x290702ee}},	//   nês_, _mauf, _تباہ_, oina_,
   {{0x6abb3ce7,0x2d89053e,0x61e600c7,0xe1ff00b5}},	//   _lauf, drae_, rykl, mból_,
   {{0x61e63ce8,0x2907030d,0x657b3ce9,0x00000000}},	//   sykl, iina_, lsuh, --,
   {{0x29073cea,0x241600a5,0x3f8419be,0xbddb00e0}},	//   hina_, _שחקן_, čmu_, _ngès,
   {{0x60de3ceb,0x657b3cec,0x3ea03ced,0x63a40207}},	// [34c0] _topm, nsuh, rfit_, _ćini,
   {{0x98be00d8,0xa3d50461,0xee373cee,0x6da33cef}},	//   _kitą_, _सपा_, тну_, рифа,
   {{0x29071254,0x644f004e,0x57bd0066,0x7e76010d}},	//   dina_, ściw, ्मोह, payp,
   {{0x2d890279,0x6abb3cf0,0x78ba00ea,0xe1ff006c}},	//   brae_, _cauf, _satv, kból_,
   {{0x78ba3cf1,0xd9973cf2,0x7ce001ff,0x9f5a021d}},	//   _patv, نخوا_, _förp, _expô_,
   {{0x29073cf3,0x97a61d32,0xc8780225,0x00000000}},	//   gina_, врил, _boğa_, --,
   {{0x8b263cf4,0x6abb00f6,0x78ba3cf5,0x00000000}},	//   _адве, _fauf, _vatv, --,
   {{0x1ae33cf6,0x399b03e6,0x8c1b0d85,0xf5480023}},	//   _косм, bês_, _חולי, _lụt_,
   {{0x29073cf7,0x81e700c8,0x399b03e6,0x78ba3cf8}},	//   bina_, _যেন_, cês_, _tatv,
   {{0x6abb0035,0x00000000,0x00000000,0x00000000}},	//   _zauf, --, --, --,
   {{0x7ae030bc,0x69c21e7e,0xd251014a,0x2b9c00a0}},	//   _komt, lvoe, ینگ_, níc_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394c3cf9,0x69c20c7c,0x213a009e,0x7ae30132}},	//   _kids_, nvoe, _bhph_, ênti,
   {{0x557700c2,0x2d89053e,0xf54800e2,0x25ef0066}},	//   _יעדן_, vrae_, _cụt_, इनरी_,
   {{0xa3cc0066,0xcebb0274,0x13b30079,0x00000000}},	//   _रपट_, мља_, _نصيح, --,
   {{0x29073cfa,0x7ae0006d,0x2d890cc9,0x200c01ba}},	//   zina_, _nomt, trae_, údia_,
   {{0x290701a8,0x8d741301,0x6abb3cfb,0x69c202a2}},	// [34d0] yina_, لالا, _rauf, jvoe,
   {{0x29071a71,0x2d8901ef,0xb5df0033,0x2c7c00b8}},	//   xina_, rrae_, _বেঁচ, vádí_,
   {{0x290702dd,0x2d890159,0x6aa20185,0x99d400d1}},	//   vina_, srae_, ffof, یتها,
   {{0x7ae03cfc,0x29073cfd,0xbcfb0037,0x399b0132}},	//   _comt, wina_, _dtéa, tês_,
   {{0xdcef01c2,0xdb0e01ef,0x69c2053e,0x3f9133a5}},	//   şdır, _arbó, gvoe, luzu_,
   {{0xdb1c0176,0x660d3cfe,0x00000000,0x00000000}},	//   _errà, _žako, --, --,
   {{0x6abb3cff,0x3f9100d0,0x273a0031,0x00000000}},	//   _tauf, nuzu_, kënd_, --,
   {{0x7bc70024,0x69c20b88,0xe1ff00fd,0x399b0183}},	//   _irju, bvoe, tból_, pês_,
   {{0xfec50033,0x7cf20044,0xc9870d6e,0x2b4d023c}},	//   _একাধ, _hæra, _јуби, _iiec_,
   {{0x04b507e5,0x394c02e6,0x657b3d00,0x7cf20093}},	//   усия, _gids_, rsuh, _kæra,
   {{0x29053d01,0x657b3d02,0x3f910195,0xe1ff00b5}},	//   _imla_, ssuh, juzu_, sból_,
   {{0x68e13d03,0x656201f4,0x3f913d04,0xdb15002a}},	//   _hold, _ftoh, duzu_, _arzú,
   {{0x64a51ba1,0x68e13d05,0x7cf200d4,0x26cf3d06}},	//   _бала, _kold, _læra, _ingo_,
   {{0x293502b5,0x3f913d07,0x3f8a0009,0xd5ac00b5}},	//   טאָן_, fuzu_, trbu_, _کہی_,
   {{0x68e13d08,0x44240164,0x3f9106a2,0x34390070}},	//   _mold, _پروف, guzu_, _אײַע,
   {{0x6ee30006,0x2b9c01c0,0x5276097a,0x69c60124}},	//   _sõbr, víc_, _суку, _škem,
   {{0xa2d104e9,0x7bc724ef,0x7ae03d09,0xf5480023}},	// [34e0] धार्, _arju, _romt, _tụt_,
   {{0x7ae003bc,0x2b4d0069,0x69ba00dc,0x7cf209bd}},	//   _somt, _aiec_, _एनबी, _bæra,
   {{0xb09b02b5,0xa2d83d0a,0xac970088,0x409b02b5}},	//   _אייר, याप्, انما_, _אביס,
   {{0x69c20244,0xdb0e0176,0x3cf00099,0x00000000}},	//   tvoe, _arbò, _इतके_, --,
   {{0x68e13d0b,0x2b9c033a,0x38cb3c96,0x187400d8}},	//   _bold, síc_, کانی_, агля,
   {{0x69c20244,0x2905009e,0x26cf3d0c,0x2d9201d5}},	//   rvoe, _cmla_, _ango_, muye_,
   {{0x7ae0086d,0x68e13d0d,0x2d9200de,0x6d4e010d}},	//   _tomt, _dold, luye_, _iiba,
   {{0x6d4e3d0e,0x62843d0f,0x2b4d00f6,0x00000000}},	//   _hiba, _ndio, _giec_, --,
   {{0x6d4e3d10,0xa2d809b1,0x2d920010,0x29050359}},	//   _kiba, यान्, nuye_, _fmla_,
   {{0xd49a021d,0xd94607e5,0x6d4e3d11,0x62843d12}},	//   хри_, _сези, _jiba, _adio,
   {{0x6d4e3d13,0x2d9201d5,0xc6250033,0x69ba23e3}},	//   _miba, huye_, মেলা_, _एनडी,
   {{0x6d4e0dc3,0x973c029d,0x68e13d14,0x2d9201d5}},	//   _liba, _opći, _zold, kuye_,
   {{0x68e10463,0x6284001e,0x59c709b4,0x7c2e00fe}},	//   _yold, _ddio, लियर, _lybr,
   {{0x6d4e01d0,0x3f9101d7,0xe104010b,0xbcfb2e7a}},	//   _niba, tuzu_, бясп, _atén,
   {{0xe44f3d15,0x96a1021a,0x7c2e167f,0x00000000}},	//   _عضو_, क्वॉ, _nybr, --,
   {{0x2d9204fb,0x00000000,0x00000000,0x00000000}},	//   fuye_, --, --, --,
   {{0x6d4e3d16,0x2d920010,0x5c753d17,0x635300af}},	// [34f0] _biba, guye_, илат, _răni,
   {{0x2d870bc9,0x6d4e3d18,0x2d4d0009,0x7c2e376a}},	//   čne_, _ciba, _ežen_, _bybr,
   {{0x6d4e0614,0x68e13d19,0xaa550c98,0x8f353d1a}},	//   _diba, _rold, авеш, _венц,
   {{0x2d923d1b,0xdd95004c,0x6d4e06a2,0xab2b0698}},	//   buye_, _камы, _eiba, رسال_,
   {{0x7e6d3d1c,0x68e13d1d,0x2b4d01a5,0x442e3d1e}},	//   mbap, _pold, _viec_, _lyf_,
   {{0x6d4e3d1f,0x68e10510,0x2b4d0035,0x00000000}},	//   _giba, _qold, _wiec_, --,
   {{0x68e13d20,0x46f53d21,0xa2d801c0,0xe3e40033}},	//   _vold, ичит, याम्, _ফেসব,
   {{0x95853d22,0x6d4e3d23,0xe1ff0093,0x00000000}},	//   алие, _ziba, gbók_, --,
   {{0xe576037c,0x6d4e01d5,0x19591482,0x6284009e}},	//   азы_, _yiba, _разы_, _rdio,
   {{0xb3a901d6,0x6d4e01ef,0x00000000,0x00000000}},	//   _çıkı, _xiba, --, --,
   {{0x53a51ad4,0xb4e500a1,0x03a51e31,0x2d920010}},	//   шанб, _नवी_, шино, zuye_,
   {{0xb6c900f5,0x69c93d24,0x7cf2008c,0x26cf023c}},	//   _جائے_, _kree, _nærn, _ungo_,
   {{0xd567195a,0x7f5700f7,0x95671172,0xa2d80355}},	//   _степ, _auxq, _съед, याब्,
   {{0x2d920010,0x6724011c,0x65693d25,0x200c00a0}},	//   vuye_, čije, mpeh, údio_,
   {{0x6ef8021d,0x6aa9017b,0x00000000,0x00000000}},	//   _líbe, _obef, --, --,
   {{0xe8df0028,0x539a0122,0x2d923d26,0x0e663355}},	//   _muốn_, _סיפו, tuye_, ркан,
   {{0xed5702e3,0x69c9006d,0x3eb20159,0x98a50260}},	// [3500] иот_, _nree, reyt_, _aklč_,
   {{0x2d920a14,0x6aa90979,0x6ef10a8a,0x00000000}},	//   ruye_, _abef, _fåbo, --,
   {{0xeb9a2294,0x6d4e000e,0x1d1902ce,0x69c93d27}},	//   тие_, _viba, ують_, _aree,
   {{0x7c2e05d3,0xfaa63d28,0x69c93d29,0x6d4e3d2a}},	//   _vybr, радо, _bree, _wiba,
   {{0x6d4e3d2b,0x7c2e004e,0xc3330122,0x2a691111}},	//   _tiba, _wybr, קוד_, ñaba_,
   {{0x6f163d2c,0x69c93d2d,0xa3d5000c,0xa3c700b8}},	//   lnyc, _dree, समा_, ैमा_,
   {{0xe8df01a5,0x2d803d2e,0x69c9001c,0x6f160035}},	//   _cuốn_, lsie_, _eree, onyc,
   {{0x6f163d2f,0x69c93d30,0x6b8300af,0x7f440176}},	//   nnyc, _free, ânge, nmiq,
   {{0x1dc906fe,0x2d803d31,0x69c93d32,0xa2c50355}},	//   रियत, nsie_, _gree, ियस्,
   {{0x44f438c7,0x2d803d33,0x3f5c01ef,0x2b58023a}},	//   спос, isie_, _oíu_, _kurc_,
   {{0x3f5c3d34,0x00000000,0x00000000,0x00000000}},	//   _níu_, --, --, --,
   {{0xe5a63d35,0x2d800173,0x6f16004e,0x442e053e}},	//   _види, ksie_, jnyc, _vyf_,
   {{0x6f16324f,0x442e001e,0x23690187,0x2d803d36}},	//   dnyc, _wyf_, _čaje_, jsie_,
   {{0xa5070036,0x09c30033,0xddcf00af,0x969200b5}},	//   _кеча_, ্নচা, _lecţ, _ایکش,
   {{0x75280035,0x63530395,0xaf070409,0x40350279}},	//   modz, _bănu, ачак, севс,
   {{0x2721016f,0xa2d8052b,0x75283d37,0xdb0703d0}},	//   fóny_, याण्, lodz, _usjø,
   {{0x63530139,0x7f4f0345,0x25ec0067,0x00000000}},	// [3510] _dănu, _vicq, आईटी_, --,
   {{0xeb1f21b2,0x6d8a006c,0x6aa90036,0x8c670036}},	//   यक्त_, املہ_, _sbef, ртад,
   {{0xba770098,0x6f163d38,0x2d803605,0x7cf234b7}},	//   لاشت, bnyc, asie_, _tærn,
   {{0x69c93d39,0x7528004e,0x2b580036,0x6f163d3a}},	//   _pree, hodz, _durc_, cnyc,
   {{0x8d8402ee,0xa2d80d53,0x7cf23d3b,0xe1ff3d3c}},	//   _мурд, यात्, _kærl, nzó_,
   {{0x6f0d2a17,0x69c912b0,0xb4e500a1,0x00000000}},	//   liac, _vree, _नवे_, --,
   {{0x6fd70026,0x69c91e7e,0x3f5c0023,0x75280207}},	//   डमिं, _wree, _xíu_, dodz,
   {{0x6f0d3d3d,0x6d450a32,0xa3d502e4,0x7cf23d3e}},	//   niac, lmha, समस_, _lærl,
   {{0x69c90160,0x7cfb0139,0x00000000,0x00000000}},	//   _uree, _vîrf, --, --,
   {{0x6f163d3f,0x6d45009c,0x6f0d3d40,0x25ec00dc}},	//   znyc, nmha, hiac, आईजी_,
   {{0x65691a2e,0x27210187,0x0326081b,0xf8b30066}},	//   speh, zóny_, йдон, ंजीप,
   {{0x8a140332,0x6132008a,0x216a23b8,0x6d450767}},	//   _اظہا, mæli, лими_, hmha,
   {{0xe2970086,0x6f1601ba,0x00000000,0x00000000}},	//   щая_, vnyc, --, --,
   {{0x2a7d01a9,0x6f16004e,0xd46602ce,0xddc40009}},	//   hawb_, wnyc, _лише_, jbiš,
   {{0xa2d801d1,0x339507f8,0x6f161cca,0x438502e7}},	//   याद्, _العز, tnyc, _البق,
   {{0x09bd0b52,0x6f0d3d41,0x2d803d42,0x836406ee}},	//   _আপনা, giac, tsie_, _بدول,
   {{0xac860409,0x82970122,0x0dca06d8,0x2d80009e}},	// [3520] йгал, _הדפס_, ылай_, usie_,
   {{0x2d803d43,0xa25b03e6,0xddcf002d,0x5c5618cd}},	//   rsie_, ndôn, _secţ, стаф,
   {{0x2d803d44,0xb5fd01c8,0x6f0d3d45,0xf53602b5}},	//   ssie_, rašy, biac, צטער_,
   {{0x6f0d3d46,0x2d803d47,0x6d4509c3,0x75283d48}},	//   ciac, psie_, amha, zodz,
   {{0x085401e0,0xfe46002d,0x98a5007a,0x00000000}},	//   овлю, _ынмо, _silġ_, --,
   {{0x2b583d49,0x6d45184f,0x6eea0187,0xd83a00af}},	//   _turc_, cmha, _výbu, лэй_,
   {{0x3706218b,0x00000000,0x00000000,0x00000000}},	//   йчив, --, --, --,
   {{0xe8df01a5,0xfaa3010c,0x7528004e,0xe80700a1}},	//   _buồn_, _насо, wodz, _वेळा_,
   {{0x186a3d4a,0x25af0027,0x00000000,0x00000000}},	//   _бази_, _cpgl_, --, --,
   {{0x6f0d3d4b,0xe29f008d,0x00000000,0x00000000}},	//   ziac, miði_, --, --,
   {{0x63a502c9,0x7528295e,0x7cf20909,0xe29f008d}},	//   _ähnl, rodz, _nærm, liði_,
   {{0x290e3d4c,0x083b02b5,0x7cf2177c,0xe7373d4d}},	//   lifa_, _געבל, _særl, _лех_,
   {{0x7982006a,0x2d4d042a,0x26c30029,0xbb3b016b}},	//   nsow, _džej_, ējot_, טעטי,
   {{0x290e1049,0xaacf00b4,0x00000000,0x00000000}},	//   nifa_, _सोनक, --, --,
   {{0x6f0d34c4,0x436703e6,0xf044002d,0x00000000}},	//   tiac, _лајн_, зэто, --,
   {{0x290e034d,0x877b0319,0x79820035,0x8c000033}},	//   hifa_, טאלי, ksow, ্থান_,
   {{0x28b9004e,0x290e023c,0x6d450098,0x00000000}},	// [3530] _इसलि, kifa_, tmha, --,
   {{0x6f0d0038,0x6d453d4e,0x463b0070,0x79820345}},	//   siac, umha, רעמע, dsow,
   {{0x6d453d4f,0x6f0d3d50,0x25a41d44,0x2fc700f8}},	//   rmha, piac, html_, _éng_,
   {{0xf2d402b5,0x6d4509c3,0x539b0122,0x443c00ac}},	//   ּעס_, smha, ריאו, _mzv_,
   {{0xb2bc02b5,0x6f1d0223,0x98a5013a,0x00000000}},	//   טמאר, _ijsc, _aklā_, --,
   {{0x2a7d006d,0x0b7b29fe,0x98ac005f,0x00000000}},	//   sawb_, _مصرع_, _didį_, --,
   {{0x0a6b2123,0xf7453d51,0x25af021d,0x00000000}},	//   _брзи_, оеко, _spgl_, --,
   {{0x46e93d52,0x05653494,0x3ea9055c,0x00000000}},	//   рдин_, овин, nfat_, --,
   {{0xa2d80ed1,0x3ea9001e,0xa8a7051a,0x00000000}},	//   यास्, ifat_, _грек, --,
   {{0x672401a0,0x00000000,0x00000000,0x00000000}},	//   čija, --, --, --,
   {{0x28150514,0x00000000,0x00000000,0x00000000}},	//   _بواس, --, --, --,
   {{0x4acf04cc,0xe29a3d53,0x232a0949,0x00000000}},	//   _सोमव, шам_, роми_, --,
   {{0x9f4c00b8,0x7cf20044,0x00000000,0x00000000}},	//   ádí_, _særm, --, --,
   {{0x2d4d01f2,0x6eea3d54,0x443c023a,0x7ce00523}},	//   _džek_, _nýbr, _fzv_, _föry,
   {{0x3ea93d55,0xc44700d1,0x7ce000b5,0x00000000}},	//   ffat_, _دیدن_, _törz, --,
   {{0x290e1a95,0x9f5900fd,0x7cf20185,0x00000000}},	//   zifa_, ázás_, _værm, --,
   {{0x6da33d56,0x82fa0357,0x23600a78,0xec7a0ece}},	// [3540] мита, _مرکز_, _čiji_, ипа_,
   {{0xa3cd0026,0x00000000,0x00000000,0x00000000}},	//   रिप_, --, --, --,
   {{0xdee63810,0x60d70070,0x00000000,0x00000000}},	//   _дони, _וויא_, --, --,
   {{0x3f983d57,0x49ca3d58,0xa25b00a0,0x261a00cc}},	//   muru_, илен_, jdôl, ừoi_,
   {{0x3f9803c3,0x290e3d59,0x3a200225,0x00000000}},	//   luru_, tifa_, çip_, --,
   {{0xf7722e63,0x7cf2054e,0xe29f0093,0x28f700c3}},	//   واع_, _mærk, riði_, жешь_,
   {{0x290e3d5a,0x31a400b5,0x7cf20b3e,0x3f98034d}},	//   rifa_, höz_, _lærk, nuru_,
   {{0x27e00254,0x290e3d5b,0x78ad011c,0xa3cd0b54}},	//   ćin_, sifa_, đava, रिन_,
   {{0x26c2016f,0x3f983d5c,0x23691635,0x7cf20a8c}},	//   ľko_, huru_, _čaja_, _nærk,
   {{0x3f983d5d,0x69c00332,0x26c22d5b,0xd90e006c}},	//   kuru_, _isme, žko_, _جیت_,
   {{0x3f980010,0x7e643d5e,0xdb1c0118,0x4acf0099}},	//   juru_, kcip, _asré, _सोडव,
   {{0x46d10035,0x443c00d5,0x3f983d5f,0x68e83084}},	//   _दोपह, _vzv_, duru_, _hodd,
   {{0x68e83d60,0x31a400a3,0x00000000,0x00000000}},	//   _kodd, göz_, --, --,
   {{0x443c3d61,0x3f983d62,0xf993011d,0x7bce0160}},	//   _tzv_, furu_, ורש_, _orbu,
   {{0x3f983d63,0xa2d800e7,0x290c010d,0x443c1793}},	//   guru_, याश्, _mmda_, _uzv_,
   {{0x69c00bc6,0x37bc0033,0x68e83d64,0x926b0166}},	//   _osme, _অপার, _lodd, _трка_,
   {{0xa2d80d41,0x63ad0009,0xa25b3d65,0x3ea90282}},	// [3550] यार्, _ćani, ndôm, rfat_,
   {{0x3f9806a2,0x68e800e9,0xa2a7060a,0x25600107}},	//   buru_, _nodd, ट्र्, _mòl_,
   {{0xa3cd159b,0x69c03d66,0x3f9801d5,0x00ba00a5}},	//   रिय_, _asme, curu_, _המתמ,
   {{0xb4e700b4,0xae0c043b,0xd7b40099,0x60c500c3}},	//   _यक्_, _सेवन_, ंबईच, _hahm,
   {{0x7e7d0ae0,0x68e83d67,0x7cfb0139,0x7bce023a}},	//   _iesp, _bodd, _cîrc, _erbu,
   {{0x68e83574,0xa3cd0d53,0x6d5d0ddb,0x2c4600b5}},	//   _codd, रिम_, _iusa, _کیمپ_,
   {{0x69c03d68,0x6d5d3d69,0x60c53d6a,0x475800d8}},	//   _esme, _husa, _mahm, орыя_,
   {{0x6d5d3d6b,0x7e7d3d6c,0x6b832b83,0x1ab400d4}},	//   _kusa, _jesp, ángu, _обся,
   {{0x6d553d6d,0x68e8016e,0x3f983d6e,0x7e7d0065}},	//   _kiza, _fodd, zuru_, _mesp,
   {{0x6d5d3d6f,0x7afb00fb,0x7e7d0c1f,0x6d550088}},	//   _musa, _hlut, _lesp, _jiza,
   {{0x6d5d3d70,0x6d553d71,0x7afb3d72,0xd91a011d}},	//   _lusa, _miza, _klut, _פועל,
   {{0xf77004e8,0x6d5d3d73,0x7ae90024,0x883a0d85}},	//   _شام_, _ousa, _joet, _התעו,
   {{0x7ae904ce,0x6d5d06b3,0x7cf301d6,0x256002d0}},	//   _moet, _nusa, _kırı, _gòl_,
   {{0x3f983780,0x6d550095,0x7cf2054e,0x7ae9007c}},	//   turu_, _niza, _værk, _loet,
   {{0x6d5d35d5,0x7afb3d74,0xd9b83d75,0x00000000}},	//   _ausa, _olut, _इन्ट, --,
   {{0xdee30a9f,0x3f983d76,0x7e7d3ca6,0x6d5523ec}},	//   носи, ruru_, _cesp, _aiza,
   {{0x6d553d77,0x7e7d1116,0x3f983d78,0x7cf20a8a}},	// [3560] _biza, _desp, suru_, _hæri,
   {{0xdd8f0dc0,0x6d5d3d79,0x3f983d7a,0x7afb0b23}},	//   اول_, _dusa, puru_, _alut,
   {{0x46bd00a1,0x68e83d7b,0x7ae93d7c,0x7afb01ae}},	//   ्याह, _rodd, _boet, _blut,
   {{0x7e7d3d7d,0x68e8046f,0x7ae93d7e,0xdb053d7f}},	//   _gesp, _sodd, _coet, nthè,
   {{0x6d5d3d80,0x7cf203d8,0x13b40083,0x6382006c}},	//   _gusa, _læri, টিয়, _kíná,
   {{0x6d550291,0x7bce03fd,0x7e7d004e,0x7afb3d81}},	//   _giza, _trbu, _zesp, _elut,
   {{0x7afb3d82,0x6d5d02bf,0xf76f00bf,0x7cf23d83}},	//   _flut, _zusa, هاي_, _næri,
   {{0x7ae93d84,0x6d550010,0x25603d85,0x7999012f}},	//   _goet, _ziza, _pòl_, buww,
   {{0x69c03d86,0xbcfb053f,0x443a1a8a,0x7cf300c1}},	//   _usme, _stéi, _šp_, _fırı,
   {{0x7ae93b0d,0x765900e9,0xf8c001c0,0x7afb00d5}},	//   _zoet, _egwy, _एसिय, _zlut,
   {{0x60c53d87,0x256002e9,0x92953d88,0xa2950823}},	//   _rahm, _wòl_, манц, мані,
   {{0x883b00a5,0x6b6500c7,0x2240005f,0x25600260}},	//   _פתאו, _jėga, _bzik_, _tòl_,
   {{0x2360011c,0x332000ee,0xd244002d,0x00000000}},	//   _čiju_, _djix_, еэри, --,
   {{0x6d5d3d89,0x0cc70083,0xdb0e0a8a,0x7e7d3d8a}},	//   _rusa, _শক্ত, _esbø, _sesp,
   {{0x6d553d8b,0x443a01a5,0xa2a50edf,0x224001d7}},	//   _riza, _áp_, _काप्, _ezik_,
   {{0x6d5d2bab,0xf8b902e4,0x6d553d8c,0x539b0122}},	//   _pusa, _इस्प, _siza, _היהו,
   {{0x7e7d3d8d,0x7ae9053e,0x26c6011e,0xdddd3d8e}},	// [3570] _vesp, _roet, _maoo_, _iesū,
   {{0x7afb3d8f,0x7ae93d90,0x81fc00a5,0x6d551505}},	//   _slut, _soet, _להחז, _qiza,
   {{0x6d553d91,0x7afb3d92,0xfe70006c,0x7e7d3d93}},	//   _viza, _plut, ئدہ_, _tesp,
   {{0x6d5d3d94,0x6d553d95,0xa3cd162b,0xdced022f}},	//   _tusa, _wiza, रित_, rsađ,
   {{0x6d5d3d96,0xa2a500db,0x7ae90a45,0x9989016f}},	//   _uusa, _कान्, _voet, ťaž_,
   {{0x7cf300a8,0x26c60069,0xbcfb0300,0x78ad00f4}},	//   _qırı, _aaoo_, _quéd, đavo,
   {{0x7ae93d97,0x7afb0118,0x23690207,0x00000000}},	//   _toet, _tlut, _čajo_, --,
   {{0x7afb05dd,0x628d0037,0x8cdb0035,0xd6ce0079}},	//   _ulut, _ndao, नावो, لقى_,
   {{0x7cf30a21,0x38c9026b,0x7cf23d98,0x387e099e}},	//   _tırı, _وائی_, _særi, _fetr_,
   {{0x628d0395,0x83891303,0x00000000,0x00000000}},	//   _adao, обов_, --, --,
   {{0x6ef81e60,0xccf21899,0x395f008c,0xd7c100ab}},	//   _bíbl, דכי_, _huus_, _शनिच,
   {{0x35f50e75,0x395f00ab,0xc878027d,0xe29f0093}},	//   _опер, _kuus_, _doğu_, ggð_,
   {{0x64a53d99,0xe60e083e,0xf54800e2,0xdb2400a2}},	//   _жала, _рд_, _lụy_, ésél,
   {{0x46bd01d1,0x7cf208c8,0x395f3d9a,0x00000000}},	//   ्यवह, _hærv, _muus_, --,
   {{0x2d8f00de,0x225f0009,0x8fa31353,0x7cf20a8a}},	//   ágen_, žuka_, каре, _kærv,
   {{0x98bf035f,0x6ef80138,0x00000000,0x00000000}},	//   _ftuħ_, _víbo, --, --,
   {{0x395f0626,0xccc63d9b,0xe1ff1111,0x3126192f}},	// [3580] _nuus_, мбай, lcón_, _одиг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1ff0020,0xa2a520af,0x00000000,0x00000000}},	//   ncón_, _काम्, --, --,
   {{0x31603d9c,0x7cf23d9d,0x395f0228,0x9411013b}},	//   _kuiz_, _nærv, _buus_, üzə_,
   {{0x7bda2ce5,0x316003e6,0x387e01c0,0x092a00f3}},	//   _štud, _juiz_, _petr_, يستي_,
   {{0x8b660098,0x395f008c,0x00000000,0x00000000}},	//   _يازم, _duus_, --, --,
   {{0x31600370,0xb9060084,0x6b631f71,0xdca32b60}},	//   _luiz_, _बच_, _акса, _шари,
   {{0x8c4338c7,0x758a00c3,0x442000cd,0x00000000}},	//   _ресе, осов_, _ći_, --,
   {{0xb8f40083,0x395f0223,0x00000000,0x00000000}},	//   _হক_, _guus_, --, --,
   {{0x1c22198f,0x3374034b,0x628d009e,0x00000000}},	//   _मशाल_, нгор, _sdao, --,
   {{0x38cb0a86,0x00000000,0x00000000,0x00000000}},	//   _باقی_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7070a86,0x3ea00f43,0xbebb0055,0xe7e43d9e}},	//   _تسلی, dgit_, _njëa, _कपडा_,
   {{0x672d10ec,0x7cf20093,0xdb053826,0x00000000}},	//   čaje, _kæru, rthé, --,
   {{0x40343d9f,0xd5c80019,0xe1f9010b,0xdb05000d}},	//   верс, _hề_, šų_, sthé,
   {{0x3ea03da0,0xd5c80019,0xceb80274,0x7e760345}},	//   ggit_, _kề_, мљу_, gbyp,
   {{0x9f340185,0x7cf205ee,0x6ea50af9,0x3cd500af}},	// [3590] теті, _læru, ङ्गु, нжас,
   {{0x2d9b02d7,0x00000000,0x00000000,0x00000000}},	//   ruqe_, --, --, --,
   {{0x7cf23da1,0xd5c80019,0x395f3da2,0x98a700ea}},	//   _næru, _lề_, _suus_, jonā_,
   {{0xbcfb3da3,0x67223157,0x6ef10b80,0xdced00f4}},	//   _québ, _njoj, _påbu, mpač,
   {{0xd5c80023,0xd8380107,0x316001ef,0x38c4010b}},	//   _nề_, _ayč_, _xuiz_, kūrė_,
   {{0x7f4d00a8,0x270c0355,0xf54800e2,0x7cf234b7}},	//   lmaq, měny_, _tụy_, _bæru,
   {{0x8aa7021d,0x5ef6012f,0x6ea30067,0x2d4d00f4}},	//   _орад, _एकम्_, गलपु, _džet_,
   {{0xa3cd0567,0x7c220095,0xd5c80019,0x395f00b9}},	//   रिस_, ğort, _bề_, _tuus_,
   {{0x79a424f9,0x2d890103,0xe6192743,0x67223540}},	//   _архе, nsae_, яди_, _djoj,
   {{0x31603da4,0x5a440144,0x6b6500c7,0x00000000}},	//   _ruiz_, _рэса, _jėgo, --,
   {{0x260f07ba,0x63ad02c4,0x00000000,0x00000000}},	//   _तेरी_, _ćans, --, --,
   {{0x2d8b1e85,0xe1ff1725,0x1ddf06fe,0xa2a50afa}},	//   _ovce_, rcón_, नमात, _काण्,
   {{0x6d470086,0xe1ff215f,0xbbac06fe,0x3afa0070}},	//   _ohja, scón_, _टङ्क, פּטע,
   {{0x64a53da5,0x673b02ee,0xdbd7005b,0xdce400f4}},	//   _чака, lluj, _käär, mpić,
   {{0x6d4b010b,0xdbd7194e,0xb4fa024b,0x00000000}},	//   įgal, _jäär, _מפסי, --,
   {{0xdbd7087a,0xd36e0286,0x64433da6,0x6d473da7}},	//   _määr, _اهي_, _izni, _ahja,
   {{0x62863da8,0xa2a50931,0xdce600ea,0xa3cd012f}},	// [35a0] mako, _कात्, _atkā, रिव_,
   {{0x62863da9,0x02ac04bc,0xa2d80577,0x3e7e00cc}},	//   lako, ट्रभ, याक्, ắt_,
   {{0xbcfb0132,0x6d470031,0x673b00d5,0x00000000}},	//   _suéc, _dhja, kluj, --,
   {{0xed5a2b5b,0x44273daa,0xbcfb0093,0x6ef10b3e}},	//   _ном_, _mxn_, _stét, _dåbs,
   {{0xddcd00af,0x260f0456,0x673b00d5,0x8277016b}},	//   rbaţ, _तेली_, dluj, גענע_,
   {{0x62862790,0x6f041896,0xb86600f8,0xd838021e}},	//   hako, lhic, راتو, _pyč_,
   {{0x8c432eb3,0x6286240f,0xddcd011c,0x673b0453}},	//   _бере, kako, mbaš, fluj,
   {{0xa6aa0037,0xcc3b0070,0xcf9300a5,0x870900b5}},	//   سابق_, _זעלט, אטה_, وڑنے_,
   {{0x62863dab,0x6443028b,0x69ba0026,0xa2c4021a}},	//   dako, _azni, _एनटी, िजन्,
   {{0xd5c8098b,0x03f803fa,0x81e60083,0x753a01d7}},	//   _về_, дној_, পনা_, ultz,
   {{0xa3cd057c,0x5c97016b,0x6f04055c,0x00000000}},	//   रिष_, עכטע_, khic, --,
   {{0x6286281e,0xa2d80761,0x6aa23dac,0x672d0009}},	//   gako, याग्, ngof, čajc,
   {{0x6f0401a6,0x7cfb0160,0x394e01f7,0x00000000}},	//   dhic, _bîrl, omfs_, --,
   {{0xa3cd3123,0x24851599,0x656f3dad,0x7cf208c8}},	//   रिश_, calm_, íche, _mærs,
   {{0xa2d80569,0x62863dae,0x136a02ee,0x65623394}},	//   याख्, bako, _эшли_, _huoh,
   {{0x643b0122,0x9f603daf,0x63b800e2,0xdced00d5}},	//   _מעונ, árás_, _ipvn, rpač,
   {{0xdd9400c7,0x3d943db0,0x7f4d00a8,0x6ef80098}},	// [35b0] латы, литр, rmaq, _míbh,
   {{0xac271dd0,0x69ba05dc,0xbebb0031,0x7cfb0160}},	//   нфек, _एनजी, _gjën, _gîrl,
   {{0x6f0400f1,0x69c20b88,0x00000000,0x00000000}},	//   bhic, ewoe, --, --,
   {{0x9e1500ef,0x6f043db1,0x59bf09b1,0x7bda0124}},	//   _адмі, chic, _एनआर, _štuc,
   {{0xdb1c006c,0xab640035,0xdbd70303,0x00000000}},	//   _arró, ężar, _säär, --,
   {{0x62863db2,0xbcfb1dad,0xdbd71130,0x00000000}},	//   zako, _etér, _päär, --,
   {{0x62863db3,0xdce40067,0x673b00d5,0x00000000}},	//   yako, jpię, tluj, --,
   {{0xdbd70d4c,0x7cf200fb,0x98b600ea,0xdce40207}},	//   _väär, _færs, īgās_, tpić,
   {{0xe7f310aa,0x62863db4,0xdb1c1111,0xdb0e0176}},	//   _अथवा_, vako, _erró, _esbó,
   {{0xd95503c5,0xa3cd0026,0xd90f006c,0x673b3db5}},	//   _شناخ, रिल_, _ھیں_, sluj,
   {{0xe29a0af4,0x62863db6,0x232a27e9,0xdce400cb}},	//   ман_, tako, дони_, spić,
   {{0x64430076,0x7bd500d5,0x069b00fd,0xddcd00f4}},	//   _vzni, _mrzu, _رخصت_, zbaš,
   {{0x62863db7,0x00000000,0x00000000,0x00000000}},	//   rako, --, --, --,
   {{0x62863db8,0x7bd50160,0x25ad3db9,0xf4870923}},	//   sako, _orzu, mtel_, _чудн,
   {{0x6f043dba,0x25ad3dbb,0x741200e0,0x4cca0033}},	//   thic, ltel_, _پويا, রামু,
   {{0x7cf2008d,0x7b110501,0x0b130033,0x00000000}},	//   _nærr, sťuj, িকুল_, --,
   {{0x0e63005f,0x66090987,0x7bd50716,0xc2c90037}},	// [35c0] ркун, nzek, _arzu, _سبيل_,
   {{0xbcfb00f7,0x5eaa0033,0x6724011c,0x7bd50035}},	//   _stér, _চোখে, čiji, _brzu,
   {{0x6f043dbc,0xe0fb0319,0x6ef83dbd,0x7cf20b41}},	//   phic, _חליל, _líbi, _bærr,
   {{0xdb1c0310,0xe6bd0099,0x00000000,0x00000000}},	//   _arrò, ्योज, --, --,
   {{0xe8942780,0x62840a4a,0xa2a50433,0x80a90033}},	//   галь, _meio, _कास्, _ছোট্,
   {{0x66090029,0x628401d7,0x26dd02d0,0x69c211ad}},	//   dzek, _leio, _anwo_, rwoe,
   {{0xebe301f0,0x7cf23dbe,0x6d5c3dbf,0xa2d806fe}},	//   _корп, _færr, _iira, याञ्,
   {{0x6d5c3dc0,0xdb1c01f7,0x3e86010b,0xbcfb000d}},	//   _hira, _errò, būtų_, _utér,
   {{0x6f030012,0x28e23dc1,0xa5340ef3,0x7bd50067}},	//   _înce, पादि, лнич, _zrzu,
   {{0x6d5c3dc2,0x672d0bec,0xc7960409,0x62840132}},	//   _jira, čaja, _арды, _aeio,
   {{0x26cd0009,0x4c9b00a5,0x00000000,0x00000000}},	//   bdeo_, וביו, --, --,
   {{0x6d5c3dc3,0x656200c3,0x200a0207,0x00000000}},	//   _lira, _tuoh, dzbi_, --,
   {{0x6594002d,0x62843dc4,0x25ad1c5b,0x66090035}},	//   _салу, _deio, ctel_, czek,
   {{0xa2a50325,0xe13500af,0x00000000,0x00000000}},	//   _काव्, унгы, --, --,
   {{0x543303c5,0xa43800d4,0x6e951e46,0x62842de8}},	//   _پرور, _язку_, ливу, _feio,
   {{0x6d5c3dc5,0xbcfb00de,0x216700c3,0x28d907df}},	//   _aira, _cuén, _итог, _योनि,
   {{0x6d5c3dc6,0x7cd90183,0x23690a3c,0x00000000}},	// [35d0] _bira, нмар_, _čaji_, --,
   {{0x6d5c3dc7,0x26cd3dc8,0xa3d609b4,0x7c3c0090}},	//   _cira, zdeo_, सिप_, _byrr,
   {{0xa2d80429,0x6d5c1221,0x7c3c001e,0x2d4d00cb}},	//   याच्, _dira, _cyrr, _džep_,
   {{0x6d5c3dc9,0x6eda0066,0x443c2c10,0x7c3c01e9}},	//   _eira, _पोपु, _myv_, _dyrr,
   {{0x6d5c3dca,0x25ad3dcb,0x99151958,0x7bd50035}},	//   _fira, xtel_, лькі, _wrzu,
   {{0x7c3c00fb,0x6d5c3dcc,0x7bc703d0,0xe0d50070}},	//   _fyrr, _gira, _tsju, רײַ_,
   {{0x6e3d0297,0x7c3c001e,0x26180127,0xe7391fde}},	//   _hysb, _gyrr, _बेबी_, нек_,
   {{0x660903cb,0x7e6d0f1a,0x25ad3dcd,0x6d5c3dce}},	//   tzek, ncap, ttel_, _zira,
   {{0x6d5c007b,0x26cd3dcf,0x25ad3dd0,0x7f5d0069}},	//   _yira, rdeo_, utel_, _misq,
   {{0x6d5c01dd,0x2ed00299,0x25ad3dd1,0x66093dd2}},	//   _xira, _हफ्त, rtel_, rzek,
   {{0x25ad3dd3,0xa2a53dd4,0x6609006c,0x29070315}},	//   stel_, _काश्, szek, mhna_,
   {{0x16140354,0x6ef82df0,0x91e6174b,0x98be004b}},	//   _तेवर_, _tíbi, гоме, _bitė_,
   {{0xa2a50567,0x7e6d0051,0xe4c800d1,0x62840160}},	//   _कार्, dcap, ربین_, _veio,
   {{0x361a00c2,0xa2d408b6,0x2569004f,0xf592004f}},	//   _אונד, _बोर्, _iúl_, _الوج,
   {{0x7f5d3dd5,0x6d5c2fe8,0x602602fb,0xaf220033}},	//   _bisq, _rira, удва, _ভীষণ_,
   {{0x6d5c3dd6,0xbcfb3dd7,0xf8c000b4,0x7e6d3d14}},	//   _sira, _stép, _एस्प, gcap,
   {{0x25693dd8,0x7f5d02e1,0xa06a3dd9,0xd7f80019}},	// [35e0] _júl_, _disq, _папа_, _ngăn_,
   {{0xee371098,0x6c8600f3,0x6d5c3dda,0x7e6d0036}},	//   уну_, الام, _qira, acap,
   {{0x6d5c3ddb,0x9f5800da,0x290701a6,0x3cf10009}},	//   _vira, nyrë_, dhna_, _dozv_,
   {{0x6d5c24ef,0x7e6d027a,0x00000000,0x00000000}},	//   _wira, ccap, --, --,
   {{0x6d5c3ddc,0x427b02b5,0xa3ca0084,0x6e3d0345}},	//   _tira, גאנג, _रैन_, _gysb,
   {{0xa3e30311,0xbebb00da,0x2907035f,0xa3d6007c}},	//   नमा_, _njëj, ghna_, सिम_,
   {{0x672d1851,0xa2a5007c,0xc5f10083,0x69c90103}},	//   čajn, _काल्, _জেলা_, _esee,
   {{0xa6f400af,0xb6f40798,0xa2d4017f,0x63a13ddd}},	//   рзиш, рзиј, _बोल्, duln,
   {{0x948600af,0xe9da02ce,0xfaf70122,0x3b0703e6}},	//   лынд, _яка_, _עצמי_, _сето_,
   {{0x38c80164,0x290701c0,0x661d008d,0x63a1355f}},	//   _جاری_, chna_, úska, fuln,
   {{0x4c9b02b5,0x00000000,0x00000000,0x00000000}},	//   עשטע, --, --, --,
   {{0x395e3dde,0xa2a50099,0x00000000,0x00000000}},	//   _hits_, _काळ्, --, --,
   {{0x7f5d02e1,0x925800c3,0x395e3ddf,0x00000000}},	//   _risq, лают_, _kits_, --,
   {{0xbcfb2b01,0xbebb0031,0x7f5d0176,0x443c3de0}},	//   _cuél, _gjëj, _sisq, _tyv_,
   {{0x395e1192,0x53a80b35,0x00000000,0x00000000}},	//   _mits_, _कमिश, --, --,
   {{0x7f5d0510,0x395e3de1,0x7cf21217,0x00000000}},	//   _qisq, _lits_, _særp, --,
   {{0x7e6d20fb,0x2d8f006c,0x9d153de2,0x7f5d3576}},	// [35f0] rcap, ége_, адач, _visq,
   {{0x395e0443,0x22493de3,0x00000000,0x00000000}},	//   _nits_, _izak_, --, --,
   {{0xa3cd11b5,0x1cb81902,0x69c9073a,0x00000000}},	//   रिए_, طالب_, _ssee, --,
   {{0x395e01ef,0x2cb83de4,0x00000000,0x00000000}},	//   _aits_, _ebrd_, --, --,
   {{0xdd010723,0x7cdb0029,0xddc400af,0x6b6500c7}},	//   ştır, _pārē, rciţ, _mėgi,
   {{0x395e0029,0x69c9008b,0x6ce701e0,0x00000000}},	//   _cits_, _vsee, _сіме, --,
   {{0x395e2370,0x80ad04cc,0xbebb01f4,0xdb050079}},	//   _dits_, _जाने, _njëk, athá,
   {{0xb8fc0cf1,0x49753de5,0x69c90d4b,0x29073de6}},	//   _तो_, _влас, _tsee, shna_,
   {{0x09b83b94,0x395e024b,0xa2c4021a,0x273a0298}},	//   _مطلع_, _fits_, िजस्, eëns_,
   {{0x63a13de7,0x9f5801f4,0x3eab028b,0xe7870746}},	//   tuln, tyrë_, _lcct_, _будо,
   {{0xd874036b,0x29053de8,0x044510a9,0xe81c007c}},	//   _طالب, _illa_, ренн, _भइया_,
   {{0x216a093c,0x2569006c,0x28d90d1f,0x395e0312}},	//   кими_, _túl_, _योति, _zits_,
   {{0xe2970733,0x614601d3,0x3f8600a0,0x26cf3de9}},	//   шая_, иема, _ňou_, _iago_,
   {{0x81b800c8,0x26cf0033,0x2b5f0036,0x846702fb}},	//   ছিল_, _hago_, _liuc_, _съде,
   {{0xbcfb02d7,0x224901b7,0x61e20124,0x3f160279}},	//   _vuél, _ezak_, _šold, аќат,
   {{0x26cf3dea,0x527638bb,0x00000000,0x00000000}},	//   _jago_, _туку, --, --,
   {{0x2905087a,0xa3cd04aa,0x6da62695,0x433b0122}},	// [3600] _olla_, रिक_, риза, _בעקב,
   {{0x80ad0299,0x4096029f,0xaefb009e,0x3eb9008c}},	//   _जाये, _трит, _ciùb, _ebst_,
   {{0x24870c05,0x28a93b23,0xd00a0012,0x6cd306ca}},	//   _menm_, च्छि, _рене_, تقلا,
   {{0x29053deb,0x26cf3dec,0xeb972872,0xbebb01f4}},	//   _alla_, _nago_, риц_, _njëh,
   {{0x6f03002d,0x28e20d41,0x2b5f01da,0x00000000}},	//   _înca, पालि, _diuc_, --,
   {{0x89da04e8,0xdb05104b,0x00000000,0x00000000}},	//   _یوزر_, rthá, --, --,
   {{0xb8ce3ded,0x26cf0269,0xf09300a5,0x3a3f095f}},	//   _का_, _bago_, קנה_, _eyup_,
   {{0xd6d73dee,0x29053def,0xfaa308bb,0x395e3df0}},	//   ать_, _ella_, _масо, _wits_,
   {{0x26cf0291,0xa96a07e5,0xf5263df1,0x395e3df2}},	//   _dago_, _риза_, ифон, _tits_,
   {{0x6296030d,0xd9460573,0x00000000,0x00000000}},	//   _adyo, _тези, --, --,
   {{0x26cf0042,0x291c3df3,0x9cd90070,0xe2f90044}},	//   _fago_, miva_, אַרז, гені_,
   {{0xe61a2d13,0x291c3df4,0x26cf3df5,0x66e31c89}},	//   _иде_, liva_, _gago_, _моха,
   {{0x26c40169,0x7bda030a,0x24873df6,0x506702fb}},	//   memo_, _štul, _fenm_, итва,
   {{0x291c3df7,0x26cf0260,0x24870260,0x7c2e31bc}},	//   niva_, _zago_, _genm_, _oxbr,
   {{0x5f94002d,0xaefb009e,0x00000000,0x00000000}},	//   жист, _niùc, --, --,
   {{0x291c3df8,0x2fcd004e,0x26c4030a,0x6d4e007a}},	//   hiva_, łego_, nemo_, _ahba,
   {{0x2249027d,0x291c3df9,0x224000fd,0x8afd007e}},	// [3610] _uzak_, kiva_, _gyik_, _jiře,
   {{0x291c1851,0x61fd3dfa,0xe1ff004e,0xd6570122}},	//   jiva_, mysl, wców_, שימת_,
   {{0x291c03c9,0x41d5074f,0x2618007c,0x705500f8}},	//   diva_, दिवस, _बेसी_, _دندا,
   {{0x26c40888,0xf21c0299,0x6e3200b8,0xaefb009e}},	//   jemo_, _पेड़_, _žebř, _diùc,
   {{0x26c417ee,0xa9c7002d,0x26cf005f,0xe1ff0067}},	//   demo_, рсек, _rago_, rców_,
   {{0x3ea93dfb,0x7c2800cd,0x26cf08d7,0x672d1bd8}},	//   lgat_, _ždre, _sago_, čajm,
   {{0x260f0299,0x26cf2303,0xb3a901c2,0x26c43dfc}},	//   _तेजी_, _pago_, _çıxı, femo_,
   {{0x3ea90ec0,0x4429022f,0x656f031d,0x2b5f03d0}},	//   ngat_, _ća_, ícho, _uiuc_,
   {{0x291c3dfd,0x26cf3dfe,0x98c70665,0xa3a90099}},	//   biva_, _vago_, _всел, गून_,
   {{0xdb1c1010,0x29053573,0x93e20084,0x61fd3b03}},	//   _aprè, _ulla_, गमंच_, dysl,
   {{0x26cf07fb,0x96b90009,0x2bda0035,0x26c43dff}},	//   _tago_, _булу_, णिया, bemo_,
   {{0x442e01a2,0x26c419cd,0x6ef80138,0x05170033}},	//   _dxf_, cemo_, _líbr, ঠকের_,
   {{0x24870260,0x00000000,0x00000000,0x00000000}},	//   _tenm_, --, --, --,
   {{0x463a0070,0x21670210,0xdb1c021e,0x3ea90345}},	//   _גענע, сири_, _eprè, egat_,
   {{0xa3cd009a,0xd0072186,0x442e0176,0xdee63e00}},	//   रिओ_, бере_, _gxf_, бови,
   {{0x3ea9013c,0x291c05e2,0x98a7004e,0x237603fc}},	//   ggat_, ziva_, ronę_, _اميد_,
   {{0x10a600d4,0xc27b00a5,0xaefb01da,0x00000000}},	// [3620] _липн, _גרפי, _siùc, --,
   {{0x26c43e01,0x291c0176,0x3bd70069,0x00000000}},	//   zemo_, xiva_, _bħq_, --,
   {{0xcfea01ca,0x26c40010,0x69db0118,0xeb9a002d}},	//   _صفحه_, yemo_, _arue, уие_,
   {{0xfaa6204b,0x7d070009,0xa3ca021a,0x00000000}},	//   садо, _eljs, _रईस_, --,
   {{0xd94607be,0x26c43e02,0x315702fd,0x00000000}},	//   беди, vemo_, _خلیج_, --,
   {{0x26c430c6,0x7f443e03,0x69db3e04,0x00000000}},	//   wemo_, lliq, _drue, --,
   {{0x291c03c1,0x26c401d5,0x7cfb0160,0x6b65005f}},	//   riva_, temo_, _pîrv, _bėgu,
   {{0xa3d60fd0,0x69db36a2,0xc6f81f7e,0x7bdc3e05}},	//   सिस_, _frue, рних_, _irru,
   {{0x26c43e06,0x69db3e07,0x291c3e08,0x2d9202d0}},	//   remo_, _grue, piva_, nsye_,
   {{0x26c43e09,0x7d1e11a8,0x28bf02e4,0xbf050a40}},	//   semo_, nips, _शॉपि, _रत्न_,
   {{0xdb1c3e0a,0x187700a5,0x26180437,0x7bda022f}},	//   _apré, _העבר_, _बेरी_, _štuj,
   {{0xa3cd00dc,0x7d1e1008,0x7cfb0160,0x61fd0421}},	//   रिज_, hips, _hîrt, tysl,
   {{0x7d1e3e0b,0x66e51bb5,0x02aa0099,0xf204010b}},	//   kips, कारक_, _कारभ, пяро,
   {{0x2d92053e,0xf1273e0c,0x76420027,0x00000000}},	//   dsye_, сьмо, _iyoy, --,
   {{0x24b70122,0x753a099b,0xf04300b5,0x98a500cc}},	//   _ההון_, motz, سٹری, _xklđ_,
   {{0x69c01f5b,0x3ea90043,0x753a01a3,0x7642001c}},	//   _opme, ugat_, lotz, _kyoy,
   {{0x7bdc3e0d,0x3ea93e0e,0x7bce00d7,0xd0d501d3}},	// [3630] _arru, rgat_, _asbu, _допъ,
   {{0x628f3e0f,0x8c673e10,0x753a0065,0x6abb0036}},	//   laco, стад, notz, _sbuf,
   {{0x7f443e11,0x69c00080,0xbc4b0086,0x6f0300af}},	//   bliq, _apme, учае_, _înco,
   {{0x69db0083,0x672d022f,0x753a01d7,0x60c715a8}},	//   _prue, čajk, hotz, lejm,
   {{0x6f0d04d6,0x693503d0,0x7bdc06a2,0x753a01d7}},	//   mhac, онду, _erru, kotz,
   {{0xd36616e6,0xf77121a0,0x20110036,0x60c706fe}},	//   _يه_, واب_, ozzi_, nejm,
   {{0x776214fa,0x76420027,0x628f3e12,0x378602fb}},	//   _biox, _ayoy, kaco, общо_,
   {{0x6d453e13,0x69db0b41,0x6abb0010,0x628f0168}},	//   llha, _true, _ubuf, jaco,
   {{0xd6293e14,0x628f3e15,0x76420027,0x9f4a00a2}},	//   ропе_, daco, _cyoy, ômée_,
   {{0x753a01d7,0x26d901ba,0xe3b90dbf,0x3871013b}},	//   gotz, ôsob_, або_, _üzr_,
   {{0x02c6392c,0xd6ce042c,0x60c70035,0x657b3e16}},	//   ойно, رقی_, dejm, spuh,
   {{0x7bda080a,0x6d4502b1,0x657b02ee,0x00000000}},	//   _štuk, hlha, ppuh, --,
   {{0x6f0d00f1,0x2d4d01f2,0x32040237,0xa3cd0803}},	//   dhac, _džez_, ámy_, रिङ_,
   {{0x672901fe,0x6d453e17,0x320c0067,0x627e0067}},	//   lnej, jlha, ądy_, dłoż,
   {{0x656b3e18,0x61433e19,0x6b65010b,0x44213e1a}},	//   _hugh, фера, _mėgs, _äh_,
   {{0x6f0d0874,0x65633e1b,0x628f310f,0x67293e1c}},	//   ghac, _hinh, caco, nnej,
   {{0x65633e1d,0x80a5006c,0x20110036,0x64433e1e}},	// [3640] _kinh, _کمپن, azzi_, _hyni,
   {{0xdca33e1f,0x6563007a,0x2d9c3e20,0x64433e21}},	//   дафи, _jinh, čve_, _kyni,
   {{0x0b5a0763,0x65633e22,0x7d1e3e23,0x656b3e24}},	//   арды_, _minh, rips, _lugh,
   {{0xe9da3e25,0x65633e26,0x6f0d3e27,0x6729035f}},	//   ике_, _linh, chac, jnej,
   {{0x67293e28,0x6d45001e,0x656b0036,0x77620042}},	//   dnej, blha, _nugh, _riox,
   {{0xf8060086,0x628f3e29,0x65633e2a,0x6f040035}},	//   жчин, zaco, _ninh, lkic,
   {{0xe3a70357,0xeb972839,0x7bdc06a2,0x656b009e}},	//   _تر_, _мир_, _urru, _augh,
   {{0x6f043e2b,0x656b3e2c,0x65633e2d,0x60c73e2e}},	//   nkic, _bugh, _ainh, zejm,
   {{0x628f07c0,0x64430381,0x65633e2f,0x3cf8330b}},	//   vaco, _ayni, _binh, _korv_,
   {{0x2b460310,0xa3d63e30,0x32d70019,0x656b3e31}},	//   lloc_, सिल_, _ủy_, _dugh,
   {{0x65633e32,0x6443001e,0x628f027a,0x753a01d7}},	//   _dinh, _cyni, taco, rotz,
   {{0x65633e33,0x753a06a2,0x672901ba,0x61e223d8}},	//   _einh, sotz, cnej, _šola,
   {{0x628f15b3,0x753a02d7,0xdce639c0,0x226a00d5}},	//   raco, potz, _aukč, _šuká_,
   {{0x6563129d,0x67203b0a,0x3cf80185,0x00000000}},	//   _ginh, limj, _norv_, --,
   {{0x6f0d111c,0x20053e34,0x628f3e35,0x60c7068e}},	//   thac, áli_, paco, rejm,
   {{0xe7f21033,0x3eaf033b,0x2b4600af,0x6563021d}},	//   _अपना_, ügt_, jloc_, _zinh,
   {{0x20050936,0x63a802b2,0x6d450176,0xbcfb0453}},	// [3650] šli_, ludn, tlha, _muév,
   {{0x65633e36,0x67291f6f,0x672d05e2,0x3cf80051}},	//   _xinh, znej, čaji, _corv_,
   {{0x63a824d4,0x690f0a8a,0xdbd6018d,0x00000000}},	//   nudn, _høeg, jääg, --,
   {{0x6f043e37,0xddcd3e38,0xfbde0183,0x7d1c0103}},	//   ckic, mbaž, _drª_, _emrs,
   {{0x63a8042f,0x6f1d0037,0x67293e39,0x48e5002d}},	//   hudn, _imsc, vnej, золв,
   {{0xb17c02b8,0x656b3e3a,0x63a81f3d,0x7cfb0395}},	//   סטור, _rugh, kudn, _vîrs,
   {{0xa2ac02cb,0x63a83e3b,0x2b463e3c,0x07a53e3d}},	//   _झाल्, judn, bloc_, чайн,
   {{0x80bb0084,0x656b1727,0x63a8011e,0x2b463e3e}},	//   श्ते, _pugh, dudn, cloc_,
   {{0x656303e6,0x64433e3f,0xdddd00fe,0x00000000}},	//   _pinh, _syni, _fesť, --,
   {{0x67291912,0xe616021f,0x656b2cfa,0x00000000}},	//   snej, яды_, _vugh, --,
   {{0x65633e40,0x6f1d0a75,0x628d009e,0x00000000}},	//   _vinh, _omsc, _beao, --,
   {{0x6443024e,0x656b3e41,0x2ef90124,0x7989018e}},	//   _vyni, _tugh, _nosf_, _kwew,
   {{0x55e50369,0x6443006a,0x65633e42,0x9f5e0355}},	//   _холб, _wyni, _tinh, átí_,
   {{0x63a83e43,0x6f1d0312,0x79890c2f,0x00000000}},	//   budn, _amsc, _mwew, --,
   {{0x6f043e44,0xbebb01f4,0xdee63e45,0x9f5e00b8}},	//   tkic, _njës, пови, ští_,
   {{0x7d1c0506,0xdce600cd,0x1b010033,0x00000000}},	//   _smrs, _vukč, লোতে_, --,
   {{0x6f04040b,0xfbde021d,0x7989030d,0x00000000}},	// [3660] rkic, _srª_, _nwew, --,
   {{0x6f043e46,0xe81c007c,0x00000000,0x00000000}},	//   skic, _भइला_, --, --,
   {{0x79892884,0xe0fb011d,0x5fe021a8,0x7f4600c3}},	//   _awew, _הליל, _पछिल, _неож,
   {{0x7989001c,0x05bd00b4,0x00000000,0x00000000}},	//   _bwew, ्बाब, --, --,
   {{0xd9463e47,0xda16007c,0x67200207,0x3cf83e48}},	//   педи, _देखत_, vimj, _torv_,
   {{0x2d803e49,0xfe6f006c,0xed5700c3,0x307a016b}},	//   mpie_, _لگے_, _ноя_, זאַנ,
   {{0xab64033b,0x2b46011e,0x2d800345,0x2ca70453}},	//   grüß, ploc_, lpie_, ónde_,
   {{0x290e0054,0x32020328,0x00000000,0x00000000}},	//   shfa_, kyky_, --, --,
   {{0xb6c8006c,0x963410be,0xceb30070,0x67203e4a}},	//   ماکے_, ьниц, גיח_, rimj,
   {{0xa2a500b8,0x63a8035f,0x00000000,0x00000000}},	//   _काङ्, tudn, --, --,
   {{0x53353e4b,0x68e801b4,0x290c0055,0xa84a0079}},	//   дент, _indd, _ilda_, _الام_,
   {{0x68fa3e4c,0xdb1c01ef,0x63a80067,0x00000000}},	//   _hotd, _oprí, rudn, --,
   {{0x63a83e4d,0xaefb01da,0x75213e4e,0xc693025a}},	//   sudn, _diùl, bilz, _נאס_,
   {{0xbebb00da,0xd62506ca,0x63a800d5,0x00000000}},	//   _njër, _تعمي, pudn, --,
   {{0x4fc405f2,0xdb1c3e4f,0x2d8003bc,0x94bb00a5}},	//   нста, _aprí, epie_, _המות,
   {{0x290c0159,0xdb1c0037,0xaefb00f1,0xdb05008d}},	//   _llda_, _bprí, _giùl, sthú,
   {{0xe3b800d0,0xf1b13010,0x68e801a3,0xf2d4016b}},	// [3670] ltı_, _जमिन, _ondd, _נעץ_,
   {{0x68fa033b,0x291e0027,0xadb4002d,0x00000000}},	//   _notd, _nmta_, эбуш, --,
   {{0xe3b806d3,0xe4ed0803,0x79890345,0x00000000}},	//   ntı_, जाति_, _swew, --,
   {{0xf1b10953,0x290c3e50,0x6f1d033b,0xa3d30067}},	//   _जमान, _alda_, _umsc, _सैफ_,
   {{0xeab00037,0xa3d30067,0x00000000,0x00000000}},	//   اعم_, _सैन_, --, --,
   {{0xd04501c2,0xe3b8008f,0xbebb00da,0x3e7c00b8}},	//   _sahə, ktı_, _gjër, rátů_,
   {{0x32020187,0xb09c0070,0x68fa0069,0xb8d50d4e}},	//   zyky_, מיגר, _dotd, _झा_,
   {{0xe5790eee,0xfbd20122,0x290c3e51,0x68e801b4}},	//   ози_, _בתל_, _elda_, _endd,
   {{0x7ae93e52,0x1de0018d,0xeaf80079,0x00000000}},	//   _inet, नियत, _عرفت_, --,
   {{0x7afb0c7c,0x257200e9,0x15f40067,0x00000000}},	//   _hout, _dâl_, ेनजर_, --,
   {{0x7afb0c1f,0xbcfb00de,0x7ae93e53,0x7521021d}},	//   _kout, _hués, _knet, rilz,
   {{0x6f030043,0x7afb0086,0x2d990116,0xbddb0260}},	//   _înch, _jout, _ovse_, _pyèl,
   {{0x60d70095,0x68e8001e,0x7afb3e54,0xd70601e0}},	//   _baxm, _yndd, _mout, _інше_,
   {{0x7afb3e55,0x672d00cd,0xbcfb02d7,0xa5b20067}},	//   _lout, čaju, _mués, _आमतौ,
   {{0x7ae93e56,0xdb1c01ba,0xa0673e57,0x50433e58}},	//   _onet, _sprí, дара_, верб,
   {{0x7afb3e59,0x7dd800b5,0x7ae90103,0x00000000}},	//   _nout, júsá, _nnet, --,
   {{0x60d73e5a,0xddc60067,0x00000000,0x00000000}},	// [3680] _faxm, _szkł, --, --,
   {{0x7ae93e5b,0x2d803e5c,0x51f7006c,0xef1f00be}},	//   _anet, rpie_, _آسٹر, _emü_,
   {{0x7afb24e0,0x6286006d,0x2d800096,0x8e863e5d}},	//   _bout, obko, spie_, _огне,
   {{0x7afb3e5e,0xe51d045c,0x7ae900f6,0xbcfb02d7}},	//   _cout, योति_, _cnet, _suét,
   {{0x7afb3e5f,0xfe420332,0xb17b01b4,0x80bb1371}},	//   _dout, _شکری, rvåg, श्वे,
   {{0xe3b800a8,0x7ae93e60,0xbebb0031,0x00000000}},	//   ytı_, _enet, _ujër, --,
   {{0x7afb3e61,0xe3b80095,0x3b0a3e62,0x2572016e}},	//   _fout, xtı_, _дево_, _sâl_,
   {{0x7afb2154,0x7ae93e63,0xb9050026,0xd7570037}},	//   _gout, _gnet, _बो_, وجيا_,
   {{0xa3b00378,0x68fa3e64,0x34943d53,0xf77200b5}},	//   टून_, _totd, напр, راں_,
   {{0x7afb02e9,0xe3b801d6,0xbcfb0453,0xbf1b0803}},	//   _zout, ttı_, _huér, _नग्न_,
   {{0x7afb3e65,0x48eb0066,0x2be105a2,0x798200fe}},	//   _yout, चारो_, फिया, lpow,
   {{0xe3af00bf,0xe3b800d0,0x3863006c,0x257200e9}},	//   گری_, rtı_, _újra_, _tâl_,
   {{0x672d0b67,0xe3b801fb,0x6f030395,0x00000000}},	//   čajt, stı_, _înci, --,
   {{0xe3af0a86,0xe3b8027d,0x00000000,0x00000000}},	//   دری_, ptı_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcc702cb,0x79820159,0x7d0e3e66,0xa3db0096}},	//   रज्ञ, kpow, _albs, ठिर_,
   {{0xa3d625d8,0x7afb1de8,0x98be0260,0x60d73e67}},	// [3690] सिक_, _rout, _aktč_, _taxm,
   {{0x7afb3e68,0x2249067f,0x7059201f,0x7ae93e69}},	//   _sout, _iyak_, _напр_, _snet,
   {{0xfe7000f5,0x7afb3e6a,0x28d90ed1,0x1eaa05f5}},	//   ادہ_, _pout, _योगि, _کاپي_,
   {{0x80bb1db9,0xd6d9004e,0x3f83003c,0x7afb0051}},	//   श्रे, koła_, mpju_, _qout,
   {{0x7afb3e6b,0x7bda3e6c,0x7ae9008b,0xa2d73e6d}},	//   _vout, _štut, _vnet, _बसन्,
   {{0xc9843961,0x23690221,0xe9d81958,0x7afb3e6e}},	//   туци, _liaj_, ькі_, _wout,
   {{0x7afb3e6f,0xf74533ce,0xe77800b5,0x5ed20033}},	//   _tout, неко, ولوں_, হারে,
   {{0x23690189,0x7ae93e70,0xbcfb00f7,0x6fc200ab}},	//   _niaj_, _unet, _guér, _लहसू,
   {{0x05650043,0x00000000,0x00000000,0x00000000}},	//   нвин, --, --, --,
   {{0xf80703ad,0x00000000,0x00000000,0x00000000}},	//   _очен, --, --, --,
   {{0x8cc104cc,0x2249027d,0x644f0067,0x00000000}},	//   र्यो, _ayak_, ęcio, --,
   {{0x23690189,0x00000000,0x00000000,0x00000000}},	//   _ciaj_, --, --, --,
   {{0x64a53e71,0xe60e10da,0x00000000,0x00000000}},	//   _зала, _сд_, --, --,
   {{0x26183e72,0x8cc122a7,0x25ad3e73,0x80bb06bc}},	//   _बेटी_, र्मो, muel_, श्ले,
   {{0xdfd20098,0x224901ef,0x2f563379,0x79820067}},	//   ديز_, _eyak_, етас, zpow,
   {{0xdb1c024e,0xdcba11b5,0x3cea0051,0x00000000}},	//   _oprá, ैज्ञ, _snbv_, --,
   {{0x6da30fbb,0xada3021d,0x7bc73e74,0x00000000}},	// [36a0] лита, латл, _apju, --,
   {{0x02c10fbf,0x00000000,0x00000000,0x00000000}},	//   ष्ठभ, --, --, --,
   {{0x1ee8006c,0xbcfb00f7,0x25ad0453,0x7ac617f9}},	//   _ہوگی_, _puér, huel_, есле,
   {{0x61e40496,0x25ad0034,0xbcfb3e75,0x8cc10fcf}},	//   _kril, kuel_, _quér, र्बो,
   {{0xdced0484,0x61e2011c,0x00000000,0x00000000}},	//   ssaġ, _šolj, --, --,
   {{0x3eb200c7,0x6b51013c,0x25ad3e76,0x7b130183}},	//   lgyt_, råga, duel_, _açud,
   {{0xfaa601c8,0xb7663367,0x00000000,0x00000000}},	//   _паво, нтий, --, --,
   {{0x61e40453,0x6d5e0f0a,0xd90e01df,0x00000000}},	//   _oril, lmpa, _گیت_, --,
   {{0x25ad1f4f,0x6d5e0079,0x00000000,0x00000000}},	//   guel_, ompa, --, --,
   {{0xe9d700d4,0x6b9c0506,0x00000000,0x00000000}},	//   _яку_, _kvrg, --, --,
   {{0x66e61738,0xdb1c000c,0x22491051,0x24181667}},	//   _пожа, _zprá, _syak_, фоны_,
   {{0x201800d7,0x6b9c0051,0x00000000,0x00000000}},	//   dzri_, _mvrg, --, --,
   {{0x23693e77,0x690600fb,0x61e40523,0x26180066}},	//   _viaj_, _aðei, _cril, _बेची_,
   {{0x2eeb00f7,0x61e40e6d,0x6b9c023a,0x00000000}},	//   _sncf_, _dril, _ovrg, --,
   {{0xb4be065a,0x23690221,0x61e41246,0xb4ac16d3}},	//   ुजी_, _tiaj_, _eril, गली_,
   {{0x61e433d4,0x2249010d,0x00000000,0x00000000}},	//   _fril, _tyak_, --, --,
   {{0x67220657,0x6ca70235,0x656a02c4,0x31720118}},	// [36b0] _mmoj, ереж, _kifh, _guyz_,
   {{0x63a83e78,0x656a035f,0x00000000,0x00000000}},	//   ordn, _jifh, --, --,
   {{0xdb1c3e79,0x6e2a00a8,0x9be4010b,0x6ef80168}},	//   _sprá, _əlbə, ліцк, _líby,
   {{0xa5a10035,0x6d5e3e7a,0x00000000,0x00000000}},	//   _खिलौ, ampa, --, --,
   {{0x25ad3e7b,0x0ab43e7c,0x63a800d5,0x644a3e7d}},	//   xuel_, احمد, hrdn, _lyfi,
   {{0x7f4d2318,0xbb850037,0x656a035f,0x6722034d}},	//   llaq, _للسي, _nifh, _amoj,
   {{0xe73918cd,0x644a3e7e,0x58940037,0x00000000}},	//   мек_, _nyfi, اجهز, --,
   {{0x25ad3e7f,0xe9ff0023,0xb8830355,0xb21b008d}},	//   tuel_, _chảo_, _svíč, rbæj,
   {{0xaefb01a6,0x6f0300af,0x6b6c0225,0x6d470069}},	//   _ciùi, _încu, _işga, _kkja,
   {{0x25ad05c9,0x80ad2561,0xaefb01da,0x61e40024}},	//   ruel_, _जागे, _diùi, _rril,
   {{0x644a001e,0x25ad3e80,0x63a800cd,0x00000000}},	//   _cyfi, suel_, grdn, --,
   {{0x60ce01f7,0x644a3e81,0x8cc1021a,0x00000000}},	//   webm, _dyfi, र्तो, --,
   {{0x25ad3e82,0x1c1e00a1,0x6d5e22ee,0x1a9a016b}},	//   quel_, _येईल_, ympa, וירע,
   {{0x7e7d3e83,0x656a3e84,0x20d50044,0x28c40b35}},	//   _afsp, _gifh, лісс, ल्पि,
   {{0x21670948,0x764b001e,0x644a00e9,0x00000000}},	//   тири_, _hygy, _gyfi, --,
   {{0x61e43e85,0x69c92193,0x6d470523,0x84640382}},	//   _tril, _opee, _akja, _съче,
   {{0x0e663e86,0x6b9c0b16,0x69c9006d,0x61e4002d}},	// [36c0] ткан, _svrg, _npee, _uril,
   {{0xdced00a8,0xd2570277,0x00000000,0x00000000}},	//   rpağ, _בשפה_, --, --,
   {{0xeb973e87,0x28c40026,0x6d5e03d0,0xdbcc01ef}},	//   вих_, ल्फि, rmpa, _póña,
   {{0xfaa60c9f,0x6207008d,0x00000000,0x00000000}},	//   тадо, _örlí, --, --,
   {{0xceb300c2,0x827702b5,0x6a160098,0x98be00ec}},	//   _דיר_, דענע_, خبار, _aktā_,
   {{0x6b5825ec,0xa3e400b4,0x92ce0033,0x67220124}},	//   díge, निम_, রায়_, _smoj,
   {{0xdbcc008a,0xc0100019,0x69c91235,0xaefb01da}},	//   _góða, _đuổi_, _epee, _siùi,
   {{0x95d8107b,0xceb40095,0xc6230083,0xdb1c3e88}},	//   едит_, ciət_, _পড়া_, _spræ,
   {{0xaa463e89,0x948600af,0x5b3500af,0xb0b2073f}},	//   _реал, кынд, _сэру, _जांग,
   {{0x6ad21a75,0xb4ac3e8a,0x44f428a1,0x03f80274}},	//   _ससुर, गले_, упос, еној_,
   {{0xe9ff0028,0x92953e8b,0xd6cf1743,0x00000000}},	//   _thảo_, ланц, _кт_, --,
   {{0xf6262d38,0x67220657,0x762600af,0x644a00d5}},	//   _идео, _umoj, _имез, _vyfi,
   {{0x69dd003e,0x63a800cd,0x644a0b88,0x00000000}},	//   _áset, srdn, _wyfi, --,
   {{0x34943e8c,0xdb05000d,0x2f15008c,0x00000000}},	//   _сакр, rrhé, _måge_, --,
   {{0x40350370,0x7f4d009f,0xe7e50a40,0x7528013a}},	//   уевс, tlaq, किया_, midz,
   {{0x75280029,0x6d473e8d,0xfcd9006c,0xb7db0317}},	//   lidz, _skja, کارڈ_, וקלי,
   {{0x2d8f02e1,0x7f4d0510,0x7e5501e0,0x26c6023c}},	// [36d0] ège_, rlaq, уває, _mboo_,
   {{0x48bd0033,0x9d14002d,0x75283e8e,0x00000000}},	//   _আফ্র, адуч, nidz, --,
   {{0x69c93e8f,0x7a0a00ea,0x7f4d00f6,0xf1bf014c}},	//   _spee, _lētā, plaq, ltá_,
   {{0x6f160af9,0x6b51013c,0x7b3c0207,0x2f150523}},	//   chyc, rågo, jčud, _båge_,
   {{0x8d87021d,0xf1bf3e90,0xb0c00246,0x7b130132}},	//   _шунд, ntá_, श्वग, _açuc,
   {{0x6f0d3e91,0x26c60103,0xb4ac0099,0xf1bf021d}},	//   lkac, _aboo_, गलो_, itá_,
   {{0xf7710206,0x6d450138,0x31580070,0x00000000}},	//   حات_, moha, דיגן_, --,
   {{0x6d453e92,0xdb05004f,0x6f0d3e93,0x00000000}},	//   loha, rthó, nkac, --,
   {{0x645c008a,0x66050421,0x00000000,0x00000000}},	//   ýrin, уппа, --, --,
   {{0x6d453e94,0x7c28022f,0x6b581db8,0xe6160421}},	//   noha, _ždri, ríge, удь_,
   {{0xc2090d85,0xf1bf0183,0x00000000,0x00000000}},	//   _צה_, etá_, --, --,
   {{0xa77a02b5,0x2a690009,0x6d45081b,0xd838002d}},	//   _טרעפ, žabu_, hoha, _рэу_,
   {{0x6d453e95,0x35a5021d,0x67293e96,0xe5a51d99}},	//   koha, _салг, miej, _сили,
   {{0x6d453e97,0x672900d8,0x3ea2012f,0xf4870368}},	//   joha, liej, _sdkt_, _рудн,
   {{0x26dd3e98,0x6609006c,0x6d453e99,0x37c30083}},	//   _kawo_, lyek, doha, ্মকর,
   {{0x67293e9a,0x26df010b,0x00000000,0x00000000}},	//   niej, nduo_, --, --,
   {{0x66093e9b,0x25bf0012,0xecea3e9c,0xccc60036}},	// [36e0] nyek, ntul_, ндал_, лбай,
   {{0x62960430,0x98a7010b,0x25bf00af,0x26dd0103}},	//   _heyo, monė_, itul_, _lawo_,
   {{0x6f1624a1,0x4aaa021d,0x62960103,0xa25b0183}},	//   phyc, екен_, _keyo, nfôn,
   {{0x6f0d3e9d,0x26dd04fb,0x6296021e,0xa3e43e9e}},	//   ckac, _nawo_, _jeyo, नित_,
   {{0x6d453e9f,0xe81c0035,0x67293ea0,0xceb400a8}},	//   boha, _भेजा_, diej, rhəd_,
   {{0x6d453ea1,0x212a006b,0x6f03002d,0xdb1c01ff}},	//   coha, nibh_, _încr, _sprä,
   {{0x26dd3ea2,0x6d5c3ea3,0x60de01e9,0x00000000}},	//   _bawo_, _ihra, _mapm, --,
   {{0x62963ea4,0x758a0340,0x75280035,0x6609023c}},	//   _neyo, нсов_, widz, fyek,
   {{0x8cc113f0,0xe9ff0023,0x1514027a,0x1634188d}},	//   र्वो, _thạo_, идия, репя,
   {{0x88bc000c,0x8386005f,0x00000000,0x00000000}},	//   _změn, лыме, --, --,
   {{0xb6a6027a,0x75283ea5,0xdb1e01f4,0x62963ea6}},	//   _биел, ridz, jtpë, _beyo,
   {{0x6676004f,0x66093ea7,0xa3a9162b,0x26dd0107}},	//   _إدار, byek, गंज_, _gawo_,
   {{0x6d4503be,0x25bf0012,0x6d5c3ea8,0x62960260}},	//   yoha, ctul_, _ohra, _deyo,
   {{0xf1bf3ea9,0x26dd007b,0x60de3eaa,0x6f0d0067}},	//   rtá_, _zawo_, _capm, wkac,
   {{0x6f0d3eab,0xf1bf0237,0xe47b00a5,0x26dd04fb}},	//   tkac, stá_, _ארוכ, _yawo_,
   {{0xfe7302e7,0x6d453eac,0x6296030d,0xe7e50127}},	//   صدر_, woha, _geyo, किता_,
   {{0x6d453ead,0x6d5c066a,0x6f0d3eae,0xcec000b8}},	// [36f0] toha, _bhra, rkac, ířat_,
   {{0xb0b2006a,0x6d5c1a07,0x6729010b,0x6f0d088a}},	//   _जाएग, _chra, ziej, skac,
   {{0x6d453eaf,0x62963eb0,0x6d5c3eb1,0xa2bc364c}},	//   roha, _yeyo, _dhra, ष्क्,
   {{0x6d451fd9,0x98a90254,0x645d00a8,0x8c6430cc}},	//   soha, đač_, əsid, студ,
   {{0x60de0723,0x6d5c09c3,0x67293eb2,0x25bf002d}},	//   _yapm, _fhra, viej, xtul_,
   {{0x6d5c09c3,0xbebb0031,0x26dd3eb3,0x645807c0}},	//   _ghra, _njëz, _sawo_, _ozvi,
   {{0xdb1c1bb4,0x67293eb4,0xa802027b,0xb8cd00ab}},	//   _språ, tiej, şınl, _कय_,
   {{0x66090118,0x88bc00b8,0x661b01d7,0x25bf05f5}},	//   tyek, _uměn, tzuk, ttul_,
   {{0x67293eb5,0x45350994,0x62963eb6,0x00000000}},	//   riej, ихот, _reyo, --,
   {{0x25bf0043,0x661b3eb7,0x62961d24,0x6729297a}},	//   rtul_, rzuk, _seyo, siej,
   {{0x661b006a,0x25bf0012,0x26dd0b04,0x47d50037}},	//   szuk, stul_, _tawo_, _خيار,
   {{0x39473eb8,0x25bf0012,0xb17b013c,0x232a1e9c}},	//   lons_, ptul_, rvån, томи_,
   {{0x80df0083,0xaefb01da,0x443c0282,0x60de008c}},	//   মান্, _liùs, _exv_, _papm,
   {{0x39473eb9,0x73e51303,0x660600c3,0x25ad00a0}},	//   nons_, _вокз, äkke, mrel_,
   {{0x5f063eba,0xdfd2004f,0x1e96002d,0x212a0874}},	//   азва, غير_, ирар, ribh_,
   {{0x1e8614a1,0x6d5c3ebb,0x394700f7,0x60de3ebc}},	//   рлам, _shra, hons_, _wapm,
   {{0x60de3ebd,0xa15601d3,0x6d5c3ebe,0x39470555}},	// [3700] _tapm, _външ, _phra, kons_,
   {{0xdca63dd9,0x39470029,0x6abb0036,0x8cc10ac4}},	//   ражи, jons_, _acuf, र्लो,
   {{0x161d0026,0x60c300b5,0x00000000,0x00000000}},	//   _बेघर_, _önma, --, --,
   {{0xdee632a6,0x25ad11cb,0x00000000,0x00000000}},	//   _томи, krel_, --, --,
   {{0x6d5c3ebf,0x39473ec0,0xd90d09b9,0xaefb009e}},	//   _thra, fons_, کیل_, _shùg,
   {{0x6d5c3ec1,0x97a63ec2,0x39473ec3,0xb21b008d}},	//   _uhra, арил, gons_, mbæt,
   {{0xf0930052,0xeb972028,0x81cc0033,0x5ed90033}},	//   חנו_, _вис_, রটি_, ডারে,
   {{0xbb430012,0xa3e42e64,0x7bdc005f,0xab6908cf}},	//   _деск, निस_, _isru, _محقق_,
   {{0xc6f7342d,0x25ad3ec4,0x2b390144,0xbddb00a2}},	//   рных_, grel_, _сярэ_, _hyèr,
   {{0x07a60df8,0x81cc0083,0x7ae23ec5,0x7ae03ec6}},	//   _важн, রটা_, ldot, _hamt,
   {{0x3c77011d,0x69c23ec7,0x2f1501ff,0x7ae03ec8}},	//   יתים_, ltoe, _låga_, _kamt,
   {{0x7ae23ec9,0x268a0413,0x443c02d7,0x8646244d}},	//   ndot, _شخصي_, _vxv_, _кнеж,
   {{0x69c20a55,0x273a00ea,0x7ae20228,0x00000000}},	//   ntoe, cīna_, idot, --,
   {{0x29c201a5,0x7ae03eca,0x7ae200c3,0x2d050099}},	//   _mưa_, _lamt, hdot, _शकेल_,
   {{0x753d0332,0x7ae23ecb,0x645825d2,0x69c20086}},	//   észe, kdot, _uzvi, htoe,
   {{0x7ae03ecc,0x69c23ecd,0x00000000,0x00000000}},	//   _namt, ktoe, --, --,
   {{0x629d3ece,0x39470248,0x7ae23b02,0x7bdc2d14}},	// [3710] maso, yons_, ddot, _asru,
   {{0x39473ecf,0x6abb3ed0,0x30a73ed1,0xaefb0211}},	//   xons_, _scuf, _трив, _ciùr,
   {{0x39470248,0xaefb0284,0x69c20d35,0xbddb0260}},	//   vons_, _diùr, etoe, _pyès,
   {{0x06ac00c8,0x7ae21b86,0x28c40266,0x69c201bf}},	//   ক্তি, gdot, ल्सि, ftoe,
   {{0xa2bc0d53,0x39473ed2,0x29c20023,0xaefb0211}},	//   ष्ट्, tons_, _cưa_, _fiùr,
   {{0x629d3ed3,0x5f7400f8,0x88bc01c0,0x29c20023}},	//   haso, _دایر, _uměl, _dưa_,
   {{0x39473ed4,0xb8ff1782,0xfb84010b,0xbddb0260}},	//   rons_, _तस_, _мытн, _tyès,
   {{0x497516c0,0x7ae000d8,0x39473ed5,0x7ae23ed6}},	//   _глас, _gamt, sons_, cdot,
   {{0x629d3ed7,0x39473e54,0x69c21c5b,0x69db3ed8}},	//   daso, pons_, ctoe, _usue,
   {{0x657b3ed9,0x25ad3eda,0x8cca0266,0x00000000}},	//   rquh, rrel_, स्पो, --,
   {{0xe29a05c2,0x94070095,0x04450fa4,0x629d3edb}},	//   лан_, _yenə_, сенн, faso,
   {{0x29053edc,0x68e109bd,0x2d853e39,0x629d3edd}},	//   _hola_, _hald, _člen_, gaso,
   {{0x68e13ede,0x29053edf,0x29c201a5,0x28c400b4}},	//   _kald, _kola_, _xưa_, ल्वि,
   {{0xe3b9052a,0x68e300da,0x61e202c6,0xa3e4035d}},	//   _ббк_, ndnd, _šols, निश_,
   {{0x29053ee0,0x09d413ab,0x629d3ee1,0x8cca0f3d}},	//   _mola_, _धन्य, baso, स्फो,
   {{0x29053ee2,0x629d0b4c,0x69c20298,0xaefb009e}},	//   _lola_, caso, ytoe, _siùr,
   {{0x7ae008c8,0x63a30103,0xaefb009e,0x6da602c8}},	// [3720] _ramt, _hvnn, _piùr, сиза,
   {{0x7ae03ee3,0x29050291,0xaefb0211,0x2f153ee4}},	//   _samt, _nola_, _chùb, _våga_,
   {{0x940c01c2,0x7ae003fd,0x2360006d,0x7ae23ee5}},	//   fadə_, _pamt, _khij_, tdot,
   {{0xb21b0093,0x9b250131,0x2b5f3ee6,0x68e10051}},	//   mbær, офіл, _chuc_, _aald,
   {{0x68e13ee7,0x29053ee8,0xd91009b9,0xadc30019}},	//   _bald, _bola_, ویر_, _thạc,
   {{0xdd8f004f,0x69c22069,0xa802027d,0xd94300c3}},	//   _سوف_, rtoe, şıml, печи,
   {{0x29053ee9,0x69c23eea,0x629d3eeb,0x7ae03eec}},	//   _dola_, stoe, yaso, _tamt,
   {{0xdc3702b5,0x69c23eed,0x6f06023a,0x00000000}},	//   _האלט_, ptoe, _jokc, --,
   {{0x68e1054e,0x629d3eee,0x6b583eef,0x80df0083}},	//   _fald, vaso, lígo, মাত্,
   {{0x68e13ef0,0x629d25b4,0x28c40035,0x18a31156}},	//   _gald, waso, ल्शि, _наум,
   {{0x629d3ef1,0x8cca0035,0x06e00033,0xd90f00b5}},	//   taso, स्यो, ভাবি, _سیٹ_,
   {{0x23a90992,0x23600221,0x68e101d7,0x2d050066}},	//   _किरद, _chij_, _zald, _शक्ल_,
   {{0x629d3ef2,0x290504d4,0xdcef002d,0x6d4e2b10}},	//   raso, _yola_, _jucă, _okba,
   {{0x463b02b5,0x629d06a2,0x777a01d7,0x940c00a8}},	//   _געדע, saso, _kutx, zadə_,
   {{0x4ac80567,0x5f943ef3,0x629d3ef4,0xaac81782}},	//   रभाव, зист, paso, रभाक,
   {{0x6d4e3ef5,0x777a3ef6,0x00000000,0x00000000}},	//   _akba, _mutx, --, --,
   {{0x3f9e008d,0x246e00a8,0x777a01b7,0xaefb009e}},	// [3730] átur_, ləm_, _lutx, _phùb,
   {{0xe29f008a,0x61ed0065,0xfe7f00a2,0x00000000}},	//   lað_, _iral, _saïd_, --,
   {{0xf2dc0033,0x2b5f0023,0x61ed00a0,0x246e00a8}},	//   ধারণ, _phuc_, _hral, nəm_,
   {{0xe29f00fb,0x61ed0a23,0x29053ef7,0x78a80069}},	//   nað_, _kral, _sola_, _addv,
   {{0x29053612,0x68e13ef8,0x99d7004f,0x210d00a1}},	//   _pola_, _pald, إتصا, _सकाळ_,
   {{0x68e10095,0xdb23006c,0xa969020a,0x777a0310}},	//   _qald, _کوری, шила_, _butx,
   {{0xe29f008a,0x68e13ef9,0x29053efa,0x2b5f0023}},	//   kað_, _vald, _vola_, _thuc_,
   {{0x68e13efb,0xd6ce026e,0x05a93efc,0x777a27aa}},	//   _wald, نقى_, авий_, _dutx,
   {{0x68e103cb,0x29053efd,0x5bc90006,0xe29f008d}},	//   _tald, _tola_, _रहुव, dað_,
   {{0xb4b33efe,0x628432b0,0x79890371,0xdb1c035b}},	//   टले_, _sfio, _itew, _sprø,
   {{0x61ed3eff,0x7bc53f00,0x777a0291,0x3940004f}},	//   _aral, nthu, _gutx, éise_,
   {{0x61ed3f01,0xe29f0093,0x7bc53f02,0x3ce33f03}},	//   _bral, gað_, ithu, _lajv_,
   {{0x64a5145c,0x61ed009e,0x6f06023a,0x00000000}},	//   _дала, _cral, _rokc, --,
   {{0xe3b10cd1,0x00000000,0x00000000,0x00000000}},	//   _قرب_, --, --, --,
   {{0xa06a3335,0x61ed3f04,0x2360006d,0xe7ec2907}},	//   рава_, _eral, _thij_, झिया_,
   {{0x61ed3f05,0x6aa9002f,0x224001ed,0xb21b3f06}},	//   _fral, _ndef, _txik_, rbær,
   {{0x7d071901,0x00000000,0x00000000,0x00000000}},	// [3740] _bojs, --, --, --,
   {{0x27160096,0x6aa90176,0x9f4100d5,0x6b58301c}},	//   _तत्र_, _adef, _vrhá_, tígo,
   {{0x8b2600d4,0x7bc53f07,0x6d4e0051,0x7989007b}},	//   одже, gthu, _vkba, _atew,
   {{0xa802027d,0x9f4100d5,0xd83807e7,0x00000000}},	//   şıkl, _trhá_, _ječe_, --,
   {{0x6aa90297,0x3ea03f08,0xd9462b65,0x2d4f0443}},	//   _ddef, mait_, оеди, gües_,
   {{0x3ea03f09,0xed570a71,0xda651902,0xf1bf00b5}},	//   lait_, _моя_, ساني, szág_,
   {{0xd7fa09eb,0xfbc33f0a,0x7989030d,0x7bc500cc}},	//   рул_, _обро, _etew, cthu,
   {{0x3ea03f0b,0xc6f81f7e,0xd83819cd,0x00000000}},	//   nait_, сних_, _neče_, --,
   {{0xe29f008a,0xb0ca0084,0x50ca0d4e,0xdcee3f0c}},	//   vað_, िभाग, िभाष, _libč,
   {{0x38c8064e,0x61ed01f4,0xdb21006c,0x3ea03f0d}},	//   _داری_, _rral, ütör, hait_,
   {{0xe29f00fb,0x06ac0083,0x3ea01511,0x61ed0124}},	//   tað_, ক্ষি, kait_, _sral,
   {{0x246e01c2,0x61ed3f0e,0x066500bf,0x8cca0162}},	//   rəm_, _pral, _کامپ, स्तो,
   {{0xe29f008a,0x3ea03f0f,0x363600f8,0x41e402a4}},	//   rað_, dait_, _براس, міра,
   {{0xe29f0093,0x7bc500e9,0x00000000,0x00000000}},	//   sað_, ythu, --, --,
   {{0xbbc90311,0xe29f0093,0x7d07008b,0x3ea000f7}},	//   _रहेक, pað_, _rojs, fait_,
   {{0x61ed3f10,0x06ac0033,0x3ea0026b,0x23280200}},	//   _tral, ক্রি, gait_, _моји_,
   {{0x61ed3f11,0x753a01a3,0x3f570225,0x00000000}},	// [3750] _ural, ontz, lçuk_, --,
   {{0xed5104cd,0x7bc53f12,0x00000000,0x00000000}},	//   رپا_, tthu, --, --,
   {{0x7d0730b0,0x3ea03f13,0x753a01d7,0x7bc53f14}},	//   _vojs, bait_, intz, uthu,
   {{0x7bc53f15,0x7d070035,0x61290009,0x776200e2}},	//   rthu, _wojs, džli, _nhox,
   {{0x7bc52726,0xa3e1111e,0x7d0701e8,0x19590409}},	//   sthu, _नैन_, _tojs, бады_,
   {{0x2795034b,0x00000000,0x00000000,0x00000000}},	//   пшир, --, --, --,
   {{0x48093f16,0x80cd00e7,0x00000000,0x00000000}},	//   сейн_, द्ये, --, --,
   {{0x753a06a2,0x7b3c0009,0x65680345,0xb6a500af}},	//   entz, nčul, emdh, чиил,
   {{0x64460dac,0xd83817ee,0xc8f90033,0x79890371}},	//   şkil, _reče_, _অতীত_, _utew,
   {{0x58bb05bc,0x6e20007c,0xe5760862,0xd8383f17}},	//   _خارج_, _ümbe, язь_, _seče_,
   {{0x6d890038,0x3ea03f18,0x767520a6,0xa2e60f9e}},	//   _hľad, yait_, _елеф, понд,
   {{0x07080098,0x62810035,0x753a01a3,0x77620024}},	//   _ويلي_, ślon, antz, _ghox,
   {{0x3ea00248,0x2bd22095,0xd838011c,0x2131022e}},	//   vait_, _सहभा, _veče_, fizh_,
   {{0x645d0669,0xdd920332,0xeb0807ba,0xeb180d2a}},	//   əsin, ہور_, _वक्त_, _दत्त_,
   {{0x3ea03f19,0xd83815d7,0xd25900ea,0x442122ac}},	//   tait_, _teče_, ļņa_, _åh_,
   {{0x673b3f1a,0x0d8602c4,0xdd92211f,0x00000000}},	//   nnuj, злан, فور_, --,
   {{0x3ea0234d,0xfe433f1b,0xc3330d85,0x00e4006c}},	// [3760] rait_, енто, _רוח_, _ہتھی,
   {{0x3ea03f1c,0x00000000,0x00000000,0x00000000}},	//   sait_, --, --, --,
   {{0x3ea03f1d,0xa3e40a5e,0xc0470023,0x307b00a5}},	//   pait_, निए_, _mượn_, _לאינ,
   {{0xc0470023,0x62862579,0x63be01e0,0x00000000}},	//   _lượn_, ncko, _åpne, --,
   {{0xceb30779,0xd6c30083,0x5ec50033,0x02c106fe}},	//   _איר_, ্যায, _লোকে, ष्टभ,
   {{0x6f041851,0x00000000,0x00000000,0x00000000}},	//   ljic, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ae33f1e,0x6f0402dd,0x753d00fd,0x25e8021a}},	//   _посм, njic, észn, जिली_,
   {{0x6e243f1f,0xbb433f20,0x00000000,0x00000000}},	//   nzib, _четк, --, --,
   {{0x47d40083,0x77690051,0x00000000,0x00000000}},	//   থিবী, amex, --, --,
   {{0xa2c11746,0x753a01ed,0x00000000,0x00000000}},	//   _वाद्, rntz, --, --,
   {{0x1dac0fd1,0xf6e500d4,0x6aa20054,0x9294010b}},	//   _चिंत, _оцін, naof, наюц,
   {{0x6f040a66,0x87250037,0x9f470118,0x00000000}},	//   djic, _تعلم, _éné_, --,
   {{0x98a700af,0x6e243f21,0xe3af00fd,0x27e90067}},	//   mină_, dzib, خری_, łane_,
   {{0x3d000821,0xaefb00f1,0x6aa2002f,0x00000000}},	//   राने_, _dhùn, kaof, --,
   {{0x63ba3f22,0x8cca0067,0x394e0110,0x643b024b}},	//   mutn, स्सो, hofs_, _לעונ,
   {{0xa3e40567,0x7b3c3f23,0xa2a20084,0x6aa20279}},	// [3770] निक_, rčul, _ख़त्, daof,
   {{0xf1b20035,0xdb1c0035,0x225811c0,0x5d54002d}},	//   _जितन, _opró, _عجيب_, екут,
   {{0x63ba3f24,0x00000000,0x00000000,0x00000000}},	//   nutn, --, --, --,
   {{0x6f160501,0xdb050031,0xadbd010b,0x00000000}},	//   ckyc, mshë, _камi, --,
   {{0xdb1c006c,0x63ba0187,0x67200031,0x8afd00fe}},	//   _apró, hutn, dhmj, _chřa,
   {{0x63ba0f1a,0xdb1c0037,0xf9903f25,0xd6d90035}},	//   kutn, _bpró, ابن_, weł_,
   {{0x1bd43f26,0xdb0501f4,0x67d203e6,0x00000000}},	//   _поря, nshë, воју, --,
   {{0x63ba046a,0xe6193f27,0xa3bb0067,0x629f0055}},	//   dutn, жди_, इंस_, _neqo,
   {{0x98a7002d,0xe9d000b5,0x98bc0355,0xdb050031}},	//   gină_, _مغل_, nově_, hshë,
   {{0xe6c40129,0xdb0501f4,0x3d0008a9,0x673b0009}},	//   češć, kshë, राये_, snuj,
   {{0x2d540006,0xdb0501f4,0x78a33f28,0x2ee90009}},	//   päev_, jshë, manv, kdaf_,
   {{0x5727036b,0x26cf0371,0x78a33f29,0x00000000}},	//   _عراق, _ubgo_, lanv, --,
   {{0x3d0007b5,0xdb0501f4,0xaefb0023,0x2ee93f2a}},	//   रामे_, eshë, _phùn, ddaf_,
   {{0x63ba3f2b,0x78a33f2c,0xdb1c033b,0xdb050031}},	//   butn, nanv, _sprü, fshë,
   {{0x80cd3f2d,0x00000000,0x00000000,0x00000000}},	//   द्धे, --, --, --,
   {{0xdbd90370,0xd00f00b5,0x9f550274,0x6e2401b7}},	//   nçõe, گلہ_, ењуј, tzib,
   {{0xdbd903e6,0xaefb01a5,0xada30036,0xee3a2325}},	// [3780] içõe, _thùn, катл, цна_,
   {{0x6e243f2e,0x61e43f2f,0x6f160501,0x80cd31d7}},	//   rzib, _isil, skyc, द्दे,
   {{0x6f660370,0x0aea0fa7,0xb6a30023,0xdbf20355}},	//   _овоз, ждей_, _phầ, příp,
   {{0x60dc3f30,0x7c6527f6,0x61e40009,0xdb1c0107}},	//   lerm, رالل, _ksil, _aprò,
   {{0xdb1c0035,0x69c30ea3,0x2baa0066,0x6aa23f31}},	//   _spró, _रमणी, _चटका, raof,
   {{0xa91d00cb,0x63ba012f,0xeb9a135b,0x98a700af}},	//   _nužd, yutn, _миг_, vină_,
   {{0x38cb0164,0xd83800cd,0x60dc033b,0x799b018e}},	//   تانی_, _beča_, ierm, _ewuw,
   {{0x60dc3f32,0x8cca00b8,0x78a302a2,0x690f03d0}},	//   herm, स्रो, aanv, _søet,
   {{0x61e40103,0x557418cd,0x00000000,0x00000000}},	//   _nsil, нгит, --, --,
   {{0x63ba3f33,0x2fdf004e,0x78a33f34,0xdbd90279}},	//   tutn, ługi_, canv, açõe,
   {{0x61e43f35,0xa91d0c99,0x290c011e,0x60dc3f36}},	//   _asil, _dužd, _ioda_, derm,
   {{0x68e83f37,0x79802982,0x290c00cb,0xdbd903e6}},	//   _hadd, _kumw, _hoda_, cçõe,
   {{0x60dc3f38,0x68e8018e,0x63ba01cc,0x6aa00ec0}},	//   ferm, _kadd, sutn, _memf,
   {{0x60dc3f39,0x68e83f3a,0xdb0501f4,0x660f3f3b}},	//   germ, _jadd, tshë, äcke,
   {{0x68e80d6f,0x61e41c55,0x57dc3f3c,0x63ba00d7}},	//   _madd, _esil, _मनोह, qutn,
   {{0xc3280082,0xdb0500da,0x3dc9003c,0xdb170042}},	//   _يكون_, rshë, ttaw_, puxé,
   {{0x645803ad,0x68fa02e6,0x8d790037,0xdb050031}},	// [3790] _hyvi, _ontd, سماء_, sshë,
   {{0x290c3f3d,0x60dc3f3e,0x68e83f3f,0xa91d3f40}},	//   _noda_, cerm, _nadd, _kuže,
   {{0x3dc93f41,0xa3e41ede,0x691401da,0x60c50107}},	//   staw_, निट_, _gàei, _ichm,
   {{0xa91d1cbe,0x160e017a,0xbebb01f4,0x290c0e0b}},	//   _muže, िहार_, _emër, _aoda_,
   {{0x68e801a8,0x290c3f42,0x3f813f43,0xa91d00fe}},	//   _badd, _boda_, _huhu_, _luže,
   {{0x290c0729,0x41b20461,0x3f81007c,0x41bc0122}},	//   _coda_, _जिसस, _kuhu_, קצוע,
   {{0x290c3f44,0x3f8107c0,0x78a3017b,0xa92700ea}},	//   _doda_, _juhu_, ranv, _režī,
   {{0x68fa01ae,0x6aa00176,0x78a30273,0x60dc220d}},	//   _entd, _gemf, sanv, zerm,
   {{0x7afb3f45,0x60c500d7,0xb9b50e6b,0x290c0279}},	//   _inut, _ochm, _سماع, _foda_,
   {{0x290c3f46,0x7ae900c3,0x68e83f47,0x7afb0187}},	//   _goda_, _haet, _gadd, _hnut,
   {{0x60dc089c,0x7afb1f2c,0x29c91725,0xdbd90132}},	//   verm, _knut, lúa_, pçõe,
   {{0x29070888,0x61e401a2,0x60c53f48,0x8c1a0122}},	//   ljna_, _psil, _achm, פורי,
   {{0x68e83f49,0xa2c10d00,0x29c90b4c,0x09cd0083}},	//   _yadd, _वार्, núa_, লিকা,
   {{0x7ae9004f,0xa91d0009,0xafe60d9e,0x69cb08f3}},	//   _laet, _fuže, ногл, itge,
   {{0xb4ab00a1,0x2ecb00b8,0x60dc19b2,0x69cb3f4a}},	//   गणी_, ाभूत, rerm, htge,
   {{0xdee33f4b,0xe45602b5,0x3f813f4c,0x60dc3f4d}},	//   лоси, _איצט_, _duhu_, serm,
   {{0xc69202b5,0x69c9006d,0x733b0070,0xf7720070}},	// [37a0] טאן_, _nqee, _מעקס, רקן_,
   {{0x7afb10b9,0x798001d5,0xece70043,0xafe60ded}},	//   _anut, _rumw, ндул_, _зоол,
   {{0x68e83f4e,0x79802379,0x309b00a5,0x3ea6141d}},	//   _radd, _sumw, _משימ, _пинг,
   {{0x6d553f4f,0x7ae93f50,0x6122016f,0x291e0703}},	//   _ekza, _caet, _dôle, _slta_,
   {{0x78a13f51,0x7ae9001e,0x291e012f,0x80cd0517}},	//   _belv, _daet, _plta_, द्वे,
   {{0x68e8035f,0x7afb0176,0x61220132,0x7ae901ed}},	//   _qadd, _enut, _fôle, _eaet,
   {{0xb90823e3,0x78a1038d,0x9d432dde,0xa2c13f52}},	//   _बस_, _delv, _серд, _वाल्,
   {{0x68e801a8,0x8b6600bf,0x76590297,0x7ae93f53}},	//   _wadd, _سازم, _bywy, _gaet,
   {{0x290c1fca,0x78a1006c,0x68e83f54,0xa84a0609}},	//   _toda_, _felv, _tadd, _کلام_,
   {{0x7d0e3f55,0x2d823f56,0xb17b013c,0xa91d264f}},	//   _jobs, _muke_, kvår, _puže,
   {{0x3320038d,0x92953f57,0x2d820f00,0x7afb0160}},	//   _blix_, канц, _luke_, _ynut,
   {{0x60c53f58,0x33203f59,0x64580187,0x765900e9}},	//   _schm, _clix_, _vyvi, _fywy,
   {{0x3f8106b3,0xd24400af,0x6e3b01ba,0x7d0e0159}},	//   _suhu_, гэри, _ľubo, _oobs,
   {{0x6e3b0506,0xd5b90044,0xa91d1c1a,0x78a101f7}},	//   _žubo, _ісі_, _tuže, _xelv,
   {{0x33203f5a,0xbf1c0461,0xdfd801d3,0x2d823f5b}},	//   _flix_, नसून_, нът_, _auke_,
   {{0x2d823f5c,0x6122000d,0x6118045e,0xd8383f5d}},	//   _buke_, _rôle, _ağlı, _lečo_,
   {{0xe7e2004e,0x7ae9102f,0x5d550be8,0x741404a3}},	// [37b0] _कैसा_, _raet, вкат, _سوکا,
   {{0xe6dd0084,0x60c500ee,0x7ae93f5e,0x2d823f5f}},	//   _मस्ज, _uchm, _saet, _duke_,
   {{0x2369006d,0x7ae93f60,0x78a13f61,0x7afb00d5}},	//   _khaj_, _paet, _relv, _pnut,
   {{0x29c90caa,0x78a13f62,0x26c601e8,0x61220279}},	//   túa_, _selv, _ncoo_, _vôle,
   {{0x7d0e0176,0x2b44005f,0xa91d0168,0x09e510b4}},	//   _fobs, _djmc_, _ružb, толн,
   {{0x69cb02c0,0x88bc01c0,0x7ae900e9,0x612200a2}},	//   rtge, _směr, _waet, _tôle,
   {{0x78a13f63,0x69cb3f64,0x29c93f65,0x2d540110}},	//   _velv, stge, súa_, päer_,
   {{0xf771211b,0x26c63f66,0x29c90300,0x69cb02b1}},	//   جات_, _ccoo_, púa_, ptge,
   {{0x49750009,0x9fb600b8,0x645c3f67,0x00000000}},	//   _алас, vřít_, ürin, --,
   {{0xe9750c26,0x26c6027a,0x2ca30024,0x34bd0096}},	//   _شهاد, _ecoo_, _jejd_, ्भेद,
   {{0xa91d0254,0x2f1c00d5,0xa8020644,0x3f57000d}},	//   _tužb, _bígl_, şırl, nçus_,
   {{0x7659001e,0x6f0f07e5,0x23690359,0xe78400af}},	//   _tywy, _nocc, _chaj_, _суфо,
   {{0xf1bf0279,0x3ea20051,0x00000000,0x00000000}},	//   guá_, _rekt_, --, --,
   {{0x2d823f68,0x2bd20066,0xa06a0409,0x2ca30069}},	//   _ruke_, _सहला, дага_, _nejd_,
   {{0x10a33f69,0x6f0f02fb,0x7d0e3f6a,0x00000000}},	//   рисн, _bocc, _robs, --,
   {{0x2d820dc3,0x6f0f027a,0xdcf50260,0x22163f6b}},	//   _puke_, _cocc, _dizč, _афор,
   {{0x6f0f0382,0x6da63f6c,0xe7bd0033,0xb17b01ff}},	// [37c0] _docc, тиза, _আনোয, rvår,
   {{0x2a7f009e,0x3ea20223,0xe7e200ab,0x00000000}},	//   _agub_, _wekt_, _कईला_, --,
   {{0x2ca30009,0xa7fc00d0,0xfce31f39,0x00000000}},	//   _dejd_, _azın, рохо, --,
   {{0x6f0f0382,0x2d8200ee,0x61f60282,0x98a71627}},	//   _gocc, _tuke_, _kryl, minę_,
   {{0x98a717a9,0xc3330277,0xdb1c0282,0x00000000}},	//   linę_, סוד_, _oprö, --,
   {{0x7b3c042a,0x6f0f1de4,0x25bf011e,0xa2d900a1}},	//   jčuv, _zocc, duul_, _फॉन्,
   {{0x6a863f6d,0xb8da3123,0x97a3010b,0xec7700f0}},	//   _алба, _आए_, арыл, _апр_,
   {{0x3d002fa9,0xd7f701fd,0x00000000,0x00000000}},	//   रावे_, туш_, --, --,
   {{0x21380009,0xdb110098,0x00000000,0x00000000}},	//   kirh_, _ógán, --, --,
   {{0xe29a0028,0xa8020095,0x660f013c,0xe3b8013b}},	//   _đưa_, şıql, äcka, trı_,
   {{0x23690221,0x394901dd,0x91820023,0x33753f6e}},	//   _phaj_, éase_, yện_, лгор,
   {{0x61f60c61,0xe3b80225,0xe61a1d77,0x00000000}},	//   _bryl, rrı_, _оде_, --,
   {{0x6f0f02fb,0x6722081b,0x25bf0051,0xd05d013b}},	//   _rocc, _iloj, cuul_, əyən,
   {{0x6f0f3f6f,0x61f6016e,0x2f150533,0x6d5e2069}},	//   _socc, _dryl, _lågt_, jlpa,
   {{0x23690189,0xb4be1a75,0x443a007c,0x6f0f0036}},	//   _thaj_, इली_, _äp_, _pocc,
   {{0x5eb407b0,0x63ba0169,0x6d5e1167,0x20070310}},	//   ийст, mrtn, elpa, _ànim_,
   {{0xa91d00fe,0x6d5e0009,0xdd9502ee,0x2ca3023a}},	// [37d0] _luža, flpa, уазы, _pejd_,
   {{0x672201f4,0x98a71640,0x01fa1804,0xaefb01da}},	//   _lloj, binę_, _נפתל, _mhùi,
   {{0x6f0f02fb,0xb227008a,0x2ca302c4,0xa91d00cd}},	//   _tocc, _fræð, _vejd_, _nuža,
   {{0x3f57000d,0x27f90355,0x3f9301ed,0x6d5e0553}},	//   rçus_, _čsn_, _itxu_, alpa,
   {{0x3ea93f70,0x271f0084,0x6eba00a5,0xdb260220}},	//   maat_, _बतौर_, _אזרח, دونی,
   {{0xeb9318dd,0x3ea93f71,0x67223f72,0x186907c3}},	//   _نظر_, laat_, _aloj, нали_,
   {{0xb8db00be,0x98a200c3,0x00000000,0x00000000}},	//   _अय_, щище, --, --,
   {{0x6b833f73,0xa91d0254,0xa6e53f74,0xaefb00f1}},	//   íngu, _duža, ужил, _bhùi,
   {{0xaefb01a6,0x8cca1119,0xe57908ce,0x656a026e}},	//   _chùi, स्को, нзи_, _bhfh,
   {{0x3ea90b88,0xaefb0284,0x499000b5,0x69db021d}},	//   haat_, _dhùi, _بیور, _ipue,
   {{0x67223f75,0x656a0211,0x80df0033,0x00000000}},	//   _floj, _dhfh, মাঞ্, --,
   {{0x15f5036b,0x61f6013c,0x3ea93f76,0x6b580d2e}},	//   _مستح, _pryl, jaat_, lígr,
   {{0x3ea93f77,0x63ba0223,0x6d47073a,0x00000000}},	//   daat_, artn, _ojja, --,
   {{0x64a53f78,0x25ad2de7,0x98a7010b,0x613400a8}},	//   _сака, msel_, tinę_, _külə,
   {{0x25ad3f79,0x201e3f7a,0x63ba00f4,0x00000000}},	//   lsel_, áti_, crtn, --,
   {{0x3ea92193,0x543a02b5,0x69db00de,0x14cf00a1}},	//   gaat_, _רעקא, _opue, त्रण,
   {{0x201e0b7f,0x2ee00137,0x74ca0b35,0x25ad08ee}},	// [37e0] šti_, reif_, त्कृ, nsel_,
   {{0x319b0100,0xb19b0319,0x25ad000b,0x527b0070}},	//   _רבינ, _רייכ, isel_, _אנפא,
   {{0xf53600c2,0x69db0033,0x25e50035,0xeb9a004c}},	//   נטער_, _apue, _जैसी_, хие_,
   {{0x3ea93f7b,0x25ad3f7c,0xa91d3c62,0x60db0009}},	//   caat_, ksel_, _ruža, đume,
   {{0x99d3004f,0xa91d3262,0x69db008c,0x00000000}},	//   متوا, _suža, _cpue, --,
   {{0x25ad3f7d,0x672215d7,0x5f260083,0xe9730037}},	//   dsel_, _sloj, _যদিও_, مهند,
   {{0x67223f7e,0xf40705f5,0x25ad095a,0xd90d00d1}},	//   _ploj, _اؤ_, esel_, بیل_,
   {{0xc6f83f7f,0x291c3f80,0x7f443f81,0x35b401f2}},	//   тних_, skva_, nniq, абир,
   {{0x25ad3f82,0x7ae23f83,0x00000000,0x00000000}},	//   gsel_, meot, --, --,
   {{0x80d600c0,0x7ae23f84,0xa91d003a,0x295601d3}},	//   म्मे, leot, _tuža, _събр,
   {{0x69c200e9,0x613400a8,0xb7d70647,0xa91d0a66}},	//   luoe, _gülə, _مولا_, _kužn,
   {{0xa91d0936,0x78aa008c,0x23a5020d,0xe5a60183}},	//   _južn, lafv, _खबरद, _биди,
   {{0x3ea93f85,0xa5960133,0xa91d0393,0xd5ae00b5}},	//   vaat_, _срещ, _mužn, _عہد_,
   {{0xa2c10967,0x7bdc3f86,0x98a700b8,0x63ba0124}},	//   _वाक्, _opru, dině_, prtn,
   {{0x3ea93f87,0x753a3f88,0xceb40095,0x00000000}},	//   taat_, mitz, rkən_, --,
   {{0x753a162d,0xa91d0c0a,0x93fb00a5,0x80d6021a}},	//   litz, _nužn, _טלוי, म्बे,
   {{0x3ea93f89,0x7bdc3f8a,0xdb1e0248,0xdcf5013a}},	// [37f0] raat_, _apru, cupé, _aizā,
   {{0x3ea93f8b,0x753a0955,0xd7f8002d,0x463b0070}},	//   saat_, nitz, _oră_, געמע,
   {{0x3ea93f8c,0x69db0bf7,0x00000000,0x00000000}},	//   paat_, _spue, --, --,
   {{0x753a06a2,0x8f9a0122,0x25ad3f8d,0x3ea90103}},	//   hitz, _שירי, ysel_, qaat_,
   {{0xa91d0a78,0x753a06a2,0x6f0d006d,0x7bdc0207}},	//   _dužn, kitz, mjac, _epru,
   {{0x6f0d0254,0x25ad3f8e,0x7a2a00b5,0x753a01b7}},	//   ljac, vsel_, _söté, jitz,
   {{0x753a06a2,0x6d450023,0x6d570183,0xd705218b}},	//   ditz, mnha, moxa, изки,
   {{0x6f0d3f8f,0x6d570e8f,0xa2c10355,0x6e2d01ed}},	//   njac, loxa, _वाग्, ozab,
   {{0x6e2d3499,0xd7060086,0xd7f80160,0x25ad3f90}},	//   nzab, рные_, _eră_, usel_,
   {{0x25ad3f91,0x6d5701ef,0x753a01d7,0x6d453f92}},	//   rsel_, noxa, gitz, nnha,
   {{0xe29a0cd0,0x25ad3f93,0x232a03d0,0x612b006c}},	//   кан_, ssel_, вони_, _külf,
   {{0x249806d0,0x25ad3f94,0x6f0d022f,0xc16900a5}},	//   ırma_, psel_, jjac, _חח_,
   {{0xe5a5083e,0xaad7022e,0x753a0074,0x6f0d0124}},	//   _тили, ण्यक, bitz, djac,
   {{0x68e33f95,0xa91d01ba,0xf4873f96,0x628f0ea5}},	//   nend, _mužo, _судн, acco,
   {{0x2bb1006a,0x8fa63f97,0x68fc00de,0x68e31e65}},	//   jąc_, рабе, _órde, iend,
   {{0x68e33f98,0x6d45081b,0x2bb10067,0x2bc90099}},	//   hend, enha, dąc_, ांना,

   {{0x661b3ab1,0xa91d03fd,0x63a3001e,0xed5a0fb4}},	// [3800] nyuk, _ružn, _hwnn, воа_,
   {{0x68e33f99,0x61e90225,0xa91d219c,0xf1bf00b5}},	//   jend, çele, _sužn, zzák_,
   {{0x68e33f9a,0x7ae23f9b,0x6f0d1eae,0x6e2d3f9c}},	//   dend, teot, bjac, azab,
   {{0x753a0291,0x6f0d004e,0xb0d200b4,0x661b01a8}},	//   zitz, cjac, द्रग, kyuk,
   {{0x2bd23f9d,0x272a01a5,0xdcfc035f,0xe8940ed2}},	//   _सहका, _hùng_, _jirċ, баль,
   {{0x68e33f9e,0x8b963f9f,0xa91d00f4,0x00000000}},	//   gend, _врач, _dužo, --,
   {{0x8c43093c,0xa91d03fd,0x753a3fa0,0x398b23f4}},	//   _дере, _tužn, vitz, _eøs_,
   {{0x6d5c008b,0x272a00e2,0x398b0a8a,0xd838003d}},	//   _hkra, _mùng_, _føs_, _ječi_,
   {{0x753a3f88,0x272a0023,0xa534002d,0x55063fa1}},	//   titz, _lùng_, йнич, ачна,
   {{0xd8380c99,0x3d09046c,0x63a30103,0x2b4600d5}},	//   _leči_, साये_, _bwnn, lnoc_,
   {{0x753a3fa2,0x6e2d3fa3,0x8cd806fe,0x8cc70067}},	//   ritz, zzab, न्यो, ालतो,
   {{0x753a3fa4,0xd6d9004e,0x612b00ab,0x661b01d5}},	//   sitz, koły_, _külg, byuk,
   {{0x78a80332,0xf5940082,0x6d45001e,0x6d5c2018}},	//   _kedv, _التج, ynha, _okra,
   {{0x78a80470,0x272a0023,0x62840065,0x753d00b5}},	//   _jedv, _bùng_, _egio, észt,
   {{0x272a00e8,0x4ad70808,0x4ea70370,0xaad701c0}},	//   _cùng_, ण्डव, ираа, ण्डक,
   {{0x68e33fa5,0x272a00e8,0x6d5c3fa6,0x6e2d3fa7}},	//   zend, _dùng_, _akra, tzab,
   {{0x68e33fa8,0xdceb0a69,0x8cc20f8a,0x6d570160}},	// [3810] yend, šičk, _लाखो, toxa,
   {{0x61ed3fa9,0xa91d01ba,0x68e33faa,0x6e2d0065}},	//   _isal, _ružo, xend, rzab,
   {{0x68e33fab,0x6d453fac,0xaefb0284,0xee871667}},	//   vend, rnha, _bhùt, _выго,
   {{0x68e33fad,0x28c902cb,0xb4790070,0x2bb10067}},	//   wend, _राहि, אָני, rąc_,
   {{0x6d5700d5,0x8d770220,0xaefb00f1,0xe91901e0}},	//   poxa, _ناسا, _dhùt, лоді_,
   {{0xf1bf2dea,0x98a23fae,0x61ed0054,0x00000000}},	//   irá_, пише, _msal, --,
   {{0xe7393faf,0xf1bf3651,0x60da00be,0x67290055}},	//   лек_, hrá_, õtmi, thej,
   {{0x61ed087a,0x7bc53fb0,0xf1bf008a,0x6d5c00b8}},	//   _osal, muhu, krá_, _zkra,
   {{0x68e33fb1,0x612b0332,0x7bc51034,0x673b00c7}},	//   pend, _küld, luhu, riuj,
   {{0xb8fc0b52,0x6aa925cb,0xf1bf3fb2,0x67290232}},	//   _তো_, _heef, drá_, shej,
   {{0x6aa93fb3,0x7bc53fb4,0x661b1f8a,0xf1bf0300}},	//   _keef, nuhu, syuk, erá_,
   {{0x7981011e,0xf1bf003e,0x272a00e2,0x91e602d6}},	//   _hilw, frá_, _rùng_, боме,
   {{0xd8383fb5,0x7bc53fb6,0x61ed0332,0x753d0332}},	//   _reči_, huhu, _csal, észs,
   {{0x6aa90244,0x7bc50465,0x79810069,0x00000000}},	//   _leef, kuhu, _jilw, --,
   {{0x79813fb7,0x61ed3fb8,0xf1bf1ea3,0xa2c100e7}},	//   _milw, _esal, ará_, _वाच्,
   {{0xf1bf3fb9,0x272a01a5,0x7bc5037b,0x1e8632dd}},	//   brá_, _vùng_, duhu, слам,
   {{0x3f85008e,0x2fdf00af,0xc58800e2,0x1d8a0037}},	// [3820] ílur_, ăuga_, _lồn_, ائري_,
   {{0x272a01a5,0x25bf20fb,0x23db00c0,0xdca62315}},	//   _tùng_, irul_, _बहाद, сажи,
   {{0x6aa92d1a,0x25bf3fba,0xb53a02b5,0xa6ad0033}},	//   _beef, hrul_, נגעש, _গানট,
   {{0xaefb0211,0x798100e5,0x25bf0298,0x00000000}},	//   _dhùs, _ailw, krul_, --,
   {{0x3ea03fbb,0x28c91db9,0x79812aea,0x00000000}},	//   mbit_, _राशि, _bilw, --,
   {{0x25bf3fbc,0x6d5c3fbd,0xc5880023,0x612b00c1}},	//   drul_, _ukra, _bồn_, _güld,
   {{0x79813fbe,0x93bc002d,0x6ab70033,0xc5880023}},	//   _dilw, nzăt, _ইউরো, _cồn_,
   {{0xbc1b0122,0x6aa90a75,0xa3ab1556,0x6d8902c4}},	//   _גולש, _geef, गठन_, _džaf,
   {{0xe9a3395d,0x79813fbf,0x3f8201f4,0x8cd80035}},	//   _натп, _filw, _miku_, न्थो,
   {{0x3f820eac,0xb606011c,0xa2c12478,0x73d830dd}},	//   _liku_, vršć, _वाङ्, адор_,
   {{0x3ea01b82,0x61ed3fc0,0xaefb0211,0x6aa9001c}},	//   kbit_, _ssal, _mhùr, _yeef,
   {{0x8cd8084b,0x3f823fc1,0xf1bf163f,0x25bf3fc2}},	//   न्तो, _niku_, trá_, brul_,
   {{0x3ea00282,0xd7570037,0x25bf00af,0x00000000}},	//   dbit_, _النت_, crul_, --,
   {{0xecc70035,0xdcfc02c4,0xa2d90785,0xf1bf3fc3}},	//   _लाइफ, _birč, _फॉर्, rrá_,
   {{0x7d151298,0x653b00a5,0x3cf10009,0x00000000}},	//   _rozs, _תעוד, _razv_, --,
   {{0x3f82104e,0xa91d022f,0x61ed0312,0xdcfc0260}},	//   _ciku_, _ružm, _tsal, _dirč,
   {{0x9c870082,0x61ed3fc4,0x6aa93c9d,0x3f8201f4}},	// [3830] مشاه, _usal, _reef, _diku_,
   {{0x7bc50657,0x612b0225,0xd13109b9,0xaefb00f1}},	//   tuhu, _büle, _آمد_, _chùr,
   {{0x25bf00d7,0xaefb01da,0x3ea03fc5,0x00000000}},	//   zrul_, _dhùr, bbit_, --,
   {{0x7bc53fc6,0x79813fc7,0x25a60118,0xd9f92101}},	//   ruhu, _silw, _owol_, инец_,
   {{0xd8380129,0x7bc53fc8,0xbddb0310,0xf3890023}},	//   _meču_, suhu, _exèr, _nản_,
   {{0x2d9903ad,0x2795052c,0x8cd8164f,0x7bc53fc9}},	//   _itse_, ошир, न्दो, puhu,
   {{0x612b027d,0x6aa93fca,0xd7093fcb,0x00000000}},	//   _güle, _teef, инке_, --,
   {{0xf38900e8,0x2d8b3fcc,0x25bf002d,0xd838022f}},	//   _bản_, _kuce_, trul_, _neču_,
   {{0xf3890023,0x2d8b022f,0xe61600c3,0x3eab0139}},	//   _cản_, _juce_, жды_, _mect_,
   {{0xc5880019,0x2d8302e9,0x451907b4,0x3ea00e31}},	//   _tồn_, _jije_, рция_, zbit_,
   {{0x2d8b02fb,0xd4692c72,0x3eb93fcd,0xd838011c}},	//   _luce_, рине_, _odst_, _beču_,
   {{0x2d9900ab,0x2d830506,0x00000000,0x00000000}},	//   _otse_, _lije_, --, --,
   {{0x2d99006f,0xdcfc3fce,0x3f823fcf,0xfe7f1ab6}},	//   _ntse_, _sirč, _riku_, _maïs_,
   {{0x2d830500,0x3f8219c6,0xe7dd10aa,0xf992035e}},	//   _nije_, _siku_, _महाप, ורך_,
   {{0x33290602,0x3ea03fd0,0xe29a06d8,0x612b027b}},	//   _flax_, tbit_, _кай_, _bülb,
   {{0xf3890019,0x6d4b3fd1,0x2d8b0027,0x1f66010b}},	//   _hảo_, égan, _buce_, ікам,
   {{0x3f82008a,0x612b3fd2,0xe7e90f9c,0x6d0500b4}},	// [3840] _viku_, _süle, झौता_, रांग_,
   {{0x2d8b3fd3,0x2d83022f,0x3eb9023a,0x3f820118}},	//   _duce_, _cije_, _edst_, _wiku_,
   {{0x2d833fd4,0x987801ba,0x3f6a167d,0xc6161022}},	//   _dije_, _páči_, _вино_, _तथ्य_,
   {{0xbddb01f7,0x27f80093,0x3eab0024,0x394c021d}},	//   _exèq, _árni_, _gect_, _sjds_,
   {{0x6f063fd5,0xe89418d9,0x59f8002d,0x2d8b0036}},	//   _inkc, паль, селя_, _guce_,
   {{0x6d890009,0x2d830107,0x26dd1857,0x25a6035f}},	//   _džad, _gije_, _abwo_, _rwol_,
   {{0xb8f2142a,0xf38900e8,0xf72a0f22,0x26dd0103}},	//   _वा_, _sản_, иций_, _bbwo_,
   {{0xdb051193,0x290502d7,0x4b34014a,0x28da00b4}},	//   gshä, _enla_, _عکاس, _मॉरि,
   {{0xf38900e8,0x29050009,0x7afd3503,0x80aa073f}},	//   _bảo_, _fnla_, _ósta, कराइ,
   {{0x6130315b,0x37e63fd6,0x01d00033,0x62960225}},	//   _hälf, _мозг, িবাদ, _afyo,
   {{0xad9b008e,0xd7ef004f,0x2cfb0070,0x00000000}},	//   _trúg, _لكل_, בליא, --,
   {{0x51873fd7,0x78ba01a2,0xf3890019,0x98bc010b}},	//   жува, _hdtv, _tản_, tovė_,
   {{0x69c23fd8,0xd838013a,0x15980088,0x00000000}},	//   nroe, _veču_, _انتخ_, --,
   {{0x3eab3fd9,0x2d8b00b8,0x98bc010b,0x60db0009}},	//   _sect_, _ruce_, rovė_, đumo,
   {{0x28d20e04,0x69c23fda,0x2d8b3fdb,0x2d830add}},	//   _सानि, hroe, _suce_, _rije_,
   {{0x2d833fdc,0x2bc900a1,0x2d8b3fdd,0x634400fd}},	//   _sije_, ांसा, _puce_, tőne,
   {{0x2d833c8b,0xd087002d,0xa80201fb,0x395c3fde}},	// [3850] _pije_, _мыни, ğıyl, kovs_,
   {{0x459b0070,0x2d8b0124,0xf3890023,0xe6c706fe}},	//   יסמע, _vuce_, _xảo_, _रञ्ज,
   {{0x2d830031,0xd25100d1,0x69c212ba,0x00000000}},	//   _vije_, _زنگ_, eroe, --,
   {{0x399000f1,0x69c2016e,0xad9b00a0,0x2d8b0124}},	//   _bàs_, froe, _prúd, _tuce_,
   {{0x69c20136,0x8cd80f8a,0x2b4d0031,0x39903fdf}},	//   groe, न्हो, _vjec_, _càs_,
   {{0xa91d025c,0x5d79016b,0x00000000,0x00000000}},	//   _kuži, _לאָק, --, --,
   {{0xdb05191b,0xa91d0124,0xb8860093,0x00000000}},	//   tshä, _juži, _svíþ, --,
   {{0x3d09065a,0x69c23fe0,0xa3bb0461,0xf9890413}},	//   सावे_, broe, ेंस_, _هنري_,
   {{0xa91d0791,0x3d000099,0xad9b00a0,0x6abb007b}},	//   _luži, राचे_, _hrúb, _iduf,
   {{0xc58801a5,0xa8a73fe1,0x799b2792,0xd838023a}},	//   _gồm_, _фрак, _ituw, _pečt_,
   {{0x7bd701a3,0x59f80043,0x61300523,0xdb1e00ac}},	//   ntxu, _леӂя_, _hälg, lupá,
   {{0x26dd070b,0x91e60836,0xd6d90067,0x7bd701ed}},	//   _ubwo_, поме, biła_, itxu,
   {{0x28d2009a,0x6d89016f,0x6130007c,0xf8d20066}},	//   _सामि, _zľav, _jälg, _सामय,
   {{0x867a0052,0x25e00084,0x3dc9011e,0x92ac0033}},	//   _פרסו, _कहती_, duaw_, খলে_,
   {{0x09c800e7,0x645c00be,0xb4d7021a,0xa06a3fe2}},	//   _रम्य, ürit, ाभी_, сава_,
   {{0xa91d3b12,0x799b001c,0x7d070c6f,0x6296034d}},	//   _duži, _otuw, _anjs, _ufyo,
   {{0x13db0026,0x613000be,0x00000000,0x00000000}},	// [3860] _बहुभ, _nälg, --, --,
   {{0x4d6300c9,0x69c212ba,0x61e43fe3,0xd00f006c}},	//   екув, vroe, _ipil, خلہ_,
   {{0x711b00c2,0xa7fc0463,0x28d213a0,0x799b018e}},	//   _הויפ, _ayın, _साबि, _atuw,
   {{0x6d890ce9,0x7d07023a,0x61300282,0x00000000}},	//   _džab, _enjs, _bälg, --,
   {{0xa96a0009,0x613001ff,0xc33300a5,0xe8fa290a}},	//   бида_, _välf, עוד_, йлд_,
   {{0x612b0006,0x69c23fe4,0x672b008a,0x3eb2067f}},	//   _küla, rroe, _algj, layt_,
   {{0xfaa63fe5,0xd7fa0043,0x3d09193c,0x8b6600b5}},	//   _наво, сул_, सारे_, _فارم,
   {{0xf38900e8,0x96ea02ce,0x69c203c4,0x4994006c}},	//   _cảm_, ська_, proe, _قیصر,
   {{0x96b70200,0x00000000,0x00000000,0x00000000}},	//   чују_, --, --, --,
   {{0x7e6603d0,0x00000000,0x00000000,0x00000000}},	//   _mykp, --, --, --,
   {{0x61e43fe6,0xd6d90067,0x00000000,0x00000000}},	//   _apil, siła_, --, --,
   {{0xa91d0912,0xd16d0139,0x61e4026e,0x637f25d3}},	//   _ruži, _fraț, _bpil, _kūni,
   {{0xa91d00c7,0x637f0029,0xd709046c,0x6709073f}},	//   _suži, _jūni, वारथ_, वारक_,
   {{0x6d5e3fe7,0x6b9c00cd,0xa91d0207,0x661d3fe8}},	//   jopa, _otrg, _puži, äske,
   {{0x6d5e3fe9,0x04db00a5,0x6b8e0027,0x00000000}},	//   dopa, _הקול, _nubg, --,
   {{0x656801ff,0x657a3fea,0x7ae4018d,0x00000000}},	//   lldh, lmth, õitl, --,
   {{0xbf1d02cb,0x7883006c,0xfe5400af,0x32000260}},	// [3870] _नवीन_, _kívü, ектэ, _griy_,
   {{0x635200ec,0xa91d0254,0x6d5e0345,0xfc460334}},	//   māna, _tuži, gopa, čína_,
   {{0x799b0223,0xa02200be,0xad9b026e,0x00000000}},	//   _stuw, ööta, _brúc, --,
   {{0x7bd701a3,0xceeb0647,0xdcfc013a,0x00000000}},	//   rtxu, _اردن_, _virā, --,
   {{0xa2c00127,0x0dc80fc5,0x6b9c08b7,0x6352013a}},	//   _वयस्, _нури_, _etrg, nāna,
   {{0x5d850a86,0xad9b3feb,0x613018fb,0xdb1e002a}},	//   _زلزل, _erúc, _välg, rupá,
   {{0x81e30083,0x47d23fec,0x6e2000ab,0x612b00a8}},	//   নটি_, نيور, _ümbr, _xüla,
   {{0x65683fed,0x28d20d12,0x273100e2,0x6abb04fb}},	//   eldh, _साथि, _máng_, _uduf,
   {{0x27313b2f,0x61300282,0x799b037b,0x060901e0}},	//   _láng_, _häle, _utuw, інок_,
   {{0x81e30083,0x7aeb01ae,0x6352013a,0xe91a00b5}},	//   নটা_, legt, dāna, _ورلڈ_,
   {{0x61e43fee,0xa3a800a1,0x69d901ae,0x69cb3fef}},	//   _spil, खील_, ltwe, luge,
   {{0xe2971a6d,0x6130007c,0x6d5e3ff0,0x61e4008c}},	//   маю_, _mäle, zopa, _ppil,
   {{0x69d93ff1,0x69cb005d,0x6d5e0054,0x7bc501ae}},	//   ntwe, nuge, yopa, hrhu,
   {{0x77693ff2,0xafe6020a,0x69d91167,0x212c0079}},	//   llex, могл, itwe, ódh_,
   {{0x6d5e3ff3,0x69cb0027,0x00000000,0x00000000}},	//   vopa, huge, --, --,
   {{0xf4120122,0xa91d0a61,0x273101a5,0x69cb3ff4}},	//   _יפו_, _gužv, _dáng_, kuge,
   {{0x6d5e3ff5,0x61e43ff6,0x6b9c1164,0x0d860009}},	// [3880] topa, _upil, _strg, длан,
   {{0x28d208b0,0xa06a3741,0x28c922a3,0x417600f8}},	//   _साधि, _мапа_, _रागि, _تابس,
   {{0x6d5e3ff7,0x5fe23dd4,0x6130022a,0xeb9a0012}},	//   ropa, _पहिल, _väld, цие_,
   {{0x69d93ff8,0x4a463ff9,0x613002b1,0x6b9c023a}},	//   ftwe, мнев, _wäld, _vtrg,
   {{0xceb30052,0x6d5e3ffa,0x6376364e,0x28d2021a}},	//   _שיש_, popa, mánd, _सादि,
   {{0x63763ffb,0xfbc600d4,0xbebb0051,0x7bc30453}},	//   lánd, _обго, _coëf, ánuc,
   {{0x63760453,0xa91d010b,0x99920067,0x69d90d35}},	//   cáng, _nužu, ódła_, atwe,
   {{0xc5880028,0x63762b83,0xd5ba0036,0x657a006d}},	//   _hồi_, nánd, осо_, wmth,
   {{0x7d1c3ffc,0xbb430431,0x6e24114f,0x69d90035}},	//   _kors, _ретк, nyib, ctwe,
   {{0x635200ec,0x272a009e,0x63760138,0x7d1c0210}},	//   vāna, _gùnn_, hánd, _jors,
   {{0xd6cf0b30,0xa3a80006,0x3cf80210,0xc5880023}},	//   _ит_, खीं_, _marv_, _mồi_,
   {{0x3d05006a,0x7d1c02e1,0x798808dd,0x63763ffd}},	//   _होने_, _lors, _hidw, jánd,
   {{0x27310028,0x7d1c0136,0x63761111,0x660f013c}},	//   _sáng_, _oors, dánd, äckt,
   {{0x63880c1f,0x7d1c0a55,0x61fd01b4,0x635202d4}},	//   tènè, _nors, rvsl, rāna,
   {{0x69cb01ae,0xc5880019,0xa3b80026,0xdfd802fb}},	//   zuge, _nồi_, _चिट_, мът_,
   {{0x63762b83,0x7bc50097,0x15f2007c,0x33180037}},	//   gánd, vrhu, _अनार_, _يزيد_,
   {{0x171b00c2,0xbf1f0084,0x937803c7,0x6d580c99}},	// [3890] קומע, _यकीन_, _تصور_, čvan,
   {{0x7d1c203e,0xc5880019,0xad9b01ef,0x2d873ffe}},	//   _cors, _bồi_, _crúa, öne_,
   {{0xe3b80ec4,0xe1ff2a04,0xd01110ad,0x63760300}},	//   nsı_, lvó_, _صلح_, bánd,
   {{0x66020291,0x63760b4c,0x0f2702ce,0x69cb3fff}},	//   _orok, cánd, _цьом, tuge,
   {{0x7d1c3dbe,0xdddd006a,0x7aeb4000,0x7988009f}},	//   _fors, _wysł, regt, _bidw,
   {{0x69cb4001,0x7d1c4002,0x69d94003,0xad9b0453}},	//   ruge, _gors, rtwe, _grúa,
   {{0x6d4500a7,0x69d92308,0x63764004,0x69cb4005}},	//   miha, stwe, láne, suge,
   {{0xf77121a0,0x6d450614,0xe6192ef5,0x66024006}},	//   دات_, liha, зди_, _brok,
   {{0x79880069,0xa91d00d5,0x2cb100fd,0x00000000}},	//   _fidw, _sužu, _kezd_, --,
   {{0x6f1d4007,0xf3890028,0x6d454008,0x63764009}},	//   _losc, _hải_, niha, zánd,
   {{0x3834135b,0x6b89006c,0x9346037c,0x6e360223}},	//   _инфр, _kieg, енне, zzyb,
   {{0x6d45400a,0x66020b41,0xdbc600be,0x63760042}},	//   hiha, _frok, _töög, xánd,
   {{0x6b89400b,0x6d45400c,0x6376400d,0xf38900e2}},	//   _mieg, kiha, vánd, _mải_,
   {{0x6b89400e,0x412a00d4,0x6d453394,0x628d009e}},	//   _lieg, чого_, jiha, _egao,
   {{0xdee61000,0x63760f56,0xd0071c8c,0xd466400f}},	//   нови, tánd, нере_, _пише_,
   {{0xc5880028,0x6b894010,0x28df1e18,0x6f1d0729}},	//   _rồi_, _nieg, प्ति, _cosc,
   {{0xee3a4011,0x63764012,0x612b4013,0xdcf40254}},	// [38a0] чна_, ránd, _küll, šačk,
   {{0xa91d0187,0x98a700d8,0x63761111,0x101600d8}},	//   _mužs, minė_, sánd, _зьмя,
   {{0x7d1c02bf,0x6f1d4014,0x7988046a,0x6b894015}},	//   _vors, _fosc, _ridw, _bieg,
   {{0x28d236e3,0x6b894016,0xb60502a7,0x7d1c0191}},	//   _साहि, _cieg, _košč, _wors,
   {{0x7d1c4017,0x6d454018,0xf38a01a5,0x44254019}},	//   _tors, biha, _cải_, hyl_,
   {{0x44252d29,0x66040187,0xf38a0023,0xc5880023}},	//   kyl_, _šiko, _dải_, _tồi_,
   {{0xfc1a02ed,0xb605023a,0x00000000,0x00000000}},	//   _عقرب_, _lošč, --, --,
   {{0x4425401a,0x28d223db,0xa2a20355,0xf38a0023}},	//   dyl_, _सावि, कुम्, _fải_,
   {{0x7988009f,0x2d8a1944,0x65610132,0x612b013b}},	//   _tidw, _kibe_, folh, _büll,
   {{0x4425401b,0x645d0095,0x628d01a6,0x6b89401c}},	//   fyl_, əsiz, _sgao, _zieg,
   {{0x61f6037d,0x290c401d,0xd5c20864,0x5335176c}},	//   _asyl, _inda_, _शिवज, вент,
   {{0x6d45401e,0x68fa03d0,0x291e401f,0x2d8a0553}},	//   ziha, _hatd, _hota_, _libe_,
   {{0x291e2cba,0xe5a30132,0x8c240083,0x6d4501d5}},	//   _kota_, _бичи, _যেমন_, yiha,
   {{0x65610370,0x442500b8,0x291e4020,0x612b0644}},	//   colh, byl_, _jota_, _güll,
   {{0xb4be0ca1,0xf2b00083,0x6f1d3d36,0x291e4021}},	//   ेली_, _কারণ, _posc, _mota_,
   {{0x628d4022,0x6d454023,0x63764024,0x2d8a4025}},	//   _ugao, wiha, táne, _aibe_,
   {{0x290c4026,0x6d454027,0x6d890df4,0x6b894028}},	// [38b0] _onda_, tiha, _džan, _rieg,
   {{0x63764029,0x6b89402a,0x612b007c,0xf38a00e2}},	//   ráne, _sieg, _külm, _rải_,
   {{0x6d45402b,0x6b890080,0x6f1d402c,0x987f0355}},	//   riha, _pieg, _tosc, _péči_,
   {{0x290c402d,0x6d45402e,0x6b890484,0x63ba402f}},	//   _anda_, siha, _qieg, istn,
   {{0x291e27ce,0x6d454030,0x6b890029,0x61300282}},	//   _bota_, piha, _vieg, _häla,
   {{0x291e4031,0x18694032,0xf38a0019,0x6b894033}},	//   _cota_, мали_, _vải_, _wieg,
   {{0x6b892251,0x63ba4034,0x637601ef,0x7d540274}},	//   _tieg, jstn, nánc, _сврх,
   {{0x3d050429,0x290c4035,0x3ea94036,0xf38a0028}},	//   _होते_, _enda_, nbat_, _tải_,
   {{0x67294037,0x63ba016f,0x4425001e,0xb4be0461}},	//   rkej, estn, wyl_, ेलू_,
   {{0x7afb4038,0x69db00f6,0x44254039,0x3f8b2802}},	//   _haut, _ique, tyl_, _licu_,
   {{0x7afb403a,0x64580176,0x6561403b,0xa2d60577}},	//   _kaut, _cxvi, rolh, _भाद्,
   {{0x7afb1d19,0x98a701c8,0x3f8b00af,0x3dc9028b}},	//   _jaut, tinė_, _nicu_, kraw_,
   {{0x7afb403c,0x6d890009,0x64580282,0x612b403d}},	//   _maut, _ržan, _exvi, _tüll,
   {{0x3dc9403e,0x39472ddc,0x6606054e,0x98a700d8}},	//   draw_, nins_, ække, rinė_,
   {{0x2d8a403f,0xa0672070,0x612b4040,0x98a7010b}},	//   _ribe_, вара_, _külj, sinė_,
   {{0x6d550009,0x2d8a00ee,0xe4560070,0x6d580207}},	//   _ajza, _sibe_, _שיקט_, čvam,
   {{0x3dc94041,0x2d8a4042,0x3f673e1f,0xa2a20630}},	// [38c0] graw_, _pibe_, тито_, कुण्,
   {{0xad9b4043,0x7afb0159,0x39474044,0xed570274}},	//   _trún, _aaut, jins_, воу_,
   {{0x69db4045,0x3ea94046,0x80d7004e,0x20561999}},	//   _aque, bbat_, _बाते, _штир,
   {{0xf1af22f2,0x291e4047,0x7afb4048,0x66040097}},	//   जीवन, _sota_, _caut, _šikm,
   {{0x7fe21a75,0x2b460037,0x39474049,0x33200176}},	//   _पहुँ, rioc_, fins_, _moix_,
   {{0xdca322f1,0x7afb404a,0x3947404b,0x3f8b0af3}},	//   _вари, _eaut, gins_, _zicu_,
   {{0x69db404c,0x7afb0248,0x8c460c8d,0x3a2600d7}},	//   _eque, _faut, _реве, syop_,
   {{0x7afb404d,0x8a060de3,0x3947404e,0x3320404f}},	//   _gaut, _избе, ains_, _noix_,
   {{0x291e4047,0x598612a2,0xc6f70733,0xae05238a}},	//   _tota_, _алаб, тных_, रियन_,
   {{0xb4be4050,0x39474051,0x7afb0375,0xe6bd00b4}},	//   ेले_, cins_, _zaut, ोलॉज,
   {{0x3cfa004e,0x33202a18,0x7afb4052,0x00000000}},	//   _उसने_, _boix_, _yaut, --,
   {{0x63ba4053,0x7ae22668,0x65c64054,0x33200176}},	//   rstn, nfot, _абда, _coix_,
   {{0x61300523,0x3f8b0009,0x201e147d,0xaad70355}},	//   _säla, _ricu_, ätin_, ण्टक,
   {{0x3f8b0207,0x00000000,0x00000000,0x00000000}},	//   _sicu_, --, --, --,
   {{0x5ea400c8,0x3f8b4055,0x33203576,0xc5790070}},	//   _ওয়ে, _picu_, _foix_, _אָקט,
   {{0x3dc90701,0x394714d2,0x637600b8,0x4ad100dc}},	//   traw_, zins_, ránc, _हाइव,
   {{0x7afb4056,0x3ea94057,0xd9d1051d,0x3f8b0124}},	// [38d0] _raut, rbat_, _समेट, _vicu_,
   {{0x39474058,0x7afb4059,0x63762ac4,0x612b0716}},	//   xins_, _saut, mána, _mülk,
   {{0x7afb405a,0x3947405b,0x6376405c,0xc3160033}},	//   _paut, vins_, lána, াসরি_,
   {{0x5a350dee,0x629d00b5,0x3dc9405d,0x201c0392}},	//   лнет, ncso, praw_, _àvia_,
   {{0x3947405e,0xa2d60f3d,0x7afb405f,0x69db29e0}},	//   tins_, _भास्, _vaut, _qque,
   {{0x4cad0083,0xb4be0af9,0x00000000,0x00000000}},	//   _চাকু, ेलो_, --, --,
   {{0x7afb17c5,0xe516022e,0x39474060,0xf7451238}},	//   _taut, तानि_, rins_, леко,
   {{0x39474061,0x236901e8,0x98bc002d,0x21210118}},	//   sins_, _nkaj_, tivă_, _lohh_,
   {{0xd4d901c8,0x39474062,0x21214063,0x637600b5}},	//   ньні_, pins_, _oohh_, jána,
   {{0xdb1c0107,0xdb1701ef,0x27314064,0x16150067}},	//   _avrè, puxó, _dána_, तमबर_,
   {{0x6b954065,0x2d8119fd,0x00000000,0x00000000}},	//   _juzg, imhe_, --, --,
   {{0x28df384a,0xf8df0e61,0x257902e1,0x39990359}},	//   प्रि, प्रय, dèle_, _kès_,
   {{0x33200248,0x6376126b,0xe60e00af,0xe6100312}},	//   _voix_, gána, _уд_, _وشه_,
   {{0xb60201c0,0x39994066,0x69cb0767,0xa2ba0355}},	//   čátk, _mès_, irge, ्लङ्,
   {{0x74d80302,0x39994067,0x67170d00,0x3d170785}},	//   _मातृ, _lès_, थापक_, नाने_,
   {{0x69c40534,0x6d8901a0,0xad9b008d,0x00000000}},	//   _रिली, _džam, _trúl, --,
   {{0xc69202b5,0x80b30083,0x3f80021d,0x00000000}},	// [38e0] מאן_, _জার্, rmiu_, --,
   {{0x23b70084,0xe6d000b8,0xc8d24068,0x7bde1e2e}},	//   _आबाद, _सञ्ज, _साइट, ttpu,
   {{0xa3bb4069,0x80aa00a1,0x7ae2406a,0x5aca406b}},	//   ेंट_, _ज्ये, tfot, елем_,
   {{0x2ca73410,0xeafa006c,0x7bde406c,0xda7a00c3}},	//   ında_, عرات_, rtpu, нял_,
   {{0x82d700c2,0x59f803ca,0xb17b04ca,0xe3a70609}},	//   רונג_, теля_, ståe, _گر_,
   {{0x399902e1,0x7ae2406d,0x6ea0035d,0x27310097}},	//   _dès_, sfot, गुरु, _rána_,
   {{0xe3a70796,0x69cb406e,0xd90d064e,0x78b81f26}},	//   _در_, arge, ظیم_, ravv,
   {{0xb8cb2bad,0x78b8406f,0x27310187,0x2cba011e}},	//   _क्_, savv, _pána_, lapd_,
   {{0x290f0037,0xd5b700af,0x63a30103,0x39990260}},	//   álaí_, лсэ_, _atnn, _gès_,
   {{0x6b824070,0x46a40cea,0x59830086,0xad9b0453}},	//   lmog, _ग्रह, _глуб, _brúj,
   {{0xb8930514,0xd6c401ca,0x245800d4,0xa8560214}},	//   _المع, _نمای, тань_, _стај,
   {{0x80d705fc,0xa3bb0026,0x257900f7,0x63760172}},	//   _बाहे, ेंज_, vèle_, tána,
   {{0x6d890129,0x637d0118,0xa2d604cc,0x80de0083}},	//   _džaj, héng, _भार्, য়ন্,
   {{0xa3d40302,0xe3af006c,0x63762ac4,0x257900f7}},	//   िंद_, _کرو_, rána, tèle_,
   {{0x09d104e9,0x629d00f5,0x67220221,0x6376006c}},	//   _सम्य, pcso, _kooj, sána,
   {{0x67223f60,0x637d0118,0x61304071,0x637629e3}},	//   _jooj, déng, _häll, pána,
   {{0x6130022a,0x612b00ab,0x6b8200cd,0x00000000}},	// [38f0] _käll, _lüli, dmog, --,
   {{0x627c0052,0x02e10653,0x61301c55,0x61ed0dc3}},	//   _אנחנ, ग्रह_, _jäll, _ipal,
   {{0xbc0700d8,0x768b027d,0x69c00185,0x00000000}},	//   ычай, _köyü, _avme, --,
   {{0x612b00a8,0x3999021e,0x00000000,0x00000000}},	//   _sülh, _pès_, --, --,
   {{0x99d70082,0x6d4b0391,0x69cb4072,0xf9c74073}},	//   اتصا, égas, urge, ущен,
   {{0x637d0300,0x6b820036,0x61ed3736,0xa4f30099}},	//   lénd, amog, _mpal, _असेच_,
   {{0x6d470069,0xd8b801b2,0x00000000,0x00000000}},	//   _imja, ادها_, --, --,
   {{0x61ed4074,0x399902d0,0x637d0300,0x32091008}},	//   _opal, _tès_, nénd, _oray_,
   {{0x857903e6,0x7d1200b5,0x613010c0,0x00000000}},	//   ксот_, _újsá, _bäll, --,
   {{0x63520228,0x6606008d,0x00000000,0x00000000}},	//   māni, ækka, --, --,
   {{0xf770042c,0xad9b05ee,0x768b01c2,0x61ed0635}},	//   _کال_, _brúk, _böyü, _apal,
   {{0x60c50037,0xe2860b46,0xb60200b8,0x48fd01c0}},	//   _adhm, илни, čárk, लयको_,
   {{0x7ae94075,0x613008f9,0x273801cb,0x9980016f}},	//   _mbet, _fäll, _séng_, šiť_,
   {{0x613006d7,0x64a54076,0x25bf22be,0xdb0500f7}},	//   _gäll, _така, msul_, sphè,
   {{0xa06a34d4,0x7ae94077,0x6722006f,0x635200ea}},	//   тава_, _obet, _yooj, hāni,
   {{0x6604042a,0x32091bae,0x75231dab,0x63764078}},	//   _šiki, _fray_, _honz, máno,
   {{0x25bf0043,0x6376006c,0x7dc600d1,0xd17600af}},	// [3900] nsul_, láno, شقان, _выны,
   {{0x7ae94079,0x127b0070,0x7523081b,0x00000000}},	//   _abet, _באפע, _jonz, --,
   {{0xc5f20162,0xf53600c2,0x7523407a,0x0cb90033}},	//   _अन्य_, סטער_, _monz, ুভূত,
   {{0x25bf007c,0x637d01dd,0x79a60b61,0x305b0d85}},	//   ksul_, cénd, арке, _ידיד,
   {{0x6b82407b,0x6722006d,0x680000fd,0x00000000}},	//   rmog, _rooj, kájá, --,
   {{0x6b82407c,0x6722007c,0xed5a0043,0x82770070}},	//   smog, _sooj, _рог_, בענע_,
   {{0xd7fa09eb,0xc6230033,0x02b60099,0x4aba00af}},	//   тул_, _বেলা_, _अजून, _аузя_,
   {{0x3ea0407d,0x6130013c,0x660d093f,0xab271159}},	//   ncit_, _säll, _šaka, _коса_,
   {{0x38c8006c,0x25bf043d,0x80d7073f,0x94aa08ce}},	//   _ماضی_, gsul_, _बाले, ктна_,
   {{0x96a602e4,0x612b2f90,0xdb0e0044,0x00000000}},	//   _ट्रॉ, _tüli, _avbø, --,
   {{0x61ed407e,0xa4140083,0x6376407f,0x6d890009}},	//   _spal, ান্য_, ránn, _džah,
   {{0x3dc0010d,0x3ea000d5,0x32093080,0x637d01ef}},	//   ksiw_, jcit_, _pray_, xénd,
   {{0x613003ad,0xa3d40567,0x15a702fb,0x6d40010b}},	//   _täll, िंह_, _къщи_, _įman,
   {{0x75234080,0x59c902e4,0xf1bf0037,0xf66900f8}},	//   _gonz, _रिसर, rsá_, _صحنه_,
   {{0x637d0391,0xf1bf4081,0xdb05000d,0xe8090066}},	//   ténd, ssá_, sphé, विया_,
   {{0x65684082,0x613018af,0x3f8f0093,0x442c4083}},	//   lodh, _jälj, ögu_, myd_,
   {{0x61ed4084,0x637d4085,0x442c001e,0x7523012f}},	// [3910] _upal, rénd, lyd_, _yonz,
   {{0x2cb800d5,0xeca70fb4,0x40352b56,0x9d140043}},	//   _cerd_, рјан, _геос, одуч,
   {{0x443e4086,0x656f000d,0x442c00e5,0x00000000}},	//   nzt_, îchi, nyd_, --,
   {{0x2731024e,0x6376006c,0x635200ea,0x65680b4f}},	//   _ráno_, jánl, tāni, hodh,
   {{0x98a51c6b,0x442c4087,0x3eb90051,0x2cb801e0}},	//   биле, hyd_, _iest_, _ferd_,
   {{0x63a40076,0x3eb94088,0x6e2d01d5,0x2cb84089}},	//   _činn, _hest_, myab, _gerd_,
   {{0x01380122,0x25a601dd,0x2d9901b4,0x59c90084}},	//   שרות_, _atol_, _huse_, _रिवर,
   {{0x3eb91ea2,0x442c001e,0x00580122,0x2d99408a}},	//   _jest_, dyd_, ישות_, _kuse_,
   {{0x6e2d408b,0x3eb9408c,0x7523027a,0xd70600c3}},	//   nyab, _mest_, _ponz, сные_,
   {{0xf9900206,0x442c02c7,0x25bf0043,0xd7e702ce}},	//   _قبل_, fyd_, rsul_, _відо,
   {{0x232a408d,0xa8a405ea,0x3cfa004e,0x2d91408e}},	//   гони_, _фрук, _उससे_, _mize_,
   {{0xe695004f,0x6376016f,0x6d890009,0x2d91408f}},	//   _الإد, ráno, _džai, _lize_,
   {{0x65680118,0x637d01dd,0xa696011d,0x7f4d4090}},	//   bodh, xéne, _הכנה_, diaq,
   {{0xa0a302fb,0x753a2a3a,0x442c016e,0x2d91273b}},	//   зард, chtz, byd_, _nize_,
   {{0x3eb94091,0x251a0122,0x1dda4092,0xaad80066}},	//   _best_, _תוצא, यूनत, _डालक,
   {{0xdd92004f,0x637d006c,0x2d910065,0x61300282}},	//   كور_, téne, _aize_, _kälk,
   {{0x2d914093,0x613003ad,0x2cb84094,0x3ea04095}},	// [3920] _bize_, _jälk, _perd_, rcit_,
   {{0x3eb90006,0x2d994096,0x3ea02579,0x2d9100a0}},	//   _eest_, _duse_, scit_, _cize_,
   {{0x417607a8,0x3eb94097,0x2cb84098,0xdd8f0041}},	//   _پاکس, _fest_, _verd_, روم_,
   {{0x2cb84099,0x2ca1004a,0x26dd00d7,0x6e2d018c}},	//   _werd_, achd_, _ncwo_, byab,
   {{0x77690453,0x7c3e00b5,0x2d910260,0x656808c7}},	//   doex, szpr, _fize_, yodh,
   {{0x3f9a00d6,0x613006d7,0x3eb92b28,0x6f04409a}},	//   _kupu_, _sälj, _zest_, ldic,
   {{0xb9000755,0x63a40c99,0x25a6409b,0xa7fc04d4}},	//   _था_, _čino, _stol_, _ayır,
   {{0x6f04409c,0xcb6a00d8,0x629608dd,0x9634409d}},	//   ndic, _сабе_, _ngyo, жниц,
   {{0x6130409e,0x442c02c7,0x612b0723,0x6f0400f1}},	//   _välj, wyd_, _kült, idic,
   {{0x443e0446,0x442c0626,0x00000000,0x00000000}},	//   tzt_, tyd_, --, --,
   {{0x78ba0029,0x6568409f,0x00000000,0x00000000}},	//   _ietv, rodh, --, --,
   {{0x442c40a0,0x443e01ae,0x6aa240a1,0xa3d70066}},	//   ryd_, rzt_, ncof, ाढ़_,
   {{0x667603c7,0x443e40a2,0x78ba00d8,0x69c20173}},	//   _ادار, szt_, _ketv, nsoe,
   {{0x3eb90006,0x70d300a1,0x2d9940a3,0x02db00b4}},	//   _sest_, तलेल, _ruse_, _भावभ,
   {{0xdbf101c0,0x889b0070,0x3f9a40a4,0x78ba0207}},	//   _příj, רבלי, _cupu_, _metv,
   {{0x2d9140a5,0x2d9940a6,0x6d5c0a1e,0x6e2d40a7}},	//   _size_, _puse_, _ajra, tyab,
   {{0x7f4d40a8,0x3eb940a9,0x612b027d,0x2d9140aa}},	// [3930] riaq, _vest_, _bült, _pize_,
   {{0x78ba40ab,0x3eb90122,0x7f4d000d,0x6e2d40ac}},	//   _netv, _west_, siaq, ryab,
   {{0x3eb940ad,0x6e2d00d7,0x28d20f8a,0x225803fc}},	//   _test_, syab, _साजि, _نجیب_,
   {{0x2d91007b,0x98a700d8,0x2d9940ae,0x69c20345}},	//   _wize_, tinį_, _tuse_, fsoe,
   {{0x49930118,0x7ccb00ea,0x69c200f8,0x00000000}},	//   سیار, tērē, gsoe, --,
   {{0x527c02b5,0x660d1001,0x78ba40af,0x612b40b0}},	//   אנדא, _šako, _cetv, _gült,
   {{0xe8090bdd,0xb8f100a1,0x78ba00a0,0x612b02b1}},	//   विधा_, _वय_, _detv, _hüls,
   {{0x3d17065a,0xe72903fa,0x661b01d7,0x612b00b5}},	//   नावे_, роид_, txuk, _küls,
   {{0x673b40b1,0x776902d7,0x78ba40b2,0xad9b0168}},	//   rhuj, roex, _fetv, _usúd,
   {{0x6f0440b3,0x6130022a,0xe80902e4,0x6d890009}},	//   zdic, _välk, विदा_, _ežav,
   {{0x09be0033,0xe8551015,0x2bd1046c,0xceb4013b}},	//   _উৎপা, _بناد, _हिफा, rkəz_,
   {{0x3f9a029d,0x63ad082d,0x799b002f,0x659540b4}},	//   _rupu_, _čand, _kuuw, _даду,
   {{0x4ade1e79,0xbebb053e,0x3f9a40b5,0x637640b6}},	//   फ्टव, _voël, _supu_, lánk,
   {{0x25ad40b7,0xb17b022a,0x3f9a40b8,0x7bd701ed}},	//   mpel_, stån, _pupu_, kuxu,
   {{0x660940b9,0x6abb00f7,0xa2e602fb,0x6f041167}},	//   lvek, _oeuf, _дойд, tdic,
   {{0x28e000b4,0x6f043376,0x6abb40ba,0x637d0042}},	//   _नाभि, udic, _neuf, rénc,
   {{0x1d261018,0xfd4a0200,0x799b018e,0x00000000}},	// [3940] омам, азак_, _nuuw, --,
   {{0x637d0248,0x3f9a0054,0xcc360987,0xbd830823}},	//   ména, _tupu_, يراع, дгук,
   {{0x61e636a2,0xb53a0070,0x6441033b,0x78ba3532}},	//   ltkl, סגעש, nzli, _retv,
   {{0x78ba0009,0xfa250083,0x2fd83dfc,0x69c240bb}},	//   _setv, _মেইল_, murg_, tsoe,
   {{0x394e02e1,0xe8fa0368,0x3d05007c,0x2a6000a8}},	//   tifs_, илд_, _होके_, çib_,
   {{0x8c46019e,0x97a619fa,0x69c20626,0x6abb0b88}},	//   _деге, орил, rsoe, _eeuf,
   {{0x3d170299,0x78ba40bc,0x394e0248,0x69c21456}},	//   नारे_, _vetv, rifs_, ssoe,
   {{0xa2d61649,0xf0930d85,0x61e640bd,0x394e000d}},	//   _भाग्, ונו_, ktkl, sifs_,
   {{0x998903ab,0x5b21006c,0xdb1e002a,0x273100cc}},	//   šaš_, _سہول, supó, _mánh_,
   {{0x2bd123f0,0x27310023,0x6b9c40be,0x637d01ef}},	//   _हिमा, _lánh_, _kurg, déna,
   {{0x66e640bf,0x6b9c40c0,0x60dc0009,0x7d7b0070}},	//   _можа, _jurg, dgrm, שריג,
   {{0x6b9c40c1,0x28c80026,0x3b060024,0xe3af0416}},	//   _murg, रणवि, ndoq_, کری_,
   {{0x6b9c40c2,0x637d00a2,0xe4da00f8,0x00000000}},	//   _lurg, géna, _نوشت_, --,
   {{0x3cf60035,0xa3b522c7,0x3ebf00cd,0xe8ee291f}},	//   ीयों_, _चौक_, _žut_, елi_,
   {{0x273101a5,0x2f190086,0x6b9c00ab,0x3d05046c}},	//   _bánh_, бовь_, _nurg, _होगे_,
   {{0x273101a5,0x2fcd0254,0x213a0526,0x394c0176}},	//   _cánh_, čeg_, _elph_, _lmds_,
   {{0xd25118dd,0x637d3113,0x68f801e8,0x3dd200e9}},	// [3950] _سند_, céna, kevd, gryw_,
   {{0xdfdb0021,0x2fd840c3,0x63a401cc,0x3d050ccf}},	//   _към_, burg_, _činj, _होखे_,
   {{0x92dd0083,0x6b9c20d4,0xe4e20387,0x60fa00a5}},	//   ড়ী_, _curg, _खानि_, _ההתק,
   {{0xdd95323d,0x3d9500af,0x27310023,0x2001023c}},	//   _намы, _нимр, _gánh_, _ishi_,
   {{0x6d580254,0x6b9c0090,0x644140c4,0x00000000}},	//   čvar, _eurg, zzli, --,
   {{0x3f8924ad,0x68f800be,0x273800ce,0x00000000}},	//   lmau_, gevd, _réna_, --,
   {{0x6abb206a,0x00000000,0x00000000,0x00000000}},	//   _teuf, --, --, --,
   {{0x6130087a,0x63763e79,0x96230083,0x7bc5000e}},	//   _väli, ránk, _বেগম_, mshu,
   {{0xe61640c5,0x7bc540c6,0x59d200ab,0x6130081b}},	//   зды_, lshu, _सियर, _wäli,
   {{0x644102c9,0x69d940c7,0x637640c8,0x66093f94}},	//   tzli, muwe, máni, rvek,
   {{0xd4690274,0x28e01d78,0x69d940c9,0x6b9c01b7}},	//   сине_, _नाति, luwe, _xurg,
   {{0x290540ca,0x644140cb,0x33290223,0x7af90069}},	//   _hala_, rzli, _coax_, newt,
   {{0x290509df,0x7bc540cc,0x63aa0036,0x69d940cd}},	//   _kala_, hshu, _etfn, nuwe,
   {{0x290740ce,0x273101a5,0x29fd01ba,0x61e640cf}},	//   ndna_, _sánh_, _mňa_, rtkl,
   {{0x290540d0,0xb4d700a1,0x61e640d1,0x69d940d2}},	//   _mala_, िली_, stkl, huwe,
   {{0x2fd8029d,0x69d940d3,0x7bc522ac,0x1dc70461}},	//   rurg_, kuwe, dshu, _लिखत,
   {{0x6b9c40d4,0x0e633bd5,0x68f800a8,0x2fd840d5}},	// [3960] _surg, ектн, yevd, surg_,
   {{0xee371f7e,0x2b4d0211,0xa91c01ba,0x69d940d6}},	//   чну_, _amec_, _ohľa, duwe,
   {{0x69d901e4,0xad9b40d7,0x309b00a5,0x3ea600af}},	//   euwe, _brús, _לשימ, _нинг,
   {{0x2907007a,0x23a1004e,0x29050159,0x3d0c0066}},	//   edna_, _mój_, _aala_, _डोरे_,
   {{0x290540d8,0x63760b4c,0x28e000b4,0x6b9c01bf}},	//   _bala_, gáni, _नादि, _wurg,
   {{0x6b9c40d9,0x290540da,0x29fd016f,0x6d891e80}},	//   _turg, _cala_, _dňa_, _džas,
   {{0x6d4e40db,0x7c65250f,0xad9b40dc,0xa91c00ee}},	//   _imba, _قافل, _frús, _chľa,
   {{0x290701f7,0xceb400a8,0x569440dd,0xfbd10355}},	//   adna_, nbə_, майт, _हितम,
   {{0x290540de,0x20dc40df,0x69d92b28,0x63760f56}},	//   _fala_, _बांध, cuwe, cáni,
   {{0xb4b602e4,0xaa3b00a5,0x00000000,0x00000000}},	//   जरे_, _התמח, --, --,
   {{0xd6cf40e0,0x3f89016e,0xdb1c00ac,0x14dd0099}},	//   _пт_, ymau_, _zvrá, _मारण,
   {{0x66e3135e,0x290540e1,0x613000be,0x66e640e2}},	//   _गायक_, _zala_, _mälu, _хода,
   {{0x290540e3,0x51870ea4,0x798a0221,0x4cc70033}},	//   _yala_, зува, omfw, র্টু,
   {{0x92dd00c8,0xf61700a5,0x660240e4,0x0cd70033}},	//   ড়ে_, _מחדש_, _isok, _হস্ত,
   {{0x5064021d,0x69d9033b,0x6f060be2,0x6d890168}},	//   етта, zuwe, _bakc, _ožar,
   {{0x6d4e40e5,0x7bc70009,0x637d40e6,0x27310097}},	//   _amba, _rvju, méno, _páni_,
   {{0x3f8900e9,0x6f0628c4,0xa3d400b4,0x637d00d5}},	// [3970] rmau_, _dakc, िंक_, léno,
   {{0x2bd10066,0x6602034d,0x00000000,0x00000000}},	//   _हिदा, _msok, --, --,
   {{0x629a01c0,0xd2510e3a,0x3d0c0099,0x613000be}},	//   ětov, _سنگ_, _डोळे_, _pälv,
   {{0x637640e7,0x660201d7,0x6d4e40e8,0x69d940e9}},	//   táni, _osok, _emba, tuwe,
   {{0x29050269,0x6d890009,0xdd910ae7,0x00000000}},	//   _pala_, _džar, _لوح_, --,
   {{0x637640ea,0x290540eb,0x6f060051,0x3cfa0176}},	//   ráni, _qala_, _zakc, cepv_,
   {{0xccf20bed,0x290534b7,0x290740ec,0x660240ed}},	//   _שכל_, _vala_, rdna_, _asok,
   {{0x290540ee,0x05a902ce,0xa2a20355,0x69d908dd}},	//   _wala_, овий_, कुञ्, puwe,
   {{0x290509bd,0x6d890254,0x7d0740ef,0xa3df00a1}},	//   _tala_, _užas, _kajs, धून_,
   {{0xb4d73dd4,0x29050176,0x98a50107,0x53c932fa}},	//   िले_, _uala_, _kolč_, огом_,
   {{0x7d0740f0,0xa3d40fd1,0x6602046a,0x637d0187}},	//   _majs, िंग_, _esok, rénn,
   {{0x4cc70033,0x7d0740f1,0xdcf500ec,0x00000000}},	//   র্চু, _lajs, _bizī, --,
   {{0xe56e0133,0x6f06023a,0xceb4013b,0x00000000}},	//   _аз_, _rakc, vbə_, --,
   {{0x65940c9f,0x6f060088,0x00000000,0x00000000}},	//   _зачу, _sakc, --, --,
   {{0xdee6304c,0x6f06028b,0x10a340f2,0xd00740f3}},	//   мови, _pakc, тисн, мере_,
   {{0x672b40f4,0x26df002f,0x63f60118,0x00000000}},	//   _jogj, nguo_, _آفيس_, --,
   {{0x63a4011c,0x7d0740f5,0xb606008d,0xceb400a8}},	// [3980] _čini, _bajs, mráð, rbə_,
   {{0x672b01f4,0xe6070594,0x7d070282,0xb606008e}},	//   _logj, _یش_, _cajs, lráð,
   {{0x711b02b5,0x7d070009,0x69c9030d,0x672b0223}},	//   _וויפ, _dajs, _avee, _oogj,
   {{0x28e02fa9,0x3cfa006a,0x6ea50324,0x973c00cd}},	//   _नाहि, _उसके_, _कलयु, _kuće,
   {{0xd946135d,0x636806d3,0x6130013c,0x973c0124}},	//   меди, mınd, _fält, _juće,
   {{0x63680d6f,0x7d0730bc,0xb4d7000c,0x6d4e40f6}},	//   lınd, _gajs, िलो_, _umba,
   {{0x6130022a,0x315702b5,0x69da030f,0x6aa9016e}},	//   _häls, ויסן_, _नमकी, _ffef,
   {{0x636806d0,0x28e00026,0x85a60370,0x6d8900cd}},	//   nınd, _नावि, мјод, _užar,
   {{0x63ad0c99,0x2d9840f7,0xd37900cd,0x672b0031}},	//   _čana, _kire_, nuće_, _dogj,
   {{0x2d981080,0x6368027b,0x00000000,0x00000000}},	//   _jire_, hınd, --, --,
   {{0x2d9840f8,0x443840f9,0x9980010b,0x6368033e}},	//   _mire_, ár_, šių_, kınd,
   {{0x2d9840fa,0x2bd10bc1,0x66020c47,0xd379011c}},	//   _lire_, _हिसा, _tsok, kuće_,
   {{0x26c440fb,0xd3790a78,0x636806d3,0x41e400d8}},	//   mamo_, juće_, dınd, кіра,
   {{0x26c440fc,0x2d980291,0xd3790254,0xe44f0e3a}},	//   lamo_, _nire_, duće_, اضی_,
   {{0xa3cb1ea2,0x4fc403d4,0x63681a68,0xa194021d}},	//   _लिए_, кста, fınd, тарч,
   {{0x2d980767,0x26c440fd,0x660d00c7,0x6d5e40fe}},	//   _aire_, namo_, _šaki, enpa,
   {{0xd37901cc,0xf1ab183b,0x8af70095,0x42550af8}},	// [3990] guće_, _بابه_, şəkk, _سندر,
   {{0x26c440ff,0x2d98000d,0xa2b9021a,0x00000000}},	//   hamo_, _cire_, ्णक्, --,
   {{0x2d984100,0x8af93943,0x26c44101,0x61304102}},	//   _dire_, знес_, kamo_, _vält,
   {{0x26c403ba,0xf38a0019,0x2d984103,0x613002b1}},	//   jamo_, _bảy_, _eire_, _fäls,
   {{0x26c44104,0xad9b004f,0x28e000a1,0x63764105}},	//   damo_, _grúp, _नाशि, mánt,
   {{0xde1602b5,0x63764106,0x3ea94107,0xd1220f06}},	//   _אַלץ_, lánt, lcat_, मायण_,
   {{0xb9070006,0x28e00084,0x3f994108,0x2d4f0067}},	//   _भा_, _नारि, _kisu_, yżej_,
   {{0x3ea94109,0x26c4410a,0x9ac700b5,0x3f9901e9}},	//   ncat_, gamo_, _آگاہ_, _jisu_,
   {{0x29d51b15,0x59c902e4,0x3f993731,0x00000000}},	//   _سياس, _रिटर, _misu_, --,
   {{0x9a840499,0x142507b0,0x636800c1,0x2d9801ef}},	//   _русл, едом, zınd, _xire_,
   {{0x26c4410b,0x61f60044,0x636804d4,0x1bff0387}},	//   bamo_, _spyl, yınd, ईबिल_,
   {{0x3f990537,0x26c41830,0x636800a8,0x273100ac}},	//   _nisu_, camo_, xınd, _pánu_,
   {{0xf38a01a5,0xb606008a,0x15f300ab,0xdb05003e}},	//   _xảy_, rráð, _अहिर_, pphæ,
   {{0x25d602b5,0x6e2012c3,0xb606008a,0xd3790124}},	//   _נוצן_, _àmbi, sráð, vuće_,
   {{0x63680dac,0x2d9800f7,0xe46500be,0x656600b5}},	//   tınd, _rire_, ööde_, ékhe,
   {{0x6d5e410c,0x539a00a5,0x613001ff,0x00000000}},	//   wnpa, _ציפו, _päls, --,
   {{0x6368036a,0x3dc9324e,0x2d98410d,0x0d86410e}},	// [39a0] rınd, gsaw_, _pire_, елан,
   {{0x63680eab,0x26c430c6,0x59c90084,0x613001ff}},	//   sınd, zamo_, _रिजर, _väls,
   {{0xf53600c2,0x2d9802e9,0xd379025c,0x3f991a8a}},	//   עטער_, _vire_, suće_, _fisu_,
   {{0x3ea9410f,0x205700c2,0x2bd10d1f,0x273101ef}},	//   ccat_, _טייל_, _हिरा, _máns_,
   {{0x637600d5,0x2d981691,0x00000000,0x00000000}},	//   láns, _tire_, --, --,
   {{0x26c42eb4,0xf806002d,0xdbc700ab,0x26cf0345}},	//   wamo_, ечин, _rööv, _adgo_,
   {{0x26c42792,0x777b002a,0xdb1c0523,0x00000000}},	//   tamo_, flux, _avrå, --,
   {{0x62840036,0xdb0e0523,0xf4150033,0x00000000}},	//   _ozio, _avbö, াহার_, --,
   {{0x26c43489,0x7bde4110,0x6e24002a,0xbb43021f}},	//   ramo_, lupu, nxib, _сетк,
   {{0xa3cb1163,0x61fb0132,0xbebb0345,0xd90d0ef2}},	//   _लिख_, çulm, _hoët, _وین_,
   {{0x628401d3,0x26c44111,0x7bde4112,0x799a002f}},	//   _azio, pamo_, nupu, _iitw,
   {{0x7ae24113,0xdbc700ab,0x799a04fb,0x6edc1f57}},	//   ngot, _tööv, _hitw, _फागु,
   {{0x7bde02c2,0x799a4114,0x00000000,0x00000000}},	//   hupu, _kitw, --, --,
   {{0x7bde4115,0xa4d402ce,0x3f99007c,0x799a035f}},	//   kupu, _рокі, _sisu_, _jitw,
   {{0x799a4116,0x3ea913b6,0x7ae20398,0x6284027a}},	//   _mitw, tcat_, kgot, _ezio,
   {{0x799a4117,0x7d1c0160,0x3f99007a,0x7ae20207}},	//   _litw, _anrs, _qisu_, jgot,
   {{0x3ea94118,0x3f991d19,0x6376063d,0x3f9e008d}},	// [39b0] rcat_, _visu_, ránt, ítur_,
   {{0xceeb00bf,0x3ea94119,0x3dc9411a,0xfd610019}},	//   _کردن_, scat_, rsaw_, _huyế,
   {{0x3f99411b,0x60c7021e,0x3ea91faf,0x9c190037}},	//   _tisu_, majm, pcat_, بياء_,
   {{0x7ae20464,0x60c7411c,0x799a002f,0x7f4400f6}},	//   ggot, lajm, _aitw, chiq,
   {{0x6f1d05f0,0x799a411d,0xd7f8002d,0xf77102fd}},	//   _insc, _bitw, _apă_, یاب_,
   {{0x60c7088a,0x7ae201d7,0x799a0260,0xfd6100e2}},	//   najm, agot, _citw, _luyế,
   {{0x2bd800b4,0xdcfc005f,0xd942411e,0x00000000}},	//   _डिया, _airė, рещи, --,
   {{0xe6191f39,0x00000000,0x00000000,0x00000000}},	//   дди_, --, --, --,
   {{0x7b64411f,0xd7060086,0x63764120,0x644800a0}},	//   _стре, тные_, záns, ezdi,
   {{0x6f0d3ad6,0x2bd8020d,0xdb05033b,0x60c70a66}},	//   hdac, _डिमा, sphä, jajm,
   {{0x6f1d4121,0x69cb0c55,0x142200d8,0x67d40fc5}},	//   _onsc, lsge, адэм, _боху,
   {{0x636800c1,0x491900b8,0xdd020207,0x6d5701b7}},	//   dınc, पाको_, _čuči, hixa,
   {{0x799a0010,0xad9b002a,0xe8090af9,0x6f0d00e5}},	//   _yitw, _asúm, विका_, ddac,
   {{0x6f1d02c9,0x69cb4122,0x60c74123,0x67294124}},	//   _ansc, isge, gajm, ljej,
   {{0x69d901ae,0x7f4400f7,0x6f0d0051,0x6d574125}},	//   hrwe, thiq, fdac, dixa,
   {{0xd36f0082,0x973c03fd,0x67294126,0x6e2406a2}},	//   _وهو_, _kuća, njej, txib,
   {{0xdca64127,0x63a303c1,0x6d570282,0x7f440031}},	// [39c0] вази, _hunn, fixa, rhiq,
   {{0x63a34128,0x7bde4129,0x6f1d01e4,0x6f0d412a}},	//   _kunn, tupu, _ensc, adac,
   {{0x40d900c2,0x7c960b07,0x7f4402e1,0x823604e8}},	//   _אַרײ, трац, phiq, _سرکا,
   {{0x6b89130f,0x799a412b,0x63a3412c,0x6729412d}},	//   _cheg, _sitw, _munn, jjej,
   {{0x7bde412e,0x6b8900e0,0x69cb412f,0x63a34130}},	//   supu, _dheg, gsge, _lunn,
   {{0x49731728,0x14dd02cb,0x7bde4131,0x6d4501ae}},	//   аліс, _मागण, pupu, chha,
   {{0x6b9b4132,0x8b964133,0x69d90051,0x63a34134}},	//   _fiug, _арач, arwe, _nunn,
   {{0x6b9b0133,0x60c70b16,0xe3af0083,0x799a0010}},	//   _giug, zajm, _কিংব, _witw,
   {{0xe9a60133,0xd3790254,0x3d170099,0xb9080033}},	//   _разп, juća_, नाचे_, _বস_,
   {{0x973c003a,0x799a2cb5,0x637d4135,0x6368033e}},	//   _duća, _uitw, méni, yınc,
   {{0x291e4136,0x63a30014,0x533519b6,0x637d01ef}},	//   _inta_, _cunn, гент, léni,
   {{0xfd610028,0x673b0168,0x2b4600e2,0x545302fb}},	//   _quyế, ckuj, nhoc_, рвют,
   {{0x290c3035,0x60c74137,0xd3790254,0xa5f80274}},	//   _kada_, tajm, guća_, _челу_,
   {{0x63a34138,0xf8b40ccf,0x290c4139,0x63680457}},	//   _funn, ुरिय, _jada_, tınc,
   {{0x63a3413a,0xfd610028,0x290c413b,0x60c7413c}},	//   _gunn, _tuyế, _mada_, rajm,
   {{0xf1a71b17,0x6f0d413d,0xe0e30083,0x60c7022f}},	//   _ирон, udac, য়েন, sajm,
   {{0x6f0d0571,0xc29902ce,0x6d57413e,0x5f9401e0}},	// [39d0] rdac, _яких_, tixa, ритт,
   {{0x290c2140,0x50b720a3,0x6f0d1d22,0x320908dd}},	//   _nada_, _अभिष, sdac, _isay_,
   {{0x290e001e,0x4035413f,0x69c00069,0x6d5701a3}},	//   ddfa_, _сенс, _awme, rixa,
   {{0x41c4064e,0x6d4500d7,0x69cb4140,0x6f1d3236}},	//   _حقیق, shha, tsge, _unsc,
   {{0x290c0291,0x61ef4141,0x637d4142,0x19591385}},	//   _bada_, ntcl, géni, нады_,
   {{0x69cb4143,0x2a69003c,0xc4bd0033,0x2b4600e2}},	//   rsge, ħab_, _ইঞ্জ, ahoc_,
   {{0x60c54144,0x6d550463,0x290c4145,0x38ca1328}},	//   _mehm, _imza, _dada_, راوی_,
   {{0x80dc0083,0x60c51b36,0x06090011,0x63a34146}},	//   ম্প্, _lehm, еник_, _runn,
   {{0x63a309bd,0x290c009c,0x67294147,0x673b4148}},	//   _sunn, _fada_, rjej, rkuj,
   {{0x290c0ae0,0x60c502c9,0xc9871c1e,0x63a34149}},	//   _gada_, _nehm, _руби, _punn,
   {{0x7e7d0b41,0x00000000,0x00000000,0x00000000}},	//   _lysp, --, --, --,
   {{0x63a3414a,0xc65400f8,0x3f4700be,0x00000000}},	//   _vunn, افیک, _jõud_, --,
   {{0x973c0a78,0x290c008f,0x63a30103,0xf770028c}},	//   _kućn, _yada_, _wunn, _بال_,
   {{0x06e30ccf,0xa11604e8,0x75d2414b,0x63a3414c}},	//   _गाँव_, دوست, _ايوا, _tunn,
   {{0xd3790c21,0xa0670dfc,0x60c5012f,0x7ae90612}},	//   suća_, гара_, _dehm, _ocet,
   {{0x2eb5052c,0xff0700af,0x7e7d0345,0x3f8b148a}},	//   исус, леск_, _bysp, _chcu_,
   {{0x60c5414d,0x637d01dd,0xcb1d0035,0x33200024}},	// [39e0] _fehm, xéni, फाईड_, _inix_,
   {{0x7e7d414e,0x63ad0009,0x637d414f,0x6464010b}},	//   _dysp, _čanj, véni, štiš,
   {{0x06e30953,0xdd8f004f,0x9f5e00b5,0x1016010b}},	//   _गांव_, أول_, ító_, _сьпя,
   {{0x290c0537,0xbda60a86,0xbae500d4,0x32090159}},	//   _sada_, _محسو, ицій, _ysay_,
   {{0x290c4150,0x629b0009,0x973c0207,0x00000000}},	//   _pada_, žuov, _bućn, --,
   {{0x3f804151,0x2b460069,0x290c4152,0xdca32a63}},	//   lliu_, shoc_, _qada_, _гари,
   {{0x8c4601ee,0x290c4153,0x637d0138,0xb8cc07b5}},	//   _севе, _vada_, séni, _गल_,
   {{0x290c0096,0x47341999,0xa81700f8,0xbb430212}},	//   _wada_, рнис, اتور_, _леск,
   {{0x290c4154,0xa3e609b4,0xdb1e09af,0x7d0e034d}},	//   _tada_, यून_, rspä, _kabs,
   {{0x291e011e,0xa9760bfe,0x5f16198f,0xdc340168}},	//   _unta_, _субј, _पोस्_, _lúčo,
   {{0x24980301,0xb9930037,0x60c54155,0x3f8000c7}},	//   ärm_, _اللب, _rehm, kliu_,
   {{0xdc3b0070,0x929505c4,0x7d0e4156,0x918200e2}},	//   געטר, ианц, _labs, yễn_,
   {{0x60c5073c,0x363603c7,0x00000000,0x00000000}},	//   _pehm, _حراس, --, --,
   {{0x3320012f,0x7d0e009e,0x61ef0479,0x973c011c}},	//   _enix_, _nabs, rtcl, _kućo,
   {{0x61ef0069,0xe8170066,0xdfd802fb,0x855600b5}},	//   stcl, थिया_, лът_, _لیکر_,
   {{0x7d0e4157,0x3f800409,0x60c5095a,0x636801fb}},	//   _aabs, gliu_, _wehm, pına,
   {{0x5d551285,0x3209010d,0x6e99005f,0x3f4700be}},	// [39f0] акат, _usay_, твар_, _nõue_,
   {{0x7ae907e5,0x7e7d0187,0x7cfa0a8a,0x00000000}},	//   _scet, _vysp, _røræ, --,
   {{0x7e7d0035,0x3f804158,0x7d0e013a,0x3ea64159}},	//   _wysp, bliu_, _dabs, žota_,
   {{0x681c002d,0xb17b013c,0x00000000,0x00000000}},	//   _mădă, fråg, --, --,
   {{0x36de0084,0x6f0f0036,0x2b44023a,0x2bd1060a}},	//   _गाड़ी_, _iacc, _dlmc_, _हिका,
   {{0x26c90c0a,0x7d0e0103,0x80ba012f,0x00000000}},	//   _žao_, _gabs, ्रये, --,
   {{0xb17b27fe,0x6f0f415a,0xe7310037,0x681c0139}},	//   mråd, _kacc, قصة_, _nădă,
   {{0x25a60034,0x6f0f415b,0xb17b0075,0xdb0708c8}},	//   _buol_, _jacc, lråd, _stjæ,
   {{0x6f0f415c,0x7545415d,0x00000000,0x00000000}},	//   _macc, иниз, --, --,
   {{0x5a34415e,0x6f0f1f26,0x25a6010d,0xb4cf01d1}},	//   _унут, _lacc, _duol_, षणे_,
   {{0xd469415f,0x336628fb,0x39454160,0x6f0f0523}},	//   тине_, ивог, _ills_, _oacc,
   {{0x6f0f17a4,0xad9b01ef,0xa3ab04bc,0x17f80037}},	//   _nacc, _crúz, _कंठ_, _حركة_,
   {{0xf7704161,0xa3e602e4,0x00000000,0x00000000}},	//   _عام_, यूब_, --, --,
   {{0xe0460336,0xa06a01c8,0xd379044d,0x00000000}},	//   анги, вага_, vrće_, --,
   {{0xd47902b5,0x7d0e4162,0x1fb50823,0x9fc74163}},	//   _באַל, _rabs, йстр, игра_,
   {{0x6f0f02fb,0x7d0e4164,0x3f80004b,0x33203ddf}},	//   _cacc, _sabs, uliu_, _unix_,
   {{0x2a7f006d,0x6f0f4165,0xdcf50260,0x681c0160}},	// [3a00] _nyub_, _dacc, _ekzč, _zădă,
   {{0x8cb602fb,0x00000000,0x00000000,0x00000000}},	//   рсач, --, --, --,
   {{0x6f0f01d3,0x6c4a0a72,0x2a7f08eb,0x2a6d008c}},	//   _facc, خلاف_, _ayub_, _axeb_,
   {{0xa3e602cb,0x39450583,0x00000000,0x00000000}},	//   यंत_, _alls_, --, --,
   {{0x7d0e0189,0x637d01dd,0x201a0124,0xdca63537}},	//   _tabs, mént, _hrpi_, _ваги,
   {{0x6f0402bf,0x6f0f027a,0xb4cf018d,0xa3e60127}},	//   leic, _zacc, षणो_, यूड_,
   {{0xed57126e,0x25a60036,0x2a7f0118,0xae0e00b4}},	//   _тор_, _suol_, _eyub_, सिकन_,
   {{0x394512c3,0x681c00af,0x44200160,0x00000000}},	//   _ells_, _rădă, _ăi_, --,
   {{0x48e64166,0x00000000,0x00000000,0x00000000}},	//   _возв, --, --, --,
   {{0x6b824167,0x2369044d,0x98a34168,0x25a602fb}},	//   llog, _sjaj_, _дифе, _vuol_,
   {{0x63681505,0xc8b5004b,0xd6c400d1,0x6139009e}},	//   rınn, _ысты, _همای, _mìlt,
   {{0x6b820a6d,0x27fe012f,0x00000000,0x00000000}},	//   nlog, _iptn_, --, --,
   {{0x6f0f4169,0x05b40071,0x644500ab,0x6b82416a}},	//   _racc, _امتح, _ühin, ilog,
   {{0xd5fb0052,0x6f0f416b,0x67220187,0x5067416c}},	//   _ספור, _sacc, _hnoj, атба,
   {{0x6f0f02fb,0x6b8201a2,0x6f04416d,0x201a00cd}},	//   _pacc, klog, feic, _crpi_,
   {{0xddc4004e,0x6b820069,0x637d000d,0x63ba3c2c}},	//   dził, jlog, ténu, mptn,
   {{0x6b8202dd,0x212101a5,0x7bde416e,0xb17b2bf2}},	// [3a10] dlog, _tnhh_, erpu, tråd,
   {{0x6f0f1c2a,0x6b82416f,0xacf400fd,0x00000000}},	//   _wacc, elog, قسمت, --,
   {{0x6f0f4170,0x6b820297,0xb17b1cd4,0x6368027d}},	//   _tacc, flog, rråd, kınl,
   {{0x637d0b06,0xb17b1cd4,0xa3f7016b,0x6f0f0b3e}},	//   cént, sråd, שמאק_, _uacc,
   {{0x636806d0,0x7bde4171,0xda074172,0xf8b40ac4}},	//   dınl, arpu, рчеп, ुरूप,
   {{0xdb07022a,0x18691eb9,0xe77800b5,0x261a01c0}},	//   _stjä, лали_, یلوں_, बिनी_,
   {{0x6d474173,0x98f401b2,0xdb09033b,0x00000000}},	//   _ilja, تثنا, _gieß, --,
   {{0x6b820392,0x2ee94174,0x00000000,0x00000000}},	//   clog, ngaf_, --, --,
   {{0x7afb02b3,0xe5790dee,0x6d4700cd,0xb60500d5}},	//   _ibut, лзи_, _klja, kráš,
   {{0x6f0402c9,0x67224175,0x39450443,0x99850037}},	//   zeic, _enoj, _ulls_, _الطو,
   {{0x6d472190,0xb60500ac,0x00000000,0x00000000}},	//   _mlja, dráš, --, --,
   {{0x67224176,0x6f04002a,0x637d01ef,0x7d050118}},	//   _gnoj, xeic, xént, hehs,
   {{0xb5a70ea7,0xd774004f,0x52760c14,0x6f044177}},	//   _трей, _بالع, суну, veic,
   {{0x67224178,0x6b821851,0x6f04033b,0x66094179}},	//   _znoj, zlog, weic, mwek,
   {{0x6f04417a,0x7afb417b,0x637d0b4c,0x63680644}},	//   teic, _obut, tént, lınm,
   {{0x27ea01b4,0x660908c7,0x00000000,0x00000000}},	//   _åbne_, owek, --, --,
   {{0x6f040446,0x637d417c,0x63680716,0x6d47003d}},	// [3a20] reic, rént, nınm, _blja,
   {{0x7afb417d,0x637d27c2,0x201a1635,0x6f0400f1}},	//   _abut, sént, _trpi_, seic,
   {{0x6b82417e,0x636801d6,0x61e6417f,0x6f04033b}},	//   tlog, yınl, lukl, peic,
   {{0xf0930122,0x63680095,0x66094180,0xba2600af}},	//   _מנת_, xınl, kwek, йдек,
   {{0xceb30779,0xb34703e6,0x61e64181,0x395c4182}},	//   _מיר_, luçõ, nukl, tivs_,
   {{0x6b824183,0xa7b80370,0x7afb0103,0x00000000}},	//   slog, алку_, _ebut, --,
   {{0x6c361c04,0x6d5e0238,0xd7fa0036,0x395c01ff}},	//   _افزا, mipa, уул_, rivs_,
   {{0x6d5e4184,0xa3e60035,0xcc3b0070,0x6b6300af}},	//   lipa, यंस_, _געלט, _екса,
   {{0xfa6a00af,0x3f4700be,0x63680448,0x00000000}},	//   _саак_, _jõua_, rınl, --,
   {{0x6d5e4185,0x61e64186,0x7afb0031,0xf8ac07b5}},	//   nipa, dukl, _zbut, _चलिय,
   {{0xa3ab0084,0x43954187,0x161600be,0x00000000}},	//   _कूद_, жанс, तिहर_, --,
   {{0xdc9b0c37,0x6d5e4188,0xb34703e6,0x66093736}},	//   טייל, hipa, duçõ, bwek,
   {{0x6d5e4189,0x66e300d8,0xf8ac0035,0xe6960037}},	//   kipa, _хоча, _चलाय, _الشد,
   {{0x067b00c2,0x6d5e418a,0xe3af03c5,0xdb000055}},	//   _ענגל, jipa, بری_, _bimë,
   {{0x6d5e418b,0x656f00fd,0xd48f05ac,0x657a418c}},	//   dipa, éche, _хр_, moth,
   {{0x3ceb0c3e,0xbfa83982,0x7eb901d3,0x61e6418d}},	//   _चाहे_, стре_, ргас_, bukl,
   {{0x171b00c2,0x61e601d6,0x7d050095,0x443e418e}},	// [3a30] נומע, cukl, tehs, lyt_,
   {{0x657a00f1,0x973c00f4,0x628d005f,0x4c4b0f99}},	//   noth, _bućk, _izao, ляем_,
   {{0x443e418f,0xfbd000bf,0x6d4702c4,0x7d0501a2}},	//   nyt_, فتن_, _vlja, rehs,
   {{0xa3ab046c,0xdb000107,0x7d0502b1,0x6d5e4190}},	//   _कंस_, _jimè, sehs, aipa,
   {{0xdd95081b,0x6d5e4191,0xdb000176,0x443e4192}},	//   _мамы, bipa, _mimè, hyt_,
   {{0x7ff400bf,0x6e204193,0x443e4194,0x973c0124}},	//   _بسیا, _ámba, kyt_, _fućk,
   {{0x61e6027d,0x657a0b48,0x00000000,0x00000000}},	//   zukl, doth, --, --,
   {{0x7afb070b,0x443e4195,0x59c601c0,0xe7394196}},	//   _ubut, dyt_, रीहर, реи_,
   {{0x63aa01ae,0xdb1c008a,0xae1c0fbf,0x657a4197}},	//   _aufn, _evró, नियन_, foth,
   {{0x61e64198,0x95551301,0xd379011c,0x63b801f7}},	//   vukl, تخبا, vrća_, _btvn,
   {{0x29074199,0x80ba00b4,0xf6d500d4,0xe29f0093}},	//   mena_, ्रसे, _діля, veða_,
   {{0xf7700514,0x61e6419a,0x65680069,0x27e701a6}},	//   _كان_, tukl, andh, munn_,
   {{0x657a0118,0x07080413,0xdb0001f7,0x6d4b00ea}},	//   both, _ديني_, _dimè, īgaj,
   {{0x2907419b,0x443e0e7d,0x31af04d4,0x657a419c}},	//   nena_, byt_, _düz_, coth,
   {{0xa0a3419d,0x61e6419e,0x628d02d0,0x48fb00b8}},	//   дард, sukl, _ezao, ल्यो_,
   {{0x77690495,0x2907419f,0xb3470279,0x61e641a0}},	//   nnex, hena_, ruçõ, pukl,
   {{0x290741a1,0x98a50067,0x00000000,0x00000000}},	// [3a40] kena_, _wolę_, --, --,
   {{0x29071851,0x63a4007c,0xf1b900b8,0x98ac0395}},	//   jena_, _hiin, íše_, _modă_,
   {{0x63a441a2,0x6d5e2873,0xbc6a006c,0x3ea61b52}},	//   _kiin, ripa, جمان_, _минг,
   {{0x6d5e41a3,0x31af037a,0x80ba0b35,0x657a023c}},	//   sipa, _yüz_, ्रवे, zoth,
   {{0xcb0701b2,0x63a441a4,0xdb0041a5,0x657a023c}},	//   زيون_, _miin, _jimé, yoth,
   {{0x290741a6,0x69db0d00,0x63a403a6,0xceb400a8}},	//   gena_, _निरी, _liin, lcə_,
   {{0x98be002d,0xa7fc00a8,0x657a02ee,0x273100b5}},	//   _altă_, _axır, voth, _hány_,
   {{0x4420114d,0x63a40b04,0xceb401c2,0x973c044d}},	//   _či_, _niin, ncə_, _kući,
   {{0x6284028b,0x657a41a7,0xcf9300a5,0x5506021f}},	//   _nyio, toth, וטה_, очна,
   {{0x637641a8,0x443e1397,0x88bc00b8,0xdb0007a7}},	//   mány, tyt_, _zněn, _simè,
   {{0xd6cf41a9,0xad1b02b5,0xceb40095,0x273100b5}},	//   _от_, בויר, kcə_, _lány_,
   {{0x657a41aa,0x443e41ab,0x74ba00b1,0x63b50bca}},	//   soth, ryt_, _श्रृ, ízna,
   {{0x657a41ac,0x63a406b3,0x3ceb009a,0xdb9b0319}},	//   poth, _diin, _चाले_, יסטר,
   {{0x443e016f,0x660241ad,0x63b80023,0x637d002a}},	//   pyt_, _ipok, _ttvn, rénq,
   {{0x63a40012,0xb4d6111a,0x403541ae,0x637600b5}},	//   _fiin, िणी_, чевс, hány,
   {{0x290741af,0xa3b700b2,0x3cfd000c,0x63a403be}},	//   zena_, _باور_, र्ने_, _giin,
   {{0xd3790537,0xdb00215f,0x80ba0246,0x290741b0}},	// [3a50] jući_, _gimé, ्रशे, yena_,
   {{0x6ac302e4,0xd3790a78,0x290741b1,0x7f4d01e9}},	//   शर्र, dući_, xena_, shaq,
   {{0x7640001e,0x823402fd,0x92ad0033,0xdab9010b}},	//   hymy, _فریا, গরী_, былі_,
   {{0x6d5c41b2,0x29072af6,0x660241b3,0xddc400ea}},	//   _emra, wena_, _opok, dziņ,
   {{0xd3790254,0x637600b5,0x00000000,0x00000000}},	//   gući_, gány, --, --,
   {{0xe81714ab,0x764000ee,0x00000000,0x00000000}},	//   थिला_, dymy, --, --,
   {{0x29070429,0xe7390036,0xb8d3046c,0x776903d0}},	//   rena_, йек_, _टल_, tnex,
   {{0x3f570484,0x27e741b4,0x6d5c0252,0xaacc06bc}},	//   għux_, runn_, _zmra, ारणक,
   {{0x290741b5,0x7769035f,0xc98703fa,0x63a441b6}},	//   pena_, rnex, _дужи, _riin,
   {{0x63a441b7,0x6d4541b8,0x34390037,0x637601ef}},	//   _siin, nkha, مسجد_, lánx,
   {{0x660241b9,0xdb0041ba,0x3cfd00e7,0x63a441bb}},	//   _epok, _simé, र्ये_, _piin,
   {{0x69c941bc,0xd7fa00a5,0xd87428c0,0x670f00b4}},	//   _kwee, _להעל, _غالب, _ासिक_,
   {{0x63a4073c,0x69c90103,0x00000000,0x00000000}},	//   _viin, _jwee, --, --,
   {{0x25bf1aec,0x55ba0122,0xd13241bd,0x69c93998}},	//   mpul_, _המסו, رمز_, _mwee,
   {{0x656141be,0x3d0f004e,0x602341bf,0x63a403a6}},	//   milh, ड़ने_, ндра, _tiin,
   {{0x0eaa0a93,0x644141c0,0x6d5c0506,0x6d4541c1}},	//   скай_, myli, _smra, ekha,
   {{0x6f1641c2,0xc7b80009,0x9f5a008d,0x2bce23db}},	// [3a60] rdyc, _mrđa_, _uppí_, हीना,
   {{0xd3790254,0x6aa941c3,0x65610279,0x98ac010b}},	//   vući_, _agef, nilh, _kodą_,
   {{0x3157012b,0x64410297,0x913b0122,0x69c9018e}},	//   _זיין_, nyli, _העיק, _awee,
   {{0x6da615ae,0x6e2001dd,0xea6400f8,0xd3790506}},	//   _нима, _ámbo, وپای, tući_,
   {{0xf38d016b,0x644141c4,0x6561003e,0x00000000}},	//   בראָ, hyli, kilh, --,
   {{0x6d5c1162,0x69c941c5,0xd379011c,0x637600b5}},	//   _umra, _dwee, rući_, rány,
   {{0x656141c6,0x69c9018e,0x6602142b,0x06e30033}},	//   dilh, _ewee, _spok, _মসজি,
   {{0xf1be052b,0x644141c7,0xddc400ea,0x85b82701}},	//   ्ठान, dyli, rziņ, олис_,
   {{0xbebb0223,0x75381f6f,0xeb970227,0x6aa8021a}},	//   _poëz, _povz, _хит_, गशीर,
   {{0xb4d601d1,0x73d80aec,0x2b460950,0x660202a7}},	//   िणे_, одор_, lkoc_, _vpok,
   {{0x69c901e4,0x764003ad,0x58bb00a5,0x656f000d}},	//   _zwee, symy, _המבצ, écha,
   {{0xaacc0569,0xc7b30d85,0x394c0098,0x6d4b00ea}},	//   ारिक, _טבע_, _hlds_, īgai,
   {{0x7afd06ea,0x660241c8,0x395e01ef,0x394c0176}},	//   _öste, _upok, _kmts_, _klds_,
   {{0x3f8241c9,0xad9b1725,0x6561021d,0x61e000fd}},	//   _akku_, _apún, cilh, ámla,
   {{0x34fb0122,0x644141ca,0x7d1502c6,0x4acc0099}},	//   _ההוד, cyli, _razs, ाराव,
   {{0x35d10299,0x9f340210,0x00000000,0x00000000}},	//   _दौड़, несі, --, --,
   {{0xc4340332,0x6d451389,0x02c30096,0x394c0147}},	// [3a70] _رکھت, tkha, _व्यभ, _olds_,
   {{0x9d140043,0x3f82081b,0x00000000,0x00000000}},	//   ндуч, _ekku_, --, --,
   {{0x69c941cb,0x69ca1ede,0x9f430355,0x70fa00a5}},	//   _swee, सीसी, lují_, _והתח,
   {{0x6d4541cc,0x7fd6011d,0x395e2a86,0x65610183}},	//   skha, _קורס_, _amts_, zilh,
   {{0xe9d800d8,0x644141cd,0x9f430355,0x2bce01c0}},	//   зкі_, zyli, nují_, हीबा,
   {{0x3f89001e,0xc7b80009,0x3eb903bc,0xba740919}},	//   llau_, _srđa_, _hfst_, رانت,
   {{0x656103e6,0x3f89001e,0x9f4300b8,0x3cfd012f}},	//   vilh, olau_, hují_, र्णे_,
   {{0x6561012f,0x69c93e8f,0xf0940317,0xeab00037}},	//   wilh, _twee, ענק_, _معك_,
   {{0xa8a72aff,0x656141ce,0x50bf0461,0x6441001e}},	//   _ерек, tilh, ्राष, wyli,
   {{0x644100d4,0x25bf41cf,0x9f430355,0x0445126e}},	//   tyli, rpul_, dují_, деон,
   {{0x3f89013a,0x656141d0,0xa2e60009,0x661b3e16}},	//   klau_, rilh, монд, svuk,
   {{0x8c1a0122,0x3cfd0253,0x65610183,0xd37900cd}},	//   קורי, र्ते_, silh, kuću_,
   {{0xa3b20992,0xd3790254,0x65610132,0x3f8900e9}},	//   _झूठ_, juću_, pilh, dlau_,
   {{0x26cf01d7,0x59e00099,0xd37900cd,0x64411023}},	//   _hego_, _निसर, duću_, pyli,
   {{0xa3cc0026,0x3f89099e,0x21a30044,0x6d8b0176}},	//   शीद_, flau_, тирм, güam,
   {{0x26cf006a,0x60c10dac,0xdb070453,0x9f430355}},	//   _jego_, ılma, _bují, bují_,
   {{0xd1ba1d05,0x2fcd00cb,0x201341d1,0xd379011c}},	// [3a80] _بابا_, ćega_, _esxi_, guću_,
   {{0x3eb9008a,0x00000000,0x00000000,0x00000000}},	//   _efst_, --, --, --,
   {{0x3f890d04,0xfb8200b5,0x25af0036,0x201c00b5}},	//   blau_, نگری, _lugl_, _évi_,
   {{0x26cf41d2,0x0b46311c,0x9f5a02d0,0x394c0453}},	//   _nego_, ьнен, _espò_, _slds_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8940572,0x2b4d123d,0x3cfd1140,0x00000000}},	//   наль, _elec_, र्दे_, --,
   {{0x59e0164f,0x6d4e0185,0x9f4300b8,0xb906073f}},	//   _निवर, _ilba, zují_, _भय_,
   {{0x27e041d3,0x26cf41d4,0x628800a8,0xa6141285}},	//   čin_, _cego_, ədov, емич,
   {{0xe9d73d35,0x6a8341d5,0xe4e600d4,0x00000000}},	//   _окт_, _алта, мінн, --,
   {{0x26cf0103,0x4a570122,0x69c241d6,0x9f4300b8}},	//   _eego_, _חשמל_, mpoe, vují_,
   {{0x3d0f0084,0xdb00002a,0xb4ae0066,0x973c012e}},	//   ड़ते_, _limí, _कली_, _suću,
   {{0xf6d6064e,0x25af41d7,0x26cf41d8,0xe7e3021a}},	//   _آزاد, _fugl_, _gego_, _गिता_,
   {{0x518741d9,0x25af41da,0xa2db0b35,0x9294010b}},	//   дува, _gugl_, पृष्, каюц,
   {{0x9f430355,0x00000000,0x00000000,0x00000000}},	//   rují_, --, --, --,
   {{0x26cf04fb,0x3f89016e,0xdb00026e,0x00000000}},	//   _yego_, tlau_, _aimí, --,
   {{0x9f580c1f,0x2bd80939,0x5f9400ca,0x6d4e41db}},	//   ntrè_, _डिजा, вист, _alba,
   {{0x200500b8,0xd25200b5,0x88bc00b8,0x3f8941dc}},	// [3a90] ůli_, _منٹ_, _vněj, rlau_,
   {{0x30152eb3,0x2b4d01ef,0x00000000,0x00000000}},	//   _здор, _slec_, --, --,
   {{0xd379025c,0x994901ba,0x2b4d41dd,0x3f89141e}},	//   suću_, núť_, _plec_, plau_,
   {{0x309a0052,0x6d4e41de,0xfb850088,0xc07a00e2}},	//   _משתמ, _elba, ردای, _lượm_,
   {{0x9f5a0093,0x26cf41df,0x6f0d41e0,0x6eba0d85}},	//   _uppá_, _rego_, meac, _מזרח,
   {{0x6f0d09e3,0x681300a8,0x59e0157d,0xdb0e00e0}},	//   leac, _hədə, _निरर, _lubè,
   {{0x26cf41e1,0x6813013b,0x7c8441e2,0x00000000}},	//   _pego_, _kədə, _ауте, --,
   {{0x6f0d41e3,0xac9441e4,0x69c209b3,0x2d8107c0}},	//   neac, _расш, bpoe, lohe_,
   {{0x681301c2,0x3989008d,0x26cf0207,0x00000000}},	//   _mədə, húsi_, _vego_, --,
   {{0xe00f0141,0x6f0d1093,0xb4e9000c,0x2d81012f}},	//   ाबाद_, heac, यले_, nohe_,
   {{0x26cf0755,0xa3e60084,0x78ac0187,0x6368027d}},	//   _tego_, यंग_, ňové, kınt,
   {{0x81d70083,0x59c61bb5,0x681300a8,0x00000000}},	//   _সহজ_, रीकर, _nədə, --,
   {{0x6f0d30d2,0x69d941e5,0x15f305e7,0x2d813a02}},	//   deac, nswe, _आमिर_, kohe_,
   {{0x463a0070,0x69d92a3a,0x00000000,0x00000000}},	//   _מענע, iswe, --, --,
   {{0x6f0d004f,0x7fd503d0,0x681300a8,0xf8b20070}},	//   feac, кіті, _bədə, רשל_,
   {{0xa3c80299,0x6f0d41e6,0x6fe10174,0xd252197c}},	//   _लौट_, geac, _फिरं, _منع_,
   {{0x9f5841e7,0xdb000279,0x20d6010b,0x69d90051}},	// [3aa0] ntré_, _limã, _пінс, jswe,
   {{0x60d51d2b,0x69d92069,0x98a50260,0xa3e3046c}},	//   cazm, dswe, _anlč_, _फटा_,
   {{0xdd8f036b,0xc1730122,0xd91000d1,0x69d90b88}},	//   حول_, _תחת_, ییر_, eswe,
   {{0x6f0d009d,0x3ce641e8,0xc446016b,0x6813013b}},	//   ceac, şov_, ערײַ_, _gədə,
   {{0x69d941e9,0xdcfc00ea,0xda650220,0x2d81007b}},	//   gswe, _ekrā, پاني, bohe_,
   {{0x6abb030d,0x48fb1d25,0x672b41ea,0x1db50067}},	//   _efuf, ल्लो_, _angj, _अंतत,
   {{0x2d9802bf,0x69c241eb,0xddcd0067,0x6abb0103}},	//   _ihre_, spoe, czał, _ffuf,
   {{0xa847004f,0x9f580093,0x3ea600ea,0x69c20051}},	//   عليم_, ftré_, žotu_, ppoe,
   {{0x3cfd02e4,0x6b82030d,0xdb00009e,0xdb0e00e0}},	//   र्वे_, moog, _iimà, _rubè,
   {{0x6b820006,0x672b41ec,0xdb0001f7,0xa9670012}},	//   loog, _engj, _himà, _зиуа_,
   {{0xd49802ce,0xdb1c1725,0x6f0d002f,0xdb0e00f6}},	//   ької_, _atré, yeac, _aubé,
   {{0x290e030d,0x88bc0355,0xd25100b5,0xd5ba002d}},	//   lefa_, _sněh, لنج_, _еск_,
   {{0xd46a00b5,0xf20405d8,0x00000000,0x00000000}},	//   تحکم_, ляро, --, --,
   {{0x6b8209e6,0x291c41ed,0xdb1c0098,0x00000000}},	//   hoog, ndva_, _dtré, --,
   {{0x6f0d0f46,0x60d510a5,0xdb070453,0x74670382}},	//   teac, razm, _lujá, _пръв_,
   {{0x681301c2,0x69c00c99,0x6b8241ee,0x69d941ef}},	//   _qədə, _otme, joog, yswe,
   {{0x6f0d41f0,0x6235140e,0xf1a71f6a,0x7bdc01d6}},	// [3ab0] reac, _репу, _прон, _avru,
   {{0x6f0d41e3,0x4ea4365f,0x00000000,0x00000000}},	//   seac, урса, --, --,
   {{0x2fd9004f,0x69c041f1,0xdb00009e,0xceb400a8}},	//   _توجد_, _atme, _bimà, mdən_,
   {{0xeab010ee,0x69d941f2,0x6b8241f3,0xddcd0035}},	//   معه_, tswe, goog, rzał,
   {{0xdb07064b,0x61fd41f4,0xdb0041f5,0x19590763}},	//   _stjó, ntsl, _simã, мады_,
   {{0xceb40669,0x3ceb009a,0x69d92b78,0xfbd316e6}},	//   ndən_, _चाटे_, rswe, _متر_,
   {{0x69c00723,0xe7392ec8,0xac9400c7,0x69d941f6}},	//   _etme, дей_, _барш, sswe,
   {{0x7bc541f7,0xdb000176,0x6abb08c7,0x9f58000d}},	//   mphu, _gimà, _ufuf, ttré_,
   {{0xceb40095,0x39150384,0x5724004f,0xeaff0026}},	//   kdən_, _имар, طريق, ोजीत_,
   {{0x637d0332,0xdb0e0300,0xdb000132,0xe3b941f8}},	//   mény, _rubé, _timã, мбо_,
   {{0x9f5841f9,0x32090159,0x798341fa,0x7bc500e2}},	//   stré_, _apay_, monw, nphu,
   {{0x3fc8006c,0x0699004f,0x61fd41fb,0x672b41fc}},	//   ہدری_, _قناة_, ftsl, _ungj,
   {{0xceb40095,0x20d600d4,0xe29712ea,0x00000000}},	//   fdən_, ківс, каю_, --,
   {{0x6e200f56,0xdb090345,0xf8d1046c,0x00000000}},	//   _ámbi, _bieë, हरिय, --,
   {{0x61fd1192,0x320907c0,0x998f00c7,0x00000000}},	//   atsl, _epay_, lygų_, --,
   {{0xdb0e002a,0x290e41fd,0xdb090345,0x98ac06fe}},	//   _tubé, zefa_, _dieë, _bodě_,
   {{0x8fa341fe,0xfe43159f,0x273800b5,0xceb400a8}},	// [3ac0] рате, анто, _pénz_, bdən_,
   {{0x64450006,0x63ae0037,0xdd8f0079,0x9f430132}},	//   _ühis, _úiné, قوق_, rujá_,
   {{0x6b8241ff,0x69c00078,0x00000000,0x00000000}},	//   toog, _stme, --, --,
   {{0xb4ae07b5,0x9f5a0282,0x998d0160,0x29050225}},	//   _कल्_, _aspö_, _preş_, _abla_,
   {{0x7983001e,0x2d980b77,0x637d00b5,0x291c0124}},	//   fonw, _thre_, gény, tdva_,
   {{0x7bc5006d,0xf80601e0,0x3ea600ea,0xdd170168}},	//   bphu, вчин, žots_, _päťs,
   {{0x9d1b02b5,0x97d72a2f,0x7d1c0037,0x290e4200}},	//   _קולט, نظير_, _iars, refa_,
   {{0xe7e30299,0x290e4201,0xceb40095,0x97144202}},	//   _गिरा_, sefa_, zdən_, умиц,
   {{0x7d1c4203,0x68ed006c,0x79834204,0xceb400a8}},	//   _kars, ándé, bonw, ydən_,
   {{0xf1dc00b1,0xdcfe4205,0x7d1c4206,0x00000000}},	//   _बिजन, kopč, _jars, --,
   {{0x295502fb,0x261702b4,0x00000000,0x00000000}},	//   _сътр, _बैठी_, --, --,
   {{0x7d1c408c,0x61fd1d2f,0x6fdc07b5,0x7bdb00a5}},	//   _lars, ttsl, _फिजू, וקטו,
   {{0xa3e60d00,0x7d1c01d7,0xceb400a8,0x00000000}},	//   यूज_, _oars, tdən_, --,
   {{0x7d1c4207,0x70bf0d00,0x61fd4208,0xa2c50033}},	//   _nars, ्रेल, rtsl, ্লেখ,
   {{0xceb401c2,0x224d4209,0xd37b16c0,0xb4ae16d3}},	//   rdən_, šek_, _очи_, कशी_,
   {{0x0ccb3779,0x6568420a,0xd43700a5,0x3eaf01b4}},	//   िर्म, lidh, _ירוק_, øgt_,
   {{0xe3b800a8,0x64480409,0xa3ac0026,0x680a00a8}},	// [3ad0] lqı_, lydi, _कूट_, _hədd,
   {{0x7d1c420b,0xbebb01d2,0x2b8e0076,0x2d8702e1}},	//   _cars, _anët, lých_, ône_,
   {{0x6ca7420c,0xe1ff420d,0x7d1c1909,0x2ca71f44}},	//   траж, ltó_, _dars, änd_,
   {{0x2b8e086d,0x7d1c0211,0x6568420e,0x63b500b8}},	//   ných_, _ears, hidh, ízni,
   {{0x7d1c420f,0x63ad4210,0xe1ff4211,0x0f3602b5}},	//   _fars, _mian, ntó_, _ערשט_,
   {{0x7d1c00d8,0x656800da,0x2b8e024e,0x6f1d097d}},	//   _gars, jidh, hých_, _hasc,
   {{0xccf20052,0x2b8e2ab5,0x6f1d4212,0xdb09000d}},	//   _לכם_, kých_, _kasc, _lieé,
   {{0xe6192f4c,0x63ad4213,0x442928c2,0x656802a2}},	//   еди_, _nian, _ča_, eidh,
   {{0x2b8e0187,0x645a00ea,0x6568023c,0xe1ff00b5}},	//   dých_, ezti, fidh, jtó_,
   {{0x6f1d4214,0x28ac06d9,0x63ad00be,0x656802ec}},	//   _lasc, _चलचि, _aian, gidh,
   {{0x63ad4215,0xe1ff0176,0x2d44017b,0x628d034d}},	//   _bian, etó_, _köer_, _ayao,
   {{0x6f1d4216,0xc7b20052,0x63ad4217,0x18a401e0}},	//   _nasc, _הבא_, _cian, _таєм,
   {{0x63ad0614,0xbbe0009a,0x6568000e,0xd6d90067}},	//   _dian, _पट्क, bidh, mał_,
   {{0x673b2dd2,0x660b00d7,0xf8c609b1,0x6b9b009e}},	//   ljuj, _ipgk, रुपय, _lhug,
   {{0x63ad4218,0xdee64219,0x6448012f,0x1fb51347}},	//   _fian, лови, cydi, истр,
   {{0x673b0496,0xd6d90035,0x63ad421a,0xa3ac0380}},	//   njuj, nał_, _gian, _कूच_,
   {{0x7d1c421b,0xdd922087,0x6f1d0395,0xe1ff00de}},	// [3ae0] _pars, مور_, _dasc, ctó_,
   {{0xdca6262e,0x7d1c013b,0x63ad421c,0x6f1d0719}},	//   гази, _qars, _zian, _easc,
   {{0x6f1d421d,0xd6d90067,0xb60500ee,0x5046081b}},	//   _fasc, kał_, _hašč, _сенб,
   {{0x7d1c421e,0x6b9b004f,0xb6050207,0x7afd1788}},	//   _wars, _chug, _kašč, _östl,
   {{0x7d1c421f,0xa96a02c4,0x298a1714,0xd6d9004e}},	//   _tars, нида_, нско_, dał_,
   {{0xc27b02b5,0xb605008b,0x6f1d4220,0x65680bf7}},	//   ערסי, _mašč, _zasc, xidh,
   {{0x656805f5,0x37aa1fff,0x6e24027a,0x8b960a80}},	//   vidh, нтин_, lvib, _брач,
   {{0x6f044221,0x65681845,0xdb0e0334,0x6b9b009e}},	//   nfic, widh, _kubí, _ghug,
   {{0x2b8e2ab5,0x63ad4222,0x44274223,0x64484224}},	//   vých_, _rian, _arn_, wydi,
   {{0x6b9b4225,0x201a0176,0x645a02b1,0x00000000}},	//   _zhug, _ospi_, tzti, --,
   {{0x33753f4b,0x65684226,0x2b8e0076,0x628d4227}},	//   игор, ridh, tých_, _syao,
   {{0x291e4228,0x63ad1c2b,0x76490010,0x4427012f}},	//   _hata_, _qian, byey, _drn_,
   {{0x291e4229,0x2b8e0076,0x63ad422a,0x645a0332}},	//   _kata_, rých_, _vian, szti,
   {{0xe1ff422b,0x291e422c,0xe693004f,0x6f040176}},	//   rtó_, _jata_, _الهد, efic,
   {{0x291e422d,0xe1ff283e,0x6f040e12,0xcf9b0431}},	//   _mata_, stó_, ffic, еја_,
   {{0x2f180b7d,0x291e004e,0x6f04043f,0x7bde177c}},	//   лось_, _lata_, gfic, dspu,
   {{0x070600b4,0x59e00835,0x4427210c,0x00000000}},	// [3af0] व्यव_, _निगर, _zrn_, --,
   {{0x291e422e,0x6b9b000e,0x6f1d01ae,0x201a022e}},	//   _nata_, _shug, _wasc, _fspi_,
   {{0xc1740052,0x6f1d422f,0xb60502c6,0x656f00f7}},	//   _לחץ_, _tasc, _zašč, échi,
   {{0xfbd000bf,0x2ef94230,0x4c9400c3,0x60d70282}},	//   ستم_, _ucsf_, щихс, _hexm,
   {{0x291e4231,0x00000000,0x00000000,0x00000000}},	//   _bata_, --, --, --,
   {{0xd6d9006a,0xed510332,0x68450036,0x18694232}},	//   wał_, _بھر_, инла, кали_,
   {{0x6b9b09e3,0x291e4233,0xd6d90035,0x00000000}},	//   _thug, _data_, tał_, --,
   {{0x5ba42691,0x06094234,0x25ae0211,0x680a013b}},	//   _груз, вник_, _aifl_, _bədb,
   {{0x291e0012,0x44274235,0x47d505f5,0xdb0e01ef}},	//   _fata_, _srn_, _چيئر, _xubí,
   {{0x291e4236,0xd6d9004e,0x05654237,0x23ba01f4}},	//   _gata_, sał_, рвон, _bëj_,
   {{0x281500d1,0x00000000,0x00000000,0x00000000}},	//   _خواس, --, --, --,
   {{0xe81b0299,0x25ee00a1,0x25ae00e5,0xb605023a}},	//   _भैया_, _आमची_, _eifl_, _pašč,
   {{0x291e0dc3,0xeb3a0070,0xbb3a0070,0x7ae40079}},	//   _yata_, דערש, דערי, óiti,
   {{0x64a54238,0x3c050066,0xdb150031,0x4427080a}},	//   _кала, _रहूँ_, _buzë, _trn_,
   {{0xdb1c0093,0xa0a62ce2,0xdb0e0b06,0x3f4700ab}},	//   _strí, равд, _subí, _nõus_,
   {{0xcc360332,0x6d554239,0xaec6423a,0x7afb0371}},	//   یراع, _alza, рбал, _ncut,
   {{0x6f04423b,0x2baf0437,0xdc3c08b7,0x4d663fe2}},	// [3b00] rfic, _जंजा, ršča, акав,
   {{0x7bde423c,0x7afb423d,0xdb00008c,0x5bae0569}},	//   tspu, _acut, _mimå, टद्व,
   {{0x291e423e,0x161c0084,0x3dc908dd,0x1d890098}},	//   _rata_, _बैनर_, apaw_, ائقي_,
   {{0x291e1de1,0x60dc423f,0x7bde4240,0xdb1c00af}},	//   _sata_, larm, rspu, _strâ,
   {{0x32020097,0xda633e10,0x00000000,0x00000000}},	//   ntky_, овци, --, --,
   {{0x60dc4241,0x07e608f1,0x28c6021a,0x00000000}},	//   narm, ацим, _र्शि, --,
   {{0x291e4242,0xb8de07b5,0x25ae023a,0xa8a302fb}},	//   _vata_, _इल_, _rifl_, орък,
   {{0xab7400d1,0x291e0e4e,0x36d40274,0xdb070093}},	//   _انرژ, _wata_, љопр, _stjö,
   {{0x291e4243,0x60dc4244,0x2b440069,0x3cfd0bdd}},	//   _tata_, karm, _iomc_, र्के_,
   {{0x60dc4245,0xe4a64246,0x00000000,0x00000000}},	//   jarm, ирно, --, --,
   {{0x60dc4247,0x332012c3,0xd49a02fb,0x3cfe22a3}},	//   darm, _baix_, ъри_, _लाने_,
   {{0x680a01c2,0x3d060141,0xf36718cd,0x33200176}},	//   _tədb, स्ते_, ртон, _caix_,
   {{0x98be0107,0x60c20395,0x00000000,0x00000000}},	//   _lotč_, _şoma, --, --,
   {{0xa18700d8,0x224b013c,0x518711ce,0x32d500e2}},	//   рымл, ryck_, рума, ấy_,
   {{0xb4c422a7,0x656f000d,0x657d00b5,0x00000000}},	//   ौरी_, èche, éshe, --,
   {{0x28c6060a,0xa85700a5,0x6d55063c,0x00000000}},	//   रुति, בילה_, _slza, --,
   {{0x60dc4248,0x236902e9,0xd25103fc,0x00000000}},	// [3b10] barm, _imaj_, _رند_, --,
   {{0x60dc4249,0x7afb002d,0x61440274,0x91a000e2}},	//   carm, _scut, _мења, _trí_,
   {{0x92d90083,0x3cfd074f,0x63b80027,0x00000000}},	//   ালী_, र्गे_, _juvn, --,
   {{0x9f4301ba,0x98be0260,0xa3b9018d,0x00000000}},	//   hujú_, _dotč_, _अंस_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfc0035,0xe9870274,0x2bd902fd,0x3f4700be}},	//   _okrę, шћен, _مارک_, _tõus_,
   {{0x9f4300a0,0x315800a5,0x2369021e,0x00000000}},	//   dujú_, שיון_, _omaj_, --,
   {{0x27e90bc6,0x21210118,0x00000000,0x00000000}},	//   čan_, _lahh_, --, --,
   {{0xd4d900ef,0x80dd0083,0x60dc424a,0x9f58424b}},	//   льні_, _বান্, yarm, ntrá_,
   {{0x60dc00a8,0x453527fb,0x6d41009e,0x00000000}},	//   xarm, схит, _òlad, --,
   {{0xb8950082,0x60dc424c,0x2b9c01c0,0x3320424d}},	//   _الاع, varm, síce_, _paix_,
   {{0x60dc424e,0x2121393e,0x63b81f2e,0xdb0e314b}},	//   warm, _aahh_, _duvn, _kubá,
   {{0x21210176,0x9f4301ba,0xdb1c0035,0xa509239c}},	//   _bahh_, bujú_, _zwró, _бела_,
   {{0x23b200e0,0x32020097,0x213300cc,0x00000000}},	//   _کميس, rtky_, _cnxh_, --,
   {{0x3202024e,0x03a60431,0x63b8424f,0xdb15021d}},	//   stky_, _лико, _guvn, _euzé,
   {{0x394508dd,0xdb1c00ac,0xd0070274,0x24984250}},	//   _lols_, _otrá, љете_, ürme_,
   {{0xf1bf00fd,0x7bc7004b,0x00000000,0x00000000}},	// [3b20] lván_, _atju, --, --,
   {{0x23694251,0x61e44252,0xdb1c01da,0xf1b500b4}},	//   _zmaj_, _ivil, _strà, ंदरन,
   {{0xdb1c0aca,0x61e41953,0x2b4401ef,0xbc6a00f8}},	//   _atrá, _hvil, _pomc_, دمان_,
   {{0x39450036,0x9f4301ba,0xdb0e00d5,0xd1042923}},	//   _aols_, zujú_, _bubá, श्रण_,
   {{0x290703d0,0x88cf0033,0x00000000,0x00000000}},	//   ffna_, _রাজক, --, --,
   {{0x394500f6,0xdb1c0079,0x9d562149,0x636f021e}},	//   _cols_, _dtrá, _انست, _kònè,
   {{0xa3f20b52,0x9f4301ba,0x3d14007c,0x39454253}},	//   _জন্য_, vujú_, ड़ीं_, _dols_,
   {{0xb8ef0141,0x00000000,0x00000000,0x00000000}},	//   _व्_, --, --, --,
   {{0x394502c4,0xdcfc0067,0x00000000,0x00000000}},	//   _fols_, _skrę, --, --,
   {{0xb9960082,0x39453203,0x28cf111a,0x63a60051}},	//   _الطب, _gols_, _स्पि, emkn,
   {{0x61e44254,0xdb1c00b8,0x9f4301ba,0x290c007a}},	//   _avil, _ztrá, rujú_, _ibda_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc6960332,0x61e41942,0x926b18cd,0xd707002d}},	//   _اشاع, _cvil, урна_, _ынце_,
   {{0x92d90083,0xd258010b,0x60230355,0x61e4004b}},	//   ালে_, сцю_, jímá, _dvil,
   {{0xf48400bf,0x290c028b,0x00000000,0x00000000}},	//   _باشی, _mbda_, --, --,
   {{0xe7f0035d,0x28cf23e3,0x3d0622d4,0x21213dd6}},	//   _घटना_, _स्नि, स्से_, _wahh_,
   {{0x7bc72acc,0x93bc00af,0x61e40409,0x00000000}},	// [3b30] _stju, zvăl, _gvil, --,
   {{0x6ca708ce,0x00000000,0x00000000,0x00000000}},	//   бреж, --, --, --,
   {{0xdb1c3255,0xd2510357,0x39454255,0x9f5800d5}},	//   _strá, _رنگ_, _rols_, strá_,
   {{0x39453201,0x33fb0070,0x6bd40079,0x00000000}},	//   _sols_, רהאנ, ستمر, --,
   {{0x39454256,0xd9450de2,0x6ab800ac,0xda07002d}},	//   _pols_, жели, _šafá, счеп,
   {{0x680a013b,0x00000000,0x00000000,0x00000000}},	//   _səda, --, --, --,
   {{0x39452c5e,0xf9900125,0xddd6004e,0x29070009}},	//   _vols_, ربه_, czył, rfna_,
   {{0x6d474257,0x290c0484,0x9b582a24,0x58940037}},	//   _hoja, _ebda_, _лист_, أجهز,
   {{0x6722046a,0x7ae94258,0x85790370,0x6d4716bf}},	//   _daoj, _idet, исот_, _koja,
   {{0x6b8b4259,0xe5690665,0xf1bf006c,0x6d47021e}},	//   logg, риод_, tván_, _joja,
   {{0x61e4425a,0x6d47425b,0x03a60374,0x998406ee}},	//   _svil, _moja, жино, _علمو,
   {{0x6d47425c,0x6722006d,0x6b8b053e,0x7ae9007e}},	//   _loja, _gaoj, nogg, _jdet,
   {{0x84e5425d,0x05740919,0x00000000,0x00000000}},	//   _долж, _کاند, --, --,
   {{0x412a08a6,0x28cf25d8,0x6d47425e,0x85a703fa}},	//   шого_, _स्मि, _noja, _ујед,
   {{0x06ae0033,0x7523002f,0x404714d0,0x00000000}},	//   ছুদি, _ianz, опро_, --,
   {{0x7ae9070b,0x75230010,0x61e40bf3,0xd336002d}},	//   _ndet, _hanz, _tvil, _фэкы,
   {{0x7523425f,0x6d4705e2,0x92e90ad9,0x80cb0026}},	// [3b40] _kanz, _boja, _طريق_, _त्वे,
   {{0x3d14004e,0x90c31bdc,0x752301a3,0xb17b01ff}},	//   ड़ें_, _обье, _janz, lsån,
   {{0x6d474260,0x3a2d00bf,0x69c901a8,0xf1bf00d5}},	//   _doja, _arep_, _atee, hvál_,
   {{0x752309ab,0xeb970086,0x6b8b03bc,0xddd60035}},	//   _lanz, оих_, gogg, rzył,
   {{0xada602ee,0x6a160bdf,0x3a2d0009,0xddd60067}},	//   _мамл, تبار, _crep_, szył,
   {{0xe7ea0202,0x6d472dd1,0xe6d2074f,0xed5a03fa}},	//   афик_, _goja, सर्ज, _тог_,
   {{0xd7f0004f,0xfc0310d7,0x6b8b4261,0x69c90119}},	//   ركة_, _опро, bogg, _etee,
   {{0x75234262,0xdb1c4263,0x98be00ec,0x00000000}},	//   _aanz, _stræ, _dotā_, --,
   {{0x75234264,0x3a2d4265,0xd04e00a8,0xa91c0168}},	//   _banz, _grep_, rabə, _skľu,
   {{0x70b902cb,0x752302fb,0x98a60192,0x94aa1180}},	//   _आलेल, _canz, _дизе, итна_,
   {{0x75234266,0x00000000,0x00000000,0x00000000}},	//   _danz, --, --, --,
   {{0x80dd0033,0xd04e013b,0x7c2e023a,0x00000000}},	//   _বাধ্, qabə, _mrbr, --,
   {{0xa2bc004e,0xe57a002d,0x00000000,0x00000000}},	//   _एलर्, _кзд_, --, --,
   {{0x752302c9,0xd5af2286,0x3d140461,0x1a9b016b}},	//   _ganz, _іс_, ड़ों_, ייכע,
   {{0x20991397,0x4f6b0279,0xab620225,0xa91c07c0}},	//   сквы_, ашам_, şüyo, _ukľu,
   {{0x75234267,0x80cb0a44,0x999201ba,0x1fa44268}},	//   _zanz, _त्रे, ždňa_, друг,
   {{0x7c2e4269,0x7523010a,0x3eaf02c9,0x5d550be8}},	// [3b50] _arbr, _yanz, ägt_, пкат,
   {{0xdd9102e7,0x80f5021f,0x442e426a,0x657a29c2}},	//   روا_, _эпох, _krf_, nnth,
   {{0x5b1511cd,0x6d470bc9,0x69c93e8f,0x657a0107}},	//   змет, _voja, _stee, inth,
   {{0x501a01f3,0x442e0282,0x795d0118,0x3a2d426b}},	//   _פורו, _mrf_, _mèwe, _prep_,
   {{0x7f3a011d,0x6b8b1c9b,0x7c2e033b,0x442e1bf8}},	//   _הערו, rogg, _erbr, _lrf_,
   {{0x6d5e426c,0xf77102fd,0x442e034e,0x6b8b1bf6}},	//   chpa, کات_, _orf_, sogg,
   {{0x6b8b0382,0x00000000,0x00000000,0x00000000}},	//   pogg, --, --, --,
   {{0x7523426d,0x657a426e,0x3a2d00f8,0x7ae9021d}},	//   _sanz, enth, _trep_, _udet,
   {{0x28cf0f19,0x29d50220,0x442e426f,0xddd60035}},	//   _स्थि, _رياس, _arf_, czyń,
   {{0xf77013cf,0x442e4270,0x00000000,0x00000000}},	//   _یان_, _brf_, --, --,
   {{0x75234271,0xb97a02b5,0xccf202b5,0x00000000}},	//   _vanz, _פרעז, עכט_, --,
   {{0x889a0122,0x28cf0864,0x75234272,0x6376008b}},	//   _הבעי, _स्ति, _wanz, kšne,
   {{0x75234273,0xd252006c,0x442e4274,0x66ba00a5}},	//   _tanz, رنس_, _erf_, _המנה,
   {{0x442e0139,0x7523002f,0x00000000,0x00000000}},	//   _frf_, _uanz, --, --,
   {{0x2f5602c4,0x8fa64275,0x00000000,0x00000000}},	//   птас, заве, --, --,
   {{0x9f580031,0x00000000,0x00000000,0x00000000}},	//   murë_, --, --, --,
   {{0x2ee0004f,0x63a44276,0x6e2f021d,0x0e66019e}},	// [3b60] raif_, _ihin, _crcb, чкан,
   {{0x28ac0cf1,0xceb400a8,0x61e6079a,0xc00600af}},	//   टेडि, ddət_, mskl, _епок,
   {{0xa3de0b7a,0x63a44277,0xbebb0051,0x61e60523}},	//   दीप_, _khin, _kaël, lskl,
   {{0xeb9a0086,0x6d5e4278,0x6e49008e,0x25600359}},	//   щие_, shpa, ðsbó, _gòlf_,
   {{0x63a44279,0x61e6427a,0x60de012f,0xcb070413}},	//   _mhin, nskl, _kepm, سيون_,
   {{0xdb1c315b,0xe8940de9,0xddd60067,0x9f580055}},	//   _strä, маль, rzyń, kurë_,
   {{0x55f80b52,0x6da3058f,0xada30aec,0xdca60923}},	//   _অনেক_, _чира, _чарл, _хави,
   {{0x9634420c,0x63a400cc,0x9f580055,0x657a0312}},	//   дниц, _nhin, durë_, wnth,
   {{0xbb3b0122,0x80dd0083,0x442e06e8,0x7e64427b}},	//   _פעמי, _বাস্, _srf_, nzip,
   {{0x443e03d0,0xf48620cc,0x63a4427c,0x442e427d}},	//   txt_, зумн, _ahin, _prf_,
   {{0x63a4427e,0xb4bc1db9,0x657a427f,0x6d5c4280}},	//   _bhin, _अली_, rnth, _mlra,
   {{0x63a44281,0x7ae20054,0x61e6095a,0x00000000}},	//   _chin, naot, fskl, --,
   {{0x63a44282,0xb7e00567,0x442e01ed,0x61e64283}},	//   _dhin, _गौतम_, _wrf_, gskl,
   {{0x442e0279,0x6d0b00b4,0x7ae24284,0x6d4a008d}},	//   _trf_, _सॉंग_, haot, öfal,
   {{0xd5a500d1,0x7ae24285,0x403429fd,0x3171003c}},	//   _تلوی, kaot, нерс, rizz_,
   {{0x63a44286,0x6d5c4287,0xa2de0099,0x00000000}},	//   _ghin, _alra, परण्, --,
   {{0x7ae2043d,0xceb400a8,0x00000000,0x00000000}},	// [3b70] daot, ddəs_, --, --,
   {{0x6d5c009e,0xa25b00f6,0x6ca70382,0x00000000}},	//   _clra, ncôm, преж, --,
   {{0x8c190b82,0xdb1c4288,0x00000000,0x00000000}},	//   تيار_, _kurè, --, --,
   {{0x63a40031,0x6d5c00fd,0x00000000,0x00000000}},	//   _xhin, _elra, --, --,
   {{0x539c00a5,0x81df0033,0x6f0d1dfb,0x1eab414b}},	//   זיאו, দূর_, mfac, _دادي_,
   {{0x6f0d4289,0x34db0f06,0x26dd0118,0xceb2016b}},	//   lfac, _मजेद, _sewo_, _שיך_,
   {{0x29c2064b,0x28de0084,0xb8e504cc,0x6e2d428a}},	//   _eða_, _नजरि, _एल_, lvab,
   {{0x6f0d02bf,0x80380122,0x6a1503c6,0x78ba0a8a}},	//   nfac, לנוע_, _омбу, _egtv,
   {{0x629a0035,0x09d70033,0x6abb007b,0x6f0d02b1}},	//   ętok, _সমকা, _iguf, ifac,
   {{0xe57600d8,0x63a4428b,0x9f580031,0xdb1c428c}},	//   дзь_, _shin, turë_, _aurè,
   {{0xceb40095,0x63a4428d,0x00000000,0x00000000}},	//   ndər_, _phin, --, --,
   {{0x68e3428e,0xe29a40bf,0x00000000,0x00000000}},	//   land, жам_, --, --,
   {{0xa3b90026,0x27e00a78,0xdb1c00e0,0x68e308c7}},	//   _अंक_, ćine_, _durè, oand,
   {{0x10a602f3,0x61e6428f,0xf65200a5,0x0ef60026}},	//   дигн, rskl, _בצד_, इल्स_,
   {{0x63a40052,0x66094290,0x6f0d4291,0x68e3133c}},	//   _thin, ltek, ffac, iand,
   {{0xe8200387,0x0cd631d7,0x7e7b2209,0x63a44292}},	//   _मनसा_, धर्म, _župa, _uhin,
   {{0x66094293,0x80dd0083,0xdd920642,0xe3a70416}},	// [3b80] ntek, _বার্, نور_, _تشوی,
   {{0x68e34294,0x66094295,0x6abb4296,0xdc3c0207}},	//   jand, itek, _aguf, nšća,
   {{0x68e34297,0x6f0d01a2,0x7e644298,0x7ae200be}},	//   dand, bfac, szip, taot,
   {{0x25ee22d4,0xaefb009e,0x67294299,0xdb1c03d0}},	//   _इटली_, _clùd, jdej, _kuré,
   {{0x68e3429a,0x6ffe0139,0xfa3629fe,0xdb1c216e}},	//   fand, _făcî, براد, _juré,
   {{0x68e3429b,0x6da6429c,0x7ae2055c,0xdb0700d5}},	//   gand, _цига, saot, _bujó,
   {{0xa3b9170c,0x6609429d,0x2bf5010b,0x9f5800a2}},	//   _अंग_, etek, _пятр, euré_,
   {{0xdca30947,0x1f5b0070,0x66090f0a,0x61e9429e}},	//   _раси, ַדיא, ftek, šeli,
   {{0x68e3429f,0xf8cf0d00,0x6609006c,0x28cf0d00}},	//   band, _स्वय, gtek, _स्वि,
   {{0x7afd42a0,0xb4e8012f,0x7ae001ff,0x7bdc0118}},	//   _östr, यणे_, _hemt, _kwru,
   {{0x291c42a1,0x69c042a2,0xdb1c42a3,0x6f0d016e}},	//   meva_, _hume, _auré, yfac,
   {{0x69c00895,0x291c42a4,0x7ae0008c,0x2b460176}},	//   _kume, leva_, _jemt, njoc_,
   {{0x69c042a5,0x394c00ea,0xdb1c00f6,0x00000000}},	//   _jume, _kods_, _curé, --,
   {{0x291c42a6,0x69c042a7,0xdb1c02e1,0xceb401c2}},	//   neva_, _mume, _duré, ydər_,
   {{0x69c042a8,0x394c42a9,0x00000000,0x00000000}},	//   _lume, _mods_, --, --,
   {{0x7ae042aa,0x69c042ab,0x291c42ac,0x394c008c}},	//   _nemt, _oume, heva_, _lods_,
   {{0x68e342ad,0x6f0d2331,0xf1a710e3,0xdb0042ae}},	// [3b90] yand, rfac, _орон, _limó,
   {{0x291c0a23,0x4fc70c98,0x61fd42af,0x77a5002a}},	//   jeva_, _осма, musl, móxe,
   {{0x291c42b0,0x660906a2,0x6e2d1ea6,0x77a5002a}},	//   deva_, ztek, svab, lóxe,
   {{0x68e32f38,0x69c042b1,0x395e0310,0xe7f400a1}},	//   wand, _bume, _alts_, ींना_,
   {{0x68e342b2,0x69c042b3,0x7ae03e81,0x395e0260}},	//   tand, _cume, _demt, _blts_,
   {{0x69c042b4,0x3329027a,0xb4e8018d,0x291c00ab}},	//   _dume, _laax_, यणो_, geva_,
   {{0x68e303c1,0x7ae00307,0x69c042b5,0xdb00002a}},	//   rand, _femt, _eume, _cimó,
   {{0x69c042b6,0x9f5837d6,0x491b01c0,0x395e0553}},	//   _fume, turé_, _यसको_, _elts_,
   {{0x69c042b7,0x67291665,0xe6161ac5,0x394c0b3e}},	//   _gume, rdej, еды_, _fods_,
   {{0x660942b8,0x291c42b9,0x7bc80248,0x61fd42ba}},	//   rtek, ceva_, _éduc, dusl,
   {{0x660942bb,0x9f581f96,0xdb1c00a2,0x2b5f063c}},	//   stek, suré_, _suré, _kluc_,
   {{0x68e142bc,0x660942bd,0xdb1c42be,0xd6d90067}},	//   _held, ptek, _strú, ykły_,
   {{0x68e142bf,0x7e7b42c0,0x61fd00ab,0x69c00b3f}},	//   _keld, _župn, gusl, _xume,
   {{0x68e1022f,0x2b5f0392,0x00000000,0x00000000}},	//   _jeld, _lluc_, --, --,
   {{0x68e142c1,0x039642c2,0x00000000,0x00000000}},	//   _meld, _прия, --, --,
   {{0x61fd2f80,0x2d83001c,0x00000000,0x00000000}},	//   busl, _ajje_, --, --,
   {{0xc7b20100,0x291c0095,0x77a50042,0xe1ff02d7}},	// [3ba0] רבן_, yeva_, cóxe, lzón_,
   {{0x68e142c3,0x7ae042c4,0xdb1c0139,0x8d7642c5}},	//   _neld, _semt, _curî, راءا,
   {{0x69c042c6,0xdee61738,0x291c02fb,0x7c3a11d7}},	//   _sume, _пони, veva_, _štrb,
   {{0x68e1008c,0xe1ff0042,0x2d830103,0xbebb0345}},	//   _aeld, izón_, _ejje_, _naëh,
   {{0x291c3e9c,0x68e142c7,0xdb000d2e,0x82d70070}},	//   teva_, _beld, _simó, גונג_,
   {{0x680a0095,0x68e142c8,0x7bc5006d,0xdb000176}},	//   _hədi, _celd, bqhu, _cimò,
   {{0xdca30368,0x291c42c9,0x7bce01ff,0x7ae042ca}},	//   _бари, reva_, _utbu, _temt,
   {{0x69c042cb,0x6d4e42cc,0x291c3c7e,0x68e100ab}},	//   _tume, _hoba, seva_, _eeld,
   {{0x68e142cd,0x291c42ce,0xe7e00387,0x00000000}},	//   _feld, peva_, _गौरा_, --,
   {{0x68e142cf,0x6d4e42d0,0xdb002dd3,0x61fd00be}},	//   _geld, _joba, _timó, vusl,
   {{0x6d4e42d1,0xf1a7045c,0x23600120,0x249801b4}},	//   _moba, _गठबन, _blij_, ærm_,
   {{0x6d4e42d2,0x68e142d3,0x5fb40243,0x61fd1c55}},	//   _loba, _zeld, ंगफल, tusl,
   {{0x3f800035,0x28ac0bdd,0x00000000,0x00000000}},	//   dniu_, टेरि, --, --,
   {{0x6d4e42d4,0x7d1e42d5,0x3f800035,0x77a501ef}},	//   _noba, jeps, eniu_, róxe,
   {{0x7d1e42d6,0x61fd42d7,0x680a00a8,0xdfd10079}},	//   deps, susl, _bədi, شيء_,
   {{0x5f940e0a,0x2d8742d8,0x6d4e022e,0x61fd1296}},	//   гист, čnem_, _aoba, pusl,
   {{0x2b9c0355,0xc0cb00af,0x00000000,0x00000000}},	// [3bb0] mích_, _нуне_, --, --,
   {{0x61ed0763,0x2b9c0355,0x752a0069,0x31350d15}},	//   _ival, lích_, _jafz, _реор,
   {{0x61ed1635,0x6d4e0121,0xdea1042c,0x614403e6}},	//   _hval, _doba, _چیزی, _сеќа,
   {{0x68e142d9,0x2b9c000c,0x7c3a00cd,0x00000000}},	//   _seld, ních_, _štrc, --,
   {{0xaa582661,0x68e142da,0x05b20035,0xe1ff00de}},	//   ницу_, _peld, ीदाब, nuó_,
   {{0x6d4e42db,0x41d90026,0x61ed0176,0x00000000}},	//   _goba, बीएस, _mval, --,
   {{0x68e142dc,0x013800a5,0x7c840268,0x00000000}},	//   _veld, תרות_, _буте, --,
   {{0x6d4e006a,0x2b9c00b8,0x68e142dd,0x3dc20027}},	//   _zoba, jích_, _weld, _yukw_,
   {{0x27e001cc,0x68e142de,0xdcea0139,0x00000000}},	//   ćina_, _teld, _înău, --,
   {{0xdb1c10db,0xe1ff0138,0x38cb0368,0x7f4f00f6}},	//   _strø, duó_, _хуан_, _locq,
   {{0x61ed19a6,0x7e7b0124,0x00000000,0x00000000}},	//   _aval, _župl, --, --,
   {{0xe1ff215f,0x36d50a7c,0x2cb00095,0x00000000}},	//   rzón_, _родр, ündə_, --,
   {{0x2d87016f,0x636601ef,0x61ed0c6e,0x98a50260}},	//   čnej_, _lóng, _cval, _malč_,
   {{0x61ed008d,0x00000000,0x00000000,0x00000000}},	//   _dval, --, --, --,
   {{0x6d4e42df,0xdee63de5,0xc0e30665,0x2d9342e0}},	//   _roba, кови, роск, doxe_,
   {{0x2b9c031b,0x6d4e42e1,0x3d1401c0,0x93fa0d85}},	//   cích_, _soba, न्ने_, _חלקי,
   {{0x6d4e004f,0x672b01f4,0xaec30ded,0x3ce30c6f}},	// [3bc0] _poba, _magj, рбул, _bejv_,
   {{0x672b01f4,0x3f80010b,0xe6120070,0x4d6342e2}},	//   _lagj, sniu_, יִע_, акув,
   {{0x6faa03fa,0x61ed0254,0x3ce32e37,0x2721007c}},	//   _овог_, _zval, _dejv_, _मसूर_,
   {{0x7d1e42e3,0x442708ee,0x2b3a002d,0x00000000}},	//   seps, _msn_, ьязэ_, --,
   {{0xa96a0de2,0x2b9c0187,0x8b6613cf,0x6d4e42e4}},	//   мида_, níci_, _یارم, _toba,
   {{0x44271ab1,0x2b9c00b8,0x38c80df3,0x672b0051}},	//   _osn_, zích_, راتی_, _aagj,
   {{0x8c433d1a,0xebe3248c,0x317b00a5,0x63660176}},	//   _кере, _восп, ורסמ, _góng,
   {{0x59dd0953,0x6f0442e5,0x98a5055c,0x00000000}},	//   _नौकर, ngic, _cnlđ_, --,
   {{0xdb1c42e6,0x692600c9,0x672b01e4,0x8f9b076b}},	//   _jurí, _имаа, _dagj, ויקי,
   {{0x4427245b,0x6b820e5e,0x73d8141d,0x2b9c00ac}},	//   _bsn_, lnog, ндор_, díci_,
   {{0x442742e7,0x3d14022e,0x2b9c031d,0x00000000}},	//   _csn_, न्ये_, tích_, --,
   {{0x18770122,0xe1ff0453,0x6e2401d5,0x442742e8}},	//   _בעבר_, tuó_, kwib, _dsn_,
   {{0x2b9c0037,0x2287002d,0x201a00ab,0xddd60035}},	//   rích_, тунг, _appi_, rzyś,
   {{0x6600005d,0x3cfe42e9,0x28c60066,0x6b8242ea}},	//   mumk, _लागे_, रुचि, hnog,
   {{0x4fc40923,0xa18401c8,0xdb1c07a6,0x3ce30009}},	//   иста, рыял, _aurí, _rejv_,
   {{0x2d980009,0x63660300,0x6f04027a,0xdb1c00ee}},	//   _akre_, _cónd, ggic, _burí,
   {{0x63660033,0x61ed00cb,0x6b820254,0xdbca00ab}},	// [3bd0] _dónd, _uval, dnog, _mõõt,
   {{0x80dd0083,0xdb1c2b01,0x63660453,0x98a5021e}},	//   _বাক্, _durí, _póng, _salč_,
   {{0x6b820297,0x7f4f00f6,0x98a5021e,0x9bf500af}},	//   fnog, _tocq, _palč_, узеч,
   {{0x4ea701c8,0xfe700332,0x66002971,0x6b820036}},	//   _арга, حدہ_, kumk, gnog,
   {{0xad9b0042,0x98a5021e,0x00000000,0x00000000}},	//   _opúx, _valč_, --, --,
   {{0x2ee90a81,0x776201dd,0xdb1c00af,0x00000000}},	//   laaf_, _alox, _curâ, --,
   {{0x6b820b67,0x672b0055,0x87b900af,0x00000000}},	//   bnog, _pagj, нуит_, --,
   {{0x070900bc,0x2ee90051,0x6c3100b5,0x98be007e}},	//   ريخي_, naaf_, _پہچا, _kotě_,
   {{0x660042eb,0xdb1c01dd,0x25600036,0xda160594}},	//   gumk, _xurí, _sòla_, _مسلک,
   {{0x776242ec,0x2ee903bc,0x2560009e,0x4e36016b}},	//   _elox, haaf_, _pòla_, אָטן_,
   {{0x672b006c,0x776201ef,0xe5760043,0x00000000}},	//   _tagj, _flox, узэ_, --,
   {{0x6720025c,0x28cf0387,0xe61100f8,0x63760207}},	//   cemj, सुरि, _هشت_, ršno,
   {{0x06b10033,0x36340647,0xc8c7012f,0x00000000}},	//   _ট্রি, _پرنس, _ललाट, --,
   {{0x6e2003e6,0xa5092123,0x44271413,0x6b820506}},	//   _âmbi, _чека_, _tsn_, znog,
   {{0xb4df0ca1,0x442700fe,0x636601ef,0xd8380097}},	//   तरी_, _usn_, _pónd, _tyče_,
   {{0x80d40d00,0x26cd42ed,0x6e3b00cd,0x2ee90d35}},	//   _ब्रे, nceo_, _šuba, gaaf_,
   {{0x224608a1,0x6b82011c,0x8fa32b92,0x0d860f08}},	// [3be0] _çok_, vnog, сате, глан,
   {{0x6e242985,0x63660176,0x8c4642ee,0x3dcd0033}},	//   rwib, _dóne, лезе, _লিখল,
   {{0x201a0093,0x4425001e,0x6b8242ef,0xc3270033}},	//   _uppi_, nwl_, tnog, যারি_,
   {{0xdb1c42f0,0xe5130240,0x7c2a0009,0xb4df1604}},	//   _turí, त्ति_, _đorč, तरु_,
   {{0x3202016f,0xf1bf05fa,0x00000000,0x00000000}},	//   nuky_, lvár_, --, --,
   {{0x6b823e44,0x7521006c,0x80a800b8,0x00000000}},	//   snog, jelz, _गराइ, --,
   {{0xd7fa002d,0x8d6342f1,0x6b820207,0x27e000f4}},	//   хул_, _увре, pnog, ćino_,
   {{0x57a60409,0x998d002d,0x660000ea,0x6d5e42f2}},	//   ышла, _preţ_, tumk, lkpa,
   {{0xfaa300d8,0xe4e61645,0x672033b8,0x9f5802d7}},	//   _гато, лінн, remj, ltró_,
   {{0x75211167,0x80d40b35,0x672042f3,0x7c220067}},	//   gelz, _ब्ले, semj, łoru,
   {{0x0d970122,0x9f580831,0xf36500af,0x00000000}},	//   רכים_, ntró_, иӂин, --,
   {{0x3d1400db,0x78a80a78,0x43950fb4,0xdb1c0176}},	//   न्ते_, _izdv, рамс, _jurà,
   {{0xa77b02b5,0x752142f4,0xc7b80023,0x9f580176}},	//   _אראפ, belz, _vpđd_, durà_,
   {{0x047500b5,0x4425016e,0x22590096,0xd8383c56}},	//   ائیگ, bwl_, rysk_, _krč_,
   {{0xe3b00357,0x6568066a,0x657a42f5,0xdb1c42f6}},	//   تری_, mhdh, mith, _strý,
   {{0x657a42f7,0x6d5e0d35,0x9f580176,0x225900d5}},	//   lith, ekpa, gurà_, pysk_,
   {{0x63ad42f8,0x645a230a,0xccfb0202,0x2ee942f9}},	// [3bf0] _ihan, lyti, еће_, raaf_,
   {{0x657a004f,0x81e80083,0x637602c6,0x490907b5}},	//   nith, মূহ_, jšnj, _साधो_,
   {{0x63ad42fa,0x2ca70307,0x63760009,0x645a1bda}},	//   _khan, ånd_, dšnj, nyti,
   {{0xbe050332,0x9f350210,0x657a0037,0x799a129d}},	//   _پوسٹ, _темі, hith, _aktw,
   {{0x63ad42fb,0x200342fc,0xdb1c01ef,0x61ef42fd}},	//   _mhan, luji_, _atró, nscl,
   {{0x657a01d2,0x63ad01a2,0x645a1482,0xdb1c01f7}},	//   jith, _lhan, kyti, _eurà,
   {{0x63ad42fe,0x315802b8,0x5ba70272,0x657a42ff}},	//   _ohan, ריון_, _браз, dith,
   {{0x63ad0028,0x7bd50291,0x61fd0124,0x645a4300}},	//   _nhan, _itzu, krsl, dyti,
   {{0x7bc74301,0x7aeb4302,0x0565002d,0x26cd0036}},	//   _huju, magt, ивин, rceo_,
   {{0x0555188d,0x7bc74303,0xb4df0e04,0x63ad0232}},	//   ртия, _kuju, तरे_, _ahan,
   {{0x64a53a11,0x7bc709df,0x63ad4304,0xd838011c}},	//   рана, _juju, _bhan, _grč_,
   {{0x63ad4305,0x7bc74306,0x7aeb4307,0x657a4308}},	//   _chan, _muju, nagt, aith,
   {{0x63ad4309,0x55e500af,0x7bc7430a,0xdb1c00d5}},	//   _dhan, _толб, _luju, _jurá,
   {{0x2907430b,0x657a00ce,0xe802045c,0x63ad430c}},	//   ngna_, cith, रूवा_, _ehan,
   {{0x6b9b09d6,0x7bc703da,0x7aeb0008,0xafe6430d}},	//   _okug, _nuju, kagt, робл,
   {{0x6b890496,0x63ad430e,0x7c3a1f45,0x7aeb430f}},	//   _njeg, _ghan, _štro, jagt,

   {{0x539b0122,0x7aeb0173,0x7bd501ed,0xf1bf00fd}},	// [3c00] _ביקו, dagt, _atzu, rvár_,
   {{0x7bc74310,0x20030355,0x6b890118,0x6b9b3ab1}},	//   _buju, buji_, _ajeg, _akug,
   {{0x0c264311,0x80dd0083,0x7bc7021d,0x6d5e4312}},	//   рмен, _বাচ্, _cuju, rkpa,
   {{0xdb1c0fb5,0x657a034d,0x6d5e00be,0x61e40027}},	//   _burá, zith, skpa, _kwil,
   {{0x9f584313,0x657a0987,0x7769009e,0x6b8901f4}},	//   stró_, yith, dhex, _djeg,
   {{0xdb1c2dd3,0x61e4000e,0xb4df021a,0x28f700c3}},	//   _durá, _mwil, तरो_, аешь_,
   {{0x63761a2e,0xdb000132,0x68ea4314,0x478a24c1}},	//   ršnj, _simõ, rafd, ксим_,
   {{0x7aeb05f5,0x2ca74315,0x657a4316,0xd8384317}},	//   cagt, ünde_, with, _vrč_,
   {{0x63ad0297,0x657a0079,0xb90e0019,0x765b011e}},	//   _rhan, tith, _xalộ_, gyuy,
   {{0x7bc003be,0xa90600d1,0x61fd0009,0x63bf00a8}},	//   _himu, _خبرن, vrsl, _siqn,
   {{0x657a0082,0x4438043f,0x7bc04318,0x28cf1119}},	//   rith, ír_, _kimu, _स्टि,
   {{0x68e84319,0x645a431a,0x657a0037,0xf743431b}},	//   _hedd, ryti, sith, _мехо,
   {{0x645a02c2,0xa5f803fa,0x27e9011c,0x61fd2193}},	//   syti, _селу_, ćane_, ursl,
   {{0x7e6d008b,0x61e400e0,0x80dd0033,0x63ad3c8f}},	//   vzap, _dwil, _বাঙ্, _whan,
   {{0x68e8431c,0x63ad431d,0x6aa0431e,0xdb1e00b8}},	//   _medd, _than, _lymf, _švýc,
   {{0x7bc7431f,0x20034320,0x7bc00010,0x201101d7}},	//   _ruju, ruji_, _nimu, rtzi_,
   {{0x7bc7323d,0x7a1a0029,0x68e8001e,0x61e400e9}},	// [3c10] _suju, nātā, _oedd, _gwil,
   {{0x7bc70a4e,0x68e801a8,0x7aeb03bc,0x6b9b4321}},	//   _puju, _nedd, wagt, _skug,
   {{0x6366006c,0x6b89025c,0x7bc0018c,0x7aeb095a}},	//   _hóna, _pjeg, _bimu, tagt,
   {{0x41c400d1,0x290c0051,0x9f5812a2,0x7bc00065}},	//   _دقیق, _acda_, strò_, _cimu,
   {{0x19591482,0x7bc04322,0x7bc74323,0x7aeb4324}},	//   лады_, _dimu, _wuju, ragt,
   {{0x7bc70614,0x98ac008f,0x6366213c,0x7a1a00ea}},	//   _tuju, _aldı_, _móna, dātā,
   {{0x680a01c2,0x68e8001e,0x7aeb27f9,0x6b5a0176}},	//   _sədr, _dedd, pagt, _aïgu,
   {{0xbb850082,0x9b9408bb,0x6b9b01d5,0xab5d0024}},	//   _الري, _дисц, _ukug, _biże,
   {{0x68e8001e,0x16390037,0x6aa0008c,0xa76202fb}},	//   _fedd, اسبة_, _gymf, якъд,
   {{0x68e84325,0x6d5502d0,0x3a2d4063,0xd7fb4326}},	//   _gedd, _joza, _isep_, _ауд_,
   {{0x61e42fa1,0xd05c00a8,0x7ae91c37,0x7bc0251e}},	//   _swil, barə, _keet, _yimu,
   {{0x69c14327,0x6d41008a,0xd05c0095,0x7ae94328}},	//   _hile, _ólaf, carə, _jeet,
   {{0x69c14329,0xe1ff432a,0x6366004f,0x7ae9432b}},	//   _kile, gró_, _cóna, _meet,
   {{0xd00a01f2,0x863602b5,0x6d550029,0x69c1432c}},	//   леге_, _לאנג_, _noza, _jile,
   {{0x05740a72,0x201e432d,0xa067432e,0xab5d009f}},	//   _باند, ïti_, бара_, _miżb,
   {{0x69c1432f,0xe1ff00de,0xe5130e62,0x6376329e}},	//   _lile, bró_, त्रि_, kšni,
   {{0xee3a1a0e,0x6b99099e,0x69c10094,0x7bc04330}},	// [3c20] ына_, dowg, _oile, _rimu,
   {{0xd05c0095,0x69c13ec8,0xe8180066,0x6d554331}},	//   zarə, _nile, _दहला_, _coza,
   {{0xd5c801a5,0x116804e8,0xd05c0095,0x3a2d027c}},	//   _nền_, _ملکی_, yarə, _asep_,
   {{0x387a0669,0x69c14332,0x68e84333,0x69c90a17}},	//   _üzrə_, _aile, _sedd, _buee,
   {{0x6d5501ef,0x7bc04334,0x00000000,0x00000000}},	//   _foza, _vimu, --, --,
   {{0xdd921144,0x69c14335,0xe6e002e4,0x6d5535d4}},	//   _روز_, _cile, नर्ज, _goza,
   {{0x7bc0124f,0x7ae90b88,0x3a2d010d,0x68e84336}},	//   _timu, _feet, _esep_, _vedd,
   {{0x2d9a4337,0x69c1004a,0x7ae9030d,0x68e84338}},	//   lope_, _eile, _geet, _wedd,
   {{0x69c14339,0xd5ba081b,0x6d55073a,0x00000000}},	//   _file, лсо_, _yoza, --,
   {{0x69c1433a,0xd05c00a8,0x8e570070,0xdb1c027d}},	//   _gile, sarə, צייג_, _burç,
   {{0xe60f02fd,0x680a00a8,0xb8960079,0x7ae9018e}},	//   وشی_, _tədq, _الضع, _yeet,
   {{0xf367059b,0x69c109be,0xe1ff433b,0x2d9a433c}},	//   стон, _zile, tró_, hope_,
   {{0xc7970332,0x3636004f,0x86c30037,0x2d9a433d}},	//   _اپنا_, _دراس, _عيون, kope_,
   {{0xe1ff433e,0x69c1081d,0x7c2e0298,0x00000000}},	//   rró_, _xile, _osbr, --,
   {{0x67d10228,0xe3c900cc,0x00000000,0x00000000}},	//   _kāja, _hằn_, --, --,
   {{0x442e433f,0x9f050833,0x443c0553,0x6366003e}},	//   _isf_, تورو, _irv_, _tóna,
   {{0x6d552bba,0x67d10080,0xa2a004cc,0x443c003d}},	// [3c30] _poza, _māja, _गुप्, _hrv_,
   {{0x7ae9360a,0x443c4340,0x60c50159,0x2d9a08c7}},	//   _seet, _krv_, _ughm, gope_,
   {{0x6d550289,0x69c14341,0x7ae94342,0x443c0009}},	//   _voza, _rile, _peet, _jrv_,
   {{0x443c021d,0xcf2700f8,0x9ce90831,0x6d551388}},	//   _mrv_, _اردي, খলেন_, _woza,
   {{0x69c14343,0x7c2e1537,0x7ae94344,0xe1ff0035}},	//   _pile, _esbr, _veet, rzów_,
   {{0xe1ff0035,0x7ae94345,0x2d9a023c,0x98be0107}},	//   szów_, _weet, cope_, _entč_,
   {{0x69c14346,0xa2a004eb,0x02fb0d4e,0x7ae94347}},	//   _vile, _गुन्, ्लाह_, _teet,
   {{0xf77114ac,0x3f8902c7,0x23cf1ede,0x09d80033}},	//   بات_, nnau_, _संबद, _সিরা,
   {{0x14da134b,0x69c1154a,0x9f604348,0x442e0526}},	//   _म्हण, _tile, érés_, _asf_,
   {{0xe5794349,0x442e0033,0x2bb91f29,0x69c1434a}},	//   рзо_, _bsf_, ेदवा, _uile,
   {{0xa34a0011,0x23690395,0x98a50409,0x00000000}},	//   азна_, _blaj_, _balą_, --,
   {{0x2bd00299,0x443c023a,0x7c3a07c0,0x80a30099}},	//   _तूफा, _drv_, _štrk, _गरजे,
   {{0x3dd9006d,0xe796006c,0x443c0176,0x442e434b}},	//   _ntsw_, _بالک, _erv_, _esf_,
   {{0x6f1d02c9,0x3f8900e9,0x443c0093,0xe0460fc5}},	//   _absc, enau_, _frv_, онги,
   {{0x3f8900e9,0x3dd90345,0x2f5614d0,0x443c00fe}},	//   fnau_, _atsw_, отас, _grv_,
   {{0x2bd00026,0x3f8909a2,0x636600ee,0x98a50409}},	//   _तंबा, gnau_, _ióno, _galą_,
   {{0xbea3434c,0x27e00a78,0x2d9a25df,0xee37151c}},	// [3c40] датк, ćini_, tope_, онт_,
   {{0x63061a95,0x00000000,0x00000000,0x00000000}},	//   _اوکل, --, --, --,
   {{0x2d9a434d,0x7ac61517,0x6e3d0282,0x00000000}},	//   rope_, осле, _ersb, --,
   {{0x8cda00dc,0xeb9a434e,0x3e7002e1,0xd1162135}},	//   _प्रो, шие_, _côté_, द्रण_,
   {{0x094a1159,0xee3711aa,0xbddb12c3,0x2d9a006d}},	//   ички_, _дня_, _crèd, pope_,
   {{0xd7fa07e5,0x394504fb,0x00000000,0x00000000}},	//   ауи_, _cnls_, --, --,
   {{0xdca31fd8,0xd90d00d1,0xb227003e,0x984a17c8}},	//   _жари, ایم_, _kvæð, ряла_,
   {{0xeb97434f,0x3b071159,0x7bde00c3,0x8b230214}},	//   _дис_, _месо_, mppu, _одсе,
   {{0x27e90254,0x598603e6,0x00000000,0x00000000}},	//   ćana_, _длаб, --, --,
   {{0xd6e200c8,0x29180014,0x442e1e60,0x02e3000c}},	//   _যাওয, _ùra_, _psf_, पर्न,
   {{0x3f890297,0x23694350,0x320200a0,0x00000000}},	//   ynau_, _plaj_, erky_, --,
   {{0x926b27ac,0x49160808,0x7bde02ee,0x443c023a}},	//   арга_, प्रो_, ippu, _vrv_,
   {{0x81d30083,0x7ae20345,0x00000000,0x00000000}},	//   হীন_, ibot, --, --,
   {{0x442e0183,0x3ce40067,0x386f027b,0xab5d007a}},	//   _tsf_, गरों_, _ömrü_, _miża,
   {{0xd5c80028,0x7528016f,0x291e3fce,0xd24e0416}},	//   _mềm_, medz, _mbta_, نچی_,
   {{0xa8570d85,0xa1150220,0x75284351,0xd5b80228}},	//   חילה_, _کودت, ledz, lmā_,
   {{0x3f894352,0x636600ac,0xd838021e,0x00000000}},	// [3c50] rnau_, _zóno, _syčl_, --,
   {{0x8c670037,0x752800b5,0x5bc30355,0xeca70274}},	//   يطان, nedz, षद्व, ојен,
   {{0x256901ba,0x00000000,0x00000000,0x00000000}},	//   _júla_, --, --, --,
   {{0xa2a04353,0x7ae22a16,0xab5d0024,0x291e099e}},	//   _गुड्, gbot, _biża, _abta_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0d08bf,0xab5d035f,0x6e2d4354,0xae5a011d}},	//   lgac, _diża, mwab, _הכשר,
   {{0x77a5043f,0x6d474355,0xe80204bc,0x7ae20036}},	//   lóxi, _inja, रंगा_, bbot,
   {{0x6f0d4356,0xdb1c4357,0x2d814358,0x656a0044}},	//   ngac, _strö, lihe_, _alfh,
   {{0x6d47042a,0x70a80af6,0x6e2d030d,0x77a5171c}},	//   _knja, _गर्ल, nwab, nóxi,
   {{0x7ac40044,0xa50903fa,0x7c3a0881,0xaefb01da}},	//   _істе, љена_, _štri, _dlùi,
   {{0x044510a9,0x03a64359,0x6e2d290f,0x3a3f0116}},	//   ченн, зино, hwab, _hrup_,
   {{0x6e2d2967,0x6b8b010d,0xb4ab0253,0x25e80099}},	//   kwab, nngg, _खरी_, चीही_,
   {{0xe7c40084,0x6d470103,0x6b8b067f,0xaefb01da}},	//   _लूटप, _onja, ingg, _glùi,
   {{0xe20b0093,0xb227008a,0x2fda012f,0x763a0070}},	//   _stóð_, _svæð, _ptpg_, _לענג,
   {{0x64a2435a,0xa067435b,0x67d100ea,0x6609435c}},	//   _паша, пара_, _mājo, luek,
   {{0x6d47435d,0xdfcf004f,0x59cb00b4,0xf41200a5}},	//   _anja, طيك_, ादार, _נפח_,
   {{0xa3e71fb4,0xdb15435e,0x7ae20044,0x77a50042}},	// [3c60] मीर_, _luzó, vbot, góxi,
   {{0x7afb435f,0x67294360,0x2d810010,0x6b8b0159}},	//   _adut, heej, gihe_, engg,
   {{0xa0a60043,0xdd8f004f,0x62542b6c,0x7ae203c1}},	//   _ханд, دول_, _džoš, tbot,
   {{0x22400fee,0x7f4a1d6c,0xe3c901a5,0x6d470273}},	//   _krik_, _الحق_, _nằm_, _enja,
   {{0x7ae24361,0x20184362,0xf8dd000c,0x98dd000c}},	//   rbot, ltri_, नुभय, नुभए,
   {{0x7ae2002a,0x6d474363,0xdb154364,0x6b8b010d}},	//   sbot, _gnja, _buzó, angg,
   {{0x20184365,0x200a00a8,0xdb0901a6,0x752820e8}},	//   ntri_, nubi_, _fheà, vedz,
   {{0x6a861c89,0x95d80086,0x6e3b0a18,0xdb090284}},	//   _елба, одит_, _šubi, _gheà,
   {{0x3a3f4366,0x7bce4367,0xd5b800ec,0xe6660208}},	//   _grup_, _hubu, tmā_, ятко,
   {{0x7bce4368,0x6b824369,0x200a436a,0x2018436b}},	//   _kubu, liog, kubi_, ktri_,
   {{0x6366008a,0x75280080,0xd5b80029,0x442c0120}},	//   _tónl, redz, rmā_, uwd_,
   {{0x98ac0080,0x7bce2107,0x3a2400d7,0xd5b800ea}},	//   _gadā_, _mubu, _kpmp_, smā_,
   {{0x7bce436c,0x27e00a78,0xd244002d,0x2240023a}},	//   _lubu, ćinu_, нэри, _crik_,
   {{0xdb090037,0x35b30402,0x22400b3e,0x77a501ef}},	//   _mheá, _збір, _drik_, vóxi,
   {{0xb4e80907,0x200a0620,0x443a3b2f,0x7bce436d}},	//   बरी_, gubi_, _ép_, _nubu,
   {{0x26c20187,0x2240436e,0xee3f00b8,0x77a509ca}},	//   žkou_, _frik_, _prý_, tóxi,
   {{0x6f0d436f,0x2240028b,0x20184370,0x7bdc0228}},	// [3c70] rgac, _grik_, atri_, _atru,
   {{0x6f0d01a6,0x77a50300,0x00000000,0x00000000}},	//   sgac, róxi, --, --,
   {{0x69db4371,0x200a027a,0x7bce156b,0x6b8b010d}},	//   _stue, cubi_, _cubu, tngg,
   {{0x23cf052b,0x7bce4372,0xa3cf0066,0xbddb4373}},	//   _संसद, _dubu, _वंस_, _crèc,
   {{0xcf560122,0x3a3f01c2,0xe3c900e2,0xdb09026e}},	//   _חברת_, _qrup_, _rằm_, _cheá,
   {{0x98a5355e,0x6d474374,0x3a2400ee,0xbddb2a1c}},	//   миле, _unja, _dpmp_, _trèb,
   {{0x7bce4375,0xb4ab0c97,0x999f00b5,0x27e9011c}},	//   _gubu, _खरे_, éről_, ćano_,
   {{0xbddb34fc,0xeafb09b9,0x3a3f4376,0x660901a3}},	//   _grèc, _درست_, _trup_, tuek,
   {{0x67294377,0x61fb044d,0xb4e80026,0x200a01b7}},	//   reej, šulj, बरू_, zubi_,
   {{0x7bce4378,0xdce702a7,0x66094379,0x00000000}},	//   _yubu, _oljč, ruek, --,
   {{0x79830283,0xab5d0069,0xe3c900e2,0x00000000}},	//   minw, _jiżo, _tằm_, --,
   {{0x79830818,0x2240437a,0x889a00a5,0x200a018c}},	//   linw, _prik_, _ובעי, vubi_,
   {{0x0caa114e,0xf77018dd,0xd6ab00f3,0xfaf6024b}},	//   _कर्म, _حال_, _ادام_, וצרי_,
   {{0xd5bb0560,0x2018437b,0x200a0159,0x6b82437c}},	//   _усе_, ttri_, tubi_, ziog,
   {{0x7f5a0370,0x8fa6437d,0x853c00c7,0x00000000}},	//   ојат_, даве, klėj, --,
   {{0x7bce437e,0x200a3591,0x79831b3f,0x6b8201ef}},	//   _rubu, rubi_, hinw, xiog,
   {{0x63a4437f,0x1da90084,0x8fa32aac,0x200a018e}},	// [3c80] _ikin, कतंत, тате, subi_,
   {{0x7bce4380,0xdd8f149c,0xe0d700af,0x00000000}},	//   _pubu, لوق_, _овь_, --,
   {{0x81d60083,0x3a2400d7,0xfe7100b5,0xdb090098}},	//   _হিট_, _spmp_, ندے_, _sheá,
   {{0x61e90043,0x200500b8,0xab5d035f,0xf4560070}},	//   ţele, álie_, _diżo, ויער_,
   {{0x1daf012f,0x63a408c7,0x7bce007b,0x00000000}},	//   _जीवत, _mkin, _wubu, --,
   {{0x7bce4381,0x7c3a4382,0x6b82010b,0x63a4011e}},	//   _tubu, _štru, siog, _lkin,
   {{0x7bdc4383,0x63a43c1f,0xa3ae0d1f,0xa2a008a9}},	//   _utru, _okin, कता_, _गुस्,
   {{0x9634117a,0xc6f84384,0x6d5c012c,0x96ea1958}},	//   ениц, чних_, _hora, цька_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a4134c,0x6d5c4385,0xb4e8004e,0x98ac0395}},	//   _akin, _jora, बरे_, _cadă_,
   {{0x7bda02e1,0x69c80069,0xb4de0035,0x00000000}},	//   _étud, _iide, _तभी_, --,
   {{0x63b60297,0x6d5c4386,0xa2a0012f,0x2246343a}},	//   _chyn, _lora, _गुह्, _šoka_,
   {{0x69c84387,0x63a4011e,0x5a9b0070,0xe2ab01cb}},	//   _kide, _dkin, ַשלא, تادن_,
   {{0x63a44388,0x6d5c4389,0x69c8007a,0x644e02b1}},	//   _ekin, _nora, _jide, äbis,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c8438a,0x7538438b,0x6d5c0284,0x238800b5}},	//   _lide, _havz, _aora, tője_,
   {{0x6d5c438c,0x69c80a32,0x443e2bf2,0xbddb009e}},	// [3c90] _bora, _oide, lvt_, _brèa,
   {{0x5bb90517,0x69c8438d,0xbddb009e,0x23b200b5}},	//   ेद्व, _nide, _crèa, mája_,
   {{0x672235b9,0x7538438e,0xfbd000f3,0x3cde07b5}},	//   _oboj, _mavz, لتن_, गड़े_,
   {{0x61ed438f,0x6d5c0037,0x69c84390,0x764202d7}},	//   _kwal, _eora, _aide, _oroy,
   {{0x69c803cb,0x6d5c4391,0xb4bb018d,0xaefb00f1}},	//   _bide, _fora, _अण्_, _dlùt,
   {{0x6d5c4392,0x69c84393,0x61ed20ff,0x75383e39}},	//   _gora, _cide, _mwal, _navz,
   {{0x69c8122e,0x31580070,0x67220069,0x61ed018e}},	//   _dide, ויגן_, _bboj, _lwal,
   {{0x69c84394,0x76424395,0x23b200fd,0x7f5d00f6}},	//   _eide, _broy, kája_, _josq,
   {{0x69c84396,0x63b60297,0x76424397,0x6d5c4398}},	//   _fide, _rhyn, _croy, _yora,
   {{0x69c84399,0x63b60159,0x6d5c439a,0x636620d9}},	//   _gide, _shyn, _xora, _ióni,
   {{0x98141c51,0x809f1db1,0xa2c209b1,0xc6250083}},	//   _لبنا, _खुले, रेन्, বিধা_,
   {{0xe29a439b,0xf7701328,0x61ed01a8,0x7bc90118}},	//   зам_, _پام_, _bwal, _jieu,
   {{0x7bc902e1,0x45240083,0x69c80159,0x764239e2}},	//   _mieu, বয়ক_, _yide, _groy,
   {{0x7bc9439c,0x661b439d,0x63662d03,0x61ed439e}},	//   _lieu, mtuk, _móni, _dwal,
   {{0x7f5d0f56,0x6d5c439f,0x61ed018e,0xa2a00f8a}},	//   _bosq, _rora, _ewal, _गुर्,
   {{0x7bc925cb,0xe29a0021,0x6d5c43a0,0xe46a00ab}},	//   _nieu, _най_, _sora, stöö_,
   {{0x6d5c43a1,0xdd920125,0x661b43a2,0x61ed22a4}},	// [3ca0] _pora, هور_, ntuk, _gwal,
   {{0xa3b40953,0x6d5c0c54,0x661b43a3,0xd29b0122}},	//   _जीत_, _qora, ituk, _משפט,
   {{0x6d5c02c9,0x26190019,0x661b43a4,0x7f5d0392}},	//   _vora, hèo_, htuk, _fosq,
   {{0x69c843a5,0xeb9743a6,0x673b004e,0x7981001e}},	//   _side, них_, jduj, _amlw,
   {{0x6d5c43a7,0x69c843a8,0x636620d9,0x7bc943a9}},	//   _tora, _pide, _cóni, _dieu,
   {{0x61fb21a4,0x443e43aa,0x442702a7,0x00000000}},	//   áuli, yvt_, _opn_, --,
   {{0x7dc900d8,0xab5d003c,0xc7c61eba,0x6aa9008c}},	//   _užsa, _miżj, нсии, _eyef,
   {{0x764243ab,0xfaa602ef,0x69c843ac,0x6366213c}},	//   _proy, _забо, _wide, _fóni,
   {{0xf6521d6c,0xadc301a5,0x644343ad,0x69c8165f}},	//   ائع_, _hoạc, _arni, _tide,
   {{0x64431f20,0x442743ae,0x69c80210,0x78a80b88}},	//   _brni, _bpn_, _uide, _tydv,
   {{0x64430254,0x661b01d7,0x6ea21cc3,0x395e01f7}},	//   _crni, atuk, _कुसु, _iots_,
   {{0x67220c21,0x644300cb,0x395e01d7,0xd49700d8}},	//   _uboj, _drni, _hots_, эры_,
   {{0x61f800d8,0x442701b4,0x2a660221,0x6366002a}},	//   нняў_, _epn_, nyob_, _xóni,
   {{0x442708c8,0x6443023a,0x257200a2,0xe8ee02a4}},	//   _fpn_, _frni, _bâle_, алi_,
   {{0xd3a743af,0x395e43b0,0x213a0260,0x00000000}},	//   _прип, _mots_, _daph_, --,
   {{0x9f34004b,0x61ed43b1,0x395e43b2,0x3f82007e}},	//   лесі, _twal, _lots_, _cmku_,
   {{0x7bc943b3,0x2a66006d,0xab5d009f,0x00000000}},	// [3cb0] _rieu, jyob_, _fiżj, --,
   {{0x7bc943b4,0x673b0009,0x395e43b5,0x00000000}},	//   _sieu, zduj, _nots_, --,
   {{0x661b06a2,0x63660d9b,0x7bc943b6,0x7f5d021d}},	//   ztuk, _sóni, _pieu, _tosq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1dd80026,0x7bc90248,0x23960029,0x72ec0070}},	//   _भूपत, _vieu, nāja_, פֿאַ,
   {{0x2d8510b3,0x333b0024,0x673900e0,0x2ee901f7}},	//   _öle_, _laqx_, _sawj, lbaf_,
   {{0xdd9406d8,0x27950036,0x7bc90023,0x0138011d}},	//   _сары, кшир, _tieu, גרות_,
   {{0x661b43b7,0x636643b8,0x394c43b9,0xfd4d00cc}},	//   ttuk, _tóni, _ends_, _ngoả,
   {{0x673b0139,0x2b4d0160,0x645c43ba,0x1a5b0037}},	//   rduj, _inec_, ärin, _عشرة_,
   {{0x661b43bb,0x395e0176,0x893400d1,0x442743bc}},	//   rtuk, _gots_, _معما, _ppn_,
   {{0x661b43bd,0x3d19074f,0xa2e603d0,0x63660176}},	//   stuk, _पाने_, конд, _mónv,
   {{0x6443008b,0x00000000,0x00000000,0x00000000}},	//   _vrni, --, --, --,
   {{0xd2f20461,0xdcfc023a,0xa2f20066,0xbddb0118}},	//   _अजीब_, _smrč, _अजीज_, _srèn,
   {{0x3ceb0035,0x44270283,0x201a01f7,0x644300fe}},	//   टरों_, _tpn_, _pqpi_, _trni,
   {{0x10a643be,0x644343bf,0x44270b51,0x00000000}},	//   тивн, _urni, _upn_, --,
   {{0xd00f2087,0x200543c0,0x20040bcc,0x0326002d}},	//   تلف_, ália_, čmi_, _рдин,
   {{0x0e6328fb,0x9f580098,0x644143c1,0x00000000}},	// [3cc0] актн, orrú_, lvli, --,
   {{0x6d8b0029,0x5bca364c,0xf0660043,0xa2c20577}},	//   kļau, िद्व, _акоп, रेण्,
   {{0x6ea20fd0,0x5f061c1b,0x395e43c2,0x2b5f00a2}},	//   _कुरु, _изна, _rots_, _bouc_,
   {{0x09e62f40,0xfded00b4,0x395e43c3,0x2d83021d}},	//   водн, _चौकस_, _sots_, _emje_,
   {{0x395e12c3,0x82d70070,0x2fc043c4,0x644100be}},	//   _pots_, דונג_, mmig_, hvli,
   {{0xfce32374,0x660943c5,0x3d190354,0xc27b00a5}},	//   _воро, drek, _पाये_, ורני,
   {{0x395e12c3,0x66091998,0x6d4e43c6,0x888400fd}},	//   _vots_, erek, _inba, دیان,
   {{0xf0931759,0x47340085,0x466a43c7,0x660943c8}},	//   ינו_, унис, дром_, frek,
   {{0x395e162d,0x660943c9,0x6441022e,0xb8c90437}},	//   _tots_, grek, evli, _गु_,
   {{0x26cf0b88,0xb5fd0355,0x00000000,0x00000000}},	//   _eggo_, myšl, --, --,
   {{0x6ab21f34,0x660906a2,0x5975010b,0x61e60345}},	//   _जरुर, arek, _сыту, epkl,
   {{0x23960080,0x66e643ca,0x0686081b,0x00000000}},	//   tāja_, _рода, _иген, --,
   {{0x51870b6b,0x2d8f006c,0x6d8b0067,0x00000000}},	//   вува, égek_, nżac, --,
   {{0x239600ec,0x60de008c,0x2fcb0207,0xd83815d8}},	//   rāja_, _cfpm, _sicg_, _ksč_,
   {{0xa3b40325,0x8438004f,0x61e60afc,0x8afd06fe}},	//   _जीव_, _أكبر_, apkl, _hoře,
   {{0x6ab20953,0x6d4e43cb,0x2fc00430,0x239600ea}},	//   _जरूर, _anba, gmig_, pāja_,
   {{0x27e90254,0x7c3a02c4,0x30c50033,0x1df80f99}},	// [3cd0] ćani_, _štrp, ্রেস, кеты_,
   {{0xdcb10023,0x9be700d4,0x00000000,0x00000000}},	//   _ở_, відк, --, --,
   {{0x9f580831,0x660943cc,0x00000000,0x00000000}},	//   guró_, zrek, --, --,
   {{0xc4770052,0x09cb00a1,0x201128f7,0x6d4e43cd}},	//   כתבו_, ाद्य, muzi_, _enba,
   {{0x201143ce,0x3f893947,0xd8380260,0xfe7f0176}},	//   luzi_, miau_, _asč_, _veïs_,
   {{0x3f8943cf,0xdb1c43d0,0x0d6402fb,0xab5d0024}},	//   liau_, _zurü, _късм, _miżi,
   {{0xb8db0726,0x201143d1,0x645c43d2,0x8bc7002e}},	//   _घर_, nuzi_, äril, _асад,
   {{0x660943d3,0x3f8943d4,0x6fd60066,0x8afd007e}},	//   trek, niau_, _मंसू, _boře,
   {{0xdb1c43d5,0x09dd0083,0x7bd543d6,0x636601ef}},	//   _euró, _ঠিকা, _huzu, _mónt,
   {{0x660943d7,0x7bd5289f,0x3f89001e,0xdb1c002a}},	//   rrek, _kuzu, hiau_, _furó,
   {{0x78540a86,0x7bd543d8,0x3f89010b,0x201143d9}},	//   _نیوز_, _juzu, kiau_, juzi_,
   {{0x91e6095d,0x36d50370,0x7bd543da,0x2011021d}},	//   ломе, _содр, _muzu, duzi_,
   {{0x2ed90083,0x3f89001e,0x660543db,0x7bd543dc}},	//   তরাষ, diau_, _спла, _luzu,
   {{0x201101a8,0xbddb0248,0xd56700af,0xab5d007a}},	//   fuzi_, _crèm, _штеп, _diżi,
   {{0x201143dd,0x5f060133,0x20050207,0x25a504c7}},	//   guzi_, лзва, šlin_, moll_,
   {{0x3f890a93,0x636601dd,0xab5d035f,0x00000000}},	//   giau_, _cónt, _fiżi, --,
   {{0x7bd543de,0x00000000,0x00000000,0x00000000}},	// [3ce0] _auzu, --, --, --,
   {{0x61e40c1f,0x7bd543df,0x25a50d9a,0x201101a8}},	//   _itil, _buzu, noll_, buzi_,
   {{0x711b0779,0x3f8900d8,0x7ae40453,0xbb4602fb}},	//   _אויפ, biau_, ñito, лежк,
   {{0x3f8943e0,0x7bd506a2,0x636600ee,0x00000000}},	//   ciau_, _duzu, _ións, --,
   {{0x25a52a0c,0xe91812ea,0x00000000,0x00000000}},	//   koll_, волі_, --, --,
   {{0x6d4e43e1,0xd8380187,0x63a6011e,0x9f580036}},	//   _unba, _psč_, hokn, curò_,
   {{0xebe30b07,0x68f81342,0x3d190084,0x6366008a}},	//   _госп, ravd, _पाते_, _jóns,
   {{0x61e443e2,0x7c930037,0xdb1c0107,0x645c194e}},	//   _otil, _الفص, _eurò, ärim,
   {{0x63a601a0,0x7bc21db3,0x7bd543e3,0x557415e1}},	//   dokn, mmou, _zuzu, игит,
   {{0x7bc243e4,0x3f89010b,0x7bd50908,0x25a543e5}},	//   lmou, ziau_, _yuzu, goll_,
   {{0x7c290bec,0x61e443e6,0xa2c205a6,0x63550eb1}},	//   _ćerk, _atil, रेस्, авну,
   {{0x7bc202e9,0x2011018c,0x61e40103,0xd3790207}},	//   nmou, vuzi_, _btil, opći_,
   {{0x388e0669,0x3f89010b,0x25a543e7,0x98ac43e8}},	//   _hər_, viau_, boll_, _radę_,
   {{0x3f89001e,0xdb09009e,0x61e900af,0x201143e9}},	//   wiau_, _dheù, ţelo, tuzi_,
   {{0x21310107,0x636643ea,0x3f89001e,0xbddb02d0}},	//   rezh_, _cóns, tiau_, _vrèm,
   {{0x20110010,0x7bd543eb,0x7bc20355,0x00000000}},	//   ruzi_, _ruzu, jmou, --,
   {{0x8cf50150,0x3f8943ec,0x7bc20282,0x51870d6e}},	// [3cf0] изац, riau_, dmou, _буна,
   {{0x3f8943d4,0x66cb013b,0x7bc201a2,0x127c0070}},	//   siau_, _hökü, emou, _ראזע,
   {{0xe1ff006c,0x3f8943ed,0xbddb0118,0x66cb027b}},	//   lsó_, piau_, _krèk, _kökü,
   {{0x224943ee,0xab5d0069,0x00000000,0x00000000}},	//   _krak_, _liżv, --, --,
   {{0xe9ff01a5,0xe1ff283e,0xfaa50166,0x7bda0118}},	//   _trận_, nsó_, јало, _étun,
   {{0x2249264f,0x7bd543ef,0xd94543f0,0xab5d009f}},	//   _mrak_, _tuzu, реки, _niżv,
   {{0x25a543f1,0xe73943f2,0x22490118,0xa3b50067}},	//   voll_, вей_, _lrak_, झता_,
   {{0x16390037,0x224943f3,0x00000000,0x00000000}},	//   نسخة_, _orak_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27050028,0x45851bdf,0x6b8b43f4,0x79c8126b}},	//   ồn_, ргов, ligg, _موقف_,
   {{0x25a543f5,0x61e443f6,0x2249128f,0x473543f7}},	//   roll_, _stil, _arak_, _внес,
   {{0x224943f8,0x03a61e96,0x61e443f9,0x69c30987}},	//   _brak_, римо, _ptil, lmne,
   {{0x63a643fa,0x25a543fb,0x66cb01d6,0x27e900cb}},	//   rokn, poll_, _dökü, ćanu_,
   {{0xa2c2164f,0x0eee02e4,0x69c30037,0xa50905f2}},	//   रेष्, जर्स_, nmne, _река_,
   {{0xa2e60409,0x224901b7,0x00000000,0x00000000}},	//   _койд, _erak_, --, --,
   {{0x684000b8,0x22490024,0x3a2d43fc,0x644f00f4}},	//   ládá, _frak_, _opep_, čkić,
   {{0x0d86081e,0x7de507f8,0xa2c243fd,0x6b8b2bb7}},	// [3d00] алан, مسلم, रेश्, digg,
   {{0x01fb0070,0xab5d035f,0x5fb80099,0xe3b900ae}},	//   _שפיל, _miżu, _आठवल, ntın_,
   {{0x22492190,0x7bc20107,0x6b8b027a,0xdb1c008d}},	//   _zrak_, tmou, figg, _burð,
   {{0x65630024,0x00000000,0x00000000,0x00000000}},	//   _lonh, --, --, --,
   {{0x7bc20fe4,0x79c6010b,0x00000000,0x00000000}},	//   rmou, айдз, --, --,
   {{0xf8060fb4,0x645c2933,0x99f501e0,0x00000000}},	//   ачин, ärik, сяці, --,
   {{0xa967282d,0xd83a002d,0x31570070,0x6b8b001c}},	//   рија_, тэл_, ייסן_, bigg,
   {{0xcb67151c,0x3cf81741,0xab5d0035,0x7c2e43fe}},	//   _касе_, _herv_, _biżu, _ipbr,
   {{0xba2943ff,0x65634400,0xae0c0026,0x49ca09cc}},	//   _مسلم_, _bonh, िंटन_, _алан_,
   {{0x656300c9,0x66cb027b,0x22490065,0x00000000}},	//   _conh, _sökü, _rrak_, --,
   {{0x3cf801a2,0xe2f900d4,0x5fd20099,0x3d1900ab}},	//   _merv_, лені_, _दंगल, _पासे_,
   {{0xe3b9013b,0xe1ff00b5,0xb6a60384,0x8afd00fe}},	//   atın_, tsó_, _киел, _kořa,
   {{0x52140ebb,0x363600d1,0xe57a2c93,0x6563099e}},	//   одят, _خراس, _изд_, _fonh,
   {{0x7c2e4401,0x74f82252,0xdd1a003c,0x3d100035}},	//   _opbr, _секр_, għżu, ालों_,
   {{0x657a004f,0xb4d200a1,0xe1ff4402,0x3f8703e6}},	//   mhth, वशी_, ssó_, аѓаа,
   {{0x22494403,0x853c010b,0x644a007a,0x65630051}},	//   _trak_, plės, _irfi, _zonh,
   {{0xdef8010b,0x443c4404,0x63ad4405,0x3eaf4263}},	// [3d10] рыс_, _hsv_, _ikan, ægt_,
   {{0xdcf90642,0x201e0443,0x443c0d92,0x657a0023}},	//   افات_, àtic_, _ksv_, nhth,
   {{0x9f3512ea,0x63ad01a8,0x0dc84406,0x00000000}},	//   _лені, _kkan, рути_, --,
   {{0xe45700c2,0x6ea24407,0x442e0132,0x3d19007c}},	//   ייבט_, _कुकु, _mpf_, _पावे_,
   {{0x6b8b4408,0x443c071e,0xf2d40070,0xe3b90095}},	//   rigg, _lsv_, קעס_, ytın_,
   {{0x443c4409,0xab5d0484,0x63ad011e,0x6b8b440a}},	//   _osv_, _riżu, _lkan, sigg,
   {{0x6602440b,0x7e6d3dd6,0x256900b5,0x65630207}},	//   _avok, lyap, _múlt_, _ronh,
   {{0x65630370,0x09e60083,0x63ad010a,0x69dc3306}},	//   _sonh, _নিরা, _nkan, _črev,
   {{0x3a75021d,0x9f5e1010,0x644a05ee,0x443c0029}},	//   _улар, été_, _arfi, _asv_,
   {{0x63ad08e1,0x657a440c,0x66e70d1f,0x6e3d0159}},	//   _akan, ghth, _ट्रक_, _mssb,
   {{0x64a5440d,0x442e0279,0xe3b90644,0x6840440e}},	//   сана, _cpf_, rtın_, rádá,
   {{0x443c0b3e,0xc16900a5,0x00000000,0x00000000}},	//   _dsv_, _אח_, --, --,
   {{0x644a0e34,0x657a09c3,0x442e02a7,0xc6a70274}},	//   _erfi, bhth, _epf_, _тржи,
   {{0x63ad018e,0x657a440f,0x1ddb004e,0xf65202b8}},	//   _ekan, chth, _बढ़त, _מצד_,
   {{0xafe61d29,0x6e2f0107,0xe1f200d1,0x660208b7}},	//   собл, _apcb, _کسب_, _zvok,
   {{0x43930798,0xef17027a,0x63ad0118,0x6b9b1413}},	//   _најс, ймс_, _gkan, _njug,
   {{0xa2a00026,0x6f1d02d7,0x2ef90160,0xa3b40380}},	// [3d20] _गुच्, _dcsc, _desf_, _जीए_,
   {{0x32024410,0x6b9b4411,0x6b892d69,0x442e27d6}},	//   msky_, _ajug, _ameg, _ypf_,
   {{0xfbd205bc,0x32020187,0xa06a14d0,0x61f6001e}},	//   ستا_, lsky_, _сана_, _hwyl,
   {{0xeafa02de,0x8afd01c0,0xef2100ea,0x00000000}},	//   ارات_, _pořa, _ceļā_, --,
   {{0x32024412,0xa96a0ddc,0xa2cb02e4,0x298a2a8a}},	//   nsky_, лида_, सेप्, лско_,
   {{0x2d8f006c,0x7c334193,0x2d8c4413,0x2b404414}},	//   éget_, ñerí, _öde_, žic_,
   {{0x764b001e,0xbddb0118,0x660227d0,0x6b9b0282}},	//   _argy, _brèw, _svok, _fjug,
   {{0x442e306e,0x7f441db3,0xab960037,0x9b960037}},	//   _rpf_, ndiq, _الرغ, _الرت,
   {{0x67190084,0xda630be8,0x657a4415,0xba5602fb}},	//   _धारक_, _евти, thth, _утвъ,
   {{0x7ae201a2,0x443c4416,0x320200d5,0x1c0d02b4}},	//   lcot, _psv_, dsky_, ांचल_,
   {{0x32024417,0x78ba00ea,0x443c0176,0xd7ea0800}},	//   esky_, _uztv, _qsv_, _смее_,
   {{0x6e244418,0x4c9b02b5,0x61f600e9,0x29f60035}},	//   ktib, רשטע, _bwyl, oła_,
   {{0x3d190324,0x2d8a0054,0x55584419,0xe5a61457}},	//   _पाले_, _ombe_, _валя_, _лиди,
   {{0x68fa008c,0x61f600e9,0x443c441a,0xab5d0024}},	//   _jetd, _dwyl, _tsv_, _jiżr,
   {{0x7dc901c8,0x442e0392,0xc05800d4,0x6e240159}},	//   _užsi, _upf_, біт_, etib,
   {{0x68fa012f,0x44ce0095,0x63ad0af0,0x7e6d1bf4}},	//   _letd, mə_, _ukan, tyap,
   {{0x320f0332,0x61f6001e,0x44ce0095,0x291e00ea}},	// [3d30] _így_, _gwyl, lə_, _octa_,
   {{0x68fa1736,0x6b89010b,0x29f60035,0x7e6d441b}},	//   _netd, _smeg, dła_, ryap,
   {{0x44ce0669,0x29f60067,0x6e241268,0x6f1d03d0}},	//   nə_, eła_, atib, _tcsc,
   {{0xe3b9027d,0x2d8a023c,0x7bc00067,0x291e441c}},	//   ktım_, _embe_, _chmu, _acta_,
   {{0x2bb8004f,0x2d8f006c,0x29f60035,0x7d03008d}},	//   حالة_, éges_, gła_, ónss,
   {{0x6ea2441d,0x98be037a,0xbddb00f7,0x69dc023a}},	//   _कुटु, _altı_, _brèv, _čret,
   {{0x29f6004e,0x6d55441e,0xab5d0069,0x6d4508c7}},	//   ała_, _inza, _diżr, mdha,
   {{0x44ce01c2,0x6b891f53,0x0609005c,0x7c25441f}},	//   də_, _umeg, аник_, mthr,
   {{0xe5791a1c,0x6d454420,0x2005011c,0x96b9093e}},	//   изи_, odha, šlih_, шуку_,
   {{0x6d4501ca,0xd7fb0dba,0x7afb02bf,0x32022977}},	//   ndha, _буд_, _heut, vsky_,
   {{0x7afb0ec0,0x6d450211,0xbddb00f7,0xf99200a5}},	//   _keut, idha, _grèv, _קרב_,
   {{0x7c250297,0x61f6001e,0x69db4421,0x20110cc2}},	//   ithr, _pwyl, _kuue, drzi_,
   {{0x32040076,0x7afb4422,0xf1aa0312,0xbb3a0070}},	//   émy_, _meut, لاسه_, בערי,
   {{0x32024423,0x7afb02c9,0x55a600b5,0x00000000}},	//   rsky_, _leut, _وجوہ, --,
   {{0x6d454424,0x7ae24425,0xafe305f2,0x320209dd}},	//   ddha, ycot, досл, ssky_,
   {{0x6d554426,0x6e244427,0x7c2500f1,0x29f60035}},	//   _anza, ttib, dthr, yła_,
   {{0x61463275,0x20d601c8,0x69c100b8,0x7f4400a2}},	// [3d40] _депа, _мінс, _ohle, rdiq,
   {{0x6e244428,0x7f4400a8,0x8cb6192f,0x69c10345}},	//   rtib, sdiq, осеч, _nhle,
   {{0x0b4607b0,0x7afb4429,0xdb0b0132,0xdcee0160}},	//   жнен, _beut, mogê, _albă,
   {{0x2018189b,0x6d450014,0xab2a442a,0x68fa0176}},	//   muri_, adha, рода_, _setd,
   {{0x7c250094,0x7afb06d1,0x2018442b,0x44ce0095}},	//   athr, _deut, luri_, zə_,
   {{0x69c13cb2,0x44ce01c2,0xbddb0443,0x29f60067}},	//   _chle, yə_, _prèv, rła_,
   {{0x2018442c,0x29f6004e,0x7c3b0009,0x69c1006b}},	//   nuri_, sła_, _ćurg, _dhle,
   {{0x44ce01c2,0x38600009,0x2240442d,0x29f60067}},	//   və_, ćir_, _osik_, pła_,
   {{0x2018442e,0x7bdc442f,0x44250035,0x69c1239a}},	//   huri_, _huru, etl_, _fhle,
   {{0x7bdc4430,0x637f00da,0x20184431,0x7c45008a}},	//   _kuru, _këng, kuri_, _ótrú,
   {{0x9cdb00c2,0x7bdc4432,0x20184433,0x22403a35}},	//   יקיפ, _juru, juri_, _asik_,
   {{0xc5f90b52,0x7bdc4434,0x883b0122,0x44ce0095}},	//   _আমরা_, _muru, _כתבו, rə_,
   {{0x6d450a8c,0x7bdc0ce8,0xd24400af,0x44ce00a8}},	//   ydha, _luru, мэри, sə_,
   {{0x7c254435,0x291c010b,0x20184436,0x98be0359}},	//   ythr, ngva_, furi_, _latč_,
   {{0x7bdc4437,0x20182d7b,0xe9ff0028,0x44ce0095}},	//   _nuru, guri_, _trần_, qə_,
   {{0x20030035,0x3a2603d0,0x00000000,0x00000000}},	//   rsji_, ktop_, --, --,
   {{0x7c254438,0x0ec522d4,0x7bdc4439,0x7e600310}},	// [3d50] wthr, लेंड, _auru, _àmpl,
   {{0x7bdc443a,0x2018443b,0x2b46443c,0x3a3f022e}},	//   _buru, buri_, edoc_, _rsup_,
   {{0x201809eb,0x7bdc443d,0x7afb443e,0x2fc2009e}},	//   curi_, _curu, _peut, _fhkg_,
   {{0x7bdc443f,0x7c254440,0x23960080,0xa2c228b1}},	//   _duru, rthr, tāji_, रेक्,
   {{0x69c12ea6,0xdb090284,0x7bdc005f,0xdb0b0031}},	//   _phle, _bheò, _euru, logë,
   {{0x4dda00a5,0xdb0900f1,0x2fc94441,0x98be0023}},	//   _לחשו, _cheò, lmag_, _antđ_,
   {{0x637f00da,0x7afb4442,0xdcfc0254,0xdb090284}},	//   _kënd, _teut, _smrć, _dheò,
   {{0x32190e7d,0x3a3f010d,0x16060d1f,0x00000000}},	//   kusy_, _tsup_, _शिखर_, --,
   {{0x20184443,0xdb090284,0x637f0055,0x67294444}},	//   zuri_, _fheò, _mënd, rfej,
   {{0x764903ad,0x7bdc2c53,0x69c1102f,0x637f01f4}},	//   rvey, _yuru, _uhle, _lënd,
   {{0x7bdc021d,0x20184445,0xc5680037,0xe3b20079}},	//   _xuru, xuri_, تحيل_, فرح_,
   {{0x20184446,0x394518aa,0xddcd011c,0x44253f90}},	//   vuri_, _hals_, jzaž, rtl_,
   {{0xbebb00da,0x44254447,0x20184448,0x0596006c}},	//   _mbës, stl_, wuri_, _کانگ,
   {{0x20184449,0xa06a005f,0x65bd00e0,0x00000000}},	//   turi_, бага_, bèha, --,
   {{0x39450310,0x645c0086,0x90c308ce,0xdfd20037}},	//   _mals_, ärit, ебре, فيس_,
   {{0x2018444a,0x321937fe,0x7bdc444b,0xdb1b0079}},	//   ruri_, busy_, _ruru, _bhuí,
   {{0x2018444c,0xd24f004f,0x2240043d,0x3f670274}},	// [3d60] suri_, _مني_, _usik_, чито_,
   {{0x7bdc1067,0x2018444d,0xf1bf444e,0xdca6444f}},	//   _puru, puri_, ltán_, пази,
   {{0x7bdc01c2,0x6bd606ca,0xf1bf0079,0x50db00a5}},	//   _quru, ستار, otán_, _לחיצ,
   {{0x7bdc4450,0x8fa64451,0xdb0900f1,0xf1bf4452}},	//   _vuru, _хаме, _sheò, ntán_,
   {{0x7bdc4453,0x39450160,0x00000000,0x00000000}},	//   _wuru, _bals_, --, --,
   {{0x23960029,0x290200ea,0x88bc0355,0xd7fa00af}},	//   māju_, _ēkas_, _obět, буи_,
   {{0x39450523,0xdca30432,0x3a264454,0x072013f0}},	//   _dals_, _зари, stop_, _यादव_,
   {{0x4c9b0122,0x3a262bf9,0xab271285,0x98a70355}},	//   _הבלו, ptop_, _носа_, leně_,
   {{0xf6230202,0xc6f715eb,0x394537e5,0x239600ea}},	//   едњо, чных_, _fals_, nāju_,
   {{0x99860ef5,0xd90d0088,0xd90e05f5,0xe3b90225}},	//   _علاو, _نیه_, _صیب_, ptık_,
   {{0x888104cd,0x2eb900e7,0x00000000,0x00000000}},	//   _لیون, _आर्त, --, --,
   {{0x18770122,0xa29500d8,0xbebb01f4,0x69ca4455}},	//   _מעבר_, дамі, _mbër, lmfe,
   {{0x637f01d2,0x6fd60fd1,0xe9ff0019,0x95ca2324}},	//   _rënd, _मंजू, _trấn_, _лука_,
   {{0x32194456,0x645c4102,0x00000000,0x00000000}},	//   rusy_, äris, --, --,
   {{0xdb1b004f,0x753a1a47,0x9f410312,0x00000000}},	//   _shuí, metz, _athá_, --,
   {{0x637f00da,0xa85702b8,0x753a4457,0xd3a400d8}},	//   _qënd, הילה_, letz, _прып,
   {{0x63af15b3,0x9d550a86,0x2fc903b3,0x290c2cb7}},	// [3d70] mocn, وچست, rmag_, _odda_,
   {{0x61ed4458,0x2fc94459,0xdb0b445a,0x63af00a0}},	//   _ital, smag_, mogé, locn,
   {{0xbddb02d0,0x637f01f4,0x3f920dc3,0x39450176}},	//   _près, _tënd, biyu_, _rals_,
   {{0x3d19018d,0x3f80018a,0xdecb32b3,0x63af445b}},	//   _पाके_, chiu_, _гугл_, nocn,
   {{0x3945445c,0xd9450426,0xa969174b,0x657d0031}},	//   _pals_, дели, жила_, ëshk,
   {{0x99670086,0xbddb0248,0x67220453,0xeab00037}},	//   ятел, _frèr, _acoj, دعم_,
   {{0x753a0291,0x394532db,0x61ed1b82,0x07a511ab}},	//   detz, _vals_, _ltal, макн,
   {{0x6d471364,0x290c445d,0x61ed445e,0x39450b88}},	//   _haja, _edda_, _otal, _wals_,
   {{0x6d47445f,0x39454460,0xa3d10084,0x61ed4461}},	//   _kaja, _tals_, वगन_, _ntal,
   {{0x6d474462,0x7bcb0cfc,0x656a0284,0x67220282}},	//   _jaja, lmgu, _cofh, _ecoj,
   {{0x6d474463,0x61ed4464,0x6fbf02cb,0x03a608bb}},	//   _maja, _atal, ्षां, дино,
   {{0x6d470c1f,0x61ed009f,0x32090107,0x98a70355}},	//   _laja, _btal, _bvay_, zeně_,
   {{0xa5092070,0x753a06a2,0x61ed0176,0x9f9f1192}},	//   _дела_, betz, _ctal, _géén_,
   {{0xf1bf06c8,0xdb0b013c,0x8afd00fe,0x673b0392}},	//   stán_, llgä, _bořk, leuj,
   {{0xdee6135d,0x61ed4465,0x2bd90fd1,0x661b4466}},	//   доби, _etal, _बंगा, luuk,
   {{0xe29a4467,0x23960080,0x64434468,0xe3b702fb}},	//   _май_, tāju_, _isni, _общ_,
   {{0x6d470394,0x16000067,0x00000000,0x00000000}},	// [3d80] _baja, लीपर_, --, --,
   {{0x6d474469,0x7ae9446a,0x41da1119,0xf1bf446b}},	//   _caja, _afet, _यूएस, ntál_,
   {{0x6d47446c,0x2005446d,0x98a5013a,0x6ad601d1}},	//   _daja, álit_, _dalī_, धश्र,
   {{0xeb97446e,0x661b446f,0xbddb0118,0x62860065}},	//   мих_, kuuk, _isèn, ozko,
   {{0x6f044470,0x09e34471,0x62861c67,0x59f8002d}},	//   maic, вочн, nzko, челя_,
   {{0x64433b12,0x7ae90370,0x6f04004a,0x6d471b0f}},	//   _osni, _efet, laic, _gaja,
   {{0x7ae94472,0x00000000,0x00000000,0x00000000}},	//   _ffet, --, --, --,
   {{0x6d474473,0x6f040014,0x661b01a8,0xdb1b009e}},	//   _zaja, naic, fuuk, _ghuà,
   {{0x753a06a2,0x6d471ebf,0x644300f6,0x00000000}},	//   tetz, _yaja, _asni, --,
   {{0x62864474,0x6f0401a6,0x61ed0088,0x28a91b8f}},	//   dzko, haic, _rtal, _चुकि,
   {{0x63af4475,0x753a06a2,0x443e02a2,0x6f044476}},	//   tocn, retz, uwt_, kaic,
   {{0x753a02bf,0x93bd0043,0xdb0b4477,0x9f9f0345}},	//   setz, ptăm, togé, _téén_,
   {{0x6f040014,0x63af36a5,0xf8e20af9,0x257b0345}},	//   daic, rocn, _पलाय, _wêla_,
   {{0xdb0b4478,0x00000000,0x00000000,0x00000000}},	//   rogé, --, --, --,
   {{0x6d474479,0xdb0b013c,0x6f040719,0xd48f01e0}},	//   _raja, llgå, faic, _рр_,
   {{0x6d47447a,0x61ed018e,0x00000000,0x00000000}},	//   _saja, _ttal, --, --,
   {{0x6d47447b,0x61ed447c,0x5d5506c2,0x62860035}},	// [3d90] _paja, _utal, нкат, czko,
   {{0x20050332,0x6d47028b,0xdcbb00c3,0x71750037}},	//   ális_, _qaja, още_, _أهدا,
   {{0x6d47447d,0x5b1507c1,0x2d93447e,0x6f0419fd}},	//   _vaja, емет, rixe_, baic,
   {{0x6d4737db,0x6f04447f,0x09e60033,0x4fc700d8}},	//   _waja, caic, _নিজা, _існа,
   {{0xa3c20d00,0x63660453,0x34bb14eb,0x00000000}},	//   ्गत_, _cóny, _उर्द, --,
   {{0xf7780069,0x00000000,0x00000000,0x00000000}},	//   _ruħa_, --, --, --,
   {{0x7d05046a,0xa3af007c,0x88bc00b8,0xb4bd00ab}},	//   mahs, कवा_, _sběr, _आरे_,
   {{0x661b09d6,0x4427028b,0x8bc4010b,0xdce7023a}},	//   tuuk, _rqn_, _асуд, _mojč,
   {{0xeab30fab,0x9f510332,0xf6510c9e,0x4a552327}},	//   _شعر_, lszó_, ائب_, _якас,
   {{0x5f0f00b4,0x44654480,0x00000000,0x00000000}},	//   तृत्_, евов, --, --,
   {{0x7ae44481,0x5fdb00b1,0xf1bf4482,0x3eb90c61}},	//   žite, _मंगल, rtál_, _lyst_,
   {{0x22520b88,0x2fd9009e,0x8afd0355,0x57ca03de}},	//   _pryk_, _nisg_, _boři, ागृह,
   {{0x55594419,0x59c400b4,0x6f044483,0x77ff021a}},	//   _надя_, _लीडर, vaic, _ईबुक_,
   {{0x23960080,0xdce70478,0x62864484,0x66090c2c}},	//   tājs_, _bojč, rzko, msek,
   {{0xa0a32214,0x7d05046a,0x62860c0f,0x6f0401a6}},	//   гард, dahs, szko, taic,
   {{0xdce72042,0x225201b4,0x2d910027,0x3eb94485}},	//   _dojč, _tryk_, _amze_, _byst_,
   {{0x6f04004a,0x539b0122,0x63a400e0,0x59af111b}},	// [3da0] raic, _מיקו, _ijin, टवार,
   {{0x6f04004a,0x3eb94486,0x660900c3,0x7d050a4e}},	//   saic, _dyst_, isek, gahs,
   {{0x6f0409c3,0x602600d8,0x660900d7,0x63a40345}},	//   paic, _ядна, hsek, _kjin,
   {{0x637f01f4,0x66094487,0x6366002a,0x8a06058f}},	//   _këna, ksek, _cónx, езде,
   {{0x63a40657,0xcb070079,0x66094488,0x7d0502c2}},	//   _mjin, ريون_, jsek, bahs,
   {{0xe89438df,0xe29f0093,0xa93402ee,0x26dd0260}},	//   каль, naða_, текш, _agwo_,
   {{0xc30b00c8,0x6da3001f,0xa3c201c0,0x6d5c4489}},	//   ষ্টি_, _сира, ्गा_, _inra,
   {{0x9634448a,0x63a401cb,0x18970037,0x6609448b}},	//   вниц, _njin, عضوة_, fsek,
   {{0x940a00a8,0x98be0395,0xfaa3448c,0xe72f0833}},	//   əmək_, _bată_, _бато, صصي_,
   {{0x63a41845,0x3d190084,0x00000000,0x00000000}},	//   _ajin, _पाछे_, --, --,
   {{0x98be002d,0xbddb0107,0x63a40183,0xe52100ab}},	//   _dată_, _asèl, _bjin, _मारि_,
   {{0x69da448d,0x7d052acc,0x60de02a7,0x8afd0355}},	//   _hite, zahs, _agpm, _poři,
   {{0x69da448e,0x201801d7,0x2fd900e9,0x98be00af}},	//   _kite, erri_, _risg_, _fată_,
   {{0x69da448f,0x63a4030d,0x3eb90a8a,0x60de00f6}},	//   _jite, _ejin, _ryst_, _cgpm,
   {{0x69da4490,0xf1bf006c,0x3ebf00cd,0x5f9503e6}},	//   _mite, lták_, _šut_, вивт,
   {{0x63a400da,0x6d5c4491,0x657a4492,0x00000000}},	//   _gjin, _anra, lkth, --,
   {{0xa3e4017a,0x69da4493,0x442c055c,0x201801ed}},	// [3db0] _भूत_, _oite, ltd_, arri_,
   {{0x69da0f73,0x657a093a,0x6b800523,0x9f5100b5}},	//   _nite, nkth, _almg, tszó_,
   {{0x7d050a4e,0x628e011c,0x320b0067,0xf9910647}},	//   rahs, ćnoš, lscy_, یبت_,
   {{0x3f6703ad,0x69da0608,0x7d054494,0x3eb94495}},	//   _чтоб, _aite, sahs, _tyst_,
   {{0x69da4496,0xaa4500c3,0x3ebf01ba,0xd6e60033}},	//   _bite, телл, _áut_, নরায,
   {{0x69da4497,0x7f4d4498,0x2b4900cd,0x37e50033}},	//   _cite, ldaq, žac_, _নববর,
   {{0x69da0ce8,0xdb0b00c8,0x5ba70eb9,0xac95081b}},	//   _dite, logí, _зраз, _равш,
   {{0x7f4d0069,0x69da4499,0x70de0fbf,0x66094343}},	//   ndaq, _eite, _मल्ल, tsek,
   {{0x69da1599,0x6e2d449a,0x63bd027a,0x98be0160}},	//   _fite, ntab, dlsn, _pată_,
   {{0x6609449b,0x6e2d449c,0x63b6449d,0x69da449e}},	//   rsek, itab, _skyn, _gite,
   {{0x290719d4,0x64a5449f,0xc98444a0,0xd6ab00d1}},	//   mana_, тана, _сути, _کدام_,
   {{0x290744a1,0xe29a44a2,0x91e644a3,0x6e2d44a4}},	//   lana_, дам_, коме, ktab,
   {{0x69c803ad,0x6e2d009f,0xe29f0093,0x290744a5}},	//   _yhde, jtab, taða_, oana_,
   {{0x657a44a6,0x290744a7,0x6e2d44a8,0x6b830031}},	//   ckth, nana_, dtab, ëngj,
   {{0x201844a9,0xafe60036,0x29070952,0x442c00ee}},	//   urri_, тобл, iana_, ctd_,
   {{0x29073d6d,0x63a4002f,0x7e7600c3,0x645e0cc2}},	//   hana_, _ujin, tyyp, _špig,
   {{0x290744aa,0x6e2d02b3,0xdb0b283e,0xfce644ab}},	// [3dc0] kana_, gtab, gogí, возо,
   {{0x290744ac,0xa3da0067,0x00000000,0x00000000}},	//   jana_, ़दक_, --, --,
   {{0x290744ad,0x69da44ae,0xe6be0567,0x61e444af}},	//   dana_, _rite, _ऊर्ज, _huil,
   {{0x69da44b0,0x79810297,0x7bc901a6,0x6e2d01f7}},	//   _site, _allw, _cheu, btab,
   {{0x61e41010,0x290744b1,0x69da44b2,0xdb15006c}},	//   _juil, fana_, _pite, óbál,
   {{0x290744b3,0x644f0ae0,0x61e444b4,0x69da01e9}},	//   gana_, ācij, _muil, _qite,
   {{0x69da44b5,0x26c000d8,0x7bc90014,0x98a5010b}},	//   _vite, _šio_, _fheu, _dalį_,
   {{0x78ba0076,0xf1bf006c,0x798109a2,0x69da44b6}},	//   _vytv, tták_, _ellw, _wite,
   {{0x69da1090,0x290744b7,0xcf930bed,0xe3b90723}},	//   _tite, bana_, יטה_, ktır_,
   {{0x69da0a45,0x442c0345,0x3b040523,0xf1bf44b8}},	//   _uite, ttd_, _hemq_, rták_,
   {{0x9d1b0100,0x657a00da,0xe81900ab,0xf4863f96}},	//   וויט, rkth, _धिया_, тупн,
   {{0x61e444b9,0xc884037a,0x61ab012f,0xc7b800cc}},	//   _buil, ışı_, चक्ष, _cqđt_,
   {{0x61e444ba,0x81be0083,0x7ae0011e,0xe5343faf}},	//   _cuil, েদন_, _mgmt, _бель,
   {{0x61e4004a,0x657d00da,0xa3dd0324,0x3f8226be}},	//   _duil, ësht, _थूक_, _alku_,
   {{0xb33b0370,0x394c0c71,0x6e2d0159,0x00000000}},	//   ança, _mads_, wtab, --,
   {{0x29073aa0,0x6e2d44bb,0x61e4006b,0x3dca0103}},	//   zana_, ttab, _fuil, _ahbw_,
   {{0x290744bc,0x6ed60864,0x7bc944bd,0xdfd801d3}},	// [3dd0] yana_, _मृदु, _rheu, тър_,
   {{0x290744be,0xbbcb111a,0x224944bf,0x6e2d44c0}},	//   xana_, िष्क, _isak_, rtab,
   {{0x290744c1,0x9f410118,0x61e444c2,0x7bc9009e}},	//   vana_, _luhé_, _zuil, _pheu,
   {{0x290744c3,0x261302cb,0x777b01a3,0xdd03027b}},	//   wana_, _दिली_, xkux, ırın,
   {{0x290744c4,0xee8700c3,0x394c00ec,0x00000000}},	//   tana_, _рыно, _bads_, --,
   {{0x394c01f7,0x9aa40037,0xc27c00a5,0x29070183}},	//   _cads_, جمهو, ורדי, uana_,
   {{0x290744c5,0xdd9400c7,0x01380122,0x7bc944c6}},	//   rana_, _тары, דרות_, _theu,
   {{0x290744c7,0x394c44c8,0x386900cd,0x00000000}},	//   sana_, _eads_, ćar_, --,
   {{0x290744c9,0x394c0107,0x999f0024,0xdb0b01f7}},	//   pana_, _fads_, _kruż_, mogà,
   {{0x61e401e4,0x394c0029,0x61e2000d,0x8934186e}},	//   _ruil, _gads_, _éoli, _نعما,
   {{0x29050029,0x61e4006b,0x9f600055,0x00000000}},	//   _iela_, _suil, ërës_, --,
   {{0x290506d7,0x888c0070,0x637f01f4,0x00000000}},	//   _hela_, _קראַ, _dëno, --,
   {{0x224900f5,0x61e42ce4,0x290502ee,0x2d8344ca}},	//   _csak_, _quil, _kela_, _olje_,
   {{0x290544cb,0x61e444cc,0x869a0070,0x461200fd}},	//   _jela_, _vuil, _אינז, _اوور,
   {{0x290544cd,0xa5da0070,0x34390070,0x61e40051}},	//   _mela_, _אַהי, _טײַע, _wuil,
   {{0x61e41093,0x290544ce,0x8afd0355,0x128800fd}},	//   _tuil, _lela_, _mořs, _لمبی_,
   {{0x1fa744cf,0x733b0070,0xdd2c00c7,0x00000000}},	// [3de0] укти_, _טעקס, _vėži, --,
   {{0x290544d0,0x5bdc0096,0x00000000,0x00000000}},	//   _nela_, यद्व, --, --,
   {{0x661b44d1,0x2d8308b7,0xe1ff01ef,0x82360647}},	//   hruk, _dlje_, nxón_, _شرکا,
   {{0xd9cc44d2,0x09e644d3,0xa09b02b5,0x501b0122}},	//   ाष्ट, годн, _טייט, _אוטו,
   {{0xf1a900f8,0x2fc00532,0x394c44d4,0x8e760dec}},	//   _سایه_, mlig_, _pads_, _сунч,
   {{0x290544d5,0x661b44d6,0xfce30b7d,0x2b4d00d7}},	//   _cela_, druk, _горо, _eaec_,
   {{0x290544d7,0xdcfe00ea,0x6f0602a7,0x6d4e0103}},	//   _dela_, sipē, _kekc, _iaba,
   {{0x6d4e44d8,0xa3e70953,0x2fc00304,0xa61444d9}},	//   _haba, _बढ़_, nlig_, амич,
   {{0x6d4e44da,0xf1b6012f,0x29050093,0x03080066}},	//   _kaba, ृतान, _fela_, _वज़ह_,
   {{0x6d4e0614,0x1637004f,0x6f0644db,0x2fc00014}},	//   _jaba, اسية_, _lekc, hlig_,
   {{0x6d4e44dc,0xa81a0dc0,0x2fc044dd,0x2db70319}},	//   _maba, _ستار_, klig_, רלין_,
   {{0x6d4e44de,0x290506a2,0x66e60036,0x2fc044df}},	//   _laba, _zela_, _сода, jlig_,
   {{0x518744e0,0x2d9a01d5,0x2fc027fe,0x228420c3}},	//   гува, kipe_, dlig_, бург,
   {{0x22491912,0x94d40043,0xa4d4093e,0xe5a30f68}},	//   _vsak_, _колц, _колі, _личи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4e44e1,0x6f06012f,0x644a44e2,0xb4c232ea}},	//   _aaba, _cekc, _isfi, ्धी_,
   {{0x6d4e44e3,0x75ed00ee,0x224944e4,0x00000000}},	// [3df0] _baba, _kĺza, _usak_, --,
   {{0x6d4e1e77,0x31353aab,0x8d770fab,0x64580097}},	//   _caba, _теор, دارا, _krvi,
   {{0x6d4e38da,0x290544e5,0x6add0456,0x2fc044e6}},	//   _daba, _rela_, यश्र, blig_,
   {{0x29050d7c,0x645828c2,0x8f4720cc,0x7ae40187}},	//   _sela_, _mrvi, _сход, žitn,
   {{0x290500c9,0x6d4e44e7,0xb4c20354,0x66020024}},	//   _pela_, _faba, ्धु_, _nwok,
   {{0x6d4e44e8,0x2d8344e9,0x09af043b,0xc27c0070}},	//   _gaba, _ulje_, टवेय, ערגי,
   {{0xa3e40953,0x660244ea,0xc9840274,0x785c0160}},	//   _भूल_, _awok, ључи, _năvă,
   {{0x6d4e44eb,0x291b01c2,0x7f4f44ec,0x7d0744ed}},	//   _zaba, şqa_, _jacq, _hejs,
   {{0x6d4e44ee,0x290544ef,0x645844f0,0x7d073a29}},	//   _yaba, _tela_, _arvi, _kejs,
   {{0x6d4e0485,0x661b44f1,0x23600223,0x80bb03de}},	//   _xaba, rruk, _snij_, _शुभे,
   {{0xa8a744f2,0x645800cd,0x657d0055,0x00000000}},	//   _срак, _crvi, ëshq, --,
   {{0xe72e02e3,0x645844f3,0x7f4f07e5,0x661b0118}},	//   _ќе_, _drvi, _nacq, pruk,
   {{0x644a002a,0x2fc00307,0x3f8900e9,0x36d5005f}},	//   _esfi, vlig_, dhau_, _тодр,
   {{0x6f0608ef,0x7d07000c,0xbddb0107,0x80b10067}},	//   _sekc, _nejs, _erèz, _आँखे,
   {{0x6fb6017e,0x2fc034ae,0x99860009,0x637f0031}},	//   لمسا, tlig_, ntoš_, _mënj,
   {{0x6d4e0a12,0x43930431,0xa2ce0380,0x1fa70200}},	//   _saba, _мајс, _सरप्, акси_,
   {{0x0e6644f4,0x6d4e44f5,0x2fc00304,0x2d9a44f6}},	// [3e00] шкан, _paba, rlig_, tipe_,
   {{0x6d4e44f7,0x2fc044f8,0x645e09ca,0xbddb0107}},	//   _qaba, slig_, _ápic, _krèy,
   {{0x6d4e0006,0x3f8901e8,0x2d9a44f9,0x7d0702f0}},	//   _vaba, bhau_, ripe_, _dejs,
   {{0x6d4e44fa,0x2d9a0c1f,0xfbc315de,0x3f8944fb}},	//   _waba, sipe_, обхо, chau_,
   {{0x6d4e44fc,0x7ae40076,0x2d9a0602,0xa96a0009}},	//   _taba, žito, pipe_, кида_,
   {{0x2d9a00da,0x93bd002d,0x7d0744fd,0x66020027}},	//   qipe_, ntăr, _gejs, _rwok,
   {{0xdc67005f,0x7659001e,0x37aa0036,0xdca305ac}},	//   _кард_, _arwy, ктин_, _дари,
   {{0x765900e9,0x3f8000c7,0x443c023a,0x785c0160}},	//   _brwy, nkiu_, _rpv_, _răvă,
   {{0xd0fb0567,0x30fb07df,0x765900e9,0x7bc20355}},	//   ्रमण_, ्रमः_, _crwy, mlou,
   {{0x645802dd,0x7659001e,0x637f01f4,0x00000000}},	//   _prvi, _drwy, _gënj, --,
   {{0xe7df009a,0x2ec31556,0xb4c2035d,0xa2d90761}},	//   _पंचप, _शर्त, ्धे_, नेन्,
   {{0x6458219c,0x7659016e,0x660244fe,0x287b0277}},	//   _vrvi, _frwy, _twok, _שנאמ,
   {{0x776244ff,0xf1bf0fb5,0x00000000,0x00000000}},	//   _inox, ktát_, --, --,
   {{0x3f890090,0x443c4500,0xdcee00ee,0xa63b00a5}},	//   whau_, _tpv_, _bobč, _סגור,
   {{0x3f8902c7,0x7d074501,0x741400d2,0x443c01d7}},	//   thau_, _rejs, _اوبا, _upv_,
   {{0x61eb01ef,0x6e950210,0x764b016e,0x04db024b}},	//   _églo, бибу, _ysgy, _בקול,
   {{0x3f89001e,0x7d074502,0x6e24027a,0xea000023}},	// [3e10] rhau_, _pejs, guib, _đếm_,
   {{0x78ad0644,0x7bc201ef,0x00000000,0x00000000}},	//   şavi, elou, --, --,
   {{0x70550357,0x8c6706e4,0x637f01f4,0x7d074503}},	//   _انجا, штад, _nënk, _vejs,
   {{0x2d98027d,0x6e244504,0x09af057c,0x7bc20fce}},	//   _emre_, buib, टव्य, glou,
   {{0x6f0d00ec,0x7f3a02b5,0x2d8f00f7,0x6e244505}},	//   maac, _גערו, èges_, cuib,
   {{0x5d850180,0x6f0d013a,0x77620e8f,0x7bc22407}},	//   _السل, laac, _anox, alou,
   {{0xb4c2018d,0x7bc24506,0xe739061c,0xf1bf00fd}},	//   ्धो_, blou, гей_, ltás_,
   {{0x7bc20443,0x6d454507,0xa7652872,0x6f0d4508}},	//   clou, leha, скид, naac,
   {{0x6b830031,0x99864205,0xf1bf4509,0x7c250097}},	//   ëngu, stoš_, ntás_, luhr,
   {{0x27170028,0xc974004f,0x77620176,0x00000000}},	//   ển_, _والث, _enox, --,
   {{0x61f6450a,0x044500aa,0x6f0d450b,0x00000000}},	//   _styl, щенн, kaac, --,
   {{0x7659001e,0x03a61583,0x6d45450c,0x69c3450d}},	//   _trwy, симо, heha, llne,
   {{0x6d45450e,0xf66800d1,0xd29a01e0,0x00000000}},	//   keha, _نحوه_, утні_, --,
   {{0x9f5800de,0x7649450f,0xb227008d,0xf778009f}},	//   mpré_, mwey, _stæð, _ruħi_,
   {{0x64a24510,0x6d452aa1,0x7649030d,0x656302ce}},	//   _наша, deha, lwey, _innh,
   {{0x44254511,0x6e244512,0x13060274,0x93bd00af}},	//   mul_, tuib, _узим, stăr,
   {{0x442509eb,0x0d8607fa,0x00000000,0x00000000}},	// [3e20] lul_, блан, --, --,
   {{0x6d451892,0x44254513,0xbf2100b4,0x00000000}},	//   geha, oul_, यलॉन_, --,
   {{0x44254514,0x98a700d8,0x7bc20791,0x5177024b}},	//   nul_, menė_, tlou, _הגיב_,
   {{0xf1bf07f8,0x4425002d,0x916600e2,0x69c34515}},	//   stát_, iul_, _hồ_, elne,
   {{0x44254516,0x6d454517,0x6e244518,0x00000000}},	//   hul_, beha, quib, --,
   {{0x76490159,0x44254519,0x7c2502c2,0x7bc200b8}},	//   dwey, kul_, buhr, slou,
   {{0x6c860082,0x4425451a,0xa9671c56,0x307a0070}},	//   _الأم, jul_, сија_, טאַנ,
   {{0xf1bf016f,0x69c3451b,0x656300e9,0x35f42fd1}},	//   ntár_, alne, _annh, опир,
   {{0x7c3b012e,0xb4c2018d,0x35f700d1,0x00000000}},	//   _ćuri, ्ध्_, یرید_, --,
   {{0x4425451c,0x00000000,0x00000000,0x00000000}},	//   ful_, --, --, --,
   {{0x442504bd,0x224000bf,0x290e0987,0x7aed0cc1}},	//   gul_, _apik_, mafa_, žate,
   {{0xe29f008a,0x29c91111,0x7649073a,0x00000000}},	//   laði_, núan_, bwey, --,
   {{0x6d45451d,0x9166055c,0x00000000,0x00000000}},	//   yeha, _bồ_, --, --,
   {{0x4425451e,0x3d22004e,0xe29f0093,0x6f0d0054}},	//   bul_, मलों_, naði_, waac,
   {{0x44250012,0x6f0d08c7,0x6d4513dc,0x637f0055}},	//   cul_, taac, veha, _lëni,
   {{0x53a41b78,0x290e451f,0xc41700b5,0xaad90253}},	//   _најб, hafa_, _اغوا_, बेडक,
   {{0x6f0d013a,0xf1ab00d1,0x6d454520,0x63ad2fe8}},	// [3e30] raac, _ماده_, teha, _ijan,
   {{0xae1e0066,0x6f0d013a,0xf1bf00b5,0x2d8700a0}},	//   यंजन_, saac, rtás_, óne_,
   {{0x6d454521,0xe29f0093,0xf1bf2d03,0x00000000}},	//   reha, daði_, stás_, --,
   {{0x53c9051e,0x6d453a9f,0x23c919b7,0x637f0031}},	//   रतिश, seha, रतिद, _bëni,
   {{0x2bb1006a,0x44254522,0x6d454523,0xe29f008a}},	//   jące_, zul_, peha, faði_,
   {{0xe7ed007c,0xb4e700fa,0x637f01f4,0x63ad0009}},	//   _चंदा_, _भले_, _dëni, _ljan,
   {{0x645e0393,0xa3e40246,0x4425002d,0xa2d9035d}},	//   _špin, _भंग_, xul_, नेत्,
   {{0xe619204b,0x63ad4309,0x44254524,0xcb3402fb}},	//   ади_, _njan, vul_, _несъ,
   {{0x69c301ba,0x44254525,0x67294526,0x1bd400c3}},	//   plne, wul_, rgej, _хотя,
   {{0x44254527,0x63ad4528,0x290e08c6,0xae1e00be}},	//   tul_, _ajan, cafa_, यूटन_,
   {{0x61fd4529,0x63ad0024,0x6b89452a,0x92e50033}},	//   epsl, _bjan, _kleg, _পড়ে_,
   {{0x442509eb,0x39472172,0x00000000,0x00000000}},	//   rul_, lens_, --, --,
   {{0x4425452b,0x63ad452c,0x0cc60035,0x515603e6}},	//   sul_, _djan, _वर्म, отву,
   {{0x6b89452d,0x3947452e,0x4425452f,0x63ad227f}},	//   _lleg, nens_, pul_, _ejan,
   {{0x44254530,0x6b9b0273,0x05960594,0x7dd01ba3}},	//   qul_, _omug, _بانگ, näse,
   {{0x290e4531,0x82a600d4,0x944200b5,0x63ad0055}},	//   zafa_, _майж, _کھین, _gjan,
   {{0x1dc54532,0x7ae4024e,0x8fa30279,0x39470cd5}},	// [3e40] वतंत, žitk, фате, kens_,
   {{0x6b894533,0x39474534,0x7dd00328,0x637f01f4}},	//   _aleg, jens_, käse, _rëni,
   {{0x394703c1,0x29c92b83,0xdee6386a,0x6b894535}},	//   dens_, túan_, _мони, _bleg,
   {{0x39470345,0x6b894536,0x00000000,0x00000000}},	//   eens_, _cleg, --, --,
   {{0x39474537,0x290e4538,0xe29f0093,0xad263f25}},	//   fens_, tafa_, taði_, _ورسو,
   {{0x39474539,0x6b9b001c,0x637f0055,0x2d9e0225}},	//   gens_, _emug, _vëni, _öte_,
   {{0xe29f0093,0xb90207df,0xda0b0084,0x00000000}},	//   raði_, _नः_, सीबत_, --,
   {{0x6b89453a,0x290e4287,0xe29f008d,0x645e00ac}},	//   _gleg, safa_, saði_, _špio,
   {{0xbddb00f7,0xe29f0093,0x056a052c,0x85460421}},	//   _isèr, paði_, ајни_, оэне,
   {{0x3947453b,0x63ad00d4,0x2bb10067,0xf778007a}},	//   cens_, _sjan, rące_, _ruħu_,
   {{0xa3e40299,0x63ad003c,0x290c021d,0x09e30033}},	//   _भूख_, _pjan, _ieda_, _নৌকা,
   {{0xf7461303,0x290c31bd,0x9f420031,0x00000000}},	//   _федо, _heda_, _dikë_, --,
   {{0x290c00ab,0xe3b90095,0x753d006c,0xcb1300a5}},	//   _keda_, brın_, ősza, ולר_,
   {{0x290c1047,0x637f0031,0x398b008c,0x00000000}},	//   _jeda_, _nënv, _tøse_, --,
   {{0xcf9b0836,0x63ad453c,0xdfd51667,0xbddb0118}},	//   аја_, _tjan, зовы, _osèr,
   {{0x290c453d,0x5215453e,0x63ad453f,0x2d8a00af}},	//   _leda_, _едит, _ujan, _albe_,
   {{0x59ca0380,0x39474540,0x645a4541,0x2d8a00d5}},	// [3e50] ितार, yens_, lvti, _blbe_,
   {{0x6b894542,0x290c4543,0x63bd3e44,0x3947037d}},	//   _sleg, _neda_, losn, xens_,
   {{0x39474544,0x6b894545,0x61ed12ff,0xe1ff02d7}},	//   vens_, _pleg, _hual, lpó_,
   {{0x61ed06b3,0x63bd1851,0x39470173,0x2d8a4546}},	//   _kual, nosn, wens_, _elbe_,
   {{0x290c4547,0x61ed02c2,0x645e2676,0x7c3b0009}},	//   _beda_, _jual, _špil, _ćuru,
   {{0xa2ce0edf,0x35cf0084,0x3947053e,0x61e500b8}},	//   _सरस्, _सीढ़, uens_, _jihl,
   {{0x76420083,0x39470c7d,0x9d1809eb,0x6d550069}},	//   _apoy, rens_, _фост_, _iaza,
   {{0x6d554548,0x6b9b070b,0x3947038d,0x61ed1d69}},	//   _haza, _umug, sens_, _oual,
   {{0x6d554549,0x394701bf,0xd7060086,0x8f9c0070}},	//   _kaza, pens_, чные_, ייהי,
   {{0x6d551049,0xb998325e,0x9f4201f4,0xd83b0fa7}},	//   _jaza, _двух_, _pikë_, _вэд_,
   {{0x1b0e0083,0x3209454a,0xab5d0069,0xf1bf0138}},	//   _হাতে_, _away_, _ekże, tuán_,
   {{0x6d55454b,0x32090260,0x61ed09c3,0x61b40d34}},	//   _laza, _bway_, _bual, ंक्ष,
   {{0x61ed454c,0x673b0009,0x290c0183,0xe29f003e}},	//   _cual, mfuj, _yeda_, kaðu_,
   {{0x6d55454d,0x61ed454e,0x321e0187,0xa6e10093}},	//   _naza, _dual, čty_, öðug,
   {{0x320900e2,0x61e50069,0x7ae901ed,0x6143454f}},	//   _eway_, _dihl, _oget, эера,
   {{0x7ae900d1,0x09a80632,0x6d55046a,0x7ae4016f}},	//   _nget, _औद्य, _aaza, žiti,
   {{0x6d554550,0x0d863f96,0x69c14551,0xe29f008d}},	// [3e60] _baza, план, _okle, faðu_,
   {{0x6d554552,0x6e36010b,0x637f01f4,0xf1bf0187}},	//   _caza, rtyb, _dënu, nuál_,
   {{0x290c4553,0xb33b4554,0x0b464555,0xdca32aff}},	//   _reda_, liça, знен, нафи,
   {{0x261c0953,0x290c0ccf,0x69c10103,0x7d010395}},	//   _मिली_, _seda_, _akle, _pârâ,
   {{0x6f044556,0x290c02ee,0x6d670098,0x00000000}},	//   mbic, _peda_, áraí, --,
   {{0x64434557,0x7ae94558,0xe7ed0066,0x290c0024}},	//   _opni, _eget, _चूहा_, _qeda_,
   {{0x8c434559,0x290c455a,0xd90d00bf,0xf7720e6b}},	//   _пере, _veda_, شین_, فاظ_,
   {{0x69c10723,0x6d55455b,0x290c05ca,0x7d0e455c}},	//   _ekle, _zaza, _weda_, _hebs,
   {{0x6d55455d,0x290c455e,0x657801e8,0x6443455f}},	//   _yaza, _teda_, _povh, _apni,
   {{0x61eb00f7,0x6d5500a8,0x7d0e008c,0xb33b0183}},	//   _égli, _xaza, _jebs, diça,
   {{0x61ed4560,0x6e240644,0x363300f8,0xbddb00e0}},	//   _sual, hrib, وریس, _opèn,
   {{0x637f00da,0x61ed012f,0x60c50086,0x6e244561}},	//   _nënt, _pual, _ryhm, krib,
   {{0x61ed4562,0x63bd4563,0x1dbe143a,0xe29800d8}},	//   _qual, rosn, ्तात, заў_,
   {{0xbddb01f7,0x26c600e0,0x27e64564,0x7d0e02b1}},	//   _apèn, _iyoo_, _hion_, _nebs,
   {{0x6d55438c,0x637f01f4,0x63bd4565,0xe29f008e}},	//   _raza, _bënt, posn, vaðu_,
   {{0x61ed4566,0x6e2402d7,0x4fc44567,0xb33b0183}},	//   _tual, frib, есуа, biça,
   {{0x6d554568,0x27e609c3,0x2bb1004e,0x6e241e33}},	// [3e70] _paza, _mion_, jąca_, grib,
   {{0x6d5501c2,0x60c500c3,0x27e62e8a,0x00000000}},	//   _qaza, _tyhm, _lion_, --,
   {{0x6d55210b,0x645e011c,0x7dd002b1,0xe29f003e}},	//   _vaza, _špij, wäsc, raðu_,
   {{0x69c14569,0x6d552f59,0x6e24009e,0x27e601d7}},	//   _skle, _waza, brib, _nion_,
   {{0x6e24456a,0x6d55456b,0x26c6456c,0x2fc9456d}},	//   crib, _taza, _nyoo_, mlag_,
   {{0xd90f00f5,0x2fc9456e,0x992b0421,0x00000000}},	//   ایا_, llag_, сюда_, --,
   {{0x2369326f,0x27e60485,0x26c600e0,0xdcf50260}},	//   _onaj_, _bion_, _ayoo_, _jozč,
   {{0x27e626c9,0x2fc903c1,0x69c10067,0x7d1c0116}},	//   _cion_, nlag_, _wkle, _zdrs,
   {{0xa3c30907,0x6f0f456f,0x645c4570,0x660410ff}},	//   ्तन_, _mecc, ærin, _çikl,
   {{0x6f0f3433,0x69c100c5,0x2fc901ae,0x3915103b}},	//   _lecc, _ukle, hlag_, _آواز,
   {{0x637f00da,0x27e62459,0x7d050874,0xa34a0227}},	//   _nëns, _fion_, ibhs, озна_,
   {{0x22523a29,0xf2a61a55,0x00000000,0x00000000}},	//   _psyk_, димп, --, --,
   {{0xe2970f99,0x6e24013b,0x00000000,0x00000000}},	//   дая_, xrib, --, --,
   {{0x6f1d1d58,0x27e606a2,0xb33b021d,0x00000000}},	//   _adsc, _zion_, riça, --,
   {{0x2fc9008c,0x6f0f0502,0x91e32626,0x14d108b0}},	//   flag_, _becc, торе, _हरिण,
   {{0x6f0f0676,0x6e244571,0x7d0e0103,0x201e011c}},	//   _cecc, trib, _sebs, štio_,
   {{0x6f044572,0x26c601a9,0x0eaa00d8,0xa2a5021a}},	// [3e80] rbic, _xyoo_, цкай_, _चेप्,
   {{0x2369003a,0x6f044573,0x6e2435f9,0x4d47002d}},	//   _znaj_, sbic, rrib, мпун_,
   {{0x2fc930bc,0x5f06280a,0x51f60493,0x6c4a0041}},	//   blag_, _озна, _عسکر, تلاف_,
   {{0x6e243b34,0x7d050037,0x5aca03e6,0x645e1f45}},	//   prib, abhs, олем_, _špik,
   {{0x6e24013b,0x25be02d7,0x7d0e0298,0x27e6081b}},	//   qrib, yotl_, _tebs, _rion_,
   {{0x2fc0004f,0x6f0f07e5,0x27e6123d,0x00000000}},	//   loig_, _zecc, _sion_, --,
   {{0xa3c3035d,0xa2a53933,0x19b9010b,0x4b260037}},	//   ्तम_, _चेन्, чуць_, _يعرف,
   {{0x1dbe06fe,0x97a31397,0xb605023a,0x00000000}},	//   ्तवत, крыл, _odšč, --,
   {{0xa3d2046c,0x00000000,0x00000000,0x00000000}},	//   वतन_, --, --, --,
   {{0x26c608c7,0x00000000,0x00000000,0x00000000}},	//   _vyoo_, --, --, --,
   {{0x291e2a13,0x88814574,0x27e64575,0x00000000}},	//   _idta_, _میون, _tion_, --,
   {{0xdcf50097,0xc6a61b50,0x00000000,0x00000000}},	//   _rozč, _орли, --, --,
   {{0x44254576,0xf207036c,0x00000000,0x00000000}},	//   arl_, ьяно, --, --,
   {{0x6f0f25ac,0x9583027a,0x398b008c,0x00000000}},	//   _secc, _илче, _løsn_, --,
   {{0x6f0f4577,0x656a004f,0x40340c5a,0x00000000}},	//   _pecc, _infh, керс, --,
   {{0x442c4578,0x9df90674,0x00000000,0x00000000}},	//   mud_, знат_, --, --,
   {{0x442c4579,0x6f0f01d3,0x2dd5002d,0xb33b0392}},	// [3e90] lud_, _vecc, ежар, liço,
   {{0x3a26081f,0x2fc9457a,0x6da40274,0xeca71d77}},	//   drop_, slag_, виђа, мјен,
   {{0x442c457b,0x2fc9457c,0x6f0f0987,0x00000000}},	//   nud_, plag_, _tecc, --,
   {{0x09b901d1,0xad9b2cd2,0x61fb00af,0x291e00fd}},	//   ेत्य, _stúd, ţulu, _adta_,
   {{0xa9690431,0xdbdc003e,0x27fe0210,0x1dbe00b4}},	//   зила_, ráðn, _attn_, ्तशत,
   {{0x442c457d,0xdb0b0037,0x7dd001ff,0x6e2d457e}},	//   kud_, ingé, läsn, muab,
   {{0x442c457f,0x1dbe00b8,0xb8f70ed1,0x6e2d024b}},	//   jud_, ्तरत, _सर_, luab,
   {{0x442c007c,0xa2f902e4,0x656a009e,0xd7f800e2}},	//   dud_, ंडोज_, _anfh, _trăn_,
   {{0x6e2d0b06,0x7afb37e2,0x00000000,0x00000000}},	//   nuab, _ifut, --, --,
   {{0x7bcb4580,0x44250185,0x20fb364c,0xe5710037}},	//   llgu, trl_, ्रोश_, اطة_,
   {{0x4425009e,0x5f1202b4,0x442c4581,0xd4690274}},	//   url_, तरम्_, gud_, чине_,
   {{0x6b994582,0x7f4d021d,0x7853013b,0x00000000}},	//   _çagı, jeaq, _nəvə, --,
   {{0x44252c7b,0xaefb01da,0x442c00f6,0x7afb4583}},	//   srl_, _gnùi, aud_, _mfut,
   {{0x442c4584,0x201e011c,0x442508b7,0x6e2d08b0}},	//   bud_, štim_, prl_, duab,
   {{0xa06703fa,0x1beb13ab,0x2bb10035,0x75d211c0}},	//   нара_, _जंगल_, jąco_, _حيوا,
   {{0x3f89005d,0x25a54585,0xdb0000f6,0x00000000}},	//   gkau_, lill_, _emmê, --,
   {{0x63a620fb,0x78530095,0x4d66010b,0x2fc01da5}},	// [3ea0] mikn, _dəvə, нкав, roig_,
   {{0x63a64586,0x25a54587,0x7dc60105,0x69a400dc}},	//   likn, nill_, رقان, _औषधी,
   {{0xa0a6021d,0x10a600d4,0x98a700c7,0x00000000}},	//   _чанд, _чинн, denį_, --,
   {{0x63a6024e,0x6e2d184c,0x3f894588,0x00000000}},	//   nikn, buab, ckau_, --,
   {{0x6f6303ad,0x25a5008a,0xa3c3021a,0xf1bf0300}},	//   _связ, kill_, ्तत_, irán_,
   {{0xdca60b6b,0xf1bf004f,0x442c4589,0x6f160225}},	//   _заги, hrán_, yud_, layc,
   {{0x442c0095,0xfdbe0035,0x3a260009,0x25a5458a}},	//   xud_, ्तीफ, srop_, dill_,
   {{0x9fb80187,0x442c03c1,0x637f0055,0x00000000}},	//   _očí_, vud_, _nënp, --,
   {{0xf1bf0033,0x63a63d5e,0x56940409,0x442c01cb}},	//   drán_, dikn, тапт, wud_,
   {{0x442c1d78,0x25a5458b,0x6286458c,0x38c804e8}},	//   tud_, gill_, dyko, _قاضی_,
   {{0x46ea00c9,0x63a6458d,0x3e5202d0,0xf1bf0300}},	//   _еден_, fikn, _lņt_, frán_,
   {{0x442c458e,0xf1bf0037,0x63a6028b,0x394e012f}},	//   rud_, grán_, gikn, lefs_,
   {{0x442c458f,0x6f164590,0x3e52021e,0xd244002d}},	//   sud_, dayc, _nņt_, лэри,
   {{0x442c4591,0xf1bf4592,0x63a60223,0x00000000}},	//   pud_, arán_, aikn, --,
   {{0xc4f70779,0xf1bf3037,0x3f6718e2,0x104801e0}},	//   _אזוי_, brán_, нтаб, няти_,
   {{0x6e2d4593,0xf1bf02d7,0x62860051,0x394e1bb3}},	//   tuab, crán_, byko, hefs_,
   {{0x28a7009a,0x82640312,0x3f89010b,0xe3b00bf5}},	// [3eb0] _केनि, _مهين, rkau_, _درو_,
   {{0x224901cc,0x3f894594,0xfd100037,0x2ca701ef}},	//   _ipak_, skau_, مجم_, úndo_,
   {{0x6f160250,0x7853013b,0x00000000,0x00000000}},	//   bayc, _təvə, --, --,
   {{0xa3c300b1,0x28c40461,0x501a00a5,0x2bb10067}},	//   ्ति_, _लुधि, _קורו, rąco_,
   {{0x2fd9012f,0x5edf0033,0x6e2d2939,0x00000000}},	//   _ihsg_, _ফ্রে, quab, --,
   {{0x63a64595,0xf2d40070,0x7dcb00ab,0xd94510bb}},	//   zikn, נעס_, küsi, теки,
   {{0xa3c30355,0x62864596,0x48fd012f,0xf8ae1a95}},	//   ्ता_, zyko, रुषो_, يکم_,
   {{0x25a54597,0x9ff30083,0xf7712ac4,0x7afb023c}},	//   will_, _জবাব_, شاب_, _ufut,
   {{0xe80d0992,0x63a64598,0x99554599,0x25a52762}},	//   _सबका_, vikn, _икац, till_,
   {{0x88e30033,0xb46501e0,0x62863383,0x00000000}},	//   নুষক, вкол, vyko, --,
   {{0x232a097b,0x63a60ce8,0x20010221,0x2249459a}},	//   мони_, tikn, _nthi_, _apak_,
   {{0xf8ae0088,0x62860f86,0x53a6034b,0x00000000}},	//   _بکه_, tyko, тамб, --,
   {{0x63a6128f,0x25a5459b,0x2001030d,0x479a0070}},	//   rikn, pill_, _athi_, _קינס,
   {{0x412a02ce,0x63a6459c,0x628615bc,0xdb00000d}},	//   ього_, sikn, ryko, _emmè,
   {{0x212102d7,0x69c30065,0x3e520107,0x00000000}},	//   _ddhh_, ione, _sņt_, --,
   {{0x7e6903c9,0x626618ea,0xe4e400d4,0x3e520260}},	//   _šepa, _авиа, _січн, _pņt_,
   {{0x63a4459d,0x69c3459e,0xee3a1142,0x59c100b4}},	// [3ec0] _imin, kone, ьна_, शकार,
   {{0x69c302ce,0xdb000248,0xa37b0183,0x3e520107}},	//   jone, _immé, rmõe, _vņt_,
   {{0xe7ed0066,0x63a4459f,0x69c345a0,0xa7fc0225}},	//   _चंगा_, _kmin, done, _arın,
   {{0xa3d2052f,0x09ca1bb5,0x661b2933,0x6a860166}},	//   वति_, ित्य, ksuk, клеа,
   {{0xaefb009e,0x7bc201ef,0x63a40103,0x2a36002d}},	//   _cnùu, roou, _mmin, тэер,
   {{0x3990009e,0x661b45a1,0x00000000,0x00000000}},	//   _bàsa_, dsuk, --, --,
   {{0xa3d20a44,0x6da30cd0,0x6d5c03c0,0x63a445a2}},	//   वता_, _тира, _iara, _omin,
   {{0x6d5c45a3,0x6d5e45a4,0x368a09cc,0x63a40159}},	//   _hara, ldpa, дсон_, _nmin,
   {{0x6d5c45a5,0x69c3203d,0x3c3c07c0,0x201e042a}},	//   _kara, bone, lív_, štih_,
   {{0x63a445a6,0x69c345a7,0x55740be8,0x00000000}},	//   _amin, cone, угот, --,
   {{0x92af12eb,0x6d5c45a8,0x19b900c3,0x6b800345}},	//   _করে_, _mara, _чуть_, _komg,
   {{0x6d5c45a9,0x661b0feb,0x7d170be2,0x00000000}},	//   _lara, bsuk, zaxs, --,
   {{0x2bb30324,0x86c300f8,0x63a43c77,0x672205f5}},	//   ंचता, _پيون, _dmin, _idoj,
   {{0x63a445aa,0xe5a30009,0x7c3e1b04,0x6602023c}},	//   _emin, _кичи, ktpr, _itok,
   {{0x25ab0248,0xdb1b0019,0xa5bd00c7,0xdb0000a2}},	//   ècle_, _khuô, krųj, _emmé,
   {{0x69c345ab,0x6d5c0269,0x63a4004e,0x2249012f}},	//   zone, _aara, _gmin, _tpak_,
   {{0x6d5c04fb,0x6d5e0120,0x93b800a5,0x00000000}},	// [3ed0] _bara, fdpa, _שלחו_, --,
   {{0x6d5e0009,0x7c3e3942,0x71750037,0x5c0745ac}},	//   gdpa, ftpr, _إهدا, вяда,
   {{0x6d5c45ad,0x69c345ae,0x7d170510,0x26190387}},	//   _dara, vone, raxs, _मौनी_,
   {{0x660245af,0x69c345b0,0x443e2129,0xff043da5}},	//   _otok, wone, itt_, _вярн,
   {{0x6d5c0a12,0xa3ab0825,0x6602251e,0x443e00e2}},	//   _fara, _गगन_, _ntok, htt_,
   {{0x6d5c35f9,0x645845b1,0x644a08c8,0x69da0355}},	//   _gara, _osvi, _opfi, _chte,
   {{0x7c3e0223,0x92af0033,0x660245b2,0xc17432e3}},	//   ctpr, _করো_, _atok, יחס_,
   {{0xdb1b01a5,0x69c345b3,0x6b800345,0x69da00be}},	//   _chuô, sone, _gomg, _ehte,
   {{0x6d5c45b4,0x7f5d45b5,0x443e45b6,0xcf9400a5}},	//   _yara, _masq, ett_, יטק_,
   {{0x6d5c45b7,0x63a445b8,0x69da3b23,0xdb0b0079}},	//   _xara, _smin, _पीपी, ingí,
   {{0xc98402c4,0x661b45b9,0x66020103,0x98c700af}},	//   _тути, ssuk, _etok, _рсал,
   {{0x7981016e,0x7f5d01f7,0xdcfc009f,0x00000000}},	//   _holw, _nasq, _porċ, --,
   {{0x6d4745ba,0x69da0d36,0x1545440d,0x798145bb}},	//   _obja, _yhte, _белм, _kolw,
   {{0xf65200a5,0xdcee007e,0x00000000,0x00000000}},	//   _לצד_, _době, --, --,
   {{0x63a445bc,0x7c3e45bd,0xb18400b8,0x3fc800fd}},	//   _tmin, xtpr, šťov, ندری_,
   {{0x63a445be,0x6d4745bf,0x7f5d45c0,0x79810103}},	//   _umin, _abja, _casq, _lolw,
   {{0x7d1545c1,0x261600dc,0x0e6600d8,0x6b800139}},	// [3ee0] _bezs, पीपी_, ыкан, _romg,
   {{0x6d5c01c2,0x3c3c45c2,0x798145c3,0x7c3e45c4}},	//   _qara, tív_, _nolw, ttpr,
   {{0x6d5c0f6b,0x315700c2,0x0c2645c5,0x8fa645c6}},	//   _vara, _גיין_, умен, _бане,
   {{0x6d5c45c7,0x69da071f,0x207b02b5,0xeb9745c8}},	//   _wara, _shte, _נאכא, лих_,
   {{0x6d5c45c9,0x8e750210,0x798145ca,0xdcfc148a}},	//   _tara, _курч, _bolw, _horč,
   {{0xdd9233cc,0xdcfc3f23,0x443e2e40,0x6d5c45cb}},	//   _اوس_, _korč, ytt_, _uara,
   {{0x3f8245cc,0x6b8045cd,0x764b010b,0x798100e5}},	//   _koku_, _tomg, _apgy, _dolw,
   {{0x3f820086,0xf09300a5,0xdcfc0097,0x7f4445ce}},	//   _joku_, מנו_, _morč, nfiq,
   {{0x09360125,0xa91c01ba,0x3f82004b,0xeb970384}},	//   _مراج, _voľb, _moku_, _сит_,
   {{0xa2a50864,0xaa93004f,0x79814224,0x3f8245cf}},	//   _चेष्, _الكث, _golw, _loku_,
   {{0x443e34b7,0xdb1b00e2,0xdb0200d5,0x94d43a7e}},	//   utt_, _thuô, dnoú, ронц,
   {{0xd4970012,0xdb0900da,0x3f820103,0x7dcb013b}},	//   урь_, _vjeç, _noku_, lüst,
   {{0x6602325a,0x7f5d0176,0x395e00b9,0x00000000}},	//   _utok, _rasq, _kats_, --,
   {{0xdcfc02c4,0x365b00a5,0xad9b01ef,0x7e64005f}},	//   _borč, _נכונ, _atún, dvip,
   {{0x6ab03914,0x7f5d45d0,0x3f8245d1,0x4395010b}},	//   जपुर, _pasq, _boku_, _вайс,
   {{0x29c900fb,0x998600b8,0x395e45d2,0xe1f002fd}},	//   núar_, spoň_, _lats_, _کسي_,
   {{0xaaa4000c,0x61f6139b,0x7f5d45d3,0x3f8245d4}},	// [3ef0] _खेलक, _guyl, _vasq, _doku_,
   {{0x442c201e,0x7bc903bc,0x7bdb01e9,0x00000000}},	//   ord_, _skeu, _shuu, --,
   {{0x7f5d0443,0xdcfc01a0,0x70fa00a5,0x7dcb027d}},	//   _tasq, _gorč, _בהתח, düst,
   {{0x442c184f,0x6ab000ab,0x798100fe,0xd7f80139}},	//   ird_, जपूर, _solw, _grăi_,
   {{0x6f0d4322,0xfe3502b5,0x798132b2,0xee870f99}},	//   mbac, _דאָך_, _polw, _сыно,
   {{0x6f0d45d5,0x395e024b,0x940a00a8,0x00000000}},	//   lbac, _cats_, şmək_, --,
   {{0x7981152b,0x6f0d1d22,0x3f82317e,0x00000000}},	//   _volw, obac, _yoku_, --,
   {{0x2d8300c9,0xf6250948,0x6f0d45d6,0x76250009}},	//   _hoje_, адио, nbac, амиз,
   {{0x2d831254,0xe61645d7,0x442c06ba,0xbb84004f}},	//   _koje_, ады_, erd_, _القي,
   {{0x2b5f006d,0x395e45d8,0xb8db0033,0x6e2d45d9}},	//   _hauc_, _gats_, _ঘর_, irab,
   {{0xa3c3022e,0x04453121,0x7dcb01ae,0x645e02b2}},	//   ्तं_, шенн, lüss, _špir,
   {{0x6e2d45da,0x2d8345db,0x62660439,0xf1bf1534}},	//   krab, _loje_, авма, brák_,
   {{0x3f821298,0x69da02e4,0x442c45dc,0xf1aa0d47}},	//   _roku_, _पीडी, ard_, ناسه_,
   {{0x660945dd,0x6e2d45de,0x48dc000c,0xdcfc0009}},	//   mpek, drab, गेको_, _porč,
   {{0x6f0d45df,0x0cb00083,0x64a21126,0xc0e645e0}},	//   fbac, _কর্ত, _маша, ровк,
   {{0xa3c30bad,0x64411b04,0x25a70124,0xb4c10067}},	//   ्तः_, mtli, _hmnl_, ंथी_,
   {{0x2d8345e1,0x644101ae,0x660945e2,0xf77200a5}},	// [3f00] _boje_, ltli, npek, חקן_,
   {{0x644103bc,0x27ef45e3,0xe3b9027d,0xd24f00d1}},	//   otli, _lign_, brıs_, _کنی_,
   {{0x644145e4,0x3f820202,0xed5745e5,0x2d830031}},	//   ntli, _toku_, рох_, _doje_,
   {{0x644145e6,0xdb0b0279,0x6e2d409a,0x395e09e1}},	//   itli, ligê, brab, _sats_,
   {{0x395e1638,0x2360006d,0x6441393f,0x2d83005f}},	//   _pats_, _maij_, htli, _foje_,
   {{0x644145e7,0x236001e8,0x442c45e8,0x2d830031}},	//   ktli, _laij_, yrd_, _goje_,
   {{0x7dcb45e9,0x6609010d,0x644102c4,0x26cf008c}},	//   rüst, epek, jtli, _aygo_,
   {{0xf1bf18fa,0x2360006d,0x7dcb007c,0xa91c07c0}},	//   nuár_, _naij_, süst, _doľa,
   {{0xd6d745ea,0x644145eb,0x00000000,0x00000000}},	//   ить_, etli, --, --,
   {{0x64411949,0x80f50a40,0x6f0d011c,0x356a2f7c}},	//   ftli, _आलेख_, zbac, трин_,
   {{0x442c0120,0x660908dd,0x98a505f9,0xf1bf00b5}},	//   urd_, apek, _falı_, lság_,
   {{0x236001a9,0x291c45ec,0x26cf0a8a,0x00000000}},	//   _caij_, lava_, _fygo_, --,
   {{0x9f4203ad,0x64412197,0x48fd000c,0xf1bf00b5}},	//   _mikä_, atli, रुको_, nság_,
   {{0x442c00d5,0x6e2d45ed,0x98a500a8,0xe9ff00e2}},	//   prd_, vrab, _zalı_, nhạc_,
   {{0x64410051,0x6ad32893,0x1fa7005f,0xddcd0067}},	//   ctli, _तर्र, араг, ywał,
   {{0xcf980500,0x6e2d1292,0x291c45ee,0xa3d21bb5}},	//   ају_, trab, hava_, वतः_,
   {{0xd7f80139,0xd13200ff,0x2d832801,0x00000000}},	// [3f10] _luă_, _کمپ_, _poje_, --,
   {{0x291c02dd,0x6f0d45ef,0x6e2d45f0,0x2b5f00ea}},	//   java_, sbac, rrab, _sauc_,
   {{0x201e0355,0x2fd200e9,0x2d8300f4,0x00000000}},	//   átit_, blyg_, _voje_, --,
   {{0x6e2d45f1,0x236001e8,0x3a75262e,0xdcfc00d5}},	//   prab, _xaij_, йлер, _forď,
   {{0xeab00c74,0x201e45f2,0x2d8300c7,0x7f7600a5}},	//   وعه_, štit_, _toje_, _הערב_,
   {{0x27ef45f3,0x9f4203ad,0x98a5027d,0xa91c07c0}},	//   _sign_, _eikä_, _salı_, _poľa,
   {{0x7c950082,0x6c850c9e,0x644145f4,0xa2ce0ea3}},	//   _الأص, _الزم, xtli, _धुन्,
   {{0x5ba41470,0x9f970310,0x00000000,0x00000000}},	//   _друз, nçà_, --, --,
   {{0x291c2018,0x6f0201ef,0x00000000,0x00000000}},	//   bava_, ñoci, --, --,
   {{0x291c45f5,0x660945f6,0x644145f7,0x660d0225}},	//   cava_, rpek, ttli, _çakm,
   {{0x74ca0266,0x644145f8,0x9f580098,0x84580382}},	//   _सुदृ, utli, rprú_, арят_,
   {{0x644145f9,0x236001e8,0x66092182,0xdcfc00ea}},	//   rtli, _qaij_, ppek, _morā,
   {{0x66052264,0x80cd00b4,0x0cd4162b,0x00000000}},	//   _упла, _दुबे, _थर्म, --,
   {{0x637f01d2,0x910302fb,0x8459021d,0x00000000}},	//   _mëny, зпре, _брит_, --,
   {{0xdcfc0029,0x236001e8,0x00000000,0x00000000}},	//   _norā, _taij_, --, --,
   {{0xd00f0041,0x291c45fa,0x2d8745fb,0xe4d20af8}},	//   علق_, zava_, önen_, _عقيد,
   {{0xa3bd0299,0xdd8f0416,0xea000023,0x67c100ea}},	// [3f20] _आदत_, کول_, _đắm_, mējd,
   {{0x201e0370,0x291c45fc,0x627b0317,0xe3b9045e}},	//   átis_, xava_, _ענינ, nsın_,
   {{0x26190084,0xbddb021e,0x6ab01579,0xcb6a0200}},	//   _मौसी_, _apès, जप्र, лаже_,
   {{0xf3f900c8,0x201e00d8,0x00000000,0x00000000}},	//   _আবার_, štis_, --, --,
   {{0xe3b9033e,0xc6b20033,0x00000000,0x00000000}},	//   ksın_, _চর্চ, --, --,
   {{0x7d960037,0x5d860037,0xfce62a21,0x82d7016b}},	//   _السؤ, _الآل, _гого, זונג_,
   {{0xf1bf006c,0xc86602fb,0x00000000,0x00000000}},	//   sság_, стли, --, --,
   {{0xbb4303ad,0x7d1e1eb8,0xf76f01b2,0xba1a00b5}},	//   _неск, laps, فاً_, _ميرا_,
   {{0xd6d0004f,0xf66a45fd,0xd7f80139,0x3ea045fe}},	//   بقة_, احبه_, _arăt_, nzit_,
   {{0x7d1e45ff,0x8afd00b8,0x39994600,0x00000000}},	//   naps, _vaře, _pèse_, --,
   {{0xf4840987,0x5fc80266,0x07a60bfe,0x2ed501c0}},	//   زادی, लवाल, _лажн, _दर्त,
   {{0xc7f70122,0x69ca1167,0x7d1e1a43,0x08770070}},	//   _הזאת_, lofe, haps, _לעבט_,
   {{0xf6d6132d,0x7d1e40b7,0x2bc901c0,0x00000000}},	//   _ازاد, kaps, िकता, --,
   {{0x645c4601,0x00000000,0x00000000,0x00000000}},	//   æris, --, --, --,
   {{0xbddb000d,0x251b025a,0xd5b8013a,0x00000000}},	//   _opèr, _גווא, mnā_, --,
   {{0xa3bd3123,0x69da02e4,0x69ca4602,0xd5b800ea}},	//   _आदि_, _पीसी, hofe, lnā_,
   {{0x63af0c4b,0x88bc00b8,0x59ba0d41,0xa91c07c0}},	// [3f30] micn, _sděl, ेवार, _roľn,
   {{0x63af2802,0xa3c300fa,0x3209067f,0xd5b802d4}},	//   licn, ्तक_, _itay_, nnā_,
   {{0xa91c01ba,0xdb0b4603,0xbddb0118,0xc8a7073f}},	//   _poľn, ligé, _spès, _केंट,
   {{0x63af1e85,0xeab100b5,0xe3b901fb,0x398b1217}},	//   nicn, وٹا_, zsın_, _løst_,
   {{0x7f3a00c2,0xa91c016f,0x0e0800af,0x784a00a8}},	//   _דערו, _voľn, _гэси_, _rəva,
   {{0xa96905c0,0x69ca4604,0x386c0a8a,0x00000000}},	//   рика_, gofe, _brdr_, --,
   {{0x88bc01c0,0x26160026,0xa3d900ab,0x77624605}},	//   _uděl, पीसी_, ऽता_, _baox,
   {{0x6d574606,0xd5b800ea,0xc864027a,0x91f9074f}},	//   lexa, enā_, ятчи, ंदाज_,
   {{0x7bcb4607,0x3b7800af,0x00000000,0x00000000}},	//   mogu, _уйтэ_, --, --,
   {{0x7bcb4608,0x6d570621,0x69ca01ef,0x74ca022e}},	//   logu, nexa, cofe, _सुहृ,
   {{0xe3ba03ad,0x32094609,0xb8590c74,0xe3b9033e}},	//   ибо_, _atay_, _خلاص_, rsın_,
   {{0x3ce10755,0x6d570e8f,0x7dd0460a,0x63af460b}},	//   _करने_, hexa, läst, gicn,
   {{0xd7c80118,0x63bd02d7,0x00000000,0x00000000}},	//   _اونه_, érna, --, --,
   {{0xdcfc0160,0x6d570051,0x7dd0460c,0x00000000}},	//   _moră, jexa, näst, --,
   {{0x7bcb007c,0x2b4d053d,0x63af012e,0xfbc901c0}},	//   kogu, _obec_, bicn, िकाम,
   {{0x673b0097,0x3ea000d7,0x6563460d,0x20053e90}},	//   nguj, tzit_, _hanh, ília_,
   {{0x2a6d01e8,0x6563460e,0x3f99010d,0x7d1e460f}},	// [3f40] _nreb_, _kanh, _dlsu_, taps,
   {{0x5bd20ed1,0x3ea001f4,0x2b4d007e,0x00000000}},	//   तत्व, rzit_, _abec_, --,
   {{0x7d1e4610,0x65631c1d,0x7bcb0987,0x6f1f013b}},	//   raps, _manh, fogu, baqc,
   {{0x29054611,0x53ca012f,0xe8000035,0x65634612}},	//   _afla_, रविश, _लंबा_, _lanh,
   {{0x394c028b,0x79c600d8,0x656300cc,0xdcfc0160}},	//   _pbds_, ойдз, _oanh, _coră,
   {{0x082a2784,0x6e244613,0xf8064614,0x291a4615}},	//   ации_, msib, очин, úpa_,
   {{0x69ca038d,0x23ca04eb,0x7d1c32c5,0x6d4e035f}},	//   rofe, रवाद, _iers, _ibba,
   {{0x65634616,0x69ca4617,0x29050093,0x7e690207}},	//   _aanh, sofe, _efla_, _šepi,
   {{0x7d1c4618,0x65630370,0xda6600f8,0x2a6d0b3e}},	//   _kers, _banh, _بازي, _greb_,
   {{0x48e64619,0x7dd0461a,0x6563461b,0x6e24461c}},	//   _дозв, mäss, _canh, isib,
   {{0x2cfb0100,0x7d1c461d,0x63af0881,0x7dd0461e}},	//   יליא, _mers, ticn, läss,
   {{0x6e24461f,0x6f042513,0x6b824620,0x7d1c01ef}},	//   ksib, jcic, njog, _lers,
   {{0x7d1c4621,0xf1bf033a,0x63af07e7,0x7dd04622}},	//   _oers, krát_, ricn, näss,
   {{0x65630370,0xd24e0580,0xc87e0095,0x628f0027}},	//   _ganh, اچي_, şğul_, ryco,
   {{0x34940714,0x63af0124,0x3f8703e6,0x7bcb1766}},	//   _хайр, picn, оѓаа, yogu,
   {{0x6d4e4623,0x67203697,0x79880103,0x7d1c0098}},	//   _abba, namj, _lodw, _aers,
   {{0x63ad3d5d,0x7d1c4624,0x59ca0e96,0x6d574625}},	// [3f50] _iman, _bers, ाकार, texa,
   {{0x7988001e,0x93bd002d,0x7d1c0139,0xfd100037}},	//   _nodw, crăr, _cers, نجم_,
   {{0x7d1c45c9,0x6d574626,0x7bcb010b,0x63ad035f}},	//   _ders, rexa, togu, _kman,
   {{0x7d1c201e,0x6d574627,0x6f0407e5,0x799a03b3}},	//   _eers, sexa, ccic, _altw,
   {{0x7d1c4628,0xea0001a5,0x63ad4629,0x7988099e}},	//   _fers, _đảm_, _mman, _bodw,
   {{0x7d1c462a,0x8dfa0122,0xa3dd0907,0x4e160122}},	//   _gers, _להשת, _तीस_, _מחשב_,
   {{0x63ad462b,0x6f1d462c,0x78570e3a,0xf1b400a5}},	//   _oman, _kesc, تیاز_, וסס_,
   {{0x65630dc3,0x7d1c01ae,0xe6190336,0x63ad08dd}},	//   _sanh, _zers, бди_, _nman,
   {{0x6563462d,0x39640086,0x7d1c00ae,0xa93500af}},	//   _panh, össä_, _yers, _неаш,
   {{0x63ad462e,0x6f1d462f,0x79884630,0x6b894631}},	//   _aman, _lesc, _godw, _hoeg,
   {{0x656303ad,0x5fbd0d91,0x8afd00b8,0xb8d00033}},	//   _vanh, ्काल, _zařa, _টু_,
   {{0x739a4632,0x6b890051,0x2600009e,0x8c490448}},	//   стос_, _joeg, _fòo_, maşı,
   {{0xa3bd164c,0x8c4906d3,0x6b894633,0xc7b2011d}},	//   _आदर_, laşı, _moeg, _אבא_,
   {{0x64a50500,0x63ad4634,0xf1bf4635,0x6b89016e}},	//   _нала, _eman, drás_, _loeg,
   {{0x6f1d4636,0x251a02b8,0x6ab8143a,0x6b9b0273}},	//   _besc, _הוצא, _अश्र, _olug,
   {{0x63ad4637,0x7d1c4638,0x9f5a314b,0x6e244639}},	//   _gman, _sers, _kupé_, tsib,
   {{0x6f1d15b7,0x59cb0c67,0x6e24463a,0x3d08000c}},	// [3f60] _desc, िवार, usib, ाँले_,
   {{0x6b9b1432,0x7d1c00da,0x7521463b,0x63ad02c6}},	//   _alug, _qers, nalz, _zman,
   {{0x1b0d0b52,0x3ce100a1,0x9f4b0176,0x7dd0033b}},	//   _হয়ে_, _करणे_, _ficà_, wäss,
   {{0x6f1d463c,0x7d1c004e,0x8c49008f,0xf1bf1c98}},	//   _gesc, _wers, daşı, brás_,
   {{0x7d1c120d,0x7988004e,0x98be00c7,0x298a1172}},	//   _ters, _podw, _patį_, йско_,
   {{0x6f1d0207,0x3e4e00ea,0x7dd00421,0xb6050116}},	//   _zesc, rētā_, räss, _mešč,
   {{0x6b9b463d,0x307a0070,0x7dd0463e,0xfce614d0}},	//   _flug, מאַנ, säss, _хово,
   {{0x3ce1463f,0x6b9b008a,0x9f5800de,0xa91c01ba}},	//   _करते_, _glug, mpró_, _koľk,
   {{0xfaa34640,0x98b10029,0x7bc002a2,0xf6430409}},	//   _зато, ībām_, _ijmu, нхэн,
   {{0xf64f211f,0x63ad01cc,0x44270051,0x75211e60}},	//   ائي_, _sman, _bvn_, galz,
   {{0x53350e8b,0xdcfc0035,0x672001f4,0xbebb0b88}},	//   мент, _gorą, pamj, _teëg,
   {{0x69d84641,0x291e013c,0x57fb00a5,0x63ad0118}},	//   llve, _heta_, _הלאו, _qman,
   {{0x291e00da,0x27070019,0xe7370036,0x752101ed}},	//   _keta_, _ống_, _хеч_, balz,
   {{0x291e00da,0x6f1d2df0,0xa3dd0084,0xdb000093}},	//   _jeta_, _sesc, _तीर_, _ummæ,
   {{0x291e048c,0x69a10808,0xdfd5021f,0x44f701df}},	//   _meta_, कोटी, довы, _عروج_,
   {{0x291e4642,0xf1bf0f56,0x2cbf0506,0xbfd901e0}},	//   _leta_, trás_, _ćud_, ідає_,
   {{0x6f1d0382,0x7d050699,0xddd000b8,0x201a0107}},	// [3f70] _vesc, tchs, _řeši, _ewpi_,
   {{0xf1bf00b5,0x6b89022e,0x7d0501ae,0x2d8a055c}},	//   rrás_, _soeg, uchs, _cobe_,
   {{0x7d0502c9,0x6f1d4643,0x2d8a4644,0x6b9b4645}},	//   rchs, _tesc, _dobe_, _plug,
   {{0xfc300fab,0x69d84646,0x291e010d,0x7d054647}},	//   احل_, elve, _aeta_, schs,
   {{0x6b890120,0x6e22003a,0x291e00a5,0x6b9b1e7e}},	//   _voeg, šobr, _beta_, _vlug,
   {{0xac1935ea,0x3f8b025c,0x64484648,0x442500b8}},	//   _могу_, _hocu_, ktdi, ysl_,
   {{0x6b8906ba,0x291e02d0,0x246c00b8,0x7e6d4649}},	//   _toeg, _deta_, _něm_, lvap,
   {{0x0609150e,0xefc80019,0x8c49045e,0xa3dd0099}},	//   оник_, _địch_, raşı, _तील_,
   {{0x291e464a,0x7afb464b,0x64480345,0x60d70282}},	//   _feta_, _igut, etdi, _lyxm,
   {{0x1dbf00c4,0x291e00fb,0x442700ea,0x3f8b0139}},	//   ्वित, _geta_, _pvn_, _locu_,
   {{0xb80817bd,0xf8e100dc,0x00000000,0x00000000}},	//   _فيلم_, _फरिय, --, --,
   {{0x61c60a64,0x7e6d024e,0xb60518b0,0x4425008e}},	//   लक्ष, kvap, _pešč, rsl_,
   {{0x1dbf01d1,0x61f701ef,0x21e4033b,0x44250110}},	//   ्वात, _bixl, höhe_, ssl_,
   {{0x4427464c,0x776901ff,0x2bb80207,0xb60508b7}},	//   _tvn_, ldex, rčci_, _vešč,
   {{0xa067464d,0x6448009f,0x3f8b022f,0xdb000086}},	//   мара_, ctdi, _bocu_, _ymmä,
   {{0x2d8a0627,0x7afb464e,0xafe302fb,0x200c00ea}},	//   _sobe_, _ngut, восл, īdi_,
   {{0xa1c62ab4,0x69c101f2,0x9f400176,0x00000000}},	// [3f80] _обид, _ojle, rmià_, --,
   {{0xee3700d4,0x7afb464f,0x69c101cb,0xa2ad0099}},	//   ьну_, _agut, _njle, ीपर्,
   {{0x291e4650,0x01350070,0x0b464651,0x67c100ea}},	//   _reta_, _אָרט_, днен, zēja,
   {{0x291e4652,0x3ebf0c0a,0x69c10009,0xa91c00a0}},	//   _seta_, _žute_, _ajle, _toľk,
   {{0x291e09df,0x656800e9,0x2d8a4653,0x27fe0160}},	//   _peta_, yddh, _tobe_, _sutn_,
   {{0x7afb01d7,0x67c100ea,0x13bb143a,0x291e0055}},	//   _egut, vēja, _उद्भ, _qeta_,
   {{0x291e4654,0xf54e0019,0x64480118,0x3a264655}},	//   _veta_, _bụng_, xtdi, ssop_,
   {{0x6f16001e,0x33200310,0x3a261292,0x88bc0355}},	//   nbyc, _neix_, psop_, _oděv,
   {{0xf54e00e8,0xa3c4009a,0x291e4656,0x00000000}},	//   _dụng_, ्वन_, _teta_, --,
   {{0xdcfc02c4,0x26d802d4,0x2b4400e2,0x67c100ea}},	//   _dorć, āro_, _hcmc_, rēja,
   {{0x68430009,0xe94700b5,0x53ca021a,0x2b44023c}},	//   _анха, _ترقی, रवंश, _kcmc_,
   {{0x64484657,0x67c100ea,0x6e364658,0x9f4c00e0}},	//   rtdi, pēja, kryb, _èlèk_,
   {{0x64480029,0xe29801c8,0x46e21140,0x33200176}},	//   stdi, даў_, _परिह, _deix_,
   {{0x246c0355,0x00000000,0x00000000,0x00000000}},	//   _těm_, --, --, --,
   {{0x855702b8,0x1dbf0355,0x33200392,0x104800c3}},	//   _חשוב_, ्वसत, _feix_, мяти_,
   {{0x27e60453,0x7e6d4659,0xa3e600b4,0x603e0160}},	//   _jhon_, tvap, _बीप_, _sămî,
   {{0x7f4d00da,0x603e0395,0x00000000,0x00000000}},	// [3f90] rfaq, _pămî, --, --,
   {{0x7e6d02e2,0x999f0009,0xdb0b1db8,0xaad20066}},	//   rvap, _spuž_, rigí, _तड़क,
   {{0x27e6043d,0x7e6d465a,0x39990107,0x00000000}},	//   _ohon_, svap, _sèso_, --,
   {{0x33200176,0x236900ee,0x27e600e2,0xa3c40355}},	//   _xeix_, _jaaj_, _nhon_, ्वय_,
   {{0xdfd103fc,0xf54e0023,0x00000000,0x00000000}},	//   _ليگ_, _rụng_, --, --,
   {{0x27e6465b,0xa3e600ab,0x68451566,0xfd1003fc}},	//   _ahon_, _बीन_, енка, _نجف_,
   {{0x27e60014,0x2001465c,0x00000000,0x00000000}},	//   _bhon_, _juhi_, --, --,
   {{0xd0f80bed,0x7afb19dd,0x27e6465d,0x1665258d}},	//   ומות_, _ugut, _chon_, евим,
   {{0xb8d600a1,0xea000019,0xf54e00e2,0x7c220207}},	//   _चे_, _đầm_, _vụng_, ćore,
   {{0x8938465e,0x27e6009e,0xdb0b0176,0x00000000}},	//   _опус_, _ehon_, ligà, --,
   {{0x76492ef1,0xf54e0023,0x33200310,0x6f160355}},	//   stey, _tụng_, _peix_, ybyc,
   {{0x6e3600c7,0x9f97021d,0xdb0b0392,0x00000000}},	//   yryb, açú_, nigà, --,
   {{0x27ed465f,0xbb3a0070,0xf7700773,0x6595010b}},	//   mmen_, הערי, _خال_, _паду,
   {{0x20011b82,0x38650009,0xddc404d9,0x00000000}},	//   _buhi_, _kslr_, kviš, --,
   {{0xddc40496,0x33200176,0x05740647,0x00000000}},	//   jviš, _teix_, _جاند, --,
   {{0x27ed142f,0xa2e61397,0xbebb0031,0xddc40009}},	//   nmen_, _пойд, _ndës, dviš,
   {{0xee3a2b7a,0x27ed4660,0x7e6900f4,0xbea3261f}},	// [3fa0] яна_, imen_, _šepr, гатк,
   {{0x27ed02bf,0x00000000,0x00000000,0x00000000}},	//   hmen_, --, --, --,
   {{0x2369006d,0x27ed4661,0x273a027b,0x88bc06fe}},	//   _yaaj_, kmen_, nünü_, _jdět,
   {{0x27ed0223,0x67c100ea,0xec1303fc,0x61ee4662}},	//   jmen_, dējo, اوند, lmbl,
   {{0xfeba18dd,0x2fc04663,0xc33300a5,0x27ed0110}},	//   _راحت_, mnig_, רוד_, dmen_,
   {{0x27e609c3,0x27ed4664,0x7db60037,0x39450036}},	//   _shon_, emen_, _أصحا, _ccls_,
   {{0xfce31129,0x27e60036,0xa3e01856,0x1dbf07df}},	//   _боро, _phon_, थता_, ्वरत,
   {{0x2fc04665,0x6d5e2873,0x27ed128f,0x00000000}},	//   nnig_, lepa, gmen_, --,
   {{0x7c3e0076,0x2fc04666,0xe60f0609,0x00000000}},	//   lupr, inig_, یشی_, --,
   {{0x6d5e4667,0x2fc000e9,0x27ed081b,0x9f4000c3}},	//   nepa, hnig_, amen_, lmiä_,
   {{0xd6da0332,0xd4970012,0x27e64668,0x7c3e00ea}},	//   _کوشش_, еря_, _thon_, nupr,
   {{0x27e60008,0x6d5e4669,0x2001466a,0x61ee0051}},	//   _uhon_, hepa, _ruhi_, embl,
   {{0x20010612,0xddc400f4,0x00000000,0x00000000}},	//   _suhi_, zviš, --, --,
   {{0x6d5e466b,0x7c3e466c,0x1a9b0070,0xc6b5016b}},	//   jepa, kupr, ליכע, _בלױז_,
   {{0xbebb071f,0x6d5e37e6,0x7c3e0088,0xc0971c64}},	//   _ndër, depa, jupr, رجست,
   {{0x443e466d,0x987b00c2,0x6602466e,0xb2750390}},	//   mut_, האלט, _kuok, _алиш,
   {{0x443e466f,0x660215eb,0x4ea74670,0x9df90f8c}},	// [3fb0] lut_, _juok, хрва, днат_,
   {{0x443e01a2,0x6d5e29a4,0x66020086,0x656a0024}},	//   out_, gepa, _muok, _jafh,
   {{0x443e4671,0x66020086,0x27ed4672,0x78bc0009}},	//   nut_, _luok, ymen_, _žrvn,
   {{0xc4d30070,0x290c0069,0x656a0b88,0xddc400cd}},	//   אגע_, _afda_, _lafh, rviš,
   {{0xa3c400c4,0x443e4673,0xa96938d0,0xd9454674}},	//   ्वत_, hut_, дила_, вели,
   {{0x443e4675,0xade50f39,0x6d5e4676,0xbd45017e}},	//   kut_, _कठिन_, cepa, _جنسي,
   {{0x443e3f8b,0x6d55006d,0x27ed4677,0x186601d3}},	//   jut_, _ibza, tmen_, ващи_,
   {{0x443e3a87,0x3f890ec0,0x67c100ea,0xdce70024}},	//   dut_, njau_, rējo, _lajċ,
   {{0x64580029,0x67c100ea,0x61ee016e,0x9f5e00a2}},	//   _apvi, sējo, ymbl, êté_,
   {{0xa8a704b2,0x27ed1e8b,0xa2d5035d,0x443e4678}},	//   _прек, smen_, _युध्, fut_,
   {{0x443e4679,0x03a62d38,0x2ede0ed1,0x00000000}},	//   gut_, вино, _मर्त, --,
   {{0x6d5e467a,0x888a016b,0x273a0448,0x00000000}},	//   zepa, _קרײַ, rünü_, --,
   {{0xa2d50d00,0x3ea901f4,0x6d5e467b,0x273a027b}},	//   _युद्, jzat_, yepa, sünü_,
   {{0x784a0095,0x91e60f24,0x67e50067,0x00000000}},	//   _səvi, тоге, bójc, --,
   {{0x443e467c,0xdfd20cd1,0x64a5467d,0x61ee467e}},	//   cut_, ليس_, _шака, rmbl,
   {{0xdee60214,0xa0670370,0x3ebf011c,0xbfc3467f}},	//   воби, њата_, _žuta_, абск,
   {{0x6d5e4680,0x2fc000fb,0xa7fc0644,0xde0303fa}},	// [3fc0] tepa, rnig_, _asıl, ипти,
   {{0x2fcd129f,0xdb0b4681,0xa3e60084,0x7c3e4682}},	//   čega_, vigá, _बीत_, tupr,
   {{0x6d5e4683,0xdd100038,0x2fc0011e,0x9f420260}},	//   repa, _týžd, pnig_, _dikò_,
   {{0xeb974684,0x75234685,0x09ca0099,0x99d300d1}},	//   ких_, _lenz, ाक्य, یتوا,
   {{0x7c3e0bce,0x443e09be,0x672202d7,0xbb434032}},	//   supr, zut_, _reoj, речк,
   {{0x7f4402e1,0x660203ad,0x7523030d,0x59df0380}},	//   lgiq, _ruok, _nenz, _पीआर,
   {{0xa3c40fff,0x1c3900c3,0x7659016e,0xdb0003d0}},	//   ्वा_, _пять_, _apwy, _ommø,
   {{0x443e4686,0xf09300a5,0xf76f1ef9,0xb8ea021a}},	//   vut_, שנה_, قاً_, _लख_,
   {{0x02e111b5,0x443e0118,0x9f590107,0x290c023c}},	//   _नरेन, wut_, _disè_, _tfda_,
   {{0x66020086,0x7bc2009e,0xa91c0168,0x00000000}},	//   _vuok, lnou, _poľu, --,
   {{0x439509a7,0x3ea94687,0x3567002d,0xd7ef0a22}},	//   ганс, zzat_, трын_, _ву_,
   {{0x443e34c7,0x752301e4,0x040d01a5,0x7bc24688}},	//   rut_, _eenz, _hưởn, nnou,
   {{0x443e4689,0xe5c61f6a,0x3f8f0093,0x1634468a}},	//   sut_, _иско, ögum_, _селя,
   {{0x7bc200b8,0x7523468b,0x656a01cf,0x7e643540}},	//   hnou, _genz, _uafh, dwip,
   {{0xd48f0043,0x7528468c,0x7bc2468d,0x9f3512ea}},	//   _тр_, madz, knou, леві,
   {{0xe3b01ee1,0x3ea9468e,0xa2c3022e,0xd90404a3}},	//   _وري_, tzat_, रपद्, _ژی_,
   {{0x7bc200b8,0x5d55029f,0x75230027,0x7c2e053c}},	// [3fd0] dnou, лкат, _yenz, _avbr,
   {{0x26050084,0x9f5900f6,0x00000000,0x00000000}},	//   _हंसी_, _misé_, --, --,
   {{0x442c0051,0x764004fb,0xbebb1472,0x9cb50934}},	//   nsd_, humy, _geën, دمات,
   {{0xed510332,0x09cb1729,0x7bc23762,0x201301d7}},	//   _گھر_, िव्य, gnou, _itxi_,
   {{0x7528468f,0x00000000,0x00000000,0x00000000}},	//   kadz, --, --, --,
   {{0x75280080,0xf2d402b5,0xca760e3a,0x9f5a0183}},	//   jadz, סעס_, اموش_, _tupã_,
   {{0x75234690,0x6d454691,0x6e2d00ec,0x9f5900a2}},	//   _renz, mgha, lsab, _aisé_,
   {{0x75234692,0x6f0d3c19,0x6d4529a2,0x2d910009}},	//   _senz, ncac, lgha, _hoze_,
   {{0xaab721b2,0x75230097,0x2d9102e9,0xdce74693}},	//   _अधिक, _penz, _koze_, _majč,
   {{0x6d452c04,0x4585395b,0x2d914694,0x6e2d4695}},	//   ngha, угов, _joze_, isab,
   {{0xfbb70567,0x2d914696,0x2013006d,0x48154697}},	//   _आगाम, _moze_, _ntxi_, _смес,
   {{0xdce74698,0xe72e0202,0x7523000e,0xf77007f6}},	//   _najč, _ће_, _wenz, _وان_,
   {{0x69c31010,0x75230c96,0x2d910282,0x75284699}},	//   onne, _tenz, _ooze_, badz,
   {{0xa06a0a93,0x957c006a,0x040d0019,0x200c0279}},	//   нага_, gląd, _xưởn, ídio_,
   {{0x69c309e3,0x656103e6,0xdce70009,0xa0a3469a}},	//   inne, melh, _bajč, бард,
   {{0x6f0d0312,0xc31e0083,0x226902ee,0x7e7b2190}},	//   gcac, _থাকি_, ätkä_, _šupa,
   {{0x6e2d1c3f,0x2d91469b,0x7f44469c,0x644f00af}},	// [3fe0] gsab, _boze_, rgiq, ăciu,
   {{0x51663301,0x63a4024e,0x7bc2469d,0x6561469e}},	//   _своб, _hlin, wnou, nelh,
   {{0x64410ce8,0x6f0d2a07,0x7e640069,0xdce701ba}},	//   nuli, bcac, swip, _fajč,
   {{0x69c3469f,0x6f0d2edb,0x20180f38,0x09dc00e7}},	//   enne, ccac, mpri_, यत्य,
   {{0xd00f0148,0x644146a0,0x656146a1,0x7c3100d5}},	//   _ولی_, huli, kelh, _čerň,
   {{0x644146a2,0xe89403ad,0x63a446a3,0x61fe012f}},	//   kuli, иаль, _llin, _jipl,
   {{0x644146a4,0x63a446a5,0x201802e9,0x6561198d}},	//   juli, _olin, npri_, delh,
   {{0x7528006a,0x96340948,0x63a446a6,0x7640041b}},	//   wadz, аниц, _nlin, tumy,
   {{0x2bb1006a,0x040d01a5,0x442e46a7,0x75280118}},	//   jący_, _tưởn, _svf_, tadz,
   {{0x63a446a8,0x35b41126,0x656146a9,0x260927c2}},	//   _alin, рбор, gelh, _dúo_,
   {{0x7528004e,0x69da46aa,0x63a4293c,0x69c80223}},	//   radz, _ikte, _blin, _ijde,
   {{0x63a41116,0x752846ab,0xdc9b00a5,0xbebb0298}},	//   _clin, sadz, גיטל, _beël,
   {{0xdce746ac,0x61fe46ad,0x877b0070,0xe5151140}},	//   _rajč, _bipl, _ראדי, _द्वि_,
   {{0x644146ae,0x9f49004f,0x7afd00b8,0x3ebf011c}},	//   buli, rmaí_, _úste, _žuto_,
   {{0x6f0d0211,0x644146af,0xb97b00c2,0x2d9146b0}},	//   tcac, culi, ענלי, _roze_,
   {{0x6e2d46b1,0x161b0084,0x3f15005f,0xb4c00127}},	//   tsab, पीकर_, рдас, ंपी_,
   {{0x6f0d46b2,0x2d9146b3,0xa3c408b6,0x7f980952}},	// [3ff0] rcac, _poze_, ्वर_, _níqu,
   {{0x6e2d222e,0x80b7021a,0x61fe0008,0x6f0d46b4}},	//   rsab, ोपदे, _gipl, scac,
   {{0x6e2d46b5,0x2dd8004f,0xdce70207,0x63a41fab}},	//   ssab, ابقة_, _tajč, _ylin,
   {{0x16040e1d,0x3a750fc5,0x61fe1f4e,0x6d450037}},	//   रदार_, илер, _zipl, sgha,
   {{0x3ce107ba,0x64413448,0x15f637e8,0x00000000}},	//   _करके_, zuli, ीदार_, --,
   {{0x69c3008e,0x67c100ea,0x00000000,0x00000000}},	//   unne, mēji, --, --,
   {{0x65610ec3,0x18a500c7,0x00000000,0x00000000}},	//   velh, райм, --, --,
   {{0x644146b6,0x69da01e0,0x69c846b7,0x00000000}},	//   vuli, _ekte, _ejde, --,
   {{0x644109d6,0xa3d90722,0x656146b8,0x2d9c00b5}},	//   wuli, ़कन_, telh, öveg_,
   {{0xbebb0173,0x7ae9056c,0x00000000,0x00000000}},	//   _reël, _izet, --, --,
   {{0x63a446b9,0x61fe46ba,0x656146bb,0x397a02b5}},	//   _plin, _ripl, relh, _שטענ,
   {{0xe29a46bc,0x644146bd,0x61fe0359,0x656146be}},	//   вам_, ruli, _sipl, selh,
   {{0x63a40b0d,0x61fe46bf,0x212a0260,0x656146c0}},	//   _vlin, _pipl, tabh_, pelh,
   {{0x644146c1,0x1a9a00c2,0x463a00c2,0x67c10029}},	//   puli, דישע, _יענע, dēji,
   {{0x1fb64025,0x212a0f49,0x63a400e0,0x39470f00}},	//   асар, rabh_, _tlin, igns_,
   {{0x63a446c2,0x7ae902e9,0x201846c3,0xa2c300b8}},	//   _ulin, _ozet, rpri_, रपश्,

   {{0x201802e9,0x61fe0644,0x8fa30340,0xdcf400f4}},	// [4000] spri_, _tipl, цате, _čađa,
   {{0x637b03ad,0x7bdb1c85,0x67f5010b,0xbebb01bf}},	//   _tänä, _akuu, _išju, _geëm,
   {{0x315700c2,0xf53602b5,0xdd8f46c4,0x7ae900a0}},	//   _דיין_, שטער_, بول_, _azet,
   {{0x3ce60006,0xf4560070,0x54560070,0x79810090}},	//   _करीं_, ייער_, יסען_, _anlw,
   {{0x7ae90036,0x67c10228,0x7bc900f6,0x00000000}},	//   _czet, cēji, _djeu, --,
   {{0xb33b01f4,0xb86646c5,0x7bdb030d,0x2d8c00be}},	//   thçk, لابو, _ekuu, _õde_,
   {{0x97a646c6,0x5886057a,0x7c850370,0x7ae946c7}},	//   ирил, рыла, _луѓе, _ezet,
   {{0xc7c60836,0x25a000f7,0x9f4200c3,0x7f980183}},	//   јски, _œil_, _eikö_, _tíqu,
   {{0xfaa330ca,0xd9460200,0x00000000,0x00000000}},	//   _дато, _вези, --, --,
   {{0x9f970176,0x00000000,0x00000000,0x00000000}},	//   nçò_, --, --, --,
   {{0xa3c400e7,0x03f90202,0x6d7902b5,0x69d846c8}},	//   ्वं_, лној_, אָרװ, move,
   {{0x58bb024b,0x00000000,0x00000000,0x00000000}},	//   _במבצ, --, --, --,
   {{0x394c0103,0x12e703d0,0x00000000,0x00000000}},	//   _kcds_, рінг, --, --,
   {{0x3d160026,0xe3a50118,0x14b70416,0xddc400ea}},	//   _प्ले_, _گشتی, ادیث_, ltiņ,
   {{0x351b0070,0x044303e6,0x06d80033,0x00000000}},	//   _יוגנ, _дејн, দেশি, --,
   {{0xa3c4012f,0xdcfc0095,0x34fb0122,0xa7fc027d}},	//   ्वः_, _sorğ, _בהוד, _arız,
   {{0x69d83981,0x63bd46c9,0x7c3e0e54,0x59d603de}},	// [4010] kove, misn, erpr, धवार,
   {{0x63bd0034,0x69d846ca,0x67c10080,0x443e313f}},	//   lisn, jove, rēji, ort_,
   {{0x69d846cb,0xdcfc0009,0x443e0176,0x629d46cc}},	//   dove, _borđ, nrt_, lyso,
   {{0x443e30d2,0x63bd46cd,0x39df0066,0x67c800b8}},	//   irt_, nisn, _पीड़ि, dějo,
   {{0x443e02bf,0x394c0176,0x7c3e0a81,0xaa67019e}},	//   hrt_, _bcds_, arpr, ртек,
   {{0x69d846ce,0x6ab72874,0xe9d8010b,0x7ae908b7}},	//   gove, _अधीर, акі_, _vzet,
   {{0x01380122,0x31580070,0x260c0066,0x2d833e4a}},	//   ברות_, ייגן_, _डूबी_, _inje_,
   {{0x1bd400d4,0x63bd1626,0x7bc9023c,0x00000000}},	//   _дося, jisn, _ujeu, --,
   {{0x443e46cf,0x69d846d0,0x7ae90254,0x63bd46d1}},	//   ert_, bove, _uzet, disn,
   {{0xc98425ef,0x69d846d2,0x00000000,0x00000000}},	//   _мухи, cove, --, --,
   {{0x232a0ea0,0xa787006c,0x7e7b0eac,0x63bd46c3}},	//   лони_, _پشاو, _šupl, fisn,
   {{0x3209022e,0x63bd46d3,0xdb0001f7,0x29fd00d5}},	//   _buay_, gisn, _immò, _mňam_,
   {{0x443e0571,0xcfcd0033,0x68e101b4,0x2b4d0176}},	//   art_, লতান, _hyld, _mcec_,
   {{0x661b46d4,0x3209011e,0x3d210035,0x68e10523}},	//   mpuk, _duay_, यरों_, _kyld,
   {{0x3ce60755,0x63bd46d5,0xa0a3141d,0xa7fc027d}},	//   _करें_, bisn, пард, _arıy,
   {{0xdb190bf7,0x2451024e,0xa3ac19b7,0xaf061c62}},	//   nnwä, mám_, _गति_, спал,
   {{0x24510187,0x823627f6,0x32091c5b,0x290546d6}},	// [4020] lám_, _اربا, _guay_, _ogla_,
   {{0xaadb007c,0x67c100ea,0x00000000,0x00000000}},	//   _बड़क, mēju, --, --,
   {{0x7ae001ff,0x67c100ea,0x00000000,0x00000000}},	//   _symt, lēju, --, --,
   {{0x7f860037,0x661b0159,0x386c00d5,0x247700cc}},	//   _الحن, kpuk, _rsdr_, _măm_,
   {{0xca560370,0x2905010d,0x24511d8a,0x247700e2}},	//   стењ, _bgla_, hám_, _lăm_,
   {{0x2002000e,0x443e1cfd,0x68e10a8a,0x2451152f}},	//   _hiki_, yrt_, _byld, kám_,
   {{0x247700e8,0x200201a8,0x8c431a1c,0x394c037d}},	//   _năm_, _kiki_, _нере, _vcds_,
   {{0x2451114d,0x69d846d7,0xfaa6107b,0xa61446d8}},	//   dám_, sove, _лабо, омич,
   {{0x69d846d9,0x63bd46da,0x5ebb02b5,0xddc400ea}},	//   pove, visn, ָזיק, rtiņ,
   {{0x7afd024e,0x68e13a92,0x67c100ea,0x24510355}},	//   _ústa, _fyld, dēju, fám_,
   {{0x63bd46db,0x443e46dc,0x6d5c46dd,0x68e10909}},	//   tisn, urt_, _mbra, _gyld,
   {{0x9f4002e1,0x200246de,0x443e46df,0x247746e0}},	//   blié_, _niki_, rrt_, _dăm_,
   {{0x63bd0537,0x32090028,0x518746e1,0xe5341f7c}},	//   risn, _quay_, бува, _дель,
   {{0x611446e2,0x24511d8a,0x443e08b7,0x63bd46e3}},	//   здру, bám_, prt_, sisn,
   {{0x43952c72,0x63bd0bcc,0x629d028b,0x68110029}},	//   _макс, pisn, syso, _kāda,
   {{0x6d5c46e4,0x02a73121,0x200246e5,0xdb0002d7}},	//   _abra, _гром, _ciki_, _almí,
   {{0x5f940384,0x200246e6,0x7c380124,0x67c100ea}},	// [4030] читт, _diki_, švrl, cēju,
   {{0x6d4e0176,0x6d5c009e,0x20020839,0xdcfc00ea}},	//   _ccba, _cbra, _eiki_, _norē,
   {{0x24770023,0x6d5c009e,0x30f700b5,0x5f950043}},	//   _xăm_, _dbra, _دودھ_, _динт,
   {{0x6d5c46e7,0x6d4e01ef,0x8f4700c3,0x00000000}},	//   _ebra, _ecba, _уход, --,
   {{0xeb902402,0x68e1012f,0xc334011d,0x2451006c}},	//   عظم_, _syld, פוס_, zám_,
   {{0xe3cf0083,0x9f420086,0x6d5c009e,0x68e1008c}},	//   রতিব, _ehkä_, _gbra, _pyld,
   {{0xa3d90992,0x319c0070,0x916600e2,0x013800a5}},	//   ़का_, רבונ, _hộ_, זרות_,
   {{0x6d5c46e8,0x661b042a,0x2fc9001e,0x2a6d01e8}},	//   _zbra, tpuk, nnag_, _tseb_,
   {{0xbebb2193,0x6ffc009e,0xf1bf0138,0x05a901e0}},	//   _beëi, _dōch, nsás_, ивий_,
   {{0xdcf50029,0x2451024e,0x290546e9,0x5f1901c0}},	//   _nozī, tám_, _ugla_, युत्_,
   {{0x661b46ea,0xb88601ef,0xd38a0bfc,0xe36646eb}},	//   spuk, reíñ, айне_, окни,
   {{0xd8d60779,0xe8d600c2,0x245142f6,0xe3bf01ed}},	//   _וועט_, _ווער_, rám_, giñ_,
   {{0xddcd00f4,0xa2840088,0x245100ac,0x00000000}},	//   zvaš, سیدو, sám_, --,
   {{0xd3780755,0x64a501c8,0x00860d9e,0x200246ec}},	//   ść_, _мала, олго, _siki_,
   {{0xa06a0a87,0x67c100ea,0x00000000,0x00000000}},	//   шава_, sēju, --, --,
   {{0xa2d50785,0xedb4012f,0x6d5c46ed,0x91660023}},	//   _युक्, ृच्छ, _sbra, _bộ_,
   {{0x672b46ee,0x442702c7,0x200246ef,0x660346f0}},	// [4040] _megj, _hwn_, _viki_, _kink,
   {{0x672b24d5,0x6603003c,0xa3c40ebd,0x9f530176}},	//   _legj, _jink, ्वक_, _buxó_,
   {{0x660346f1,0x200246f2,0x7e7d033b,0xc2c900b5}},	//   _mink, _tiki_, _ersp, _نبیل_,
   {{0x644102a8,0x533702b5,0xab8311ce,0x680a0035}},	//   irli, ַנצן_, душк, _wędk,
   {{0xadeb0f19,0x644101ae,0x4427028b,0x7d0d0079}},	//   _जीवन_, hrli, _lwn_, íosú,
   {{0x660346f3,0x44270122,0x6d5c1c90,0xe3bf01ed}},	//   _nink, _own_, _ubra, ziñ_,
   {{0x672b46f4,0x8c950210,0x7afd15d8,0x213a23ca}},	//   _begj, _ерті, _ústn, _mdph_,
   {{0x2d98016f,0x24803384,0x3ebf011c,0x6b630dba}},	//   _hore_, _čim_, _žuti_, _окса,
   {{0x2d9846f5,0x644146f6,0x672b00da,0x3ea000b5}},	//   _kore_, erli, _degj, nyit_,
   {{0xa2d50035,0x7e7b1b76,0x68ed0355,0x442746f7}},	//   _युग्, _šupk, řada, _bwn_,
   {{0x2d9846f8,0x2ec6021a,0x6441044d,0x681100ea}},	//   _more_, लपुत, grli, _tāda,
   {{0x6603309d,0x2d98022d,0xb4ea0722,0x442746f9}},	//   _eink, _lore_, _मरी_, _dwn_,
   {{0x64410b0d,0x660301d7,0xc7f700a5,0xdceb46fa}},	//   arli, _fink, _וזאת_, _čiča,
   {{0xbf9b0370,0x6603010b,0xa18410b0,0x69ca46fb}},	//   _ciên, _gink, мысл, nnfe,
   {{0x656846fc,0x69ca46fd,0x84380037,0x7e7d0009}},	//   medh, infe, _اكبر_, _srsp,
   {{0x6448120d,0x656800da,0x00000000,0x00000000}},	//   mudi, ledh, --, --,
   {{0x59bc0433,0xdce70035,0x66030371,0x2fc903bc}},	// [4050] ्चार, _mają, _yink, rnag_,
   {{0xd90404e8,0x2d9846fe,0xe1ff0035,0x80d63979}},	//   _لی_, _core_, zwój_, _मुके,
   {{0x644802dd,0x2d9846ff,0xdb0001f7,0x00000000}},	//   nudi, _dore_, _almà, --,
   {{0xdcee063c,0x656800d1,0x00000000,0x00000000}},	//   _gabč, hedh, --, --,
   {{0x7e7d3bed,0x672b4700,0x2d984701,0x644831de}},	//   _ursp, _regj, _fore_, hudi,
   {{0x2d984702,0x656801d2,0x672b00fb,0xa969204d}},	//   _gore_, jedh, _segj, сика_,
   {{0x6c544703,0x660301c8,0xe73906cd,0x3f992802}},	//   _окру, _rink, бей_, _kosu_,
   {{0xfe6e006c,0x64484704,0x2d980bde,0x3f9901d7}},	//   _جگہ_, dudi, _zore_, _josu_,
   {{0x672b01f4,0x6568002f,0xf96b002d,0x4427016e}},	//   _vegj, fedh, _врей_, _swn_,
   {{0x65680919,0x7bcb2b0c,0xbebb0345,0x6441013b}},	//   gedh, lngu, _feëv, trli,
   {{0x66034705,0xbf9b0028,0xb0db00a1,0xe8792499}},	//   _vink, _riên, _मुलग, _دماغ_,
   {{0x66033953,0x7bcb4706,0x3f994707,0x660b043d}},	//   _wink, nngu, _nosu_, _tugk,
   {{0x66034708,0x7bcb4709,0x245201cb,0x656801cb}},	//   _tink, ingu, ونیس, bedh,
   {{0x644808c2,0x7769470a,0x6d1b0026,0x67e50453}},	//   budi, leex, _प्लग_, dóji,
   {{0x03a611ca,0x2d980c6f,0x2b5f0207,0x80d60b35}},	//   _нико, _rore_, _obuc_, _मुखे,
   {{0x3f86043f,0xf43a0122,0xc00310b4,0xc43a00a5}},	//   ñou_, _התקש, епск, _התקי,
   {{0xa3d90035,0x7e6d010d,0x3f9900fe,0x2d980147}},	// [4060] ़कर_, gwap, _dosu_, _pore_,
   {{0xc27b00c2,0xf27b0100,0x3f8f0093,0xdb020132}},	//   _פריי, _פריש, ögur_, lhoç,
   {{0x2d980044,0x319b00a5,0x1d1900d4,0xcb0a128d}},	//   _vore_, _הבינ, юють_, ميان_,
   {{0x2b5f0176,0x9f4002d7,0x2d98470b,0xdb00470c}},	//   _cbuc_, rmió_, _wore_, _almá,
   {{0x2d98470d,0xbebb0298,0x6568023c,0x6448470e}},	//   _tore_, _seëv, yedh, zudi,
   {{0x7bcb08c7,0xceb30070,0x2ac10185,0x00000000}},	//   angu, _טיר_, _sæbø_, --,
   {{0xb4ea0299,0x644801dd,0x88841a95,0x00000000}},	//   _मरे_, xudi, بیان, --,
   {{0x6f160051,0x6448470f,0x7e7b00d5,0xcc5700a5}},	//   ncyc, vudi, _šupi, _מבלי_,
   {{0x65684710,0x35f428cc,0x00000000,0x00000000}},	//   tedh, мпир, --, --,
   {{0x64484711,0xb21b008a,0x7bc24712,0x00000000}},	//   tudi, lvæg, liou, --,
   {{0x92e90b52,0xb0db0006,0xaac000a1,0xd9430340}},	//   _বলে_, _मुंग, _शेतक, _чехи,
   {{0x64484713,0x28c900b8,0xb4cc20d8,0x656800d1}},	//   rudi, िपरि, _रखी_, sedh,
   {{0x64484714,0x51874715,0x98a50029,0x3f99002d}},	//   sudi, пува, _ielā_, _rosu_,
   {{0x64484716,0xddcd004e,0xfdeb0084,0xe3b9037a}},	//   pudi, ztał, _जींस_, nsız_,
   {{0xf1b0026e,0x1fa70043,0x55770317,0xddcd0035}},	//   اءُ_, праг, _מעגן_, ytał,
   {{0x5f944717,0x94730082,0x213100da,0x3ce00066}},	//   нист, _أدوا, sazh_, _कड़े_,
   {{0x63ad4718,0x7bc24719,0x59dc04e9,0xa3e60380}},	// [4070] _ilan, diou, मकार, _बीट_,
   {{0x63ad05ee,0x799a06d1,0x224b02b1,0x00000000}},	//   _hlan, _notw, muck_, --,
   {{0x63ad471a,0x7bcb471b,0x7e6d0345,0xa3c40099}},	//   _klan, tngu, swap, ्वच_,
   {{0x7988471c,0xff250ef5,0x3f990159,0xa14900b5}},	//   _andw, _تبدی, _uosu_, _اسکے_,
   {{0xf8ae006c,0x63ad0054,0x7bcb0031,0xd8380359}},	//   یکم_, _mlan, rngu, _avč_,
   {{0x63ad471d,0xddcd006a,0xdcfc00d8,0x799a0090}},	//   _llan, stał, _norė, _cotw,
   {{0x63ad471e,0x77690118,0x7bcb471f,0xd8380168}},	//   _olan, teex, pngu, _cvč_,
   {{0x7bc24720,0xe619204b,0x798801a8,0xa2c306fe}},	//   ciou, оди_, _endw, रपञ्,
   {{0x6d4a2cad,0x6b894721,0xbebb0345,0x6b9b009e}},	//   ófag, _ineg, _geët, _ioug,
   {{0x63ad4722,0xa3e60534,0x224b03c1,0x77690523}},	//   _alan, _बीज_, duck_, seex,
   {{0x69c304d5,0x6b894723,0x6b9b0345,0x00000000}},	//   mine, _kneg, _koug, --,
   {{0x63ad4724,0x21e4033b,0x80c10033,0x6b9b030d}},	//   _clan, höht_, _শুভ্, _joug,
   {{0x69c309e3,0x63ad0612,0x6b8900d7,0x6b9b00a2}},	//   oine, _dlan, _mneg, _moug,
   {{0xdcee0080,0x63ad4725,0x69c34726,0x6b9b4727}},	//   _labā, _elan, nine, _loug,
   {{0xc0e34451,0x00000000,0x00000000,0x00000000}},	//   ворк, --, --, --,
   {{0xa3e62088,0x69c34728,0x6d434729,0x23602190}},	//   _बीच_, hine, ónan, _ubij_,
   {{0x69c3472a,0x7bc20122,0x6e3600d8,0x6f16024b}},	// [4080] kine, viou, usyb, rcyc,
   {{0xfbd2006c,0x6ec2020d,0x6aa20054,0xceb400a8}},	//   ھتا_, _रेणु, vyof, rzə_,
   {{0xbc6a00d1,0x6b9b472b,0x63ad472c,0x7bc2024b}},	//   تمان_, _boug, _ylan, tiou,
   {{0x160d0099,0x6b9b472d,0x80bc0099,0x00000000}},	//   सदार_, _coug, ोपीं, --,
   {{0x7bc2472e,0x6b89046a,0x799a0035,0x69c3472f}},	//   riou, _dneg, _potw, fine,
   {{0x7bc24730,0x69c34731,0x6b89008b,0x00000000}},	//   siou, gine, _eneg, --,
   {{0xa96711b9,0xa3de000c,0xe3b900d0,0xb4cc08a9}},	//   фија_, तका_, rsız_, _रखे_,
   {{0x5883005f,0x6d5e32e8,0x69c34732,0x9cd7011d}},	//   тыша, lfpa, aine, _חולה_,
   {{0x056a0166,0x63ad01da,0x799a0103,0x06e10831}},	//   ојни_, _rlan, _totw, মেসি,
   {{0xdc3e0097,0xc9860af8,0x799a0260,0x00000000}},	//   _líče, _تشري, _uotw, --,
   {{0x69dd0037,0xdb0b002a,0x00000000,0x00000000}},	//   _ísea, cigó, --, --,
   {{0xe71700d1,0x18a330e0,0xb86500f3,0x00000000}},	//   _قيمت_, _шахм, _سامو, --,
   {{0x63ad00a0,0xbebb03bc,0x00000000,0x00000000}},	//   _vlan, _leër, --, --,
   {{0xa4d402ce,0x63ad4733,0xab5d009f,0x224b06d1}},	//   _полі, _wlan, _imże, ruck_,
   {{0xcf9b1b78,0xa0c505f5,0x7bc04734,0x2eed0bc6}},	//   оја_, ريرو, _ommu, _šef_,
   {{0x69c34735,0x657a081c,0x6578008c,0x6d5e1167}},	//   zine, ldth, _havh, efpa,
   {{0x24583bf6,0x4ade0581,0x6b9b4736,0x776201ef}},	// [4090] lém_, _फुलव, _roug, _mbox,
   {{0x7bc037da,0xdce70035,0x6b894737,0x645a3367}},	//   _ammu, _zaję, _sneg, otti,
   {{0x645a03ad,0x245801c0,0x61e52b63,0xb4cc0084}},	//   ntti, ném_, _ikhl, _रखो_,
   {{0x290c0008,0x645a00c3,0x7e7b0124,0xce9502fb}},	//   _agda_, itti, _šupu, _замъ,
   {{0x2458446b,0x645a02a2,0x65780282,0x00000000}},	//   hém_, htti, _oavh, --,
   {{0x68e802c7,0x245801c0,0x69c33638,0x657800ee}},	//   _bydd, kém_, uine, _navh,
   {{0x3d1a0429,0xe7394738,0x69c3409c,0x98be027d}},	//   मुळे_, пей_, rine, _batı_,
   {{0x69c3257c,0x68e80297,0xa69503e6,0xdb0b01ef}},	//   sine, _dydd, ерој, rigó,
   {{0x69c34739,0x92ea0083,0x645a07b4,0xb906473a}},	//   pine, _গল্প_, etti, _यु_,
   {{0x68e80297,0x69c30c6f,0xe89500d8,0xdb0b01ef}},	//   _fydd, qine, _пазь, pigó,
   {{0x6578006d,0x64a5004b,0x69c1473b,0xf77334d9}},	//   _davh, хана, _imle, _لاش_,
   {{0xe3b210ee,0x61e510cd,0x61f7009e,0x853c010b}},	//   ارد_, _akhl, _ahxl, nkėj,
   {{0xda0f0d53,0x645a473c,0x6d550067,0x00000000}},	//   ादित_, atti, _ocza, --,
   {{0x3f8b055c,0xdb090176,0x7ae903d0,0x00000000}},	//   _ancu_, _lleï, _myet, --,
   {{0xe3b20082,0x24580279,0xceb400a8,0x23a200d5}},	//   _مرة_, cém_, hbət_, _sóju_,
   {{0xafe3473d,0x201e0029,0x7ae9030d,0x84080207}},	//   госл, īti_, _oyet, _beđž,
   {{0x3d02009a,0x0d862d45,0x7ae9473e,0x765b473f}},	// [40a0] वेने_, нлан, _nyet, ntuy,
   {{0xe1f221a0,0x62844740,0x00000000,0x00000000}},	//   _حسب_, _irio, --, --,
   {{0x315700c2,0x28df27c6,0x0b4600a4,0x7ae94741}},	//   _איין_, _पुलि, енен, _ayet,
   {{0x7ae9018e,0x765b011e,0x68e84742,0x6d55027d}},	//   _byet, ktuy, _rydd, _ecza,
   {{0x68e801b4,0x24584743,0x00000000,0x00000000}},	//   _sydd, zém_, --, --,
   {{0x7ae90008,0x645a4744,0x6e2402d7,0x321202d7}},	//   _dyet, ytti, mpib, _muyy_,
   {{0xab2a0de3,0x28c31371,0xf8064745,0x7ae90855}},	//   _нова_, _वेदि, нчин, _eyet,
   {{0x245801c0,0xceb400a8,0x7ae90260,0xf09300a5}},	//   vém_, bbət_, _fyet, רנה_,
   {{0x4aaa004b,0x68e8001e,0x1dd41140,0x765b043d}},	//   _экан_, _wydd, _ददात, gtuy,
   {{0xe9da323d,0x24584746,0x98a70035,0xb8e800b5}},	//   _экз_, tém_, waną_, _قبضے_,
   {{0x645a0421,0xddc625d3,0x61e500ee,0xa4d44747}},	//   utti, _apkū, _rkhl, тоні,
   {{0x24583bf6,0x645a4748,0x62844749,0x38cb00d1}},	//   rém_, rtti, _brio, _عالی_,
   {{0x6284474a,0x645a039b,0x765b00e2,0xf773016b}},	//   _crio, stti, ctuy, _תקנ_,
   {{0x2244024e,0x04940037,0x67e50067,0x6284474b}},	//   ámka_, _للتح, bójs, _drio,
   {{0x6284474c,0x2fc2012f,0x9f3500d8,0x27e60069}},	//   _erio, _bmkg_, кеві, _kkon_,
   {{0x62840037,0x8d7700f8,0x9f5a00d5,0xddc4027b}},	//   _frio, کارا, _tupý_, ttiş,
   {{0x6284474d,0xa3de3779,0x00000000,0x00000000}},	// [40b0] _grio, तकर_, --, --,
   {{0x442e0051,0x98b00067,0x443c00fe,0x00000000}},	//   _kwf_, जनाए, _kvv_, --,
   {{0x9f5a0176,0x7ae90487,0x7c2e0051,0x443c0176}},	//   _cupó_, _syet, _cwbr, _jvv_,
   {{0x7ae901d2,0xa03a02b5,0x443c474e,0x64480079}},	//   _pyet, _קערפ, _mvv_, irdi,
   {{0xbf360052,0x853c010b,0xbebb0051,0xdb0e0093}},	//   _בארץ_, rkėj, _geëp, þjál,
   {{0x27e60602,0x7ae9474f,0x89a800d4,0xfaa22286}},	//   _akon_, _vyet, нків_, рашо,
   {{0xa3e1018d,0xceb400a8,0xbddb0107,0x00000000}},	//   थवा_, sbət_, _avèg, --,
   {{0x7c25233c,0xceb4013b,0x00000000,0x00000000}},	//   mphr, mbər_, --, --,
   {{0x200b4750,0x443c3cba,0x6448099b,0x7bd800f7}},	//   _mici_, _avv_, erdi, évue,
   {{0x69c129c2,0x200b00cd,0x3ce60035,0x443c00fe}},	//   _umle, _lici_, _जुडे_, _bvv_,
   {{0x6f1d0223,0x64480506,0x7c250098,0x00000000}},	//   _ofsc, grdi, nphr, --,
   {{0x200b0012,0x62844751,0x442e2e89,0xe72e0274}},	//   _nici_, _prio, _dwf_, _ње_,
   {{0x27ff4752,0xe297086c,0x64484753,0x67294754}},	//   mmun_, вая_, ardi, mbej,
   {{0x27ed4755,0x27e002dd,0x200b4756,0xa06a1a6e}},	//   llen_, čine_, _aici_, мага_,
   {{0xddd6024e,0x200b4757,0xcfaa00f8,0xc0e600cf}},	//   jvyš, _bici_, وارم_, товк,
   {{0x62844758,0x44254759,0x200b475a,0x9f4f008d}},	//   _trio, mpl_, _cici_, ögð_,
   {{0x200b0382,0x27ed475b,0x628401ed,0x6f0f00f6}},	// [40c0] _dici_, ilen_, _urio, _dgcc,
   {{0x27ed02bf,0x7aef00ac,0xf4240033,0x00000000}},	//   hlen_, _úcty, _ভিতর_, --,
   {{0x27ed475c,0x7649475d,0xed57475e,0x6c330079}},	//   klen_, hrey, тох_, لفلا,
   {{0x61ee038e,0x27ed475f,0x27ff4760,0x09bc01d1}},	//   llbl, jlen_, jmun_, ्च्य,
   {{0x27ed4486,0x2000055c,0xdb0901da,0x00000000}},	//   dlen_, mmii_, _smeò, --,
   {{0x27ed4761,0xdb0b008a,0x213815c8,0x200b00af}},	//   elen_, rigð, narh_, _zici_,
   {{0x27ed4762,0xd7fa00af,0x281400fd,0x00000000}},	//   flen_, муи_, دوبس, --,
   {{0x27ed4763,0x64480254,0x443c0051,0x00000000}},	//   glen_, vrdi, _rvv_, --,
   {{0xb8e91a75,0xda65017e,0x76494764,0x00000000}},	//   _ले_, _مالي, grey, --,
   {{0x21380b16,0x27ed4765,0x644802c6,0xd82601fd}},	//   jarh_, alen_, trdi, _аджи,
   {{0x27ed4766,0xa3de01d1,0x76490be2,0xad3700a5}},	//   blen_, तकं_, arey, כניס_,
   {{0xd3a72f19,0xd5b000bf,0x7649008a,0xa73a0d93}},	//   троп, _گفت_, brey, _آثار_,
   {{0x200b0124,0xdcf50116,0x00000000,0x00000000}},	//   _rici_, _razč, --, --,
   {{0x200b00ee,0x20130176,0x443c0051,0x442e016e}},	//   _sici_, _puxi_, _tvv_, _twf_,
   {{0x999901ba,0x200b026b,0x64a30200,0x00000000}},	//   _ísť_, _pici_, _ваја, --,
   {{0x02a70423,0xa34700d8,0x61ee12ba,0xc3550fb4}},	//   _аром, _рэкл, albl, _скиј,
   {{0x291e022a,0x9ed9027a,0xfe70004f,0x200b4767}},	// [40d0] _ofta_, хмат_, يدك_, _vici_,
   {{0x68ed00b8,0xbbdb0387,0x67293e17,0x27ff0be2}},	//   řadi, यक्क, zbej, zmun_,
   {{0x27ed4768,0x00000000,0x00000000,0x00000000}},	//   ylen_, --, --, --,
   {{0x291e01e9,0x6f1d0183,0x00000000,0x00000000}},	//   _afta_, _ufsc, --, --,
   {{0xd945277d,0xeab00c74,0x27ed082b,0x00000000}},	//   гели, يعه_, vlen_, --,
   {{0x48791f08,0x2fc901e8,0x27ed4769,0x76490225}},	//   есия_, liag_, wlen_, vrey,
   {{0xac94476a,0x27ed476b,0x00000000,0x00000000}},	//   _карш, tlen_, --, --,
   {{0x869900c9,0x27ed476c,0x7649476d,0x291e476e}},	//   етот_, ulen_, trey, _efta_,
   {{0x67290022,0x27ed476f,0x3ea94770,0x0609172a}},	//   rbej, rlen_, nyat_, нник_,
   {{0x59b70d00,0x27ed4771,0x98c70d6e,0x00000000}},	//   _अतिर, slen_, _исел, --,
   {{0x27ed4772,0x58d401af,0x00000000,0x00000000}},	//   plen_, _кофт, --, --,
   {{0xc20935d9,0x3ea91221,0xddcd0a78,0x1b110033}},	//   _זה_, kyat_, jvaž, ারকে_,
   {{0xdcf40274,0x442500fe,0x213802c4,0x1db303de}},	//   _čača, spl_, tarh_, ंघात,
   {{0x06e50083,0x3ea94773,0xe3b20088,0x7afd0097}},	//   _পৃথি, dyat_, _گرت_, _ústu,
   {{0x75d20c26,0xa0674774,0x00000000,0x00000000}},	//   _ديوا, лара_, --, --,
   {{0x645c0443,0x3a260051,0x1fb5002d,0xa3d8021a}},	//   àrie, ypop_, асур, _ादि_,
   {{0x3ea94775,0x20004776,0x93fb1804,0x4d6621c3}},	// [40e0] gyat_, rmii_, _אלקי, лкав,
   {{0xaf03002d,0x00000000,0x00000000,0x00000000}},	//   спул, --, --, --,
   {{0xa0a60ece,0xacf611b9,0xf53602b5,0x28c300b4}},	//   _санд, учај, רטער_, _वेलि,
   {{0x65ad016f,0x22404777,0x00000000,0x00000000}},	//   _súhl, _kvik_, --, --,
   {{0x9f590a8a,0x00000000,0x00000000,0x00000000}},	//   _risø_, --, --, --,
   {{0xfce63b8b,0xf8b00118,0x82770070,0x00000000}},	//   _бого, يکا_, טענע_, --,
   {{0xdca31c87,0x00000000,0x00000000,0x00000000}},	//   _лари, --, --, --,
   {{0x7c3e4778,0x3f804779,0x00000000,0x00000000}},	//   mspr, ndiu_, --, --,
   {{0x7c3e477a,0x248701dd,0x36d4477b,0x35b4477c}},	//   lspr, _arnm_, ропр, ибир,
   {{0x2db7016b,0xd90e0105,0x00000000,0x00000000}},	//   ָלטן_, _عیب_, --, --,
   {{0x7c3e477d,0xd7ef10d4,0x69ca477e,0x6d430079}},	//   nspr, _гу_, mife, ónai,
   {{0x3ea90669,0x2fc901e8,0x3f800031,0x7c3e477f}},	//   yyat_, xiag_, jdiu_, ispr,
   {{0x65940af5,0xbee302e4,0xdcf50029,0x224000ac}},	//   _валу, _कुंभ_, _mazā, _cvik_,
   {{0x7c3e4780,0x00000000,0x00000000,0x00000000}},	//   kspr, --, --, --,
   {{0xd48f4781,0x753a06a2,0x2fc901e8,0x351b0317}},	//   _ур_, matz, tiag_, _אוונ,
   {{0x443e4782,0x753a0291,0x7c3e038d,0x69ca4783}},	//   mst_, latz, dspr, hife,
   {{0x7c3e136f,0x443e4784,0xcfe80098,0xe81b0380}},	// [40f0] espr, lst_, افقه_, _पूना_,
   {{0x753a06a2,0x443e4785,0x2fc90221,0x3f8001ef}},	//   natz, ost_, siag_, adiu_,
   {{0x443e03d0,0x69ca4786,0x7c3e4787,0x3ea9022e}},	//   nst_, dife, gspr, syat_,
   {{0x443e4788,0x753a4789,0xdb0002e9,0x09dd0e61}},	//   ist_, hatz, _komè, यव्य,
   {{0x753a0291,0x443e01ae,0x2d85478a,0x236901f4}},	//   katz, hst_, _óleo_, _mbaj_,
   {{0x443e478b,0x61e70129,0x7c3e2a86,0xd8250340}},	//   kst_, nojl, bspr, адки,
   {{0x443e478c,0x753a06a2,0xa7b50431,0x3158478d}},	//   jst_, datz, исиј, טיגן_,
   {{0x07a5478e,0xc1d2004e,0x31d2022e,0x661d007e}},	//   раин, _सद्ग, _सद्ध, ísko,
   {{0x7bcb478f,0x443e4790,0x6a2300b5,0xdb000392}},	//   migu, est_, _اہتم, _nomè,
   {{0x27e004c3,0x7bcb4791,0x6d574792,0x27330028}},	//   čina_, ligu, ngxa, ản_,
   {{0x443e4793,0x232a14a1,0x2d8109c3,0x61e702c4}},	//   gst_, кони_, idhe_, dojl,
   {{0x7bcb4794,0xe2860009,0x888a02b5,0xb4d5238a}},	//   nigu, алми, _שרײַ, _सखी_,
   {{0x2d9125cb,0x753a01d7,0xdb004795,0x443e4796}},	//   _onze_, batz, _comè, ast_,
   {{0x7bcb02b3,0xdb004797,0x443e37e9,0x7c3e4798}},	//   higu, _domè, bst_, yspr,
   {{0x7bcb4799,0x9f490079,0x2d810207,0x98a70355}},	//   kigu, alaí_, ddhe_, vaně_,
   {{0x673b00d8,0x788000b8,0xfe460036,0x7bcb0088}},	//   nauj, lává, инбо, jigu,
   {{0xef17479a,0x2240479b,0x3f8001dd,0xd007479c}},	// [4100] рму_, _uvik_, rdiu_, рете_,
   {{0x7c3e479d,0x9d46392c,0x63a40139,0x644e002a}},	//   tspr, режд, _hoin, ábig,
   {{0x63a4479e,0x98a700b8,0x9f400037,0x62863a07}},	//   _koin, raně_, iliú_, lvko,
   {{0x7c3e479f,0x63a447a0,0x753a0291,0x6ad10026}},	//   rspr, _join, zatz, तपूर,
   {{0x63a41010,0x63b647a1,0x7c3e47a2,0x7c2947a3}},	//   _moin, _mlyn, sspr, _čere,
   {{0x443e150b,0x63a447a4,0x7c3e47a5,0x63b600e9}},	//   yst_, _loin, pspr, _llyn,
   {{0x8c4347a6,0xb9c30082,0x7880000c,0x7b9602ce}},	//   _мере, تقوي, dává, _краї,
   {{0x63a447a7,0x443e47a8,0x96341a76,0x2ca747a9}},	//   _noin, vst_, бниц, ände_,
   {{0x753a0291,0x443e00e9,0x6b82016e,0x3b071784}},	//   tatz, wst_, mdog, _вето_,
   {{0x443e0a75,0xdb0047aa,0x6b8200b5,0x55060b32}},	//   tst_, _nomé, ldog, ична,
   {{0x753a03cb,0x443e47ab,0x63b6001e,0x63a447ac}},	//   ratz, ust_, _blyn, _boin,
   {{0x63a447ad,0x443e4091,0x753a47ae,0xa91c00ee}},	//   _coin, rst_, satz, _daľe,
   {{0x443e47af,0x753a06a2,0x63a447b0,0xdcfc009f}},	//   sst_, patz, _doin, _barċ,
   {{0x463b00c2,0xdb0047b1,0x7bcb018c,0x443e47b2}},	//   _יעדע, _comé, zigu, pst_,
   {{0xdb0047b3,0x63b6001e,0x63a4004f,0xa18400d8}},	//   _domé, _flyn, _foin, цыял,
   {{0x63a40122,0x6d5c47b4,0x63b600e9,0x200f00ab}},	//   _goin, _acra, _glyn, ögi_,
   {{0x7bcb47b5,0x6b8247b6,0xa91c07c0,0x69c804c1}},	// [4110] vigu, ddog, _maľb, _omde,
   {{0x71750bdf,0x00000000,0x00000000,0x00000000}},	//   _اهدا, --, --, --,
   {{0x6fb500f8,0x2ca70043,0x7bcb47b7,0x2d8101f4}},	//   _همدا, ând_, tigu, rdhe_,
   {{0x6d5c47b8,0x6f950037,0x6b80016e,0x6b820088}},	//   _ecra, _الحض, _camg, gdog,
   {{0x7bcb47b9,0x6b8047ba,0x673b00d8,0x60db00d0}},	//   rigu, _damg, vauj, ğumu,
   {{0x7bcb47bb,0x753847bc,0x6d5c0079,0xdcf50160}},	//   sigu, _nevz, _gcra, _cază,
   {{0x673b0029,0x7bcb47bd,0x98ac0139,0xb4d501d1}},	//   tauj, pigu, _redă_, _सखे_,
   {{0xba7701cb,0x69c80408,0x6b80016e,0xb21b008d}},	//   _پارت, _emde, _gamg, tvæl,
   {{0x63a404d6,0x673b47be,0x7bc9002f,0x9a840369}},	//   _roin, rauj, _imeu, _муфл,
   {{0x63a447bf,0x67da003c,0x63b6279f,0x7afb0065}},	//   _soin, rċja, _slyn, _izut,
   {{0x63a447a0,0x63b647c0,0xb50a073f,0xd90f00b5}},	//   _poin, _plyn, _हृदय_, _کیں_,
   {{0xe29a1ed5,0x798147c1,0xdb00002a,0x7bdb073a}},	//   гам_, _halw, _somé, _jjuu,
   {{0x6d4747c2,0x1b7a02b5,0x63a41bb1,0x798147c3}},	//   _odja, נטשע, _voin, _kalw,
   {{0xc6920122,0x6ec2046c,0x7bdb0207,0x00000000}},	//   _מאד_, _रेगु, _ljuu, --,
   {{0x63a40086,0x86220647,0x00000000,0x00000000}},	//   _toin, _وکیل, --, --,
   {{0x79810c1f,0x644109e1,0x442702a7,0x6d4747c4}},	//   _lalw, msli, _itn_, _adja,
   {{0xa3ad009a,0x24431707,0x8fa347c5,0x4427006d}},	// [4120] _गवत_, lım_, чате, _htn_,
   {{0x6b8047c6,0x7bc947c7,0x442747c8,0xfce60009}},	//   _samg, _ameu, _ktn_, бозо,
   {{0x24430d6f,0x644147c9,0xb53a0070,0x6b80012f}},	//   nım_, nsli, רגעש, _pamg,
   {{0x80c10083,0x442747ca,0x644102b1,0x673947cb}},	//   _শুক্, _mtn_, isli, _newj,
   {{0x7981018e,0x644101f7,0x244310b1,0x00000000}},	//   _balw, hsli, hım_, --,
   {{0x644147cc,0x09e307c1,0x3f820086,0x6d5c47cd}},	//   ksli, почн, _haku_, _ucra,
   {{0x5886021f,0x3f8200d6,0x7e640fe4,0x78b50095}},	//   сыла, _kaku_, ltip, _üzvl,
   {{0x244306d0,0xf0930122,0x64411e54,0x3f8247ce}},	//   dım_, לנו_, dsli, _jaku_,
   {{0x201a47cf,0x3f8247d0,0x6441053e,0x673908c7}},	//   _lupi_, _maku_, esli, _dewj,
   {{0x4427028b,0x3f821034,0x79812413,0x7e6400d7}},	//   _btn_, _laku_, _galw, itip,
   {{0x539900d4,0x395e0069,0x7e6402e2,0x24430225}},	//   авня_, _icts_, htip, gım_,
   {{0x61e10567,0x3f820dc3,0x7e6447d1,0xddcd0225}},	//   पक्ष, _naku_, ktip, ktaş,
   {{0x644301ef,0x6441053e,0x798147d2,0x44270210}},	//   _evni, asli, _yalw, _etn_,
   {{0x44270009,0x7e640009,0x69d847d3,0xf43400af}},	//   _ftn_, dtip, nnve, _декэ,
   {{0x201a0036,0x44260c26,0xd48f29d6,0xdc3c010b}},	//   _cupi_, _ارتف, _эр_, _išėj,
   {{0x1fa40272,0x442c0107,0x201a0088,0x7e7d00ee}},	//   пруг, mpd_, _dupi_, _pssp,
   {{0x680a006a,0x6e990f08,0xdcfc016f,0x7e642487}},	// [4130] _będz, швар_, _darč, gtip,
   {{0xbddb47d4,0x201a002f,0x628d01b7,0x9f5902d7}},	//   _evèn, _fupi_, _irao, _pisó_,
   {{0x6ad10c03,0x9f4001f7,0x387e023a,0xa3ad08b0}},	//   तप्र, boià_, _nstr_, _गवा_,
   {{0x2d9c47d5,0x798147d6,0x395e47d7,0x628d01cb}},	//   över_, _salw, _acts_, _krao,
   {{0x25f9009a,0x244306d3,0x69d8008a,0x6d4347d8}},	//   _उठली_, zım_, fnve, ónas,
   {{0x6e2d47d9,0x244306d3,0x644147da,0x3f820065}},	//   mpab, yım_, ysli, _zaku_,
   {{0x3f820088,0x321300d5,0x29fd07c0,0x387e00fe}},	//   _yaku_, _mixy_, _kňaz_, _cstr_,
   {{0x79810103,0x628d0009,0x395e47db,0x2d830418}},	//   _walw, _orao, _ects_, _haje_,
   {{0xe616342d,0x44270168,0x644147dc,0xfbd20319}},	//   оды_, _stn_, wsli, _חתן_,
   {{0x644147dd,0x244306d3,0x4427012f,0x2d83044d}},	//   tsli, tım_, _ptn_, _jaje_,
   {{0x87e72eb3,0xd46947de,0x628d47df,0x2d8347e0}},	//   _люде, шине_, _arao, _maje_,
   {{0x24430d6f,0x201a1445,0xe695028c,0x2d8347e1}},	//   rım_, _rupi_, _ولاد, _laje_,
   {{0x628d0094,0x244301d6,0x644147e2,0xbebb02a2}},	//   _crao, sım_, ssli, _geëx,
   {{0x628d006b,0x201a47e3,0x644109e1,0x2d8347e4}},	//   _drao, _pupi_, psli, _naje_,
   {{0xdcfc47e5,0x3f8236ee,0x03a61bca,0xf992011d}},	//   _parč, _paku_, _мико, ורם_,
   {{0xa3be05f8,0x628d04e6,0x7e6400c3,0x224d00ee}},	//   _इति_, _frao, ttip, šeka_,
   {{0x628d01dd,0xf7720100,0x2d8347e6,0x6e2d2487}},	// [4140] _grao, וקן_, _baje_, gpab,
   {{0xdd9209b9,0x201a0183,0x3f8247e7,0xda1d00ab}},	//   بوط_, _tupi_, _waku_, _पढ़त_,
   {{0x7e6447e8,0x3f8247e9,0x3f6a47ea,0x2a7f00ab}},	//   stip, _taku_, _кино_, _asub_,
   {{0x6d430093,0x2ca7013c,0x2b5f0176,0xcb6a35ec}},	//   ónar, ända_, _ccuc_, раде_,
   {{0x387e023a,0xdddd0168,0x00000000,0x00000000}},	//   _sstr_, _srsť, --, --,
   {{0x2d830129,0x77690051,0x00000000,0x00000000}},	//   _gaje_, efex, --, --,
   {{0x69d847eb,0xc7b80207,0x00000000,0x00000000}},	//   rnve, _luđe_, --, --,
   {{0xca7647ec,0xdb002f07,0x2d8347ed,0x466a3c60}},	//   _музы, _homí, _zaje_, аром_,
   {{0xdb000187,0x2d830010,0x00000000,0x00000000}},	//   _komí, _yaje_, --, --,
   {{0x28960202,0x2360013a,0x00000000,0x00000000}},	//   _мјес, _acij_, --, --,
   {{0x317847ee,0x00000000,0x00000000,0x00000000}},	//   derz_, --, --, --,
   {{0x28c304bc,0xdb0000fe,0x00000000,0x00000000}},	//   _वेटि, _lomí, --, --,
   {{0x9f4912c3,0xc6d600b5,0x6e220098,0x00000000}},	//   llaç_, _بتات, íobl, --,
   {{0x27e902dd,0x442c0ec7,0x6756103b,0xd8380359}},	//   čane_, ppd_, _ایکس_, _kwč_,
   {{0x2d8347ef,0x1fa7004b,0x855700a5,0x00000000}},	//   _raje_, ораг, _ושוב_, --,
   {{0x09b70c67,0x628d0341,0xcf980202,0x2d8347f0}},	//   _अत्य, _trao, оју_, _saje_,
   {{0x2d8347f1,0x00000000,0x00000000,0x00000000}},	// [4150] _paje_, --, --, --,
   {{0xc05b010b,0xdc8b0370,0xab5d0024,0xd6d90067}},	//   _кім_, исел_, _imżi, nała_,
   {{0xdb000179,0x417a00a5,0x2d8347f2,0xd8380260}},	//   _domí, _הנתב, _vaje_, _nwč_,
   {{0x207a00c2,0xbbb507ba,0x2d830848,0x307a02b5}},	//   _פארא, ंसेक, _waje_, _פארנ,
   {{0xbf9a02b8,0x200947f3,0x720a00b5,0x8f9a00a5}},	//   _הירש, mmai_, _خفیہ_, _הירי,
   {{0x200947f4,0xd838021e,0x00000000,0x00000000}},	//   lmai_, _bwč_, --, --,
   {{0x01380122,0xd6d90067,0xcb3502fb,0x00000000}},	//   חרות_, dała_, _невъ, --,
   {{0x2a7f006d,0x20092e6d,0x00000000,0x00000000}},	//   _tsub_, nmai_, --, --,
   {{0xe81b0b47,0x2a7f00be,0x00000000,0x00000000}},	//   _पूरा_, _usub_, --, --,
   {{0x77bc002a,0x316100ee,0x959900af,0x00000000}},	//   _réxe, _nchz_, стиу_, --,
   {{0x2009006c,0xc7b8022f,0xb9c40698,0x317847f5}},	//   kmai_, _suđe_, _تقلي, verz_,
   {{0x78fa00a5,0x00000000,0x00000000,0x00000000}},	//   _הפעו, --, --, --,
   {{0x65950b25,0x27ed47f6,0xd7c80088,0x00000000}},	//   _наду, moen_, _بونه_, --,
   {{0x7c2901c0,0x27ed47f7,0x4e1f007c,0x00000000}},	//   _čern, loen_, _बढ़ई_, --,
   {{0xf9920070,0x91030c98,0x00000000,0x00000000}},	//   ערל_, епре, --, --,
   {{0xef1a0674,0x20092bdf,0xc7b80254,0x27ed47f8}},	//   сма_, gmai_, _tuđe_, noen_,
   {{0xdee32bfa,0x7a190107,0x27ed0065,0xdce7005f}},	// [4160] еоти, _lňtb, ioen_, _kajė,
   {{0x27ed47f9,0x22440187,0x00000000,0x00000000}},	//   hoen_, ámku_, --, --,
   {{0x27ed47fa,0x711b02b5,0x61ee47fb,0x660f00a0}},	//   koen_, _לויפ, mobl, ícky,
   {{0xdb0009eb,0xe1ff0b4c,0x2009002d,0x161b3138}},	//   _româ, ntón_, cmai_, नदार_,
   {{0x27ed47fc,0xf38d0070,0x7bc301f4,0x25650260}},	//   doen_, יראָ, ënua, _kňlč_,
   {{0x61ee47fd,0x00000000,0x00000000,0x00000000}},	//   nobl, --, --, --,
   {{0x2d9801ff,0x27ed3b74,0x3157016b,0x38c800f8}},	//   _inre_, foen_, ליסן_, غاتی_,
   {{0x27ed47fe,0xd6d9004e,0x6d5e007c,0xdcfc00ea}},	//   goen_, wała_, lgpa, _garā,
   {{0x9f40006c,0x61ee47ff,0xa3c000df,0xd6d90067}},	//   llió_, kobl, ंघन_, tała_,
   {{0x6d5e4800,0x61ee00b8,0x273a0023,0xe1ff1c5b}},	//   ngpa, jobl, ẫn_, etón_,
   {{0x3dbe0083,0x200900d8,0xb4b60084,0x61ee4801}},	//   _আদাল, ymai_, छने_, dobl,
   {{0x394c0069,0x23bb0055,0xd6d90067,0x27ed0088}},	//   _hdds_, _bëja_, sała_, coen_,
   {{0xa3be02cb,0x2fc002ec,0x394c02d7,0x59b000b4}},	//   _इतर_, dhig_, _kdds_, _जकार,
   {{0xbf9b4802,0xa91c00a0,0xd49a01e0,0x00000000}},	//   _chên, _maľo, _гри_, --,
   {{0x657a4803,0x7c290009,0x20090409,0x00000000}},	//   meth, _čero, tmai_, --,
   {{0x657a4804,0x645a2793,0x2d980139,0x7dc00282}},	//   leth, muti, _anre_, _lösd,
   {{0x645a4805,0x61ee22c0,0xdb1b0183,0x00000000}},	// [4170] luti, bobl, _fluê, --,
   {{0xd9041c04,0x27ed4806,0x2bb50aad,0x200900e1}},	//   _می_, zoen_, ंस्थ, smai_,
   {{0x645a4807,0xdcfc0080,0x69c0258f,0xd2f900fd}},	//   nuti, _parā, वसनी, _دکھا_,
   {{0x4a75004b,0x657a00e2,0x394c024b,0x2249023a}},	//   дыкт, heth, _adds_, _kvak_,
   {{0x657a4808,0x645a4809,0xc5f80029,0xdcfc013a}},	//   keth, huti, klē_, _varā,
   {{0x645a1024,0x657a480a,0x3f89480b,0x00000000}},	//   kuti, jeth, ldau_, --,
   {{0x27ed480c,0xe7390086,0xb7b50023,0xdb090b88}},	//   toen_, оей_, _dụn, _koeë,
   {{0x645a480d,0x3f89480e,0x2249025c,0x96050567}},	//   duti, ndau_, _ovak_, रष्ट_,
   {{0x27ed3ecd,0x2b4d1eae,0x38672e19,0x645a0036}},	//   roen_, _idec_, stnr_, euti,
   {{0x27ed480f,0x657a4810,0x645a0054,0x00000000}},	//   soen_, geth, futi, --,
   {{0x645a4811,0x9f4b00b8,0x2bc400e7,0xdb000079}},	//   guti, _akcí_, लोका, _iomá,
   {{0xd6ce0164,0x657a016e,0xe3b9013b,0x98ac007e}},	//   اقی_, aeth, sqın_, _ledě_,
   {{0x3f890297,0x657a4812,0xdb004813,0xe1ff4814}},	//   ddau_, beth, _komá, rtón_,
   {{0xe1ff1111,0x657a01cb,0x213e0037,0x3f9900be}},	//   stón_, ceth, úth_, _ansu_,
   {{0x645a1116,0xc7b80019,0x2fc0016e,0x25650260}},	//   cuti, _ttđt_, thig_, _vňlč_,
   {{0xee3a4815,0x61ee18b0,0x3e660248,0x3a2d010d}},	//   жна_, sobl, tôt_, _otep_,
   {{0x7dc0186a,0x61ee0d9a,0x66e80055,0x68e40225}},	// [4180] _löse, pobl, mëkë, ğidi,
   {{0x3f8902c7,0x27e002dd,0xfd1200bf,0x3f86031d}},	//   adau_, čini_, نجا_, žou_,
   {{0xdb1902e9,0x93bd002d,0x6d5e4816,0x3a2d0118}},	//   viwò, mpăr, rgpa, _atep_,
   {{0x3e660248,0x2b4d0176,0x657a00b5,0xa91c00ee}},	//   pôt_, _cdec_, zeth, _paľo,
   {{0x657a023c,0xe1ff00b5,0x8e7500af,0x6d5e0159}},	//   yeth, któl_, _пурч, pgpa,
   {{0x082a42ee,0x7dc0033b,0xfaa30274,0x9f4002d7}},	//   оции_, _böse, таљо, plió_,
   {{0xdb0005d3,0xab2a0eb9,0x701c0033,0x657a0987}},	//   _domá, _мова_, _তবুও_, veth,
   {{0x645a4303,0xf76f211b,0x657a001e,0x4fbb0070}},	//   vuti, لاً_, weth, ַציא,
   {{0x6e220082,0x7bc24817,0xb4b6000c,0x657a0987}},	//   íobh, mhou, छन्_, teth,
   {{0x27e902f6,0xb8b603fa,0xfe9b00a5,0x332900f6}},	//   čana_, _осећ, קיימ, _sfax_,
   {{0xd7ef09eb,0x62840086,0x22494818,0x799a0010}},	//   _ау_, _asio, _svak_, _intw,
   {{0x645a4819,0x7bc202e6,0x28db057c,0xb21b008d}},	//   ruti, nhou, यपरि, kvæt,
   {{0x645a481a,0x6d4e0a78,0x7c29481b,0x7a190107}},	//   suti, _odba, _čerm, _kňta,
   {{0x7988481c,0x645a481d,0x3f89016e,0x5ec70033}},	//   _jadw, puti, wdau_, লপমে,
   {{0x79880484,0x291801ba,0x7bc2481e,0x69c6010b}},	//   _madw, _úrad_, khou, _įkel,
   {{0x80a01e79,0x98a7011c,0x64481789,0x661800ee}},	//   _ऑपरे, žiću_, msdi, _hivk,
   {{0x799a1c47,0x63ad481f,0x443c0221,0x7c2e00ea}},	// [4190] _ontw, _ioan, _hwv_, _atbr,
   {{0x443c0189,0x8d77036b,0x63ad01a5,0x7bc24820}},	//   _kwv_, بارا, _hoan, ehou,
   {{0xdb004821,0x3a2d0122,0x798a001e,0x2d8701ba}},	//   _romá, _step_, ddfw, ľne_,
   {{0x799a4822,0x2d870936,0x63ad4823,0x96ae00dc}},	//   _antw, žne_, _joan, टहाउ,
   {{0x63ad043d,0x79884824,0x443c01e8,0xdb00053d}},	//   _moan, _badw, _lwv_, _pomá,
   {{0x9f40008a,0xd6d90035,0x7988001e,0xf1bf4825}},	//   llið_, wało_, _cadw, mpás_,
   {{0x6d454826,0x79880090,0x7bc24827,0x20194828}},	//   maha, _dadw, bhou, _kisi_,
   {{0x6d454829,0x799a482a,0x7bc2482b,0x64481516}},	//   laha, _entw, chou, dsdi,
   {{0xdb000097,0x201926fb,0x6b9b0024,0xf77103fc}},	//   _tomá, _misi_, _inug, ناک_,
   {{0x6d45482c,0x77bc3612,0x77b51423,0x49740214}},	//   naha, _véxa, _máxi, _илус,
   {{0x69c30094,0x63ad482d,0x6618482e,0x6b9b008c}},	//   mhne, _boan, _divk, _knug,
   {{0x6d45482f,0x20194830,0xceb401c2,0x03a606e4}},	//   haha, _nisi_, yyə_, химо,
   {{0x6d450c47,0x63ad00e8,0x442e4831,0x6b894832}},	//   kaha, _doan, _etf_, _maeg,
   {{0x6d4506b3,0x443c0221,0x1aec0083,0x7bc24833}},	//   jaha, _fwv_, জেকে_, zhou,
   {{0x6d454834,0xc0e32360,0x7dc002c9,0x20190371}},	//   daha, горк, _lösc, _bisi_,
   {{0x67290831,0x63ad4835,0x93bd00af,0x66180207}},	//   ncej, _goan, spăr, _zivk,
   {{0x6d454836,0x76494837,0x62840054,0x20194838}},	// [41a0] faha, nsey, _usio, _disi_,
   {{0x6d454839,0x6b9b1d11,0x7bc231dc,0x443c01e8}},	//   gaha, _anug, whou, _ywv_,
   {{0x7bc2483a,0x69c301a6,0x443c0221,0x2019483b}},	//   thou, dhne, _xwv_, _fisi_,
   {{0x63ad483c,0x7988001e,0xbea62b34,0x6ecb046c}},	//   _xoan, _sadw, _замк, _सेकु,
   {{0x6d45483d,0x7bc20903,0x6b890069,0xb21b0c71}},	//   baha, rhou, _daeg, lvær,
   {{0x6d45124f,0x7bc21e78,0x69c3483e,0x58d4483f}},	//   caha, shou, ghne, колт,
   {{0x307a0070,0x7bc201bf,0x7c2e30f6,0x6b890024}},	//   לאַנ, phou, _utbr, _faeg,
   {{0x2d8a0acd,0x66184840,0x6b890107,0x6b9b0523}},	//   _habe_, _sivk, _gaeg, _gnug,
   {{0x7bc0227d,0x69c3009d,0x442e4841,0x63ad4842}},	//   _ilmu, bhne, _stf_, _roan,
   {{0x69c34843,0x932701cb,0x63ad4844,0xe9674845}},	//   chne, کردن, _soan, _паул_,
   {{0x61fc00e5,0x81d60083,0x644800d8,0x63ad4846}},	//   dlrl, িকা_, usdi, _poan,
   {{0xd5b80080,0x6d454847,0x2d8a4848,0x443c0118}},	//   skā_, zaha, _labe_, _vwv_,
   {{0x6d454849,0x63ad484a,0x2019484b,0x443c012f}},	//   yaha, _voan, _risi_, _wwv_,
   {{0x27e028c2,0x2019484c,0x7afd0c71,0x443c006f}},	//   činu_, _sisi_, _øste, _twv_,
   {{0x7bc00dac,0x442e484d,0x6d45484e,0x63ad00e2}},	//   _olmu, _utf_, vaha, _toan,
   {{0x77b51a71,0x6d451845,0x70e10354,0x00000000}},	//   _páxi, waha, _नशील, --,
   {{0x20193caa,0x9f40008d,0xa3d6021a,0x80d1021a}},	// [41b0] _visi_, rlið_, _िगत_, _डेरे,
   {{0x2d8a04a5,0x7bc0484f,0x9ce72ecf,0x20194850}},	//   _cabe_, _almu, нцел, _wisi_,
   {{0x6d454851,0x2d8a01d7,0x2019021e,0xf99f0023}},	//   raha, _dabe_, _tisi_, _đè_,
   {{0x6d454852,0x77b50132,0x7e690139,0x00000000}},	//   saha, _táxi, _ţepu, --,
   {{0x6d454853,0x69c309c3,0x6b892a4d,0x00000000}},	//   paha, thne, _vaeg, --,
   {{0x2d8a0291,0x7bc04854,0xfa340220,0x3f8b0027}},	//   _gabe_, _elmu, ارند, _hacu_,
   {{0x7e6d1402,0x3f8b4855,0x18a5061c,0x00000000}},	//   ltap, _kacu_, тайм, --,
   {{0x4ad20380,0x27e915d7,0xaad202d1,0x7649242d}},	//   _देवव, čano_, _देवक, tsey,
   {{0x7e6d4856,0x3f8b4857,0x69c30260,0xef1f0310}},	//   ntap, _macu_, phne, _raül_,
   {{0x76494858,0xdb0000a6,0xef1f4859,0x7afb0159}},	//   rsey, _domä, _saül_, _iyut,
   {{0x69c1485a,0x3947485b,0xef1f0176,0x76490a21}},	//   _ille, mans_, _paül_, ssey,
   {{0x3947485c,0x7d1a008d,0x7e6d485d,0x00000000}},	//   lans_, _útse, ktap, --,
   {{0x95850421,0xd29901e0,0x7dc0017b,0x00000000}},	//   _алле, нтрі_, _lösa, --,
   {{0x69c10176,0xdb1b0310,0x3f8b0312,0x00000000}},	//   _jlle, _lluï, _aacu_, --,
   {{0xa0670ea0,0xb21b054e,0x394701f7,0x2d8a485e}},	//   кара_, tvær, ians_, _rabe_,
   {{0x2d8a0d65,0xc2c60037,0x3f8b0027,0x61e500fe}},	//   _sabe_, _ليبي, _cacu_, _ejhl,
   {{0x3947485f,0x321a024e,0x69c10f67,0x7e6d4860}},	// [41c0] kans_, _tipy_, _olle, gtap,
   {{0x39474861,0xb21b2b6f,0x6296007b,0x2d8a01e9}},	//   jans_, svær, _iryo, _qabe_,
   {{0x39474862,0x7afb22be,0xdd8f097f,0xc1bb02b8}},	//   dans_, _ayut, تول_, _חמיש,
   {{0x2487002a,0x629600d5,0x22404863,0x3f8b0371}},	//   _msnm_, _kryo, _kwik_, _gacu_,
   {{0x39474864,0xaad2000c,0x4ad20af9,0xa3ea057c}},	//   fans_, _देशक, _देशव, _मदन_,
   {{0x7afb02b3,0x3f8b01d5,0x39474865,0x00000000}},	//   _dyut, _zacu_, gans_, --,
   {{0xdca30ca6,0x8c434866,0x3f8b0010,0xdb1b0392}},	//   _кари, _весе, _yacu_, _fluï,
   {{0x69c133d4,0xd90d0df3,0x77bc01ef,0xdb090952}},	//   _elle, سین_, _véxo, _cleó,
   {{0x39474867,0x83fd0254,0x7c291bd8,0x25ae023a}},	//   bans_, nuđe, _čeri, _pofl_,
   {{0x39474868,0x3d200067,0xe1ff470c,0x69c1099e}},	//   cans_, _बलों_, rtók_, _glle,
   {{0x7e6d01a3,0xb81b0067,0x6296437e,0xd76400b5}},	//   ztap, _पंचम_, _aryo, _منای,
   {{0x69d8024b,0xccf30122,0x629603d0,0x2ca72119}},	//   live, יכת_, _bryo, ändi_,
   {{0xe29801c8,0x645d010b,0x27e60088,0x83fd0207}},	//   ваў_, ąsia, _ijon_, juđe,
   {{0x72050037,0x69d84869,0x988200ee,0x3f8b034d}},	//   اوسم, nive, _míľa_, _sacu_,
   {{0x43950f16,0x3f8b486a,0x6296001c,0x00000000}},	//   _байс, _pacu_, _eryo, --,
   {{0x3947486b,0x69d8486c,0x645a2381,0x7e6d486d}},	//   zans_, hive, mrti, ttap,
   {{0x39470c1f,0x69d81e8b,0xdf44010b,0x2ceb00ab}},	// [41d0] yans_, kive, рэсп, _जुड़ल_,
   {{0x7e6d486e,0x645a0afc,0x3f8b01d5,0x69d808b7}},	//   rtap, orti, _wacu_, jive,
   {{0x7e6d05eb,0x3947486f,0x7afb00e7,0x2b4401f7}},	//   stap, vans_, _syut, _bemc_,
   {{0x645a23d5,0x83fd0254,0x5c040409,0xbddb02d0}},	//   irti, buđe, аяча, _avèt,
   {{0x39474870,0xb5fd0076,0x2b440a4e,0x69d8023a}},	//   tans_, luše, _demc_, five,
   {{0x69d80568,0xe81b13ab,0x1a68006c,0x6d340fa7}},	//   give, _पूजा_, ئیلی_, _верф,
   {{0x39474871,0x2d814872,0xddc4002d,0x7c8409ce}},	//   rans_, mehe_, stiţ, _куте,
   {{0x39474873,0x23690189,0x2d814874,0x7afb0008}},	//   sans_, _ncaj_, lehe_, _tyut,
   {{0x39474875,0x69d84876,0xdcfc0009,0x27e60107}},	//   pans_, bive, _parć, _djon_,
   {{0xb5fd0693,0x7dc0013c,0xceb202b5,0xddcd0035}},	//   kuše, _lösn, ציי_, jważ,
   {{0xddc44877,0x83fd02c4,0x59b80127,0xa3c00864}},	//   ntiš, zuđe, _अवतर, ंघल_,
   {{0xdb1b0443,0x62960260,0xb5fd0a69,0x27e60031}},	//   _lluí, _pryo, duše, _gjon_,
   {{0xe1ff004e,0x2d810118,0x673b4878,0xe2970aeb}},	//   ntów_, kehe_, mbuj, гая_,
   {{0x27ff4879,0x2d81025c,0xddc4010b,0xf1ce0067}},	//   llun_, jehe_, ktiš, होंन,
   {{0x057404e8,0xaf9a487a,0xb5fd00cd,0x22400051}},	//   _خاند, нтах_, guše, _wwik_,
   {{0xe1ff004e,0x200b01c0,0x69d84565,0x3945487b}},	//   któw_, _chci_, zive, _lels_,
   {{0xe81b0461,0xd24f00bc,0x412a487c,0xa2db0026}},	// [41e0] _पूछा_, _فني_, _попо_, _पेप्,
   {{0xdca603fa,0x69d80176,0x3a240345,0xd23b00a5}},	//   лази, xive, _rump_, _רגיל,
   {{0x27e9029d,0x3a2401a2,0x83fd011c,0x00000000}},	//   čanj_, _sump_, suđe, --,
   {{0x4fa6487d,0x0aea081b,0x6e3612ba,0xab2a1150}},	//   _симв, ндей_, ppyb, хода_,
   {{0x69d8487e,0xdb1b0b9f,0x6934006c,0x673b008b}},	//   tive, _fluí, لکار, dbuj,
   {{0x7c29086d,0x7d03033b,0x20000328,0x645a008d}},	//   _červ, ünsc, llii_, yrti,
   {{0x69d8362b,0x39454045,0xa2db0653,0x1d07487f}},	//   rive, _dels_, _पेन्, _бери_,
   {{0x69d84880,0x57b40346,0x8b954881,0x76aa2b65}},	//   sive, рбит, _круч, етов_,
   {{0x386e4882,0xa51c035d,0x00000000,0x00000000}},	//   stfr_, नश्च_, --, --,
   {{0x80ba0083,0x6b824883,0x645a08b7,0x59b81bdd}},	//   _উইন্, leog, trti, _अविर,
   {{0x8d5b0070,0x645a00f6,0xcdf7016b,0x00000000}},	//   עכטי, urti, רמיי_, --,
   {{0x1bf40461,0x645a4884,0x3cdc007c,0x6b824885}},	//   इकिल_, rrti, _गइने_, neog,
   {{0x59b80f39,0x63bd4886,0xdb1902b1,0x61f50a21}},	//   _अवार, rksn, chwä, tozl,
   {{0x645a08b7,0x6b820159,0x80d30033,0x00000000}},	//   prti, heog, _দুষ্, --,
   {{0xdb00116c,0x86070071,0x61f547bc,0xc9b700a5}},	//   _comú, _حقوق_, rozl, נהלת_,
   {{0xb5fd15d8,0x2d810118,0x200006bc,0x6e260118}},	//   ruše, wehe_, glii_, _bukb,
   {{0x6b824887,0x141c0122,0xa3ea00a1,0xbebb01f4}},	// [41f0] deog, _אוהב, _मदत_, _afër,
   {{0x21670ca6,0xb5fd012e,0xbddb000d,0x764201a8}},	//   _стиг, puše, _avèr, _mwoy,
   {{0x2d810657,0x80d300c8,0xcd072503,0x7642030d}},	//   rehe_, _দুর্, учаи, _lwoy,
   {{0x394500a2,0xa13404e8,0x6722002f,0x00000000}},	//   _sels_, _پریش, _ngoj, --,
   {{0x39450955,0xa96907be,0x2d814888,0xddc44889}},	//   _pels_, вила_, pehe_, stiš,
   {{0xa85504bf,0x9f520248,0x98551000,0xe1ff0035}},	//   атиј, voyé_, атиш, rtów_,
   {{0xe1ff006a,0xdb02008d,0x3945488a,0x5b37036b}},	//   stów_, skoð, _vels_, _معذر,
   {{0x9b890332,0x765b0831,0x98a5002d,0x5a350370}},	//   _جنرل_, truy, _află_, _внат,
   {{0x6d470452,0x66e5488b,0xdb09008a,0x3945488c}},	//   _keja, ропа, _gleð, _tels_,
   {{0xca740088,0x6d4734c7,0x3ea90176,0x00000000}},	//   _دافغ, _jeja, ixat_, --,
   {{0xa3ea488d,0x7983488e,0x6d47488f,0x76420107}},	//   _मदद_, menw, _meja, _ewoy,
   {{0x6d474890,0x798300e9,0x7e7d32d5,0x00000000}},	//   _leja, lenw, _opsp, --,
   {{0x75d50332,0x981403c7,0xe5a50165,0x6d55023a}},	//   _پيغا, _ابلا, _вили, _odza,
   {{0x6d474891,0x79830b17,0x865a00a5,0xdb0000ee}},	//   _neja, nenw, _ידני, _pomú,
   {{0x6e26011e,0x59b801c0,0x7e7d00ea,0x46d90066}},	//   _sukb, _अवसर, _apsp, _बेतह,
   {{0xa067051b,0xe2ca0088,0x4427002d,0x2fc94892}},	//   јата_, _لوبو_, _iun_, ghag_,
   {{0x44274893,0x6d474894,0xef1a0ddc,0x798302a2}},	// [4200] _hun_, _beja, тма_, kenw,
   {{0x442019c6,0x44274895,0x6d470453,0x79830051}},	//   _hii_, _kun_, _ceja, jenw,
   {{0x6d474896,0x44204897,0xa0a641f8,0x442703ed}},	//   _deja, _kii_, _танд, _jun_,
   {{0x44274898,0x2fc94899,0xfc030431,0x3e6f489a}},	//   _mun_, chag_, опхо, büt_,
   {{0x4420002d,0x7983489b,0x83fd0506,0x0a94010b}},	//   _mii_, fenw, nuđa, салю,
   {{0xe85402aa,0x7983489c,0x442702d0,0xe9f700d8}},	//   منتد, genw, _oun_, аніі_,
   {{0xfce3093c,0x80b60083,0x7c270069,0x4427489d}},	//   _доро, ৃপক্, _gujr, _nun_,
   {{0x44200ccf,0xdcfe0009,0x99dd0260,0x00000000}},	//   _nii_, nepč, _pwňc, --,
   {{0x4427489e,0x7983033b,0x00000000,0x00000000}},	//   _aun_, benw, --, --,
   {{0x77bc00c8,0x4427489f,0x44200211,0x7c200079}},	//   _méxi, _bun_, _aii_, _himr,
   {{0x44271a71,0x2fc00136,0x77bc31f4,0x778601b8}},	//   _cun_, kkig_, _léxi, _влез,
   {{0x442748a0,0xe73a010c,0x07a348a1,0x672248a2}},	//   _dun_, _ред_, _махн, _ugoj,
   {{0x442748a3,0x659400d4,0x2c510035,0xdcee0228}},	//   _eun_, _галу, ząd_, _babī,
   {{0x44271f41,0x2fc9011e,0x7c2048a4,0x2fc00223}},	//   _fun_, whag_, _limr, ekig_,
   {{0x4427004a,0x44200043,0x0ce10033,0xdcee0228}},	//   _gun_, _fii_, _ভর্ত, _dabī,
   {{0x6d470614,0x442037af,0xee1f00b4,0x2fc048a5}},	//   _seja, _gii_, बद्ध_, gkig_,
   {{0xd2510082,0x6d470452,0x442748a6,0x5d550bff}},	// [4210] _عند_, _peja, _zun_, йкат,
   {{0x44270269,0x27e902dd,0x7c201c8b,0x44203a69}},	//   _yun_, čani_, _aimr, _zii_,
   {{0x442714f3,0x4095004f,0x7c290187,0x6d4748a7}},	//   _xun_, _الجر, _čers, _veja,
   {{0x442048a8,0x0c240804,0x7c2048a9,0x2fc009af}},	//   _xii_, імін, _cimr, ckig_,
   {{0x6d470453,0x2d87000d,0x7983326c,0x7c200031}},	//   _teja, ônes_, tenw, _dimr,
   {{0xb5fd48aa,0xb6020187,0x389500ea,0x6db506d8}},	//   kuša, _žánr, _pār_, _уйгу,
   {{0xb5fd0029,0x798348ab,0x6e2d0510,0xed0500b5}},	//   juša, renw, lqab, _طورپ,
   {{0x44270122,0xb5fd11c6,0xf7710037,0x7983326c}},	//   _run_, duša, ساب_, senw,
   {{0x26cd0bec,0x2d910c21,0x442748ac,0x442048ad}},	//   uzeo_, _kaze_, _sun_, _rii_,
   {{0x442048ae,0x442748af,0x69ca48b0,0xf9d40012}},	//   _sii_, _pun_, chfe, _доуэ,
   {{0x2d910232,0x442048b1,0x69fa02b5,0x80dc0033}},	//   _maze_, _pii_, _עלעק, _মুন্,
   {{0x442700cc,0x4815382e,0x9cd600a5,0xdfe3046c}},	//   _vun_, _умес, מותה_, _गदगद_,
   {{0x442048b2,0x1af70083,0x79a4002d,0x00000000}},	//   _vii_, েশকে_, _урӂе, --,
   {{0x442748b3,0x44202464,0xa06a48b4,0x77bc0391}},	//   _tun_, _wii_, лага_, _réxi,
   {{0x442048b5,0xd4350071,0x40952f44,0x8fa648b6}},	//   _tii_, _اعتب, ортт, баве,
   {{0x44200feb,0x98b00009,0x00000000,0x00000000}},	//   _uii_, žaću_, --, --,
   {{0x2d9148b7,0x63a448b8,0x2a7f006d,0xd00748b9}},	// [4220] _baze_, _inin, _npub_, сете_,
   {{0x7c20037d,0xef170274,0x63a400e0,0xd8380207}},	//   _simr, сму_, _hnin, _hrče_,
   {{0x63a401a0,0xa3be252c,0x46d9046c,0xd83802a7}},	//   _knin, _ेता_, _बेसह, _krče_,
   {{0xc7b800cb,0xcb0a00e0,0xe1ff01f7,0xf456016b}},	//   _tuđi_, هيان_, btós_, מיער_,
   {{0xaad20299,0x7e6448ba,0x69ca48bb,0x8eba09eb}},	//   _देखक, quip, thfe, _сынт_,
   {{0xcaa5004f,0x2244024e,0x9f49008a,0x98be0160}},	//   تصمي, ámky_, llað_, _netă_,
   {{0xc0f20019,0x2a7f16b5,0x63a448bc,0x7c2048bd}},	//   _rượu_, _epub_, _onin, _timr,
   {{0x63b648be,0xb5fd48bf,0x963448c0,0x69ca0055}},	//   _noyn, vuša, ониц, shfe,
   {{0xa37b0370,0xcf930122,0x00000000,0x00000000}},	//   niõe, לטה_, --, --,
   {{0x63a448c1,0x7bc20159,0x54541e5b,0x758a0043}},	//   _anin, lkou, овот, усив_,
   {{0x29370779,0x26c248c2,0xc7af0086,0x63a4011e}},	//   _האבן_, ško_, _её_, _bnin,
   {{0x7bc248c3,0x63b6009e,0x290c48c4,0xb5fd0eac}},	//   nkou, _coyn, _izda_, ruša,
   {{0xadfa12e7,0xa3ea0026,0x63a445bd,0x59be00b4}},	//   ्तान_, _मदर_, _dnin, ्सपर,
   {{0xb5fd48c5,0x236d004e,0x63a448c6,0x7bcb0031}},	//   lušn, żej_, _enin, zhgu,
   {{0x2d9148c7,0x7bc20421,0xe1ff0098,0x00000000}},	//   _raze_, kkou, hróg_, --,
   {{0x543b00c2,0x628d0037,0x290c0097,0x69c80176}},	//   _געהא, _tsao, _mzda_, _llde,
   {{0xa37b03e6,0x69c806ae,0x628d0009,0x98bc010b}},	// [4230] giõe, _olde, _usao, ravę_,
   {{0xd83848c8,0x00000000,0x00000000,0x00000000}},	//   _zrče_, --, --, --,
   {{0xb5fd02c6,0x9f490093,0x2d9100f4,0x249c1491}},	//   kušn, blað_, _vaze_, _jrvm_,
   {{0x69c848c9,0xfd10004f,0x69da48ca,0xf8a900d1}},	//   _alde, رجل_, _amte, یگاه_,
   {{0x957c004e,0xd838021e,0x290c48cb,0x2d914741}},	//   ciąg, _atč_, _azda_, _taze_,
   {{0x7bc248cc,0x957c0035,0xdb1b0443,0x00000000}},	//   akou, niąd, _lluç, --,
   {{0xd90e0332,0xe1ff0093,0x69da0282,0x00000000}},	//   ہیے_, próf_, _dmte, --,
   {{0x7bc2230a,0x69c808ee,0x6fc948cd,0x00000000}},	//   ckou, _elde, रसिं, --,
   {{0x7bdb0345,0x969400af,0x00000000,0x00000000}},	//   _imuu, прэш, --, --,
   {{0x63a448ce,0xb5fd48cf,0x64460207,0x00000000}},	//   _snin, krše, ćkin, --,
   {{0x7bc90a45,0xa50905c2,0x6d580079,0x638648d0}},	//   _kleu, рена_, óvai, огна,
   {{0x645c0370,0xe29a031a,0xf1a932e3,0x63b6013b}},	//   ária, аам_, _בס_, _qoyn,
   {{0x63b601ef,0xbddb0107,0x98a5005f,0x00000000}},	//   _voyn, _pwèl, _kelį_, --,
   {{0x83fd0f44,0x38a00043,0x7bc903b6,0x69c32d20}},	//   vrđe, _fără_, _lleu, nkne,
   {{0x7bc9016e,0xd83800cd,0x7bc200f6,0x9f49008d}},	//   _oleu, _trče_, ykou, tlað_,
   {{0x63a448d1,0x7c29024e,0x0fb30035,0x6fda00b8}},	//   _unin, _čerp, ीसगढ, můck,
   {{0x82360754,0xee3748d2,0x7dc00282,0x0ec40067}},	// [4240] _بربا, жну_, _hösi, लैंड,
   {{0x7bc948d3,0x7bdb48d4,0x715a00af,0xb5fd00f4}},	//   _aleu, _amuu, _трис_, zušn,
   {{0x7bc90248,0xc2e9006c,0xa37b0132,0xc8d800ab}},	//   _bleu, _نعیم_, siõe, _भेंट,
   {{0xa2c10084,0x61fc00af,0xcb6700d8,0x2d0a0099}},	//   रैक्, lorl, жаце_, _वरील_,
   {{0xf38d02b5,0x7bc248d5,0x00000000,0x00000000}},	//   טראָ, rkou, --, --,
   {{0x61fc48d6,0x3e7400c3,0x7bc248d7,0x7e761b99}},	//   norl, mät_, skou, mtyp,
   {{0xa967282d,0x7bc948d8,0x7e7648d9,0x91a900e2}},	//   ција_, _fleu, ltyp, _quả_,
   {{0xcb6748da,0x7bc948db,0xef1f0176,0x17f70037}},	//   _масе_, _gleu, _taüt_, يرية_,
   {{0x61fc006c,0x7e7648dc,0xa96a0bd7,0x3e741a06}},	//   korl, ntyp, _виза_, nät_,
   {{0xd5ba48dd,0x69c32cfc,0xe80a0722,0xb5fd00cd}},	//   рси_, ckne, _हीरा_, sušn,
   {{0x61fc48de,0x7e7601f4,0xb5fd0293,0x443848df}},	//   dorl, htyp, pušn, ër_,
   {{0xb5fd01cc,0x3e7448e0,0x47c30102,0x7e760051}},	//   vrše, kät_, _обхв, ktyp,
   {{0x671600c0,0x61fc48e1,0x394c02d7,0x3e740086}},	//   देशक_, forl, _keds_, jät_,
   {{0xdb000391,0x61fc48e2,0x35f748e3,0x7e7648e4}},	//   _homó, gorl, _ورود_, dtyp,
   {{0x7e7601a2,0xdb00004e,0xc1050037,0x00000000}},	//   etyp, _komó, سوري, --,
   {{0xd9c20033,0x394c48e5,0x443e48e6,0xc7b800cd}},	//   ্চিম, _leds_, mpt_, _tuđu_,
   {{0x443e48e7,0x7e7648e8,0x61fc05f5,0x394c0223}},	// [4250] lpt_, gtyp, borl, _oeds_,
   {{0x7bc9152b,0x443e0120,0xdd910037,0x224900f8}},	//   _sleu, opt_, عوا_, _iwak_,
   {{0x7bc948e9,0xc1720122,0x0cab0279,0x98bc00b8}},	//   _pleu, _אחי_, штаи_, ravě_,
   {{0x70fa0122,0x60fa0122,0x22490fbc,0x443e48ea}},	//   _להתח, _להתק, _kwak_, ipt_,
   {{0xbf360317,0x3f8948eb,0x7bc919c1,0x7c3e0d35}},	//   _מארץ_, meau_, _vleu, appr,
   {{0x22490054,0x3f8900a2,0xb5fd00cd,0xdeba00a5}},	//   _mwak_, leau_, gušl, _המשל,
   {{0x69c348ec,0x443e01e4,0xdd5800af,0x225e0067}},	//   rkne, jpt_, _фасч_, ątki_,
   {{0x7bdb0dc3,0x3f8948ed,0xdb000037,0x7b08008d}},	//   _umuu, neau_, _comó, ðstæ,
   {{0x61fc01d6,0xab6600ab,0x443e48ee,0xddcd002d}},	//   yorl, stüü, ept_, ctaţ,
   {{0x49b8126b,0xb5fd33c1,0xdcfc0009,0x6e3b033e}},	//   _والد_, rušo, _zarđ, _çubu,
   {{0x61fc0c61,0x224906d4,0x64a500d8,0x92e80033}},	//   vorl, _awak_, чана, _ভরে_,
   {{0x7e761b99,0x2b4d0176,0x00000000,0x00000000}},	//   ytyp, _jeec_, --, --,
   {{0x61fc144d,0x3f8948ef,0x443e02a2,0x290501ef}},	//   torl, deau_, apt_, _hyla_,
   {{0x3e740d36,0x3cdc0006,0x290548f0,0xd83800ee}},	//   vät_, _गइले_, _kyla_, _hrča_,
   {{0x5502004e,0x61fc48f1,0x8fa600d8,0x77bc01dd}},	//   _रुपए_, rorl, паве, _téxt,
   {{0x3e7448f2,0x09b80266,0x2905010d,0x4abd2e64}},	//   tät_, _अव्य, _myla_, ्नाव,
   {{0x61fc48f3,0x00000000,0x00000000,0x00000000}},	// [4260] porl, --, --, --,
   {{0x3e7448f4,0x7d1a008a,0x7dc00523,0x5f76132d}},	//   rät_, _útsk, _lösv, _کادر,
   {{0x7e7607a0,0x91bb00a5,0x3f890db4,0x3e740421}},	//   styp, _המיי, beau_, sät_,
   {{0x3f8948f5,0xcb6a0274,0x00000000,0x00000000}},	//   ceau_, саде_, --, --,
   {{0x20020051,0x7f4448f6,0xf1b00803,0xc333011d}},	//   _ikki_, mbiq, ञापन, גוד_,
   {{0x2905000c,0x443e2129,0x00000000,0x00000000}},	//   _byla_, ypt_, --, --,
   {{0xdb00004e,0x7dcb0035,0x6d5c48f7,0x23cc022e}},	//   _pomó, yższ, _idra, ासाद,
   {{0x6d4e0452,0xf09302b8,0x394c3889,0x2905005f}},	//   _heba, תנה_, _weds_, _dyla_,
   {{0x6d4e0464,0x5aca0210,0x7c2e3236,0x6d5c055c}},	//   _keba, _улам_, _hubr, _kdra,
   {{0x645c051b,0x6d4e48f8,0x7c2e48f9,0xddd60035}},	//   ário, _jeba, _kubr, jwyż,
   {{0x2249053e,0x443e01ae,0x493b0122,0x41b00b35}},	//   _swak_, upt_, _הגבו, ञानस,
   {{0x6d4e48fa,0xd8381bd8,0x7c2e0118,0x6284053f}},	//   _leba, _grča_, _mubr, _bpio,
   {{0x6d5c0888,0x3f8948fb,0xd7a900a1,0x35a611d0}},	//   _odra, veau_, कारच, _надг,
   {{0x171b01f3,0x6d4e48fc,0x443e48fd,0x6d5c48fe}},	//   _הודע, _neba, ppt_, _ndra,
   {{0x3f8948ff,0x3cdc02cb,0x628401ed,0x00000000}},	//   teau_, _गेले_, _epio, --,
   {{0x6d5c0297,0x83fd0009,0x6284009e,0x6d4e0065}},	//   _adra, brđa, _fpio, _aeba,
   {{0x3f894900,0x6d4e402e,0x7dc002c9,0x443c4901}},	// [4270] reau_, _beba, _lösu, _htv_,
   {{0x20022ea0,0x3f8902e1,0x7c2e4902,0x6d4e4903}},	//   _ekki_, seau_, _bubr, _ceba,
   {{0x7c2e0f56,0x3f894904,0x6d5c00e9,0x6aa00069}},	//   _cubr, peau_, _ddra, _armf,
   {{0x7c2e1b8d,0x09c5012f,0x2c750c60,0x442e4283}},	//   _dubr, वस्य, råd_, _muf_,
   {{0x7e644905,0x6d4e0103,0x443c123c,0x442e0282}},	//   crip, _feba, _ltv_, _luf_,
   {{0x6d4e1892,0x20090297,0x64584906,0x443c2909}},	//   _geba, llai_, _ovvi, _otv_,
   {{0x6d454374,0xfc6401d3,0xa37b00ab,0x00000000}},	//   mbha, _пътн, lnõu, --,
   {{0x6d5c4907,0x6d45004a,0x6d4e4908,0x2a602b6c}},	//   _zdra, lbha, _zeba, šiba_,
   {{0x442e328b,0xb9044909,0x6458490a,0x6d45066a}},	//   _auf_, _पे_, _avvi, obha,
   {{0x6b8b0044,0x6d4509c3,0x443c490b,0x6d4e01ed}},	//   legg, nbha, _btv_, _xeba,
   {{0x62842c46,0x442e000e,0x6d45490c,0x2009010b}},	//   _spio, _cuf_, ibha, klai_,
   {{0xe72e490d,0xf77001ca,0x6b8b490e,0x6d450014}},	//   _је_, _ماه_, negg, hbha,
   {{0xe56e490f,0x27ff0c1f,0x27380028,0x443c007c}},	//   _из_, moun_, _ứng_, _etv_,
   {{0x6b8b02fb,0x27ed16ad,0x443c4910,0x6e270051}},	//   hegg, lnen_, _ftv_, _nijb,
   {{0x27ed34e6,0x957c004e,0x6d450079,0x6d5c00d7}},	//   onen_, siąc, dbha, _rdra,
   {{0x27ed4911,0x6d4e1760,0x64414912,0x7e644913}},	//   nnen_, _seba, mpli, trip,
   {{0x27ed4914,0x22160439,0x6b8b4915,0xd12f006c}},	// [4280] inen_, _офор, degg, امہ_,
   {{0x3f4c0028,0x27ed02c9,0x7e644916,0x00000000}},	//   ếu_, hnen_, rrip, --,
   {{0x64414917,0x7c2e4918,0x225e0035,0xeb9a1bb1}},	//   npli, _qubr, ątku_, жие_,
   {{0x27ed0a75,0x6d4e02ce,0xddcd4919,0xab830086}},	//   jnen_, _weba, rtaš, вушк,
   {{0x6d4e0273,0xddcd0254,0x602707c0,0x27ed0110}},	//   _teba, staš, _kŕmn, dnen_,
   {{0x27ed491a,0x7c2e491b,0xb5fd012e,0x6d4300d0}},	//   enen_, _tubr, sušj, ınac,
   {{0xdcfc0080,0xd7a902cb,0x27ed01ae,0x6441006d}},	//   _varē, कांच, fnen_, jpli,
   {{0x27ed318b,0x442e491c,0xb5fd0bec,0x2d983dd1}},	//   gnen_, _ruf_, vrša, _hare_,
   {{0x2d98491d,0x443c01ba,0x7dc0008a,0x442e491e}},	//   _kare_, _stv_, _föst, _suf_,
   {{0x7dc006a8,0xaa4328ea,0x89160e6b,0x2d98491f}},	//   _göst, _рефл, _قبائ, _jare_,
   {{0x9cec0b52,0x2d984920,0x98c50009,0x200900e9}},	//   _করুন_, _mare_, _čuće_, ylai_,
   {{0x443c4921,0x2d9800d1,0x61ee43c1,0x442e23a9}},	//   _vtv_, _lare_, enbl, _vuf_,
   {{0x2d98002d,0xdcf50029,0x83fd0009,0xdb1902b1}},	//   _oare_, _pazī, nuđi, ckwä,
   {{0x8c140083,0xb5fd4922,0x2d984923,0x6b8b01e4}},	//   িদিন_, prša, _nare_, zegg,
   {{0x6e2701e4,0x7c3b0009,0x443c0103,0x26c400c7}},	//   _rijb, _čuro, _utv_, lymo_,
   {{0x2a664924,0x2d9800be,0x6e270051,0xa80501ef}},	//   krob_, _aare_, _sijb, miñá,
   {{0xd90400d1,0x3f82028b,0x6b8b34b7,0x2d98293a}},	// [4290] _چی_, _dbku_, vegg, _bare_,
   {{0x44290221,0xd90402fd,0x2d980122,0x6d4500f1}},	//   _hia_, _نی_, _care_, ubha,
   {{0x442901a5,0x7dc0022a,0x6d450094,0x6b8b4925}},	//   _kia_, _röst, rbha, tegg,
   {{0x26c400d8,0xb5fd219e,0x7dc0017b,0x00000000}},	//   kymo_, tušk, _böss, --,
   {{0x44294926,0x6b8b4927,0x2d984928,0x27ed0b41}},	//   _mia_, regg, _fare_, vnen_,
   {{0x44294929,0x2d98492a,0x26c400d8,0xb5fd3c56}},	//   _lia_, _gare_, dymo_, rušk,
   {{0x442901ef,0x3f99492b,0x6b8b492c,0x7e6d492d}},	//   _oia_, _kasu_, pegg, luap,
   {{0x27ed492e,0x4429492f,0x64414930,0xb5fd4931}},	//   unen_, _nia_, vpli, pušk,
   {{0x3f994932,0x27ed4933,0x27ff4934,0x2fc90cca}},	//   _masu_, rnen_, roun_, ikag_,
   {{0x7c293dd0,0xe61615eb,0x44294935,0xe9380148}},	//   _hier, нды_, _aia_, _قسمت_,
   {{0x7c294936,0x44294937,0xf3e619b6,0xb5fd00ec}},	//   _kier, _bia_, ежно, nuši,
   {{0x7c29081b,0x44294938,0x64411192,0x603c0107}},	//   _jier, _cia_, rpli, _jčme,
   {{0x44294939,0x7c29493a,0x2d830c21,0x5275493b}},	//   _dia_, _mier, _obje_, куру,
   {{0xb5fd493c,0x6441493d,0x645500b5,0x00000000}},	//   kuši, ppli, ázis, --,
   {{0xf50500d4,0xb5fd00ea,0x61ee493e,0x2d9831e4}},	//   _язко, juši, rnbl, _rare_,
   {{0x442900e8,0x35c50299,0x2d98493f,0x7c294940}},	//   _gia_, _लकड़, _sare_, _nier,
   {{0x9cec00c8,0x7dd2054e,0x7e6d0159,0x3f99008c}},	// [42a0] _করেন_, _læse, guap, _dasu_,
   {{0xddc40690,0x44294941,0x22400fef,0x2b5f002d}},	//   stiž, _zia_, _itik_, _aduc_,
   {{0x7c294942,0x2d9804ca,0x3a3f011e,0xb5fd2c14}},	//   _bier, _vare_, _atup_, guši,
   {{0x7c294943,0x2d9802c0,0xf8b00105,0xf43a0070}},	//   _cier, _ware_, یکا_, לגעמ,
   {{0x2d980043,0x7c294944,0xb5fd10ec,0x66013ae1}},	//   _tare_, _dier, vršn, kolk,
   {{0x98a50463,0x2b5f009e,0x7c291ead,0xb5fd3c2c}},	//   _adlı_, _educ_, _eier, buši,
   {{0x3ea00139,0xb5fd0009,0x83fd011c,0x7c293672}},	//   lvit_, cuši, suđi, _fier,
   {{0x26c400d8,0xf76f00ad,0xdb2101ae,0x7adb0026}},	//   tymo_, ماً_, _äuße, _मेकअ,
   {{0xe1ff2675,0x660104ca,0xc6f802ce,0xadf40afa}},	//   drón_, folk, ьних_, _आदान_,
   {{0x44294945,0x66014946,0xa3e30d1f,0x7c294947}},	//   _sia_, golk, फोन_, _zier,
   {{0xd7ef0ff6,0x442919c6,0x22400c1f,0x62960260}},	//   _бу_, _pia_, _atik_, _asyo,
   {{0x87da2087,0x442901e8,0x07da036b,0x6035010b}},	//   _عباس_, _qia_, _عذاب_, _sąmo,
   {{0x44294948,0x6601379a,0x518741d9,0x3f994949}},	//   _via_, bolk, нува, _rasu_,
   {{0x80b50f17,0x799a0069,0x248702a7,0x7dd20a8a}},	//   _उपदे, _jatw, _fpnm_, _læsb,
   {{0x4429494a,0x3f99494b,0x2240494c,0xe1ff0d2e}},	//   _tia_, _pasu_, _etik_, brón_,
   {{0x645a317d,0xb5fd494d,0x7e6d494e,0x7dd20a8a}},	//   msti, vuši, tuap, _næsb,
   {{0x63ad494f,0x645a1eef,0x7c290443,0x3f9933ee}},	// [42b0] _inan, lsti, _rier, _vasu_,
   {{0x7c294950,0xf41f0086,0x799a01d5,0xb21b01b4}},	//   _sier, lmä_, _natw, dtæg,
   {{0x7c29142b,0x3a3f4951,0x3f9900ab,0x00000000}},	//   _pier, _stup_, _tasu_, --,
   {{0xeaec0437,0x7c290453,0x7dd20a8a,0x00000000}},	//   जपूत_, _qier, _ræse, --,
   {{0x7c294952,0x2bb80082,0x645a0284,0xb5fd03c9}},	//   _vier, عامة_, hsti, suši,
   {{0x645a4953,0x7c29004e,0xb5fd0124,0xf41f0086}},	//   ksti, _wier, puši, hmä_,
   {{0x7c294954,0x660103c4,0x645a4955,0x83fd0124}},	//   _tier, volk, jsti, luđu,
   {{0x645a4956,0xf41f016f,0x7dd201b4,0xdb2300d1}},	//   dsti, jmä_, _væse, _موزی,
   {{0xdb000a8c,0xdcfc005f,0x6b9b0409,0x00000000}},	//   _anmæ, _barė, _iaug, --,
   {{0x63ad4957,0x6b9b01e0,0x799a159c,0x645a4958}},	//   _anan, _haug, _gatw, fsti,
   {{0x6b9b4959,0xe1ff495a,0x2240495b,0x645a2ce1}},	//   _kaug, trón_, _stik_, gsti,
   {{0xa3dc004e,0x2240012f,0x7bcb495c,0x63ad0069}},	//   णों_, _ptik_, nkgu, _cnan,
   {{0x6b9b495d,0xe1ff364e,0x799a1815,0x63bf0069}},	//   _maug, rrón_, _yatw, _doqn,
   {{0xf5050525,0x63ad495e,0x6b9b495f,0x645a4960}},	//   _изло, _enan, _laug, bsti,
   {{0x1c110084,0x248700d7,0x6d5701ed,0xdd920df3}},	//   ़ताल_, _upnm_, daxa, یور_,
   {{0x6b9b4961,0x673b0097,0xe1ff00b5,0xdb000168}},	//   _naug, ncuj, lról_, _komô,
   {{0x35a60722,0xd00728a1,0x2a7d006d,0x69ca0a8a}},	// [42c0] _कोड़, тете_, jtwb_, ykfe,
   {{0x63ad4962,0xdca62641,0xa2db0f17,0x3ea04963}},	//   _znan, кази, _पेट्, rvit_,
   {{0x6b9b4964,0x9f400037,0x3ea04965,0x00000000}},	//   _baug, iniú_, svit_, --,
   {{0x9f40004f,0xfdbd02e4,0x799a00e7,0xaa461109}},	//   hniú_, ोसॉफ, _satw, ведл,
   {{0xdaba00bf,0x799a02e9,0xe1ff006c,0x6d574966}},	//   بهشت_, _patw, król_, baxa,
   {{0x645a4967,0x9d430043,0x799a0103,0x00000000}},	//   ysti, _верд, _qatw, --,
   {{0x7d03033b,0x38c800d1,0x8b962123,0xf41f0421}},	//   ünst, عاتی_, _ирач, ymä_,
   {{0x645a4968,0x799a3772,0x6b9b190f,0x2c7c4969}},	//   vsti, _watw, _gaug, míd_,
   {{0x4b7b02b5,0x645a496a,0x799a496b,0x60c70035}},	//   _קאמו, wsti, _tatw, zyjm,
   {{0x645a0557,0x7bc001a2,0xd6d90035,0x9f400079}},	//   tsti, _homu, nały_, gniú_,
   {{0xc8ca00bf,0x81c90083,0xdcfc010b,0x7afd1217}},	//   _توان_, লোড_, _varė, _østr,
   {{0xf746496c,0x673b0036,0x3d1a0035,0x7bc0496d}},	//   _редо, ccuj, _भरने_, _jomu,
   {{0xe737496e,0x7bc00088,0xf41f169c,0x7ae40098}},	//   _реч_, _momu, rmä_, úith,
   {{0x7bc0030d,0x8af700a8,0x9f490079,0x2c4a0409}},	//   _lomu, _şəkl, rnaí_, _kėdę_,
   {{0xcf9b0370,0x61e70223,0x6fca00ac,0x3a2c496f}},	//   мја_, rijl, _kých, _midp_,
   {{0x63ad0269,0x7bc03a3c,0x938b20e3,0x00000000}},	//   _unan, _nomu, _цска_, --,
   {{0x6d570392,0x3f15061c,0x8e3800fd,0x290c0523}},	// [42d0] taxa, удас, نسلر_, _lyda_,
   {{0xab5d006a,0x6b9b01c8,0x9d550037,0xddc40009}},	//   _może, _saug, انات, tuiš,
   {{0x6d574970,0x6b9b4971,0x7bc01f79,0xb5fd00c7}},	//   raxa, _paug, _bomu, mušt,
   {{0x80dc00c8,0x6d570282,0x8af700a8,0xddc40009}},	//   _মুক্, saxa, _çəkm, ruiš,
   {{0x7bc04972,0x290c00d0,0x764204fb,0xbebb0055}},	//   _domu, _ayda_, _ntoy, _egër,
   {{0x6b9b2494,0xbddb0107,0x00000000,0x00000000}},	//   _waug, _vwès, --, --,
   {{0xdb0006d7,0xe7393a4d,0x6d554973,0x6b9b3135}},	//   _anmä, ней_, _ieza, _taug,
   {{0xccf202da,0x7c3a02e1,0xdb00016f,0x9d181397}},	//   _הכל_, _étra, _pomô, _рост_,
   {{0x5a342eb3,0x6d551e77,0x6fca0187,0x59a40026}},	//   _внут, _keza, _dých, _गोवर,
   {{0x6d551b71,0xb5fd0506,0x00000000,0x00000000}},	//   _jeza, jušt, --, --,
   {{0x290c02c7,0x6d554974,0xa3ea01b8,0xdcfc0160}},	//   _gyda_, _meza, една_, _ibră,
   {{0x6d554975,0x61e50315,0x69b90026,0xe1ff00b5}},	//   _leza, _amhl, _एचडी, sról_,
   {{0x5b7a016b,0xdce70168,0x00000000,0x00000000}},	//   ערשא, _najľ, --, --,
   {{0x6d5505ed,0x69c14976,0xe7f60066,0x61e50211}},	//   _neza, _jole, ुकथा_, _cmhl,
   {{0x394200a8,0xdb19033b,0xdcfc0160,0x63af0098}},	//   _əks_, chwö, _mbră, áiní,
   {{0xd6d9004e,0xb5fd0187,0x00000000,0x00000000}},	//   wały_, rušu, --, --,
   {{0x6d554977,0x0d861f7c,0x7bc04978,0xb5fd0693}},	// [42e0] _beza, ллан, _romu, vršj,
   {{0x6d554979,0xb5fd0a78,0x69c1497a,0x02b700a5}},	//   _ceza, dršk, _nole, _עליך_,
   {{0x6d55497b,0x7bc0497c,0x0b460823,0x317b0070}},	//   _deza, _pomu, гнен, _ארימ,
   {{0x9f0603c7,0x09be0577,0x2d9c0e46,0x39580009}},	//   _موجو, ्स्य, žve_, _žrs_,
   {{0x69c1497d,0x160322c7,0x6fca016f,0x61e5001e}},	//   _bole, रकार_, _rých, _ymhl,
   {{0x6d55497e,0x6b821e36,0x38a30225,0xd8380207}},	//   _geza, sfog, _bır_, _hrči_,
   {{0x69c1497f,0x7bc04980,0x082a4981,0xf806027a}},	//   _dole, _tomu, нции_, лчин,
   {{0x6d554982,0x69c10118,0x38a30448,0x29d0009e}},	//   _zeza, _eole, _dır_, _gàan_,
   {{0x6fca0076,0x7c224983,0x6e2e4984,0x6b8400ab}},	//   _vých, mmor, _kibb, õigu,
   {{0x69c14985,0x6e2e4986,0x290c0533,0x00000000}},	//   _gole, _jibb, _tyda_, --,
   {{0x7c2201ef,0x6fca016f,0x2db7016b,0x290c1505}},	//   omor, _tých, אלין_, _uyda_,
   {{0x7c2212ba,0x69c14987,0xdb1b01ef,0x00000000}},	//   nmor, _zole, _gluó, --,
   {{0x64434988,0x6e2e006d,0x628302c4,0x69c10107}},	//   _etni, _oibb, _ćnos, _yole,
   {{0x69d8064b,0x6e2e1c2b,0x26db00a5,0xbddb13b6}},	//   nhve, _nibb, _אקדמ, _atèn,
   {{0x6d55029d,0x69cc488d,0xdcfc0029,0x2937016b}},	//   _reza, _तकनी, _darī, ראלן_,
   {{0x602700ee,0x629a00ec,0x00000000,0x00000000}},	//   _kŕmi, ātor, --, --,
   {{0x7c220500,0xb5fd4989,0x5d55498a,0x6e2e498b}},	// [42f0] dmor, pušt, икат, _bibb,
   {{0x61e5239a,0xdcfc00ea,0xbddb021e,0x78a81e74}},	//   _umhl, _garī, _etèn, _ordv,
   {{0x6d550496,0x628e011c,0x69c1498c,0xa11500d1}},	//   _veza, čnoš, _role, _خودت,
   {{0x69c1498d,0xba750088,0x7d0e008c,0xd8380124}},	//   _sole, لاتت, _dybs, _grči_,
   {{0x69c1498e,0x6e2e17a4,0xbd6b03fa,0x81e80033}},	//   _pole, _fibb, _прве_, যকর_,
   {{0x6e2e498f,0x27e64990,0x1db9018d,0x68454991}},	//   _gibb, _amon_, _उचित, анка,
   {{0x69c14992,0x7e6d1e54,0x7d1a003e,0x8c250037}},	//   _vole, lrap, _útsp, _نفسه,
   {{0x28b6112b,0x2d934993,0x16650896,0x3d1a00b4}},	//   _अपरि, lexe_, авим, _भरते_,
   {{0x78a8010b,0x27e60260,0x6b890027,0x2c41005f}},	//   _erdv, _dmon_, _ibeg, _dėde_,
   {{0x69d801ae,0x27e64994,0x2d934995,0x6aa9007e}},	//   chve, _emon_, nexe_, _iref,
   {{0x7e6d4996,0x6aa9008d,0x628d01b7,0x67d51309}},	//   hrap, _href, _apao, _кожу,
   {{0x6aa94997,0xcc760122,0x7e6d4998,0x6b890069}},	//   _kref, סגרת_, krap, _jbeg,
   {{0x6b894999,0xe72e499a,0xdcfc0228,0xb8110035}},	//   _mbeg, _фе_, _parī, _डीएम_,
   {{0xa06a01c8,0xe046027a,0x6aa9000e,0x64a51129}},	//   кага_, инги, _mref, _вака,
   {{0x7c22499b,0x90c31578,0x7649393e,0x64430051}},	//   ymor, обре, lpey, _utni,
   {{0x6aa9027a,0x3ead0506,0x00000000,0x00000000}},	//   _oref, _šeta_, --, --,
   {{0x7e6d499c,0xee37499d,0x7c220e6c,0x00000000}},	// [4300] grap, инт_, vmor, --,
   {{0x998c00ea,0x6b89159c,0x83fd011c,0x27e9031d}},	//   _vidū_, _abeg, vrđi, čany_,
   {{0xd8380c21,0x7c22499e,0x7e6d0009,0xc1010023}},	//   _trči_, tmor, arap, _mượt_,
   {{0xc1010028,0x5aca005f,0x6e2e02b7,0x8fa62f7c}},	//   _lượt_, клем_, _wibb, _таме,
   {{0x7e6d0602,0x6e2e499f,0x27e60176,0x6aa900e9}},	//   crap, _tibb, _rmon_, _cref,
   {{0x20ba164f,0xceb30122,0x6aa9001e,0x7c3a00f7}},	//   _उपाध, _ויש_, _dref, _étro,
   {{0xa3c60939,0x6aa92a8b,0x69d829f1,0x7c220176}},	//   _एवं_, _eref, rhve, pmor,
   {{0x4c9b00a5,0x7bd901ae,0x06e70033,0x57a60279}},	//   _בבלו, chwu, _পড়ি, ршка,
   {{0x6aa949a0,0xab2701fd,0x764d045e,0x19960274}},	//   _gref, _вота_, _çayl, _вјер,
   {{0x6b8938cb,0x14ca00c3,0xe4a618cd,0x00000000}},	//   _zbeg, выми_, армо, --,
   {{0xd4972e02,0xd5b710b0,0x388e00a8,0x00000000}},	//   аря_, рсы_, _sərf_, --,
   {{0xc7c70086,0x00000000,0x00000000,0x00000000}},	//   _выше_, --, --, --,
   {{0x926b02fb,0x00000000,0x00000000,0x00000000}},	//   ърна_, --, --, --,
   {{0x7e6d0382,0xf20700d4,0xab5d009f,0x00000000}},	//   vrap, рямо, _moża, --,
   {{0x55bb024b,0x00000000,0x00000000,0x00000000}},	//   _במגו, --, --, --,
   {{0xb5fd039c,0x7e6d49a1,0x2cad0009,0x25e218da}},	//   vrši, trap, _čed_, टोरी_,
   {{0x51871ad4,0xba3d01c0,0x9df9075c,0xd83849a2}},	// [4310] _куна, _prům, гнат_, _grčv_,
   {{0x7e6d49a3,0x27050028,0xeca703fa,0xcd2b0cd1}},	//   rrap, ồng_, ијен, نسان_,
   {{0x7e6d038d,0x317401ba,0x6fd80079,0x7c670754}},	//   srap, ňazí_, _síce, شاال,
   {{0x5b25004f,0x6aa919d7,0x2d9349a4,0x7e6d49a5}},	//   مفضل, _pref, sexe_, prap,
   {{0x6608104e,0x7c3b0009,0xd9451e38,0xfaa51c20}},	//   kodk, _čuru, бели, сало,
   {{0xceb2012b,0x81c90083,0x6fd800b8,0xab5d009f}},	//   _זיך_, লোর_, _více, _doża,
   {{0xf09402b5,0x6fca0187,0xc10100e2,0x25f5021a}},	//   ַנץ_, _výcv, _rượt_, एचसी_,
   {{0x6aa949a6,0xd0f802b8,0xddcd0169,0x38690496}},	//   _tref, ימות_, ntaž, čar_,
   {{0x06090d28,0x6aa90054,0x00000000,0x00000000}},	//   лник_, _uref, --, --,
   {{0x5887086c,0x660849a7,0xb86b49a8,0xd83803e0}},	//   _выда, godk, _ајде_, _fuč_,
   {{0xc10101a5,0x03a62d7a,0xddcd010b,0x39150088}},	//   _vượt_, бино, ktaž, _اواز,
   {{0xd8380260,0x00000000,0x00000000,0x00000000}},	//   _prčv_, --, --, --,
   {{0x27ed20b7,0x870700c3,0xddc401f2,0x9f4901ef}},	//   mien_, _тяже, hriš, ciaé_,
   {{0x27ed49a9,0xd5b117bd,0xddc449aa,0x7dd2008c}},	//   lien_, _رفع_, kriš, _ræso,
   {{0x3f6a49ab,0x7dd201b4,0x87db0066,0x27ed01e4}},	//   ливо_, _sæso, _बताऊ, oien_,
   {{0x6ab73054,0xafe3005c,0x543a0070,0xd8380124}},	//   _आपूर, посл, _געקא, _grču_,
   {{0x442049ac,0xef1a49ad,0x7546006c,0xdfcf0079}},	// [4320] _ihi_, ума_, _érzé, ريك_,
   {{0x27ed49ae,0x44323698,0xeef500d8,0x00000000}},	//   hien_, _hiy_, іятэ, --,
   {{0x442000e8,0x7dc00332,0x27ed49af,0x61ee41a5}},	//   _khi_, _kösz, kien_, mibl,
   {{0x27ed0086,0x61ee49b0,0xab5d0067,0x00000000}},	//   jien_, libl, _poża, --,
   {{0x27ed49b1,0xdcfc0009,0x69cc0324,0x44200f49}},	//   dien_, _obrć, _तकदी, _mhi_,
   {{0xddc4029d,0x61ee49b2,0xd8380009,0x443202d0}},	//   briš, nibl, _puč_, _liy_,
   {{0x6d5e49b3,0x442049b4,0x27ed49b5,0xa3ca3e9e}},	//   mapa, _ohi_, fien_, ोसा_,
   {{0x6d5e49b6,0x27ed49b7,0x442001a5,0x61ee00a8}},	//   lapa, gien_, _nhi_, hibl,
   {{0x95ca49b8,0x320a1027,0xb97a00fd,0x52b42160}},	//   гуна_, koby_, _محاذ_, ुहोस,
   {{0x6d5e49b9,0x44200033,0x61ee49ba,0x27ed0120}},	//   napa, _ahi_, jibl, aien_,
   {{0xab5d006a,0x44200014,0x183600bf,0x320a37fe}},	//   _możn, _bhi_, _طراح, doby_,
   {{0x442049bb,0x27ed49bc,0x6d5e49bd,0x00000000}},	//   _chi_, cien_, hapa, --,
   {{0x6d5e49be,0x443249bf,0x442049c0,0xbddb0118}},	//   kapa, _diy_, _dhi_, _stèm,
   {{0x61ee49c1,0x867b0bed,0x41e401c8,0xe5a31286}},	//   gibl, _תרגו, піса, _ничи,
   {{0x84462087,0x6d5e49c2,0xba3d00b8,0x388e00a8}},	//   _اختل, dapa, _průk, _hərb_,
   {{0x44200028,0xddc40cc2,0xe8df055c,0x00000000}},	//   _ghi_, vriš, _chộm_, --,
   {{0x61ee17ad,0xddcd49c3,0xa3ce00a1,0xab5d0024}},	// [4330] bibl, rtaž, _शकत_, _bożn,
   {{0x27ed26c4,0x6d5e2aaf,0x61ee49c4,0x2b4400d7}},	//   zien_, gapa, cibl, _afmc_,
   {{0x2bdd0967,0x9f3503d0,0xddcd01c8,0x236902c6}},	//   _मतदा, _мені, ptaž, _kdaj_,
   {{0x5b1538d0,0x649e0129,0x27ed49c5,0xe1ff0035}},	//   омет, mšić, xien_, trów_,
   {{0x27ed49c6,0x4ea70279,0x7e7902b5,0x6d5e49c7}},	//   vien_, _урна, _דאָז, bapa,
   {{0x7f5f0024,0xddc402b2,0x27ed49c8,0xddcd0067}},	//   laqq, priš, wien_, ntaż,
   {{0x27ed49c9,0x64ac042a,0x3ea949ca,0x9f5202d7}},	//   tien_, nđić, lvat_, coyó_,
   {{0x236901d2,0x22490464,0x7f5f2b72,0x3ea949cb}},	//   _ndaj_, _otak_, naqq, ovat_,
   {{0x27ed49cc,0x959501c8,0xb5fd011c,0xed1800b5}},	//   rien_, ошні, kršt, _نہےں_,
   {{0x27ed49cd,0x26cd046a,0xb46538ea,0x4489021d}},	//   sien_, ryeo_, окол, абон_,
   {{0x27ed49ce,0x442001a5,0x224949cf,0x3ea949d0}},	//   pien_, _phi_, _atak_, hvat_,
   {{0x6d5e49d1,0xd87400f3,0x4420006d,0x232a1362}},	//   zapa, _رامب, _qhi_, иони_,
   {{0xfdfb0302,0x6d5e49d2,0xadfb0433,0xb21b0a8a}},	//   ्वास_, yapa, ्वान_, rtæn,
   {{0xb21b054e,0x6d5e01a2,0x2e2d0009,0x3ea900b9}},	//   stæn, xapa, _džfk_, dvat_,
   {{0x442000e8,0x320a49d3,0x61ee49d4,0x6d5e49d5}},	//   _thi_, roby_, ribl, vapa,
   {{0x6d5e3dc2,0x442000f1,0x61ee449a,0xdb000176}},	//   wapa, _uhi_, sibl, _famè,
   {{0x63a412aa,0x61ee02e9,0x6e4603c5,0x81c90033}},	// [4340] _iain, pibl, زنام, লোই_,
   {{0x63a449d6,0x236902c6,0x628649d7,0x61ee49d8}},	//   _hain, _zdaj_, mtko, qibl,
   {{0x63a449d9,0x6d5e49da,0x3ea90086,0x628649db}},	//   _kain, rapa, avat_, ltko,
   {{0x63a406a2,0xddcd0043,0x2d8549dc,0xc50c016b}},	//   _jain, tuaţ, _ölen_, נלאָ,
   {{0x6d5e49dd,0x63a420df,0x1a9641bd,0x3ea949de}},	//   papa, _main, تجاج, cvat_,
   {{0xfce605d2,0x63a449df,0xf2d30d85,0x286a00ed}},	//   _дого, _lain, ועד_, арио_,
   {{0xa37b0370,0x6d5c0080,0x628600ab,0xdb0001f7}},	//   lhõe, _iera, htko, _mamé,
   {{0x6d5c491c,0x62860557,0xd90d00d1,0xdb0001ef}},	//   _hera, ktko, دیم_, _lamé,
   {{0x6d5c38b2,0x7e6449e0,0xab5d006a,0xa37b0279}},	//   _kera, nsip, _możl, nhõe,
   {{0x7c3c49e1,0x186a0786,0x7e6449e2,0xdb00000d}},	//   _kurr, _важи_, isip, _ramè,
   {{0x63a449e3,0x6d5c49e4,0x291849e5,0x3ea949e6}},	//   _bain, _mera, _ára_, zvat_,
   {{0x7bc21010,0x63a44286,0x6d5c49e7,0x7e641504}},	//   njou, _cain, _lera, ksip,
   {{0x63a449e8,0x7c3c0291,0x69c823f4,0x6d5c0090}},	//   _dain, _lurr, _kode, _oera,
   {{0x69c849e9,0xdb000248,0x345500b5,0x7bc249ea}},	//   _jode, _camé, _کروڑ, hjou,
   {{0xe5020167,0x63a449eb,0x69da009e,0x6ab7164f}},	//   _रुचि_, _fain, _mlte, _आप्र,
   {{0x6d5c0079,0x63a403e9,0x6fd80300,0x7bc20282}},	//   _aera, _gain, _píca, jjou,
   {{0x6d5c49ec,0x7c3c03cb,0x443c0189,0x224949ed}},	// [4350] _bera, _aurr, _huv_, _utak_,
   {{0x69c849ee,0x443c1020,0x7c3c49ef,0x63a449f0}},	//   _node, _kuv_, _burr, _zain,
   {{0x7c3c0052,0x6d5c03c1,0x63a4254a,0x2fd9023a}},	//   _curr, _dera, _yain, _tlsg_,
   {{0x69da49f1,0x7c3c00da,0x443c49f2,0x00000000}},	//   _alte, _durr, _muv_, --,
   {{0x443c33a0,0x69c849f3,0x7d7718dd,0x29f60035}},	//   _luv_, _bode, _واسط, kład_,
   {{0x7c3c49f4,0x69c849f5,0xdb1b0132,0x2bab0355}},	//   _furr, _code, _louç, _घोरा,
   {{0x69c849f6,0x443c0221,0x69cc0066,0x6e3d49f7}},	//   _dode, _nuv_, _तकरी, _husb,
   {{0x6286006a,0x61c808b6,0x6d4501a6,0x69da49f8}},	//   ytko, _रक्ष, lcha, _elte,
   {{0x7f5d49f9,0x69c849fa,0x443c01e8,0x6d4549fb}},	//   _mesq, _fode, _auv_, ocha,
   {{0x6d4549fc,0x6d5c1a71,0x7f5d0248,0x63a405f0}},	//   ncha, _xera, _lesq, _sain,
   {{0x2b400693,0xb21b3a92,0x63a449fd,0xa5091b81}},	//   žice_, rtæl, _pain, сена_,
   {{0x6d4549fe,0x228410b2,0xdb0049ff,0x6e354a00}},	//   hcha, tök_, _samé, _lizb,
   {{0x63a44a01,0x98a70092,0x7dd3027d,0x2a9d0107}},	//   _vain, manı_, _kısı, _jňb_,
   {{0x63a44a02,0x6e3500cb,0x853c010b,0x228400b5}},	//   _wain, _nizb, ndėl, rök_,
   {{0x63a44a03,0x6e3d02c9,0x22844a04,0x6d454a05}},	//   _tain, _ausb, sök_, dcha,
   {{0x6d5c1221,0xe1ff004e,0x63a409c3,0x7e644a06}},	//   _sera, wrót_, _uain, tsip,
   {{0xdb004a07,0x6d5c0464,0x6e3d0211,0x69cc0243}},	// [4360] _tamé, _pera, _cusb, _तकली,
   {{0x443c01e8,0x65612aab,0x6e3d0009,0x7e644a08}},	//   _yuv_, nalh, _dusb, rsip,
   {{0x6d5c0ddf,0x7e644a09,0x315700c2,0x98a706d3}},	//   _vera, ssip, _מיין_, kanı_,
   {{0x6d4509e3,0x7bc902e1,0x69c8108a,0x6d5c4a0a}},	//   acha, _coeu, _sode, _wera,
   {{0x6d450189,0x7bc20086,0x0ba90079,0x00000000}},	//   bcha, rjou, تالى_, --,
   {{0x7c3c4a0b,0x09e327fb,0xed52042c,0x7bc216c9}},	//   _turr, ночн, _سپر_, sjou,
   {{0x69c81851,0x65614a0c,0x764b001e,0xec770274}},	//   _vode, dalh, _atgy, _нпр_,
   {{0x79980c1f,0xf09300a5,0x2d9a4a0d,0x7bdb4a0e}},	//   sevw, גנה_, lepe_, _gluu,
   {{0x69c84a0f,0xa3c60066,0x6fd800d5,0xbddb01da}},	//   _tode, _एवज_, _líco, _stèi,
   {{0x69da4a10,0x65610279,0x443c006f,0xba3d00b8}},	//   _ulte, galh, _puv_, _prův,
   {{0x395e1c47,0x443c0118,0xb4c802e4,0x244101f7}},	//   _iets_, _quv_, ोने_, _cóm_,
   {{0xedb9035d,0x883b00a5,0x395e4a11,0x24414a12}},	//   _उच्छ, _התאו, _hets_, _dóm_,
   {{0x65614a13,0x6d454a14,0x7f5d0024,0x2a66027a}},	//   balh, ycha, _resq, nsob_,
   {{0x2d9a0c21,0x65614a15,0x6d4541c7,0xa41001c0}},	//   jepe_, calh, xcha, ětší_,
   {{0x7f5d00c9,0xd48f0012,0x395e4a16,0x850405f5}},	//   _pesq, _яр_, _mets_, _توغن,
   {{0x34fb0122,0x395e4a17,0x4abe08b0,0xd1300841}},	//   _להוד, _lets_, ्हाव, امِ_,
   {{0x6d454a18,0x9f40008a,0x69c30035,0x00000000}},	// [4370] tcha, rnið_, yjne, --,
   {{0x6d454a19,0x7bc90248,0xf1d1000c,0x4df401e0}},	//   ucha, _soeu, _सकिन, няєт,
   {{0x6d451aa7,0x24410019,0x98a70644,0x7bdb4a1a}},	//   rcha, _xóm_, yanı_, _pluu,
   {{0x6d454a1b,0xbddb00f7,0x398f00d0,0x98a7013b}},	//   scha, _suèd, zısı_, xanı_,
   {{0x398f0723,0xe8101cce,0x7bc900f7,0x6e3d4a1c}},	//   yısı_, ावना_, _voeu, _uusb,
   {{0x2d9a0043,0xf9c72374,0x00000000,0x00000000}},	//   cepe_, ящен, --, --,
   {{0xf8920370,0x395e4a1d,0x65610183,0x98a700c1}},	//   вајќ, _dets_, valh, tanı_,
   {{0x65614a1e,0x2a660cca,0x9b59449f,0x24411d54}},	//   walh, bsob_, _фиат_, _róm_,
   {{0x65610370,0x395e0443,0xaa580370,0x98a70644}},	//   talh, _fets_, _ниту_, ranı_,
   {{0x395e4a1f,0x98a7037a,0x7c2b3248,0x0445444f}},	//   _gets_, sanı_, lmgr, меон,
   {{0x65614a20,0x398f00d0,0x31630a18,0x58d4002d}},	//   ralh, rısı_, dajz_, _пофт,
   {{0x6fd84a21,0x65614a22,0x98a7013b,0x6835005f}},	//   _cícl, salh, qanı_, _išdo,
   {{0xe60e0a93,0x656103e6,0x398f033e,0xdcfc009f}},	//   _ад_, palh, pısı_, _marġ,
   {{0xc58e0028,0x2441307d,0x00000000,0x00000000}},	//   _hồng_, _tóm_, --, --,
   {{0x2fcb0310,0x1c0d0066,0x2c0d022e,0x00000000}},	//   _bocg_, िकाल_, िकां_, --,
   {{0x53e2018d,0x624b02d4,0x00000000,0x00000000}},	//   _पतिश, _bļod, --, --,
   {{0x2fcb0036,0x2d9a4a23,0xc58e00e2,0x00000000}},	// [4380] _docg_, tepe_, _mồng_, --,
   {{0x270c00e8,0xc58e0019,0x25a70260,0xe1ff02d7}},	//   ớng_, _lồng_, _janl_, lsón_,
   {{0x2d9a4a24,0x224000be,0x00000000,0x00000000}},	//   repe_, _huik_, --, --,
   {{0x224000d7,0xc58e0019,0x2d9a4a25,0x395e00a5}},	//   _kuik_, _nồng_, sepe_, _sets_,
   {{0xa3e31ab2,0xdb000107,0x20054135,0xa2a40067}},	//   फोट_, _anmò, élie_, _चैम्,
   {{0xc3330122,0x3a2500ee,0x3f8000c7,0x62960103}},	//   דוד_, _chlp_, lgiu_, _mpyo,
   {{0xc58e0023,0x22404a26,0x00000000,0x00000000}},	//   _bồng_, _luik_, --, --,
   {{0x3f804a27,0x466a01f6,0x6bda00f8,0xc58e00e2}},	//   ngiu_, ором_, _بورس_, _cồng_,
   {{0x96342743,0xdb0006fe,0x00000000,0x00000000}},	//   нниц, _kamí, --, --,
   {{0xb21b00fb,0xc6f70733,0xba2300d8,0x25a7009e}},	//   rtæk, ьных_, _адук, _canl_,
   {{0xdb00039f,0x25a70260,0xdcee0225,0xd83806fe}},	//   _mamí, _danl_, _kabı, _ksčm_,
   {{0x22400130,0x7e764a28,0xc58e00cc,0xee3f00fe}},	//   _buik_, kryp, _gồng_, _krýt_,
   {{0xf7d70319,0x51874a29,0xfd650023,0x228400af}},	//   _קודש_, мува, _chuỗ, кург,
   {{0x69d84a2a,0x23af0325,0x22400b0d,0xdb0006fe}},	//   nkve, _जोरद, _duik_, _namí,
   {{0x442b4a2b,0x86370d85,0x3cfa0035,0xe8df0023}},	//   pmc_, _קרוב_, ्थों_, _kiềm_,
   {{0x5f941457,0x14cb1bb5,0xf39000e2,0x3f804354}},	//   кист, ाहरण, _hảng_, ggiu_,
   {{0xee3f0028,0xc3090083,0x7e764a2c,0x2cb10183}},	// [4390] _quý_, রেজি_, gryp, _srzd_,
   {{0xdb000176,0x69d80223,0x3f800139,0x00000000}},	//   _camí, jkve, agiu_, --,
   {{0x61f506d3,0xf3900023,0x3ea008dd,0x315600a5}},	//   mizl, _mảng_, awit_, _איתן_,
   {{0xe8df01a5,0x61f50448,0x60d600a5,0xee3f0023}},	//   _niềm_, lizl, _נורא_, _tuý_,
   {{0xdb002cc9,0xc58e0019,0x9f8a00ab,0xaa67027a}},	//   _famí, _rồng_, tööd_, фтек,
   {{0x92a90035,0x61f500d0,0x8afd0355,0xe8df055c}},	//   _załó, nizl, _neře, _chởm_,
   {{0x2b400528,0x5fd300c0,0xdcfc0024,0x00000000}},	//   žica_, _सवाल, _tarġ, --,
   {{0x013802da,0xe3ca01dd,0x321100ac,0x69d80345}},	//   ורות_, _mañá_, hozy_, akve,
   {{0xf3900028,0xddcd00af,0xc58e00e2,0x00000000}},	//   _bảng_, craţ, _vồng_, --,
   {{0x2d814a2d,0xf3900019,0x69d80f8e,0xab6200ab}},	//   nghe_, _cảng_, ckve, _üüri,
   {{0x2d81006b,0x00000000,0x00000000,0x00000000}},	//   ighe_, --, --, --,
   {{0xe29a1bda,0x7dd20093,0x1ac60033,0x224003bc}},	//   пам_, _hæst, _শেয়া, _puik_,
   {{0x45d5310b,0x2bc7017f,0x27ff0448,0x25a70107}},	//   _подс, _रचना, mnun_, _tanl_,
   {{0xdfd201cb,0x25a702d7,0xf3ff021d,0x7a240392}},	//   گير_, _uanl_, anã_, pòte,
   {{0xdb004a2e,0xc0e64a2f,0x25aa02fd,0x9f9d0093}},	//   _ramí, ховк, _رضوی_, tæðu_,
   {{0x7dd2054e,0x27ff4a30,0x3ea04a31,0x7e764a32}},	//   _læst, nnun_, twit_, tryp,
   {{0x3f804a33,0xe81000ab,0xdb000279,0xdee31457}},	// [43a0] rgiu_, ावता_, _mamã, готи,
   {{0x7dd24a34,0xdcee0225,0xfce64a35,0x00000000}},	//   _næst, _sabı, нозо, --,
   {{0xeb9a1e26,0x5ec80033,0x3ea002d0,0x515b00a5}},	//   зие_, _রেখে, swit_, _מכיו,
   {{0xab8320c3,0xfc39021e,0x986600b5,0xdb000139}},	//   гушк, _ciŭ_, ہیئے_, _ramâ,
   {{0x200000af,0x7dd2008c,0x00000000,0x00000000}},	//   mnii_, _bæst, --, --,
   {{0xa8a6087b,0x693403fc,0x603c0107,0xdb000139}},	//   ерик, نکار, _fčmt, _pamâ,
   {{0x1d070183,0xde034a36,0x27ff008a,0xa81701cb}},	//   _зери_, _спри, fnun_, کتور_,
   {{0x20004a37,0x27ff4a38,0x6fe00266,0x69d84a39}},	//   nnii_, gnun_, नसिं, skve,
   {{0x20000400,0xd5b00037,0x00000000,0x00000000}},	//   inii_, لفة_, --, --,
   {{0x7dd2054e,0x00000000,0x00000000,0x00000000}},	//   _gæst, --, --, --,
   {{0x8afd01c0,0xe8df0019,0xddcd010b,0x35f3002d}},	//   _veře, _tiềm_, nraš, упэр,
   {{0xab5d003c,0x6b820371,0xba3d00fe,0x00000000}},	//   _pożi, ngog, _krůp, --,
   {{0xf3900023,0xdb1b0183,0x70c91140,0x00000000}},	//   _tảng_, _anuê, रह्ल, --,
   {{0x20000395,0xddcd010b,0xd5b800ea,0x7dd20a8a}},	//   enii_, kraš, rmās_, _mæss,
   {{0xc60c05f7,0x61f54a3a,0xddcd00cd,0x7dd20b3e}},	//   सकीय_, rizl, jraš, _læss,
   {{0x4395081b,0x61f504d4,0xe8df01a5,0x386c0097}},	//   _раис, sizl, _hiểm_, _mvdr_,
   {{0x4429026c,0xe8df0028,0x6fd84a3b,0xd8380107}},	// [43b0] _iha_, _kiểm_, _mích, _asčk_,
   {{0x20000400,0x442909a9,0xddcd01ba,0xd9040105}},	//   anii_, _hha_, fraš, _هی_,
   {{0x6fd8004f,0xc5f302b5,0x2d814a3c,0x44294a3d}},	//   _oích, נדע_, rghe_, _kha_,
   {{0xdfd50012,0x6d580093,0x7dd203d0,0x00000000}},	//   _ромы, ðvar, _bæss, --,
   {{0xfaa50cf9,0x44291727,0x443b4a3e,0x28a60067}},	//   тало, _mha_, _miq_, _कैबि,
   {{0xe9d801c8,0x442900bf,0xbddb2fdc,0xddcd00f4}},	//   нкі_, _lha_, _etèr, braš,
   {{0x44294a3f,0x603c021e,0xd26200ea,0x394c008c}},	//   _oha_, _kōma, _ziņā_, _dfds_,
   {{0x44290028,0xe739022b,0x386c1f83,0x99dd00fe}},	//   _nha_, мей_, _dvdr_, _buňc,
   {{0x5a350810,0xa3bb045c,0x6fd80037,0x7c2901d5}},	//   _анат, घाई_, _dích, _iher,
   {{0x44290b55,0x7c3b009e,0x00000000,0x00000000}},	//   _aha_, _hiur, --, --,
   {{0x4429060e,0x7c29002f,0x7c3b0df0,0x09b6016b}},	//   _bha_, _kher, _kiur, _שפעט_,
   {{0x44294a40,0x443b00d7,0xdb002fba,0x7c290107}},	//   _cha_, _ciq_, _hamá, _jher,
   {{0x44294a41,0x764200d7,0x7c293a23,0x3d18046c}},	//   _dha_, _guoy, _mher, _बुने_,
   {{0xdb000831,0x44294a42,0x412a1303,0x7c3b009e}},	//   _jamá, _eha_, дого_, _liur,
   {{0x7c294a43,0x703a00d8,0xdb004a44,0x2b4d0176}},	//   _oher, дчас_, _mamá, _ofec_,
   {{0x64430043,0x2000002d,0x656303db,0xe9ff00e2}},	//   _iuni, unii_, _henh, _duẩn_,
   {{0xee3a4011,0x0d862214,0xfe430c90,0x20004776}},	// [43c0] дна_, клан, инто, rnii_,
   {{0xddcd042d,0x7c290010,0x7c3b1e86,0xdb00314b}},	//   traš, _aher, _aiur, _namá,
   {{0x7c3b4a45,0x64434a46,0x7c290608,0xa3c9074f}},	//   _biur, _juni, _bher, लॉक_,
   {{0x7c294a47,0x64434a48,0x7c3b4a49,0x656306f2}},	//   _cher, _muni, _ciur, _lenh,
   {{0x7c29227f,0x64434a4a,0x6b82119e,0x776201ef}},	//   _dher, _luni, rgog, _reox,
   {{0x65630370,0x7c292487,0xddcd4a4b,0x2d9e0355}},	//   _nenh, _eher, praš, _úte_,
   {{0x64434a4c,0xdb000037,0x2ca708c8,0x7c2901da}},	//   _nuni, _damá, ændt_, _fher,
   {{0x7c3b1089,0x7c294a4d,0xd6da2374,0x00000000}},	//   _giur, _gher, дто_, --,
   {{0xfaa34a4e,0x443b0069,0x2bab00b4,0x64434a4f}},	//   _като, _riq_, _घोटा, _auni,
   {{0x44294a50,0x64434a51,0x7c3b1de7,0xa2c600b8}},	//   _sha_, _buni, _ziur, ामन्,
   {{0xd82f0012,0x64434a52,0x44294a53,0x7d7b0122}},	//   _вэ_, _cuni, _pha_, וניו,
   {{0x64434a54,0xa78501b2,0x4429006f,0x656303c4}},	//   _duni, _مشهو, _qha_, _eenh,
   {{0xa3c90141,0x6e3c0874,0x64434a55,0x44291f8b}},	//   लॉग_, _oirb, _euni, _vha_,
   {{0x4429009e,0x6e3c4a56,0xe60f4a57,0xdb0001ef}},	//   _wha_, _nirb, _وشو_, _xamá,
   {{0x442931ab,0x656814cc,0x64c30312,0x64434a58}},	//   _tha_, madh, _نيول, _guni,
   {{0x65684a59,0x44294a5a,0x443b0023,0xd7c500a1}},	//   ladh, _uha_, _uiq_, वायच,
   {{0x6e3c06d3,0x63ad010d,0x40344a5b,0x7d1c4a5c}},	// [43d0] _birb, _iaan, ретс, _ayrs,
   {{0xf41f3dee,0x7c294a5d,0x3f7300e8,0x64434a5e}},	//   llä_, _sher, ệu_, _yuni,
   {{0x6e3c01c8,0x63ad4a5f,0x7c2917ec,0xd010006c}},	//   _dirb, _kaan, _pher, صلے_,
   {{0x63ad007c,0x2d87004e,0x65684a60,0x6e3c0211}},	//   _jaan, żne_, hadh, _eirb,
   {{0x63ad4a61,0x7c3b12c3,0x3b09013b,0xdb0000b8}},	//   _maan, _viur, çaq_, _pamá,
   {{0x7c290052,0x7d1c2129,0x63ad4a62,0x65684a63}},	//   _wher, _fyrs, _laan, jadh,
   {{0x7c2901f3,0x3da40021,0x6568262d,0xc98436ae}},	//   _ther, _тряб, dadh, ручи,
   {{0x656300c9,0x63ad02b3,0x64431ae8,0x7c294a64}},	//   _senh, _naan, _runi, _uher,
   {{0x65680657,0x64434a65,0x7e6d4a66,0x65634a67}},	//   fadh, _suni, nsap, _penh,
   {{0x7a240c1f,0x65680105,0x6fd80132,0x64434a68}},	//   pòta, gadh, _víci, _puni,
   {{0x63ad01a8,0x656303e6,0x22524a69,0xa3df0099}},	//   _baan, _venh, _styk_, णसं_,
   {{0xf1a90122,0x6563099e,0x64430c3a,0x6aa90168}},	//   _מס_, _wenh, _vuni, _ksef,
   {{0x656300c9,0x65684a6a,0x63ad4a6b,0xe8df0023}},	//   _tenh, badh, _daan, _diễm_,
   {{0x20194a6c,0x7e6d0051,0x656800ce,0x2448099e}},	//   _aksi_, dsap, cadh, _fûm_,
   {{0x63ad0987,0xe0d500d4,0xb21b01b4,0xdb00033b}},	//   _faan, ають, kræf, _unmö,
   {{0x63ad00a7,0x8c43037a,0xdce700b8,0x6e3c4a6d}},	//   _gaan, ışla, ůměr, _sirb,
   {{0x628f05d0,0x7e6d2326,0xd0070421,0x00000000}},	// [43e0] ctco, gsap, уете_, --,
   {{0xef174a6e,0xe05800d1,0xcf250037,0x67fe00ea}},	//   уму_, _لیست_, شرقي, rīji,
   {{0xb33b0370,0x63ad000e,0xe5f602b5,0xf8a50416}},	//   meça, _yaan, נזער_, _بک_,
   {{0x3ebf022f,0x8afd00b8,0x6e3c033b,0xb33b0183}},	//   _šute_, _seřa, _wirb, leça,
   {{0xa3c904bc,0x388e00a8,0x6568023c,0x7e6d00b5}},	//   लॉट_, _tərk_, yadh, csap,
   {{0x9f520093,0x6e3c0079,0x48aa0200,0xb33b021d}},	//   ábær_, _uirb, етим_, neça,
   {{0x20190086,0x65684148,0xf41f00c3,0x69d5052f}},	//   _yksi_, vadh, ylä_, _बकरी,
   {{0x7674095d,0x2caa1442,0x9f490093,0x61d10d00}},	//   алиф, _isbd_, nnað_, _सक्ष,
   {{0x7bc04a6f,0x628f01da,0x63ad4a70,0xeef70070}},	//   _inmu, xtco, _raan, ָמיר_,
   {{0x63ad3718,0x35f41129,0x1a9b0070,0x0ae90413}},	//   _saan, рпор, _אימע, _شرقي_,
   {{0x4d7b00c2,0x63ad0269,0x9f490093,0x65684a71}},	//   ערטע, _paan, knað_, radh,
   {{0x53352832,0xd6d90067,0xf789021d,0x00000000}},	//   иент, był_, raçá_, --,
   {{0x656800f8,0x2d980443,0x63ad4a72,0x9985005f}},	//   padh, _obre_, _vaan, _gilų_,
   {{0x63ad000e,0x8556042c,0xab5d0069,0x2d9800a2}},	//   _waan, _حیدر_, _inże, _nbre_,
   {{0x628f2050,0x63ad4a73,0x6fd80443,0x6f1d00ee}},	//   stco, _taan, _lícu, _sysc,
   {{0x2d984a74,0x7e6d4a75,0x9f490093,0xa3e901c0}},	//   _abre_, tsap, gnað_, _यति_,
   {{0xa2c600ab,0x8c43033e,0xb33b0279,0x388e013b}},	// [43f0] ामण्, ışma, beça, _dəri_,
   {{0x6b8901d3,0x2d8a0069,0x6f1d00ac,0x2d98055c}},	//   _sceg, _ccbe_, _vysc, _cbre_,
   {{0x7e6d4a76,0x8d7400ad,0xa3e90d53,0xd6d90035}},	//   ssap, صالا, _यता_, zył_,
   {{0x2d984a77,0x785100ea,0xa3bb0edf,0x00000000}},	//   _ebre_, _jāve, घाट_, --,
   {{0xe8df0019,0x291e010d,0xdefb0409,0x29f60035}},	//   _kiệm_, _ayta_, _чын_, ałam_,
   {{0x291e013c,0x764900a8,0x7bc002d7,0x3eb904fb}},	//   _byta_, vqey, _enmu, _irst_,
   {{0x3eb900fe,0x00000000,0x00000000,0x00000000}},	//   _hrst_, --, --, --,
   {{0x3eb94a78,0xccf20122,0x7df4004e,0x291e0031}},	//   _krst_, _וכל_, yńsk, _dyta_,
   {{0x6aa900a5,0xda7801d3,0xafdb0a8c,0x00000000}},	//   _usef, _бях_, _kiøb, --,
   {{0xdcf506a8,0x67fe0080,0xe8df01a5,0x45d54a79}},	//   _hazı, dīju, _niệm_, рцит,
   {{0x69c14a7a,0x7843006c,0xa509496c,0xdcf500d0}},	//   _inle, _bőve, тена_, _kazı,
   {{0x672e00b5,0x78bc0146,0xceb4013b,0x00000000}},	//   önjü, _árva, yvə_, --,
   {{0xe9ff0028,0xa2c617f1,0xf6790070,0xe1ff0067}},	//   _luận_, ामध्, _סאַמ, nsów_,
   {{0xdcf50ec4,0x3f8b01e4,0xd9e50d00,0x70b3051d}},	//   _lazı, _accu_, कसित_, ुमूल,
   {{0xb33b4a7b,0x4376002d,0x059600d1,0x3eb900be}},	//   reça, _купт, _خانگ, _arst_,
   {{0x3eb9021d,0x5f060210,0xdcf501fb,0x00000000}},	//   _brst_, азба, _nazı, --,

   {{0x8d660086,0x67fe0029,0xddc4003c,0xb33b0132}},	// [4400] ивае, cīju, priż, peça,
   {{0x957c004e,0x6835010b,0xddd40067,0x00000000}},	//   wiąz, _išdu, _żało, --,
   {{0x3eb902c9,0x0b464a7c,0x7b6607b0,0x61fc048f}},	//   _erst_, анен, атле, mirl,
   {{0x61fc1a68,0x9f060a86,0x69c11788,0x3218468c}},	//   lirl, _نوجو, _anle, lory_,
   {{0x61fc004f,0x00000000,0x00000000,0x00000000}},	//   oirl, --, --, --,
   {{0xed57291e,0x61fc4a7d,0x291e4a7e,0x00000000}},	//   _вор_, nirl, _pyta_, --,
   {{0x67fe0029,0x07e64a7f,0x996501e0,0xdcf50225}},	//   zīju, ицим, стіл, _fazı,
   {{0xd90d0357,0x69c14a80,0xdb00016f,0x61fc4a81}},	//   رین_, _enle, _pamä, hirl,
   {{0xe5c64a82,0x28a60299,0x61fc0463,0x3a2c00d7}},	//   асно, _कैरि, kirl, _thdp_,
   {{0x7c224a83,0xd94331fb,0xf8b800e2,0x1dc90096}},	//   llor, _дефи, _trĩ_, रायत,
   {{0xdcf508ca,0x61fc048f,0xc8ca03c5,0x32184a84}},	//   _yazı, dirl, _جوان_, dory_,
   {{0x67fe0029,0x1aed0033,0xf367021d,0xe7833f6b}},	//   tīju, _ছুটে_, штон, _душо,
   {{0x61fc4a85,0x27e64a86,0x290900d0,0x1dc900e7}},	//   firl, _ilon_, şaat_, रामत,
   {{0x32184a87,0xd9f800c0,0x3d0f083f,0x67fe0029}},	//   gory_, ्चित_, _तुझे_, rīju,
   {{0x27e64a88,0x67fe0029,0x8c430225,0x3f670c9f}},	//   _klon_, sīju, ışka, итаб,
   {{0x3eb9003d,0x645a4a89,0x7c224a8a,0xe53b076b}},	//   _prst_, mpti, jlor, _בתור,
   {{0x32184a8b,0xb33b03e6,0x61fc4a8c,0xdcf50095}},	// [4410] bory_, meço, birl, _razı,
   {{0x61fc4a8d,0x645a4a8e,0x3eb9008b,0xf1ab00d1}},	//   cirl, opti, _vrst_, _شاخه_,
   {{0x33180332,0xe9ff0028,0x27e60421,0x82340098}},	//   _مزید_, _quận_, _olon_, _بريا,
   {{0x1b100b52,0x2249028b,0x3eb90169,0x7c220090}},	//   ়েছে_, _kuak_, _trst_, glor,
   {{0x6fd84a8f,0xfaa709c2,0x224900d7,0x78ba4a90}},	//   _víct, ршен, _juak_, _artv,
   {{0xa2580122,0x2249022e,0x27e64a91,0xbf360d85}},	//   סבוק_, _muak_, _alon_, _לארץ_,
   {{0x6ce400d4,0x2249325b,0xfb8700d8,0x3ea9053e}},	//   _діте, _luak_, _вызн, lwat_,
   {{0x61fc01c2,0x32180076,0x1a680a86,0x3f894a92}},	//   zirl, zory_, _چینی_, ngau_,
   {{0xe6190eee,0x61fc0716,0x27e60211,0x19591ac5}},	//   лди_, yirl, _dlon_, _базы_,
   {{0xa2c60026,0x27e60260,0x69c100a5,0xc485182f}},	//   ामस्, _elon_, _unle, блок,
   {{0x3218024e,0x3ea9046a,0x80d70033,0x61fc4a93}},	//   vory_, hwat_, _ডেস্, virl,
   {{0x3ea94a94,0x22491f8a,0x32184a95,0x986400b5}},	//   kwat_, _buak_, wory_, _بیٹے_,
   {{0x61fc4a96,0x6b9b462e,0x78ba19cd,0x13a800d1}},	//   tirl, _mbug, _zrtv, هنگی_,
   {{0x6abb034d,0x00000000,0x00000000,0x00000000}},	//   _mruf, --, --, --,
   {{0x61fc4a97,0x6b9b0273,0x25a54a98,0x32184a99}},	//   rirl, _obug, mell_, rory_,
   {{0x25a54a9a,0x2b4003c9,0x61fc4a9b,0x037a014a}},	//   lell_, žici_, sirl, _صحبت_,
   {{0xf4130122,0x32184a9c,0x61fc0949,0x628000b5}},	// [4420] _מפה_, pory_, pirl, ámod,
   {{0x25a54a9d,0x62864a9e,0x6b9b179a,0x63a6103b}},	//   nell_, muko, _abug, lekn,
   {{0x1d1901c8,0xec7a28cf,0x3ea90159,0xb5fa0070}},	//   аюць_, упе_, awat_, נלעכ,
   {{0x63a64a9f,0x28bd0af9,0x3ea908dd,0x6abb2f6b}},	//   nekn, ्मनि, bwat_, _bruf,
   {{0x7c224aa0,0xeafa0bdf,0x25a54aa1,0x78ba021d}},	//   rlor, درات_, kell_, _srtv,
   {{0x27e607e7,0x5ed10033,0x25a5313c,0x6b9b018e}},	//   _slon_, _সেকে, jell_, _ebug,
   {{0x25a54aa2,0x62864aa3,0x27e64aa4,0x6fcc00a1}},	//   dell_, huko, _plon_, हापू,
   {{0x62861c85,0x6abb008c,0x765b0027,0x00000000}},	//   kuko, _fruf, fpuy, --,
   {{0xe9ff0028,0x25a54aa5,0x6abb4aa6,0x765b1296}},	//   _quản_, fell_, _gruf, gpuy,
   {{0x25a54aa7,0x78bc03e6,0x224900d7,0xab5d0024}},	//   gell_, _árvo, _ruak_, _inża,
   {{0xd4970086,0x9d260033,0xd5b70421,0x1dc9157d}},	//   бря_, _বলুন_, ссы_, रातत,
   {{0x22493ae0,0x62864aa8,0x645a0b48,0x63a64aa9}},	//   _puak_, fuko, rpti, gekn,
   {{0x25a54aaa,0xb33b03e6,0x62864aab,0x00000000}},	//   bell_, reço, guko, --,
   {{0x25a54aac,0x07370122,0xe67700a5,0x9c8300cd}},	//   cell_, _האדם_, _פתוח_, ščis,
   {{0x660f07c0,0xc0c837d5,0xba3d0355,0xcf9b03e6}},	//   écke, буте_, _průz, лја_,
   {{0x62864aad,0x22491051,0x3ea94aae,0x6722030d}},	//   buko, _tuak_, twat_, _kyoj,
   {{0x9df90dee,0xe3b00833,0x3f894aaf,0x200c4ab0}},	// [4430] анат_, _سري_, rgau_, édia_,
   {{0xdce7006a,0x644a4ab1,0x3ea9165a,0xa2c60803}},	//   _zdję, _kufi, rwat_, ामर्,
   {{0x212701a5,0x3ea93170,0x656a4ab2,0x00000000}},	//   _ánh_, swat_, _mefh, --,
   {{0x60da007c,0x644a4ab3,0x661a00f4,0x6abb008d}},	//   ätme, _mufi, hotk, _pruf,
   {{0x661a4ab4,0xf42a00c3,0x20090090,0x998c005f}},	//   kotk, lvää_, mnai_, _didž_,
   {{0x25a54ab5,0x63a600ea,0x20094ab6,0xc9874ab7}},	//   xell_, zekn, lnai_, суди,
   {{0x25a54ab8,0x644a4ab9,0x661a0097,0x200900c7}},	//   vell_, _nufi, dotk, onai_,
   {{0x6b9b0010,0x62864aba,0x86990370,0x00000000}},	//   _ubug, yuko, атот_, --,
   {{0x25a54abb,0x64584abc,0x6abb0010,0x785100ea}},	//   tell_, _atvi, _uruf, _dāva,
   {{0x661a4abd,0x644a251e,0xceb4011d,0xb33b0225}},	//   gotk, _bufi, ליפ_, reçl,
   {{0x25a54abe,0x6683006c,0x20091047,0x388e00a8}},	//   rell_, _کیخل, knai_, _dərs_,
   {{0x62864abf,0x644a0010,0x2d8c0225,0x59c7074f}},	//   tuko, _dufi, _ödev_, लावर,
   {{0xf7700ae7,0x8c1a02da,0x25a54ac0,0x63a64ac1}},	//   _سان_, שורי, pell_, rekn,
   {{0x6d4701d2,0x27ff4ac2,0x20090e3c,0x644a0124}},	//   _ngja, liun_, enai_, _fufi,
   {{0x61434ac3,0x62864ac4,0xd618006c,0xd5b800ea}},	//   дера, suko, _اتنا_, klāj_,
   {{0x27ed04e0,0x24750029,0x76430159,0x543602fd}},	//   nhen_, mām_, _hiny, _برتر,
   {{0x44204ac5,0x76434ac6,0x9d2600c8,0x29f6004e}},	// [4440] _iki_, _kiny, _বলেন_, cław_,
   {{0x76434ac7,0x27ff01e9,0x2be2012f,0x764b4ac8}},	//   _jiny, hiun_, पस्थ, _mugy,
   {{0x76430464,0x24750080,0xa3ce084b,0xd6cf0033}},	//   _miny, nām_, राप_, িনিয,
   {{0xeb9a00c9,0x76434ac9,0x661a003a,0x00000000}},	//   рид_, _liny, zotk, --,
   {{0x27ed4aca,0x27ff4acb,0xa9231dab,0x1fb50409}},	//   dhen_, diun_, ížno, _эсэр,
   {{0x76434189,0x24750029,0x27ed4acc,0x14c91cce}},	//   _niny, kām_, ehen_, िमाण,
   {{0x24750ae0,0xe7860011,0xd7c504ef,0xe7ea09ce}},	//   jām_, оупо, वांच, ифик_,
   {{0x27ff4acd,0x644a4ace,0x44204acf,0x24750029}},	//   giun_, _rufi, _nki_, dām_,
   {{0xa3ce1db6,0x76433633,0x661a05ca,0x386900cd}},	//   रान_, _biny, totk, ćara_,
   {{0x44200332,0x44320453,0x76430118,0x44f401e0}},	//   _aki_, _ahy_, _ciny, зпос,
   {{0x76430464,0x4420012f,0x24750029,0x27ff02d7}},	//   _diny, _bki_, gām_, biun_,
   {{0x27ed328b,0x86c60098,0x27ff002d,0x2b404ad0}},	//   chen_, _ويان, ciun_, žicu_,
   {{0x442001d1,0x661a4ad1,0x76434ad2,0x764b0103}},	//   _dki_, potk, _finy, _gugy,
   {{0x24750029,0x44204ad3,0x76434ad4,0x61ee0159}},	//   bām_, _eki_, _giny, ghbl,
   {{0x29f6004e,0x645802ce,0x7a240176,0xf3ff021d}},	//   sław_, _utvi, gòti, piã_,
   {{0x35e00953,0x187b02b5,0x44203ffc,0x7643010a}},	//   _पकड़, יטלב, _gki_, _ziny,
   {{0x543400f8,0x20094ad5,0x44394ad6,0x76434ad7}},	// [4450] _ترور, rnai_, mms_, _yiny,
   {{0x27ff0c6f,0xdcbb3943,0x27ed1c2b,0x44394ad8}},	//   ziun_, ище_, zhen_, lms_,
   {{0x44394ad9,0x27ed0031,0x7a240176,0x00000000}},	//   oms_, yhen_, còti, --,
   {{0xf5370070,0xdb1b0132,0x999e007e,0x27ed0055}},	//   קטאר_, _anuá, _bitů_, xhen_,
   {{0x60130484,0x161a0084,0xed15006c,0xeab30037}},	//   għme, नकार_, _کہاں_, بعض_,
   {{0x7f3a00a5,0xa9663cc0,0x75ed0168,0xdce700fe}},	//   _לערו, пиша_, _kúze, _hejč,
   {{0xa3ce0e6f,0x76434ada,0x764b4adb,0x68254adc}},	//   राम_, _riny, _sugy, lódi,
   {{0x76434add,0x44394ade,0xf7711b15,0x75ed18fa}},	//   _siny, jms_, راب_, _múze,
   {{0x27ed4adf,0x76433b4f,0x27ff01f4,0x443200e9}},	//   rhen_, _piny, riun_, _rhy_,
   {{0x27ed00da,0x24750029,0x27ff1e2b,0x443900d8}},	//   shen_, tām_, siun_, ems_,
   {{0x44204ae0,0x7a2d002a,0x5edf0033,0x26cd002a}},	//   _pki_, cúta, _নেমে, sxeo_,
   {{0x3835325e,0x24750029,0xdce701c0,0x764b4ae1}},	//   _энер, rām_, _nejč, _tugy,
   {{0xddcd0a4c,0xa3ce0066,0x247500ea,0xa6350210}},	//   draž, राब_, sām_, _енді,
   {{0x44320122,0x44394ae2,0x66ba011d,0x247500ea}},	//   _why_, ams_, _למנה, pām_,
   {{0x412a4ae3,0x44204ae4,0x4439012f,0x44324ae5}},	//   сово_, _tki_, bms_, _thy_,
   {{0x66010069,0xe0434ae6,0x8ca60324,0x2fd90284}},	//   lilk, енси, _टैगो, _cosg_,
   {{0x6e4600ce,0x00000000,0x00000000,0x00000000}},	// [4460] سنام, --, --, --,
   {{0xd8380260,0xf8bd4ae7,0x42fb00a5,0x00000000}},	//   _apčl_, ्माय, _להפס, --,
   {{0x63b60723,0xddcd02c6,0x360d0083,0xdd8f01b2}},	//   _kayn, braž, _হঠাৎ_, اوم_,
   {{0x20570319,0x1b150033,0x660101ed,0x00000000}},	//   _מיטל_, তেছে_, hilk, --,
   {{0x63b60dc3,0x682501ef,0x00000000,0x00000000}},	//   _mayn, códi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca34ae8,0x6601279a,0xa8a3010b,0x44394ae9}},	//   _пари, dilk, ерык, yms_,
   {{0x7a2d4aea,0x368a2d7a,0x00000000,0x00000000}},	//   rúta, бсон_, --, --,
   {{0x61fe0443,0x2e3401ff,0x8626010b,0x00000000}},	//   _ompl, räff_, зьне, --,
   {{0xf9c40ef5,0x660102c2,0x644d0009,0x7a2d00a0}},	//   _تحری, gilk, _čair, lútn,
   {{0x69c8257c,0xdcfc01d6,0x443900ec,0xb21b0093}},	//   _inde, _karı, tms_, fræn,
   {{0xb21b054e,0x61fe2e65,0x63b60510,0x21ef033b}},	//   græn, _ampl, _cayn, _mühe_,
   {{0x44394aeb,0x63b64aec,0xe9ff01a5,0x66014aed}},	//   rms_, _dayn, _quần_, bilk,
   {{0x44394aee,0x69da03ad,0x66014aef,0x224501ff}},	//   sms_, _jote, cilk, ölk_,
   {{0xddcd01cc,0x859b0122,0x69da4af0,0xc0c8002d}},	//   traž, _השוו, _mote, путе_,
   {{0x61fe4af1,0xe9ff0028,0xa3ce0591,0x0ec80141}},	//   _empl, _tuần_, राण_, रमंड,
   {{0x69c81cd5,0xe9ff0019,0x52150b25,0xadb50d6e}},	// [4470] _onde, _huấn_, _одит, мбаш,
   {{0x69da4af2,0xd5b800ea,0x9f490079,0x63b6034d}},	//   _note, ndā_, mhaí_, _zayn,
   {{0xdcfc06d3,0x68254af3,0x26c0010b,0xdce702a7}},	//   _barı, sódi, _šiol_, _tejč,
   {{0x69c83fe0,0xd7e60037,0x00000000,0x00000000}},	//   _ande, _شك_, --, --,
   {{0x69da4af4,0xa3ce02cb,0x69c80279,0x7ae24af5}},	//   _bote, रात_, _bnde, gyot,
   {{0x69da4af6,0xa85903fa,0xdea4103b,0x38590421}},	//   _cote, ојих_, _سیمی, орию_,
   {{0x7c844af7,0x69da01ba,0x66012b47,0x9e342192}},	//   _путе, _dote, vilk, _черч,
   {{0x7b08104b,0x69da01ed,0x2d8c0225,0x00000000}},	//   ástá, _eote, _öder_, --,
   {{0x66014af8,0xdb00007e,0x6d4a00ae,0x00000000}},	//   tilk, _kamý, şlaş, --,
   {{0xd70603ad,0xa37b00ab,0x00000000,0x00000000}},	//   ьные_, skõl, --, --,
   {{0xdcfc0d6f,0xb21b0d50,0x6add198f,0x7bc91472}},	//   _yarı, træn, _मथुर, _kneu,
   {{0xd91a012b,0x66011201,0xa3ce00dc,0x68e34af9}},	//   _וועל, silk, राध_, mynd,
   {{0x28bd0b35,0x68e30093,0x69c80a8a,0x7bdb0107}},	//   ्मवि, lynd, _ynde, _mouu,
   {{0xe6180210,0x63b64afa,0xc7b900fd,0x00000000}},	//   _еді_, _wayn, ldő_, --,
   {{0x324341f8,0x68e303d0,0x1fb60009,0xf1c30af9}},	//   терг, nynd, мсар, शाजन,
   {{0xdfd2381f,0xc7b9006c,0x9f400098,0x00000000}},	//   خير_, ndő_, mhiú_, --,
   {{0x1dc90325,0xdb00008a,0x9f49004f,0x24530023}},	// [4480] रांत, _samþ, chaí_, _hãm_,
   {{0x68e30527,0xee374afb,0x7ae2000e,0xdcfc008f}},	//   kynd, дну_, vyot, _sarı,
   {{0x69da0059,0x7e760107,0x00000000,0x00000000}},	//   _rote, ssyp, --, --,
   {{0x69da4afc,0xdcfc00a8,0x7bc9099e,0x00000000}},	//   _sote, _qarı, _cneu, --,
   {{0xbb4300d8,0x24530019,0xc4c90355,0x1958010b}},	//   вецк, _lãm_, िमुख, палы_,
   {{0x7ae24afd,0x6286018d,0x98c61538,0x00000000}},	//   ryot, irko, дсил, --,
   {{0x68e3054e,0x7ae2010d,0x69da4afe,0xdcfc027d}},	//   gynd, syot, _vote, _tarı,
   {{0xb8d6051d,0x69da4aff,0x5fd100a1,0xb9060440}},	//   _छन_, _wote, हायल, _पथ_,
   {{0x69da4b00,0x6d434b01,0x00000000,0x00000000}},	//   _tote, žnat, --, --,
   {{0x69c8024b,0xd49a0012,0x752f004e,0x7bc9024e}},	//   _unde, орм_, ęczn, _zneu,
   {{0x43954b02,0x35f7004f,0x628634d2,0xe9ff0023}},	//   нанс, بريد_, erko, _quấn_,
   {{0x9f490037,0x00000000,0x00000000,0x00000000}},	//   thaí_, --, --, --,
   {{0x3dca0107,0x00000000,0x00000000,0x00000000}},	//   _onbw_, --, --, --,
   {{0xe9ff01a5,0xddcd080a,0x00000000,0x00000000}},	//   _tuấn_, ksaš, --, --,
   {{0x62864b03,0x301503e6,0x9f400098,0x00000000}},	//   arko, едвр, chiú_, --,
   {{0xdb004b04,0xb21b008a,0x71990088,0x00000000}},	//   _jamó, mræm, _کندز_, --,
   {{0xdb0002d7,0x00000000,0x00000000,0x00000000}},	// [4490] _mamó, --, --, --,
   {{0x442b1016,0x645701ef,0x25ac00e9,0x7bc90d35}},	//   llc_, _éxic, nedl_, _sneu,
   {{0x7bc9109e,0x3d9417a3,0x00000000,0x00000000}},	//   _pneu, тихр, --, --,
   {{0xaa0720ab,0xdab9010b,0x00000000,0x00000000}},	//   वच्छ_, зыкі_, --, --,
   {{0x442b184f,0xbddb0176,0x68e300e5,0xdce702d4}},	//   ilc_, _quès, wynd, _dejā,
   {{0x7bc90297,0x68e30a8a,0x1c004b05,0xe9d800d8}},	//   _wneu, tynd, लोबल_, мкі_,
   {{0x6c540009,0x4c170647,0xdcee0067,0xdd941023}},	//   _аксу, _قبرس, _odbę, _шары,
   {{0x68e30103,0xbddb000d,0x6286017b,0xd7750037}},	//   rynd, _guèr, yrko, رابع,
   {{0xa3ce25de,0xd7090340,0xd90e00b5,0x00000000}},	//   रास_, яние_, لیے_, --,
   {{0x7c2b4b06,0x9f400037,0xb33b0392,0xb46503c6}},	//   llgr, thiú_, neçu, нкол,
   {{0x64c90026,0xdb000310,0x2a6d01ed,0xe57600af}},	//   िमेश, _famó, _hweb_, эзэ_,
   {{0xab5d0035,0x8ca80437,0xf8bd178c,0x00000000}},	//   _poży, _घनघो, ्मीप, --,
   {{0xc7d6168d,0x1ae10033,0xd9e3046c,0x00000000}},	//   _רוני_, _খেতে_, _औकात_, --,
   {{0xdb00004e,0xa3ce4b07,0xe2a7008d,0x645c1d2b}},	//   _zamó, राह_, óðar_, íric,
   {{0xa0a30fc5,0x1c1f045c,0xc95232e3,0x8fa64b08}},	//   лард, यकाल_, רמל_, наве,
   {{0x6286003a,0xdb001c02,0x00000000,0x00000000}},	//   prko, _mamò, --, --,
   {{0x44224b09,0x63a44b0a,0x8d660800,0xdb00021e}},	// [44a0] mok_, _ibin, евзе, _lamò,
   {{0x44224b0b,0xa3ce0325,0x7c2b1b4a,0xfc4700ac}},	//   lok_, राव_, elgr, _šípy_,
   {{0x3b86021d,0xfce30f24,0x2d870138,0x44220381}},	//   елег, лофо, ónea_, ook_,
   {{0x44224b0c,0x00000000,0x00000000,0x00000000}},	//   nok_, --, --, --,
   {{0x63a44b0d,0x5b2315eb,0xdb000d2e,0xe7d308b0}},	//   _mbin, льша, _ramó, थानप,
   {{0x44224b0e,0x2a6d0036,0xdb000107,0x427b0070}},	//   hok_, _dweb_, _bamò, לאנג,
   {{0x6d4e043d,0xbad80083,0x22440187,0x25ac0355}},	//   _igba, _দেখছ, ímky_, vedl_,
   {{0x3ebf025c,0x44224b0f,0x8c432447,0x38b10207}},	//   _šuti_, jok_, _бесе, _dšr_,
   {{0x44224b10,0x7c224b11,0xa61403fa,0x6280006c}},	//   dok_, moor, кмич, ámol,
   {{0x63a44b12,0x7c224b13,0x5b352408,0x00000000}},	//   _abin, loor, _рэсу, --,
   {{0x6d4e0159,0xa37b00ab,0x44224190,0x63a40103}},	//   _mgba, lkõi, fok_, _bbin,
   {{0x44224b14,0x2bc60653,0x988b00fd,0x3eb20345}},	//   gok_, _रोमा, _رحمہ_, kwyt_,
   {{0xa2be0967,0x6d5c02e9,0x55e64b15,0x1db2022e}},	//   शिष्, _ofra, _подб, ीयात,
   {{0x7c220903,0x63a40273,0xdb0220d9,0x6d4e010d}},	//   hoor, _ebin, ndoñ, _ngba,
   {{0x7c224b16,0x00000000,0x00000000,0x00000000}},	//   koor, --, --, --,
   {{0x44224b17,0x2b490c99,0x629a002d,0x98bc027d}},	//   cok_, žaci_, ător, navı_,
   {{0x7c224b18,0x7e64121e,0xddd40009,0xa3ce0ed1}},	// [44b0] door, gpip, _šašo, रार_,
   {{0x628f0027,0xab5d009f,0x63bd4b19,0x63af06fe}},	//   muco, _inżi, ldsn, lecn,
   {{0x557700c2,0x7c224b1a,0x680700e0,0x00000000}},	//   געבן_, foor, _jèjè, --,
   {{0x6d5c4b1b,0x63bd1661,0x2002022e,0x7c2200ab}},	//   _efra, ndsn, _gmki_, goor,
   {{0x629d4b1c,0x6d5c001e,0x7f7600a5,0x63bd0d35}},	//   ntso, _ffra, _בערב_, idsn,
   {{0x44224b1d,0x00000000,0x00000000,0x00000000}},	//   zok_, --, --, --,
   {{0x7c224b1e,0x44224b1f,0x7c2c000d,0x628f00d5}},	//   boor, yok_, éorè, huco,
   {{0x7c2204f4,0x63af24e4,0x628f0103,0x88c40118}},	//   coor, jecn, kuco, اتول,
   {{0xdcee00b8,0x629d4b20,0x628f0156,0x63af00d5}},	//   _odbě, jtso, juco, decn,
   {{0x44223540,0x628f119e,0x628000b5,0x63a40207}},	//   wok_, duco, ámom, _sbin,
   {{0x44224b21,0xa3ce0026,0x06df0033,0x764a4b22}},	//   tok_, राल_, _বেশি, _dify,
   {{0x7e640159,0xa2be04bc,0x6ec4018d,0x629d16d1}},	//   ypip, शिल्, रिमु, ftso,
   {{0x44224b23,0x06df0033,0x21f400be,0x940d013b}},	//   rok_, _বেরি, _lähe_, ntdə_,
   {{0x44224b24,0x6d5b027d,0x21ef00be,0x00000000}},	//   sok_, _şuan, _püha_, --,
   {{0x44224b25,0x21f401ae,0x2002012f,0x910300ed}},	//   pok_, _nähe_, _pmki_, апре,
   {{0x63a42f10,0x6d5c027a,0xe3b20fab,0xc0e303e6}},	//   _ubin, _sfra, _ضرب_, шоск,
   {{0x539b0052,0xf77200c2,0x7c220903,0x785100ea}},	// [44c0] _חיפו, יקן_, voor, _dāvi,
   {{0x7c220d26,0x4d630d30,0x7e64009e,0x00000000}},	//   woor, икув, rpip, --,
   {{0xeb9a4419,0x7c224b26,0x67f500ee,0x8c4618cd}},	//   дие_, toor, _kájd, веже,
   {{0x31780035,0xe7270037,0x7a2d0079,0xcb0a00f3}},	//   larz_, _نص_, lúth, ويان_,
   {{0x7c220136,0x6d5c00d7,0x00000000,0x00000000}},	//   roor, _tfra, --, --,
   {{0x7c224b27,0xf1d5021a,0xa3ce04aa,0x31780067}},	//   soor, दायन, राँ_, narz_,
   {{0x7c224b28,0xa37b00ab,0x09e300ed,0xdcee0107}},	//   poor, skõi, ројн, _kebč,
   {{0x67f5016f,0x61df16d3,0x20124b29,0xb21b01b4}},	//   _nájd, _नक्ष, nnyi_, træk,
   {{0x31780035,0x680700e0,0x466700af,0xbb434b2a}},	//   karz_, _sèjè, крэм_, _ветк,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4cc00ab,0x624b0484,0xa3ce02b4,0x68250a20}},	//   रमे_, _bżon, रां_, ródr,
   {{0x60130484,0x629d0df7,0xd5be00ea,0xbf9b0183}},	//   għml, ttso, _šāda_, _amên,
   {{0x61e1022a,0x63af30ec,0x68250138,0x75ed07c0}},	//   öllo, recn, pódr, _kúzl,
   {{0x629d0291,0x63af0169,0xdcfc0260,0x628f2005}},	//   rtso, secn, _adrč, ruco,
   {{0x629d4b2b,0x67f500b5,0x00000000,0x00000000}},	//   stso, _fájd, --, --,
   {{0xa3ce166b,0x2d984b2c,0x25bc007e,0x00000000}},	//   राः_, _acre_, _havl_, --,
   {{0x4429383a,0x2caa1af8,0x2d870300,0x644d0211}},	// [44d0] _ika_, _apbd_, óneo_, _iiai,
   {{0x20120273,0x644d016e,0x21f400be,0x60c500ee}},	//   anyi_, _hiai, _pähe_, _trhm,
   {{0x9f9c008d,0x270e0f9c,0x645e000d,0x644d08c7}},	//   _tíð_, ापुर_, _épid, _kiai,
   {{0x21f400ab,0x44294b2d,0xddcd00a0,0x3ebf0207}},	//   _vähe_, _jka_, dsať, _šutu_,
   {{0x3b840210,0x53a50e04,0x26c60221,0x20094b2e}},	//   рліг, ग्यश, _nroo_, miai_,
   {{0x20090a93,0x644d4b2f,0x443b00e2,0x5fd1021a}},	//   liai_, _liai, _lhq_, हावल,
   {{0x44294b30,0x3eb900d7,0xb4cc0035,0xa3e40026}},	//   _oka_, _hsst_, रमो_, पॉड_,
   {{0x20090a93,0x644d4b31,0x44290232,0xa3d70084}},	//   niai_, _niai, _nka_, साफ_,
   {{0x7c290291,0xa3d70c57,0x5b1503fa,0x46493537}},	//   _iker, सान_, _смат, нзин_,
   {{0xe61602ee,0x44290b04,0xf99318dd,0x2009027a}},	//   лды_, _aka_, _خبر_, hiai_,
   {{0x200900d8,0x44294b32,0x644d4b33,0x240a02fb}},	//   kiai_, _bka_, _biai, енни_,
   {{0x442901f4,0x67f50097,0xb33b00a8,0x00000000}},	//   _cka_, _báje, veçr, --,
   {{0xe5a54b34,0xe2c70572,0x7c3b4b35,0x644d4b36}},	//   _били, гляд_, _mhur, _diai,
   {{0x44294b37,0x27ed1b2f,0xab5d009f,0x25bc008c}},	//   _eka_, lken_, _inżu, _gavl_,
   {{0x644d4b38,0x7c2901d7,0x624b009f,0x7c3b00ee}},	//   _fiai, _oker, _iżol, _ohur,
   {{0x27ed4b39,0x2009100d,0x2d830fbc,0x644d2a97}},	//   nken_, giai_, _adje_, _giai,
   {{0xee3a2d13,0x27ed4b3a,0x25f7045c,0xe1ff4b3b}},	// [44e0] ена_, iken_, एसपी_, mpón_,
   {{0xdd920071,0x7c294b3c,0x7c3b4b3d,0xe1ff0138}},	//   صوص_, _aker, _ahur, lpón_,
   {{0x27ed4b3e,0x67f501c0,0x6da303d0,0x7c3b1600}},	//   kken_, _záje, сиха, _bhur,
   {{0x27ed04ce,0xa3d70d53,0x7c3b4b3f,0x20094b40}},	//   jken_, साय_, _chur, ciai_,
   {{0xead43e3d,0x7c3b00da,0x09e64b41,0xab770c74}},	//   роль, _dhur, лодн, امها_,
   {{0x2d83039a,0x27ed0a75,0x61ee01a2,0x3ea04b42}},	//   _gdje_, eken_, nkbl, mtit_,
   {{0x7c3b239a,0x3ea04b43,0xf84a00af,0x00000000}},	//   _fhur, ltit_, нчий_, --,
   {{0xd6da4b44,0x2fc04b45,0x7c2901ed,0x38340bfe}},	//   ето_, ndig_, _gker, јнир,
   {{0xb4cc00b4,0x3ea04b46,0xa3ce00c0,0x4429012f}},	//   रम्_, ntit_, राई_, _rka_,
   {{0x44294b47,0xa96a004f,0x644d010b,0x27ed4b48}},	//   _ska_, _أمام_, _siai, aken_,
   {{0x2ed11bc6,0x66080118,0xd82f0144,0xb4be0084}},	//   _सप्त, ridk, _гэ_, ँटे_,
   {{0x27ed4b49,0x3ea04b4a,0x78ba006c,0x2a640a4e}},	//   cken_, ktit_, _istv, _ktmb_,
   {{0xa3d71a75,0x200900d8,0x518700c9,0x6608028b}},	//   साब_, viai_, лува, pidk,
   {{0x2fc04b4b,0x54e60079,0x00000000,0x00000000}},	//   edig_, _مسبق, --, --,
   {{0xb21b08c8,0xf55b00a5,0x00000000,0x00000000}},	//   kræv, _אדומ, --, --,
   {{0x657a4b4c,0x44294b4d,0x087702b5,0x442f4b4e}},	//   lath, _uka_, טעלט_, _óg_,
   {{0x20090a93,0x33a80133,0x6e954b4f,0xe3bf01ef}},	// [44f0] riai_, _също_, ризу, coña_,
   {{0x7c3b4b50,0x78ba01cc,0x7c294b51,0x200901c8}},	//   _shur, _ostv, _sker, siai_,
   {{0x69bb045c,0x3ea04b52,0x200900d8,0x7c3b009e}},	//   _एसबी, atit_, piai_, _phur,
   {{0x657a4b53,0x200c0248,0xa3ce0461,0xce9502fb}},	//   hath, édit_, राए_, _камъ,
   {{0x657a4b54,0x63bf0be2,0x3ea001f7,0x78ba0176}},	//   kath, _maqn, ctit_, _astv,
   {{0x17ed0803,0x88c5004f,0x657a2014,0xac772499}},	//   जस्व_, لتعل, jath, _مارش,
   {{0x28c506d9,0x27ed4b55,0x7c3b2da9,0x14b00967}},	//   विधि, tken_, _thur, _जनगण,
   {{0x7c3b4b56,0x78ba0009,0x06851fd8,0x7c294b57}},	//   _uhur, _dstv, агин, _uker,
   {{0x27ed4b58,0xe7e60ccf,0x657a4b59,0x6b9b009e}},	//   rken_, _ओकरा_, fath, _icug,
   {{0x27ed4b5a,0x657a103b,0x80bb0033,0xdb000183}},	//   sken_, gath, _উপন্, _camõ,
   {{0x21f4007c,0x2fc04b5b,0x25f70bdd,0xddc600fe}},	//   _näha_, ydig_, एसबी_, _cukř,
   {{0x02c64b5c,0xab5d007a,0x245a0031,0x69bb0067}},	//   аймо, _dażg, _dëm_, _एसडी,
   {{0x657a179a,0x66670421,0x386900f4,0x00000000}},	//   bath, _съез, ćaru_, --,
   {{0x657a4b5d,0xe1ff01dd,0xe3bf002a,0x00000000}},	//   cath, spón_, roña_, --,
   {{0xab5d006a,0x61464b5e,0x61ee309a,0x412a05c2}},	//   _każd, рева, rkbl, тово_,
   {{0x3ea04659,0x2fc00244,0x6f66027a,0x1f661f67}},	//   ttit_, udig_, рваз, ркам,
   {{0x3ea04b5f,0x2fc04b60,0xed5a1457,0x765b00cc}},	// [4500] utit_, rdig_, воз_, nquy,
   {{0xc27b0779,0x3ea04b61,0x20190009,0x645e4135}},	//   _שריי, rtit_, _ejsi_, _épic,
   {{0x3ea04b62,0x2a64046a,0x8fa616ef,0x7a2d0093}},	//   stit_, _stmb_, _кане, nútu,
   {{0x78ba0009,0x3ea04b63,0x657a026b,0xc50c0070}},	//   _rstv, ptit_, zath, עלאָ,
   {{0xa3d7035d,0x62880035,0x657a4b64,0x6b9b009e}},	//   सात_, ądow, yath, _dcug,
   {{0x9f400421,0x00000000,0x00000000,0x00000000}},	//   rkiä_, --, --, --,
   {{0x44c50029,0x218902b5,0x657a4b65,0x2c6c0107}},	//   _nē_, אָפּ, vath, _dòdò_,
   {{0xc7c64b66,0x657a4b67,0x63a60051,0xb21b05ee}},	//   рски, wath, jfkn, lræt,
   {{0x657a4b68,0x8f9b0100,0xd6d709eb,0x2a640176}},	//   tath, דיפי, атэ_, _utmb_,
   {{0x35f40e75,0x26c000d8,0x78ba0009,0xb21b003e}},	//   спор, _šios_, _tstv, nræt,
   {{0xd7ef19fa,0x78ba02c6,0x7d7b0397,0x6aa21736}},	//   _ду_, _ustv, כניו, ltof,
   {{0x7bc20852,0x7bc007ee,0xa3ce0084,0x657a4b69}},	//   ndou, _jamu, राग_, sath,
   {{0x7bc04b6a,0x6aa24b6b,0x657a0cdb,0x7a2d0093}},	//   _mamu, ntof, path, rútv,
   {{0x7bc04b6c,0x44c50107,0x00000000,0x00000000}},	//   _lamu, _fē_, --, --,
   {{0xe6b61604,0xa3d71cce,0x16b605a6,0xb21b3e88}},	//   _अनुज, साद_, _अनुब, dræt,
   {{0x7bc01690,0x7415064e,0x2aa002d0,0x6aa20409}},	//   _namu, _دوبا, kòb_, ktof,
   {{0x64581eca,0xe7ee0006,0x65780221,0xdb23045e}},	// [4510] _huvi, _जवना_, _kevh, ürül,
   {{0x64584b6d,0x7bc00086,0x5d670f16,0xe7a60099}},	//   _kuvi, _aamu, ртаз, क्तप,
   {{0x7bc0203d,0x8d740987,0xab5d0024,0xdcbb02fb}},	//   _bamu, زالا, _laże, ъща_,
   {{0x81b800c8,0x6458184b,0x61e502b1,0x1fa71e96}},	//   ছাঃ_, _muvi, _hohl, _трог,
   {{0x7bc04b6e,0x61e501ae,0x6458018f,0x201e00a2}},	//   _damu, _kohl, _luvi, étie_,
   {{0x64580370,0x6578024e,0x7bc00069,0xafdb008c}},	//   _ouvi, _nevh, _eamu, _giør,
   {{0x61e505d3,0x7bc0035f,0x64580e95,0xb60800ee}},	//   _mohl, _famu, _nuvi, _myšľ,
   {{0xe7394b6f,0x7bc024a8,0x7bc22cd7,0x6abb01ef}},	//   лей_, _gamu, cdou, _tsuf,
   {{0x6abb1d99,0x60130484,0x66d30225,0x645802ee}},	//   _usuf, għmi, dıkö, _auvi,
   {{0x7bc04b70,0x44c5013a,0x645800c7,0x75ed00ee}},	//   _zamu, _pē_, _buvi, _kúzi,
   {{0x64580043,0x7bc02d06,0x628f0973,0x00000000}},	//   _cuvi, _yamu, erco, --,
   {{0x69c14b71,0x2bda0026,0x645803e6,0x69c34b72}},	//   _hale, णाया, _duvi, ldne,
   {{0x61e54b73,0x97560122,0x28c506fe,0xa3e91b8f}},	//   _bohl, _הינו_, विवि, _मकर_,
   {{0x69c100f8,0xbb3a0100,0x44c5013a,0x61e50160}},	//   _jale, טערי, _tē_, _cohl,
   {{0x69c14b74,0x67f5016f,0x9f4201f4,0x628f0051}},	//   _male, _zája, _tokë_, arco,
   {{0x69c14b75,0x6d550168,0xa3ce00b4,0x81b80831}},	//   _lale, _agza, राओ_, ছাই_,
   {{0x0d862b7a,0x7bc04b76,0x38a10037,0x64583ad9}},	// [4520] йлан, _ramu, hór_, _zuvi,
   {{0x7bc04b77,0x69c14b78,0xab8c01d6,0xa7fc037a}},	//   _samu, _nale, _çözü, _atıl,
   {{0x7bc04b79,0x315702b8,0x41d500a1,0x6458002a}},	//   _pamu, _ליין_, दारस, _xuvi,
   {{0x6d554b7a,0x69c14b7b,0x2aa002e9,0x6aa20dc6}},	//   _egza, _aale, tòb_, ttof,
   {{0x7bc0030d,0x7bc24b7c,0x00000000,0x00000000}},	//   _vamu, rdou, --, --,
   {{0x6aa24b7d,0xe2a70093,0x7bc01548,0x2bfa0083}},	//   rtof, óðir_, _wamu, েকেই_,
   {{0x6aa24b7e,0x69c14b7f,0xf8c500a1,0x7bc04b80}},	//   stof, _dale, विषय, _tamu,
   {{0xb8d00ccf,0x7bc0000e,0x9f4202e9,0x67f505c9}},	//   _ओह_, _uamu, _pokè_, _pája,
   {{0x69c14b81,0xa3d70a40,0x77790069,0xa3dc111b}},	//   _fale, सास_, _dewx, ठान_,
   {{0x69c14b82,0xceb30bed,0xd5ba2c86,0x38a10035}},	//   _gale, ליח_, уси_, bór_,
   {{0x62844b83,0x2813006c,0xc957004f,0x61e54b84}},	//   _avio, _کونس, _المش_, _rohl,
   {{0x69c109fa,0xd6df0033,0xdb0b3441,0x67f500ee}},	//   _zale, _বেওয, legá, _hájn,
   {{0x61e5033a,0xa3ce06bc,0x69c1276d,0x628f32ef}},	//   _pohl, राज_, _yale, urco,
   {{0x64584b85,0x69c14b86,0x7afd027d,0xe3bf0391}},	//   _tuvi, _xale, _üste, poño_,
   {{0x27e64b87,0x61e5023a,0x00000000,0x00000000}},	//   _koon_, _vohl, --, --,
   {{0x61e501ae,0x27e64b88,0xdb0b0042,0x00000000}},	//   _wohl, _joon_, hegá, --,
   {{0x6d480076,0x442b49d3,0x63ad4b89,0x7988011e}},	// [4530] _údaj, moc_, _iban, _oddw,
   {{0xd04701c2,0x442b4b8a,0x63ad06f7,0xa3d700dc}},	//   _əmək, loc_, _hban, साव_,
   {{0x69c14b8b,0x63ad46a6,0x00000000,0x00000000}},	//   _rale, _kban, --, --,
   {{0x69c14b8c,0xb21b01b4,0x79880090,0xeb9001b2}},	//   _sale, præs, _addw, فظه_,
   {{0x63ad4b8d,0xb4d50066,0x38a10035,0x33204b8e}},	//   _mban, _सप्_, wór_, _xxix_,
   {{0x69c14498,0x7e6d4b8f,0xda78325e,0x442b3c05}},	//   _qale, mpap, сяц_, hoc_,
   {{0x69c34b90,0x25f70026,0x16d10461,0x63ad4b91}},	//   rdne, एससी_, तम्ब, _oban,
   {{0x16654b92,0x57e93e47,0x6b750e9f,0xb5fd0009}},	//   овим, рдим_, _флау, mpši,
   {{0x7c2b4b93,0x69c10e45,0x27e600a7,0x2bcf1782}},	//   mogr, _tale, _doon_, _सोया,
   {{0x63ad4b94,0x69c1009e,0x38c900b5,0x27e60107}},	//   _aban, _uale, _پائی_, _eoon_,
   {{0xca484b95,0x0446294a,0x27e603bc,0xf2c9100a}},	//   _الله_, женн, _foon_, _שע_,
   {{0x38850080,0x2bcf00ab,0xa34a1682,0x442b00cc}},	//   mēr_, _सोमा, изна_, goc_,
   {{0xe72e0a55,0x645e000d,0x67f500d5,0xf1d50099}},	//   _це_, _épin, _hájo, दांन,
   {{0x27e60120,0x7c2b4b96,0x7a3f00a2,0x00000000}},	//   _zoon_, hogr, bête, --,
   {{0x7c2b21a9,0x27e64b97,0x442b2423,0xdcf500fe}},	//   kogr, _yoon_, boc_, _bezč,
   {{0x6b894b98,0x7c2b035f,0xb4d52df6,0x67f50097}},	//   _ndeg, jogr, समी_, _májo,
   {{0xa3d705f7,0x7e6d2a41,0xc7b202b8,0x7c2b4b99}},	// [4540] सार_, gpap, ובן_, dogr,
   {{0x6b894b9a,0x0d862659,0x13a6006c,0x6ab80033}},	//   _adeg, ілен, _اچھی_, _আপলো,
   {{0x7c2b4b9b,0xb6070029,0xd5fa0070,0x67f500a0}},	//   fogr, mašī, ספער, _nájo,
   {{0x35db0066,0xfbfa0033,0x00000000,0x00000000}},	//   बाड़, েক্ষ_, --, --,
   {{0x27e6067f,0x254e0095,0x6013003c,0x7d24006c}},	//   _roon_, zəl_, għmu, _کہان,
   {{0x27e600a5,0xc8c50026,0x6b894b9c,0x00000000}},	//   _soon_, विंट, _edeg, --,
   {{0x23ca00dc,0x27e64b9d,0x2e2f033b,0xdb0b2f64}},	//   ियाद, _poon_, rüft_, regá,
   {{0x254e0095,0x76aa1e92,0x7a3f00f7,0xeb972701}},	//   vəl_, атов_, vête, _мис_,
   {{0x442b4b9e,0x27e6028b,0xfaa62519,0xe7a60099}},	//   voc_, _voon_, _фазо, क्षप,
   {{0x27e61516,0x80bb0083,0xd9461bc0,0x63ad4b9f}},	//   _woon_, _উপস্, _дези, _sban,
   {{0x27e64ba0,0x41de01c0,0xf1de0af9,0xe7861783}},	//   _toon_, मानस, मानन, _дуло,
   {{0x7a3f0248,0xab5d009f,0x3fc50033,0x00000000}},	//   rête, _każa, _এক্ষ, --,
   {{0x442b47b8,0x23dd00a1,0xb6cb00b5,0x555800af}},	//   roc_, याबद, _پانے_, _лаля_,
   {{0x67fc4ba1,0x00000000,0x00000000,0x00000000}},	//   _déje, --, --, --,
   {{0x7c2b4ba2,0xba3d000c,0x957c0035,0x6234002d}},	//   yogr, _způs, ając, феру,
   {{0x63ad4ba3,0x6825004e,0x6d58010b,0x7e6d20b1}},	//   _uban, wódz, žval, tpap,
   {{0x7c2b33c7,0x2241012f,0x9f340210,0x00000000}},	// [4550] vogr, _thhk_, деті, --,
   {{0x7c2b02e9,0xf2d202b5,0xe2a70093,0x6b89027a}},	//   wogr, _װעט_, óður_, _sdeg,
   {{0x7e6d4ba4,0x61e1008a,0x91ba011d,0x31351641}},	//   spap, öllu, _המתי, _хенр,
   {{0xf3ff0370,0x3c3c2c0e,0xab5d4ba5,0x7e6d1fb2}},	//   nhã_, tíva_, _baża, ppap,
   {{0xa96905f2,0xa3e90722,0x00000000,0x00000000}},	//   била_, _मकई_, --, --,
   {{0xf1cb07df,0x00000000,0x00000000,0x00000000}},	//   ायिन, --, --, --,
   {{0x7c2b46da,0x2d814ba6,0x67f500b5,0xb60700c7}},	//   pogr, mahe_, _fájl, našū,
   {{0xe7a60324,0x96953e3d,0x2d8100f8,0xab5d0069}},	//   क्लप, прош, lahe_, _faża,
   {{0x41cb052f,0xf7710220,0xf1cb01d1,0xab5d0069}},	//   ायास, واک_, ायान, _gaża,
   {{0x2d814ba7,0xc9f70037,0x00000000,0x00000000}},	//   nahe_, _بسرع, --, --,
   {{0xc3290122,0xa3d70edf,0x645e000d,0x1bf200b4}},	//   _עו_, सां_, _épil, _अकमल_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8100e0,0xc5f502fb,0x9f590260,0x00000000}},	//   kahe_, _някъ, _ilsè_, --,
   {{0x2167021d,0x00000000,0x00000000,0x00000000}},	//   зири_, --, --, --,
   {{0x2d813f22,0xdb0901f7,0xe3c200c1,0x00000000}},	//   dahe_, _obeï, _alış_, --,
   {{0x27ff011e,0xddc408b7,0x6d480079,0x99870355}},	//   nhun_, dpiš, _údai, konů_,
   {{0x35d00953,0x44201872,0x67f50097,0x3f800183}},	// [4560] _थोड़, _iji_, _nájm, raiu_,
   {{0x62860a78,0x614600d8,0xb21b008a,0x64440118}},	//   msko, _непа, nsæl, _hhii,
   {{0xd7bd0429,0xe7bd0e9b,0xc1730052,0x62860d5c}},	//   ्याच, ्याप, _אחת_, lsko,
   {{0xeb9a0aec,0x60db00a5,0xfaa631d3,0x5f070067}},	//   сид_, _הקטנ, задо, _सेक्_,
   {{0x6286287d,0x4420000e,0xa3bf0066,0x64560225}},	//   nsko, _mji_, ीयत_, _miyi,
   {{0x201201c2,0x62864ba8,0x433b0070,0x6456001c}},	//   liyi_, isko, זענב, _liyi,
   {{0x7af200b8,0x44204ba9,0x624b0024,0x61470e8c}},	//   _řetě, _oji_, _iżot, mélé,
   {{0x442000da,0x6456035a,0xfaa61174,0x6286038d}},	//   _nji_, _niyi, _набо, ksko,
   {{0x628635b9,0xf4220033,0x6f044baa,0xfaa40416}},	//   jsko, নতার_, nzic, _تجزی,
   {{0x62864bab,0x44204bac,0x44324bad,0xa2d00355}},	//   dsko, _aji_, _aky_, दिन्,
   {{0x62864bae,0x43954baf,0xbebb01f4,0x64561939}},	//   esko, манс, _nxën, _biyi,
   {{0x62864bb0,0x64444bb1,0x6722006f,0x6b824bb2}},	//   fsko, _chii, _txoj, naog,
   {{0x644401da,0x62864bb3,0x201201c2,0x2d811295}},	//   _dhii, gsko, diyi_, yahe_,
   {{0x6f04004e,0x443209d6,0x171b00a5,0x4420005f}},	//   dzic, _eky_, _פוגע, _eji_,
   {{0x64440211,0x2d814bb4,0x64a349a8,0x6f040051}},	//   _fhii, vahe_, _заја, ezic,
   {{0x75370052,0x999e00d8,0x645632c7,0x62860a8a}},	//   _מאוד_, _kitų_, _giyi, bsko,
   {{0xa3d32fa9,0xdb080248,0x6b824bb5,0x2d814bb6}},	// [4570] _होय_, _élèv, daog, tahe_,
   {{0x44394bb7,0xddc4011c,0x6456313a,0x41de057c}},	//   lls_, tpiš, _ziyi, माणस,
   {{0x6457116c,0x44394bb8,0x271e01a5,0x999e00d8}},	//   _éxit, ols_, ịnh_, _litų_,
   {{0x44cc000c,0xa3d31bc6,0x200000af,0x09aa0083}},	//   _mě_, _होम_, chii_, _গোলা,
   {{0x44394bb9,0xd90f006c,0x2d870300,0xb5fd4bba}},	//   ils_, گیا_, ónes_, opšt,
   {{0x44391228,0x3ea94bbb,0x614700f7,0x2fc94bbc}},	//   hls_, mtat_, célé, ldag_,
   {{0xd90f0332,0xa3bf0b54,0x44cc00b8,0xa3cd05f8}},	//   دیا_, ीया_, _ně_, रया_,
   {{0x2fc94bbd,0x62864bbe,0x4439003c,0x7a4300fe}},	//   ndag_, ysko, jls_, _bítý,
   {{0x3ea94bbf,0x3c4400d8,0xb4d507df,0x44394bc0}},	//   ntat_, _чэрв, सम्_, dls_,
   {{0x64564bc1,0x44394bc2,0x3ea94bc3,0x44200088}},	//   _siyi, els_, itat_, _sji_,
   {{0x79834bc4,0x6f040382,0xa2d006fe,0x3ea94bc5}},	//   manw, zzic, दिभ्, htat_,
   {{0x628625d2,0x443902d4,0x3ea90523,0x2fc90120}},	//   tsko, gls_, ktat_, jdag_,
   {{0xe5a54bc6,0x3ea900da,0x2fc94787,0xe7960088}},	//   _жили, jtat_, ddag_, _زانک,
   {{0x62864bc7,0x42552bc5,0xd252006c,0x44394bc8}},	//   rsko, етст, ئنس_, als_,
   {{0xa0a318c4,0x62864bc9,0x64564bca,0xcfc50033}},	//   кард, ssko, _tiyi, _একজন,
   {{0x62861269,0x2fc90269,0x2e3401ae,0x6f0401e4}},	//   psko, gdag_, häft_, tzic,
   {{0xb22603e6,0x79831596,0x2a6d3ee5,0x8c130033}},	// [4580] _омил, kanw, _nteb_, িকান_,
   {{0x20000468,0x6f044bcb,0x2bc60240,0xdb08000d}},	//   shii_, rzic, _रोजा, _élév,
   {{0x2a6d001e,0xfce30f88,0xbf9b0345,0x6da32f44}},	//   _ateb_, кофо, _blêd, тиха,
   {{0x1ee80332,0xab5d004e,0x7c65126b,0x3ea901f7}},	//   _فوجی_, _ważn, ءالل, btat_,
   {{0x3ea94bcc,0xaaba006c,0xbd030051,0xbaba2402}},	//   ctat_, تدار_, _éénz, تداء_,
   {{0x5f07012f,0x79834bcd,0xab5d009f,0x27fd099e}},	//   _सेट्_, ganw, _fażo, _alwn_,
   {{0x6d5c1851,0x6da319b3,0xada32682,0x63a400ee}},	//   _igra, _шира, _шарл, _ocin,
   {{0xab2a24f2,0x67fc015e,0x9b930037,0x7a3f00a2}},	//   _доба_, _béja, _للفت, rêta,
   {{0x9f49027d,0x79834bce,0x00000000,0x00000000}},	//   rkaç_, banw, --, --,
   {{0x4439003c,0x67fc4bcf,0x63a40210,0x79834bd0}},	//   wls_, _déja, _acin, canw,
   {{0x0d970bed,0x2fc90173,0x1bf20084,0xdb0b0bf3}},	//   וכים_, ydag_, _अकाल_, regå,
   {{0x69c84bd1,0x44393605,0x63a4009e,0x3ea90bca}},	//   _hade, uls_, _ccin, ytat_,
   {{0x6d5c4bd2,0x65944bd3,0xf7730122,0x44392fb6}},	//   _ogra, _залу, _סקס_, rls_,
   {{0x69c84bd4,0x6d5c00bf,0x69ca4bd5,0x44cc00b8}},	//   _jade, _ngra, ndfe, _tě_,
   {{0x24650029,0x2fc94bd6,0xa158151c,0x4439013a}},	//   _tēma_, tdag_, дару_, pls_,
   {{0x765819c6,0x3ea94bd7,0x69da2487,0x63a40037}},	//   _hivy, ttat_, _lnte, _gcin,
   {{0xda1f065a,0x2fc94bd8,0x69da4bd9,0x63bd4bda}},	// [4590] _बदलत_, rdag_, _onte, mesn,
   {{0x69c84bdb,0x3ea94bdc,0xa3d34bdd,0x629d4bde}},	//   _nade, rtat_, _होत_, muso,
   {{0x3ea94bdf,0x629d4be0,0x69ca00e9,0x798304fb}},	//   stat_, luso, ddfe, vanw,
   {{0x3ea94be1,0x60c5009f,0x63bd010b,0xf41f0086}},	//   ptat_, _ishm, nesn, nnä_,
   {{0x69c84be2,0x8d770d47,0x79834be3,0x656a0044}},	//   _bade, _ياسا, tanw, _offh,
   {{0xa2d0021a,0xe29c0122,0x6d5c40fe,0x76580027}},	//   दित्, קשור, _ggra, _nivy,
   {{0x69c84be4,0x28c20026,0x7983018c,0x5ba7027a}},	//   _dade, _वैदि, ranw, _ораз,
   {{0x63bd4be5,0x69c80e0b,0x6d5c1851,0x629d4be6}},	//   jesn, _eade, _zgra, kuso,
   {{0x7bdb067f,0x69c81f79,0x63bd3262,0x629d02c4}},	//   _inuu, _fade, desn, juso,
   {{0x69c84be7,0x629d4be8,0x6b8000ea,0xa91c0168}},	//   _gade, duso, _zemg, _deľb,
   {{0x7658300e,0x45190421,0x03a64be9,0x63bd4bea}},	//   _divy, яция_, нино, fesn,
   {{0x9f4b051b,0x69c84beb,0x232a0009,0x63bd4bec}},	//   _você_, _zade, зоми_, gesn,
   {{0x7658006d,0x69da00e5,0x629d4bed,0xe7840208}},	//   _fivy, _ynte, guso, _рухо,
   {{0x80cc00a1,0xe5a5027a,0x7c220cc1,0x290700f4}},	//   हिले, _чики, čori, ozna_,
   {{0x6026089e,0x798100d7,0x3e644bee,0x7e7d0024}},	//   едва, _melw, _söt_, _awsp,
   {{0x63a44bef,0x6d5c4bf0,0x63bd03e0,0x776906aa}},	//   _ucin, _sgra, cesn, ncex,
   {{0x2d961558,0x629d1bec,0xa3bf0099,0x69ca016e}},	// [45a0] ерес, cuso, ीयर_, ydfe,
   {{0xee374bf1,0xab5d0035,0x6e930312,0x7bcb0051}},	//   ену_, _inży, اللا, edgu,
   {{0x272101a5,0x6b8000d7,0x6d5c008b,0x29070009}},	//   ỳnh_, _pemg, _vgra, jzna_,
   {{0x69c84bf2,0x7bcf0279,0x7981016e,0x6d5c0067}},	//   _sade, _ócul, _aelw, _wgra,
   {{0x69c84bf3,0x79811232,0x7afd0225,0x7e641505}},	//   _pade, _belw, _üstl, qqip,
   {{0x6d5c4bf4,0x69c801ef,0x63bd297a,0xdcfc00d5}},	//   _ugra, _qade, zesn, _herč,
   {{0x9d431353,0x69c84bf5,0x798100e9,0x69ca4bf6}},	//   _берд, _vade, _delw, rdfe,
   {{0x7658002f,0x3f8200cd,0x7791042c,0xdcfc0107}},	//   _sivy, _jeku_, لیما, _jerč,
   {{0x63bd4bf7,0x69c84bf8,0x3a260eb9,0x601b00c3}},	//   vesn, _tade, _змаг, lämä,
   {{0x69da0446,0x48e64bf9,0x3f824bfa,0x7981016e}},	//   _unte, _позв, _leku_, _gelw,
   {{0x29180006,0x2907006a,0x63bd00d8,0x76581476}},	//   _ära_, czna_, tesn, _vivy,
   {{0x3f820a78,0x629d4bfb,0x388c00b8,0x00000000}},	//   _neku_, tuso, měr_, --,
   {{0x63bd4bfc,0x1dd100b1,0xfbd300a5,0x290d0207}},	//   resn, _सफलत, אתר_, ćkaš_,
   {{0x63bd4bfd,0x65944bfe,0x28c507df,0x00000000}},	//   sesn, _раку, विचि, --,
   {{0x3f821581,0x63bd4bff,0xadc30023,0x1dce00ab}},	//   _beku_, pesn, _ngạc, _होइत,
   {{0x653b00a5,0x629d4c00,0x00000000,0x00000000}},	//   _מעוד, puso, --, --,
   {{0xf4580070,0x6e9400af,0x3f820207,0xdcfc023a}},	// [45b0] _איהר_, литу, _deku_, _derč,
   {{0x644f4c01,0x4df401e0,0x50f51403,0xe1ff0098}},	//   lmci, ляєт, _азот, apór_,
   {{0x2cb80160,0xe29f0093,0xe9df00e2,0x41de0de8}},	//   _cprd_, luð_, _đú_, मारस,
   {{0x2cb801d1,0x00000000,0x00000000,0x00000000}},	//   _dprd_, --, --, --,
   {{0x69dd000c,0x7bcb3ee4,0xe29f008a,0x16bc3010}},	//   पाली, rdgu, nuð_, ्टोब,
   {{0x25be02c4,0xa3d30d4e,0x3f820124,0xbf9b00f6}},	//   jetl_, _होस_, _zeku_, _flêc,
   {{0x9f40008a,0x998300c7,0x3f820118,0x00000000}},	//   lkið_, _ųjų_, _yeku_, --,
   {{0xf1e30035,0x79814c02,0x29074c03,0xe29f008d}},	//   खाड़_, _welw, rzna_, kuð_,
   {{0x6d48004f,0xa3e50a40,0x4a55002d,0x395e0132}},	//   _údar, नान_, _акас, _fgts_,
   {{0x2d834c04,0x388c01c0,0xa2c500b8,0xc1cb01d1}},	//   _jeje_, běr_, िबन्, ायोग,
   {{0x2d834c05,0x53dd1e18,0x26c602d7,0x00000000}},	//   _meje_, यांश, _esoo_, --,
   {{0x2d834c06,0x9f400093,0xe29f0093,0x00000000}},	//   _leje_, kkið_, fuð_, --,
   {{0x3f824c07,0x72c300d8,0x7c3a000d,0x65c500d8}},	//   _reku_, абяз, _être, _абла,
   {{0xb82300c8,0x1a9a0070,0x2d834c08,0x3d1200ab}},	//   _পঠিত_, וישע, _neje_, _धइले_,
   {{0xdcfe00ec,0x3f824c09,0xdcfc4c0a,0x320107c0}},	//   kapā, _peku_, _perč, _dlhy_,
   {{0xa3bf07df,0x601b00c3,0x2b5f4c0b,0x00000000}},	//   ीयः_, vämä, _nguc_, --,
   {{0x2d834c0c,0x3f824c0d,0x1f6300af,0xdcfc4c0e}},	// [45c0] _beje_, _veku_, ркум, _verč,
   {{0x601b0086,0x25f70026,0x2fcb0176,0x00000000}},	//   tämä, एसटी_, _eacg_, --,
   {{0x602601c8,0x2d834c0f,0xd00a4c10,0x48bc0033}},	//   _адна, _deje_, _жене_, _অপ্র,
   {{0xa3e500be,0x67fc000d,0x388c0355,0xa91c07c0}},	//   नाय_, _réjo, věr_, _neľa,
   {{0x67fc02e1,0xe7e50907,0x4422006c,0x59c00380}},	//   _séjo, काना_, ink_, _एसआर,
   {{0xc3330bed,0x67f5006c,0x3ea00160,0x5a3301e0}},	//   בוד_, _máju, muit_, аніт,
   {{0xfce3093c,0x3ea04c11,0xa3e50b47,0x621b0070}},	//   _коро, luit_, नाम_, ווסק,
   {{0x321800d5,0x8c460086,0x1de000ab,0x00000000}},	//   hiry_, _ребе, नावत, --,
   {{0x3ea04c12,0xa3dc0825,0x96340610,0x7c223ed1}},	//   nuit_, ठाई_, лниц, mnor,
   {{0x25a707e5,0x7c2201e0,0x442201bf,0x00000000}},	//   _ccnl_, lnor, enk_, --,
   {{0x2a640031,0x25f700b4,0x9f4b0183,0x1514195c}},	//   _humb_, एसजी_, _vocé_, удня,
   {{0x7c224c13,0xa3d30084,0xd7ef004f,0x26c6006f}},	//   nnor, _होश_, _وكل_, _tsoo_,
   {{0x51874c14,0xa2d00440,0xadf3020d,0x56940812}},	//   кува, दिष्, _आकलन_, _салт,
   {{0x3ea01010,0x7c2202c9,0x569302c4,0xe4d4097f}},	//   duit_, hnor, _ташт, _مقتد,
   {{0x225800c3,0xc05b01e0,0xd7f80395,0x2a642be0}},	//   тиры_, діа_, _luăm_, _lumb_,
   {{0x28d30803,0x23aa00a1,0xe7e50066,0x3ea01d69}},	//   थिति, _कायद, काया_, fuit_,
   {{0x3ea04be4,0x7c220f86,0x66f400b4,0x2d8301e9}},	// [45d0] guit_, dnor, ेनिक_, _peje_,
   {{0x9f400093,0x7c22001e,0x00000000,0x00000000}},	//   rkið_, enor, --, --,
   {{0x2d834c15,0x23aa01c0,0xe7e501c0,0xab5d0069}},	//   _veje_, _कामद, कामा_, _hażi,
   {{0x7c224c16,0x3ea04c17,0x200c0443,0xab5d035f}},	//   gnor, buit_, èdit_, _każi,
   {{0xee840733,0x3ea000af,0x2d8301f4,0x600300ab}},	//   _высо, cuit_, _teje_, _tõmb,
   {{0x27ef082b,0x7c224c18,0x2a644c19,0x00000000}},	//   _sogn_, anor, _dumb_, --,
   {{0x7c224c1a,0x2002012f,0x5faa01c0,0x89d60037}},	//   bnor, _ylki_, ङ्कल, طوير_,
   {{0x6d471851,0x06c90fa7,0xc30a0033,0x683e0055}},	//   _izja, егий_, রপতি_, nëdh,
   {{0x2a6408b7,0x00000000,0x00000000,0x00000000}},	//   _gumb_, --, --, --,
   {{0xab5d0024,0x00000000,0x00000000,0x00000000}},	//   _nażi, --, --, --,
   {{0xe616002d,0xa91c0168,0x00000000,0x00000000}},	//   удэ_, _teľa, --, --,
   {{0xe29a38a6,0x657a4c1b,0x4c9a0317,0x67240097}},	//   нам_, abth, עברו, _žije,
   {{0xab5d035f,0xdb0000ee,0xa8220088,0x00000000}},	//   _bażi, _obmý, _دکون, --,
   {{0xfb1600c2,0x7c221e85,0x471a0070,0x64a54c1c}},	//   אַלט_, znor, _אונג, _бака,
   {{0x2fc04c1d,0x7c224c1e,0x09cd0033,0x1fb60009}},	//   teig_, ynor, লাপা, лсар,
   {{0x3ea04c1f,0xd9c00035,0x854400af,0xe3b20af8}},	//   tuit_, _एस्ट, _тэче, _طرب_,
   {{0xdee34ae8,0x5faa00b8,0xab5d0024,0x2002023a}},	// [45e0] боти, ङ्गल, _fażi, _vlki_,
   {{0x3ea04c20,0xa3e50e96,0xfce600ed,0x116800b5}},	//   ruit_, नाथ_, лозо, _جلدی_,
   {{0x3ea04c21,0x7c220b24,0xb5fa0070,0xab5d035f}},	//   suit_, tnor, עלעכ, _każw,
   {{0x9e66004f,0x63a6310c,0x3ea04c22,0xab8340c5}},	//   _ماسن, ngkn, puit_, бушк,
   {{0x7c224c23,0xa3e50ca1,0x6d4701b7,0x00000000}},	//   rnor, नात_, _ezja, --,
   {{0xe91800d8,0xdd920a42,0x00000000,0x00000000}},	//   колі_, _دوس_, --, --,
   {{0x67f501ba,0x6e2b00b5,0x00000000,0x00000000}},	//   _nájs, égbe, --, --,
   {{0xa3d3004e,0xb21b01b4,0xddcd0207,0x6d580207}},	//   _हों_, lsæt, mpaš, žvas,
   {{0xdce7004b,0x7bc22e65,0x81ea0831,0x00000000}},	//   _bejė, meou, _মতন_, --,
   {{0x88c60037,0xb21b08c8,0x00000000,0x00000000}},	//   _متصل, nsæt, --, --,
   {{0xd5b70f99,0xab5d0069,0xce3700a5,0x00000000}},	//   усы_, _bażw, ראית_, --,
   {{0x7bc200a5,0x4547010b,0x00000000,0x00000000}},	//   neou, ычым_, --, --,
   {{0xa3d60534,0xb21b01b4,0xa3d30d1f,0xddcf0160}},	//   _सफर_, ksæt, _होः_, _nucş,
   {{0x7bc20345,0x798a0051,0x00000000,0x00000000}},	//   heou, nafw, --, --,
   {{0x661a4c24,0xb21b01b4,0x683e0055,0x00000000}},	//   mitk, dsæt, tëdh, --,
   {{0xd90400f5,0xa2c506d9,0xddcf0160,0x7e660282}},	//   _ہی_, िबद्, _bucş, _bukp,
   {{0xdd9b150d,0x1de002e4,0x7bc24c25,0x44294c26}},	// [45f0] еше_, नांत, deou, _ija_,
   {{0x273300e8,0x27210028,0x44294c27,0xd90404e8}},	//   ợng_, ẳng_, _hja_, _فی_,
   {{0x27200299,0x644d4c28,0x628f004f,0x645f0248}},	//   मपुर_, _khai, lsco, _épis,
   {{0x907a0319,0x44294c29,0x7bc20147,0x00000000}},	//   _שטרי, _jja_, geou, --,
   {{0x644d006e,0x661a0ec0,0x628f4c2a,0x44294c2b}},	//   _mhai, kitk, nsco, _mja_,
   {{0x3d1902cb,0x661a012f,0x628f027a,0xe9d800d8}},	//   _येथे_, jitk, isco, лкі_,
   {{0xa3d600c0,0x661a4c2c,0x44294c2d,0x6d472b26}},	//   _सफल_, ditk, _oja_, _uzja,
   {{0x7bc24c2e,0x44294c2f,0x660301ba,0xe739137c}},	//   ceou, _nja_, _slnk, кей_,
   {{0x0ab80357,0x6f0d4c30,0x628f004e,0x6b8b4c31}},	//   _مطلب_, nzac, jsco, magg,
   {{0x44291693,0xa2d906bc,0x7c292b6f,0x628f2407}},	//   _aja_, मिन्, _hjer, dsco,
   {{0x644d0f46,0xe005111b,0x628f4c32,0x629d32c5}},	//   _bhai, रसाद_, esco, erso,
   {{0x69c32ac8,0x6b8b4c33,0x644d4c34,0xdcfc0160}},	//   lene, nagg, _chai, _heră,
   {{0x7c294c35,0x644d1b7e,0xf7700372,0x7c3b000e}},	//   _mjer, _dhai, _ران_, _mkur,
   {{0x412a10a9,0x69c34c36,0x44294c37,0x7c290506}},	//   вого_, nene, _eja_, _ljer,
   {{0x644d09e3,0x645f4c38,0x629d009e,0x78a30095}},	//   _fhai, _fiqi, arso, nunv,
   {{0x7c294c39,0x69c34c3a,0x27ed4c3b,0x644d1093}},	//   _njer, hene, njen_, _ghai,
   {{0xee3a1878,0x69c34c3c,0xfbbb0355,0x2bbb0f0d}},	// [4600] вна_, kene, ोजनम, ोजना,
   {{0xdbdf05ee,0x7c3b4c3d,0x69c34c3e,0x27ed01f4}},	//   _síðs, _akur, jene, hjen_,
   {{0x7c294c3f,0x27ed4c40,0x27ff0093,0xb21b4263}},	//   _bjer, kjen_, kkun_, rsæt,
   {{0x6b8b01a8,0x20094c41,0x661a4c42,0x27ff023a}},	//   gagg, chai_, zitk, jkun_,
   {{0x69c34c43,0x27ed4c44,0x7c29300d,0xead40fa4}},	//   fene, djen_, _djer, соль,
   {{0x7c294c45,0x200002ee,0xa3d30006,0xd90d0647}},	//   _ejer, lkii_, _होई_, کیم_,
   {{0xf80611ca,0xa3c80bc1,0x082a3804,0x7c291123}},	//   ичин, ैया_, кции_, _fjer,
   {{0x200002ee,0x7c294c46,0x27ed4c47,0xd6da4c48}},	//   nkii_, _gjer, gjen_, вто_,
   {{0x644d02c7,0x69c34c49,0xdcfc0139,0x4429023a}},	//   _rhai, bene, _feră, _rja_,
   {{0x644d4c4a,0xceb30122,0xe83901c0,0x67fc02d7}},	//   _shai, קית_, ější, _méji,
   {{0x2dd90779,0x644d4c4b,0x25e81649,0x661a4c4c}},	//   אַרב, _phai, जाबी_, ritk,
   {{0x644d01e8,0x628f2407,0x20094c4d,0xb4c6000c}},	//   _qhai, tsco, xhai_, _उनी_,
   {{0x661a4c4e,0x628f0382,0x629d4c4f,0x2fd200e9}},	//   pitk, usco, urso, ddyg_,
   {{0x3633183b,0xa3e50084,0x79884c50,0x20c200b4}},	//   _وروس, नाह_, _jedw, शबंध,
   {{0x644d4c51,0x04940514,0x463902b5,0x7988099e}},	//   _thai, _البح, _געװע, _medw,
   {{0xa3bb028c,0x6f0d162d,0x1473006c,0x69c34c52}},	//   _شاعر_, tzac, _باوج, zene,
   {{0x63ad4c53,0x60d301c8,0x69c34c54,0x6b8b4c55}},	// [4610] _ican, _žemė, yene, vagg,
   {{0x443904a5,0xa3e50953,0x20090189,0x69c34c56}},	//   los_, नाव_, shai_, xene,
   {{0x6b8b4c57,0xd010006c,0x41b600f8,0x27ed4c58}},	//   tagg, سلے_, _امپر, yjen_,
   {{0x44394c59,0xe29f008e,0x69c31f97,0x201b00a8}},	//   nos_, orð_, wene, qiqi_,
   {{0x7c290280,0x6b8b4c5a,0x44394c5b,0x63ad0453}},	//   _vjer, ragg, ios_, _mcan,
   {{0x44394c5c,0x6b8b4927,0x89a802ce,0xf9910c74}},	//   hos_, sagg, иків_, سبت_,
   {{0x44394c5d,0x69c34c5e,0x7c29071f,0x27ed01d2}},	//   kos_, rene, _tjer, tjen_,
   {{0x44394c5f,0x7c3b0895,0x7c290054,0x6ebb000c}},	//   jos_, _ukur, _ujer, _उहाँ,
   {{0x44390aca,0x27ed1e07,0x69c34c60,0x26d936b0}},	//   dos_, rjen_, pene, íso_,
   {{0x27ed03b4,0x443907a6,0x27ff4c61,0x79884c62}},	//   sjen_, eos_, skun_, _gedw,
   {{0x44394c63,0x6b89007c,0x27ed38f5,0xddc6010b}},	//   fos_, _keeg, pjen_, _sukū,
   {{0x27ed01f4,0x6b894c64,0x63ad0098,0x00000000}},	//   qjen_, _jeeg, _ccan, --,
   {{0x6b894c65,0x1dc700c0,0x63ad009e,0x7c3a008d}},	//   _meeg, रजात, _dcan, _ítre,
   {{0x6b894c66,0x63ad0118,0xf676016b,0x3dd10067}},	//   _leeg, _ecan, _הײסט_, _nazw_,
   {{0x44391290,0xa3e51365,0x20000421,0x00000000}},	//   bos_, नाश_, tkii_, --,
   {{0x44391423,0x6b894c67,0x6e3c02c6,0xb4fa0122}},	//   cos_, _neeg, _skrb, _תפקי,
   {{0x20000421,0xa3e5073f,0x7c390090,0xdee30dfc}},	// [4620] rkii_, नार_, dowr, поти,
   {{0xbd8a00d1,0x2000081b,0xe05800d1,0xa2c506fe}},	//   انان_, skii_, _چیست_, िबर्,
   {{0xf8a51c17,0x6b89018e,0xe05800bf,0x59ae0099}},	//   _تک_, _beeg, _نیست_, _घाबर,
   {{0x44d70043,0xab83002d,0x7988021e,0x7c390345}},	//   _mă_, пушк, _sedw, gowr,
   {{0x6b8903bc,0xa91c0038,0x798800e9,0xa4c20260}},	//   _deeg, _veľm, _pedw, _jãƒâ_,
   {{0x44394c68,0xa2d91bb5,0xfce63f74,0x3ea04c69}},	//   zos_, मित्, _лого, mrit_,
   {{0x443911e9,0xdca34a2f,0x6b89011e,0x7d2400b5}},	//   yos_, _нари, _feeg, _بہان,
   {{0x44392b5c,0xc7c62698,0xe6982701,0x6b8905a0}},	//   xos_, сски, авиш_, _geeg,
   {{0xa3ac0084,0xf76f16e6,0x6edb0569,0x2d8a0118}},	//   खलन_, راي_, नियु, _kebe_,
   {{0x2d8a28da,0x63ad11be,0x44390371,0x44d70139}},	//   _jebe_, _scan, wos_, _bă_,
   {{0x44391c1d,0x44d709eb,0xd7ef4c6a,0xa3e50067}},	//   tos_, _că_, _еу_, नाल_,
   {{0x44d7002d,0x25dd0437,0xccf300a5,0xceb400a8}},	//   _dă_, _कोठी_, לכת_, ktə_,
   {{0xb3aa05f7,0xa2d01edf,0x659400d8,0x41e712ea}},	//   _कारख, दिग्, _далу, біва,
   {{0x2d9c03e6,0x555800d8,0xdb0f00f7,0x3ea04c6b}},	//   óvel_, _каля_, édér, drit_,
   {{0x3ea04c6c,0xa1594c6d,0x61fa013c,0x6025010b}},	//   erit_, раву_, ötla, lėmi,
   {{0xf1ad0355,0xceb40095,0x3ea04c6e,0x403500d8}},	//   ञ्जन, ftə_, frit_, цебс,
   {{0x6b89007c,0x602500d8,0xf41f00c3,0xbe1901e0}},	// [4630] _reeg, nėmi, miä_, ажає_,
   {{0x6b89007c,0xf41f00c3,0xafdb08c8,0x00000000}},	//   _seeg, liä_, _skød, --,
   {{0x2d8a09ab,0x8d740934,0x3ea001f4,0x61e50345}},	//   _debe_, سالا, arit_, _inhl,
   {{0x3ea04c6f,0xf41f0086,0xab9401e0,0x9f590a8c}},	//   brit_, niä_, зиці, _alså_,
   {{0x3ea04c70,0xdefb021f,0x7867006c,0x6b8920c8}},	//   crit_, _сын_, _műve, _veeg,
   {{0x600a016f,0x6b894c71,0x2d8a064c,0xf41f0421}},	//   _výme, _weeg, _gebe_, hiä_,
   {{0xe7e50ac4,0xf41f0086,0x9f420107,0x3f8b0118}},	//   काला_, kiä_, _ankè_, _kecu_,
   {{0xdd0e06d3,0x2d810014,0x2d8a0a66,0xf41f00c3}},	//   lışa, lbhe_, _zebe_, jiä_,
   {{0x44d709eb,0x600300ab,0x3f8b0207,0x27f60079}},	//   _să_, _nõmm, _mecu_, تفيد_,
   {{0xe6190854,0x0693006c,0xdd0e0644,0x44d70139}},	//   рдо_, _ہاتھ, nışa, _pă_,
   {{0xa3e5035d,0x25dd00a1,0xd7c800d1,0xb4e30b4d}},	//   नां_, _कोणी_, _گونه_, नमे_,
   {{0x3f8b0c21,0x44d70012,0xf41f02ee,0x61e500cc}},	//   _necu_, _vă_, giä_, _anhl,
   {{0x61f70051,0x42ba010b,0x00000000,0x00000000}},	//   _boxl, шыню_, --, --,
   {{0xc8ad0174,0xa3da0722,0x3ea04c72,0x44d70160}},	//   _टमाट, _डोर_, vrit_, _tă_,
   {{0x3f8b0207,0x00000000,0x00000000,0x00000000}},	//   _becu_, --, --, --,
   {{0x1dac006a,0xa3e5021a,0x3ea04c73,0x3f8b0124}},	//   _चाहत, नाः_, trit_, _cecu_,
   {{0x3f8b0274,0xd0070be8,0x61f7009e,0x1756016b}},	// [4640] _decu_, цете_, _foxl, ַסער_,
   {{0x3ea04c74,0x64464c75,0x62960371,0x3fc600b5}},	//   rrit_, llki, _ivyo, _ڈگری_,
   {{0xa91c0038,0xdcfc0009,0x24650029,0x64460298}},	//   _veľk, _merć, _tēmu_, olki,
   {{0x3ea04c76,0xdee60beb,0x2d8a01ba,0x26dd030d}},	//   prit_, _доми, _webe_, _orwo_,
   {{0x2d8a28da,0x61f700a8,0xf41300a5,0xb4c60067}},	//   _tebe_, _yoxl, ופא_, _उन्_,
   {{0xdd9204e8,0xddd500ea,0x2d980207,0x20230067}},	//   _زور_, _aizņ, _udre_, ąpił_,
   {{0x9d43081b,0xf1b20035,0x26cf0051,0x8b960ddc}},	//   _жерд, _जानन, _asgo_, _мрач,
   {{0x6d4e4c77,0x3b861283,0x602500c7,0x6296034d}},	//   _izba, _флаг, tėmi, _ovyo,
   {{0xc6f715eb,0xf41f0086,0x6b823a34,0xc05300a5}},	//   жных_, viä_, mbog, וזה_,
   {{0x64460069,0xa2d90127,0xc5fa0279,0x26dd099e}},	//   elki, मिस्, рѓи_, _drwo_,
   {{0x629602d0,0xf41f00c3,0x647412ea,0xc8ca08cf}},	//   _avyo, tiä_, ягну, _خوان_,
   {{0x9f49008a,0x6b824c78,0x387101cb,0x00000000}},	//   kkað_, nbog, _ézra_, --,
   {{0x9347004f,0xc34b01d3,0xf41f00c3,0x27e64c79}},	//   تخدم, ряне_, riä_, _inon_,
   {{0xf41f03ad,0x7205004f,0x64460553,0x3f8b4c7a}},	//   siä_, أوسم, alki, _secu_,
   {{0x386c0187,0xd01b4c7b,0x6aa24c7c,0xf41f00c3}},	//   _judr_, афа_, hrof, piä_,
   {{0x386c024e,0x7a3f0248,0x6b824c7d,0x600300ab}},	//   _mudr_, nêtr, jbog, _tõmm,
   {{0x85561c0c,0x656d04d4,0xfe704c7e,0x3f8b4c7f}},	// [4650] _دیگر_, _şahi, ندل_, _vecu_,
   {{0x41b20084,0x00000000,0x00000000,0x00000000}},	//   _जायस, --, --, --,
   {{0x2d8126c9,0x27e6289e,0xdd0e10b1,0xd7bc0099}},	//   rbhe_, _onon_, rışa, ्जाच,
   {{0x6b821f8b,0x44cc0067,0x64580310,0xf8e40066}},	//   gbog, _mś_, _èxit, _कपड़ा_,
   {{0x7f760319,0x442b4c80,0x0dcb002d,0x6d4e2cc2}},	//   _מערב_, inc_, _куви_, _ezba,
   {{0x3ea90257,0x6d580187,0x24520187,0x28b90037}},	//   muat_, ývac, máme_, مطبخ_,
   {{0x200b00d7,0x64460093,0x3ea91bb1,0x47d40033}},	//   _klci_, ylki, luat_, থানী,
   {{0x95f502e4,0x6aa2016e,0x97c5063d,0xf81302fd}},	//   ेस्ट_, brof, ستعم, بستگ,
   {{0xb4e3021a,0xe6194c81,0x6b9b043d,0x3ea94c82}},	//   नम्_, йди_, _idug, nuat_,
   {{0x27e605eb,0x442b0392,0x973202fd,0x386c0090}},	//   _enon_, enc_, رکنا, _fudr_,
   {{0x04460eb9,0xe5760012,0x24521dab,0x00000000}},	//   зенн, язэ_, háme_, --,
   {{0x3897002d,0x24520187,0x7a3f000d,0x7c2b03c1}},	//   măr_, káme_, cêtr, nngr,
   {{0xe72e4c83,0x66e50011,0x26dd0010,0x7c2b4c84}},	//   _че_, _хола, _urwo_, ingr,
   {{0xbb3a02b5,0x2452024e,0xdcee00c7,0x3ea901f7}},	//   מערי, dáme_, _gebė, duat_,
   {{0x25e805f8,0xa7fc0225,0x753c02b1,0x00000000}},	//   जारी_, _atıy, ürzt, --,
   {{0x6b9b4c85,0x6aa24c86,0x3ea908c7,0xa2d905f8}},	//   _ndug, yrof, fuat_, मिश्,
   {{0xe7ec00ab,0xdfcf4c87,0x3ea94a52,0x00000000}},	// [4660] झाता_, ديق_, guat_, --,
   {{0xa3b802e4,0x273a01a5,0x9f490093,0x7c2b0afc}},	//   घ्र_, ừng_, rkað_, engr,
   {{0x50460f28,0x9f49003e,0x61460009,0x2fc901da}},	//   _необ, skað_, _хена, beag_,
   {{0x3ea90f1a,0x6aa24c88,0x25dd111b,0x46bd175f}},	//   buat_, trof, _कोसी_, ्बाह,
   {{0x3f922247,0x6b9b099e,0x00000000,0x00000000}},	//   mayu_, _ddug, --, --,
   {{0xec160118,0x3f922a37,0x44224c89,0xceb302b8}},	//   _کورد, layu_, hik_, _איש_,
   {{0x5886010b,0xa3cc020d,0xa3ac193c,0xa3be0c3e}},	//   чыла, रजा_, खला_, ीजा_,
   {{0x44224c8a,0x4c9b00a5,0x6e3e0296,0x00000000}},	//   jik_, _לבלו, lopb, --,
   {{0x44224c8b,0xfaa34c8c,0x442b01a2,0x2cbf00f4}},	//   dik_, _пато, vnc_, _ćudi_,
   {{0x3f9240f4,0x449800d4,0x2a651d22,0x05ea00af}},	//   hayu_, овою_, _gilb_, сфии_,
   {{0x44224c8d,0x69ca4c8e,0x00000000,0x00000000}},	//   fik_, mefe, --, --,
   {{0x44224c8f,0x27e6011e,0xa2d926d4,0xe3bf01ed}},	//   gik_, _unon_, मिल्, kiñe_,
   {{0x3f920703,0xa3be0067,0x39450345,0x00000000}},	//   dayu_, ीज़_, _zyls_, --,
   {{0x69d814c2,0x245201c0,0x7c221315,0x9f590a8a}},	//   ndve, váme_, hior, _ilsø_,
   {{0x7c2b001e,0x7c224c90,0x55bb024b,0x69d84c91}},	//   yngr, kior, _המוו, idve,
   {{0x44224c92,0x3ea94c93,0x69ca22ac,0x987b0070}},	//   cik_, tuat_, hefe, מאלט,
   {{0xdb1b008a,0x2fc9006b,0x69ca4c94,0xa85732e3}},	// [4670] _nauð, reag_, kefe, לילה_,
   {{0x24520187,0x2bf90083,0xdb0700f7,0x2dd4002d}},	//   ráme_, _আগেই_, _élég, нжур,
   {{0x69ca4c95,0x7c224c96,0x2a6d012f,0x624045f8}},	//   defe, fior, _sueb_, möop,
   {{0x7c2201d3,0x389700af,0x69d80fdb,0x00000000}},	//   gior, văr_, edve, --,
   {{0x3ea90310,0xf42a00c3,0x69d80223,0x00000000}},	//   quat_, ltää_, fdve, --,
   {{0x44224c97,0xdb1b0093,0x39454c98,0x69ca4c99}},	//   zik_, _dauð, _pyls_, gefe,
   {{0x44224c9a,0xf99017bd,0x7c22004e,0x2d9301dd}},	//   yik_, ابه_, bior, maxe_,
   {{0x7c224c9b,0x44224c9c,0x2d93447e,0x7ae0027d}},	//   cior, xik_, laxe_, _frmt,
   {{0x671d0066,0x38664c9d,0x7bcb2d08,0x69ca4c9e}},	//   _बेशक_, _dior_, megu, befe,
   {{0x7bcb4c9f,0x2d93043f,0x49bb01ca,0x44224ca0}},	//   legu, naxe_, _دارد_, wik_,
   {{0x69c14ca1,0x386600f1,0x03a64ca2,0x7e7d0176}},	//   _ible, _fior_, мино, _ltsp,
   {{0x7bcb4ca3,0xc20900a5,0x38660036,0x6d4700a0}},	//   negu, _דה_, _gior_, _myja,
   {{0x44224ca4,0x24800a78,0x15f50037,0x656d0160}},	//   rik_, _čime_, _يستح, _şahu,
   {{0x44224ca5,0xd9f01e79,0xa06a0948,0x7c224ca6}},	//   sik_, चायत_, жава_, zior,
   {{0x61434ca7,0x69c124cf,0x7e7d2791,0x21670279}},	//   вера, _mble, _atsp, дири_,
   {{0xdee62afc,0x7bcb4ca8,0xdb090310,0xd4360037}},	//   моби, jegu, _oceà, _تعتب,
   {{0x44204ca9,0x69c14caa,0x7bcb4cab,0x3f922b63}},	// [4680] _imi_, _oble, degu, rayu_,
   {{0x44204cac,0x69bf09b4,0x3f92012f,0xdb1b0093}},	//   _hmi_, ल्मी, sayu_, _rauð,
   {{0x44204cad,0xdd8f16e6,0x69ca0a8c,0xdb1b0093}},	//   _kmi_, شون_, vefe, _sauð,
   {{0xf76702aa,0x69c1119b,0x7bcb0fde,0x7e670051}},	//   _لا_, _able, gegu, _eijp,
   {{0x44200f9f,0x69ca4cae,0x6d470093,0xbd8a0037}},	//   _mmi_, tefe, _eyja, _ونحن_,
   {{0x7c224caf,0x2d930138,0xe6070919,0x38660284}},	//   sior, caxe_, _شش_, _sior_,
   {{0x69ca4cb0,0x69d84cb1,0x386603e6,0x64440103}},	//   refe, rdve, _pior_, _okii,
   {{0x69c10053,0xc6f81f7e,0x23aa0099,0x998700c7}},	//   _eble, зних_, _कागद, fonų_,
   {{0x8b2601c8,0x9f590036,0x7c200211,0x69ca081b}},	//   _ўдзе, _cosè_, _immr, pefe,
   {{0x44204cb2,0xf1c00084,0x6444343c,0x44f40340}},	//   _ami_, श्मन, _akii, епос,
   {{0xf4be00c8,0x3dd800e9,0x76430a8a,0x00000000}},	//   েম্ব, _marw_, _dkny, --,
   {{0x2d9301dd,0x44204cb3,0x69c1023a,0x00000000}},	//   zaxe_, _cmi_, _zble, --,
   {{0x27f7024e,0x44204cb4,0x63b40187,0x236d008b}},	//   žená_, _dmi_, _žená, žejo_,
   {{0xf42a03ad,0x34944cb5,0x44204cb6,0x6444001c}},	//   ttää_, _закр, _emi_, _ekii,
   {{0x44204cb7,0x40352788,0x7e6702a2,0x7bcb10a2}},	//   _fmi_, еевс, _rijp, yegu,
   {{0xf42a00c3,0x44de003c,0x7e6f021d,0x7bcb0485}},	//   rtää_, _iċ_, _pucp, xegu,
   {{0x7bcb4cb8,0xdb094cb9,0x2d933762,0xf42a0086}},	// [4690] vegu, _oceá, taxe_, stää_,
   {{0x9f590aca,0x7bcb4cba,0x6d474cbb,0xdd914cbc}},	//   _josé_, wegu, _pyja, اوا_,
   {{0x7bcb4cbd,0x2d931fdc,0x99730355,0x999e00fe}},	//   tegu, raxe_, těži_, _aktů_,
   {{0x4ea74cbe,0x2d930391,0x6d474cbf,0x3dcf0033}},	//   _орга, saxe_, _vyja, রাইল,
   {{0x6f16004e,0x6d47004e,0x26c60221,0x823400bf}},	//   czyc, _wyja, _npoo_, _سریا,
   {{0x7bcb4cc0,0x9f590176,0xa5b70160,0x628d023c}},	//   segu, _nosé_, _amγn, _mwao,
   {{0x7bcb0176,0x00000000,0x00000000,0x00000000}},	//   pegu, --, --, --,
   {{0x200901c8,0x23c1021a,0x6e25046a,0xc607012f}},	//   nkai_, ष्मद, lihb, षस्य_,
   {{0x5a354cc1,0x9f590138,0x442000f6,0x00000000}},	//   _знат, _bosé_, _rmi_, --,
   {{0xe61600c3,0x645601d5,0x78ae0079,0x69c10207}},	//   едь_, _shyi, óivé, _uble,
   {{0x656d1d1b,0x2d914cc2,0x628d08c7,0xdddd0228}},	//   _şahs, _meze_, _awao, _atsū,
   {{0xafdb054e,0x2d914cc3,0x44200be2,0x600a00d5}},	//   _skøn, _leze_, _qmi_, _rýmo,
   {{0xe2974cc4,0xb3b10534,0xddc64cc5,0x44204cc6}},	//   ная_, _झारख, _lukš, _vmi_,
   {{0xd25209b9,0x2fd9099e,0x20cb052f,0x00000000}},	//   انس_, _aasg_, ाबंध, --,
   {{0x76414cc7,0x442002ee,0x2fd900e5,0x00000000}},	//   moly, _tmi_, _basg_, --,
   {{0x44204cc8,0xdb1b01ef,0x2fd90284,0x764101ff}},	//   _umi_, _abuí, _casg_, loly,
   {{0xddc601c8,0x2a7f0221,0xbea32634,0xdcf4011c}},	// [46a0] _aukš, _ntub_, латк, đačk,
   {{0x8c960044,0x6e461d05,0x9f590391,0x76414cc9}},	//   ерді, رنام, _xosé_, noly,
   {{0x2d914cca,0x6f16004e,0xb0af0084,0x2a7f011e}},	//   _deze_, szyc, जूदग, _atub_,
   {{0xe7df045c,0xe7ae111e,0x61fe4ccb,0x207b0070}},	//   _खोला_, _टाइप, _hopl, _מאטא,
   {{0xd12f01ca,0x764101ff,0xe3bf002a,0x00000000}},	//   _نمی_, koly, niña_, --,
   {{0x387e0160,0x00000000,0x00000000,0x00000000}},	//   _pttr_, --, --, --,
   {{0x0aea0088,0x76414ccc,0x9f590e8c,0xe7ec00ab}},	//   _کرزي_, doly, _rosé_, झाला_,
   {{0xd6d00037,0x2d914ccd,0x09cd0033,0x7d120225}},	//   لقب_, _zeze_, লাগা, ıksı,
   {{0x27fd2fb6,0x87e30086,0x7641006c,0x9f591f96}},	//   _down_, ующе, foly, _posé_,
   {{0xb9060083,0x76414cce,0xe3bf0485,0x61fe0228}},	//   _পথ_, goly, diña_, _nopl,
   {{0x3e76008d,0x54550be8,0xd82f081b,0x69da0952}},	//   _læt_, квот, _бэ_, _iate,
   {{0x38ba00da,0x8937011d,0x69da4ccf,0xa3eb00b4}},	//   mër_, _ארבע_, _hate, टाइप_,
   {{0x61fe2921,0x8c1b011d,0x645d4cd0,0xe3bf0065}},	//   _bopl, לוטי, rmsi, giña_,
   {{0x61fe153c,0x69da4cd1,0x24524cd2,0x00000000}},	//   _copl, _jate, ráma_, --,
   {{0x61fe05d3,0xc0c84cd3,0x2fc04cd4,0x2fd9016e}},	//   _dopl, нуте_, ffig_, _pasg_,
   {{0x50f40aeb,0x69da4cd5,0x2009010b,0x657a0079}},	//   ызст, _late, ukai_, lcth,
   {{0xfe73146d,0xe3bf0391,0x40340086,0x2d9102d0}},	// [46b0] ادر_, ciña_, уетс, _peze_,
   {{0xe45f022a,0x20094cd6,0x2fd9001e,0xddc6023a}},	//   lmö_, skai_, _wasg_, _pukš,
   {{0x2d9102cc,0x2a7f4cd7,0x463b02b5,0xa2d90f8a}},	//   _veze_, _stub_, לעמע, मिक्,
   {{0x38ba01f4,0x2d210099,0xddc600f4,0x249c0b3e}},	//   dër_, _मधील_, _vukš, _mvvm_,
   {{0x69da4cd8,0x3f8931b4,0x2d91273a,0x38ba053e}},	//   _bate, mbau_, _teze_, eër_,
   {{0x3ea94cd9,0xddc600ea,0x38ba0055,0x3f894cda}},	//   mrat_, _tukš, fër_, lbau_,
   {{0x6b750674,0x69da4cdb,0x00000000,0x00000000}},	//   _албу, _date, --, --,
   {{0x3f8901ae,0x3ea94cdc,0x6d5549db,0xf0941804}},	//   nbau_, orat_, _izza, אנק_,
   {{0x69da3f53,0x41b2045c,0xe3bf01ef,0x3ea94cdd}},	//   _fate, _जालस, xiña_, nrat_,
   {{0xfbd0006c,0x38ba01f4,0x69da4cde,0x3ea94cdf}},	//   _پتہ_, bër_, _gate, irat_,
   {{0x7bdb010d,0x61fe0409,0x38ba0031,0xa802027b}},	//   _kauu, _ropl, cër_, ğırm,
   {{0x3ea9108a,0xe29a4ce0,0x61fe4ce1,0x232a0949}},	//   krat_, мам_, _sopl, доми_,
   {{0x61fe4ce2,0x69da2d06,0x290723bd,0x7bdb067f}},	//   _popl, _yate, lyna_, _mauu,
   {{0xe3bf0391,0x6d554ce3,0xa1160118,0x69da04c7}},	//   riña_, _ozza, پورت, _xate,
   {{0x3ea94ce4,0x3e764ce5,0x27f4006c,0x3f8901ae}},	//   erat_, _sæt_, _شہید_, fbau_,
   {{0xa3b90299,0x3ea94ce6,0xe3bf20d9,0x7bdb0dc3}},	//   _चाय_, frat_, piña_, _nauu,
   {{0x61fe4ce7,0x3ea94ce8,0x6d554ce9,0x38ba0031}},	// [46c0] _topl, grat_, _azza, zër_,
   {{0xee371f7e,0x600a00d5,0x9f5900b5,0x98ac0409}},	//   вну_, _kýmk, _alsó_, _gydė_,
   {{0x3ea94cea,0x69da4ceb,0xa3d60099,0x7bdb02b1}},	//   arat_, _rate, _हसा_, _bauu,
   {{0xdca33466,0x3ea94cec,0x3e76054e,0x69da426b}},	//   раци, brat_, _tæt_, _sate,
   {{0x69da4ced,0x3ea94cee,0xbea314d0,0x6d55018e}},	//   _pate, crat_, _каяк, _ezza,
   {{0x38ba01d2,0x19580f99,0x1dac021a,0x69da0024}},	//   tër_, налы_, _चाटत, _qate,
   {{0xc2130052,0x29074cef,0x69da4cf0,0xed3500af}},	//   שהו_, gyna_, _vate, _бэтэ,
   {{0x69da3d29,0xf0930122,0xc7c6189d,0x7d03013c}},	//   _wate, בנה_, тски, änse,
   {{0x69da4cf1,0xbb4619b6,0x38ba0031,0xa37b021d}},	//   _tate, _реак, sër_, ndõe,
   {{0x38ba01d2,0x7bc24cf2,0x35f42e2d,0x98a50409}},	//   për_, lfou, упор, _gylį_,
   {{0x26181bc6,0x43954cf3,0x7ae24cf4,0xa8a516a4}},	//   योगी_, ланс, lvot, _مصنو,
   {{0xd9f00302,0x657a0037,0x9723006c,0x3c3c00a0}},	//   चावत_, scth, افیو, tívy_,
   {{0x9f590133,0x6d580187,0x00000000,0x00000000}},	//   _così_, ývaj, --, --,
   {{0x3ea91075,0x6594178e,0x00000000,0x00000000}},	//   vrat_, _саку, --, --,
   {{0x62860298,0x3f894cf5,0x7bc20d35,0x00000000}},	//   apko, tbau_, kfou, --,
   {{0x3ea937f3,0xe3bf0391,0xdcfc0009,0x7ae24cf6}},	//   trat_, miño_, _nerđ, kvot,
   {{0x9f554cf7,0x7ae20c99,0x3ea94cf8,0xe3bf0042}},	// [46d0] увач, jvot, urat_, liño_,
   {{0x3ea94cf9,0x644f4a52,0x3f894843,0x629d4cfa}},	//   rrat_, llci, sbau_, msso,
   {{0x629d4cfb,0x3ea94cfc,0x7bdb010d,0xe3bf0042}},	//   lsso, srat_, _pauu, niño_,
   {{0xe7c20026,0x3ea94cfd,0x60110282,0x2d9c01ef}},	//   _वॉलप, prat_, _fåma, óver_,
   {{0x629d4cfe,0x41c00567,0x2a6c009e,0x7e550919}},	//   nsso, श्वस, _bidb_, _منحص,
   {{0xf2d40070,0x629d4cff,0x29070067,0x201e00ea}},	//   שעס_, isso, tyna_, ītie_,
   {{0x9f40008d,0x00000000,0x00000000,0x00000000}},	//   ljið_, --, --, --,
   {{0x31580122,0x629d4d00,0x29074d01,0xe3bf4d02}},	//   כיון_, ksso, ryna_, diño_,
   {{0x29074d03,0xf99307f6,0x00000000,0x00000000}},	//   syna_, _نبض_, --, --,
   {{0x32010187,0x6b990159,0x629d4d04,0x1dc6018d}},	//   _nohy_, lawg, dsso, र्पत,
   {{0x25e800ab,0xdb004066,0x629d026a,0x00000000}},	//   जाजी_, _admè, esso, --,
   {{0x629d0cba,0xb21b008e,0xdd41018e,0x225a0055}},	//   fsso, spæl, _aŋŋa, _shpk_,
   {{0xd90f0332,0x2bc502cb,0x46a52947,0x320106fe}},	//   _دیں_, ळ्या, _салв, _bohy_,
   {{0x9f5901f7,0x644f00f4,0xab5d0069,0xe3bf4d05}},	//   _cosí_, alci, _lbżo, biño_,
   {{0xf6520052,0x8fa601c8,0xe3bf01dd,0x629d0523}},	//   _הצג_, лаве, ciño_, asso,
   {{0x629d4d06,0x628606c7,0xdd41018e,0x00000000}},	//   bsso, ppko, _eŋŋa, --,
   {{0x823600bf,0x63a44d07,0x64464d08,0x543b0070}},	// [46e0] _مردا, _idin, moki, _רעפא,
   {{0x64464d09,0xdcfc0009,0xa37b0183,0x00000000}},	//   loki, _serđ, rdõe, --,
   {{0x7bc20118,0xeafa0220,0x6446005f,0x7ae202d7}},	//   tfou, کرات_, ooki, wvot,
   {{0x6446323d,0x0ecf0084,0xdb19004e,0x09bd0033}},	//   noki, _सैकड, jewó, _আফগা,
   {{0x69c34d0a,0x7bc24d0b,0x20020118,0x63a43af3}},	//   ffne, rfou, _ioki_, _mdin,
   {{0x64464d0c,0x69bf1bb5,0x82d70070,0x7ae24d0d}},	//   hoki, ल्ली, טונג_, rvot,
   {{0xed574d0e,0xa3e408b0,0x64464d0f,0x20024d10}},	//   _бор_, नया_, koki, _koki_,
   {{0x8c464d11,0x63a44d12,0x62840103,0x200200ea}},	//   _себе, _ndin, _otio, _joki_,
   {{0x64464d13,0x6d4e00d5,0x2002004b,0x00000000}},	//   doki, _hyba, _moki_, --,
   {{0x63a44d14,0x2d9a0107,0xe3bf4d15,0x629d4d16}},	//   _adin, nape_, tiño_, vsso,
   {{0x1dc60e61,0x32010184,0x69c8009f,0x6ad40b35}},	//   र्यत, _rohy_, _ibde, _धनुर,
   {{0x644606a2,0x2d9a0107,0xe3bf0b4c,0x629d4d17}},	//   goki, hape_, riño_, tsso,
   {{0x63a4001e,0x2d9a4d18,0x69c8011e,0xe60f00d1}},	//   _ddin, kape_, _kbde, زشی_,
   {{0x629d4cfe,0xd57600c3,0x62840037,0x63a44d19}},	//   rsso, _судь, _dtio, _edin,
   {{0x25dd00a1,0x6ea7046c,0x6d4e04c1,0x00000000}},	//   _कोटी_, _चिहु, _nyba, --,
   {{0x629d45c4,0xb34400a8,0x63a400f4,0x00000000}},	//   psso, zaçə, _gdin, --,
   {{0x442b4d1a,0x69c8008b,0x20024d1b,0xddab1099}},	// [46f0] mic_, _obde, _doki_, етел_,
   {{0x442b4d1c,0xdb190067,0x68e82413,0x00000000}},	//   lic_, zewó, _ordd, --,
   {{0x5c071112,0x3cd50340,0x20024d1d,0x63a400c3}},	//   ляда, ржес, _foki_, _ydin,
   {{0x24b7016b,0x6d4e099e,0x00000000,0x00000000}},	//   רהאן_, _dyba, --, --,
   {{0x68e8001e,0xfaa72a24,0x3ec400b8,0xaac40312}},	//   _ardd, ушен, ěstí_, متون,
   {{0x7c974d1e,0xa2ad1af6,0x627c02b5,0x200219cd}},	//   _مشرا, _जिन्, ענונ, _zoki_,
   {{0x6ce400d4,0x442b4d1f,0x64464d20,0x5ce400d8}},	//   _літе, kic_, yoki, _люта,
   {{0x442b4d21,0x644601ed,0x00000000,0x00000000}},	//   jic_, xoki, --, --,
   {{0x442b4d22,0x64464d23,0x6d4e011e,0x7c2b4d24}},	//   dic_, voki, _zyba, migr,
   {{0x7c2b4d25,0xe9d8006c,0x76250f6d,0x00000000}},	//   ligr, _مذمت_, рмоз, --,
   {{0x64464d26,0x442b4d27,0xa8a40798,0x62844d28}},	//   toki, fic_, _грчк, _stio,
   {{0x442b4d29,0x0446095d,0xe3661000,0x600a00a0}},	//   gic_, ремн, икни, _tými,
   {{0x20024d2a,0xe60e3cef,0xe356010b,0x601800fe}},	//   _roki_, _дд_, ртнэ, _jíme,
   {{0x64464d2b,0x2bd20761,0x7ae94d2c,0x20020826}},	//   soki, _सस्थ, _mret, _soki_,
   {{0x64464d2d,0x91031517,0x2d9a0124,0x7c2b01a2}},	//   poki, опре, vape_, kigr,
   {{0x7c2b029d,0x30754d2e,0x442b4d2f,0x63a44d30}},	//   jigr, сурс, cic_, _udin,
   {{0xa0671d6b,0x5ea60037,0x20020176,0xfe7f099e}},	// [4700] рата_, شمال, _voki_, _drïo_,
   {{0x6ea7009a,0x660303ad,0x7bc9008c,0x7c2b0345}},	//   _चिरु, _jonk, _abeu, eigr,
   {{0x2d9a4d31,0x7ae94d32,0xeb9a392c,0x20024d33}},	//   rape_, _aret, вие_, _toki_,
   {{0x7ae94d34,0xa2ad00c0,0x6d4e05d3,0x7d03013c}},	//   _bret, _जिम्, _vyba, änsa,
   {{0x245902e1,0x6018006c,0x2d9a0db4,0xda661858}},	//   néma_, _címe, pape_, авди,
   {{0x7ae94d35,0x442b4d36,0xfcaa0118,0x1a89006c}},	//   _dret, zic_, _لارو_, ائنٹ_,
   {{0xdca332ff,0x8ccd3123,0x7ae94d37,0x1dc60ebd}},	//   _мари, _सहयो, _eret, र्णत,
   {{0x442b4d38,0x2d9810a7,0x7ae94d39,0x8c43292e}},	//   xic_, _here_, _fret, _десе,
   {{0x2d984d3a,0x1dc6022e,0x442b4d3b,0xe9da002d}},	//   _kere_, र्थत, vic_, _ика_,
   {{0x9a6a0fab,0xa3b90992,0x2d984d3c,0x3ea04d3d}},	//   _شمال_, _चाह_, _jere_, isit_,
   {{0x2d984d3e,0x442b4d3f,0x66031516,0x3f8001ba}},	//   _mere_, tic_, _donk, kciu_,
   {{0x1dc601d1,0x3ea04d40,0x2d984d41,0x00000000}},	//   र्तत, ksit_, _lere_, --,
   {{0x66034d42,0x6018002a,0x00000000,0x00000000}},	//   _fonk, _oímb, --, --,
   {{0x442b4d43,0x2d984d44,0x7c2b040b,0x66034d45}},	//   sic_, _nere_, zigr, _gonk,
   {{0x442b4d46,0xe45321a0,0x3ea000da,0x76484d47}},	//   pic_, _وضع_, esit_, mody,
   {{0x34fb02da,0x66030051,0x2d984d48,0x9f5901f7}},	//   _יהוד, _zonk, _aere_, _posà_,
   {{0x44294d49,0x2d984d4a,0x7875010b,0x7c2b4d4b}},	// [4710] _ima_, _bere_, _išve, vigr,
   {{0x273300e8,0x7ae901d2,0x442901e8,0x2ca70831}},	//   ảng_, _rret, _hma_, ándo_,
   {{0x7ae90280,0x2d9801e0,0x3ea002ee,0x0eac07b5}},	//   _sret, _dere_, asit_, _चिथड,
   {{0x37ac0083,0x1b050083,0x3f800036,0x5fdf0099}},	//   ক্তর, _শেষে_, cciu_, _पोचल,
   {{0xf1ec0953,0x7c2b4d4c,0x3f9900e9,0x2d98021d}},	//   _छोड़_, rigr, _iesu_, _fere_,
   {{0x2ba70028,0x2d980526,0x7ae94d4d,0x442900ec}},	//   ốc_, _gere_, _vret, _lma_,
   {{0x44294d4e,0xb7bd0043,0x3f990009,0x9f4b00de}},	//   _oma_, liţi, _kesu_, _tocó_,
   {{0x013802da,0x7ae94d4f,0x2d814d50,0x3f994d51}},	//   ירות_, _tret, lche_, _jesu_,
   {{0x7ae94d52,0x2d98027d,0x6f0d4d53,0x7c3b0010}},	//   _uret, _yere_, nyac, _ijur,
   {{0x44294d54,0x2d814d55,0xe6161385,0x644d4d56}},	//   _ama_, nche_, йды_, _akai,
   {{0x2d814d57,0x7c2902c4,0x66034d58,0x3f8043e8}},	//   iche_, _kmer, _vonk, yciu_,
   {{0x3f99072b,0x7c290069,0xe8df055c,0x00000000}},	//   _nesu_, _jmer, _chụm_, --,
   {{0xd7c800f8,0x7c29018e,0x24524d59,0x6018007e}},	//   _خونه_, _mmer, námi_, _límc,
   {{0x27ff437b,0x661a4d5a,0x644d06a2,0x44294d5b}},	//   ljun_, chtk, _ekai, _ema_,
   {{0x2d984d5c,0x2d814d5d,0x27ff00d7,0x00000000}},	//   _rere_, dche_, ojun_, --,
   {{0x2d984d5e,0x3ea04d5f,0x248700d7,0x7c3b4d60}},	//   _sere_, tsit_, _itnm_, _njur,
   {{0x2d984d61,0xee3a2186,0x3f804d62,0x7d0301ff}},	// [4720] _pere_, гна_, rciu_, änsn,
   {{0x823600bf,0x3ea04d63,0xc3330319,0x7c3b4d64}},	//   _دربا, rsit_, _מוח_, _ajur,
   {{0x3ea04d65,0x44290297,0x2d980044,0x62650312}},	//   ssit_, _yma_, _vere_, _بايق,
   {{0xa3cb0302,0x2d980052,0x3ea04d66,0x3f994d67}},	//   र्प_, _were_, psit_, _gesu_,
   {{0x7c3b4d68,0x2d984d69,0x6f0d0371,0xcc8800f8}},	//   _djur, _tere_, cyac, انچه_,
   {{0x2d8102fb,0x7c3b0027,0x00000000,0x00000000}},	//   cche_, _ejur, --, --,
   {{0x3f994d6a,0xa3b9017a,0x81cb0033,0x7c3b035f}},	//   _yesu_, _चाल_, _রোড_, _fjur,
   {{0x6d5c3c1f,0x6c361aa6,0x7c3b01f4,0x00000000}},	//   _izra, _افرا, _gjur, --,
   {{0xa3cb0f9c,0xe9a62b34,0x76480096,0x00000000}},	//   र्फ_, _газп, tody, --,
   {{0x645f08e3,0x644d4d6b,0xa3cb164f,0x44291d86}},	//   _shqi, _skai, र्न_, _sma_,
   {{0x764801c8,0x6aa24d6c,0xb7bd0043,0xf8ac0084}},	//   rody, lsof, ziţi, _घटिय,
   {{0x14a90ebd,0xd7f70036,0x661a023c,0x00000000}},	//   _किरण, _гуш_, shtk, --,
   {{0x6d5c012f,0x3f990159,0xdb0000b8,0x6f0d0282}},	//   _lzra, _resu_, _odmí, xyac,
   {{0x6d5c0293,0x799a4d6d,0x260901ef,0xf8dc0035}},	//   _ozra, _jetw, _dúos_, _मनाय,
   {{0x9583006a,0x442900d5,0x3f990303,0x799a4d6e}},	//   łącz, _tma_, _pesu_, _metw,
   {{0x442902e3,0xdb00002a,0xb7bd00af,0x644d4d6f}},	//   _uma_, _admí, tiţi, _ukai,
   {{0x44394d70,0x7c3b2b6c,0x6d5c4d71,0x6aa202a2}},	// [4730] mns_, _rjur, _azra, jsof,
   {{0x44394d72,0x7c294d73,0x799a4d74,0x2d814d75}},	//   lns_, _smer, _netw, uche_,
   {{0x44394d76,0x2d812939,0x226401c0,0x6f0d02d7}},	//   ons_, rche_, řské_, syac,
   {{0x44394d77,0x2d81463c,0x3b551b96,0xafdb0185}},	//   nns_, sche_, окер, _sjøf,
   {{0x799a0052,0x44394d78,0x1dc600e7,0x6d4b02b1}},	//   _betw, ins_, र्हत, ßgab,
   {{0x79e7006c,0xe29c0070,0x00000000,0x00000000}},	//   صوبہ_, נשור, --, --,
   {{0xb4c70006,0x799a02e9,0x7c2901f4,0xf8a900bf}},	//   _उहे_, _detw, _tmer, شگاه_,
   {{0x7c294d79,0xa3cb1365,0x6b820382,0x44392eec}},	//   _umer, र्म_, ccog, jns_,
   {{0xe6190de3,0xe7390812,0x1dc60fff,0x27ff4d7a}},	//   иди_, реп_, र्वत, rjun_,
   {{0xdce50716,0xf62500d4,0x799a01bf,0x6b9b12ba}},	//   lahı, ідно, _getw, _heug,
   {{0xafdb0044,0x6b9b028b,0xbf9b000d,0xdb19033b}},	//   _gjøg, _keug, _poêl, gewö,
   {{0x6b9b02e6,0x799a02e9,0xd7e40eb9,0x44394d7b}},	//   _jeug, _zetw, _нічо, gns_,
   {{0xe5a5141d,0x7c39099e,0xafdb008c,0x93462286}},	//   _дили, inwr, _mjød, інге,
   {{0x6b9b0014,0x20190069,0xda7a016b,0xdcfc004b}},	//   _leug, _alsi_, ינשר, _gerė,
   {{0x6b820602,0x7d03013c,0x443910c3,0xc0e330ef}},	//   ycog, änsl, bns_, морк,
   {{0x6b9b4d7c,0x28dc018d,0x44394d7d,0x64470bde}},	//   _neug, _मनसि, cns_, čkic,
   {{0x3e7f00af,0x00000000,0x00000000,0x00000000}},	// [4740] _cît_, --, --, --,
   {{0x237f00a0,0x18160d4e,0x7e56093e,0x8d564d7e}},	//   ľuje_, _तत्व_, ітац, отеч,
   {{0x237f4d7f,0x799a4d80,0x6b9b4d81,0xe7d90324}},	//   žuje_, _retw, _beug, ढ़ाप,
   {{0x6aa21f39,0x274300c7,0x00000000,0x00000000}},	//   tsof, _kūną_, --, --,
   {{0x6b8233ad,0x799a0359,0xafdb008c,0x3e7f4513}},	//   rcog, _petw, _sjøg, _gît_,
   {{0x6b820042,0x6aa20029,0x13e30033,0x48aa154b}},	//   scog, rsof, যায়, атим_,
   {{0xa3cb0f19,0x6d5c2c14,0x6b9b009e,0xa3dd0066}},	//   र्ड_, _uzra, _feug, ड़म_,
   {{0x9989012e,0x32c4027d,0x6aa203d0,0x6b9b0065}},	//   đaš_, köy_, psof, _geug,
   {{0x41ca08b0,0x4439054e,0xdcfc00c7,0x799a018e}},	//   िभास, vns_, _perė, _tetw,
   {{0x44394d82,0x6b9b033b,0xd6260079,0x00000000}},	//   wns_, _zeug, تعبي, --,
   {{0xa2ad021a,0x7d7b0122,0xd7fa1958,0x37ac0033}},	//   _जिह्, יניו, _вул_, ক্ষর,
   {{0x69d84d83,0x44394d84,0xd7ef004f,0x69ca1360}},	//   leve, uns_, _لكم_, lffe,
   {{0x44394d85,0x787500d8,0x4736097f,0x01e40033}},	//   rns_, _išva, _براز, মানদ,
   {{0x69d84d86,0x9f4002b1,0x44390308,0x00000000}},	//   neve, weiß_, sns_, --,
   {{0xcf9b4d87,0xdce50095,0x6018008a,0x443900ec}},	//   ија_, yahı, _síma, pns_,
   {{0x69d84d88,0xdc3a2f80,0x00000000,0x00000000}},	//   heve, kçıs, --, --,
   {{0xa3cb09b8,0xd83802d0,0x20194d89,0x69d80044}},	// [4750] र्ण_, _avčk_, _vlsi_, keve,
   {{0x69d84d8a,0x63bd00c7,0x9f420260,0x69ca0051}},	//   jeve, lgsn, _makè_, jffe,
   {{0x69d84d8b,0x628f4d8c,0xa25b000d,0x9f420107}},	//   deve, lpco, ntôm, _lakè_,
   {{0x601800fb,0x69ca198d,0x61e50207,0x00000000}},	//   _tíma, effe, _hahl, --,
   {{0x61e54d8d,0x7ccc00ea,0xdb090051,0xa3ae00b4}},	//   _kahl, vērš, _ideë, _ओएस_,
   {{0x69d84d8e,0x61e50069,0x78750207,0x00000000}},	//   geve, _jahl, _ašva, --,
   {{0x61e54d8f,0x6b9b4d90,0x5ba70c94,0x7e7d1e54}},	//   _mahl, _teug, _мраз, _husp,
   {{0x69ca0069,0xf8ae05f5,0x7e7501d7,0xb8d30324}},	//   affe, اکل_, _hizp, _झट_,
   {{0x69d84d91,0xe9ab0088,0x7ae00051,0x2be00099}},	//   beve, _ندان_, _gsmt, _नसता,
   {{0x61e50076,0x69d84d92,0x80d20083,0x7e7d4d93}},	//   _nahl, ceve, হিত্, _musp,
   {{0x7e7d4d94,0x7e754d95,0x00000000,0x00000000}},	//   _lusp, _mizp, --, --,
   {{0x8883006c,0x00000000,0x00000000,0x00000000}},	//   _ٹیکن, --, --, --,
   {{0x61e50fc2,0x7e7d4d96,0x5ed30083,0xb77a00a5}},	//   _bahl, _nusp, সিডে, _האנש,
   {{0x61e50160,0x00000000,0x00000000,0x00000000}},	//   _cahl, --, --, --,
   {{0x7e7d4d97,0xe3b2004f,0x628f0051,0xc5e10033}},	//   _ausp, _كرة_, apco, বাদপ,
   {{0x7e754d98,0xa3cb4d99,0x69d83987,0xafdb0b3e}},	//   _aizp, र्द_, zeve, _skør,
   {{0x7e7d0094,0xd0074d9a,0x61e50c75,0x3f9208dd}},	// [4760] _cusp, чете_, _fahl, rbyu_,
   {{0x9f4200b8,0x0ea700d8,0x7e7d354b,0x24520097}},	//   _jaké_, якуй_, _dusp, rámu_,
   {{0xdcfc00ea,0x69d843f4,0xb33b0132,0x7e7d1024}},	//   _ierī, veve, maça, _eusp,
   {{0xb33b4d9b,0x61e502c9,0x69d80122,0x69c1009e}},	//   laça, _zahl, weve, _acle,
   {{0x7e7d0176,0x37c30033,0x69d84d9c,0xa3dd00ab}},	//   _gusp, ্যার, teve, ड़त_,
   {{0xb33b4d9d,0x69ca4d9e,0x693401df,0xdca60ddc}},	//   naça, uffe, وکار, _наги,
   {{0x69d80568,0x7bd946f6,0x69ca001e,0xdb0220d9}},	//   reve, bewu, rffe, rgoñ,
   {{0xa2ad21f2,0x69c14d9f,0xebe30c0d,0x601115ed}},	//   _जिल्, _ecle, _посп, _påmi,
   {{0xc6f715eb,0xba3d00b8,0x5eca0083,0x8c4301d3}},	//   зных_, _kvůl, রিকে, _чете,
   {{0x68e1022e,0x1dcf37e8,0x69d80031,0x69c10079}},	//   _fsld, स्पत, qeve, _gcle,
   {{0xa3cb0006,0x9f4700b8,0x61e508b7,0xb33b0d99}},	//   _रउआ_, ěné_, _rahl, daça,
   {{0x61e54da0,0x49170d85,0xf3ff0183,0x00000000}},	//   _sahl, _מקבל_, rmão_, --,
   {{0x61e506b3,0xf3ff0132,0x00000000,0x00000000}},	//   _pahl, smão_, --, --,
   {{0x27e60037,0x7e7d4da1,0x9f55000d,0xdcfc00ea}},	//   _haon_, _rusp, _âgée_, _cerī,
   {{0x27e6010d,0xdcfc00ea,0xa3aa1856,0x387e02a7}},	//   _kaon_, _derī, गृह_, _jutr_,
   {{0x7e7d4da2,0x61e5083b,0xd3db0037,0x2ee2008c}},	//   _pusp, _wahl, _طبعا_, _bskf_,
   {{0x63ad02d0,0x61e54da3,0x984e00a8,0xb33b0183}},	// [4770] _idan, _tahl, nğın_, baça,
   {{0x628d4da4,0xb33b0132,0xc0cb0043,0x27e64da5}},	//   _itao, caça, _луме_, _laon_,
   {{0x63ad0ea5,0x00000000,0x00000000,0x00000000}},	//   _kdan, --, --, --,
   {{0x644f4da6,0x27e6026b,0xa3dd007c,0x79882069}},	//   noci, _naon_, ड़ि_, _afdw,
   {{0x9f4b021d,0x7e7d02e2,0x63ad023c,0x00000000}},	//   _cocô_, _uusp, _mdan, --,
   {{0x2d850006,0x200b01ba,0x644f03d0,0x628d023c}},	//   _üle_, _hoci_, hoci, _mtao,
   {{0xa3dd27bd,0x63ad4da7,0x08d400d8,0x27e64da8}},	//   ड़ा_, _odan, ецыя, _baon_,
   {{0x63ad4da9,0xd0f80122,0x628d0065,0xd7ee0312}},	//   _ndan, למות_, _otao, لكى_,
   {{0x200b4daa,0x644f4dab,0x660a0051,0xda6705f5}},	//   _moci_, doci, _bofk, _فائي,
   {{0x63ad4dac,0xa3cb04cc,0xa3dd007c,0x7b740037}},	//   _adan, र्स_, ड़ऽ_, _أطفا,
   {{0x1dcf0518,0x044608a6,0x628d4dad,0x39151015}},	//   स्यत, денн, _atao, _تواز,
   {{0x200b1824,0x60184dae,0xa7150274,0x2a7f3a74}},	//   _noci_, _címl, _одељ, _kuub_,
   {{0x9f42000c,0x0cba00b1,0xe72e0043,0xe297325e}},	//   _také_, _उम्म, _ре_, мая_,
   {{0x628d0037,0x1dcf0387,0x63ad4daf,0x754800b5}},	//   _dtao, स्मत, _edan, épzé,
   {{0xb33b4db0,0x200b4db1,0x27e6067f,0x6b894db2}},	//   raça, _boci_, _yaon_, _ofeg,
   {{0x644f3824,0x63ad4db3,0x9f49008e,0xdb1b0138}},	//   coci, _gdan, tjað_, _acuí,
   {{0x200b025c,0xb33b4db4,0x6da63924,0x00000000}},	// [4780] _doci_, paça, диза, --,
   {{0x6b890955,0x63ad05d1,0x9f490093,0xdcf5021e}},	//   _afeg, _zdan, rjað_, _egzč,
   {{0xa3cb28b1,0x61464db5,0x200b00b5,0xa2a40a44}},	//   र्व_, _цена, _foci_, _कबड्,
   {{0x442200cc,0x00000000,0x00000000,0x00000000}},	//   nhk_, --, --, --,
   {{0xeafa009a,0x27e60094,0x34da000c,0x7bc64db6}},	//   ्हेत_, _raon_, _बन्द, _ökum,
   {{0x2bae0028,0x09e303fa,0x2a6500cc,0x644f4db7}},	//   ộc_, вољн, _chlb_, zoci,
   {{0x27e64db8,0x644f0453,0x00000000,0x00000000}},	//   _paon_, yoci, --, --,
   {{0x2fc04db9,0xb8d605f7,0x2eed02a7,0x00000000}},	//   ngig_, _जि_, _šefi_, --,
   {{0x19c621e2,0x7c224dba,0xd6da01e0,0x63ad009e}},	//   _обам, mhor, іти_, _rdan,
   {{0x7c2200c9,0xb9930037,0x00000000,0x00000000}},	//   lhor, _للكب, --, --,
   {{0xf9c7064e,0x27e60269,0x24590bfc,0x628d4dbb}},	//   _تحقی, _taon_, зань_, _stao,
   {{0x7c224dbc,0x00000000,0x00000000,0x00000000}},	//   nhor, --, --, --,
   {{0xa3cb1ae9,0x61ca00be,0x43940274,0x200b0139}},	//   र्ष_, िभूष, ђарс, _roci_,
   {{0x200b2f88,0x644f28d4,0x9f590037,0x321803bc}},	//   _soci_, soci, _tosú_, gkry_,
   {{0x200b4dbd,0x7c2220e7,0x644f12b8,0xdfd51ac5}},	//   _poci_, khor, poci, новы,
   {{0xa3cb0a64,0xe3d00019,0x44220176,0x7c22031d}},	//   र्श_, _hằng_, chk_, jhor,
   {{0x200b4dbe,0x7c224dbf,0x628d0054,0xd6bc0033}},	// [4790] _voci_, dhor, _utao, _অনুপ,
   {{0x786503e6,0x6b890036,0xa3cb0864,0xc2084dc0}},	//   móve, _sfeg, र्र_, _يقين_,
   {{0x291901c2,0x94440594,0x23c604aa,0x6aa90093}},	//   _əsas_, _سپین, _वामद, _svef,
   {{0x7c224dc1,0xe0d20070,0x200b0207,0xb33b0176}},	//   ghor, _גײט_, _uoci_, naço,
   {{0x1dc70084,0x24440448,0x00000000,0x00000000}},	//   _लापत, nıma_, --, --,
   {{0x998c0009,0x3ea92a4d,0xceb2016b,0x00000000}},	//   _ejdž_, msat_, _גיך_, --,
   {{0x38660211,0x7c22026e,0x00000000,0x00000000}},	//   _bhor_, bhor, --, --,
   {{0x38664dc2,0x3f894dc3,0x7c220f93,0x765a0298}},	//   _chor_, ncau_, chor, elty,
   {{0xe3d000e8,0x3ea94dc4,0x3b542bfc,0xf7710c26}},	//   _bằng_, nsat_, _актр, داث_,
   {{0xe3b202fd,0x2444013b,0x00000000,0x00000000}},	//   گرد_, dıma_, --, --,
   {{0x69c41404,0x3866009e,0x25e001c0,0xb33b000d}},	//   _राती, _fhor_, _कसरी_, faço,
   {{0xccf202b5,0x1dcf1cce,0x3ea94dc5,0xe3b2103b}},	//   אכט_, स्तत, ksat_, درد_,
   {{0x386d33d4,0xf6080088,0xddce00fe,0x00000000}},	//   mmer_, ستیه_, _libš, --,
   {{0x64a50fe9,0x386d4dc6,0x3ea94dc7,0x44220031}},	//   _зака, lmer_, dsat_, shk_,
   {{0x25a54dc8,0x3ea914d8,0x3218053e,0x614305d8}},	//   mall_, esat_, rkry_, гера,
   {{0xd007150d,0x386d4dc9,0xb33b0a4f,0x7c220031}},	//   несе_, nmer_, caço, xhor,
   {{0x44204dca,0x63a64dcb,0x9f420c1f,0x3ea9011e}},	// [47a0] _ili_, makn, _ankò_, gsat_,
   {{0xfde74dcc,0xa3c00f9f,0x44200189,0x25a501a6}},	//   ндук_, ुभव_, _hli_, nall_,
   {{0x1dc60387,0x44e101c8,0x3ea9104e,0x7c220122}},	//   र्गत, _jų_, asat_, thor,
   {{0xf7674dcd,0xc5f80029,0x63a609e7,0x386d4dce}},	//   _ما_, nmēr_, nakn, jmer_,
   {{0xa3b81db1,0x7c224dcf,0x386d4dd0,0x25a52426}},	//   _चयन_, rhor, dmer_, kall_,
   {{0x7c224dd1,0xc3330100,0x63a622be,0x386d4dd2}},	//   shor, נוג_, hakn, emer_,
   {{0x44204dd3,0xf1d2046c,0xe3d00028,0xeb9a00c9}},	//   _oli_, द्यन, _rằng_, _нив_,
   {{0x63a64dd4,0xc6f83f7f,0x644440f7,0x00000000}},	//   jakn, дних_, _njii, --,
   {{0x25a54dd5,0x63a60d1c,0x09bf0033,0x291a013a}},	//   fall_, dakn, _ইসরা, špa_,
   {{0x44204dd6,0xceb301f3,0x25a54dd7,0x6447022f}},	//   _ali_, נית_, gall_, čkim,
   {{0x43950810,0x44201bb4,0x6018006c,0xa3dd007c}},	//   канс, _bli_, _címk, ड़ल_,
   {{0x63a6046a,0x07a60210,0x443226d8,0x00000000}},	//   gakn, _чадн, _cmy_, --,
   {{0x25a54dd8,0xe29801c8,0xb33b4dd9,0xee3f01c0}},	//   ball_, наў_, raço, _svým_,
   {{0x44204dda,0x171b00c2,0x244400d0,0x7af600c3}},	//   _eli_, _צוגע, rıma_, äyty,
   {{0x9f47000c,0xb33b3203,0xa2ad0084,0x63a64ddb}},	//   ění_, paço, _जिक्, bakn,
   {{0x44200021,0x3ea94ddc,0x63a60176,0x00000000}},	//   _gli_, tsat_, cakn, --,
   {{0x50644ddd,0x3f892051,0x5fe20099,0x62804dde}},	// [47b0] утра, rcau_, _पसरल, ímot,
   {{0x645d4ddf,0x44200bde,0x6ca72659,0x386d4de0}},	//   llsi, _zli_, ердж, zmer_,
   {{0x3ea94de1,0x09bf00c8,0x44200086,0xc0ab14ac}},	//   ssat_, _ইসলা, _yli_, _عادل_,
   {{0x3ea900b8,0xdb1b0b4c,0x2eed07e7,0xb33b027d}},	//   psat_, _acuá, _šefu_, yaçl,
   {{0x645d0037,0x00000000,0x00000000,0x00000000}},	//   ilsi, --, --, --,
   {{0xdc130463,0xdb0001f4,0xf2d40070,0x245900d5}},	//   rşıs, _zemë, רעס_, mému_,
   {{0x25a54de2,0x63a60703,0xf8694de3,0x6d42002d}},	//   vall_, yakn, ومتي_, şoar,
   {{0x20094de4,0x00000000,0x00000000,0x00000000}},	//   njai_, --, --, --,
   {{0x3a754de5,0x386d4de6,0x25a502ce,0x2459024e}},	//   _алар, rmer_, tall_, nému_,
   {{0x386d096d,0x64440051,0xa3d40d55,0x645d0345}},	//   smer_, _sjii, स्न_, elsi,
   {{0x442002e9,0x25a54de7,0xfeb90033,0x24590097}},	//   _pli_, rall_, ুবিধ, hému_,
   {{0x66b52aa9,0x24590187,0xe78717f8,0x69c34de8}},	//   _абду, kému_, _чужо, lgne,
   {{0xe3b80092,0x63a64de9,0x27ed4dea,0x25a54deb}},	//   ğı_, rakn, mden_, pall_,
   {{0xe3b80463,0x27ed4dec,0xdb0007a7,0x44e1010b}},	//   şı_, lden_, _demè, _tų_,
   {{0x69c34ded,0x44204dee,0x20564def,0x63a608eb}},	//   igne, _tli_, втар, pakn,
   {{0x27ed42c1,0x44204df0,0x784801c0,0xdb00021e}},	//   nden_, _uli_, pěve, _femè,
   {{0x27ed4df1,0x26cd0300,0x63a44df2,0x81c90033}},	// [47c0] iden_, nteo_, _iein, োয়_,
   {{0x63a44df3,0x27ed0086,0x6f0401dd,0x00000000}},	//   _hein, hden_, rxic, --,
   {{0x63a4327a,0x60184df4,0x62844df5,0x61fe4df6}},	//   _kein, _lími, _huio, _inpl,
   {{0x27ed04ce,0x6284002f,0x69c40099,0x63a401ed}},	//   jden_, _kuio, _राही, _jein,
   {{0xa3d421b2,0x27ed4df7,0x63a40938,0x7bc22948}},	//   स्य_, dden_, _mein, rgou,
   {{0x63a44df8,0xbda50642,0x61ee4df9,0x27ed4dfa}},	//   _lein, _محفو, ndbl, eden_,
   {{0xdca311a7,0x7d03022a,0x27ed02a2,0x88580a80}},	//   _васи, änst, fden_, никс_,
   {{0x63a44dfb,0x6b85004f,0x27ed4dfc,0xa3d40461}},	//   _nein, _مشكل, gden_, स्म_,
   {{0x1dcf0edf,0x7e7c4dfd,0x6d5c4dfe,0x59d600fd}},	//   स्वत, _kirp, _hyra, _لغار,
   {{0xdb004dff,0x4b550133,0x49ba04e8,0xae0505dc}},	//   _remè, _съст, _زائد_, रायन_,
   {{0x63a44e00,0x24e301c8,0xdb0002d0,0x7e7c0031}},	//   _bein, ацяг, _semè, _mirp,
   {{0x61fe0c1f,0x63a44e01,0x6d5c0533,0x61ee0051}},	//   _anpl, _cein, _myra, edbl,
   {{0x63a44e02,0x59c91f4c,0xf11b00c0,0x6d5c0282}},	//   _dein, _रामर, नन्द_, _lyra,
   {{0x2459024e,0xe71700a5,0x752d0355,0x62840139}},	//   vému_, _בחדר_, _řaze, _duio,
   {{0x63a44e03,0x41d204e9,0xafdb03d0,0xf1d200b8}},	//   _fein, द्धस, _fjøl, द्धन,
   {{0x63a44e04,0x61fe4e05,0x6b80010d,0x7e7c2715}},	//   _gein, _enpl, _ngmg, _airp,
   {{0x44394e06,0x62844e07,0x6d5c00a3,0x7e7c01b7}},	// [47d0] mis_, _guio, _ayra, _birp,
   {{0x27ed01d6,0x63a401d7,0x24590187,0xf1ab0088}},	//   zden_, _zein, rému_, _کاکه_,
   {{0x27ed4e08,0x44394e09,0x7e7c00e9,0x00000000}},	//   yden_, ois_, _dirp, --,
   {{0x44394e0a,0xc4d300c2,0x6d5c4e0b,0x00000000}},	//   nis_, יגע_, _dyra, --,
   {{0x78650987,0x6d5c008d,0xd17e0160,0x81e60033}},	//   jóva, _eyra, _nopț, ফার_,
   {{0x44394e0c,0x27ed4e0d,0xa96913f9,0xdd9400d8}},	//   his_, wden_, нила_, _вары,
   {{0x443915d6,0x69c34e0e,0x48791172,0xa3d40026}},	//   kis_, rgne, нсия_, स्ड_,
   {{0x44394e0f,0x27ed4e10,0x317c0122,0x26cd4c55}},	//   jis_, uden_, ורומ, tteo_,
   {{0x27ed4e11,0x63a44e12,0x9f42072c,0x6d5c0031}},	//   rden_, _rein, _kaká_, _zyra,
   {{0x63a40408,0xf99316a4,0x26cd3f38,0x27ed4e13}},	//   _sein, _ضبط_, rteo_, sden_,
   {{0x63a44e14,0xdb004e15,0x26cd0453,0x03a60073}},	//   _pein, _remé, steo_, лино,
   {{0x60184e16,0xdb00143f,0x7ae90207,0x00000000}},	//   _tími, _semé, _kset, --,
   {{0x8c1a0122,0x62844db2,0x63bb0093,0x63a44e17}},	//   גורי, _quio, óuna, _vein,
   {{0x63a44e18,0x44394e19,0x7ae9002f,0x00000000}},	//   _wein, ais_, _mset, --,
   {{0x63a44e1a,0x28c6073f,0xf8c600b4,0x412a496e}},	//   _tein, रूपि, रूपय, хово_,
   {{0x44394e1b,0x7ae93abf,0xd5cf02cb,0x24830187}},	//   cis_, _oset, त्रज, íjmu_,
   {{0xdb004e1c,0x00000000,0x00000000,0x00000000}},	// [47e0] _temé, --, --, --,
   {{0x61fe4e1d,0xee374e1e,0x00000000,0x00000000}},	//   _unpl, гну_, --, --,
   {{0xa3cb0e68,0x7ae94e1f,0x27330019,0x9f4700b8}},	//   र्क_, _aset, ảnh_, ěná_,
   {{0x6d5c4e20,0xc17800d8,0x201e00ea,0xdca31150}},	//   _vyra, žės_, ītis_, саци,
   {{0x6d5c004e,0x1b170033,0x7e7c00c7,0xa3cc046c}},	//   _wyra, _দেবে_, _tirp, _लान_,
   {{0xa3d40591,0x44394e21,0xb88501ba,0x7ae901ef}},	//   स्त_, zis_, zlíš, _dset,
   {{0x7ae90332,0x44394e22,0x98a30274,0x69e20355}},	//   _eset, yis_, бије, _čteč,
   {{0x7981001e,0x6b80011e,0xb8140bfe,0xa8140009}},	//   _eglw, _ugmg, рдиј, рдиш,
   {{0xdd3a0160,0x2907009e,0x00000000,0x00000000}},	//   _făţa, axna_, --, --,
   {{0x44394e23,0x68ed004e,0xd91005f5,0xdb2306c9}},	//   wis_, łada, _ویش_, _órái,
   {{0xdb091d7f,0x97c601b2,0xd7ef002d,0xafdb0044}},	//   _ideá, _مقاو, _лу_, _sjøm,
   {{0x44394e24,0x661d0055,0x00000000,0x00000000}},	//   uis_, ëskr, --, --,
   {{0xa3cb3b29,0xe69300e0,0x23c60354,0x6a640392}},	//   र्ग_, _هلند, _वारद, nòfo,
   {{0x65941397,0xf77300a5,0x00000000,0x00000000}},	//   _таку, _פקס_, --, --,
   {{0x43950ffd,0xa1594e25,0x00000000,0x00000000}},	//   _кайс, таву_, --, --,
   {{0xa3cb00c4,0x5f951283,0x9f4b0453,0x443920e2}},	//   र्ख_, риат, _hacé_, qis_,
   {{0x9f590176,0x00000000,0x00000000,0x00000000}},	// [47f0] _rosó_, --, --, --,
   {{0x23690260,0xa3dd0066,0x7bc91c8b,0xafdb0185}},	//   _izaj_, ड़क_, _sceu, _kjøk,
   {{0x9f5902d7,0xa8070225,0x7dda0a8a,0x9f4b00f6}},	//   _posó_, ngıç, _søsæ, _macé_,
   {{0xf41f0086,0x7ae90506,0xd9ad007e,0xac7400f8}},	//   nkä_, _pset, घण्ट, مانش,
   {{0x9f4200a0,0x00000000,0x00000000,0x00000000}},	//   _taká_, --, --, --,
   {{0xa3cc0d12,0x7ae9290b,0x9f490037,0xa2cd0066}},	//   _लाभ_, _vset, ndaí_, _तमन्,
   {{0xf41f0421,0x6d430079,0x00000000,0x00000000}},	//   kkä_, únad, --, --,
   {{0xb8cd0953,0xc888004f,0xa8020644,0x2a7e01d7}},	//   _कब_, دخول_, şınm, _eitb_,
   {{0x78a40a78,0x7ae900d5,0xf7451129,0x76250d46}},	//   ćiva, _uset, репо, имиз,
   {{0xe6160421,0x00000000,0x00000000,0x00000000}},	//   иды_, --, --, --,
   {{0x998402aa,0x64a51a55,0x80a7021a,0x00000000}},	//   _المو, јама, टीमे, --,
   {{0xf7704e26,0xda030864,0xdcfc035f,0x7bc60093}},	//   _کام_, लावत_, _jerġ, _ökut,
   {{0x2bd7134b,0x32130187,0x59da0026,0xfbd70096}},	//   ण्या, _boxy_, _मॉडर, ण्यम,
   {{0xe2973e1f,0x058706d8,0x00000000,0x00000000}},	//   рар_, _судм, --, --,
   {{0x463a02b5,0x28dd0243,0xc0e600af,0x00000000}},	//   _בעסע, _महफि, шовк, --,
   {{0x09af0033,0xdb0b0093,0xd3ba010b,0xd8380260}},	//   চ্চা, yggð, _рукі_, _nwčl_,

   {{0xe5a30023,0x27ef1fdf,0x84450079,0x00000000}},	// [4800] _điệ, _magn_, _دخول, --,
   {{0x2d9602ee,0x9f590036,0xbda50037,0x2480008c}},	//   ррас, _posò_, محمو, _hiim_,
   {{0xdddd0043,0xdcfc0024,0x601805ee,0x644602ee}},	//   _susţ, _berġ, _símu, onki,
   {{0x41d20e61,0x64464e27,0x60de002f,0x27ef0118}},	//   द्रस, nnki, _ippm, _nagn_,
   {{0xa3cb006a,0x64464e28,0xe8094e29,0x24804e2a}},	//   र्ट_, inki, वाना_, _miim_,
   {{0x225801a3,0xca560274,0x3ceb00c3,0x7c9602fb}},	//   nork_, штењ, äivä_, _врац,
   {{0x68ed0035,0x2b4d4e2b,0x2c6700be,0x00000000}},	//   ładn, _exec_, sõda_, --,
   {{0xf09300a5,0x644602c4,0x8c46027a,0x60180093}},	//   חנה_, jnki, _тебе, _tímu,
   {{0x236001e8,0xafdb0044,0x9f4b00f6,0x00000000}},	//   _nyij_, _sjøk, _pacé_, --,
   {{0x225801f2,0xa3d40bdd,0x2480009e,0x7afd0093}},	//   jork_, स्स_, _aiim_, _ásta,
   {{0xf41f0086,0x200202ee,0x2480009e,0x38cb0987}},	//   tkä_, _onki_, _biim_, _لانی_,
   {{0x38600037,0x27ef1ac1,0x00000000,0x00000000}},	//   _óir_, _gagn_, --, --,
   {{0xe694004f,0x63b600e9,0x00000000,0x00000000}},	//   _التد, _ddyn, --, --,
   {{0x20024687,0xa3cb25d8,0x644600c3,0x27e44e2c}},	//   _anki_, र्ज_, anki, lemn_,
   {{0x2bd700b8,0x26c44e2d,0xfbd72c2b,0x9f490079}},	//   ण्डा, lumo_, ण्डम, rdaí_,
   {{0xcf980202,0x02a70086,0x63b62200,0xe8090035}},	//   ију_, _кром, _gdyn, वाया_,
   {{0xf77302b5,0xa3cc0e04,0x26c400c7,0xe4d800b5}},	// [4810] ַקע_, _लात_, numo_, _شوکت_,
   {{0x20022b51,0x22580176,0x6e200160,0x60184e2e}},	//   _enki_, cork_, _îmbl, _bíms,
   {{0xa3d40325,0x2eeb012f,0x63b6001e,0xdb000160}},	//   स्व_, _wscf_, _ydyn, _nemâ,
   {{0xa3cb0325,0x69da033b,0x26c44e2f,0xccf80274}},	//   र्च_, _abte, kumo_, шћу_,
   {{0x2ef401c8,0x784801c0,0xe2140e3a,0x68fa4e30}},	//   _дзяр, těvn, _طبیع, _artd,
   {{0x26c4004b,0x9ce7006c,0xa80200d0,0xdb0002d7}},	//   dumo_, _پورے_, şılm, _gemí,
   {{0x601800b8,0x2b8d0079,0x00000000,0x00000000}},	//   _tímt, _cócó_, --, --,
   {{0x9f950006,0x26c44e31,0x442b012f,0x2fc94e32}},	//   _nüüd_, fumo_, jhc_, ngag_,
   {{0x25ac022e,0x26c4010b,0x27ef3498,0xa3cb01c0}},	//   fadl_, gumo_, _vagn_, र्छ_,
   {{0xa3cb473a,0x7afb4e33,0x24804e34,0x0609208b}},	//   र्घ_, _irut, _siim_, унок_,
   {{0xedf90083,0xa3cc046c,0x248000be,0x249600f8}},	//   _আকাশ_, _लाद_, _piim_, ینید_,
   {{0xe29a4e35,0x04464e36,0x26c44e37,0x22584e38}},	//   лам_, семн, bumo_, work_,
   {{0xe60e383f,0x734900af,0x8544005f,0x7bdb001c}},	//   _ед_, ачёв_, _akėč, _mbuu,
   {{0x7afb47e7,0x00000000,0x00000000,0x00000000}},	//   _mrut, --, --, --,
   {{0xdb004e39,0x7bdb001c,0x2480018d,0x00000000}},	//   _remí, _obuu, _tiim_, --,
   {{0xdfd20ad9,0x6143002d,0x601800a0,0xa3ba1015}},	//   ثير_, чеса, _ríms, _صابر_,
   {{0xa067029f,0x92b6126b,0x386f01da,0x7afb023a}},	// [4820] сата_, _احبا, _mhgr_, _nrut,
   {{0x7bdb01a8,0xe80900a1,0xdcfc4e3a,0xa3d40067}},	//   _abuu, वाडा_, _agrā, स्र_,
   {{0xa63a02b5,0x60de013c,0x7afb4e3b,0x7bdb030d}},	//   נגער, _uppm, _arut, _bbuu,
   {{0x26c40008,0x20f80124,0xd00a135b,0x00000000}},	//   yumo_, _iči_, _семе_, --,
   {{0x7afb006e,0xdb000a20,0xdb0b000d,0x6205008d}},	//   _crut, _temí, nagè, _útlá,
   {{0xa8a60150,0x6d43004f,0xf1db06fe,0x26c44e3c}},	//   брик, únac, म्पन, vumo_,
   {{0x6da31682,0x7afb2759,0x00000000,0x00000000}},	//   _хиса, _erut, --, --,
   {{0x7afb4e3d,0x26c44e3e,0x69cd32ea,0x7c2b4e3f}},	//   _frut, tumo_, _साथी, chgr,
   {{0xfaa34b5c,0xdb00021d,0x00000000,0x00000000}},	//   _нато, _demã, --, --,
   {{0x26c400d8,0xba234e40,0x69da0027,0xa6340208}},	//   rumo_, _едук, _ubte, інні,
   {{0x26c44e41,0x8afd00b8,0xba3d0355,0x00000000}},	//   sumo_, _vyře, _tvůr, --,
   {{0x69d84e42,0x66030103,0x00000000,0x00000000}},	//   lfve, _ennk, --, --,
   {{0x1da8009a,0xcc3b02b5,0x7c220065,0xdcfc007a}},	//   गरात, רעכט, ikor, _ferħ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c224e43,0x463b00c2,0x2444013b,0x765a4e44}},	//   kkor, _געגע, zımi_, moty,
   {{0xef99215b,0x7c224e45,0x00000000,0x00000000}},	//   ркаш_, jkor, --, --,
   {{0x44294e46,0x7c224e47,0x63af0035,0xbe394b2a}},	// [4830] _ila_, dkor, macn, азах_,
   {{0x442933a0,0xf1a7224a,0x629d4e48,0x3e6f00be}},	//   _hla_, _урин, mpso, küte_,
   {{0x7afb02a8,0x3895013a,0x4429053e,0x443b027a}},	//   _srut, _kāre_, _kla_, _kmq_,
   {{0x7afb0cca,0x63af4e49,0x237f0254,0x7c220105}},	//   _prut, nacn, žuju_, gkor,
   {{0xd90f4e4a,0x69c44e4b,0x5ba800d8,0x1eab00ce}},	//   کیا_, _राखी, скім_, _حاجي_,
   {{0x6e94059b,0x44294e4c,0x7afb3702,0xe9d8010b}},	//   _хиру, _lla_, _vrut, йкі_,
   {{0x1b1700c8,0x44294e4d,0xec6b0272,0x442200d4}},	//   _দেশে_, _ola_, _брак_, ykk_,
   {{0xe7394e4e,0x7c22013c,0x44293ee2,0x1bd44e4f}},	//   ией_, ckor, _nla_, _нося,
   {{0x7c2901d6,0x7afb4e50,0x7c3b4e51,0x63af0207}},	//   _iler, _urut, _imur, dacn,
   {{0x44294e52,0x644d20fb,0xc8ab0133,0x765a4e53}},	//   _ala_, _ajai, _бъде_, goty,
   {{0x44294e54,0xf3e615de,0x7c294e55,0x67d500d4}},	//   _bla_, ожно, _kler, _можу,
   {{0x7bcb0464,0xc2090122,0x443b02fb,0x44220159}},	//   nggu, _בה_, _cmq_, ukk_,
   {{0x44290755,0x644d012f,0x7c290118,0x61e700b5}},	//   _dla_, _djai, _mler, fejl,
   {{0x44290bb0,0xf8dd112b,0x7c290d9a,0xdb0b00f7}},	//   _ela_, _महाय, _ller, gagé,
   {{0x7c294e56,0x7c3b4e57,0x64470009,0x7c224e58}},	//   _oler, _omur, čkir, ykor,
   {{0xf1db00b8,0x7c3b0027,0xff260f24,0x41db0099}},	//   म्बन, _nmur, омбо, म्बस,
   {{0xee3a00b6,0xf99f01a5,0xfe0505e7,0x69dc00b5}},	// [4840] ана_, _đèn_, रांस_, _öreg,
   {{0xdb000076,0x7c3b4e59,0x26c20a78,0x442900cd}},	//   _nemá, _amur, škog_, _zla_,
   {{0x7c294e5a,0x20f82a9f,0x4177006c,0x55ba00a5}},	//   _bler, _uči_, _واپس, שמעו,
   {{0xab6615dd,0x228f0644,0x6f0d0042,0x7c294e5b}},	//   овел, _yük_, bxac, _cler,
   {{0x3ce601ba,0x65633705,0x00000000,0x00000000}},	//   ňov_, _lynh, --, --,
   {{0xdca6059b,0xceb400a8,0xdb090051,0x00000000}},	//   _маги, msə_, _zeeë, --,
   {{0xdb004e5c,0x7c290304,0x082a216f,0xc27b00a5}},	//   _demá, _fler, иции_, ברסי,
   {{0xd6da4e5d,0xdb000443,0xd7fa4e5e,0x7c290093}},	//   ато_, _temà, рук_, _gler,
   {{0x699602fb,0xceb400a8,0x63af00ee,0xaa4600af}},	//   _дрех, nsə_, vacn, _деал,
   {{0x44294e5f,0x9f4201ef,0x00000000,0x00000000}},	//   _sla_, _bakú_, --, --,
   {{0xa3cc0299,0x44294e60,0x65630297,0x63af0cc1}},	//   _लाश_, _pla_, _cynh, tacn,
   {{0x9f4b00ac,0x1e170e61,0x6563099e,0x00000000}},	//   _sací_, _दक्ष_, _dynh, --,
   {{0x63af4e61,0xdb090051,0xa3cc073f,0x28131a7c}},	//   racn, _reeë, _लार_, _تونس,
   {{0x442911e9,0xe534325e,0x8ccb0035,0x60180310}},	//   _wla_, _нель, _हमलो, _símp,
   {{0x44291b88,0x6563001e,0x63af03c9,0xdb0b0e8c}},	//   _tla_, _gynh, pacn, ragé,
   {{0x44294e62,0x1ddd0af9,0xdb0f4e63,0x60c700f4}},	//   _ula_, न्नत, _çeçe, rujm,
   {{0x645d4e64,0x51870009,0x23280274,0x63ad0211}},	// [4850] mosi, _муна, _моћи_, _iean,
   {{0x645d4e65,0x44fa00ec,0x7c3b4e66,0xdd9b4e67}},	//   losi, _kī_, _smur, рша_,
   {{0x7c290725,0x63ad4e68,0x69c40fcf,0xdb004e69}},	//   _pler, _kean, _राजी, _remá,
   {{0x645d4e6a,0x515a0122,0xdb002de1,0x68ed0035}},	//   nosi, _לכתו, _semá, ładk,
   {{0x7c2901d2,0xfaa54e6b,0x63ad0122,0x62854e6c}},	//   _vler, чало, _mean, _kiho,
   {{0x645d001e,0x7e7902b5,0x628501c0,0x78650831}},	//   hosi, _לאָז, _jiho, móvi,
   {{0xa3cc0e1d,0x645d4e6d,0x201938cb,0x62853e02}},	//   _लाल_, kosi, _kosi_, _miho,
   {{0x7c3b070b,0x63ad4e6e,0x1bb80e0c,0x7c2906a2}},	//   _umur, _nean, _واقع_, _uler,
   {{0xdb0004a5,0xd7060086,0x20194e6f,0xe7390036}},	//   _temá, зные_, _mosi_, сеп_,
   {{0xe8090243,0x62854e70,0x6618006d,0x80e10083}},	//   वाहा_, _niho, _covk, _পছন্,
   {{0x1ddd0e96,0x6fcb00a1,0xd90c042c,0x645d4e71}},	//   न्यत, िलां, _نیو_, fosi,
   {{0x63ad30d2,0x645d4e72,0x201905e2,0x628501ed}},	//   _cean, gosi, _nosi_, _aiho,
   {{0x63ad09bb,0x62854e73,0x59d225d8,0x050b0033}},	//   _dean, _biho, _सामर, শনের_,
   {{0xf7700e0c,0x1dc74e74,0xf67502b5,0x877a02b5}},	//   _شان_, _लागत, _צײַט_, _פאסי,
   {{0x76414e75,0x62850ec0,0x63ad0608,0x2019002f}},	//   mily, _diho, _fean, _bosi_,
   {{0xa3ad004e,0x63ad4e76,0x20194e77,0x201201e8}},	//   गरण_, _gean, _cosi_, ujyi_,
   {{0x64db021a,0x6285035f,0x20194e78,0x6fad08a9}},	// [4860] _बहुश, _fiho, _dosi_, _ज़रू,
   {{0x99c60083,0xceb40095,0x6b89001c,0x628504fb}},	//   _এস্ক, rsə_, _ageg, _giho,
   {{0x20190024,0x59d200b4,0xceb400a8,0x00000000}},	//   _fosi_, _साबर, ssə_, --,
   {{0x6285443a,0x59c9046c,0x6aa9073a,0xae0504aa}},	//   _ziho, _राउर, _bwef, राउन_,
   {{0x41d308b0,0x76414e79,0x321a4e7a,0x62850371}},	//   _तामस, kily, _kopy_, _yiho,
   {{0x69d50723,0x7848000c,0x3ea03344,0xa8a6446e}},	//   _özel, pěvk, mpit_, прик,
   {{0xfce30a9f,0x645d42cb,0x20194e7b,0x76414e7c}},	//   _поро, yosi, _yosi_, dily,
   {{0xafdb0c71,0xd83800d5,0x00000000,0x00000000}},	//   _hjør, _otče_, --, --,
   {{0xae200299,0x66184e7d,0x6aa90297,0x645d4e7e}},	//   _मकान_, _povk, _gwef, vosi,
   {{0x63ad4e7f,0x764102d0,0x3ea04e80,0xddce0024}},	//   _sean, gily, ipit_, _nibż,
   {{0xa96a0e0c,0x63ad3726,0x18a30210,0xaa571b20}},	//   _امام_, _pean, _захм, _علما_,
   {{0xb86516a4,0x9f400033,0x69dc013c,0x6285027c}},	//   _قانو, ndió_, _öreb, _siho,
   {{0xe8094e81,0x6285465b,0x76414e82,0x63ad02d7}},	//   वारा_, _piho, bily, _vean,
   {{0x321a00a5,0xdcf700a8,0x20194e83,0x44fa013a}},	//   _copy_, zaxı, _sosi_, _tī_,
   {{0x63ad006e,0x20194151,0x92cd0083,0x62854e84}},	//   _tean, _posi_, রবে_, _viho,
   {{0x2d980107,0xc5f800ea,0x248e00a2,0xa25b021d}},	//   _afre_, ldē_, _iufm_, crôn,
   {{0x62852997,0xafdb4e85,0x38950228,0xb6a30023}},	// [4870] _tiho, _bjør, _māra_, _nhấ,
   {{0x9f4b021d,0x6b89009e,0x6285009e,0x00000000}},	//   _cacá_, _sgeg, _uiho, --,
   {{0xa3d404cc,0x20190086,0x8cc400b4,0x8bd5002d}},	//   स्क_, _tosi_, ांगो, джец,
   {{0x22434cca,0x76414e86,0x8d744e87,0x2d8a0e85}},	//   lijk_, zily, رالا, _egbe_,
   {{0xdcf70095,0xafdb0185,0xb6a300e2,0x00000000}},	//   raxı, _fjør, _chấ, --,
   {{0xafdb02ce,0x9b0400d8,0x00000000,0x00000000}},	//   _gjør, эзід, --, --,
   {{0xe8091b8f,0x23bf0035,0x389502d4,0x20d74e88}},	//   वाला_, ्लाद, _bāra_, nçi_,
   {{0xccf20052,0xdb001193,0x764100e9,0x6aa9030d}},	//   _בכל_, _bemä, wily, _twef,
   {{0x224304ce,0x997e0043,0x7641129d,0xdddc0df4}},	//   kijk_, tăţi_, tily, _hirš,
   {{0x20d700d0,0xdb000168,0x7a2f0044,0x00000000}},	//   kçi_, _demä, _bøte, --,
   {{0x76413b34,0xa25b0370,0xa3ea2b33,0x321a37fe}},	//   rily, trôn, одна_, _ropy_,
   {{0x1ddd08b0,0x4ad12095,0x3e7400a0,0xdd1c01ba}},	//   न्तत, _समाव, mäte_, náša,
   {{0xdb0001ae,0x764108dd,0x00000000,0x00000000}},	//   _gemä, pily, --, --,
   {{0x14c502e4,0xb77a011d,0x7a2f1f8b,0x00000000}},	//   _विपण, _ואנש, _føte, --,
   {{0x3f992208,0x3eb90088,0x7a2f008c,0x987d01fb}},	//   _bfsu_, _avst_, _gøte, lçın_,
   {{0x98a7004e,0x3ea00159,0xafdb0b41,0xdb000523}},	//   czną_, tpit_, _amøb, _hemå,
   {{0x61f7011e,0x44770070,0x850500b5,0x321a113c}},	// [4880] _faxl, _קעפל_, _روکن, _topy_,
   {{0x3ea04e89,0xae0e0035,0x3e740553,0xdddc00c7}},	//   rpit_, साधन_, käte_, _birš,
   {{0x3ea0027d,0xe803198f,0xdddc00ec,0x00000000}},	//   spit_, _शोभा_, _cirš, --,
   {{0xdca34e8a,0x6fb20035,0x0b46386a,0xd838021e}},	//   таци, _ज़िं, мнен, _jwčt_,
   {{0x8db602ce,0xa3cc0632,0x25ee0591,0x5f06010b}},	//   _осві, _लाई_, _असली_, _ўзга,
   {{0x1ddd012f,0x2cb8012e,0x9e7601cb,0x00000000}},	//   न्दत, _tvrd_, _آهست, --,
   {{0x2611046c,0x35a71163,0xda6500ad,0xafdb02ce}},	//   तानी_, _ग़ज़, راهي, _kjøp,
   {{0x7d03054e,0xa6f400af,0xb6a30023,0xb6f400ed}},	//   ænse, езиш, _thấ, езиј,
   {{0xc6f715eb,0x78ad0a78,0x6b6331e6,0xe7bf049c}},	//   дных_, ćava, _акта, _एयरप,
   {{0x6aa20036,0x00000000,0x00000000,0x00000000}},	//   mpof, --, --, --,
   {{0x994a15f4,0x6e20002d,0x00000000,0x00000000}},	//   _بلال_, _îmbu, --, --,
   {{0x61f701c2,0x69da0efa,0x224301e4,0xf3ff0183}},	//   _saxl, प्री, wijk_, rlão_,
   {{0xe29800d8,0xd8380260,0x25ae4e8b,0xdb003fd5}},	//   маў_, _dwčt_, _tefl_, _femå,
   {{0x20d706d0,0x7d031a42,0x00000000,0x00000000}},	//   tçi_, ånsk, --, --,
   {{0x22430a75,0xd01b02c4,0x00000000,0x00000000}},	//   rijk_, офа_, --, --,
   {{0x4ea711b9,0x1af40033,0x6d430079,0x20d74e8c}},	//   држа, _আপনে_, únam, rçi_,
   {{0x799a0051,0x20d7013b,0x00000000,0x00000000}},	// [4890] _oftw, sçi_, --, --,
   {{0x2489006f,0xff0400c3,0x7c3a010b,0xbd6b00c3}},	//   _hiam_, ъясн, _įtra, орее_,
   {{0x2489012f,0x644f15a2,0x224101ed,0x9f49021d}},	//   _kiam_, onci, _imhk_, ndaú_,
   {{0xdddc01c8,0x447c02b5,0xdfa7004f,0x64580132}},	//   _virš, ַנגע, _تحدي, _êxit,
   {{0xa3d4074f,0xd6c62087,0x200b4e8d,0x644f0037}},	//   स्ट_, _حق_, _inci_, inci,
   {{0x9f4200b8,0x661c01ff,0x628b000d,0x245900a2}},	//   _jaký_, örkl, _égou, rémy_,
   {{0x9f4000fb,0x1b1700c8,0x2489028b,0xe946006c}},	//   ldið_, _দেখে_, _oiam_, ٹروی,
   {{0x248901a9,0x3e7402c9,0xa25b021d,0x00000000}},	//   _niam_, räte_, drôm, --,
   {{0x9f4000fb,0xf625071d,0x23694e8e,0x3e744e8f}},	//   ndið_, едпо, _nyaj_, säte_,
   {{0xa3e24e90,0x644f09ab,0xe611004f,0x24890176}},	//   न्न_, enci, اشة_, _aiam_,
   {{0xd46a4e91,0x26110067,0x00000000,0x00000000}},	//   зине_, ताबी_, --, --,
   {{0x24890221,0x00000000,0x00000000,0x00000000}},	//   _ciam_, --, --, --,
   {{0xe72e496c,0x27ed4e92,0x24894e93,0x6b9b023c}},	//   _се_, meen_, _diam_, _mfug,
   {{0x27ed4e94,0x2c060084,0x644f4e95,0x200b027a}},	//   leen_, _सोनू_, anci, _anci_,
   {{0xafe610a9,0x50b5294d,0x42d00083,0x9f4700b8}},	//   новл, ксту, িবেশ, ěný_,
   {{0x27ed03ad,0x24890019,0x6b9b001c,0x00000000}},	//   neen_, _giam_, _nfug, --,
   {{0x6446303d,0x15f34e96,0x00000000,0x00000000}},	// [48a0] miki, _असार_, --, --,
   {{0x27ed4e97,0xd12f00b5,0xe0da0274,0x6b9b01a8}},	//   heen_, جمہ_, _ево_, _afug,
   {{0x61d7012b,0x27ed4e98,0x61ee4e99,0x59c90ec5}},	//   _אויף_, keen_, mebl, _राजर,
   {{0x64464e9a,0x248901e8,0xdb1b1111,0xae0e0fbf}},	//   niki, _xiam_, _acuñ, साहन_,
   {{0x27ed14db,0xa3e221b2,0x59f807b4,0x24840187}},	//   deen_, न्य_, деля_, íjmy_,
   {{0x61ee0a8a,0x64464e9b,0x6b9b073a,0x6486009e}},	//   nebl, hiki, _efug, _sųil,
   {{0x64464e9c,0xed5713c7,0x27ed0a8a,0x7e7e393e}},	//   kiki, _зор_, feen_, mmpp,
   {{0x27ed3ecd,0x683e0080,0xa3cc0992,0x64464e9d}},	//   geen_, līdz, _लाग_, jiki,
   {{0x64464e9e,0xc5f80080,0x24890221,0x61ee1995}},	//   diki, klēt_, _riam_, kebl,
   {{0x2c752c9a,0x61ee4910,0x682e009e,0x601800b5}},	//   råde_, jebl, _dùda, _címz,
   {{0xa3cc04aa,0x64464e9f,0x27ed4ea0,0x2489006f}},	//   _लाख_, fiki, been_, _piam_,
   {{0x27ed059c,0x64460010,0x2489006d,0x682e0211}},	//   ceen_, giki, _qiam_, _fùda,
   {{0x24894ea1,0x61ee0345,0x644f0223,0x00000000}},	//   _viam_, febl, rnci, --,
   {{0x61ee4ea2,0x00000000,0x00000000,0x00000000}},	//   gebl, --, --, --,
   {{0x2bd10953,0x248901a9,0x64462f38,0x00000000}},	//   _हाला, _tiam_, biki, --,
   {{0x24890a4e,0x63a901dd,0x64464ea3,0x7a2f0044}},	//   _uiam_, ñend, ciki, _møta,
   {{0x9df94ea4,0x9f4201ba,0xe7e23dd4,0xc2750bfe}},	// [48b0] мнат_, _taký_, क्या_, _илиј,
   {{0x04b70332,0x6b9b0382,0x61ee00e0,0x27ed01b7}},	//   _تھیں_, _sfug, cebl, zeen_,
   {{0x27ed099e,0x386603d0,0x00000000,0x00000000}},	//   yeen_, _okor_, --, --,
   {{0x27ed01b7,0x09c91e82,0x683e010b,0x00000000}},	//   xeen_, रल्य, būdi, --,
   {{0x27ed4ea5,0x9f590031,0x00000000,0x00000000}},	//   veen_, _masë_, --, --,
   {{0x7bc04ea6,0x64464ea7,0xceb202b5,0x6ad10026}},	//   _edmu, ziki, _דיך_, _समीर,
   {{0x27ed4ea8,0xed150332,0x64464ea9,0x7e600183}},	//   teen_, _جہاں_, yiki, _ímpa,
   {{0xa90400f3,0x644601d7,0xac7700b5,0xfbd80026}},	//   ابون, xiki, _سازش, _डायम,
   {{0x27ed4eaa,0x8ccd0067,0x61e5148a,0x2fb6016b}},	//   reen_, दूरो, _obhl, כּים_,
   {{0x27ed0d36,0x3866005d,0x26c302c6,0x7ae9007b}},	//   seen_, _ekor_, čjo_, _ipet,
   {{0x64464eab,0x03a60ddc,0x61ee008c,0x853c010b}},	//   tiki, кино, vebl, lbėj,
   {{0x61aa052b,0x61ee067f,0x61e50341,0x29050b3f}},	//   कर्ष, webl, _abhl, _irla_,
   {{0x386d0723,0x26cd0b4c,0x64464ccf,0xdb0907a6}},	//   mler_, queo_, riki, _ideó,
   {{0x64464eac,0x66820332,0x387f4ead,0x7ae601ff}},	//   siki, _پیپل, lmur_, _äkte,
   {{0x64464eae,0x25b60413,0xa06a029f,0x213e01a6}},	//   piki, _شهيد_, дава_, àth_,
   {{0x386d0723,0x61ee0173,0x7ae90086,0xdee60200}},	//   nler_, sebl, _opet, коби,
   {{0xc7b20779,0xa067216f,0x69c105d1,0x60dc4eaf}},	// [48c0] יבן_, тата_, _odle, strm,
   {{0x44204eb0,0x386d02c9,0xdee33537,0x69c100ce}},	//   _hoi_, hler_, рофи, _ndle,
   {{0x386d4eb1,0xf76700fd,0x387f0ce8,0xdd8f00bc}},	//   kler_, _چا_, kmur_, زون_,
   {{0xf76703c7,0x351a02b5,0x69c112e1,0x386d4eb2}},	//   _نا_, ווענ, _adle, jler_,
   {{0x44204eb3,0x386d4793,0x80e21db6,0x7c29003c}},	//   _moi_, dler_, _पहुं, _ċert,
   {{0xa3e219b7,0x44204eb4,0x386d01ae,0x7875010b}},	//   न्त_, _loi_, eler_, _išvy,
   {{0x6e43105c,0x386d4eb5,0x61e3027d,0x44204eb6}},	//   _терз, fler_, _önle, _ooi_,
   {{0x44204eb7,0x386d0bf3,0xc6f83e87,0x7c2b00a5}},	//   _noi_, gler_, ених_, ckgr,
   {{0xa3cc4eb8,0x7c2001a6,0xf76f004f,0x95ca290e}},	//   _लाज_, _iomr, ياً_, муна_,
   {{0x386d4eb9,0x6444018e,0xceb30122,0x44200037}},	//   aler_, _amii, סית_, _aoi_,
   {{0x386d1e54,0xd7ef1a24,0x44320626,0x290505e2}},	//   bler_, _ку_, _bly_, _grla_,
   {{0x44204eba,0x07a64ebb,0x6d43004f,0x386d4ebc}},	//   _coi_, _радн, únai, cler_,
   {{0xa3e2051d,0x27e64ebd,0x44204ebe,0x2bd7057c}},	//   न्ध_, _ibon_, _doi_, ण्टा,
   {{0x44204ebf,0x00000000,0x00000000,0x00000000}},	//   _eoi_, --, --, --,
   {{0x44204ec0,0x76480107,0x44322151,0x00000000}},	//   _foi_, midy, _fly_, --,
   {{0xceb40669,0xa3e20b47,0x44204ec1,0x853c00c7}},	//   yyət_, न्द_, _goi_, ybėj,
   {{0x09ca0083,0xda0200a1,0xcddb0274,0x00000000}},	// [48d0] ল্যা, लयात_, дње_, --,
   {{0xe7e20433,0x386d01d6,0x44201740,0x61e501da}},	//   क्ता_, zler_, _zoi_, _ubhl,
   {{0x7ae94ec2,0x2d874ec3,0x386d01d6,0x705508cf}},	//   _spet, äne_, yler_, _مندا,
   {{0xd0110037,0x6835219d,0x7ae90103,0x13b70831}},	//   _الح_, _káde, _ppet, _ঝাড়,
   {{0x7c2b4ec4,0x386d4eb1,0x683500fe,0x39e9195c}},	//   rkgr, vler_, _jáde, едло_,
   {{0x386d4ec5,0x27e63540,0x853c010b,0x7ae902a7}},	//   wler_, _abon_, rbėj, _vpet,
   {{0x386d4ec6,0xbd68002d,0x18694ec7,0x00000000}},	//   tler_, _арте_, наки_, --,
   {{0xb8db13a0,0x386d2386,0x387f008d,0x00000000}},	//   _अब_, uler_, umur_, --,
   {{0x386d4ec8,0x44204ec9,0x3b554eca,0x7ae9022e}},	//   rler_, _roi_, _скар, _upet,
   {{0x386d22b1,0x44204ecb,0x69c1054e,0x7c2001ba}},	//   sler_, _soi_, _udle, _zomr,
   {{0xc32914b0,0x44200133,0xb7d52087,0x386d4ecc}},	//   _צו_, _poi_, _مقاب, pler_,
   {{0x889a00a5,0xe7e201c0,0x649e013a,0x00000000}},	//   _טבעי, क्दा_, _bīib, --,
   {{0x44204ecd,0x27fd0297,0x55e5005f,0xe2974ece}},	//   _voi_, _iawn_, _болб, лая_,
   {{0x27fd048c,0x27ff06a2,0x42550ece,0xbb3a016b}},	//   _hawn_, ldun_, атст, געשי,
   {{0x44204ecf,0x7afe013a,0xd8380107,0x673b00d5}},	//   _toi_, āpti, _otčl_, lzuj,
   {{0x644400a7,0x27ff4ed0,0xc4d20319,0x62492f70}},	//   _umii, ndun_, _הגה_, ržoa,
   {{0x67294ed1,0x51ba00af,0x673b00d5,0x00000000}},	// [48e0] nyej, _пыня_, nzuj, --,
   {{0xc3330052,0x63b64ed2,0x6296011e,0x7c2023bc}},	//   _לוח_, _heyn, _iuyo, _somr,
   {{0x645d002a,0x7c2001a0,0x2bca0009,0x629608c7}},	//   érig, _pomr, елеп_, _huyo,
   {{0x61fe4ed3,0x62964ed4,0xeaba4ed5,0xeb9a1126}},	//   _hapl, _kuyo, ейд_, хид_,
   {{0x61fe4ed6,0x682e0211,0x4af84073,0x62960260}},	//   _kapl, _dùdl, телю_, _juyo,
   {{0x673b01ba,0x63b60093,0xcb0700e0,0x2ee0012f}},	//   dzuj, _leyn, ايون_, mtif_,
   {{0x76480359,0x6f044031,0x7c2003c1,0xb33b00a8}},	//   vidy, lvic, _tomr, rbçi,
   {{0x61fe02d0,0x26c20a78,0x76aa248c,0x20004ed7}},	//   _lapl, škom_, нтов_, ndii_,
   {{0xe8090907,0x76484ed8,0x2ee04ed9,0x963402ef}},	//   वाजा_, tidy, ntif_, иниц,
   {{0x14ca03ad,0xa3e21bb5,0x61fe3993,0x3e4b005f}},	//   ными_, न्स_, _napl, _gėtė_,
   {{0x63b601c2,0xb993180a,0x69da0139,0x87e64eda}},	//   _beyn, _المب, _icte, _бюле,
   {{0xd7f74edb,0x6296018c,0x6f043257,0x68fa011e}},	//   _буш_, _buyo, kvic, _istd,
   {{0x2000003e,0xfe040bc1,0x051400c8,0x74c00edf}},	//   ddii_, रयास_, ানের_, _विकृ,
   {{0x629610ce,0x6f04023a,0x9f4b0037,0x69d5027d}},	//   _duyo, dvic, _tacú_, _özet,
   {{0x61fe0430,0xa3e2193c,0xd5b80080,0x2611135e}},	//   _dapl, न्ह_, skās_, तारी_,
   {{0xddd00009,0xd34601cb,0xe7f9012f,0x50670fc5}},	//   _češi, اییه_, ्यया_, утга,
   {{0x2dcb03fa,0x629600f8,0x3da7095d,0x6f042443}},	// [48f0] ећен_, _guyo, греб, gvic,
   {{0x61fe4edc,0x443901f7,0x63b604d4,0x68fa0110}},	//   _gapl, lhs_, _zeyn, _ostd,
   {{0x2ee00ce8,0x823400d1,0xe817000c,0x6f040036}},	//   atif_, _دريا, थामा_, avic,
   {{0x3e97017e,0x66e5007c,0x69da409c,0xaed504b2}},	//   _مؤسس, _कहलक_, _acte, _комш,
   {{0x2ee04edd,0x26c20254,0x3d9501e0,0x00000000}},	//   ctif_, škoj_, _вигр, --,
   {{0x3ea91201,0x69250009,0xdd9400c7,0x00000000}},	//   mpat_, имла, _гары, --,
   {{0x27fd4ede,0x3895013a,0x6835219d,0xaad123f0}},	//   _pawn_, _kāri_, _nádc, _समकक,
   {{0x26df0036,0x00000000,0x00000000,0x00000000}},	//   ttuo_, --, --, --,
   {{0x63b600fb,0xdb260332,0xe739059d,0xa3d92501}},	//   _reyn, _پولی, теп_, ालन_,
   {{0x63b600a2,0x673b0355,0x7afb4edf,0x3ea94a49}},	//   _seyn, rzuj, _isut, ipat_,
   {{0x62961d4c,0x672901f4,0x61fe4ee0,0xdcee0139}},	//   _suyo, syej, _rapl, _izbă,
   {{0xe29a4ee1,0x61fe4ee2,0x07d801b2,0x638606c2}},	//   кам_, _sapl, _مذهب_, игна,
   {{0x61fe23c6,0x63bb0093,0x8c1a011d,0x00000000}},	//   _papl, ðuna, דורי, --,
   {{0x6f0407e5,0xdb0000ac,0x09b5016b,0x00000000}},	//   vvic, _nemý, יפֿט_, --,
   {{0x61fe0009,0x63b60159,0x216a1347,0x60264ee3}},	//   _vapl, _teyn, тиви_, адва,
   {{0x3204006a,0x44394ee4,0x62962a81,0x3db20083}},	//   śmy_, chs_, _tuyo, _চাইল,
   {{0x645d0248,0x7afb0282,0x00000000,0x00000000}},	// [4900] érie, _nsut, --, --,
   {{0x6f044ee5,0xee374ee6,0x2ee04ee7,0x7bdb4ee8}},	//   rvic, ану_, rtif_, _acuu,
   {{0x7afb39b0,0x3ea908dd,0x25dd2869,0x2ee000a2}},	//   _asut, apat_, _खानी_, stif_,
   {{0xa3d900dc,0x2ee0175d,0x00000000,0x00000000}},	//   ालय_, ptif_, --, --,
   {{0x539b00a5,0x00000000,0x00000000,0x00000000}},	//   דינו, --, --, --,
   {{0x26cd0211,0x98c62695,0x7a340284,0x7bdb030d}},	//   dreo_, асил, _bàta, _ecuu,
   {{0x7a340176,0x7afb073a,0x00000000,0x00000000}},	//   _càta, _esut, --, --,
   {{0x5886004b,0xa5d80299,0xb8fe170c,0xb8ce007c}},	//   шыла, _माहौ, _तम_, _कऽ_,
   {{0xe7e20ac4,0xfaa32a63,0x00000000,0x00000000}},	//   क्षा_, _мато, --, --,
   {{0x7ae24ee9,0xb3b00033,0x00000000,0x00000000}},	//   mtot, _কাগজ, --, --,
   {{0x0d970122,0xd82f0d8a,0x44394eea,0x7ae24eeb}},	//   יכים_, _дэ_, ths_, ltot,
   {{0xe7860012,0x66e637d7,0x62980254,0x69d81b4a}},	//   _куло, _вода, _čvor, lgve,
   {{0x7ae24eec,0x26cd4eed,0xa3d9046c,0x2c7c0098}},	//   ntot, creo_, ालब_, cíde_,
   {{0xe7f94eee,0xb7e2035d,0x05dd00a1,0x25dd0387}},	//   ्यथा_, क्रम_, _मायब, _खायी_,
   {{0x68350187,0x389500ea,0x44394eef,0x7ae20303}},	//   _háda, _pāri_, phs_, htot,
   {{0x3ea94ef0,0xdb00033b,0x5f450037,0x00000000}},	//   tpat_, _bemü, منزل, --,
   {{0xdb004ef1,0xe7f90f9f,0x63bd4ef2,0x3ea94ef3}},	// [4910] _memó, ्यता_, masn, upat_,
   {{0x3ea918b8,0x63bd0169,0x3135479c,0x59d20c03}},	//   rpat_, lasn, _геор, _सागर,
   {{0x9b951c2d,0xbe88075a,0x7c391727,0x8d6803e6}},	//   ملات, рсте_, thwr, ајца_,
   {{0xa2ce06bb,0x3ea94ef4,0x63bd4ef5,0x61f54ef6}},	//   _तिम्, ppat_, nasn, lezl,
   {{0x09df0083,0xdb0001ae,0xee873122,0xdd0100cb}},	//   _যোগা, _gemü, _выво, čuđe,
   {{0x8d77132d,0x6ca74674,0x63bd4ef7,0x7a34009e}},	//   _نازا, _враж, hasn, _pàta,
   {{0x63bd4ef8,0x2ef50095,0xd90f103b,0x261a1db9}},	//   kasn, şafı_, بیا_, बानी_,
   {{0x63bd0888,0x9b890071,0x68354ef9,0x69d80afc}},	//   jasn, _منزل_, _báda, agve,
   {{0xdb004efa,0x63bd0124,0x683501ef,0xfbd2011d}},	//   _demó, dasn, _cáda, _מתן_,
   {{0x26cd4efb,0xa2ce1db1,0x63bb008a,0x9967002d}},	//   rreo_, _तिब्, ðunn, _ктел,
   {{0x26cd011c,0xa90805f5,0xd54948d2,0x00000000}},	//   sreo_, _پينل_, упне_, --,
   {{0x63bd4efc,0x0ec702e4,0x7bd9046a,0xd7950037}},	//   gasn, _लिंड, ngwu, _الإخ,
   {{0x3a250024,0x686600fd,0x06d50831,0x00000000}},	//   _kolp_, _اپنے, _তৈরি, --,
   {{0xe2974efd,0xc6920070,0xdb1901cb,0xf3ff0132}},	//   сар_, _זאג_, gawé, boão_,
   {{0x658700d8,0x32434efe,0xaad10067,0x00000000}},	//   _тыдз, черг, _समझक, --,
   {{0xdb0012c3,0x35dd0387,0x00000000,0x00000000}},	//   _memò, _माड़, --, --,
   {{0xe7e902cb,0x63a44eff,0x00000000,0x00000000}},	// [4920] झ्या_, _ifin, --, --,
   {{0x60c90029,0x00000000,0x00000000,0x00000000}},	//   ņema, --, --, --,
   {{0xb7f9065f,0x24800107,0x7ae214a0,0x00000000}},	//   ्याम_, _khim_, wtot, --,
   {{0x7ae24f00,0x2a7e00d7,0x7ff64f01,0x00000000}},	//   ttot, _shtb_, _اسدا, --,
   {{0xa3d94f02,0xdb0001dd,0x853c010b,0x6d4305ee}},	//   ालत_, _remó, lbėt, únar,
   {{0x20020657,0x7ae24f03,0x3e360a86,0xbea300d4}},	//   _haki_, rtot, _افسر, _харк,
   {{0x20020388,0x69d84f04,0xa8a300d8,0xf41f0086}},	//   _kaki_, rgve, прык, yjä_,
   {{0x6d5702b5,0x2002004e,0x7d5700a5,0xdb000392}},	//   _הילף_, _jaki_, _הילד_, _demò,
   {{0x368a2d7a,0x20024f05,0x3b074f06,0x9f490093}},	//   лсон_, _maki_, _лето_, ndað_,
   {{0x20024f07,0x63a42dd3,0x63bd4f08,0x00000000}},	//   _laki_, _afin, wasn, --,
   {{0xe8530148,0x63bd4f09,0x61f51cbe,0x69c827b0}},	//   _کنند, tasn, vezl, _idde,
   {{0x24804f0a,0x49170122,0x20024f0b,0x161603de}},	//   _chim_, _לקבל_, _naki_, ताहर_,
   {{0x63a42a07,0xb8652ac4,0x00000000,0x00000000}},	//   _dfin, _بالو, --, --,
   {{0x63a409bd,0xe5342c4c,0x9f4b00b5,0x61e900cd}},	//   _efin, _мель, ámít_, đelo,
   {{0x63bd4f0c,0xdddc3cf1,0x20024f0d,0x25dd020d}},	//   pasn, _birž, _baki_, _खाती_,
   {{0xf485006c,0x25be011e,0x655700a5,0x290c0207}},	//   _باتی, latl_, _לבוא_, _mrda_,
   {{0x69c84f0e,0x20024f0f,0x59c80099,0x52dd0033}},	// [4930] _odde, _daki_, रणार, যবহৃ,
   {{0x290c4f10,0xdceb00a0,0x877b016b,0x20070067}},	//   _orda_, žiči, ראמי, śni_,
   {{0x5f950043,0x62870fef,0x2ca73c0d,0xacf900af}},	//   _минт, mmjo, ënd_, рнеу_,
   {{0x69c80052,0x69db4bdd,0xfbd000bf,0x644f3ec3}},	//   _adde, _नाही, فته_, nici,
   {{0xdc390484,0x7a340176,0x290c4f11,0x809f0127}},	//   għġb, _càto, _arda_, _खंडे,
   {{0x290c0a23,0x644f4f12,0x69c80176,0x8cbb00bc}},	//   _brda_, hici, _cdde, _مدرس_,
   {{0xa3d94f13,0xf1dc009a,0x3a25006d,0x644f3cae}},	//   ाला_, _बासन, _volp_, kici,
   {{0x09ca0083,0x644f4f14,0x290700b8,0x69c801a8}},	//   ল্লা, jici, rvna_, _edde,
   {{0xba550370,0x4e0d0534,0x7a340176,0x683500d5}},	//   _двај, _सफाई_, _gàto, _fádn,
   {{0x63a44f15,0x7aed4f16,0x0a6b00ed,0x44fa00ec}},	//   _sfin, çatu, _срби_, _bū_,
   {{0x24804f17,0x6e274f18,0xe5710037,0x290c02a7}},	//   _phim_, _mojb, بطة_, _grda_,
   {{0x644f02e1,0x546a00c3,0x787e0031,0xd46a12b9}},	//   gici, рамм_, tëve, риме_,
   {{0xe29a4f19,0x386901f2,0x200234eb,0x645d4a22}},	//   раг_, čard_, _raki_, éria,
   {{0xa5092217,0x20024f1a,0x6e2702c4,0x25be0312}},	//   _века_, _saki_, _nojb, catl_,
   {{0x20023d96,0xf41f03ad,0x2480006f,0x7bc900f7}},	//   _paki_, mmän_, _thim_, _odeu,
   {{0x66034f1b,0xf41f09bf,0x23600189,0xdbf200b8}},	//   _hank, lmän_, _txij_, _příz,
   {{0x3e6f006c,0xef1a18cd,0x26c24f1c,0x1ea90037}},	// [4940] yütt_, шма_, škov_, مالي_,
   {{0x66034f1d,0x7bc91417,0x20024f1e,0x2d150127}},	//   _jank, _adeu, _waki_, णमूल_,
   {{0x20024f1f,0x6835024e,0x9f4b0176,0x660333e6}},	//   _taki_, _nádo, _bacó_, _mank,
   {{0x66034f20,0x717b0052,0x44e30065,0x2aaa0610}},	//   _lank, _כניס, iñ_, атко_,
   {{0xda660133,0x7bc9001e,0xd8380254,0x683500d5}},	//   овди, _ddeu, _juče_, _pádn,
   {{0x683c02e1,0xd838011c,0x3b0d0055,0x00000000}},	//   _méde, _muče_, _dreq_, --,
   {{0x2d98231d,0x644f4f21,0x69db06bc,0xd838030a}},	//   _igre_, yici, _नारी, _luče_,
   {{0x66030a45,0x00000000,0x00000000,0x00000000}},	//   _aank, --, --, --,
   {{0x644f4f22,0xb5fc0484,0x389502d4,0x00000000}},	//   vici, loġi, _bārs_, --,
   {{0x644f004e,0x69c822ac,0x66034f23,0x6d4000a8}},	//   wici, _udde, _cank, _əman,
   {{0x66034f24,0x644f4f25,0x290c4f26,0x00000000}},	//   _dank, tici, _urda_, --,
   {{0x7c224f27,0xd6d90035,0xd8380a66,0x683c00ee}},	//   njor, szła_, _buče_, _béde,
   {{0x2d9800ea,0x67560416,0xdddc0024,0x683c4f28}},	//   _ogre_, _بخار, _birż, _céde,
   {{0x644f4df4,0x44fa0197,0x7e040266,0x38690254}},	//   sici, _tū_, रयोग_, čare_,
   {{0x69c20127,0xf43500af,0x59df0a90,0x00000000}},	//   _रजनी, _некэ, प्टर, --,
   {{0xd90400f8,0x26c20097,0x60c900ea,0x20c500ea}},	//   _یی_, škou_, ņemo, rķi_,
   {{0xdd9b2753,0x9f4b0443,0x7c224f29,0x442901ed}},	// [4950] аше_, _racó_, djor, _ioa_,
   {{0x442900e8,0xddab1129,0x26c43e05,0x9f4b00de}},	//   _hoa_, ртал_, ismo_, _sacó_,
   {{0x6aa94f2a,0x442901d7,0x2016016f,0x765a4f2b}},	//   _stef, _koa_, ácií_, inty,
   {{0x7c224f2c,0x1c0b0325,0x44294f2d,0x68351534}},	//   gjor, _सोशल_, _joa_, _rádo,
   {{0x44294f2e,0xe47c0070,0x3b093bd5,0x7d0e02b1}},	//   _moa_, בראכ, село_, _erbs,
   {{0xceb2343f,0x44294f2f,0x6f0f0036,0x52d80070}},	//   _איך_, _loa_, _ircc, קווע_,
   {{0x66034f30,0x644d00c3,0x00000000,0x00000000}},	//   _rank, _omai, --, --,
   {{0x44294f31,0x66034f32,0x59d73556,0x9f400279}},	//   _noa_, _sank, _ठाकर, ceió_,
   {{0x66034f33,0x7c3b43c3,0x61e902c4,0x00000000}},	//   _pank, _ilur, đelj, --,
   {{0x644d13e0,0x3eb901ae,0x7c2907b6,0x44294f34}},	//   _amai, _mwst_, _hoer, _aoa_,
   {{0x44290bb0,0x7c294f35,0x66034f36,0x644d02a7}},	//   _boa_, _koer, _vank, _bmai,
   {{0x44293612,0x7c294f37,0x66034f38,0xd8380207}},	//   _coa_, _joer, _wank, _puče_,
   {{0x66034f39,0x44290cb7,0x7c293796,0xa3e200b4}},	//   _tank, _doa_, _moer, न्ग_,
   {{0x683c006c,0xd838011c,0x386d29c4,0x249600d1}},	//   _véde, _vuče_, loer_, _کنيد_,
   {{0x7c3b06d3,0x3eb9001e,0x442908c8,0x55ba00a5}},	//   _olur, _awst_, _foa_, _המצו,
   {{0xd838011c,0x644d4f3a,0x386d1b54,0xe3ba3cc0}},	//   _tuče_, _gmai, noer_, _уби_,
   {{0xe7e31163,0x2fc04f3b,0x7d0e0a3c,0x00000000}},	// [4960] _गाना_, raig_, _srbs, --,
   {{0x2caa028b,0x3ea00031,0xd6bd0033,0x386d4f3c}},	//   _ptbd_, rqit_, _আমায, hoer_,
   {{0x7c2912b0,0xa06a0390,0x7c3b4f3d,0x6e930934}},	//   _boer, _гана_, _blur, رلما,
   {{0x386d1872,0x7c29379d,0xd6d9004e,0x7c3b4f3e}},	//   joer_, _coer, kuł_, _clur,
   {{0x08e60033,0x6835021d,0x6e3e0176,0x00000000}},	//   কিছু_, _cádm, phpb, --,
   {{0x38a30463,0x7c3b4f3f,0xd6d90067,0x00000000}},	//   _sıra_, _elur, duł_, --,
   {{0x7c29081c,0x7c3b06f3,0x53be06fe,0x60c80079}},	//   _foer, _flur, ्णाश, ádmh,
   {{0x971401d3,0xd6da00d4,0x8d5b00a5,0x7c3b245b}},	//   дмиц, бто_, _הכלי, _glur,
   {{0xa2ce022e,0x7a3d02d0,0x41dc0084,0xafdb03d0}},	//   _तिष्, _sète, _बांस, _imøt,
   {{0xba293655,0x44294f40,0x644d4f41,0xceb30122}},	//   _وسلم_, _soa_, _smai, עית_,
   {{0x386d4f42,0x09c8021a,0x645d2e38,0x44294f43}},	//   boer_, रणीय, ério, _poa_,
   {{0x897b02b5,0x889b0bed,0x644d0069,0x62490187}},	//   _פראצ, _הבאי, _qmai, nžov,
   {{0x44294f44,0x288b0357,0xd05000a8,0xee3f0168}},	//   _voa_, _اصلی_, _ödəy, _stým_,
   {{0xa2ce01c0,0x26c200d8,0x442900cc,0xafdb008c}},	//   _तिर्, škos_, _woa_, _kløg,
   {{0x0cd70083,0x44294f45,0xae0a000c,0xb3570594}},	//   _সন্ত, _toa_, _होइन_, تیکا_,
   {{0x644d4f46,0x656f02b1,0x7a2f0044,0x00000000}},	//   _umai, ßche, _høtt, --,
   {{0x7c294f47,0xd01000b5,0x92080228,0x00000000}},	// [4970] _roer, ھلے_, _brāļ, --,
   {{0xd3580122,0x7c294f48,0xb2bc00a5,0xe2850220}},	//   _משחק_, _soer, _המזר, _تطبی,
   {{0x7c3b4f49,0xd7dc0429,0x7c294f4a,0x7a2f01e0}},	//   _plur, _यांच, _poer, _møtt,
   {{0x645d4f4b,0x317e02b1,0x629f0c6f,0x00000000}},	//   nnsi, ütze_, _kuqo, --,
   {{0xa3e2142a,0x25dd0cc5,0x7c290244,0x386d03c4}},	//   न्ट_, _खाली_, _voer, voer_,
   {{0x200900d8,0xae0a00a1,0x7c294f4c,0x645d033b}},	//   ldai_, _होऊन_, _woer, hnsi,
   {{0x7c290136,0xbca500f8,0x2ee900fb,0x9f40008d}},	//   _toer, _آمري, ltaf_, leið_,
   {{0x77f920ab,0x7c3b4f4d,0xd6d9004e,0x645d4f4e}},	//   ्येक_, _ulur, tuł_, éril,
   {{0xfaf03d15,0x2ee90297,0x6b9b4f4f,0xd70600c3}},	//   _مثل_, ntaf_, _igug, дные_,
   {{0x62974f50,0xafdb0044,0x6d45012f,0xd6d90035}},	//   _nixo, _fløg, ozha, szło_,
   {{0x69c34f51,0x6f0d0124,0xa3d900e7,0x01e30033}},	//   mane, hvac, ालं_, য়াদ,
   {{0x69c34201,0x9f400093,0x629701f7,0x628500b5}},	//   lane, keið_, _aixo, _ahho,
   {{0x200902c7,0x7a340211,0x629701ed,0x7a2f0044}},	//   ddai_, _bàth, _bixo, _føtt,
   {{0x27ed02c9,0x2009010b,0x62850260,0x7a34009e}},	//   lfen_, edai_, _chho, _càth,
   {{0x4096097b,0xafe600d4,0x261a4f52,0x6b9b001c}},	//   драт, мовл, बारी_, _ogug,
   {{0x69c34f53,0x6d450ac8,0x62974f54,0x6b9b1e41}},	//   hane, dzha, _eixo, _ngug,
   {{0x69c34f55,0xf4130122,0x2cad0c99,0x27ed01ae}},	// [4980] kane, _יפה_, _čeda_, ifen_,
   {{0x69c34f56,0x20194f57,0x683c4f58,0xd12f006c}},	//   jane, _ensi_, _méda, دمہ_,
   {{0x621b0779,0x61fc4f59,0xd8380009,0xafdb035b}},	//   _וויק, merl, _luča_, _blød,
   {{0x61fc4f5a,0x629f0510,0x69c30260,0x3e7d0036}},	//   lerl, _yuqo, eane, bìto_,
   {{0x69c31599,0xdb0b4f5b,0xdb00016f,0x62494f5c}},	//   fane, dagó, _nemô, ržov,
   {{0x320a4f5d,0x69c34f5e,0x27ed24d9,0x7bc200a2}},	//   ndby_, gane, efen_, saou,
   {{0x26f80ca1,0x27ed3a09,0x60dc4f5f,0x7a2f0044}},	//   ्ट्र_, ffen_, nurm, _røtt,
   {{0xec160088,0x61fc4f60,0x27ed001e,0x61e9011c}},	//   _تورد, herl, gfen_, đeli,
   {{0x69c34f61,0x61fc4f62,0xa3e20311,0x60dc4f63}},	//   bane, kerl, न्छ_, hurm,
   {{0x38690a78,0x645d4f64,0x61fc0e8e,0x683c1f55}},	//   čara_, wnsi, jerl, _déda,
   {{0x7bc04f65,0x6aa008c7,0x7a3401da,0x62970069}},	//   _kemu, _humf, _ràth, _rixo,
   {{0x7bc04f66,0x6835024e,0x6aa02f10,0x60dc4f67}},	//   _jemu, _nádh, _kumf, durm,
   {{0x7bc04f68,0x645d4f69,0x61fc4f6a,0xd8380009}},	//   _memu, rnsi, ferl, _guča_,
   {{0x60dc035f,0xc5d50083,0x6aa04f6b,0x9f590523}},	//   furm, ত্বপ, _mumf, _jaså_,
   {{0xe5f70122,0xa3e7020c,0xf7080023,0x60dc008d}},	//   _חזור_, _पाप_, _hủ_, gurm,
   {{0x7bc04f6c,0x6f0d19be,0x2009010b,0x7a3d0107}},	//   _nemu, tvac, udai_, _mèta,
   {{0x61fc0723,0x69c34f6d,0x6aa0012f,0x20094f6e}},	// [4990] berl, yane, _numf, rdai_,
   {{0x61fc4f6f,0x2ca7043f,0xab5d004e,0x44394f70}},	//   cerl, índo_, _jeże, lks_,
   {{0x69c34f71,0x7bc0006c,0x2ee94f72,0x443946fe}},	//   vane, _bemu, staf_, oks_,
   {{0x44394f73,0x69c34f74,0x7bc0028b,0x09d700a1}},	//   nks_, wane, _cemu, ठल्य,
   {{0x69c34f75,0xa3e7255b,0x7bc04f76,0x44394f77}},	//   tane, _पान_, _demu, iks_,
   {{0xd3380122,0x683c0248,0xa2d7049c,0x6aa03889}},	//   ורדה_, _réda, _बिन्, _dumf,
   {{0xdb0b0082,0x27ed0723,0x3e74013c,0x7bc016f4}},	//   tagó, tfen_, rätt_, _femu,
   {{0x27ed02c9,0x44390a75,0x683c0248,0xb90700b1}},	//   ufen_, jks_, _péda, _बम_,
   {{0x27ed4f78,0x61e50097,0x9f4b0187,0xf7080019}},	//   rfen_, _ochl, _obcí_, _củ_,
   {{0x44394f79,0x7bc00129,0xd8380009,0x69c30055}},	//   eks_, _zemu, _vuča_, qane,
   {{0xc8c903c5,0x27ed01ae,0x69c14f7a,0x7bc0073a}},	//   _روشن_, pfen_, _iele, _yemu,
   {{0x69c14f7b,0x29054f7c,0x61e54f7d,0x7a340392}},	//   _hele, _isla_, _achl, _ràti,
   {{0x61fc4f7e,0x2bd000a1,0x68354f7f,0x7a340176}},	//   terl, हणता, _nádi, _sàti,
   {{0x69c100f5,0x97560122,0x60dc16c9,0x44394f80}},	//   _jele, _אינו_, turm, aks_,
   {{0x69c14f81,0x61fc4f82,0x463a0070,0xae03162b}},	//   _mele, rerl, _מעסע, रजनन_,
   {{0x44394f83,0x69c102fd,0x61fc4f84,0x1de200a1}},	//   cks_, _lele, serl, _पाहत,
   {{0x68354f85,0xdfcf017e,0x61fc1425,0x60dc1eb8}},	// [49a0] _cádi, صيل_, perl, surm,
   {{0x7bc01201,0x9f4028e9,0x69c14f86,0x2d9c177c}},	//   _semu, lgië_, _nele, øve_,
   {{0x7bc0124f,0x163602b5,0x41bb00a5,0xb6360070}},	//   _pemu, ענער_, _מציע, ערעס_,
   {{0x09c800a1,0xdd8f2087,0x3a3e00e7,0xa06a4f87}},	//   रण्य, حوم_, _sltp_, _хама_,
   {{0x2905027d,0x628e0210,0x2fc2023a,0xa3de0067}},	//   _asla_, ombo, _iekg_, _ढाई_,
   {{0xfce64f88,0x6f0600d7,0xf7080023,0x7bc0030d}},	//   _пого, _iskc, _rủ_, _wemu,
   {{0x7bc04f89,0xf1b30d85,0x645d01cb,0x44394f8a}},	//   _temu, נסה_, érik, yks_,
   {{0x69c11153,0x6aa0023c,0x00000000,0x00000000}},	//   _eele, _tumf, --, --,
   {{0x69c10332,0xc6f7021f,0x6e2e4f8b,0x8c4300c3}},	//   _fele, еных_, _kobb, _сете,
   {{0x69c14f8c,0x6e2e4f8d,0x3a06006c,0x78a1027a}},	//   _gele, _jobb, _سکتی_, _fulv,
   {{0x6e2e4f8e,0x78a1035b,0x3ea21cb3,0x06de0033}},	//   _mobb, _gulv, _lukt_, _বৈশি,
   {{0x61e50446,0xf70801a5,0x44394f8f,0xdcfc02d4}},	//   _schl, _tủ_, uks_, _agrī,
   {{0xa3e7135e,0x44394f90,0x27e64f91,0x62490009}},	//   _पाठ_, rks_, _icon_, džor,
   {{0x44394f92,0x171b0122,0x6e2e4f93,0x69c135d4}},	//   sks_, _מודע, _nobb, _xele,
   {{0x68351dad,0x2cad00cd,0x00000000,0x00000000}},	//   _sádi, _čedo_, --, --,
   {{0x4ea708a6,0x683c00a2,0x3ea24a11,0xaf340919}},	//   ержа, _médo, _bukt_, گرفت,
   {{0x63ad0297,0x63bb0093,0xfe1c021a,0x00000000}},	// [49b0] _ifan, ðunu, नांस_, --,
   {{0x6e2e0602,0xa3d9052b,0x54e407b5,0x5d674f94}},	//   _cobb, ालक_, _कमाए_, нтез,
   {{0x6e2e4f95,0xf65300c2,0x24894f96,0x660a0051}},	//   _dobb, נצע_, _kham_, _mafk,
   {{0x3ea24f97,0x447c016b,0x00000000,0x00000000}},	//   _fukt_, ִנגע, --, --,
   {{0x63ad0657,0x09e506c2,0x6f842a2d,0x00000000}},	//   _mfan, волн, _бурж, --,
   {{0x660a4f98,0x533802b5,0x25e5021a,0x9f490079}},	//   _nafk, ענגן_, ज्ञी_, nfaí_,
   {{0x18690210,0x63ad4f99,0x200b0c3a,0xecf812ea}},	//   маки_, _ofan, _kaci_, _перш_,
   {{0xe81e4f9a,0x69c14f9b,0x200b4f9c,0x248900e2}},	//   भाषा_, _wele, _jaci_, _nham_,
   {{0xdb00008a,0xdcfc0029,0x200b150c,0xfae00355}},	//   _afmæ, _izrā, _maci_, íště_,
   {{0x3b544ca7,0x63ad4f9d,0x69c1002f,0x68350097}},	//   _скур, _afan, _uele, _nádv,
   {{0xd46a02cc,0x044603ad,0x558938df,0x9f490037}},	//   дине_, венн, ьбом_, dfaí_,
   {{0x200b4f9e,0x25dd020d,0x2af5007c,0x00000000}},	//   _naci_, _खाकी_, _इहाँ_, --,
   {{0xe72e4f9f,0x66053cf4,0x24894fa0,0x66e505a1}},	//   _те_, _апла, _dham_, _рола,
   {{0xe2974fa1,0xe5a2002d,0x2d9c016f,0x7a3d0443}},	//   кая_, _киши, ľvek_, _mèto,
   {{0xe29736c9,0x200b03c6,0xa2ce2e33,0x63ad016e}},	//   тар_, _baci_, _तिक्, _ffan,
   {{0x63a9043f,0x6e2e0036,0x200b002d,0xdfd20037}},	//   ñent, _sobb, _caci_, شيط_,
   {{0x6da64fa2,0xa3e7135e,0x200b4fa3,0x00000000}},	// [49c0] виза, _पात_, _daci_, --,
   {{0x4f95002d,0x27ff01e9,0x00000000,0x00000000}},	//   урсу, heun_, --, --,
   {{0x200b4bcc,0x24890159,0x2d963e71,0x614609cc}},	//   _faci_, _yham_, трас, _рена,
   {{0x69d70391,0x7a3d0260,0x92e40033,0x644600e2}},	//   óxen, _bèto, নবী_, nhki,
   {{0x7c6514ac,0x6e2e4fa4,0x200000af,0x7d1500fd}},	//   دالل, _tobb, meii_, _erzs,
   {{0x6f0401d5,0x683c000d,0xdb0b008d,0x00000000}},	//   mwic, _pédo, ragð, --,
   {{0x98c301c8,0x7c962585,0x27e60051,0xdd1707c0}},	//   асыл, _арац, _pcon_, _päťr,
   {{0xd83802c4,0x660a2ef1,0x00000000,0x00000000}},	//   _vučo_, _safk, --, --,
   {{0xe7e30302,0xfaa60f23,0xc0530122,0x6f044fa5}},	//   _गारा_, _разо, יזה_, nwic,
   {{0x63ad002d,0x44ea027a,0x14ca0421,0x00000000}},	//   _sfan, tù_, мыми_, --,
   {{0xa3e7046c,0x24894fa6,0xd5b800ea,0x63ad033b}},	//   _पाद_, _pham_, rbā_, _pfan,
   {{0x6f0404fb,0x27ff01e9,0xa2d74fa7,0x386001ed}},	//   kwic, ceun_, _बिद्, _ñir_,
   {{0x200b0160,0x68fa0069,0x2ee000a2,0x660a0553}},	//   _raci_, _hptd, juif_, _tafk,
   {{0x7df3000c,0x200b4fa8,0xab5d009f,0x6f044fa9}},	//   _měsí, _saci_, _jeża, dwic,
   {{0x24894faa,0x63a901dd,0x6f040035,0x200b4fab}},	//   _tham_, ñens, ewic, _paci_,
   {{0x63ad0054,0x2369006f,0x44ce4fac,0xaad200b4}},	//   _ufan, _txaj_, mę_, _सिंक,
   {{0x44ce3e96,0x59b400be,0x2284013c,0x4ea42214}},	// [49d0] lę_, ुरार, söka_, арха,
   {{0xf1b7361f,0x41b70569,0x7a3d0392,0x27ff4fad}},	//   _अभिन, _अभिस, _rèto, zeun_,
   {{0x44ce4fae,0x3cd50945,0x200b0139,0x72340037}},	//   nę_, ужес, _taci_, _خريط,
   {{0x1c1d0f8a,0x6f044faf,0x3866008c,0xfbd00079}},	//   फाइल_, bwic, _njor_, قته_,
   {{0x41a722a7,0xab5d0069,0x44fa0033,0x2fc90051}},	//   _खलास, _beża, েমিক_, maag_,
   {{0x44ce3e96,0x2fc94fb0,0x3e6f4fb1,0x00000000}},	//   kę_, laag_, hütz_, --,
   {{0x44ce004e,0x27ff11ad,0xe8f50037,0x99850116}},	//   ję_, teun_, استخ, _bolš_,
   {{0xd7094fb2,0x2fc9010d,0x44ce297a,0x22584fb3}},	//   ение_, naag_, dę_, zirk_,
   {{0x27ff4fb4,0xe5a51334,0x3c5800af,0x00000000}},	//   reun_, липи, _ритэ_, --,
   {{0x9a87342d,0x7afb01a2,0x27ff0b88,0x26f300ab}},	//   _рубл, _iput, seun_, _अहीर_,
   {{0x27ff012f,0x44ce3e9a,0x38660185,0x00000000}},	//   peun_, gę_, _fjor_, --,
   {{0xc20901f3,0x999e0107,0x2fc903bc,0x68350183}},	//   _מה_, _antň_, jaag_, _pádu,
   {{0x2fc903bc,0x5a4400af,0x2e360b3e,0x00000000}},	//   daag_, _сэӂа, _kæft_, --,
   {{0x644601d2,0x387f4fb5,0x44ce2854,0x8644010b}},	//   shki, llur_, bę_, _кніж,
   {{0x213e4fb6,0x44ce004e,0x66014fb7,0xd61800b5}},	//   áth_, cę_, melk, _جتنا_,
   {{0x6f0402c9,0x00000000,0x00000000,0x00000000}},	//   twic, --, --, --,
   {{0x44204150,0x33260669,0x26cd4fb8,0x64560010}},	// [49e0] _ini_, _çox_, nseo_, _imyi,
   {{0x44324fb9,0x6f04296d,0xa2062258,0xdee30573}},	//   _hoy_, rwic, _спод, софи,
   {{0x44324fba,0x44204fbb,0x644403a6,0x629e08dd}},	//   _koy_, _kni_, _klii, _iipo,
   {{0xf7671c04,0xdd8f0125,0x0b462294,0x50db02b5}},	//   _ها_, سون_, лнен, _אקטא,
   {{0xa3e71033,0xa09b02b5,0x60c90080,0x44324fbc}},	//   _पास_, _ריכט, ņemt, _moy_,
   {{0xa2d70e6f,0x4432359a,0xf41f00c3,0x629e4fbd}},	//   _बिस्, _loy_, lmät_, _jipo,
   {{0x44204fbe,0x6601108a,0xe8151a75,0x629e023a}},	//   _oni_, delk, _दोहा_, _mipo,
   {{0x387f008a,0xc6f83e87,0x383405f2,0x44324fbf}},	//   glur_, вних_, рнир, _noy_,
   {{0x66014fc0,0xab6607b4,0x44ce0035,0x99850009}},	//   felk, _свал, wę_, _volš_,
   {{0x44204fc1,0x44ce1648,0x64443eb0,0x629e3df7}},	//   _ani_, tę_, _alii, _nipo,
   {{0x7ae24fc2,0x387f4fc3,0x6444009e,0x44324fc4}},	//   luot, blur_, _blii, _boy_,
   {{0x2b9a008f,0x44320088,0x44ce297a,0x6444009e}},	//   _gücü_, _coy_, rę_, _clii,
   {{0x44204fc5,0x44320831,0x44ce3e96,0x7ae200d8}},	//   _dni_, _doy_, sę_, nuot,
   {{0x44204fc6,0x65944fc7,0x69ca4fc8,0xe29800d8}},	//   _eni_, _калу, nafe, лаў_,
   {{0x64444fc9,0x765a4fca,0xbe05006c,0x443200a2}},	//   _flii, mity, یورٹ, _foy_,
   {{0x765a4fcb,0xa2ce00a1,0x7ae200d8,0x69ca4fcc}},	//   lity, _तिच्, kuot, hafe,
   {{0xcddb0d44,0x2fc93440,0x69ca4fcd,0x147a006c}},	// [49f0] ење_, raag_, kafe, _ججوں_,
   {{0x59e00d53,0x7ae200d8,0x629e4fce,0x7c200107}},	//   _नागर, duot, _gipo, _anmr,
   {{0x2d874fcf,0x70550118,0x44204fd0,0x9d230033}},	//   åne_, _نندا, _yni_, পন্ন_,
   {{0x6601004e,0x5b151c80,0x765a0086,0x64440211}},	//   zelk, имет, hity, _xlii,
   {{0x34c10ac4,0x3ea9347f,0x7ae200d8,0x998c00b8}},	//   _शब्द, qqat_, guot, _bodů_,
   {{0x08d507b4,0x50b82588,0x6835024e,0x69ca008e}},	//   ация, _جدید_, _nádr, gafe,
   {{0x765a0118,0x1a68006c,0x66014fd1,0x63bd010d}},	//   dity, دیلی_, velk, kbsn,
   {{0x38aa009e,0x00000000,0x00000000,0x00000000}},	//   _dùr_, --, --, --,
   {{0x7afb4fd2,0x7bcb4fd3,0x44200088,0xeab00180}},	//   _uput, magu, _rni_, _فعل_,
   {{0x44324fd4,0x7bcb4fd5,0x387f0093,0xdb020093}},	//   _soy_, lagu, slur_, mboð,
   {{0x996740b4,0x629e4fd6,0x442005ca,0xc3290d85}},	//   _стал, _ripo, _pni_, _קו_,
   {{0x7bcb4fd7,0x629e4fd8,0x2aab054e,0x66014fd9}},	//   nagu, _sipo, _køb_, selk,
   {{0xa3e704bc,0x68e34fda,0x44320083,0x660106a2}},	//   _पार_, lund, _voy_, pelk,
   {{0x7bcb1526,0x44200703,0x44320359,0x451900af}},	//   hagu, _wni_, _woy_, _ация_,
   {{0x20563b41,0x68e34fdb,0x44200099,0x7ae200d8}},	//   атар, nund, _tni_, zuot,
   {{0x44204fdc,0x645d4fdd,0x7f1a0210,0x7bcb0428}},	//   _uni_, érit, кізу_, jagu,
   {{0x7bcb4fde,0x68e34fdf,0x63a44fe0,0xdee61e31}},	// [4a00] dagu, hund, _igin, рози,
   {{0x68e34fe1,0x7ae21ac5,0x7e230274,0xa3e60387}},	//   kund, vuot, одуж, _काँप_,
   {{0x68e3007c,0x6b890036,0xcd060036,0x61e101ef}},	//   jund, _azeg, рпей, ólle,
   {{0xdee60525,0xf09f4fe2,0x68e34fe3,0x7ae2342d}},	//   _коми, _già_, dund, tuot,
   {{0x69ca4fe4,0x6b89004e,0xc5fe0033,0x63a40468}},	//   tafe, _czeg, ্ঞতা_, _mgin,
   {{0x68e34fe5,0x7ae201c8,0x63a40159,0xda6332dc}},	//   fund, ruot, _lgin, овчи,
   {{0x68e304a5,0x7bcb0ce7,0x765a00c3,0x93e60066}},	//   gund, bagu, vity, _कांच_,
   {{0xd7fa188d,0x63a44fe6,0xa2d70fd1,0xdca31b81}},	//   тук_, _ngin, _बिल्, _фати,
   {{0xf1c60380,0x09e64fe7,0x765a4fe8,0x68350037}},	//   वरान, _возн, tity, _pádr,
   {{0x63a40291,0xd8382a9f,0x7e6200a2,0x38aa0284}},	//   _agin, _muči_, éoph, _tùr_,
   {{0x24420083,0x69c804ce,0x765a4fe9,0x09b400be}},	//   _cómo_, _iede, rity, ुरीय,
   {{0x765a03ad,0x69c84fea,0x290c300c,0x15e20067}},	//   sity, _hede, _isda_, _खाकर_,
   {{0x69c84feb,0x59ba00a1,0x05260033,0xe87500b5}},	//   _kede, _उभार, মনের_, _اننگ,
   {{0x69c84fec,0x63a403cb,0x2245008a,0x7bcb4fed}},	//   _jede, _egin, ólk_, zagu,
   {{0x645d0248,0xd1380009,0x7bcb4fee,0xa2a70035}},	//   éris, ахт_, yagu, _टूर्,
   {{0xd838023a,0x78a8005f,0x63a403d0,0x683c00f6}},	//   _buči_, _mudv, _ggin, _bédi,
   {{0x78a84fef,0x69c80223,0x290c012f,0x926b021d}},	// [4a10] _ludv, _oede, _lsda_, _арна_,
   {{0x645d4ff0,0x68e30e36,0x7bcb44da,0x38690a78}},	//   lisi, yund, wagu, čari_,
   {{0x7bcb4ff1,0x6b89006c,0xdd9b0210,0x68e34ff2}},	//   tagu, _szeg, тша_, xund,
   {{0x645d4ff3,0x68e34ff4,0x69c84ff5,0x62950036}},	//   nisi, vund, _aede, lmzo,
   {{0x69c84ff6,0x68e34ff7,0xf1db045c,0x290c4ff8}},	//   _bede, wund, _बयान, _asda_,
   {{0x7bcb4ff9,0x645d4ffa,0xa9690d15,0x68e344a7}},	//   sagu, hisi, лила_, tund,
   {{0xa3e7009a,0x00000000,0x00000000,0x00000000}},	//   _पां_, --, --, --,
   {{0xb8ff057c,0xccf20122,0x69c839e1,0x645d4ffb}},	//   _ति_, _מכל_, _eede, jisi,
   {{0x63a40176,0xe7f80067,0x64b30139,0x6b800282}},	//   _rgin, ्ज़ा_, _măie, _gymg,
   {{0x69c84ffc,0x68e34ffd,0x63a40211,0x00000000}},	//   _gede, pund, _sgin, --,
   {{0x63a40176,0x645d4ffe,0xda7a0070,0x6e350051}},	//   _pgin, fisi, _ענער, _mozb,
   {{0x6aa102bf,0x645d4fff,0xafdb0044,0x69c85000}},	//   _hilf, gisi, _bløm, _zede,
   {{0xd874004f,0xe5a505ac,0x69c8027d,0x7bc91192}},	//   _بالب, _лили, _yede, _meeu,
   {{0x7bc911cc,0x683c0248,0x69c801d7,0xdb020132}},	//   _leeu, _rédi, _xede, scoç,
   {{0x6aa15001,0x64b55002,0x61432b34,0x1a9a02b5}},	//   _milf, _احتر, пера, טישע,
   {{0x44f15003,0x645d0f00,0x63a435b9,0x683c000d}},	//   má_, cisi, _ugin, _pédi,
   {{0x44f15004,0xef1a00d8,0x6aa12b28,0x20120008}},	// [4a20] lá_, ыма_, _oilf, rdyi_,
   {{0x7a3d0260,0x2d960421,0xee371368,0x00000000}},	//   _fèti, брес, бну_, --,
   {{0x44f10076,0x69c83754,0x9f5902d7,0xfca9026e}},	//   ná_, _rede, _basó_, لانو_,
   {{0xa3d8022e,0x69c80bcc,0x9f590453,0xd9e000b4}},	//   ाणि_, _sede, _casó_, नल्ट,
   {{0x69c85005,0x44f1024e,0x6aa15006,0x7ff70919}},	//   _pede, há_, _bilf, _اسپا,
   {{0x645d22a2,0x2fc017f0,0x44f10187,0x291800b5}},	//   zisi, lbig_, ká_, _árak_,
   {{0x69c85007,0xa3d81e79,0xfce30043,0x645d5008}},	//   _vede, ाणा_, _норо, yisi,
   {{0x69c83d7d,0x44f10237,0xdd8f381f,0x78a804e0}},	//   _wede, dá_, _سوق_, _vudv,
   {{0x69c85009,0x2ee0001e,0x0b46002d,0x95ca3d1a}},	//   _tede, nrif_, _унан, луна_,
   {{0x645d09ac,0x6aa1099e,0x8c3d0139,0x7bc91cb3}},	//   wisi, _gilf, _vişe, _zeeu,
   {{0xd7fa4de5,0x645d500a,0x9986500b,0x44f10183}},	//   _бул_, tisi, _الاو, gá_,
   {{0x3d003123,0x2ee0500c,0x225a264a,0x7a3d0107}},	//   _रहने_, krif_, _ampk_, _bètw,
   {{0xd7960514,0x645d500d,0x073a0071,0xafdb08c8}},	//   _الشخ, risi, _حساب_, _fløj,
   {{0x44f10097,0x76410282,0x3dca030d,0x2ee00d57}},	//   bá_, ckly, _nebw_, drif_,
   {{0x6e3515b3,0x645d2c26,0x44f12278,0xd2582659}},	//   _rozb, pisi, cá_, сця_,
   {{0x2ee0001e,0xdbf101c0,0x8c3d002d,0x645d013b}},	//   frif_, _přík, _mişc, qisi,
   {{0x94120095,0x78a20395,0x403400c3,0x6e350035}},	// [4a30] _niyə_, _miov, четс, _pozb,
   {{0xdd0402b4,0x7a3d0107,0x00000000,0x00000000}},	//   रबंध_, _tèti, --, --,
   {{0x40350384,0x9f590831,0x26c60051,0x64b30395}},	//   _денс, _pasó_, _lwoo_, _tăie,
   {{0x6aa1500e,0xbebb01f4,0xd1b800b5,0xd8380207}},	//   _silf, _rrëf, _پایا_, _kuču_,
   {{0x79813252,0xa3e70299,0xab294de5,0x44f105c9}},	//   _sylw, _पाई_, рола_, zá_,
   {{0x6ca72294,0x683c2464,0x6e350506,0x3eb90a8a}},	//   _граж, _médu, _uozb, _itst_,
   {{0x44f10132,0x7bc9500f,0x64b30160,0x6aa15010}},	//   xá_, _teeu, _măic, _vilf,
   {{0x44f1114d,0x81c100c8,0x5d541ac5,0x26df00de}},	//   vá_, ুলি_, _экст, truo_,
   {{0xb8d00e1d,0x6aa15011,0xafdb0b3e,0x2d830055}},	//   _टू_, _tilf, _pløj, _hyje_,
   {{0x44f15012,0xe81e00a1,0x8f9c0070,0xf9d40043}},	//   tá_, _मोठा_, ניזי, _ноуэ,
   {{0x386a0098,0x81c10831,0x00000000,0x00000000}},	//   úiré_, ুলা_, --, --,
   {{0x44f15013,0x78a20133,0xd838013a,0x00000000}},	//   rá_, _giov, _buču_, --,
   {{0x44f100ac,0x684200d8,0x683c5014,0x64b30139}},	//   sá_, _інша, _cédu, _băic,
   {{0x44f103e6,0x683c5015,0x3869011c,0x00000000}},	//   pá_, _dédu, čaru_, --,
   {{0x2bcc0931,0x6f1d033b,0xd6780037,0xc05a0200}},	//   ारमा, _arsc, _احنا_, арац_,
   {{0x44d50029,0x98a00129,0xa3e71db1,0xe3b20ca8}},	//   mā_, ćić_, _पाए_, _غرب_,
   {{0x44d50029,0x44c7006c,0x3ea35016,0x321315bd}},	// [4a40] lā_, lő_, _bijt_, _faxy_,
   {{0x22570037,0x3eab0147,0x00000000,0x00000000}},	//   _وليد_, _duct_, --, --,
   {{0x44d50080,0x6f1d02c9,0x8fa65017,0xe7ea060a}},	//   nā_, _ersc, _мане, _टाला_,
   {{0x984c01c0,0x09b4007e,0xb4fa016b,0x2d8300fe}},	//   věď_, ुर्य, ילער, _dyje_,
   {{0xb6055018,0x3eb90223,0x44d5013a,0x3f820225}},	//   _kršč, _gtst_, hā_, _uyku_,
   {{0x44d50080,0x248000d7,0x41bf112b,0x8c3d0139}},	//   kā_, _lkim_, ्रयस, _pişc,
   {{0x44d50ae0,0x8c4633c9,0xf84a1a24,0x7c06004f}},	//   jā_, _деве, ичий_, _وبرك,
   {{0x44d50029,0x24800221,0x44c700b5,0x47342123}},	//   dā_, _nkim_, dő_, знис,
   {{0xf0935019,0x7bc2501a,0x3a2500ee,0x466a103e}},	//   ונה_, mbou, _fnlp_, иром_,
   {{0x683c02e1,0x2480501b,0xd0130033,0xafdb008c}},	//   _rédu, _akim_, হায়_, _pløk,
   {{0xa90a2489,0x683c00f7,0x2918501c,0x44d50228}},	//   _خيال_, _sédu, _éra_, gā_,
   {{0x7bc2501d,0xd8380009,0x80b10099,0x249200cc}},	//   nbou, _puču_, _आंबे, _chym_,
   {{0xfbd30052,0x0665026b,0x61fe0036,0xe60f00e0}},	//   ותר_, _کانپ, _bbpl, رشی_,
   {{0xa3e73893,0x248001d6,0x44d500ea,0x46140d93}},	//   _पाक_, _ekim_, bā_, _روبر,
   {{0xa2d708d1,0x63b6001e,0x69da0159,0x7ae2477f}},	//   _बिक्, _ffyn, _mdte, hrot,
   {{0x80dc009a,0x7ae2501e,0x1eab33cc,0xd83800f4}},	//   _फिरे, krot, لائي_, _tuču_,
   {{0xddab07c1,0x7bc20051,0x8c3d04d4,0x69da501f}},	// [4a50] ател_, dbou, _nişa, _odte,
   {{0x291e0463,0x32551958,0x9e1500d8,0xb60502a7}},	//   _orta_, _хвор, ядзі, _gršč,
   {{0x62870a78,0x61f800a8,0x30f700b5,0x0ea7046c}},	//   mljo, _övla, _بوجھ_, _कंकड,
   {{0x3ea30051,0x7bc2213d,0x00000000,0x00000000}},	//   _wijt_, gbou, --, --,
   {{0x44c70332,0x291e5020,0x7ae25021,0x78ba03d0}},	//   ző_, _arta_, grot, _attv,
   {{0x6f0d002f,0xab5d035f,0x00000000,0x00000000}},	//   mwac, _jeżi, --, --,
   {{0xa3eb020c,0x291e5022,0x7ae20036,0x7bc200f6}},	//   मला_, _crta_, arot, bbou,
   {{0x7ae203c1,0x3d0007ba,0x44d50029,0x2bcc0099}},	//   brot, _रहते_, vā_, ारणा,
   {{0x7ae20e8f,0x2480012f,0x787e0031,0x78ba0185}},	//   crot, _rkim_, tëvr, _ettv,
   {{0x44d50080,0x44c70332,0x1dcb018d,0x24805023}},	//   tā_, tő_, िरित, _skim_,
   {{0x69c3008b,0x6f0d033b,0x62870009,0x3b1f0069}},	//   mbne, hwac, dljo, _hruq_,
   {{0x44d50029,0x78fa00a5,0xafdb03d0,0x644f0098}},	//   rā_, _לפעו, _fløi, ghci,
   {{0x44d50029,0x38b1008d,0x93435024,0xd6d90067}},	//   sā_, _hár_, еняе, była_,
   {{0x27ed5025,0xe29a0409,0x44d50029,0xe7362e2d}},	//   lgen_, саг_, pā_, _хеш_,
   {{0x20d70484,0x38b100b5,0xab5d0024,0x249200a2}},	//   għi_, _jár_, _deżi, _thym_,
   {{0x27ed5026,0x38b100f5,0x216703e6,0x7bdb030d}},	//   ngen_, _már_, чиси_, _nduu,
   {{0x27ed0b7b,0x62872997,0x38b1004f,0x2d87033b}},	// [4a60] igen_, bljo, _lár_, ünen_,
   {{0x2d9609d0,0x7bdb1138,0x64460086,0xee370274}},	//   прес, _aduu, lkki, пну_,
   {{0x38b10037,0x60265027,0x7ae20035,0x6abb0b23}},	//   _nár_, _една, wrot, _atuf,
   {{0x27ed04ce,0x64460086,0xeb9a274f,0x7bc25028}},	//   jgen_, nkki, бие_, ubou,
   {{0x2cbf0124,0x291e014c,0x7bdb073a,0x7bc240bb}},	//   _čude_, _srta_, _dduu, rbou,
   {{0x27ed3cd3,0x38b1006c,0x7bc25029,0x82d702b5}},	//   egen_, _bár_, sbou, לונג_,
   {{0xdd8600b5,0x7ae2502a,0x2bcc142a,0x26160387}},	//   _رجسٹ, srot, ारदा, _भोगी_,
   {{0x27ed293e,0x7e7e502b,0x291e502c,0x38b10037}},	//   ggen_, lopp, _vrta_, _dár_,
   {{0xab5d0035,0x68e30051,0x00000000,0x00000000}},	//   _odży, arnd, --, --,
   {{0x0f5700a5,0x683c0e8c,0x7e7e00d4,0x27ed502d}},	//   פיים_, _cédr, nopp, agen_,
   {{0x291e502e,0xa3d800e7,0x6608502f,0x628700cd}},	//   _urta_, ाणं_, redk, vljo,
   {{0x7e7e5030,0x33205031,0x6f0d0067,0x66085032}},	//   hopp, _brix_, ywac, sedk,
   {{0x62870009,0xafdb082b,0x683c00fe,0x00000000}},	//   tljo, _kløv, _fédr, --,
   {{0x64460328,0x644f02d7,0x00000000,0x00000000}},	//   akki, shci, --, --,
   {{0xd5fb0052,0xfbcc3f52,0x62870282,0x64b30139}},	//   _הפור, ाराम, rljo, _hăin,
   {{0xd4680500,0xb4d800a1,0xab5d0069,0x11f700d1}},	//   _није_, ाळी_, _geżw, _کودک_,
   {{0x44295033,0x644d01a2,0xb27503d0,0x7a3d5034}},	// [4a70] _ina_, _ilai, _олиш, _mètr,
   {{0x6f0d5035,0x644d0221,0x9f40008a,0xa3eb000c}},	//   rwac, _hlai, rfið_, मलव_,
   {{0x644d4e0a,0x4429010d,0x6abb5036,0x27ed5037}},	//   _klai, _kna_, _stuf, ygen_,
   {{0x26d9006c,0x44295038,0x60d60d85,0xc0ab00fd}},	//   ások_, _jna_, _קורא_, _پاگل_,
   {{0x44295039,0x38b1503a,0xf41f00c3,0x00000000}},	//   _mna_, _sár_, ylän_, --,
   {{0x38b1503b,0x41bf0026,0x7e7e0382,0x443b258e}},	//   _pár_, ्रिस, copp, _loq_,
   {{0x4429503c,0x27ed503d,0xe9d00934,0x6446503e}},	//   _ona_, tgen_, اغه_, ykki,
   {{0x63a90888,0xccf20d85,0x4429503f,0x38b100b5}},	//   ženj, _שכן_, _nna_, _vár_,
   {{0xf1bf0967,0x41bf1cc3,0x61fb00cd,0x64b30139}},	//   ्रान, ्रास, đulj, _căin,
   {{0x44295040,0x644d5041,0x7c3b5042,0x7aeb08dd}},	//   _ana_, _alai, _hour, mugt,
   {{0x644d4749,0x7c3b0c1f,0x240a1d13,0x27ed2de6}},	//   _blai, _kour, онни_, pgen_,
   {{0x3320105d,0x7c3b1762,0xc1c60c67,0x61c63010}},	//   _prix_, _jour, वर्ग, वर्ष,
   {{0x7c3b0c1f,0x644603ad,0x386d03d0,0x44291e11}},	//   _mour, rkki, mner_, _dna_,
   {{0x44295043,0x412a027a,0x386d5044,0x387f024b}},	//   _ena_, оого_, lner_, lour_,
   {{0x386d4409,0x7c295045,0xa3e700a1,0x32180345}},	//   oner_, _oner, _पाच_, rdry_,
   {{0x644d5046,0x7c3b5047,0x442901a2,0x33205048}},	//   _glai, _nour, _gna_, _trix_,
   {{0xee3a5049,0x386d08f3,0x7e7e038d,0x7d090009}},	// [4a80] она_, iner_, topp, _ćesa,
   {{0x442928c2,0x7c29504a,0x386d504b,0x7aeb0777}},	//   _zna_, _aner, hner_, dugt,
   {{0x44290297,0x7e7e504c,0x386d16d1,0x7c3b504d}},	//   _yna_, ropp, kner_, _bour,
   {{0x7c3b504e,0x387f02e1,0x7e7e504f,0x7aeb2a86}},	//   _cour, jour_, sopp, fugt,
   {{0x7c3b0f84,0x386d5050,0x387f00f6,0x6f1b0009}},	//   _dour, dner_, dour_, _šucv,
   {{0x386d39e1,0xf6470037,0xa6e20093,0xed5a0384}},	//   ener_, _شئ_, _æðis, _дог_,
   {{0x7c3b1691,0x7a3d0118,0x7aeb00c7,0x66da0168}},	//   _four, _pètr, augt, _mäkš,
   {{0xd6da5051,0x386d5052,0x387f5053,0x69c5008a}},	//   ото_, gner_, gour_, ðher,
   {{0x6e3c2090,0xd90e006c,0x44295054,0x644d009e}},	//   _korb, _چیت_, _rna_, _rlai,
   {{0x4429006e,0x644d5055,0xe81e0722,0x2bcc052b}},	//   _sna_, _slai, _मोरा_, ारवा,
   {{0x386d5056,0x644d5057,0x7c3b5058,0x7a3d0176}},	//   bner_, _plai, _your, _tètr,
   {{0x44290069,0x2121283e,0x6e3c5059,0x387f505a}},	//   _qna_, _rrhh_, _lorb, cour_,
   {{0x644d0af3,0x6e3c11ad,0x4429055c,0x683507c0}},	//   _vlai, _oorb, _vna_, _nády,
   {{0x6e3c505b,0x6aa80024,0x29180b0c,0x4429016e}},	//   _norb, _jidf, _áras_, _wna_,
   {{0x6aa82ea2,0x44290625,0x30a7505c,0x00000000}},	//   _midf, _tna_, драв, --,
   {{0x4429505d,0x44f8505e,0x43950d8a,0x672201a0}},	//   _una_, mé_, _пайс, _kroj,
   {{0x6e3c505f,0x44f85060,0x66185061,0x63ad36f3}},	// [4a90] _borb, lé_, _kavk, _igan,
   {{0x7c3b5062,0x3ea75063,0xb6a50023,0x7c295064}},	//   _sour, önt_, _nhậ, _sner,
   {{0x44f85065,0xa2cb01d1,0x7c3b1691,0x2d8701b4}},	//   né_, तीर्, _pour, æne_,
   {{0x386d00d5,0x7aeb5066,0x228401ff,0x9fbf00d5}},	//   xner_, tugt, sökt_, bčák_,
   {{0x6e3c0b50,0x44f85067,0x20190043,0x6722006d}},	//   _forb, hé_, _iasi_, _nroj,
   {{0x20195068,0x386d22ea,0x44f85069,0x7aeb506a}},	//   _hasi_, wner_, ké_, rugt,
   {{0x2019506b,0x387f1010,0x386d28a9,0x63ad506c}},	//   _kasi_, tour_, tner_, _ogan,
   {{0x6722376b,0x63ad506d,0x44f8506e,0x7c29506f}},	//   _broj, _ngan, dé_, _uner,
   {{0x387f00f6,0xb6a5002d,0x6d451363,0xd7060421}},	//   rour_, ниил, lyha, еные_,
   {{0x63ad2ef3,0x20195070,0x67225071,0x62850345}},	//   _agan, _lasi_, _droj, _nkho,
   {{0x20192dc4,0x44f85072,0x387f5073,0x6618008b}},	//   _oasi_, gé_, pour_, _davk,
   {{0x20192875,0xa01b022a,0x67225074,0x63ad0027}},	//   _nasi_, _skön, _froj, _cgan,
   {{0x672200c7,0x64b30160,0x64ba009f,0x00000000}},	//   _groj, _tăio, _rċie, --,
   {{0x44f8163f,0x3d000006,0x63ad0103,0xe60500c3}},	//   bé_, _रहले_, _egan, ärää,
   {{0x20190657,0x7d02006a,0x44f800f7,0x6e3c0009}},	//   _basi_, łosz, cé_, _rorb,
   {{0x20195075,0x5436006c,0x62851ba3,0x63ad0069}},	//   _casi_, _سربر, _ekho, _ggan,
   {{0x2cbf1b8d,0x6496004f,0x6b8900f8,0x2019027c}},	// [4aa0] _čuda_, ráid, _nyeg, _dasi_,
   {{0x64960037,0x6618006d,0x09e50033,0x63ad47c2}},	//   sáid, _xavk, প্তা, _zgan,
   {{0x6e3c5076,0x10a62872,0x20195077,0x09d80083}},	//   _vorb, _пион, _fasi_, সলমা,
   {{0x27ff0478,0xfbd2006c,0x2019002d,0x6b892967}},	//   jfun_, اتا_, _gasi_, _byeg,
   {{0xeb9a002d,0x98a7010b,0x764800c7,0x6b8904fb}},	//   чид_, lynė_, ykdy, _cyeg,
   {{0x44f85078,0x67220055,0xb86600f8,0xf2d3016b}},	//   yé_, _rroj, کاتو, רעג_,
   {{0x321a1b66,0x64b30139,0x44f800a2,0x00000000}},	//   _mapy_, _băim, xé_, --,
   {{0x44f85079,0x63a9507a,0x6603010d,0xb6010300}},	//   vé_, ženi, _abnk, ñánd,
   {{0xd5bd0821,0xe6662070,0x63ad0210,0xbbcc01c0}},	//   ोरंज, етно, _rgan, ारीक,
   {{0x44f8507b,0x63ad507c,0xa2d42493,0x6440507d}},	//   té_, _sgan, _बौध्, ömin,
   {{0x3a2c0176,0x44f8488c,0x00000000,0x00000000}},	//   _indp_, ué_, --, --,
   {{0x44f8507e,0xe7ea00b4,0xe73a0086,0x75330160}},	//   ré_, _टाटा_, _нее_, _şezâ,
   {{0x44f8507f,0x20195080,0xa2d409b4,0xfdf007b5}},	//   sé_, _rasi_, _बौद्, _चांस_,
   {{0x20195081,0xae0200b4,0xbebb0055,0x5bcc018d}},	//   _sasi_, र्मन_, _brën, ारुव,
   {{0x201901d2,0xdfd515eb,0xc6930070,0x9f490037}},	//   _pasi_, ковы, _גאס_, rgaí_,
   {{0x63ad262a,0x2442008d,0x8c3d0225,0x3a3e008c}},	//   _ugan, _dóms_, _pişm, _lotp_,
   {{0x02a748b9,0x20195082,0x533517d0,0x747c1804}},	// [4ab0] _пром, _vasi_, _репт, _מנהג,
   {{0xbebb0031,0x4439013c,0x20195083,0x6b890371}},	//   _frën, ljs_, _wasi_, _ryeg,
   {{0x70595084,0xbebb0c6f,0x27ff0381,0x00000000}},	//   _жанр_, _grën, yfun_, --,
   {{0x20191310,0x2d8a0b3e,0xae02111a,0x00000000}},	//   _uasi_, _dybe_, र्बन_, --,
   {{0x2fc95085,0xee3f0023,0x6d4541fa,0x7de701e0}},	//   mbag_, _buýt_, syha, _півд,
   {{0x3eaa02bf,0x2fc922fc,0xd2b80122,0xbb425086}},	//   _gibt_, lbag_, עלות_, решк,
   {{0xdd945087,0xf1b41804,0xdd1600ee,0x27ff00cc}},	//   _бары, נסק_, _päťc, tfun_,
   {{0x2fc901a2,0x00000000,0x00000000,0x00000000}},	//   nbag_, --, --, --,
   {{0x39490ae0,0xc2210084,0x6b890371,0x00000000}},	//   ņas_, मयाब_, _uyeg, --,
   {{0x9f40027a,0xa01b1366,0x00000000,0x00000000}},	//   ggiù_, _sköl, --, --,
   {{0x2ee9026e,0x57f5097b,0x27ff00d5,0x00000000}},	//   hraf_, _апет, pfun_, --,
   {{0xbebb01f4,0x2ee900d7,0xb936016b,0x00000000}},	//   _rrën, kraf_, _ברעג_, --,
   {{0x52be009a,0xae0205e7,0x321a5088,0xfe0200b4}},	//   ्ठेस, र्डन_, _papy_, र्डस_,
   {{0xdddc011c,0x2ee95089,0x2cbf02a7,0x00000000}},	//   _okrš, draf_, _čudn_, --,
   {{0xd1790044,0x00000000,0x00000000,0x00000000}},	//   есті_, --, --, --,
   {{0x2fc902b3,0x3eaa035f,0x88e30033,0x2d8a00ee}},	//   gbag_, _sibt_, _মহাক, _rybe_,
   {{0xf48704e8,0x59d10006,0x20000139,0xdfcf0c74}},	// [4ac0] _جاوی, हरार, rfii_, زيل_,
   {{0x78ab0298,0x6d1d021a,0xbebb0055,0x00000000}},	//   _ligv, फिंग_, _trën, --,
   {{0x77790024,0xdee3002d,0x00000000,0x00000000}},	//   _lxwx, лоӂи, --, --,
   {{0xee3f0023,0x0b460402,0xd6d90067,0x628e14f9}},	//   _suýt_, кнен, szły_, llbo,
   {{0x3a3e0009,0x2d8a0051,0x3eaa0118,0x00000000}},	//   _potp_, _wybe_, _tibt_, --,
   {{0xdb0912ba,0xee3f00e2,0x00000000,0x00000000}},	//   _egeï, _quýt_, --, --,
   {{0x9e630798,0x628e0051,0x00000000,0x00000000}},	//   _тврд, ilbo, --, --,
   {{0xb8140836,0x8c4301f2,0x628e508a,0xdd8f1b20}},	//   удиј, _кесе, hlbo, _ذوق_,
   {{0xae020653,0xc6f70086,0x78ab0345,0x09f6002d}},	//   र्थन_, вных_, _digv, _ачея,
   {{0x60de0009,0x8f9b0070,0x3d090066,0x95380279}},	//   _ovpm, ויפי, _सहमे_, езот_,
   {{0x39584409,0x499300b5,0xa01b0093,0x00000000}},	//   _års_, _پیٹر, _sköm, --,
   {{0x69d8508b,0x443f008a,0xae02210a,0x442d4d15}},	//   lave, ðu_, र्तन_, ñe_,
   {{0x38b8064b,0xc4580421,0x00000000,0x00000000}},	//   _hér_, тиях_, --, --,
   {{0x61bf0825,0xe2980a93,0x320507c0,0xdb0900a2}},	//   ्रेष, каў_, ýly_, énég,
   {{0x2cbf0254,0x443902a7,0x00000000,0x00000000}},	//   _čudo_, pjs_, --, --,
   {{0x38b8064b,0x69d8508c,0x2ee90b0d,0xf3ff0183}},	//   _mér_, have, traf_, mião_,
   {{0x6e2e00d7,0x69d8508d,0x2d8e033b,0xf3ff0132}},	// [4ad0] _bnbb, kave, üfen_, lião_,
   {{0x2ee9508e,0xa2b00b7a,0x1d6b0957,0x8fa40274}},	//   rraf_, ंदर्, وصاً_, рађе,
   {{0xf3ff0370,0xae020964,0x3da700d8,0xa3b70461}},	//   nião_, र्धन_, траб, _जला_,
   {{0x8c3d0d6f,0x32110c3d,0x00000000,0x00000000}},	//   _kişi, lezy_, --, --,
   {{0x81d60083,0x69d8508f,0x99850139,0x00000000}},	//   _হাত_, fave, _balş_, --,
   {{0xfe711aa6,0x69d84570,0xf41f03ad,0xae020387}},	//   _اگر_, gave, hdä_, र्दन_,
   {{0xd90f0ef2,0xdddc042a,0x08d400d8,0x78ab0a8a}},	//   تیا_, _ukrš, ацыя, _pigv,
   {{0x649d0312,0x2241240f,0xf3ff021d,0x00000000}},	//   léif, _lohk_, dião_, --,
   {{0x69d805d3,0x645601f4,0xfc6401d3,0x672d0207}},	//   bave, ëzim, _търн, _šajb,
   {{0x996707c2,0x7bd95090,0x69d80d99,0x5eeb0066}},	//   _ител, lawu, cave, _चिन्_,
   {{0xf3ff00c9,0x04461403,0xe81e00be,0x00000000}},	//   gião_, генн, _मोका_, --,
   {{0x8c3d027b,0x26d900fd,0x00000000,0x00000000}},	//   _bişi, ásos_, --, --,
   {{0x66e51e46,0x6f0700ea,0x00000000,0x00000000}},	//   _сола, nībā, --, --,
   {{0x41a52e4f,0x7bd95091,0x2cad5092,0x09e50033}},	//   _गृहस, hawu, _lied_, প্রা,
   {{0xe2975093,0x50b507be,0x09d80083,0xafe61f7c}},	//   уар_, исту, _সামা, ловл,
   {{0x3dcd0083,0x69d85094,0x8c3d002d,0x7bd901a8}},	//   _লাগল, zave, _fişi, jawu,
   {{0x7bd91872,0x7afd02b1,0x00000000,0x00000000}},	// [4ae0] dawu, _ästh, --, --,
   {{0x2bcc0567,0x5337134d,0xed5a0de9,0xbbcc0e62}},	//   ार्थ, _ענין_, ноз_, ार्क,
   {{0x2d9600af,0x61465095,0x2cad0173,0x69d85096}},	//   урас, _сена, _bied_, vave,
   {{0x7bd95097,0x3ce6016f,0xa2cb00b4,0x00000000}},	//   gawu, čov_, तीक्, --,
   {{0x38b8064b,0x69d85098,0x6e2e012f,0x20125099}},	//   _sér_, tave, _tnbb, meyi_,
   {{0x20120644,0x2ab90107,0xd37b0070,0x2476013a}},	//   leyi_, _dèb_, ערסט, kāmo_,
   {{0xdd920ef5,0xf41f0086,0x7c962408,0x6f160176}},	//   _طور_, ydä_, _брац, lwyc,
   {{0x69d8509a,0xdb020391,0x06c80033,0x64561406}},	//   save, scoñ, _শিবি, ūzij,
   {{0xd5b0004f,0xc9f600ad,0x6f0700ea,0x7bc00069}},	//   يفة_, _مساع, cībā, _ifmu,
   {{0x6aca0083,0x2489509b,0x38b800b5,0xfaa64054}},	//   _রিপো, _skam_, _tér_, _сазо,
   {{0x5fb4009a,0x2ab902d0,0xbebb0031,0x659421c3}},	//   ंखाल, _zèb_, _rrëm, рану,
   {{0x8c3d00c1,0x61bf021a,0xf3ff0183,0x00000000}},	//   _pişi, ्र्ष, rião_, --,
   {{0x6eb00174,0xf3ff0279,0x41e700d8,0x4e140084}},	//   _अंगु, sião_, ліва, ड़ाई_,
   {{0xa546006c,0xd6270274,0xf3ff0132,0x7bd93729}},	//   _مضبو, _боље_, pião_, zawu,
   {{0x64960037,0x3211189a,0x00000000,0x00000000}},	//   máin, rezy_, --, --,
   {{0x60181112,0x64960037,0x00000000,0x00000000}},	//   лося_, láin, --, --,
   {{0xe80600a1,0x2cad509c,0x93f600a8,0x2d980124}},	// [4af0] व्या_, _ried_, şəcə, _azre_,
   {{0x63a9024e,0x2cad509d,0x539c076b,0x64960405}},	//   žens, _sied_, _איחו, náin,
   {{0x2cad509e,0x7bd9313a,0x61e501a6,0x867b0319}},	//   _pied_, tawu, _idhl, ערבו,
   {{0x644f509f,0x3d053e72,0x628750a0,0x6f070228}},	//   nkci, _रहीं_, lojo, tībā,
   {{0x16140299,0x69d90084,0x290c00d7,0x649d0037}},	//   तजार_, _नजदी, _apda_, méid,
   {{0x386650a1,0x7bd950a2,0x628750a3,0xeab000d1}},	//   _amor_, sawu, nojo, سعه_,
   {{0xa3c5004e,0x7bd918f9,0x48790ea7,0x6f070029}},	//   एडा_, pawu, ксия_, sībā,
   {{0xaae70125,0xa6e550a4,0x33290211,0x644f0223}},	//   _مسئو, ажил, _orax_, jkci,
   {{0xfd100332,0x628750a5,0xb8fc07df,0x86990370}},	//   _وجہ_, kojo, _तौ_, ктот_,
   {{0x60c53dc2,0xe708004f,0x7b7407f6,0xb8db0083}},	//   _othm, اتين_, _اطفا, _অব_,
   {{0x481503fe,0x39150987,0x6f160035,0x62874886}},	//   _вмес, _خواز, zwyc, dojo,
   {{0xd46a50a6,0x61e5006b,0x332950a7,0x00000000}},	//   тиме_, _adhl, _brax_, --,
   {{0x628750a8,0xe81e0084,0xd6c303c5,0x60c550a9}},	//   fojo, _मोटा_, _امتی, _athm,
   {{0x35a5010b,0xe5a52c86,0xe29a0036,0x64960079}},	//   _калг, _кили, таг_, cáin,
   {{0x20120225,0xa06a36eb,0x649d0098,0x7643034d}},	//   teyi_, вава_, féid, _iony,
   {{0x2eb10761,0x764350aa,0x67240207,0x00000000}},	//   जदूत, _hony, _šiji, --,
   {{0x443250ab,0x764350ac,0x442050ad,0x332900de}},	// [4b00] _iny_, _kony, _iai_, _grax_,
   {{0x442050ae,0x4422022e,0x64440118,0x114a002d}},	//   _hai_, ldk_, _hoii, _апой_,
   {{0x442050af,0x76431581,0x44320176,0x00000000}},	//   _kai_, _mony, _kny_, --,
   {{0x442050b0,0x09d800c8,0x69c150b1,0x7ac60183}},	//   _jai_, _সাধা, _afle, аске,
   {{0x442050b2,0x2b1600c3,0xf1da0066,0x68e100fe}},	//   _mai_, рьер, _बजान, _avld,
   {{0x442050b3,0xae020d00,0x5eeb035d,0xf41f1ba3}},	//   _lai_, र्शन_, _चित्_, llät_,
   {{0x44320097,0x09cf0083,0x442050b4,0xfce30352}},	//   _ony_, _রাখা, _oai_, _моро,
   {{0x442050b5,0x69c10103,0x2fc002c4,0x7d0e50b6}},	//   _nai_, _efle, ncig_, _ipbs,
   {{0x04f20b52,0xa2b20b7a,0x2cb800d7,0x764350b7}},	//   _জনের_, _इंग्, _hurd_, _bony,
   {{0x44320052,0x7c2250b8,0x764350b9,0x44200298}},	//   _any_, ldor, _cony, _aai_,
   {{0x442050ba,0x7c2050bb,0x764300d1,0x628750bc}},	//   _bai_, _kamr, _dony, vojo,
   {{0x44200700,0x764300d7,0x44322e73,0x7aed003d}},	//   _cai_, _eony, _cny_, šate,
   {{0x442050bd,0x6287123c,0x7c20012f,0x443200b8}},	//   _dai_, tojo, _mamr, _dny_,
   {{0x177900d8,0x7c2050be,0xb28700d8,0x7d1c00d5}},	//   _ёсць_, _lamr, рымк, _osrs,
   {{0x442050bf,0x628750c0,0xd49b0183,0x3d0508a9}},	//   _fai_, rojo, _ири_, _रहें_,
   {{0x442050c1,0x7c2002c6,0x764350c2,0xa3d81604}},	//   _gai_, _namr, _zony, िरण_,
   {{0x7c22001e,0x628750c3,0x81d60083,0x764304fb}},	// [4b10] ddor, pojo, _হার_, _yony,
   {{0x7d01022a,0x442050c4,0xe3b00037,0x4ae0012f}},	//   _älsk, _zai_, _ترى_, _निजव,
   {{0x442050c5,0x60c550c6,0x7d1c0176,0x7c2203d0}},	//   _yai_, _uthm, _csrs, fdor,
   {{0x442050c7,0x7c2050c8,0x8c3d002d,0x3dd80298}},	//   _xai_, _camr, _nişt, _eerw_,
   {{0x7ac40202,0x26c60189,0x7c2050c9,0x69c102c9}},	//   осје, _ntoo_, _damr, _pfle,
   {{0x98e5004f,0x6f0f01ed,0xa3c900b4,0x2d8702b1}},	//   مكتو, _ipcc, _ल्स_, ünes_,
   {{0x7c220051,0x764324ad,0xf09f00e2,0x94170099}},	//   bdor, _rony, _khà_, _तसंच_,
   {{0x64960037,0x3eb950ca,0x987100c7,0x27e6169c}},	//   gáil, _kust_, _všį_, _cdon_,
   {{0x3eb90052,0x442050cb,0x764350cc,0x3b550c8a}},	//   _just_, _rai_, _pony, _укар,
   {{0x442050cd,0x3eb950ce,0x443250cf,0x6b9b01d7}},	//   _sai_, _must_, _sny_, _izug,
   {{0x671c19db,0x442050d0,0xb9950082,0x200b024e}},	//   _बैठक_, _pai_, _الاب, _obci_,
   {{0xf09f098b,0x645d00d8,0x64960037,0x764350d1}},	//   _nhà_, ūrin, cáil, _wony,
   {{0x442050d2,0x386d50d3,0x7609021d,0x47a50033}},	//   _vai_, mier_, _белг_, _গ্রী,
   {{0x386d1752,0x61461a7d,0x44220a8a,0xf77000bc}},	//   lier_, бега, sdk_, _تام_,
   {{0x4420021f,0x6f1d2cdc,0x3eb90044,0xf09f01da}},	//   _tai_, _assc, _aust_, _bhà_,
   {{0x386d50d4,0x44e30092,0xe3b2028c,0x7d1c0279}},	//   nier_, mı_, _عرب_, _rsrs,
   {{0x44e306a8,0x8fa307b0,0xf09f00f1,0x3eb101b7}},	// [4b20] lı_, зате, _dhà_, _bizt_,
   {{0x7c2050d5,0x2ee0046a,0x386d50d6,0x6d5e50d7}},	//   _samr, rsif_, hier_, tzpa,
   {{0x44e3036a,0xa3ac00b4,0x2ee02f1f,0x9f40027a}},	//   nı_, _कृत_, ssif_, ggiò_,
   {{0xaae60082,0xa3d800ab,0xa01b01ff,0xf09f009e}},	//   مستو, िरि_, _sköv, _ghà_,
   {{0x7c2201d2,0x3eb950d8,0x09cf00c8,0x386d2172}},	//   rdor, _gust_, _রাজা, dier_,
   {{0x44e301c2,0x09d800c8,0x4df550d9,0x7c2250da}},	//   kı_, _সাহা, _мяст, sdor,
   {{0x386d50db,0x8d630012,0xa3d80683,0x5e5702b5}},	//   fier_, _евре, िरा_, _פילע_,
   {{0x386d17ad,0x44e306d0,0xbebb00e5,0x00000000}},	//   gier_, dı_, _crëw, --,
   {{0x2bce02cb,0x6f0450dc,0x64960037,0x2cbf0121}},	//   _ह्या, ntic, ráil, _čudi_,
   {{0x59cf02cb,0x14ca0421,0xb8fe0033,0x6f040719}},	//   _स्पर, лыми_, _তম_, itic,
   {{0x461400b5,0x69da0080,0x386d50dd,0x44e30471}},	//   موکر, _iete, bier_, gı_,
   {{0x6f041075,0x7bc250de,0x291e2353,0x69da50df}},	//   ktic, ncou, _ista_, _hete,
   {{0x7ae40082,0x69da50e0,0x7ae250e1,0x136b2632}},	//   áith, _kete, nsot, ушни_,
   {{0x69da00da,0x44e300d0,0xe71700a5,0x3eb940bb}},	//   _jete, bı_, _לחדר_, _rust_,
   {{0x44e32c7c,0x6f04027a,0x7ea9010b,0x2ca60159}},	//   cı_, etic, _užpi, kmod_,
   {{0x6f040160,0x6f1d028b,0x3eb950e2,0x61fe0069}},	//   ftic, _pssc, _pust_, _ecpl,
   {{0x255701c2,0x2ca6010d,0x69da0051,0x645d0767}},	// [4b30] vələ_, dmod_, _oete, mhsi,
   {{0x69da50e3,0x386d0120,0x291e1c55,0xd35800a5}},	//   _nete, zier_, _osta_, _לשחק_,
   {{0xf09f50e4,0xdd9b0272,0x93780647,0x00000000}},	//   _thà_, уша_, _نصیر_, --,
   {{0x69da00b9,0x2ca650e5,0xa01b1aee,0xdda8002d}},	//   _aete, gmod_, _sjöf, стул_,
   {{0x291e0012,0x6f041116,0x705500d1,0x44e30448}},	//   _asta_, ctic, _هنگا, zı_,
   {{0x44e30723,0x291e08dd,0x25570095,0x386d0051}},	//   yı_, _bsta_, sələ_, wier_,
   {{0x386d50e6,0x6e350009,0x52b505e7,0xa8590274}},	//   tier_, _inzb, ंदुस, ијих_,
   {{0x7bc250e7,0xd6d12e36,0x25e10380,0x7658004b}},	//   ccou, وقع_, पण्ण, _alvy,
   {{0x291e2140,0x386d50e8,0x9f4000fb,0xa3d80302}},	//   _esta_, rier_, ngið_, िरस_,
   {{0x69da50e9,0x44e30463,0x386d50ea,0xa01b0093}},	//   _gete, tı_, sier_, _fjög,
   {{0xe80602cb,0xa3ac157d,0xa509095d,0xe97501cb}},	//   व्हा_, केन_, шена_, _بهاد,
   {{0x44e350eb,0x69da50ec,0x6abb002f,0x81d60033}},	//   rı_, _zete, _kuuf, _হাই_,
   {{0x44e308d2,0x69da01d6,0x55e50328,0x8c1a02b8}},	//   sı_, _yete, _долб, בורי,
   {{0x59cf05f7,0x26cd325f,0xa3d80066,0x44e30225}},	//   _स्मर, mpeo_, िरह_, pı_,
   {{0x69c311d9,0x645d0079,0x26cd02d7,0x00000000}},	//   icne, bhsi, lpeo_, --,
   {{0x6f0450ed,0x645d50ee,0xa927010b,0xafdb0044}},	//   ttic, chsi, mažė, _kløy,
   {{0x9f400093,0x672950ef,0xc61c0033,0x3b1f0024}},	// [4b40] ggið_, nvej, তারা_, _nsuq_,
   {{0xee370545,0x7bc250f0,0xa01b0e80,0x2d9650f1}},	//   ону_, wcou, _sköt, орес,
   {{0x69da50f2,0x321850f3,0x41d00311,0x09d80083}},	//   _rete, mery_, _त्यस, _সালা,
   {{0x6f040280,0x69da50f4,0x7bc202e1,0x321850f5}},	//   ptic, _sete, ucou, lery_,
   {{0x7bc202e1,0xbb4315eb,0x69da3587,0x2ca650f6}},	//   rcou, мецк, _pete, rmod_,
   {{0x2ca60168,0x1ad901c8,0x98c601f0,0x7bc250f7}},	//   smod_, сьць_, осил, scou,
   {{0x7ae250f8,0x69da1b00,0xa3ea022e,0x32180b88}},	//   ssot, _vete, मणा_, iery_,
   {{0xe8e000e8,0x69da50f9,0x6abb0103,0x98a30200}},	//   hiệp_, _wete, _fuuf, мије,
   {{0x69da50fa,0x645d01f4,0x32180cd5,0x00000000}},	//   _tete, ërim, kery_, --,
   {{0x78ba0006,0x32180096,0x93f600a8,0x393600af}},	//   _tutv, jery_, şələ, _мэес,
   {{0x291e3da6,0x680201c0,0x321850fb,0x645d50fc}},	//   _usta_, _půjč, dery_, thsi,
   {{0x2bb10299,0x2ef203bc,0xafdb0044,0x00000000}},	//   ुँचा, kryf_, _fløy, --,
   {{0x321805a6,0xafdb01e0,0x59de2135,0x00000000}},	//   fery_, _gløy, _नजार, --,
   {{0x2ef20173,0xe69304cd,0x321850fd,0x00000000}},	//   dryf_, _قلند, gery_, --,
   {{0x306b0214,0x00000000,0x00000000,0x00000000}},	//   ајан_, --, --, --,
   {{0x91cb00b8,0x62950453,0x00000000,0x00000000}},	//   _त्रै, slzo, --, --,
   {{0x321850fe,0x2a6c023a,0xdb1902b1,0x00000000}},	// [4b50] bery_, _omdb_, ubwü, --,
   {{0x551e2b22,0x9f40008d,0x2009002a,0x69ca0127}},	//   _बनाए_, rgið_, sfai_, _स्ली,
   {{0x8d6803e6,0x78a20168,0x59de0f19,0x3b1f009f}},	//   ојца_, _ohov, _नज़र, _ssuq_,
   {{0x7d0539d6,0x14b5016b,0x00000000,0x00000000}},	//   rths, פּער_, --, --,
   {{0x2cbf00cb,0xab290d46,0x00000000,0x00000000}},	//   _čudu_, сола_, --, --,
   {{0x01d90033,0xdcfb00d1,0x76b20067,0x78a200fd}},	//   _তাঁদ, _پرسش_, _słyn, _ahov,
   {{0x76b20035,0x69c3026e,0x00000000,0x00000000}},	//   _płyn, rcne, --, --,
   {{0x78a2033a,0x787e0029,0x672950ff,0x32180edf}},	//   _chov, tīva, tvej, zery_,
   {{0xf7710514,0x00000000,0x00000000,0x00000000}},	//   عاب_, --, --, --,
   {{0x67295100,0x056500c3,0x38b1023a,0xc8f90831}},	//   rvej, звон, _išrm_, _আনীত_,
   {{0x32185101,0x26cd01f2,0x67295102,0x7a7a0070}},	//   very_, speo_, svej, _פרעס,
   {{0x59cf112b,0x32185103,0x00000000,0x00000000}},	//   _स्तर, wery_, --, --,
   {{0x32183c86,0x29075104,0x8c1a00a5,0x3a25027d}},	//   tery_, ltna_, זורי, _kalp_,
   {{0x78a95105,0xaadd0e6f,0x00000000,0x00000000}},	//   lmev, नीयक, --, --,
   {{0x20562324,0x290705e2,0x10a617a3,0x32180298}},	//   птар, ntna_, зивн, rery_,
   {{0xaec613ba,0xa01b1366,0x044600af,0xd37f0207}},	//   збал, _skör, _хеин, šćak_,
   {{0x32185106,0x1f660259,0x00000000,0x00000000}},	// [4b60] pery_, чкам, --, --,
   {{0x290704c3,0xbebb0055,0x00000000,0x00000000}},	//   ktna_, _arës, --, --,
   {{0x628e025c,0xc1bb00a5,0x7af90051,0x00000000}},	//   mobo, _למיש, euwt, --,
   {{0x628e2473,0xdd8f250f,0x78a901f4,0xc50c0070}},	//   lobo, دوم_, jmev, שלאָ,
   {{0x2a6c0279,0x20070095,0x2905035f,0x29075107}},	//   _pmdb_, əni_, _aqla_, etna_,
   {{0x78a25108,0xf1be00b4,0x26c201ba,0x3a250176}},	//   _shov, ्डिन, íkom_, _calp_,
   {{0xa3ac193c,0x3a250176,0x00000000,0x00000000}},	//   केत_, _dalp_, --, --,
   {{0x24801851,0x628e0232,0x78a201e8,0x68f80523}},	//   _njim_, hobo, _qhov, ruvd,
   {{0x628e5109,0x649d510a,0xf1be012f,0x00000000}},	//   kobo, féin, ्डान, --,
   {{0x628e0118,0x649d026e,0x24920168,0x3a250183}},	//   jobo, géin, _akym_, _galp_,
   {{0x628e0273,0x1fa90387,0xd7ef0043,0x557300af}},	//   dobo, _कण्ड, _пу_, егэт,
   {{0xf8aa03fa,0x3567005f,0x00000000,0x00000000}},	//   _увек_, ярын_, --, --,
   {{0xa3be0084,0x00000000,0x00000000,0x00000000}},	//   ेड़_, --, --, --,
   {{0x628e235b,0xa5770009,0x24800118,0x67220421}},	//   gobo, _ščeć, _ejim_, _isoj,
   {{0x06b10355,0x00000000,0x00000000,0x00000000}},	//   řící_, --, --, --,
   {{0x661a17a5,0x559700a5,0xa01b01ff,0xa3d80355}},	//   letk, _מדוע_, _sjöb, िरः_,
   {{0xead700c8,0x628e2e2c,0xbebb0031,0x1eab24e7}},	// [4b70] _সম্ম, bobo, _rrës, مائي_,
   {{0x661a510b,0x037800a5,0x672d0c99,0xff5f099e}},	//   netk, _מתחת_, _šajk, _ffîn_,
   {{0xa25b00a0,0x8c3d027d,0xef1f0225,0x00000000}},	//   spôs, _ahşa, _eyüp_, --,
   {{0x69c8510c,0x3d0e07b5,0x661a02e2,0x6722080a}},	//   _afde, _ठहरे_, hetk, _osoj,
   {{0x0dcb0dbf,0x661a16b7,0x00000000,0x00000000}},	//   _губи_, ketk, --, --,
   {{0x661a510d,0x7aed0009,0x22960093,0x1de1060a}},	//   jetk, šato, tæki_, _फ़ित,
   {{0x661a219c,0x649d0079,0x67221857,0x00000000}},	//   detk, véin, _asoj, --,
   {{0xfbd30172,0x29070693,0x97d9093e,0x06c90421}},	//   _ستر_, rtna_, цьку_, огий_,
   {{0x26010953,0x628e070b,0x2907510e,0x649d07a2}},	//   _शादी_, yobo, stna_, téin,
   {{0x7ae950bc,0x2bd5012f,0x764a099e,0x00000000}},	//   _ivet, दरका, _cofy, --,
   {{0x6e27029e,0x628e510f,0xa78700d1,0x7ae90093}},	//   _majb, vobo, _کشاو, _hvet,
   {{0x6e2702c4,0x7ae90237,0xecd50026,0x68fc03d0}},	//   _lajb, _kvet, डीएफ, _årda,
   {{0x661a5110,0x649d02d7,0x446302fb,0xdd1c00ac}},	//   betk, péin, твяв, mšťa,
   {{0x6e2704c3,0x764a0297,0x661a19cd,0x27ff0d83}},	//   _najb, _gofy, cetk, lgun_,
   {{0xe2970ecf,0xe7d132ea,0x41272b5b,0x27ff5111}},	//   фар_, _सभाप, моро_, ogun_,
   {{0x27ff5112,0x628e09d6,0x10a30798,0x7ae95113}},	//   ngun_, sobo, висн, _ovet,
   {{0x628e5114,0x0323002d,0xdee30226,0x27ff01a3}},	// [4b80] pobo, _адын, коти, igun_,
   {{0x64460e46,0xe2920d93,0x649d0098,0x00000000}},	//   ljki, _جذب_, héil, --,
   {{0x7ae92174,0xdbc6007c,0x8c4600d4,0x00000000}},	//   _avet, _mööd, меже, --,
   {{0x661a5115,0xae0209b1,0xed5701e0,0x69b332b1}},	//   zetk, र्जन_, ьох_, ेखनी,
   {{0x671c19b7,0x7ae9139d,0xb5e30083,0x6e2713e9}},	//   _बैंक_, _cvet, _মানচ, _fajb,
   {{0xbe1600d1,0x6e2700c5,0x2bce00b8,0x7ae900ee}},	//   _توسع, _gajb, _ह्रा, _dvet,
   {{0x661a0332,0xdd920df3,0x247600ea,0x7ae95116}},	//   vetk, _شور_, nāms_, _evet,
   {{0x27ff5117,0x3332008c,0xada35118,0x649d0079}},	//   ggun_, _oryx_, _расл, géil,
   {{0x59cf0ac4,0xf0930122,0x2d985119,0x00000000}},	//   _स्वर, כנה_, _hyre_, --,
   {{0x6446006d,0x00000000,0x00000000,0x00000000}},	//   ejki, --, --, --,
   {{0xe01e1ea2,0x661a0fb0,0x984c0035,0x38c80105}},	//   _पसंद_, retk, jść_, _راضی_,
   {{0x6280511a,0x2d980d51,0x00000000,0x00000000}},	//   émon, _myre_, --, --,
   {{0xd62a0a26,0xe666511b,0x984c0067,0x2d9800f6}},	//   _моде_, _отко, eść_, _lyre_,
   {{0x6cfe0324,0x27e40159,0xe56f02fd,0x38a129e3}},	//   _उमंग_, lamn_, اطی_, móra_,
   {{0x6e27511c,0xfbde18da,0x2d980a8a,0x98a50160}},	//   _rajb, मराम, _nyre_, _urlă_,
   {{0x6e27511d,0x27e415ed,0x3eb814a0,0x00000000}},	//   _sajb, namn_, _airt_, --,
   {{0x44291e83,0xa2b90026,0x02a70009,0x3eb80093}},	// [4b90] _iaa_, _एंट्, _ором, _birt_,
   {{0x5ec80b52,0x44294f63,0x8009006c,0x27e40364}},	//   _লিখে, _haa_, _کردہ_, hamn_,
   {{0x7ae9041a,0x4429511e,0x649d0079,0x527401cb}},	//   _svet, _kaa_, héim, _جايز,
   {{0x4429425e,0xfbd00037,0x260e39f2,0x2d980c71}},	//   _jaa_, لته_, त्ती_, _dyre_,
   {{0x44291c55,0x644d0160,0x2d9801a2,0x6e270484}},	//   _maa_, _moai, _eyre_, _tajb,
   {{0x4429511f,0xf2d402b5,0x644d02d7,0x38a12589}},	//   _laa_, דעס_, _loai, dóra_,
   {{0xd87600e0,0x00000000,0x00000000,0x00000000}},	//   کميت_, --, --, --,
   {{0x442903be,0x644d01ed,0x260109a0,0xf8a80037}},	//   _naa_, _noai, _शाही_, وديه_,
   {{0x69ca0026,0x7c3b5120,0x7ae90036,0x2b9000d1}},	//   _स्की, _inur, _uvet, _پیوس,
   {{0x7c295121,0x7c2b0702,0x00000000,0x00000000}},	//   _haer, ldgr, --, --,
   {{0x44291d50,0x7c294280,0xa9070609,0x442b099e}},	//   _baa_, _kaer, _زبان, fdc_,
   {{0xc2090052,0x7c2b5122,0x3d07004e,0x625901da}},	//   _לה_, ndgr, _हमने_, _dìom,
   {{0x7c295123,0x4429052a,0xdbc600ab,0x644d4fb4}},	//   _maer, _daa_, _tööd, _doai,
   {{0x66f60122,0x7c29053e,0x44295124,0x443b0069}},	//   _נמצא_, _laer, _eaa_, _enq_,
   {{0x44295125,0xf99200c2,0x7c3b1620,0x60c202c4}},	//   _faa_, ָרן_, _onur, _čoms,
   {{0x387f008a,0xe3da0083,0x7c29007c,0x3eb8007a}},	//   nnur_, _থাকব, _naer, _sirt_,
   {{0x20005126,0x3f8603e6,0xa3ac004e,0xdbd90093}},	// [4ba0] rgii_, çou_, केश_, _ræðu,
   {{0x63a42c47,0x7c3b0098,0x44291855,0x7c2b0a81}},	//   _izin, _anur, _zaa_, edgr,
   {{0x44295127,0x7c2909aa,0x3eb805ee,0x7c2b0051}},	//   _yaa_, _baer, _virt_, fdgr,
   {{0x7c290297,0x3eb8509c,0x64960037,0x44290312}},	//   _caer, _wirt_, máis, _xaa_,
   {{0x7c290224,0x6496004f,0xc333016b,0x00000000}},	//   _daer, láis, ָוו_, --,
   {{0x2d98071f,0x63a4002f,0x7c2940c2,0x7c2b0345}},	//   _tyre_, _mzin, _eaer, adgr,
   {{0xada30009,0x6da30a87,0x00000000,0x00000000}},	//   _барл, _бира, --, --,
   {{0x7c29001e,0x387f008e,0x63a40103,0x3b0a5128}},	//   _gaer, gnur_, _ozin, _небо_,
   {{0x63a43772,0x00000000,0x00000000,0x00000000}},	//   _nzin, --, --, --,
   {{0x44295129,0xb60201c0,0x649d0037,0x6280512a}},	//   _saa_, _část, réim, émol,
   {{0x4429512b,0x63a4512c,0x442b0069,0x83f9512d}},	//   _paa_, _azin, tdc_, менс_,
   {{0xe78601fd,0x63a40103,0x6aba512e,0x00000000}},	//   _пуло, _bzin, _hitf, --,
   {{0x4429512f,0x442b0027,0x6aba008c,0xa3ac1746}},	//   _vaa_, rdc_, _kitf, केल_,
   {{0x44290858,0x63a41715,0x442b01ef,0x67260093}},	//   _waa_, _dzin, sdc_, ækju,
   {{0x63a443c6,0x44295130,0x6aba5131,0x30a715c0}},	//   _ezin, _taa_, _mitf, ерав,
   {{0x759b0397,0x442900e7,0x6aba0036,0x645f01f4}},	//   _מיוח, _uaa_, _litf, _ulqi,
   {{0x64960079,0x09e60033,0xf41f0421,0x7c29314a}},	// [4bb0] ráit, _নানা, meä_, _raer,
   {{0x38a1008a,0x765a010b,0x7c3b026a,0x2ee9016e}},	//   jórn_, nkty, _snur, rsaf_,
   {{0x7c290310,0x6496004f,0x61e70055,0xe821111b}},	//   _paer, cáis, majl, _मसला_,
   {{0x64960037,0x2fcb0183,0xafdb0d51,0x61e748a9}},	//   láir, _ufcg_, _snøf, lajl,
   {{0x7c2b5132,0x7c293d3e,0x09d80033,0x27ef0027}},	//   rdgr, _vaer, _সাজা, _rdgn_,
   {{0x6f0d009e,0x7c295133,0x64960079,0x50d402fd}},	//   mtac, _waer, náir, _جزیر,
   {{0x6f0d5134,0x9d183282,0x26cf0453,0xf41f0421}},	//   ltac, _порт_, _stgo_, keä_,
   {{0x61e75135,0x6f0d0284,0xa3ac007c,0x64960079}},	//   hajl, otac, केँ_, háir,
   {{0x387f5136,0x7c840009,0xd7060086,0xc6250083}},	//   rnur_, _суре, вные_, বাসা_,
   {{0x6f0d2b01,0x61e70009,0x62850207,0x00000000}},	//   itac, jajl, _njho, --,
   {{0xc9590ef5,0x63a40332,0x69ca0fcf,0x6b9b00d7}},	//   _تلاش_, _szin, _स्टी, _hyug,
   {{0x6f0d5137,0xa01b01ff,0x00000000,0x00000000}},	//   ktac, _sjön, --, --,
   {{0xa3ac22a3,0x032300d4,0xa85600a5,0x00000000}},	//   कें_, адян, _שינה_, --,
   {{0x765a5138,0x64960079,0x6b9b04e1,0xdcfc005f}},	//   ckty, gáir, _myug, _gyrė,
   {{0x26c2016f,0x4096095d,0x09e60083,0x20c70023}},	//   íkov_, врат, _নামা, _cõi_,
   {{0x20c701a5,0x3e64330b,0x645d01f4,0x7eab033b}},	//   _dõi_, _möte_, ërit, nüpf,
   {{0x6b9b006c,0x63a45139,0x00000000,0x00000000}},	// [4bc0] _nyug, _uzin, --, --,
   {{0xed5a2f44,0x3f9c0228,0x02fb016b,0x0e630f16}},	//   моз_, āvu_, _קלימ, акун,
   {{0xa06a0ecf,0xf8b30f0d,0x6f0d00f1,0xa01b0093}},	//   _жана_, ुदाय, atac, _kjöl,
   {{0xf53602b5,0x2d950f08,0x6b9b513a,0x6f0d0176}},	//   כטער_, урус, _byug, btac,
   {{0x20550d8a,0xa01b029b,0x6f0d513b,0xafdb0185}},	//   _стэр, _mjöl, ctac, _snøg,
   {{0x9f4201f4,0x239a005f,0x00000000,0x00000000}},	//   _lekë_, _iąją_, --, --,
   {{0x6b890160,0xda650c74,0xc27b076b,0x7aeb009e}},	//   _exeg, داني, ורסי, asgt,
   {{0xdca62f54,0x26170026,0x5ca60043,0xd7f00037}},	//   _раби, _बॉबी_, _рибб, حكة_,
   {{0xe3e10083,0x9f49008a,0xcb0a2149,0x799a0035}},	//   _ভালব, ngað_, _زيان_, _wytw,
   {{0x2bce08b0,0x6aba0298,0x00000000,0x00000000}},	//   हुरा, _uitf, --, --,
   {{0x4e3500c2,0x765a1875,0x61e70200,0x672d02c4}},	//   אָרן_, rkty, vajl, _šajt,
   {{0x2baf009a,0x89790070,0x99790070,0x6f0d513c}},	//   जेवा, _אָנה, _אָנפ, ytac,
   {{0xae0307b5,0x6f0d0510,0x00000000,0x00000000}},	//   _लालन_, xtac, --, --,
   {{0x175700a5,0x07a30274,0x59c608b0,0x63a0018d}},	//   _בסדר_, _тачн, रुचर, ümna,
   {{0xc693012b,0xa01b00fb,0x7ae0006d,0x645d01f4}},	//   _דאס_, _fjöl, _lwmt, ëris,
   {{0x20c70ccf,0x260e0026,0x6f0d513d,0x61e708a1}},	//   _või_, त्री_, ttac, sajl,
   {{0x53352632,0xc6250083,0x3eaa009e,0x9f49008d}},	// [4bd0] _септ, বারা_, _bhbt_, ggað_,
   {{0x6f0d513e,0x3a2c0e8f,0x3a3e0036,0x20c700ab}},	//   rtac, _nadp_, _nntp_, _tõi_,
   {{0x6f0d23d4,0x7bf915df,0xc7b900b5,0x00000000}},	//   stac, енер_, ndőr_, --,
   {{0x645d513f,0xda050653,0x00000000,0x00000000}},	//   nksi, _राहत_, --, --,
   {{0x61e50110,0x7ae00090,0x9f9d008d,0x00000000}},	//   _kehl, _cwmt, _gæði_, --,
   {{0x61e50355,0x9964007e,0x9aa50088,0x3a3e055c}},	//   _jehl, _hůře_, دمتو, _cntp_,
   {{0x645d0093,0x3a2c01ef,0xf4bd0033,0xa3e30ca1}},	//   kksi, _dadp_, _আব্ব, धरा_,
   {{0xccf20052,0x7af601c8,0x39490c0a,0xda0500dc}},	//   _לכל_, šyta, ćas_, _रावत_,
   {{0x6295006c,0x60c55056,0x7c310009,0x00000000}},	//   kozo, _luhm, ćerč, --,
   {{0xb7bd002d,0x61e50097,0x645d3c9a,0x85493bd5}},	//   deţe, _nehl, eksi, езов_,
   {{0x69c15140,0xf3e63669,0x1fb00ca4,0x00000000}},	//   _igle, лжно, _झण्ड, --,
   {{0x38850228,0xd6d90067,0x00000000,0x00000000}},	//   mēro_, zyły_, --, --,
   {{0x81d50b52,0xc87906d0,0x7ae0006d,0x61e55141}},	//   _হয়_, miş_, _xwmt, _behl,
   {{0x412a142c,0xc8790644,0x61e500ee,0x00000000}},	//   ного_, liş_, _cehl, --,
   {{0x216a224a,0x00000000,0x00000000,0x00000000}},	//   хиви_, --, --, --,
   {{0xc8790463,0x787e00ea,0x645d5142,0x91d40067}},	//   niş_, tīvi, cksi, _ब्रै,
   {{0x44225143,0xee3a5144,0x61e502bf,0x69c103ab}},	// [4be0] mek_, нна_, _fehl, _ogle,
   {{0x69c10125,0xb2262bfc,0xc87900a8,0x5d6a1bb1}},	//   _ngle, _смол, hiş_, низм_,
   {{0xf1a8000c,0xc879027d,0xdca60265,0x2d9c01b4}},	//   _गरिन, kiş_, гажи, æve_,
   {{0x44225145,0xfca9183b,0x161300b4,0x504602c4}},	//   nek_, نانو_, त्तर_, _семб,
   {{0x6d43013c,0x442201d7,0xc87910b1,0x00000000}},	//   änar, iek_, diş_, --,
   {{0x44225146,0x90e502fd,0x31e20033,0x28f800af}},	//   hek_, _حسین, _বাঁশ, векь_,
   {{0x44225147,0x645d0086,0x09e60033,0x9f420107}},	//   kek_, yksi, _নাদা, _sekè_,
   {{0x44225148,0xd6da08ce,0xb6f400ed,0x69c15149}},	//   jek_, нто_, азиј, _egle,
   {{0x205700c2,0x6e2e514a,0x59cf0026,0x3b860ea6}},	//   טיקל_, _kabb, _स्कर, _слаг,
   {{0x6e2e514b,0x91d40461,0x7c2250f1,0x09b90033}},	//   _jabb, _ब्लै, leor, ঁড়া,
   {{0x629501c0,0x4422514c,0x6e2e018e,0x00000000}},	//   vozo, fek_, _mabb, --,
   {{0x4422006c,0x6e2e514d,0x3d0708a9,0x645d0086}},	//   gek_, _labb, _हमसे_, uksi,
   {{0x645d514e,0xb8930037,0x61e50381,0x00000000}},	//   rksi, _النع, _pehl, --,
   {{0x442d0121,0xae0313ab,0x6e2e018e,0x7c22514f}},	//   že_, _लाइन_, _nabb, heor,
   {{0xd49b5150,0x44225151,0x62955152,0x27e65153}},	//   _при_, bek_, rozo, _keon_,
   {{0x442208a1,0x6e2e5154,0x4fd53ec2,0x6295248a}},	//   cek_, _aabb, ржат, sozo,
   {{0x6e2e5155,0x7c225156,0xf3ff03e6,0x62955157}},	// [4bf0] _babb, deor, lhão_, pozo,
   {{0x27e65158,0xe45f013c,0xed8b5159,0x60c54ab4}},	//   _leon_, lkö_, нсек_, _tuhm,
   {{0xf3ff0370,0xfbd60083,0x6e2e515a,0x4add0066}},	//   nhão_, _হয়ত, _dabb, _नौजव,
   {{0x7c22515b,0x69c1515c,0xe45f0421,0x00000000}},	//   geor, _sgle, nkö_, --,
   {{0x6e2e2e4b,0xab29015a,0xbb450afd,0x200b0211}},	//   _fabb, тола_, релк, _icci_,
   {{0x4422515d,0x27e91977,0xe45f0421,0x7e79016b}},	//   zek_, _žan_, hkö_, _יאָז,
   {{0x4422515e,0x32580122,0xaa5603fa,0x68450192}},	//   yek_, רסום_, рију_, инка,
   {{0x5d840082,0x7ccc06d3,0x248906fd,0x6e2e018e}},	//   _الفل, _uğra, _njam_, _zabb,
   {{0xc8790d6f,0x4422515f,0xaa070698,0x27e6053e}},	//   riş_, vek_, _مظاه, _deon_,
   {{0x69c10496,0x44225160,0xf1b500b4,0x24895161}},	//   _ugle, wek_, ंधान, _ajam_,
   {{0x44225162,0xe5a52839,0x35a55163,0xd46a0e79}},	//   tek_, рини, ранг, вине_,
   {{0x6f1d01e4,0x76b20035,0x442201b7,0x3e6401ff}},	//   _opsc, _błys, uek_, _möta_,
   {{0x44225164,0x76b2004e,0x24890118,0x66e50009}},	//   rek_, _płyt, _djam_, _тола,
   {{0x44225165,0x27e65166,0x368b262e,0x00000000}},	//   sek_, _zeon_, _ясен_, --,
   {{0x44225167,0x6f1d0009,0xc0e63e3d,0x64a610d7}},	//   pek_, _apsc, робк, _кака,
   {{0x6e2e5168,0x251a00a5,0x7cc5010b,0xe7ac0067}},	//   _sabb, _יוצא, _gėri, _चरमप,

   {{0x6e2e008a,0x00000000,0x00000000,0x00000000}},	// [4c00] _pabb, --, --, --,
   {{0x2bde25d8,0x2cbf0395,0x9dba0647,0x3e640523}},	//   मर्थ, _aiud_, نداز_, _böta_,
   {{0x2cad012f,0x6e2e0382,0x716a32a6,0xa0a61813}},	//   _bhed_, _vabb, _ранг_, _ванд,
   {{0x3d07007c,0x6e2e5169,0xe3bf0453,0x213a0176}},	//   _हमरे_, _wabb, señe_, _irph_,
   {{0x6e2e516a,0x7e60002d,0x7bc400d8,0x7c22516b}},	//   _tabb, _împo, žiuo, reor,
   {{0x7c220f1a,0xe9df0023,0xb8f40037,0x7af6010b}},	//   seor, _đúc_, مكتب, šyto,
   {{0x6f0402a8,0x672b00da,0x7c221111,0x27e602d7}},	//   luic, _asgj, peor, _peon_,
   {{0x649d516c,0x5fc60066,0x9cd7011d,0xc5f00033}},	//   néit, लखिल, _כולה_, জ্ঞা_,
   {{0x44f10484,0x76aa00c3,0xbebb0031,0x00000000}},	//   eġ_, ктов_, _rrëz, --,
   {{0xfaa6516d,0x1daa0963,0x27e617d9,0x649d000d}},	//   _тазо, _करात, _weon_, héit,
   {{0x994a0d82,0x24592491,0x76b20035,0xe45f00c3}},	//   _جلال_, гань_, _słys, tkö_,
   {{0x7d030443,0x291e0a4e,0xd4980012,0x00000000}},	//   ànsi, _ipta_, иря_, --,
   {{0x6f04516e,0x3d080099,0x38660395,0x00000000}},	//   juic, ांडे_, _ilor_, --,
   {{0x3d07004e,0x38660c99,0x2019012f,0x48fd000c}},	//   _हमले_, _hlor_, _sbsi_, रूको_,
   {{0x3866037d,0x24890183,0x00000000,0x00000000}},	//   _klor_, _tjam_, --, --,
   {{0x4e191fe0,0xc1040037,0x61e20124,0x00000000}},	//   न्नई_, توفي, _đole, --,
   {{0x6f04516f,0x2cbf0176,0x3e6401ff,0x200b00e2}},	// [4c10] guic, _riud_, _söta_, _vcci_,
   {{0x291e5170,0x644f0ce9,0x7e6000af,0x38660176}},	//   _opta_, ljci, _împl, _llor_,
   {{0x38665171,0x9f400183,0x628700cd,0x00000000}},	//   _olor_, raiá_, mnjo, --,
   {{0x6280024e,0xbd440037,0x644f00f4,0x6f043638}},	//   émov, تنمي, njci, buic,
   {{0x649d0098,0x00000000,0x00000000,0x00000000}},	//   léis, --, --, --,
   {{0xa3ac0e62,0x38665172,0x20090548,0x0dcb05c2}},	//   केट_, _alor_, lgai_, _шуми_,
   {{0xceb200c2,0x649d0037,0x20f30207,0x00000000}},	//   _מיך_, néis, nći_, --,
   {{0x200914cf,0x6c85004f,0x4c941f7c,0x38662051}},	//   ngai_, _الرم, _дисс, _clor_,
   {{0xf74900d1,0x649d5173,0xa3d6073f,0xdd380228}},	//   اجعه_, héis, ाँस_, māša,
   {{0xd4d901c8,0x38665174,0x1a6500b5,0x628700cd}},	//   льмі_, _elor_, _دیتی_, jnjo,
   {{0x628710d1,0x99350416,0x00000000,0x00000000}},	//   dnjo, _دفات, --, --,
   {{0xdd380080,0x491c1a75,0x44e300b5,0x15f30e62}},	//   nāša, _महतो_, rű_, _आयकर_,
   {{0x38a1008a,0x27ed5175,0x649d002a,0x00000000}},	//   jóri_, maen_, véit, --,
   {{0x27ed5176,0x00000000,0x00000000,0x00000000}},	//   laen_, --, --, --,
   {{0x7643006a,0x649d0312,0xa06a01d3,0x216712fa}},	//   _inny, téit, гава_, бири_,
   {{0x320c004e,0x20095177,0x00000000,0x00000000}},	//   żdy_, ggai_, --, --,
   {{0x644400a7,0x649d0037,0xaec31b50,0x628700f4}},	// [4c20] _inii, réit, збул, bnjo,
   {{0x44325178,0xf41f00c3,0x6f0412f7,0xf76700b5}},	//   _hay_, nnän_, ruic, _ہا_,
   {{0x44325179,0x61ee517a,0x5bc6004f,0x20090034}},	//   _kay_, mabl, مقال, bgai_,
   {{0xdd8f517b,0x61ee517c,0x4432517d,0x8b6a517e}},	//   رون_, labl, _jay_, лиев_,
   {{0x443201f3,0x645602e9,0xa2ce0127,0x7643073a}},	//   _may_, _moyi, _धूम्, _onny,
   {{0x523a02b5,0x649d004f,0x33200d14,0x320a0ab8}},	//   רײַנ, néir, _mpix_, ngby_,
   {{0xed570012,0x629e517f,0x38660176,0xdd3800ea}},	//   _лор_, _mkpo, _plor_, bāša,
   {{0x764318f4,0xc6f83f7f,0x44322bf9,0xb88101ba}},	//   _anny, аних_, _nay_, _šíre,
   {{0x6d5e010b,0x254e00a8,0x00000000,0x00000000}},	//   lypa, məli_, --, --,
   {{0x4432011e,0x70b400b4,0xbb3b02b5,0x7e7e5180}},	//   _aay_, ंगुल, _געמי, nipp,
   {{0x64560159,0x44325181,0xd9430d07,0xe3bf0453}},	//   _boyi, _bay_, _нефи, deña_,
   {{0x76435182,0x44325183,0x27ed0138,0x213800d5}},	//   _enny, _cay_, caen_, dvrh_,
   {{0x44320052,0x6287011c,0x74ca07df,0xa3b30035}},	//   _day_, tnjo, _संवृ, झें_,
   {{0x61ee0890,0x649d0037,0xa6b602fb,0x64440103}},	//   gabl, téis, _усещ, _enii,
   {{0x44325184,0x62875185,0xf64f00e0,0x64440a8a}},	//   _fay_, rnjo, _سئو_, _fnii,
   {{0x200900d8,0x6d5e081c,0x62875186,0x20f3022f}},	//   ugai_, dypa, snjo, rći_,
   {{0x62355187,0x61ee449a,0xe3bf1e6e,0x62874205}},	// [4c30] _депу, babl, beña_, pnjo,
   {{0x63ad03cb,0x44325188,0x518717e0,0x200901d7}},	//   _izan, _zay_, _гума, sgai_,
   {{0x254e013b,0x60195189,0x44323fbd,0x00000000}},	//   fəli_, _коня_, _yay_, --,
   {{0xac1904e7,0x4432518a,0xc1b50380,0x6e2502b1}},	//   роду_, _xay_, ंधीग, sehb,
   {{0x3de80083,0xa3ea0d53,0xdea400b5,0x00000000}},	//   _পারল, यरत_, _کیلی, --,
   {{0x6d5e0051,0x63ad392d,0xdcf40448,0x08d5195c}},	//   bypa, _mzan, _çağl, оция,
   {{0x6d5e165a,0x27ed518b,0x00000000,0x00000000}},	//   cypa, taen_, --, --,
   {{0x61ee518c,0x63ad518d,0x00000000,0x00000000}},	//   zabl, _ozan, --, --,
   {{0x44321691,0x27ed518e,0x7d030138,0x61ee1691}},	//   _ray_, raen_, ánsf, yabl,
   {{0x61ee518f,0x44325190,0x64565191,0x06960037}},	//   xabl, _say_, _soyi, ينية_,
   {{0x61ee5192,0x63ad5193,0x44320122,0xe3bf01ef}},	//   vabl, _azan, _pay_, veña_,
   {{0x29075194,0x63ad00d7,0x87b95195,0xccf20070}},	//   muna_, _bzan, _култ_, וכט_,
   {{0x29075196,0x6d5e004e,0x61ee0f00,0xd6db0d28}},	//   luna_, zypa, tabl, _сте_,
   {{0x386d0370,0x44320052,0x95cb5197,0x387f012f}},	//   lher_, _way_, _суда_, liur_,
   {{0x61ee5198,0x44320028,0x29075199,0x6456519a}},	//   rabl, _tay_, nuna_, _toyi,
   {{0xe3bf0083,0xd12f00b5,0x2055519b,0x649d0098}},	//   seña_, کمہ_, птур, séir,
   {{0x8fa3519c,0x290703be,0xa067519d,0x7e7e01ae}},	// [4c40] дате, huna_, цата_, tipp,
   {{0x2907519e,0xa3af4bdd,0x6d5e519f,0x63a401d5}},	//   kuna_, _करत_, typa, _iyin,
   {{0x29071a69,0xb5fa0070,0x629c142b,0x38a11cac}},	//   juna_, שלעכ, moro, lóru_,
   {{0x290751a0,0x6ac204bc,0x7e7e03d0,0xc50c0070}},	//   duna_, शद्र, sipp, רלאָ,
   {{0x386d003c,0x9d0a0083,0x254e00a8,0x7e7e51a1}},	//   dher_, রবেন_, rəli_, pipp,
   {{0x29070273,0x63a401d5,0x6f1651a2,0xab5d0024}},	//   funa_, _myin, mtyc, _egżo,
   {{0x290751a3,0xa3ea007c,0xed5a01e0,0x20e800af}},	//   guna_, यरा_, _тов_, nşi_,
   {{0x629c51a4,0x63a401a8,0x386d51a5,0x254e013b}},	//   horo, _oyin, gher_, qəli_,
   {{0x63a451a6,0x629c51a7,0x368a0c8d,0x2907002d}},	//   _nyin, koro, исон_, auna_,
   {{0x629c24b8,0x2ca651a8,0xda660911,0x00000000}},	//   joro, llod_, _باري, --,
   {{0x290751a9,0x63a401a8,0x63ad0c0f,0x99860841}},	//   cuna_, _ayin, _szan, _بلاو,
   {{0x386d51aa,0x6f16004e,0x63a40232,0x248d0279}},	//   cher_, ktyc, _byin, õem_,
   {{0x629c51ab,0x63a404fb,0x2ca60176,0x00000000}},	//   foro, _cyin, ilod_, --,
   {{0x59dd000c,0x629c16a3,0x672251ac,0xcfe70033}},	//   नुपर, goro, _ipoj, _ফাইন,
   {{0xc0cb1a39,0x63a4018e,0x2ca608dd,0x00000000}},	//   руге_, _eyin, klod_, --,
   {{0x200f00ab,0x765808c7,0x6280000d,0x43950746}},	//   ügi_, _hovy, émor, _найс,
   {{0x629c51ad,0x290706a2,0x63ad51ae,0x7658361e}},	// [4c50] boro, zuna_, _uzan, _kovy,
   {{0xe3bf1111,0xcddb0274,0x290751af,0x00000000}},	//   leño_, рња_, yuna_, --,
   {{0x290751b0,0x00000000,0x00000000,0x00000000}},	//   xuna_, --, --, --,
   {{0xa3af0429,0x2907306e,0x672207e7,0x69c80185}},	//   _करा_, vuna_, _opoj, _agde,
   {{0xfb270088,0x3d070006,0x386d027d,0xcfab1b20}},	//   تراپ, _हमके_, vher_, _خادم_,
   {{0xdc55006c,0x76584a69,0x5ba8010b,0x00000000}},	//   _کرسک, _novy, цкім_, --,
   {{0x386d01f3,0x6b8d00af,0xa3af007c,0xe3bf02d7}},	//   ther_, _ţigă, _करऽ_, keño_,
   {{0x629c51b1,0xbd440037,0x25ed0099,0x6e3527ee}},	//   zoro, _تنفي, _आजही_, _hazb,
   {{0x290751b2,0x386d01ae,0x629c306e,0xe3bf0453}},	//   suna_, rher_, yoro, deño_,
   {{0x386d51b3,0xdb1b0183,0x7ae9007a,0x63a404fb}},	//   sher_, _aguç, _iwet, _ryin,
   {{0x629c51b4,0x64a62681,0xe9d001b2,0x386d51b5}},	//   voro, зана, _شغل_, pher_,
   {{0x7ae951b6,0x629c51b7,0xdb00000d,0x6f160067}},	//   _kwet, woro, _symé, ytyc,
   {{0x629c51b8,0xaacb0b35,0x4acb012f,0x87040ca8}},	//   toro, ादिक, ादिव, _قبول,
   {{0xf7700e3a,0x7ae951b9,0x70b451ba,0x63a40027}},	//   _جام_, _mwet, ंग्ल, _vyin,
   {{0x629c2792,0x213e0037,0x7ae9001c,0x9f402e1a}},	//   roro, íth_, _lwet, mbié_,
   {{0x629c51bb,0x6f160088,0x3de80033,0xe3bf0453}},	//   soro, ttyc, _পাইল, ceño_,
   {{0x629c51bc,0x44200232,0x0e660036,0x7ae90069}},	// [4c60] poro, _ibi_, пкан, _nwet,
   {{0x44200097,0x6f160035,0x388500ea,0x7bc94354}},	//   _hbi_, rtyc, mēru_, _ageu,
   {{0x6f16006a,0x0c2611d0,0x7ae9073a,0x261300be}},	//   styc, змен, _awet, _दानी_,
   {{0x3d1c3ded,0x9b6a0402,0x7ae901a8,0x7e7c0051}},	//   _नहीं_, йшла_, _bwet, _wmrp,
   {{0x442051bd,0xfaa638c3,0x225a0107,0x0ef9061c}},	//   _mbi_, падо, _kopk_, _мэры_,
   {{0x6f041d22,0x8d6651be,0x4420013a,0x7ae90090}},	//   mric, _евге, _lbi_, _dwet,
   {{0x6722510d,0x7bc90211,0x6f0451bf,0xfce60c06}},	//   _spoj, _fgeu, lric, _хобо,
   {{0x442051c0,0x50be01d1,0x765851c1,0xdca31682}},	//   _nbi_, ्दिष, _sovy, _заси,
   {{0x6f0451c2,0x07f7004f,0xa01b008a,0x76580097}},	//   nric, سريع_, _kjör, _povy,
   {{0x442051c3,0x6f04066a,0xe67800d4,0x60c600ea}},	//   _abi_, iric, ійні_, _likm,
   {{0x7ae90a8d,0x442051c4,0xe3bf0138,0x6f0451c5}},	//   _zwet, _bbi_, teño_, hric,
   {{0x2b200b1c,0x6f0451c6,0x60c62b63,0x442051c7}},	//   _यहाँ_, kric, _nikm, _cbi_,
   {{0xa5f83668,0xe3bf51c8,0x6f040051,0xf7491301}},	//   _делу_, reño_, jric, _وجهه_,
   {{0xe3bf09ab,0x4420018e,0xf7bb00a5,0xa2c40274}},	//   seño_, _ebi_, _הזדמ, ељск,
   {{0x6f0451c9,0xe3bf0300,0xceb400a8,0xadeb0026}},	//   eric, peño_, ktəb_, टरसन_,
   {{0x442051ca,0x3eba0159,0x6e350355,0x30a40867}},	//   _gbi_, empt_, _sazb, ерув,
   {{0x442b14a6,0xa01b0583,0x6f0451cb,0xbfab325e}},	// [4c70] mec_, _björ, gric, стве_,
   {{0x442b51cc,0x44394f70,0x7bc90014,0x00000000}},	//   lec_, lds_, _sgeu, --,
   {{0xe3b000e0,0x7ae951cd,0x78a20121,0x6e3500b8}},	//   _لری_, _swet, _okov, _vazb,
   {{0x443951ce,0x442b51cf,0xc0ab234a,0x78a22973}},	//   nds_, nec_, _داخل_, _nkov,
   {{0x6f0401dd,0x1a650e3a,0x6e350009,0xa01b0093}},	//   cric, ویری_, _tazb, _fjör,
   {{0x442b51d0,0xbb420166,0xa01b0093,0x00000000}},	//   hec_, тешк, _gjör, --,
   {{0xdd940bbc,0x442b2240,0x261301c0,0x63a80067}},	//   _зары, kec_, _दाबी_, ędni,
   {{0x442b51d1,0xba7700d1,0x443951d2,0x673b011c}},	//   jec_, _کارت, jds_, tvuj,
   {{0x442b51d3,0x78a200d5,0xbb8505f5,0x00000000}},	//   dec_, _dkov, _غلطي, --,
   {{0x44390a45,0x442051d4,0x673b0097,0x7c2b51d5}},	//   eds_, _sbi_, rvuj, legr,
   {{0x442b0392,0xb5790086,0xff5f016e,0xa3ea00b4}},	//   fec_, ющих_, _sgîl_, यरल_,
   {{0x442b2190,0x78a2023a,0x44200118,0x225a0168}},	//   gec_, _gkov, _qbi_, _sopk_,
   {{0x087602b5,0x442000fe,0x78a909e1,0xe73800d4}},	//   _קענט_, _vbi_, mlev, _неї_,
   {{0x7c2b10d6,0x60c6419a,0x4420022e,0x6f0408b7}},	//   hegr, _sikm, _wbi_, vric,
   {{0x442b0e7d,0x3d0c004e,0xa2ce29ad,0x6f0419b8}},	//   bec_, _हमें_, _धूर्, wric,
   {{0x44200034,0x78a951d6,0x26c73339,0x388500ea}},	//   _ubi_, nlev, _hino_, mērs_,
   {{0x26c751d7,0xaec60798,0x26cf51d8,0x7c2b51d9}},	// [4c80] _kino_, дбал, _jugo_, degr,
   {{0x6fde0026,0x2fcb0069,0x6f0451da,0x26c708c7}},	//   _फ्रं, _egcg_, rric, _jino_,
   {{0x26cf0b4c,0x60c651db,0x6f04033b,0x00000000}},	//   _lugo_, _tikm, sric, --,
   {{0x26c751dc,0x7c2b0c55,0x50b60131,0x06e30083}},	//   _lino_, gegr, _існу, _মিনি,
   {{0x78a951dd,0xa01b51de,0x00000000,0x00000000}},	//   dlev, _tjör, --, --,
   {{0x78a2054e,0x26c751df,0x442b076e,0x628e51e0}},	//   _skov, _nino_, zec_, nnbo,
   {{0x443951e1,0x7c2b17a8,0x248000d7,0x628e29ca}},	//   yds_, begr, _omim_, inbo,
   {{0x290051e2,0x6c31006c,0x8b2603e6,0x78a951e3}},	//   čia_, _مہما, _одбе, glev,
   {{0x442b2d5b,0x26c70273,0x2a6c00d7,0x61fe51e4}},	//   vec_, _bino_, _tldb_, _odpl,
   {{0x443951e5,0x26cf51e6,0x26c73526,0x98ae00c1}},	//   wds_, _dugo_, _cino_, ınır_,
   {{0x26c751e7,0x78a951e8,0x7ae251e9,0x7e6000af}},	//   _dino_, blev, lpot, _împu,
   {{0x27ef008a,0x628e0d35,0x69d802c4,0x443951ea}},	//   _gegn_, enbo, lcve, uds_,
   {{0x443951eb,0x26c701d3,0x442b201b,0x7ae251ec}},	//   rds_, _fino_, rec_, npot,
   {{0x442b3384,0x26c751ed,0x31353d52,0x6d4151ee}},	//   sec_, _gino_, негр, _šlam,
   {{0x6d5800c3,0x6aaa00e9,0x00000000,0x00000000}},	//   äval, ilff, --, --,
   {{0x2480022e,0x628e0223,0x26c751ef,0x3de80033}},	//   _gmim_, anbo, _zino_, _পাগল,
   {{0x69da51f0,0xeb0d0fa9,0x7c2b51f1,0x7ae21278}},	// [4c90] _ofte, _समेत_, vegr, jpot,
   {{0x26c701f7,0x69da0069,0x78a04583,0x00000000}},	//   _xino_, _nfte, homv, --,
   {{0x8c3d01d6,0x61f500d0,0x00000000,0x00000000}},	//   _akşa, mazl, --, --,
   {{0x1ddf0c67,0x69da257c,0x1bd54073,0x6d410138}},	//   _प्रत, _afte, ходя, _álam,
   {{0x27ef0307,0x78a951f2,0x7ae24157,0xd9e60033}},	//   _regn_, vlev, gpot, _নাজম,
   {{0x26cf0010,0xdcfb00d1,0x6f0d002f,0x27ef02ce}},	//   _rugo_, _ورزش_, muac, _segn_,
   {{0x6f0d04a0,0x26cf51f3,0x26c713e5,0x78a951f4}},	//   luac, _sugo_, _rino_, tlev,
   {{0x69da51f5,0x26c751f6,0x61f5033e,0x26cf0159}},	//   _efte, _sino_, hazl, _pugo_,
   {{0x6f0d4df4,0x27ef51f7,0x78a951f8,0x26130992}},	//   nuac, _vegn_, rlev, _दादी_,
   {{0x78a951f9,0x996700c3,0x5b3402fd,0x24920345}},	//   slev, _отел, _جعفر, _sjym_,
   {{0x26c751fa,0x78a951fb,0x27ef03db,0x03e70033}},	//   _vino_, plev, _tegn_, _কাজী_,
   {{0x26cf51fc,0x6f0d51fd,0xa77551fe,0x26c751ff}},	//   _tugo_, kuac, _плеч, _wino_,
   {{0x3ea10006,0x2f2300ea,0x26dd01d5,0xe3b22402}},	//   koht_, nīgā_, _utwo_, طرح_,
   {{0xd7740fab,0x6f0d2993,0x7afb002f,0x64620035}},	//   _جامع, duac, _mvut, _świą,
   {{0x628e5200,0xe29738d2,0x6acb0d4e,0x7bdb001c}},	//   rnbo, хар_, ादुर, _ofuu,
   {{0x7bdb018e,0x00000000,0x00000000,0x00000000}},	//   _nfuu, --, --, --,
   {{0x06e30033,0x61f55201,0x2d870300,0x00000000}},	// [4ca0] _মিডি, bazl, únen_, --,
   {{0xa2d50ca1,0x337700a5,0x7bdb018e,0xee372fb8}},	//   _यंत्, _נעים_, _afuu, нну_,
   {{0x9f4203ad,0x7afb5202,0x5bba0d1f,0x0217011d}},	//   _sekä_, _avut, ेश्व, _אחים_,
   {{0xdee64f88,0x6acb1b8f,0x7ae20282,0x00000000}},	//   _поми, ादूर, tpot, --,
   {{0x7ae21269,0x29075203,0x6f0d23d4,0x80d600b4}},	//   upot, erna_, cuac, _मंडे,
   {{0x9f5202e9,0x7bdb001c,0x9b435204,0x00000000}},	//   vayè_, _efuu, انوو, --,
   {{0xdd920514,0x090301c8,0x7bdb0103,0x00000000}},	//   _صور_, гчым, _ffuu, --,
   {{0x7ae25205,0x9d1b0d85,0x61f5116d,0x69d80009}},	//   ppot, _מולט, zazl, scve,
   {{0x29070094,0x78a00f8e,0x61f50448,0x2f230228}},	//   arna_, romv, yazl, cīgā_,
   {{0xe7e00026,0x3b830de0,0xbafb00a5,0x70be02b4}},	//   _ग्रा_, _слуг, _מהמש, ्दुल,
   {{0xf76f00d1,0x65945206,0xddce0228,0x00000000}},	//   لای_, тану, _albū, --,
   {{0x7ccc0644,0x00000000,0x00000000,0x00000000}},	//   _uğru, --, --, --,
   {{0x4e10000c,0x59dd022e,0x00000000,0x00000000}},	//   ालाई_, नुवर, --, --,
   {{0x1ee7006c,0x00000000,0x00000000,0x00000000}},	//   ہوری_, --, --, --,
   {{0xe4a7275d,0x290e0069,0xe29f008a,0x64400132}},	//   _прио, nufa_, nuði_, ômic,
   {{0x6f0d2e6a,0xd49801c8,0x2ea9007c,0x00000000}},	//   tuac, _пры_, कत्त, --,
   {{0x644d5207,0x3eb802c4,0x9e074a10,0x290e02b1}},	// [4cb0] _inai, _bhrt_, ечел, hufa_,
   {{0x290e3eb0,0x443b5208,0x6f0d0719,0x29075209}},	//   kufa_, _haq_, ruac, yrna_,
   {{0x443b00da,0x62870bbc,0x26130246,0x3eaf00ea}},	//   _kaq_, mijo, _दासी_, ēgt_,
   {{0x6287520a,0xfbd00037,0x644d009e,0xf217046c}},	//   lijo, مته_, _jnai, _ताड़_,
   {{0x6f0d520b,0x201c0095,0xdd9000b5,0x1e5100b5}},	//   quac, əvi_, لوے_, _پہاڑ,
   {{0x62873262,0x2f2300ea,0x644d009e,0x52d8016b}},	//   nijo, rīgā_, _lnai, עווע_,
   {{0x644d520c,0x290e0979,0x00000000,0x00000000}},	//   _onai, gufa_, --, --,
   {{0x7e600043,0x644d01da,0x00000000,0x00000000}},	//   _împr, _nnai, --, --,
   {{0x2ba80084,0x62871ac5,0x5b152327,0x7afb04f7}},	//   _छुपा, kijo, _шмат, _uvut,
   {{0x7c3b520d,0x644d520e,0xada201ba,0xddce007e}},	//   _haur, _anai, čúva, _bobř,
   {{0x62873cf1,0x7c3b520f,0x644d009e,0x291c0bca}},	//   dijo, _kaur, _bnai, ctva_,
   {{0x7c3b0291,0xddce01c0,0x9f5200f7,0x644d111f}},	//   _jaur, _dobř, sayé_, _cnai,
   {{0x7c3b027a,0x987a02b5,0xe7c00299,0x62875210}},	//   _maur, _קאנט, शेदप, fijo,
   {{0xd2520082,0x628700d8,0x412a1470,0x16180803}},	//   جنس_, gijo, мого_, _दायर_,
   {{0x443b2c99,0x78b9006d,0xc61600a5,0x7fd60823}},	//   _faq_, _khwv, _יחסי_, візі,
   {{0x7c3b5211,0x644d1c8b,0xc00310b4,0x61e20160}},	//   _naur, _gnai, ипск, _şold,
   {{0x628711c4,0xee3a5212,0x98450029,0xb4ae0127}},	// [4cc0] bijo, мна_, dēļ_, कती_,
   {{0x62875213,0x644d009e,0x3e640282,0x00000000}},	//   cijo, _znai, _nött_, --,
   {{0x7c3b5214,0x5fa700a1,0x6fa20a44,0x68e1262d}},	//   _baur, _कुठल, _कुरू, _ntld,
   {{0x7c3b5215,0x81d90083,0xb5090a40,0xfb8a0336}},	//   _caur, ারণ_, _विनय_, мбек_,
   {{0x7c3b5216,0x6a6f0b3e,0x00000000,0x00000000}},	//   _daur, _søfa, --, --,
   {{0xe18904e8,0x291c3a8c,0x290e5217,0xc33300a5}},	//   _آئین_, ttva_, tufa_, יוד_,
   {{0x6e3c5218,0x3e6401ff,0x00000000,0x00000000}},	//   _iarb, _dött_, --, --,
   {{0x62873262,0x7c3b5219,0x290e003c,0x291c006c}},	//   zijo, _gaur, rufa_, rtva_,
   {{0x291c1851,0x3e640523,0x644d0211,0x78870260}},	//   stva_, _fött_, _rnai, _sèvè,
   {{0x644d521a,0xb9080083,0x443b2c42,0x7c3b521b}},	//   _snai, _বি_, _saq_, _zaur,
   {{0xa96a1aa6,0xb7bd002d,0xd82f09eb,0x443b521c}},	//   _تمام_, deţu, _кэ_, _paq_,
   {{0x70be051d,0x7c22521d,0x62871047,0x6e3c521e}},	//   ्दोल, nfor, wijo, _larb,
   {{0x628700d8,0x63b6004e,0xa3e2004e,0x7c2201ef}},	//   tijo, _czyn, धड़_, ifor,
   {{0x867301e0,0x3e64017b,0x00000000,0x00000000}},	//   _кліє, _möts_, --, --,
   {{0x628701c8,0x236d016f,0x7c22521f,0x9f4b01ba}},	//   rijo, šej_, kfor, _vecí_,
   {{0x628701c8,0x6e3c0298,0x6d410037,0x644d5220}},	//   sijo, _aarb, _álai, _unai,
   {{0xdef84fa1,0x62871023,0x7c3b0139,0x6e3c11f0}},	// [4cd0] вых_, pijo, _raur, _barb,
   {{0x63ad5221,0x7c225222,0x6e3c449a,0xa3df000c}},	//   _iyan, efor, _carb, दुर_,
   {{0x6e3c5223,0x7c225224,0x7c3b5225,0x63ad00d1}},	//   _darb, ffor, _paur, _hyan,
   {{0x7c225226,0x6e3c00f1,0x63ad01a8,0x6acb2483}},	//   gfor, _earb, _kyan, ाद्र,
   {{0x6e3c5227,0x20195228,0x4ea75229,0x2613007c}},	//   _farb, _icsi_, _арва, _दाली_,
   {{0x63ad522a,0xb0d20066,0x6e3c522b,0x39450211}},	//   _myan, _दूँग, _garb, _prls_,
   {{0x7c3b0a09,0x7c22522c,0x63ad522d,0x6aa3096d}},	//   _taur, bfor, _lyan, ronf,
   {{0x81d90b52,0x6a740176,0x6285009e,0x63ad522e}},	//   ারি_, _ràfe, _lmho, _oyan,
   {{0x63ad522f,0x62850a75,0x7c8410be,0xe29f0093}},	//   _nyan, _omho, _туре, luðu_,
   {{0x3d0802cb,0x6e3c007a,0xdb00008c,0x00000000}},	//   ांचे_, _xarb, _bymæ, --,
   {{0x63ad5230,0x81d90083,0x4e360070,0xb0d20067}},	//   _ayan, ারা_, אָכן_, _दूंग,
   {{0xf2c902b5,0x63ad5231,0x224600d0,0xb4ae0d2a}},	//   _זע_, _byan, _şok_, कते_,
   {{0x63ad25a2,0xd7f80402,0x00000000,0x00000000}},	//   _cyan, _рух_, --, --,
   {{0x45450a86,0xd29500d4,0xa3e40518,0x20190051}},	//   _منتق, арсь, _प्र_, _acsi_,
   {{0x7c225232,0x509603fa,0x7eab033b,0x63ad5233}},	//   yfor, грађ, nüpu, _eyan,
   {{0x6e3c5234,0x388c00b8,0x63ad0107,0x00000000}},	//   _sarb, běru_, _fyan, --,
   {{0x386d0244,0x6d475235,0x63ad5236,0x660300d7}},	// [4ce0] iker_, _arja, _gyan, _kdnk,
   {{0x6d475237,0x9e665238,0x44f10207,0x6e3c0510}},	//   _brja, دارن, oš_, _qarb,
   {{0x386d0eed,0x6e3c5239,0x8c46523a,0x85f602b5}},	//   kker_, _varb, леже, רמעס_,
   {{0xeb9a1eea,0x6e3c523b,0x386d0a75,0x6d470009}},	//   ние_, _warb, jker_, _drja,
   {{0x5efe018d,0x6e3c523c,0x7c22523d,0xab620095}},	//   _लिट्_, _tarb, rfor, _şübh,
   {{0x7c224f95,0x386d523e,0xada60210,0x00000000}},	//   sfor, eker_, _багл, --,
   {{0x7c22523f,0x14cf00a1,0xe9df00e2,0x00000000}},	//   pfor, _संगण, _đút_, --,
   {{0x63a9006a,0x660307e5,0x386d07d4,0xdca63b3c}},	//   żeni, _adnk, gker_, _саби,
   {{0x6a161b31,0xeb971309,0x44f101c8,0x57a60763}},	//   _مبار, _бит_, eš_, ышка,
   {{0x63ad5240,0x2ca600be,0x660301ed,0x388c0355}},	//   _ryan, lood_, _cdnk, věru_,
   {{0x63ad2bef,0xf1a40067,0x38ba0b88,0x00000000}},	//   _syan, _खुलन, eëre_, --,
   {{0xd5b729d6,0x2ca65241,0x386d5242,0x63ad5243}},	//   ысы_, nood_, cker_, _pyan,
   {{0x6d4142ae,0x657a00b5,0x00000000,0x00000000}},	//   _álav, szth, --, --,
   {{0x63ad5244,0x2ca65245,0x998500c7,0x00000000}},	//   _vyan, hood_, _galų_, --,
   {{0x2ca600ab,0x63ad0118,0x9f4b01f7,0x69ce08bf}},	//   kood_, _wyan, _secà_, _úbed,
   {{0x9f4b0176,0x00000000,0x00000000,0x00000000}},	//   _pecà_, --, --, --,
   {{0x26ce5246,0x44295247,0x2ca62475,0x22870f7a}},	// [4cf0] _kifo_, _iba_, dood_, _бунг,
   {{0x261c0380,0xdd9b01e0,0xdddc0107,0x6d4702a7}},	//   _माफी_, нше_, _forō, _prja,
   {{0x261c1a75,0x386d1b25,0xbc1902a4,0x6a6f0b3e}},	//   _मानी_, yker_, вілі_, _søfo,
   {{0x201900d7,0x44290359,0x7a1e0260,0x6d4702a7}},	//   _ucsi_, _jba_, _lņtč, _vrja,
   {{0x44295248,0x447c0070,0x291e0024,0xb05b02b1}},	//   _mba_, ענדע, _aqta_, _diät,
   {{0xaa45280a,0x06e30083,0xcb6623d7,0x6d415249}},	//   рекл, _মিলি, раше_, _šlau,
   {{0x442909d6,0x2ca60051,0xe5090f9c,0x6f0d053f}},	//   _oba_, bood_, _विधि_, lrac,
   {{0x6f0d184f,0x442915b7,0x7c870bfe,0x31bc007e}},	//   orac, _nba_, _суге, _hází_,
   {{0x7c29524a,0x6c5408d9,0x6f0d1b7c,0x3d11018d}},	//   _iber, _укту, nrac, दूरे_,
   {{0x442919c7,0x386d1953,0x06851b52,0xa525311e}},	//   _aba_, sker_, ргон, амод,
   {{0x4429524b,0x6f0d19fd,0x25ae099e,0x00000000}},	//   _bba_, hrac, _cyfl_, --,
   {{0x64a63be0,0x6f0d524c,0x67390221,0x60cf00b8}},	//   рама, krac, _tswj, _nicm,
   {{0xf6e71a55,0x7c29070b,0x27ed524d,0x61f7524e}},	//   _сцен, _mber, mben_, _bexl,
   {{0x27ed524f,0x877a02b5,0x44295250,0x60cf0037}},	//   lben_, _באני, _eba_, _aicm,
   {{0x7c295251,0x6f0d5252,0x44290090,0x60cf0160}},	//   _ober, erac, _fba_, _bicm,
   {{0x3fe65253,0x6f0d5254,0x27ed5255,0x629524ab}},	//   ржав, frac, nben_, anzo,
   {{0x27ed02bf,0x1e8613ba,0x7eb00086,0x261c26c6}},	// [4d00] iben_, алам, läpi, _मामी_,
   {{0x7c29273c,0x60cf0036,0x2ca65256,0xe0da0ef3}},	//   _aber, _eicm, wood_, _иво_,
   {{0x6f0d148b,0x27ed0332,0x61fc5257,0x60cf0176}},	//   arac, kben_, marl, _ficm,
   {{0x61fc5258,0x6f0d5259,0x8b6a0204,0x00000000}},	//   larl, brac, киев_, --,
   {{0xa01b013c,0x7c290118,0x60c4525a,0x612c00b5}},	//   _omöj, _dber, mmim, _fölö,
   {{0x61fc525b,0x27ed02c9,0x7c290408,0x60c4525c}},	//   narl, eben_, _eber, lmim,
   {{0xed573e86,0x2ca600be,0xe2a7008d,0xfa6710b4}},	//   _кор_, pood_, úðir_, рајк_,
   {{0x5838195c,0x61fc525d,0x27ed00b5,0x26ce0523}},	//   узия_, harl, gben_, _sifo_,
   {{0x61fc525e,0xc6f700d8,0x98be00af,0xdb0003d0}},	//   karl, аных_, _artă_, _bymå,
   {{0x61fc525f,0xa3bd0d55,0x7c295260,0x645d006d}},	//   jarl, _अरब_, _zber, wjsi,
   {{0x27ed5261,0x61fc5262,0x44295263,0x26ce0054}},	//   bben_, darl, _pba_, _vifo_,
   {{0x746b151d,0x61f75264,0x6f0d016e,0x44290118}},	//   тров_, _sexl, yrac, _qba_,
   {{0xec7100c2,0x61fc5265,0x26ce5266,0x44295267}},	//   פֿט_, farl, _tifo_, _vba_,
   {{0x443f29cd,0x7d03024e,0x6f0d1387,0xa5f84cd3}},	//   žu_, ánsk, vrac, _секу_,
   {{0x6f0d5268,0x7875008d,0x00000000,0x00000000}},	//   wrac, _háva, --, --,
   {{0x6f0d5269,0x4429526a,0x61ee0024,0x60c4067f}},	//   trac, _uba_, abbl, gmim,
   {{0x61fc526b,0x6f0d526c,0x5fa7020c,0x60cf0176}},	// [4d10] barl, urac, _कुशल, _vicm,
   {{0x61fc526d,0xe45f022a,0x27ed006c,0x6f0d526e}},	//   carl, ljö_, zben_, rrac,
   {{0x6f0d004a,0x27ed006c,0x00000000,0x00000000}},	//   srac, yben_, --, --,
   {{0x6f0d0e7d,0x88bc00b8,0x00000000,0x00000000}},	//   prac, _zpěv, --, --,
   {{0x7875314b,0x27ed526f,0x00000000,0x00000000}},	//   _náva, vben_, --, --,
   {{0xaac41c2d,0x53380070,0x7f3a0070,0x2489030d}},	//   يتون, ינדן_, _געשו, _lmam_,
   {{0x27ed0332,0xdd9400c7,0xaa560200,0x00000000}},	//   tben_, _дары, сију_, --,
   {{0x61fc4a8c,0x7c293a8d,0x27ed5270,0x787507a6}},	//   zarl, _uber, uben_, _báva,
   {{0x27ed5271,0xbb85004f,0x61fc5272,0x2cad00d7}},	//   rben_, _الذي, yarl, _iked_,
   {{0x7875024e,0x27ed5273,0x24890183,0x60c400f4}},	//   _dáva, sben_, _amam_, zmim,
   {{0x61fc5274,0xe5a51126,0xd46a0009,0x76410f0a}},	//   varl, сини, гине_, rdly,
   {{0x25450080,0x3e760093,0x261c0bdd,0x2a65008c}},	//   _vēl_, _mæta_, _माथी_, _holb_,
   {{0xb7da0070,0xe5090067,0x2a650bf7,0x00000000}},	//   _עקסי, _विवि_, _kolb_, --,
   {{0x91e30369,0x2cbf009f,0x00000000,0x00000000}},	//   зоре, _lhud_, --, --,
   {{0x61fc3bc0,0x25aa0187,0x7875053d,0x55f600a5}},	//   rarl, čilé_, _záva, _המצב_,
   {{0x61fc5275,0x349300ed,0x2055021d,0x00000000}},	//   sarl, _најр, отур, --,
   {{0x60c45276,0x63a95277,0x00000000,0x00000000}},	// [4d20] rmim, üent, --, --,
   {{0x61fc0be2,0x3e76008a,0xe3b200b5,0xc7b20317}},	//   qarl, _bæta_, _ورک_, לבן_,
   {{0xa0a600d8,0x63a9003c,0x81461c73,0x80ba06d9}},	//   _ганд, żent, _انجن, ्षदे,
   {{0x628e5278,0x78a902c4,0x31570070,0x00000000}},	//   libo, joev, _היטן_, --,
   {{0x38ba01f4,0x78a95279,0x2a650312,0x00000000}},	//   jëra_, doev, _bolb_, --,
   {{0xdee30a87,0x261307b5,0x42db016b,0x2ce80919}},	//   _хори, _दागी_, אקסע, _نظری_,
   {{0xb5093b29,0x6496003c,0x3e76008d,0x092a0a42}},	//   _विषय_, rġij, _gæta_, استي_,
   {{0x628e05dd,0xe45f013c,0x38c800b5,0x7c960079}},	//   hibo, xjö_, جاتی_, _الرص,
   {{0x628e527a,0xe81908b6,0x3f8000a0,0xb8ff0775}},	//   kibo, _धारा_, nziu_, _धू_,
   {{0x8c44002d,0xda650c74,0xbdf60033,0x628e034d}},	//   ăşur, _والي, _চাঁদ_, jibo,
   {{0xd7ef527b,0x628e01a2,0x499a02fb,0xa96a00bc}},	//   _ну_, dibo, _стая_, _حمام_,
   {{0x7d031111,0x6aaa01bf,0x628e0051,0x7eab018d}},	//   ánsi, loff, eibo, hüpp,
   {{0x6a6f008c,0x938b058f,0xb0db12e7,0xe80d021a}},	//   _bøfh, усна_, _मंहग, _ियता_,
   {{0x38660d26,0x3f80010b,0x171b0070,0xe45f01ff}},	//   _hoor_, dziu_, _עווע, sjö_,
   {{0x54e60071,0x9f590626,0x65931357,0x3866527c}},	//   _استق, _gesê_, _нашу, _koor_,
   {{0x760201c0,0x4395527d,0x81d90033,0x6aaa0110}},	//   bízí, _майс, ারই_, hoff,
   {{0x9df9527e,0x628e018c,0x6aaa527f,0x3e76008d}},	// [4d30] инат_, bibo, koff, _sæta_,
   {{0x2cad5280,0x787500ac,0x88bc0355,0x741500fd}},	//   _sked_, _návn, _zpět, _اوکا,
   {{0xa159021d,0x5fae0066,0x6aaa096d,0xe2a7008d}},	//   _тану_, _झुठल, doff, úður_,
   {{0x38665281,0x2a65010d,0xf3ff0183,0x00000000}},	//   _noor_, _solb_, naã_, --,
   {{0x629a0237,0x6d5830c8,0x00000000,0x00000000}},	//   čtov, ävar, --, --,
   {{0x6aaa5282,0xbebb0055,0xb5090067,0x00000000}},	//   goff, _epër, _विलय_, --,
   {{0x78750187,0x38661472,0xeab0017e,0x48790102}},	//   _dávn, _boor_, رعه_, исия_,
   {{0xd7091eea,0x201b0024,0x998c0009,0x628e037b}},	//   ание_, ngqi_, _fadž_, zibo,
   {{0x38665283,0x78a95284,0xa3e006d9,0x628e01d5}},	//   _door_, roev, _तलब_, yibo,
   {{0x78a40496,0x70b50066,0x69a40099,0x394c0160}},	//   čiva, ंतुल, _चुकी, _frds_,
   {{0x7ae90009,0x628e0260,0x2d815285,0x7e670a66}},	//   _htet, vibo, nzhe_, _mojp,
   {{0x386632c5,0x36d5021d,0x7d0000fe,0x00000000}},	//   _goor_, _додр, _hárá, --,
   {{0x628e5286,0x28df0e04,0x27ff1ea7,0x63ba0035}},	//   tibo, _पंडि, maun_, ętno,
   {{0x479a0070,0x78750187,0x27ff0093,0x7ae908c7}},	//   _דינס, _kávo, laun_, _mtet,
   {{0x628e5287,0x764302c2,0xe2975288,0x9f590031}},	//   ribo, _iany, цар_, _fesë_,
   {{0x4fea16ac,0x76435289,0x7ae90086,0x628e528a}},	//   рман_, _hany, _otet, sibo,
   {{0x7643528b,0x44201010,0x6d41528c,0x628e00ee}},	// [4d40] _kany, _ici_, _šlap, pibo,
   {{0x764300d5,0x645601e8,0x3f80528d,0xaec300d4}},	//   _jany, _hnyi, rziu_, дбул,
   {{0x7643528e,0x78750076,0x6444528f,0x7ae9086a}},	//   _many, _návo, _kaii, _atet,
   {{0x614301c0,0x2b4d009e,0x673b00d7,0xf22000ab}},	//   sílá, _brec_, kwuj, _बाड़_,
   {{0x6aaa5290,0x2b4d12c3,0x64440dc3,0xeb9a034b}},	//   toff, _crec_, _maii, шид_,
   {{0x6f040298,0x764340e9,0xf8b4022e,0x2b4d0176}},	//   msic, _nany, ुष्प, _drec_,
   {{0x44205291,0x6f045292,0x787c5293,0x38665294}},	//   _oci_, lsic, _léve, _poor_,
   {{0x644400a7,0x6aaa0b44,0x6d4e009f,0x2b4d1599}},	//   _naii, soff, _irba, _frec_,
   {{0x386638eb,0x76435295,0xf2200299,0x6f045296}},	//   _voor_, _bany, _बाढ़_, nsic,
   {{0x64565297,0x0f570122,0xf76f004f,0x6f0401a6}},	//   _anyi, קיים_, ضاً_, isic,
   {{0x76435298,0x2fc701a5,0x9f5901f4,0x80d637e8}},	//   _dany, ̀ng_, _pesë_, _मंगे,
   {{0x629e5299,0x44202a5a,0x9f590107,0xa8a503d0}},	//   _ajpo, _cci_, _fesè_, _ерік,
   {{0x7643529a,0x7875033a,0x27e602d0,0x6b82529b}},	//   _fany, _závo, _ifon_, nzog,
   {{0x787c1010,0x764300a7,0x6d4e529c,0x6456529d}},	//   _déve, _gany, _orba, _enyi,
   {{0x4420529e,0x64444b31,0x6f0602a7,0x867b00a5}},	//   _fci_, _faii, _avkc, _דרגו,
   {{0xa2bb00dc,0x6f04033b,0x764301d5,0x787500ac}},	//   _शीर्, fsic, _zany, _návl,
   {{0xcddb529f,0x6d4e52a0,0x2fcf022a,0x76434ed4}},	// [4d50] ање_, _arba, ägg_, _yany,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae952a1,0x4439021d,0x27e6182d,0x7cf00107}},	//   _stet, oes_, _ofon_, _ròrò,
   {{0x2b4d52a2,0x6f0402b1,0x44200088,0x7ae900f6}},	//   _prec_, bsic, _xci_, _ptet,
   {{0x09e5425d,0x443952a3,0x6d4e52a4,0xfbd011c0}},	//   полн, ies_, _erba, نته_,
   {{0x443952a5,0x27e600e9,0x7ae9023a,0x00000000}},	//   hes_, _afon_, _vtet, --,
   {{0xc27c0122,0x6d4e0506,0x27ff52a6,0x76430951}},	//   שרוי, _grba, taun_, _rany,
   {{0x443952a7,0x764352a8,0x2b4d52a9,0x319c0317}},	//   jes_, _sany, _trec_, יבונ,
   {{0x764352aa,0x27ff52ab,0x7ae952ac,0x00000000}},	//   _pany, raun_, _utet, --,
   {{0x458500ca,0x673b52ad,0x787552ae,0x787c52af}},	//   згов, rwuj, _távo, _réve,
   {{0x261c0299,0x27ff046a,0x764352b0,0x64440159}},	//   _मारी_, paun_, _vany, _paii,
   {{0x443952b1,0x764352b2,0x6f041f06,0x19ba00a5}},	//   ges_, _wany, ysic, _המעב,
   {{0x764352b3,0xe72e01c8,0x649601ba,0xb7da00a5}},	//   _tany, _яе_, jšie, _הקני,
   {{0x11da004f,0x200b0036,0x200005d6,0xb6cc0448}},	//   صورة_, _adci_, waii_, şürü,
   {{0x66014367,0x6b820382,0x59cb06fe,0x95cb00c3}},	//   malk, zzog, ाधिर, _туда_,
   {{0x44391762,0x6601026b,0x26dd0371,0x53a60131}},	//   ces_, lalk, _kuwo_, _найб,
   {{0x27fd02c7,0x44e100e4,0x6d4e02c4,0x389700af}},	// [4d60] _mewn_, _hó_, _srba, gări_,
   {{0x6f0402bf,0x660143a2,0x59cb0785,0x44e152b4}},	//   rsic, nalk, ाधार, _kó_,
   {{0x6f0452b5,0x44e10332,0x8ebb0033,0xa2d50026}},	//   ssic, _jó_, _অংশগ, _यूट्,
   {{0x44e10514,0x6d4e011c,0xa0a60009,0x3897002d}},	//   _mó_, _vrba, _хамд, bări_,
   {{0x387f01d2,0x660152b6,0x44e152b7,0x61fe00f8}},	//   dhur_, kalk, _ló_, _kepl,
   {{0x443952b8,0xfbd00026,0x63b60086,0x660152b9}},	//   zes_, _तृणम, _myyn, jalk,
   {{0x44e152ba,0x443952bb,0xa96704bf,0x6d4e3820}},	//   _nó_, yes_, зија_, _urba,
   {{0x8c4352bc,0x443952bd,0x387f2657,0x9f590176}},	//   _песе, xes_, ghur_, _sesé_,
   {{0x443952be,0x66013ffc,0x76aa00c3,0x26dd0118}},	//   ves_, falk, йтов_, _cuwo_,
   {{0x660152bf,0x443952c0,0x44e152c1,0x7bc052c2}},	//   galk, wes_, _bó_, _izmu,
   {{0x44e1098b,0xb0db0243,0x27fd0297,0x3897002d}},	//   _có_, _मूंग, _fewn_, zări_,
   {{0x44e12556,0x443952c3,0x387f26c9,0x5fbe0035}},	//   _dó_, ues_, chur_, ्धाल,
   {{0x23c702e4,0x61fe0173,0x69da0159,0x00000000}},	//   रेंद, _bepl, _kgte, --,
   {{0x660116b7,0x442b009f,0x61fe52c4,0x550600af}},	//   calk, sfc_, _cepl, _ечиа,
   {{0x61fe52c5,0x443952c6,0x63a411ef,0xf1a41129}},	//   _depl, pes_, _exin, ертн,
   {{0x44392aae,0x3897002d,0x629c055c,0x26dd0027}},	//   qes_, tări_, anro, _yuwo_,
   {{0xe81d0066,0x9f3403d0,0x60de0176,0x00000000}},	// [4d70] फलता_, неті, _eupm, --,
   {{0x61fe4099,0xdcfc0d6f,0x764852c7,0x3897002d}},	//   _gepl, _ayrı, nddy, rări_,
   {{0x705500b5,0xfe1e0963,0x2be100b4,0x06e30033}},	//   _ہنگا, _पारस_, _फलदा, _মিছি,
   {{0x69da0626,0x254c01c0,0x81d90083,0x6a6f0b41}},	//   _agte, _měl_, ারও_, _løft,
   {{0xdb1b00e2,0xfebb00f8,0xaa453efc,0x00000000}},	//   _nguô, _هاست_, делл, --,
   {{0x52da0033,0x66011505,0x00000000,0x00000000}},	//   বীকৃ, xalk, --, --,
   {{0x387f52c8,0x660152c9,0x6d340ece,0xa3b41cce}},	//   thur_, valk, _перф, _जुन_,
   {{0x31580052,0x69da0626,0x44e11685,0x01bf0083}},	//   ליון_, _egte, _ró_, _আলাদ,
   {{0x44e1130f,0x00000000,0x00000000,0x00000000}},	//   _só_, --, --, --,
   {{0x387f00da,0x2caf0120,0x44e152ca,0x649600cd}},	//   shur_, logd_, _pó_, kšic,
   {{0x61fe0052,0xd9990082,0xa3d0035d,0x64a652cb}},	//   _repl, _بنات_, वेन_, дана,
   {{0x69c152cc,0x66014dcb,0xc20902b8,0x9507006c}},	//   _izle, salk, _כה_, _ہفتے_,
   {{0xf7450b66,0x660152cd,0x61fe52ce,0xae1e52cf}},	//   _цело, palk, _pepl, _पालन_,
   {{0x44e100fd,0x00000000,0x00000000,0x00000000}},	//   _tó_, --, --, --,
   {{0x91e31d67,0x00000000,0x00000000,0x00000000}},	//   тосе, --, --, --,
   {{0x63a406a2,0x7bdb018e,0x6ac9021a,0x00000000}},	//   _txin, _nguu, िगुर, --,
   {{0x672952d0,0xe4c70357,0x61fe05d3,0x25820248}},	// [4d80] ntej, _تصوی, _tepl, _télé_,
   {{0xaae10084,0x80be1119,0xb8810355,0x4ae100be}},	//   _पढ़क, _वीरे, _šíle, _पढ़व,
   {{0xa06a0202,0xa01b0ed4,0x787c52d1,0xf41f01ff}},	//   _дана_, _blöd, _léva, miär_,
   {{0xe8191e79,0x7875024e,0x672952d2,0x00000000}},	//   _धागा_, _dávk, ktej, --,
   {{0x7648001e,0x6d5a141f,0x7c650037,0x0f3500af}},	//   yddy, _štad, عامل, _пэря,
   {{0x3b060510,0x9f4015d8,0x44320118,0x7bdb0103}},	//   rsoq_, ncií_, _lby_, _eguu,
   {{0xa01b01ff,0x443252d3,0xb05b017b,0x00000000}},	//   _flöd, _oby_, _ohäl, --,
   {{0x807b02b5,0xa3ae02e4,0x6a7401f7,0x907b0070}},	//   ַניצ, कथा_, _màfi, ַטיי,
   {{0x29071c8b,0x6f16001e,0x9f4001ba,0x69da0036}},	//   asna_, nryc, kcií_, _tgte,
   {{0x443252d4,0x787c52d5,0x00000000,0x00000000}},	//   _aby_, _déva, --, --,
   {{0xc58a0086,0x6d5a00b5,0x7ae0023c,0x00000000}},	//   ющие_, _átad, _humt, --,
   {{0x7ae052d6,0x291c2759,0x6f160067,0x00000000}},	//   _kumt, muva_, kryc, --,
   {{0x291c52d7,0x7ae000ea,0x6f160355,0x6a6f0b3e}},	//   luva_, _jumt, jryc, _tøft,
   {{0x443209d6,0xeb910070,0x25740098,0x00000000}},	//   _eby_, אָל_, _cúlú_, --,
   {{0x7ae000da,0x40350d9e,0x291c00ee,0x306b0bfe}},	//   _lumt, невс, nuva_, ојан_,
   {{0xfe700088,0x64a40506,0x00000000,0x00000000}},	//   یدل_, rđic, --, --,
   {{0x7ae052d8,0x00000000,0x00000000,0x00000000}},	// [4d90] _numt, --, --, --,
   {{0x291c52d9,0x752f0035,0x29070b88,0x645a00ea}},	//   kuva_, ńcze, ysna_, ētie,
   {{0xdd910037,0xe3b00416,0xdb000097,0x649600c7}},	//   دوا_, _مری_, _vymý, lšia,
   {{0x6f160035,0x291c52da,0x78a23998,0x7ae0081b}},	//   bryc, duva_, _njov, _bumt,
   {{0x60cd52db,0x5fa70067,0xceb4013b,0x00000000}},	//   mmam, _कुचल, rtər_, --,
   {{0x629552dc,0x60cd52dd,0x6d43008e,0xceb400a8}},	//   nizo, lmam, ænas, stər_,
   {{0x63ba0035,0x08d5188d,0x2ebd0569,0x291c4377}},	//   ętni, нция, ्गीत, guva_,
   {{0x60cd037a,0x672952de,0x787507c0,0x290752df}},	//   nmam, ttej, _kávi, rsna_,
   {{0x290752e0,0xb9060fd1,0x28df00be,0xe73900af}},	//   ssna_, _यू_, _पूरि, чеп_,
   {{0x44320703,0xa3d000ab,0x5a3400af,0x2a6c023a}},	//   _sby_, _वृष_, _инут, _godb_,
   {{0x672952e1,0x62950065,0x60cd52e2,0x00000000}},	//   stej, dizo, kmam, --,
   {{0x60cd01ba,0x672952e3,0x6a740176,0x00000000}},	//   jmam, ptej, _ràfi, --,
   {{0x68e152e4,0x78bb00b8,0x62950031,0x3945022f}},	//   _huld, mluv, fizo, _hsls_,
   {{0x68e152e5,0xe5a552e6,0x629552e7,0x78bb28ef}},	//   _kuld, _пили, gizo, lluv,
   {{0x205652e8,0xa564004f,0x9f5900ee,0xe6b400d1}},	//   нтар, _لدين, _desí_, _جلوگ,
   {{0x6f1652e9,0x60cd0269,0xa01b01ff,0x2c7e01f7}},	//   tryc, gmam, _smör, _oïda_,
   {{0x91e652ea,0xaec6192f,0x1fa70ece,0xaade0084}},	// [4da0] _попе, ебал, екти_, _फूंक,
   {{0x68e10107,0x7a33008f,0x1ea91301,0x60cd0ffd}},	//   _ould, nıtı, والي_, amam,
   {{0x6d5a52eb,0xe82000a1,0x2480053e,0x2c7e0815}},	//   _štab, _याला_, _klim_, _aïda_,
   {{0x442252ec,0x60cd52ed,0x2a6c02a7,0x83c7021a}},	//   ngk_, cmam, _sodb_, रेकआ,
   {{0xfe1e00a1,0x7a330381,0x8b660079,0x00000000}},	//   _पाऊस_, kıtı, عاصم, --,
   {{0x291c52ee,0x68e152ef,0x78a2054e,0x38ba01f4}},	//   tuva_, _buld, _sjov, mëri_,
   {{0x7875024e,0xbea3082a,0xa3d010aa,0x78bb0036}},	//   _závi, _сарк, वेत_, fluv,
   {{0xb509035d,0x200252f0,0x291c017b,0x7ae052f1}},	//   _विजय_, _jeki_, ruva_, _tumt,
   {{0x9f4052f2,0x7d1e0c71,0x20020506,0x862600d8}},	//   ncià_, lups, _meki_, ньне,
   {{0x68e1054e,0x248022ca,0x7e6e52f3,0x200252f4}},	//   _fuld, _alim_, _jobp, _leki_,
   {{0x68e152f5,0x04b8006c,0x7d1e0159,0x60cd52f6}},	//   _guld, کھوں_, nups, ymam,
   {{0x7c2219d3,0x200252f7,0x2480000d,0x62950035}},	//   ngor, _neki_, _clim_, wizo,
   {{0xa6ca027a,0x320100ee,0x00000000,0x00000000}},	//   _елда_, _pehy_, --, --,
   {{0x569411d0,0x7d1e00f4,0x248052f8,0x649600c7}},	//   _шалт, kups, _elim_, ršia,
   {{0xc17721b6,0x3e76008a,0x629552f9,0xa1582401}},	//   ردست, _gæti_, rizo, нару_,
   {{0x7c2252fa,0x629552fb,0x200252fc,0x24800345}},	//   jgor, sizo, _ceki_, _glim_,
   {{0x2002027d,0x7e6e009e,0xa3d0198f,0x764a0103}},	// [4db0] _deki_, _bobp, वेद_, _kafy,
   {{0x60cd2d37,0x64960097,0x64a40009,0x248000cd}},	//   smam, nšin, nđin, _zlim_,
   {{0x98730012,0x60cd027d,0x2002002f,0x4ea435f7}},	//   nţă_, pmam, _feki_, урта,
   {{0x6ac9043b,0x7c2252ec,0xe1f00987,0x764a0359}},	//   िग्र, ggor, _پسی_, _lafy,
   {{0x68e152fd,0x290c2e1a,0xbb450be8,0x00000000}},	//   _suld, _avda_, телк, --,
   {{0xc3340d85,0x64960009,0x7c2201a3,0x20020225}},	//   רוס_, jšin, agor, _zeki_,
   {{0xecbb0647,0x68e1013b,0x00000000,0x00000000}},	//   _فطرت_, _quld, --, --,
   {{0x787c0248,0xccf20122,0x6496010b,0x9f400036}},	//   _dévo, _ככל_, ešin, mbiò_,
   {{0x3e760093,0x6615006c,0x7b182bfc,0xb6a5002d}},	//   _sæti_, ózko, _потр_, киил,
   {{0x68e152fe,0x78bb52ff,0x24802d71,0xa3b50067}},	//   _tuld, sluv, _slim_, _झड़_,
   {{0xe5a55300,0x35a502c4,0x764a00e9,0x24800359}},	//   тини, танг, _dafy, _plim_,
   {{0x39580079,0xf77000f8,0x00000000,0x00000000}},	//   _ársa_, _گام_, --, --,
   {{0x20025301,0xe3b20037,0x4ccb0831,0x00000000}},	//   _reki_, شرح_, িদপু, --,
   {{0x3ce2009a,0x09d50083,0x6d5501dd,0xf77005bc}},	//   _ओढले_, _স্যা, _orza, _دام_,
   {{0x2b910028,0x998700d8,0x41270274,0x272b01cf}},	//   ạch_, menų_, коро_, løn_,
   {{0x660303ad,0xa3e805f7,0x38ba0031,0x00000000}},	//   _henk, मुख_, tëri_, --,
   {{0x6d470006,0x66035302,0x3fe30370,0x6d555303}},	// [4dc0] _asja, _kenk, ржув, _arza,
   {{0x66035304,0x2b5800b8,0x6d555305,0x78a400cd}},	//   _jenk, _črc_, _brza, čivi,
   {{0x66035306,0x5bca021a,0xa3e900ab,0x20025307}},	//   _menk, िध्व, _बलम_, _teki_,
   {{0x38ba00da,0x66032780,0x6d550a18,0x7d1e5308}},	//   përi_, _lenk, _drza, rups,
   {{0x4fa300d4,0x38ba01f4,0x7d1e0a2d,0x787c0107}},	//   _вияв, qëri_, sups, _dévl,
   {{0x290c01e4,0x66035309,0x7c220afc,0x6a7d0107}},	//   _pvda_, _nenk, sgor, _dèfo,
   {{0x09d50b52,0x81b400c8,0x7d530332,0x00000000}},	//   _স্বা, জের_, _پہنچ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf0931759,0x1ae602ce,0x6603530a,0x649601c0}},	//   ינה_, _розм, _benk, tšin,
   {{0x78ad01cc,0x6496010b,0x998700c7,0xe4e603d0}},	//   čava, ušin, genų_, кімн,
   {{0x6603530b,0x64963426,0xf76f00d1,0x00000000}},	//   _denk, ršin, مای_, --,
   {{0x7d030370,0x660303bc,0xf3ff0183,0x00000000}},	//   ânsi, _eenk, rjão_, --,
   {{0x6496530c,0x6603530d,0x4e2201c0,0x1634110d}},	//   pšin, _fenk, मलाई_, _беля,
   {{0x6603530e,0x261c0006,0x00000000,0x00000000}},	//   _genk, _माटी_, --, --,
   {{0x6720530f,0x00000000,0x00000000,0x00000000}},	//   lumj, --, --, --,
   {{0x70bf009a,0x66035310,0x6486002a,0x43850037}},	//   ्षेल, _zenk, _cóid, _ملعق,
   {{0x3d050302,0x44295311,0xd9040332,0x645f40eb}},	// [4dd0] हीने_, _ica_, _ڈی_, _inqi,
   {{0xd9040357,0x644d1e7e,0x81d80033,0x00000000}},	//   _وی_, _haai, াড়_, --,
   {{0xf1ab00d1,0x644d0afc,0x44290051,0x6a7d021e}},	//   _زاده_, _kaai, _kca_, _sèfo,
   {{0x261c00a1,0x66085312,0x644f0051,0x6d5500d5}},	//   _माझी_, hadk, ndci, _vrza,
   {{0x644d247d,0x09cb1cce,0x44295313,0x660808dd}},	//   _maai, ाध्य, _mca_, kadk,
   {{0x26dc5314,0x6e950de3,0x20090173,0x6d555315}},	//   _nivo_, _сигу, laai_, _trza,
   {{0x60dd4c54,0x66035316,0x44295317,0xceb20122}},	//   _kism, _renk, _oca_, _הים_,
   {{0x44295318,0x60dd007a,0x66035319,0xa2bb531a}},	//   _nca_, _jism, _senk, _शीघ्,
   {{0x60dd531b,0x660315eb,0x1bd400af,0x7c290225}},	//   _mism, _penk, _вотя, _icer,
   {{0x44290014,0x660301f4,0x645f0024,0x7c29023a}},	//   _aca_, _qenk, _anqi, _hcer,
   {{0x6603531c,0x7c29022f,0x3e760093,0x644d0a81}},	//   _venk, _kcer, _gætu_, _baai,
   {{0x60dd531d,0x09d500c8,0x4429531e,0x6603531f}},	//   _nism, _স্থা, _cca_, _wenk,
   {{0xe7395320,0x66035321,0x66085322,0xddce010b}},	//   _чел_, _tenk, badk, _pobū,
   {{0xa3d002e4,0x44295323,0x81bf0083,0x171a0070}},	//   वेष_, _eca_, েশন_, _נוצע,
   {{0x644d12ba,0x60dd011c,0x24995324,0x76415325}},	//   _faai, _bism, bism_, mely,
   {{0x27ed5326,0x60dd5327,0x9f4b0036,0x26dc003d}},	//   ncen_, _cism, _recò_, _zivo_,
   {{0xa3d05328,0xb4c223db,0x60dd5329,0x6f0d0176}},	// [4de0] वेश_, ्गी_, _dism, gsac,
   {{0x7c29532a,0xe1fa0a93,0x60dd010b,0x6287532b}},	//   _acer, _яго_, _eism, chjo,
   {{0x6720532c,0x6f0d09c3,0x8d760037,0x200915ef}},	//   zumj, asac, داءا, baai_,
   {{0x7641006c,0x3b8600c3,0x1acc00b4,0xac2500d4}},	//   hely, ллег, ाष्ठ, ифік,
   {{0x7c290e06,0x7521033b,0x7f760274,0x7641532d}},	//   _dcer, hulz, _сунц, kely,
   {{0x7c293540,0x24990282,0x4af9002d,0x00000000}},	//   _ecer, zism_, тэця_, --,
   {{0x7641532e,0x2499021e,0xdca60274,0xe5670037}},	//   dely, yism_, _бави, _اط_,
   {{0x249920f8,0x26dc1635,0x752102d7,0x187407e5}},	//   xism_, _sivo_, dulz, ргия,
   {{0x26dc08c2,0x6496063b,0xb6061bda,0x644d532f}},	//   _pivo_, ršil, лянк, _raai,
   {{0x76415330,0x44291ba3,0x320a011e,0x644d5331}},	//   gely, _sca_, jaby_, _saai,
   {{0x66083879,0x26dc5332,0x644d5333,0x64965334}},	//   radk, _vivo_, _paai, mšij,
   {{0x69c85335,0x66085336,0x27ed05f5,0xb4af0066}},	//   _izde, sadk, ccen_, कवे_,
   {{0x24995337,0x66085338,0xe6c4008a,0x44295339}},	//   rism_, padk, þjóð, _vca_,
   {{0x764123ca,0x644d533a,0x2499533b,0x20090b0d}},	//   cely, _waai, sism_, waai_,
   {{0x6d5a01ba,0x6486004f,0x44290f43,0x867b02b8}},	//   _štan, _dóib, _tca_, _ארגו,
   {{0x60dd00a8,0xddc701f2,0x6f0d3b72,0x4429533c}},	//   _qism, _nojš, tsac, _uca_,
   {{0x60dd0029,0x2009053e,0x657a0090,0xe7f726c6}},	// [4df0] _vism, raai_, lyth, ीरता_,
   {{0x6f0d533d,0x81b40083,0x7c293b02,0xa28300b5}},	//   rsac, জেই_, _scer, _ایسو,
   {{0x3e760093,0x6285533e,0xa3e90324,0x60dd533f}},	//   _rætt_, _ilho, _बला_, _tism,
   {{0x6f0d009e,0x3b55167d,0x22430009,0xac1927b9}},	//   psac, икер, lejk_, тоду_,
   {{0xeab123fb,0x6f0f002f,0x63ad009f,0xae1e0067}},	//   يعت_, _uvcc, _jxan, _पाचन_,
   {{0x78750076,0xfbd000f8,0x657a471f,0x64960097}},	//   _návr, ستن_, kyth, všim,
   {{0x62855340,0x76415341,0x00000000,0x00000000}},	//   _mlho, vely, --, --,
   {{0x69d50076,0x7641001e,0x7af500d4,0x9f5202d7}},	//   _územ, wely, _взає, cayó_,
   {{0x068534b5,0x62855342,0x76415343,0x27ed5344}},	//   игин, _olho, tely, rcen_,
   {{0xbb84004f,0x27ed00af,0x7a5700b5,0xd6ce00bc}},	//   _الكي, scen_, _حضرا, وقي_,
   {{0x81eb0033,0x657a00e9,0x38ba0031,0x940b00a8}},	//   মরা_, gyth, tërt_, licə_,
   {{0xb4c2178c,0x62855345,0x752f0035,0x76415346}},	//   ्गे_, _alho, ńczo, sely,
   {{0x386d5347,0xa3d00992,0x752100a8,0x00000000}},	//   mjer_, वें_, sulz, --,
   {{0x386d2d31,0x471a00c2,0x387f458a,0x36690214}},	//   ljer_, _יונג, lkur_, _јако_,
   {{0x628501ba,0x3d050324,0x64960009,0x3aeb0185}},	//   _dlho, _हौले_, nšik, _løp_,
   {{0xe0df01d3,0x387f5348,0x386d1e8b,0x78750097}},	//   _ciò_, nkur_, njer_, _závr,
   {{0x387f008d,0x4e060368,0xe3b80095,0xdddc0139}},	// [4e00] ikur_, изаб, şıb_, _borş,
   {{0xa2cd035d,0x7c3d0225,0x00000000,0x00000000}},	//   _दीप्, _ısra, --, --,
   {{0x387f00fb,0xb7f70026,0x386d0bbf,0x00000000}},	//   kkur_, ीराम_, kjer_, --,
   {{0xf53600c2,0xe53602b5,0x629c5349,0xe0df534a}},	//   יטער_, יטעט_, liro, _giò_,
   {{0x386d025c,0xf417016b,0xddc7023a,0x00000000}},	//   djer_, בֿות_, _vojš, --,
   {{0x291c0274,0x7bc90409,0xd3570277,0xad2604cd}},	//   trva_, _dzeu, ייני_, _پرسو,
   {{0x6496534b,0x6da303d6,0x64a402c4,0x38ba0031}},	//   ršij, _дира, rđij, dërr_,
   {{0xdca60384,0xfce3534c,0xb4c20066,0x69c83e43}},	//   _таби, _фото, ्गो_, _vzde,
   {{0x629c534d,0xe6664234,0x657a001e,0x6aa80183}},	//   kiro, атно, wyth, _tjdf,
   {{0x291c011c,0xd6d70012,0x657a055c,0x00000000}},	//   prva_, итэ_, tyth, --,
   {{0xd7ef0b46,0x629c534e,0x69c81772,0x787c534f}},	//   _му_, diro, _uzde, _lévi,
   {{0xe2f903d0,0x629c1be9,0x657a0122,0x2ca600e9}},	//   лемі_, eiro, ryth, nnod_,
   {{0x68e85350,0x628501e8,0x629c0103,0x6d5a05e2}},	//   _hudd, _plho, firo, _štal,
   {{0x629c5351,0x68e85352,0x00000000,0x00000000}},	//   giro, _kudd, --, --,
   {{0x27300211,0x80075353,0x00000000,0x00000000}},	//   làn_, ичае, --, --,
   {{0x68e85354,0x63ad06a2,0x394c51c7,0x629c0345}},	//   _mudd, _txan, _msds_, airo,
   {{0x629c5355,0x68e85356,0xddce00fe,0x0eeb01e0}},	// [4e10] biro, _ludd, _bobů, тьби_,
   {{0x387f00c7,0x629c20d9,0x9df81676,0x787c000d}},	//   zkur_, ciro, инут_, _dévi,
   {{0x2ca60297,0x61e5009e,0x6d5a00b5,0xab62027d}},	//   fnod_, _ighl, _átal, _şüph,
   {{0xa5d902b5,0x2ca6011e,0xe5370070,0x940b00a8}},	//   אַני, gnod_, שטאט_, ticə_,
   {{0x7bc00297,0x64860279,0xdefb0409,0x386d02c4}},	//   _cymu, _jóia, _шын_, vjer_,
   {{0x7bc0001e,0x6a7d0176,0x8e850037,0x28df0b35}},	//   _dymu, _kèfi, _السه, _पूजि,
   {{0x68e85357,0x3cf000a0,0x3a2c0371,0x00000000}},	//   _cudd, ľové_, _dcdp_, --,
   {{0xbca50642,0x629c0a78,0x68e8183a,0x3cf00187}},	//   _امري, ziro, _dudd, žové_,
   {{0x387f5358,0x7bc0001e,0x6a7d02e9,0x7c3b0010}},	//   rkur_, _gymu, _lèfi, _ibur,
   {{0xba740514,0x387f0093,0x629c01dd,0xca74004f}},	//   _والت, skur_, xiro, _والغ,
   {{0x629c5359,0xe82000a1,0xb348003c,0x7c3b035f}},	//   viro, _याचा_, _maħż, _kbur,
   {{0xb4e7000c,0x07080220,0x1bef01c0,0x64a60409}},	//   _बढी_, _چيني_, _छलफल_, сама,
   {{0x629c535a,0x27ff1581,0x7ae1535b,0x7c3b535c}},	//   tiro, mbun_, _kilt, _mbur,
   {{0x6d5a535d,0x787c5078,0x412a08a6,0x69c1535e}},	//   _štam, _révi, лого_, _kyle,
   {{0x7ae90086,0x7c3b535f,0x787c000d,0xd17901e0}},	//   _luet, _obur, _sévi, асті_,
   {{0x629c00d8,0x69c1004b,0x6a7d0310,0x7ae90b88}},	//   siro, _myle, _dèfi, _ouet,
   {{0xee3a0b46,0xa01b022a,0x64465360,0x7ae109bb}},	// [4e20] лна_, _glöm, meki, _oilt,
   {{0xdfcf0180,0x7c3b5361,0xdd8f0919,0xcf25004f}},	//   ريل_, _abur, کوم_, ترفي,
   {{0x7bc00297,0x8d5a02ee,0x7ae913bf,0xd9f8073f}},	//   _symu, ышат_, _auet, ुरसत_,
   {{0xac0a1d91,0x644606a2,0x68e85362,0x1d07117a}},	//   унда_, neki, _rudd, сеци_,
   {{0x7ae15363,0x20005364,0x7d1e011c,0x7ae902d7}},	//   _bilt, mbii_, srps, _cuet,
   {{0x60c45365,0x68e85366,0xdd2001c0,0x7ae15367}},	//   llim, _pudd, může, _cilt,
   {{0x5d860082,0x68e8003c,0x7ae10031,0x7ae901f7}},	//   _الأل, _qudd, _dilt, _euet,
   {{0x6d5c5368,0x6d4e5369,0x60c4536a,0x69c1001e}},	//   _irra, _isba, nlim, _dyle,
   {{0xd6da0ec9,0x69c1027d,0xc6f71ac5,0xa01b017b}},	//   лто_, _eyle, бных_, _blöj,
   {{0x27300310,0x7ae1536b,0x60c4083b,0x7c3b1149}},	//   ràn_, _gilt, hlim, _zbur,
   {{0xe72f09b9,0x6d5a536c,0x245f0086,0x7ae901b7}},	//   وصی_, _štaj, _nämä_, _zuet,
   {{0x6446536d,0x746b536e,0x99640355,0xab5d0067}},	//   geki, уров_, _kůže_, _wyże,
   {{0x27e6536f,0x7ae91c02,0x60c400fe,0xdc9b00a5}},	//   _igon_, _xuet, dlim, ריכל,
   {{0x9964000c,0x60c45370,0x442d0035,0x6d5c5371}},	//   _může_, elim, że_, _orra,
   {{0x7e750f86,0x9f490079,0x29df007a,0x3eba0027}},	//   _rozp, rcaí_, _għaċ_, dopt_,
   {{0x64a41c56,0x60c45372,0x9f490037,0x64465373}},	//   _наја, glim, scaí_, ceki,
   {{0x6d5c5374,0x6e992d7a,0x660a4ed6,0x68e25375}},	// [4e30] _arra, авар_, _kefk, _miod,
   {{0x44390d26,0x660a0051,0x68e2009e,0x7c3b0139}},	//   lfs_, _jefk, _liod, _sbur,
   {{0x443933a0,0x7ae95376,0x24890cfd,0x9f59008d}},	//   ofs_, _suet, _klam_, _jesú_,
   {{0x7ae15377,0x27e601a5,0x71f8006c,0xa3d014eb}},	//   _silt, _ngon_, _پریس_, वेक_,
   {{0x6d5c5378,0x7ae10006,0xcb692ecf,0x6d4e5379}},	//   _erra, _pilt, рале_, _esba,
   {{0x6446537a,0x27e6537b,0x91fb00b4,0x2b4d0116}},	//   zeki, _agon_, ्रिज_, _vsec_,
   {{0x68e20014,0x64462ff3,0x7ae1537c,0xaefb009e}},	//   _biod, yeki, _vilt, _brùg,
   {{0x7c3b070b,0x69c1024e,0x645a00ea,0xa01b01ff}},	//   _ubur, _vyle, ētik, _slöj,
   {{0x68e2537d,0x7c24004f,0x200b002d,0x7b670352}},	//   _diod, óire, _meci_, _утве,
   {{0x2489537e,0x27e606a2,0x2cbf0124,0x7ae10345}},	//   _alam_, _egon_, _hkud_, _uilt,
   {{0x6446537f,0x24890fee,0x68e200f1,0x60c402ee}},	//   teki, _blam_, _fiod, ylim,
   {{0x7c2b5380,0x6d5a003a,0xf99200a5,0x2ee301e4}},	//   nggr, _štak, _קרא_, _lijf_,
   {{0xe60e4d87,0x644632b5,0x78bb5381,0x78a95382}},	//   _од_, reki, mouv, mnev,
   {{0x64465383,0x78bb01c0,0x24891a99,0x78a95384}},	//   seki, louv, _elam_, lnev,
   {{0x7f5d01da,0x78a90031,0x91e3260f,0x200b5385}},	//   _arsq, onev, доре, _beci_,
   {{0x200b0248,0x78a95386,0x78bb20d0,0x53a600d4}},	//   _ceci_, nnev, nouv, _майб,
   {{0x200b5387,0x60c41d11,0x26c50453,0x3eba02a2}},	// [4e40] _deci_, rlim, ollo_, topt_,
   {{0x60c415a8,0x245f03ad,0x78a907c0,0x6d5a008d}},	//   slim, _tämä_, hnev, _átak,
   {{0x0d8601c8,0x26c51f52,0x60c45388,0x78bb02e9}},	//   ўлен, illo_, plim, kouv,
   {{0x78a91bd8,0xbb860312,0x5f2a00c3,0x200b5389}},	//   jnev, يلاي, _комм_, _geci_,
   {{0x78a90496,0x2cad3485,0x69c5393f,0xaefb009e}},	//   dnev, _djed_, ühen, _crùd,
   {{0x200b002d,0xaefb0211,0x78a91fe7,0xed5a0200}},	//   _zeci_, _drùd, enev, _ког_,
   {{0x6d5c538a,0x6d4e538b,0xcb1c00a1,0x00000000}},	//   _urra, _usba, _निवड_, --,
   {{0xa774538c,0x26c53529,0xdd8f028c,0x78a9476b}},	//   злич, ello_, _شوق_, gnev,
   {{0x920a0d1f,0xa01b0093,0xaefb01da,0x76aa0421}},	//   वराज_, _slök, _grùd, итов_,
   {{0xd6d015f4,0x2489538d,0x00000000,0x00000000}},	//   عقد_, _slam_, --, --,
   {{0xceb300c2,0x24890221,0x994a0082,0x286a03fa}},	//   ויז_, _plam_, _خلال_, _врло_,
   {{0x66e604a1,0x78bb1010,0xe7860210,0xe3b80092}},	//   _дода, couv, _муло, ğın_,
   {{0x200b538e,0xe3b806d0,0x4439538f,0xc87f02c9}},	//   _reci_, şın_, rfs_, öße_,
   {{0x9f5902fb,0xaaca000c,0x628e00a5,0x44390282}},	//   _gesù_, ितिक, ghbo, sfs_,
   {{0x76485390,0x31c417c2,0x7cf3003c,0x2019011e}},	//   medy, дств, _oħra, _pdsi_,
   {{0x24895391,0xda780187,0x76485392,0x752802a7}},	//   _ulam_, _loď_, ledy, mudz,
   {{0x200b016f,0x9f340185,0xaaca01c0,0x6ee9023a}},	// [4e50] _veci_, меті, िताक, _ožbe,
   {{0x628e5393,0xa3b411b5,0x2cbf5394,0x7cf3009f}},	//   chbo, _जुट_, _skud_, _aħra,
   {{0x92b4004f,0x2ee30120,0x64a400cd,0x649600f4}},	//   _تحيا, _vijf_, rđiv, ršiv,
   {{0x6ac30266,0x76481292,0x2ee30223,0xa3c40b35}},	//   षत्र, hedy, _wijf_, _्रम_,
   {{0xd5d102e4,0x395e4a89,0x76480c47,0x7c2b057f}},	//   _हरभज, _arts_, kedy, rggr,
   {{0x38665395,0x76480035,0x7528034d,0x6a7d0260}},	//   _anor_, jedy, kudz, _nèft,
   {{0x7f4d003c,0x78a94ac1,0x6ca75396,0xec6b2701}},	//   lwaq, tnev, _драж, _крак_,
   {{0x2cad0009,0xb4b501c0,0x00000000,0x00000000}},	//   _ujed_, जको_, --, --,
   {{0x32110076,0x78bb5397,0x00000000,0x00000000}},	//   kazy_, rouv, --, --,
   {{0x7afb067f,0x78a95398,0x78bb5399,0x26c5539a}},	//   _itut, snev, souv, ullo_,
   {{0xa3de00b4,0x64860037,0xc8ab01d3,0x395e0051}},	//   थेन_, _fóil, _къде_, _grts_,
   {{0x3f4d022f,0xc8640945,0x00000000,0x00000000}},	//   _ožu_, _отчи, --, --,
   {{0x69c701b4,0x649600d5,0x00000000,0x00000000}},	//   _øjeb, dšit, --, --,
   {{0xdbe80026,0x7afb08c7,0x7528539b,0x00000000}},	//   _ओल्ड_, _mtut, budz, --,
   {{0xd132004f,0xe297539c,0xa06a2753,0x45d20274}},	//   عمر_, чар_, бава_, _пољс,
   {{0x4fea1309,0x2b5f013b,0xb4ba00fd,0x7afb1998}},	//   сман_, _oruc_, _دُعا_, _otut,
   {{0x443201d5,0xe29a0009,0x831711cf,0x1e86010b}},	// [4e60] _icy_, _гап_, _فقير_, плам,
   {{0x64562a8e,0xef1712ea,0x00000000,0x00000000}},	//   _hayi, яму_, --, --,
   {{0x6456539d,0x7afb539e,0x3f860334,0xaefb01da}},	//   _kayi, _atut, šou_, _crùb,
   {{0xdee60073,0x2b5f539f,0x64560260,0x787c00f6}},	//   _номи, _bruc_, _jayi, _lévr,
   {{0x645653a0,0x6486004f,0x6f6300d8,0x201253a1}},	//   _mayi, _nóim, _звяз, mayi_,
   {{0x645601c2,0x2b5f0160,0x787c2507,0x386653a2}},	//   _layi, _druc_, _névr, _snor_,
   {{0x9d430ec9,0x64860037,0x764853a3,0xadc30023}},	//   _перд, _póil, vedy, _trạc,
   {{0x201253a4,0x6456018c,0x629e0159,0x23600051}},	//   nayi_, _nayi, _lmpo, _orij_,
   {{0x629e53a5,0x64860079,0x49080067,0x67292df0}},	//   _ompo, _cóim, _सबको_, guej,
   {{0xbafb0122,0x9f97011d,0x64560103,0x8b030355}},	//   _להמש, פדיה_, _aayi, ářen,
   {{0x645653a6,0x2fc70019,0x764853a7,0xf76f00d1}},	//   _bayi, ́ng_, redy, نای_,
   {{0x629e53a8,0x38660043,0x64560103,0x23600051}},	//   _ampo, _unor_, _cayi, _brij_,
   {{0x787c02e1,0x645653a9,0x764853aa,0x6b820679}},	//   _févr, _dayi, pedy, nyog,
   {{0xe1f800af,0x356a1e56,0x00000000,0x00000000}},	//   зерч_, _грин_, --, --,
   {{0xe63b0052,0x32111298,0x645653ab,0xa63b00a5}},	//   _התוכ, razy_, _fayi, _הגור,
   {{0x629e53ac,0x2ec505f8,0x6456018e,0x201253ad}},	//   _empo, वत्त, _gayi, gayi_,
   {{0xa2b52235,0x98a7011c,0x649653ae,0xe8d700a5}},	// [4e70] _обич, šiću_, ršit, לולר_,
   {{0x64562c56,0x00000000,0x00000000,0x00000000}},	//   _zayi, --, --, --,
   {{0x7afb53af,0x645653b0,0xaefb0211,0x2d8753b1}},	//   _stut, _yayi, _brùc, áne_,
   {{0x317e01ae,0x64561505,0x76840260,0x64960009}},	//   ätze_, _xayi, _bòyk, lšir,
   {{0x2d8736a5,0x61ec006c,0xaefb009e,0xf1ab0088}},	//   šne_, _állá, _drùc, _خاکه_,
   {{0xa96953b2,0x64860079,0xe7f700b4,0x649600f4}},	//   жика_, _róim, ीर्थ_, nšir,
   {{0x6d5a3c4e,0xa2a000a1,0x00000000,0x00000000}},	//   _štav, _ऑगस्, --, --,
   {{0xa3ad0632,0x2b5f53b3,0xa01b0282,0x99620168}},	//   कपा_, _truc_, _elöv, _míňa_,
   {{0x645653b4,0x7afb0858,0x999e004b,0x6605018d}},	//   _rayi, _utut, _batų_, _õhkk,
   {{0x645653b5,0x00000000,0x00000000,0x00000000}},	//   _sayi, --, --, --,
   {{0xe3b806d3,0x1fda01c0,0xa9070754,0x201253b6}},	//   ğım_, _भण्ड, _ربان, yayi_,
   {{0xe3b8008f,0x03a653b7,0x6aa353b8,0x236002c4}},	//   şım_, димо, linf, _prij_,
   {{0x672953b9,0x201253ba,0x798300e9,0x7cf3007a}},	//   quej, vayi_, lynw, _oħro,
   {{0xa50902e3,0x23600a75,0x6aa353bb,0x64561939}},	//   _дека_, _vrij_, ninf, _wayi,
   {{0x645653bc,0x2012166c,0x2d1c0cf1,0x00000000}},	//   _tayi, tayi_, _पटेल_, --,
   {{0x205512f8,0xa0670d10,0x2360023a,0x00000000}},	//   нтур, маса_, _trij_, --,
   {{0x8fa315de,0x20120010,0x6aa353bd,0xe29a083e}},	// [4e80] вате, rayi_, kinf, _маи_,
   {{0x629e53be,0xc3c912de,0x201253bf,0x6b8208c7}},	//   _umpo, _عظيم_, sayi_, vyog,
   {{0x6aa353c0,0xb05b0328,0x44f3021d,0x00000000}},	//   dinf, _ikän, _jã_, --,
   {{0x44f30028,0x6aa30553,0x00000000,0x00000000}},	//   _mã_, einf, --, --,
   {{0x4bda042c,0x44f353c1,0x3945021d,0xcce50037}},	//   آباد_, _lã_, _apls_, رسمي,
   {{0x6aa353c2,0x6b82024c,0x6d5a00f4,0x00000000}},	//   ginf, ryog, _štau, --,
   {{0xa9670798,0x5de30009,0x44f353c1,0x9f4b0093}},	//   дија_, _ажра, _nã_, élög_,
   {{0x649653c3,0xd90d00f8,0x63b60027,0x00000000}},	//   zšir, صیه_, _oxyn, --,
   {{0xdca32b05,0xb05b013c,0xab6500ea,0x9f590345}},	//   _рати, _okän, _peļņ, _afsê_,
   {{0xda6653c4,0x44f30023,0xceb400a8,0x2ba400ab}},	//   _تاري, _bã_, qsəd_, _खेया,
   {{0x6fd50084,0x9986197c,0x44f353c5,0x00000000}},	//   _दरभं, _تلاو, _cã_, --,
   {{0x25fe0fd1,0x9f4053c6,0x092901b2,0x44f30019}},	//   _श्री_, nció_, _رسمي_, _dã_,
   {{0xf76f00ce,0x69c853c7,0x78750097,0xbf9b0345}},	//   _ناو_, _hyde, _návy, _leêr,
   {{0x44f303e6,0x09d50033,0x81d80033,0x7e7c081b}},	//   _fã_, _স্টা, িশন_, _norp,
   {{0x7ae8177c,0x44f30023,0x9f40006c,0x64961ada}},	//   _midt, _gã_, kció_, ršir,
   {{0x765853c8,0x7ae80a8a,0x7afc02a7,0x00000000}},	//   _havy, _lidt, _črtn, --,
   {{0x69c853c9,0x76580088,0x77620069,0x6aa300fe}},	// [4e90] _lyde, _kavy, _jrox, yinf,
   {{0x765a0b88,0x51870c06,0x234800d1,0xc5f800ea}},	//   ndty, _жума, _کلیپ_, ncē_,
   {{0x44f30028,0x7e7c03c4,0x69c853ca,0xa01b01ff}},	//   _xã_, _dorp, _nyde, _blöt,
   {{0x6ab90fcf,0x7e7c0a32,0x6aa353cb,0x776201ef}},	//   ेत्र, _eorp, winf, _orox,
   {{0x7e7c0c61,0x6d5a53cc,0x798300e9,0x909802fb}},	//   _forp, _štat, wynw, _цвят_,
   {{0x765853cd,0x9f4012c3,0x7e7c06a2,0x69c853ce}},	//   _navy, ació_, _gorp, _byde,
   {{0x6aa34e3f,0x7ae82487,0xa01b53cf,0x69c8099e}},	//   rinf, _didt, _flöt, _cyde,
   {{0x9f40162d,0x6aa353d0,0x44f353d1,0x7762021d}},	//   cció_, sinf, _rã_, _brox,
   {{0xf41f00c3,0x44f353d2,0x7762021d,0x7658273b}},	//   tkän_, _sã_, _crox, _bavy,
   {{0xb6cc06d3,0xe3b801d6,0xddc70097,0x44f3021d}},	//   şünü, şık_, _mojž, _pã_,
   {{0x765853d3,0x9f4007e5,0x69c853d4,0x00000000}},	//   _davy, nciò_, _gyde, --,
   {{0x776201ef,0x44f353d1,0xb05b0454,0xe7950279}},	//   _frox, _vã_, _skän, _пиењ,
   {{0xf74553d5,0x7dee00b5,0x69c853d6,0x00000000}},	//   _чело, nősí, _zyde, --,
   {{0x273902e9,0x09e30083,0xf770083a,0x44f33817}},	//   mèn_, _ন্যা, _خام_, _tã_,
   {{0x64a601c8,0x04460036,0x614331ee,0x673b20c3}},	//   _пака, _зейн, лера, ltuj,
   {{0xa0b503fa,0x645a00ea,0xafe61285,0x00000000}},	//   вљуј, ētis, еобл, --,
   {{0x44200ec4,0x673b05d1,0x3cff0254,0x7bc90054}},	// [4ea0] _idi_, ntuj, _čuva_, _nyeu,
   {{0xa2c10355,0x00000000,0x00000000,0x00000000}},	//   लकण्, --, --, --,
   {{0xa01b53d7,0x7e7c033b,0x9f5902d7,0x442053d8}},	//   _plöt, _vorp, _besó_, _kdi_,
   {{0x673b0e7d,0x273902d0,0x6d5e00ab,0x44200355}},	//   ktuj, kèn_, rvpa, _jdi_,
   {{0x7e7c53d9,0x9f400443,0x98a700b8,0x69c817ad}},	//   _torp, rció_, stně_, _syde,
   {{0xada60102,0x6f0453da,0x273953db,0x00000000}},	//   _загл, mpic, dèn_, --,
   {{0x9f4053dc,0x6f0453dd,0x442053de,0x64440103}},	//   pció_, lpic, _odi_, _obii,
   {{0x776253df,0x7ae853e0,0x442053e1,0x7658010b}},	//   _prox, _widt, _ndi_, _savy,
   {{0x765800d8,0x656353e2,0xc6a653e3,0x69c701b4}},	//   _pavy, _arnh, ерни, _øjen,
   {{0x442053e4,0x69c853e5,0x644453e6,0x69961761}},	//   _adi_, _tyde, _abii, _прех,
   {{0x442001f4,0x23d300b4,0x2a6c0a8a,0x00000000}},	//   _bdi_, _सरहद, _indb_, --,
   {{0x2ebe00c0,0x64440211,0x273901cb,0x00000000}},	//   ्तुत, _cbii, bèn_, --,
   {{0x366a03ad,0x78a253e7,0x442053e8,0xa8870340}},	//   _надо_, _imov, _ddi_, _яйца_,
   {{0x442053e9,0xa6aa1dbf,0x6f0401a2,0xaefb009e}},	//   _edi_, _عاشق_, dpic, _brùn,
   {{0xe5f70052,0x44204605,0xaefb009e,0x659404d9}},	//   _אזור_, _fdi_, _crùn, _шаку,
   {{0xceb4013b,0x00000000,0x00000000,0x00000000}},	//   zrət_, --, --, --,
   {{0x6d4700fb,0x644f11b4,0x752f0035,0x9f590176}},	// [4eb0] _spja, meci, ącze, _resó_,
   {{0x644f53ea,0x442053eb,0x645d5200,0x6d47009f}},	//   leci, _zdi_, ldsi, _ppja,
   {{0x4420001e,0x6d5a4644,0x7d1c012e,0xaefb0211}},	//   _ydi_, _štar, _cvrs, _grùn,
   {{0x673b1615,0x645d53ec,0x9f400382,0x273953ed}},	//   ytuj, ndsi, rciò_, yèn_,
   {{0x20091901,0x2a7e00d7,0x60cd00d0,0x645d01a6}},	//   mbai_, _botb_, mlam, idsi,
   {{0x2ebe1ad0,0xaa4538bb,0x78a211b8,0x644f0160}},	//   ्तृत, текл, _amov, heci,
   {{0x60cd0036,0x84ef046c,0xf2d4016b,0x00000000}},	//   olam, _घूंट_, װעק_, --,
   {{0x644f53ee,0x60cd53ef,0x673b0086,0x2009055c}},	//   jeci, nlam, ttuj, nbai_,
   {{0x644f375f,0x7528004e,0x442000ec,0x60cd014c}},	//   deci, erdz, _rdi_, ilam,
   {{0x2d850006,0x645d21bf,0x60cd1c52,0xb05b01ff}},	//   _üles_, edsi, hlam, _skäl,
   {{0x673b0bca,0x4420022e,0x644f53f0,0xe97500f3}},	//   stuj, _pdi_, feci, _جهاد,
   {{0x64a600d8,0x6f0453f1,0xe20a0d53,0x644f0138}},	//   тама, ypic, वर्ण_, geci,
   {{0x60cd31fd,0x96b50274,0x289a025a,0x8c1a076b}},	//   dlam, _искљ, _קינא, וורי,
   {{0x68eb043d,0x645d03bc,0xcb1200a5,0x672953f2}},	//   _higd, adsi, שלם_, mrej,
   {{0x644f53f3,0xa564004f,0x09e30033,0x00000000}},	//   beci, _مدين, নুরা, --,
   {{0x60cd53f4,0x68fc0332,0x6444022f,0x76412aab}},	//   glam, _érde, _ubii, lfly,
   {{0xc0e314b4,0x68eb53f5,0x7d1c0254,0xafe653f6}},	// [4ec0] ротк, _migd, _svrs, тоал,
   {{0x60cd53f7,0xaefb0019,0x68eb53f8,0x7641055b}},	//   alam, _trùn, _ligd, nfly,
   {{0xe0da0202,0x60cd53f9,0x321853fa,0x6f0453fb}},	//   _ово_, blam, mary_, spic,
   {{0x68eb53fc,0x6aca112b,0x6f0453fd,0x321853fe}},	//   _nigd, ित्र, ppic, lary_,
   {{0x03e40083,0x2480004e,0x2ca653ff,0xda7a0fa7}},	//   কুরী_, _moim_, riod_, дяй_,
   {{0x644f006a,0x67295400,0x32185401,0x60c45402}},	//   zeci, drej, nary_, loim,
   {{0xbea35403,0x7d1c068b,0x76415404,0x6da63810}},	//   _тарк, _uvrs, dfly, _рива,
   {{0x7d5702b5,0x8c460424,0xc983107b,0x60c45405}},	//   _בילד_, _шебе, руши, noim,
   {{0x644f5406,0x32180096,0x67295407,0x68eb14f4}},	//   veci, kary_, grej, _digd,
   {{0x60c40037,0x60cd0381,0x3aeb00f8,0x68eb03d0}},	//   hoim, zlam, _قبلی_, _eigd,
   {{0x644f5408,0x60cd5409,0x32180e7d,0x24550037}},	//   teci, ylam, dary_, هندس,
   {{0x52bd0517,0x60cd0095,0x3213540a,0x78a2540b}},	//   ोत्स, xlam, _sexy_, _umov,
   {{0x645d31bc,0x16030026,0x248401ff,0x60cd438e}},	//   rdsi, _श्वर_, ömma_, vlam,
   {{0x644f0169,0xc7d700a5,0x7afd540c,0x2ebe0096}},	//   seci, _סוגי_, _éste, ्तोत,
   {{0x60cd540d,0xb6d90070,0x61143851,0x00000000}},	//   tlam, _אַקט, идру, --,
   {{0xf0b400d8,0x64860079,0x00000000,0x00000000}},	//   айсь, _sóiv, --, --,
   {{0x200900d8,0x6d5a0254,0x9ed90be8,0x05c60066}},	// [4ed0] rbai_, _štap, емат_, _रुतब,
   {{0x60cd0657,0xd25100bf,0x00000000,0x00000000}},	//   slam, _اند_, --, --,
   {{0x60cd540e,0x67294cbf,0x00000000,0x00000000}},	//   plam, zrej, --, --,
   {{0x6adb1365,0x60c4011e,0xaac401cb,0x60cd013b}},	//   यग्र, coim, یتون, qlam,
   {{0xa09a02b5,0x0c241112,0x291e08b7,0x68eb540f}},	//   _נישט, рмін, _avta_, _rigd,
   {{0x67290bec,0xbbd30b4a,0x68eb5410,0x00000000}},	//   vrej, _तरीक, _sigd, --,
   {{0x98ac027b,0x38ca0118,0x127c016b,0x00000000}},	//   _ardı_, کاوی_, ואגע, --,
   {{0xc1740052,0x67295411,0x88c500b8,0x321804aa}},	//   שחק_, trej, _ověř, zary_,
   {{0x3f89012f,0x64860079,0x98be013a,0x00000000}},	//   nyau_, _móit, _astē_, --,
   {{0x67295412,0x24920298,0x24800160,0x00000000}},	//   rrej, _slym_, _soim_, --,
   {{0x32180187,0x76411cdb,0x68eb043d,0x34aa0610}},	//   vary_, rfly, _tigd, евно_,
   {{0x67295413,0x764110dd,0x32180067,0x00000000}},	//   prej, sfly, wary_, --,
   {{0x32185414,0x60c41c36,0x61e900a8,0x78a907c0}},	//   tary_, voim, əmlə, miev,
   {{0x78a95415,0x3ced0160,0xb6074c16,0x88c500fe}},	//   liev, _liev_, _рядк, _dvěř,
   {{0x60c45416,0x26c50f1f,0x32185417,0xa5ca0066}},	//   toim, molo_, rary_, _सुपौ,
   {{0x32185418,0x78a95419,0x26c5541a,0x00000000}},	//   sary_, niev, lolo_, --,
   {{0xddd505d3,0x3218189a,0x6486004f,0x60c4541b}},	// [4ee0] _rozš, pary_, _dóit, roim,
   {{0x35a80084,0x94190095,0x78a900a5,0x20f8011c}},	//   _छेड़, disə_, hiev, _učio_,
   {{0x60c403e6,0x26c512a2,0xa2c109b8,0x78a9541c}},	//   poim, iolo_, लकर्, kiev,
   {{0x20562c21,0x26c51f97,0x317b02b5,0x628e541d}},	//   _стор, holo_, _נאכד, lkbo,
   {{0x26c5541e,0x7f7509eb,0xa3aa22c7,0x5fe00a44}},	//   kolo_, _курц, _गेम_, पेशल,
   {{0x3b060055,0xc33302da,0x628e541f,0x386f0107}},	//   rpoq_, מוד_, nkbo, _angr_,
   {{0x26c55420,0x00000000,0x00000000,0x00000000}},	//   dolo_, --, --, --,
   {{0x7d030138,0x00000000,0x00000000,0x00000000}},	//   ínse, --, --, --,
   {{0x64860037,0x26c55421,0x3af90260,0x386f01ed}},	//   _lóis, folo_, _gèp_, _dngr_,
   {{0x0f570052,0x9b930082,0x26c51680,0x386f0159}},	//   ניים_, _الكت, golo_, _engr_,
   {{0x45d40f08,0xba290987,0x00000000,0x00000000}},	//   ронс, _جسقم_, --, --,
   {{0x628e0afc,0xceb4013b,0x00000000,0x00000000}},	//   ekbo, xsən_, --, --,
   {{0x26c501ba,0x752f0067,0x00000000,0x00000000}},	//   bolo_, ącza, --, --,
   {{0x26c50133,0x39ae00a8,0x6aaa016e,0xb05b00c3}},	//   colo_, _kəs_, niff, _ikäi,
   {{0x661a5422,0xa194010b,0x64860079,0x20f82d5b}},	//   matk, барч, _cóis, _učil_,
   {{0x661a5423,0x6aaa01ae,0x88bc00b8,0x98a700af}},	//   latk, hiff, _uvěd, mună_,
   {{0xb4c30026,0xceb40095,0x443b5424,0x2ba43877}},	// [4ef0] ्ती_, rsən_, _icq_, _खेला,
   {{0x645f06c4,0x661a006c,0x648601ef,0x78a90036}},	//   _haqi, natk, _fóis, ziev,
   {{0x5d555425,0xf1ab00d1,0x236900ac,0x13b40647}},	//   ркет, _ساده_, _hraj_, _نصیح,
   {{0x44fa08e3,0x2369308b,0x3af9142f,0x661a005d}},	//   _më_, _kraj_, _pèp_, hatk,
   {{0x09dd5426,0x661a0f1a,0x78a95427,0x44fa0031}},	//   मध्य, katk, viev, _lë_,
   {{0xb4c300db,0x44fa0173,0x2ba400a1,0x39ae00a8}},	//   ्तु_, _oë_, _खेळा, _bəs_,
   {{0x44fa5428,0x661a5429,0x78a90a75,0x26c502fb}},	//   _në_, datk, tiev, volo_,
   {{0x645f542a,0x7d010160,0x1d340043,0x3af90107}},	//   _naqi, _cârţ, _ынся, _tèp_,
   {{0x26c501d3,0x78a9542b,0x6c84004f,0x236901e8}},	//   tolo_, riev, _القم, _nraj_,
   {{0x201b3fba,0x661a542c,0x44fa01f4,0x78a9542d}},	//   haqi_, gatk, _bë_, siev,
   {{0x26c5542e,0x291a1575,0xfe3600a5,0x78a9542f}},	//   rolo_, špar_, ברתי_, piev,
   {{0x26c50273,0xe3660836,0x23690118,0x64a40009}},	//   solo_, акми, _braj_, lđiz,
   {{0x661a0f1a,0x645f012f,0x26c55430,0x64860098}},	//   batk, _daqi, polo_, _sóis,
   {{0x412a5431,0x6486004f,0x27ff0382,0xee0f0567}},	//   кого_, _cóir, lcun_, िरोध_,
   {{0x7c3b0033,0x645f0034,0x91e65432,0x628e5433}},	//   _ocur, _faqi, рове, rkbo,
   {{0x27ff5434,0x20f80a18,0x7bcd0029,0x7c3b5435}},	//   ncun_, _učim_, ļauj, _ncur,
   {{0x44fa01f4,0xee3a41fe,0xa3e55436,0x60dd0260}},	// [4f00] _zë_, кна_, भेद_, _dhsm,
   {{0x2bdc111e,0x27e001a6,0x00000000,0x00000000}},	//   _बरबा, _ùine_, --, --,
   {{0x645f5437,0xc27b0052,0x2b4d5438,0x29050345}},	//   _yaqi, _סרטי, _apec_, _ntla_,
   {{0x8c462aac,0xdd8f17bd,0xeb060165,0xae4400b5}},	//   реде, بوم_, ачко, _گھرو,
   {{0x661a0ec0,0x39ae0095,0x200200d7,0x29055439}},	//   yatk, _səs_, _ifki_, _atla_,
   {{0x7c3b543a,0x00000000,0x00000000,0x00000000}},	//   _ecur, --, --, --,
   {{0x6aaa543b,0x661a543c,0x00000000,0x00000000}},	//   riff, vatk, --, --,
   {{0x6d5c543d,0x6b8b543e,0x20004fc1,0x661a1581}},	//   _isra, bygg, ncii_, watk,
   {{0x44fa071f,0x661a543f,0xd6da5440,0x20050095}},	//   _së_, tatk, кто_, _əli_,
   {{0x7afd0831,0x3cf801b4,0x6d5c009e,0x64460345}},	//   _ésta, _kurv_, _ksra, efki,
   {{0x44fa08e3,0x661a2e11,0x200001ba,0xb05b00c3}},	//   _që_, ratk, kcii_, _ikäv,
   {{0xb4c32c29,0x661a5441,0x69da5442,0xf746218b}},	//   ्ते_, satk, _izte, _ведо,
   {{0x661a5443,0x6d5c011e,0x645f013b,0x6e3c03d0}},	//   patk, _lsra, _vaqi, _ocrb,
   {{0x44fa5444,0x171b02b8,0x6d4e08c8,0x236901ba}},	//   _të_, _יודע, _opba, _vraj_,
   {{0x645f0516,0xbbd30e9b,0xa0a75445,0x30a75446}},	//   _taqi, _तर्क, ашал, арав,
   {{0xe3b80457,0x64a40d6e,0x00000000,0x00000000}},	//   ğır_, _маја, --, --,
   {{0x6d5c128f,0xe3b80463,0x6618006d,0x3ef80012}},	// [4f10] _asra, şır_, _kevk, интэ_,
   {{0xde19036b,0x425500d2,0x44395447,0x5d6700af}},	//   اقات_, _اندر, lgs_, итез,
   {{0xc21200a5,0x2d875448,0x3cf80282,0x2b4d5449}},	//   _מהי_, âne_, _curv_, _spec_,
   {{0x4439544a,0x6285544b,0x315602b5,0x67220169}},	//   ngs_, _hoho, _פירן_, _ovoj,
   {{0x69da0291,0x6285544c,0x66cf03d0,0x6b653b4d}},	//   _azte, _koho, søki, скла,
   {{0x6285544d,0x20193448,0x6b8b5200,0x66181b0e}},	//   _joho, _hesi_, rygg, _nevk,
   {{0x201919c6,0x6285544e,0x8d95004f,0x69da0035}},	//   _kesi_, _moho, _الأش, _czte,
   {{0xb4c3544f,0x20195450,0x6ca45451,0x6285028b}},	//   ्तो_, _jesi_, _друж, _loho,
   {{0xb8fe1033,0x20195452,0xb4c3000c,0xaefb01da}},	//   _दी_, _mesi_, ्तै_, _brùi,
   {{0x62855453,0x27ff2f88,0x6d5c0159,0x443911b7}},	//   _noho, scun_, _ysra, egs_,
   {{0x74ea5454,0x752f0035,0x79a75455,0xaefb01da}},	//   лдог_, ączo, _трае, _drùi,
   {{0x44395456,0x6486004f,0xb4d2227d,0x201911b4}},	//   ggs_, _cóip, वते_, _nesi_,
   {{0x62855457,0x26d912c3,0xe60e5458,0xd8d61804}},	//   _boho, ïsos_, _нд_, _פונט_,
   {{0xcb120122,0xd29501e0,0xaefb009e,0x443932c5}},	//   הלך_, орсь, _grùi, ags_,
   {{0x62850e6a,0x2019005d,0x40960f9e,0x2ef90009}},	//   _doho, _besi_, брат, _ausf_,
   {{0x387f16ab,0x20195459,0x10a32d7a,0xe0df4564}},	//   njur_, _cesi_, писн, _chò_,
   {{0x2019545a,0xa0670133,0x2000545b,0x777b002a}},	// [4f20] _desi_, щата_, rcii_, nxux,
   {{0x62853f01,0xdc1013f0,0x20000036,0x1fb500d4}},	//   _goho, ार्ड_, scii_, істр,
   {{0x629c004f,0x387f0093,0x7bdb018e,0xda02021a}},	//   mhro, kjur_, _azuu, _र्गत_,
   {{0xeb9a0ea7,0x6285545c,0x2019002f,0xa5da0070}},	//   лие_, _zoho, _gesi_, אַדי,
   {{0x7c650118,0x387f01ff,0x69da00b5,0xdfd2026e}},	//   تالل, djur_, _szte, _ريس_,
   {{0x6e960514,0x629c545d,0x6d5c0037,0x20100067}},	//   _السا, nhro, _tsra, łnić_,
   {{0x6722545e,0xd7fa034b,0x5fac02cb,0x6d5c4f18}},	//   _svoj, луп_, _घेतल, _usra,
   {{0xceb40095,0xb4d229ce,0x387f545f,0x8c430f94}},	//   ksək_, वतो_, gjur_, _несе,
   {{0x7f445460,0xdddc002d,0xfce30009,0x672000cd}},	//   ntiq, _forţ, _хото, usmj,
   {{0xb4c3021a,0x3ce6308a,0x1f5b0d85,0x44395461}},	//   ्त्_, lmov_, נדיא, wgs_,
   {{0x62853bdb,0x69da5462,0x66180044,0x98c4027d}},	//   _roho, _uzte, _vevk, ştım_,
   {{0x67220bcc,0xc9770bed,0xfbdc09f9,0x44391eef}},	//   _tvoj, _לגבי_, _बराम, ugs_,
   {{0x62855463,0x44395464,0xb4c3007e,0x20195465}},	//   _poho, rgs_, ्तौ_, _resi_,
   {{0x65942729,0x629c026e,0x00000000,0x00000000}},	//   _малу, ghro, --, --,
   {{0x2019027a,0xe3b80225,0xc693016b,0xe0df00cc}},	//   _pesi_, şıp_, _מאס_, _phò_,
   {{0x3ce60770,0x3eaa0223,0x00000000,0x00000000}},	//   jmov_, _ambt_, --, --,
   {{0x44295466,0x6285033a,0x644d01d7,0x2019127d}},	// [4f30] _ida_, _toho, _ibai, _vesi_,
   {{0x43d400ad,0x68fa19d5,0x41555467,0x201901cb}},	//   _عزيز, _outd, _двос, _wesi_,
   {{0x20195468,0x7f440248,0xe0df00e2,0x44290147}},	//   _tesi_, atiq, _thò_, _kda_,
   {{0x4255006c,0x3e8500b8,0xdddc0139,0x00000000}},	//   _انگر, _sítě_, _sorţ, --,
   {{0xa03a00c2,0x644d004f,0x7f445469,0x903a0070}},	//   _דערפ, _mbai, ctiq, _דערה,
   {{0x44291699,0x660d0254,0xf1bd00e7,0x8cd90067}},	//   _lda_, _đako, _ईशान, _फीरो,
   {{0x644d003b,0x4429546a,0x6f0d546b,0x3ce6011e}},	//   _obai, _oda_, lpac, bmov_,
   {{0xa3aa3914,0x6d453303,0x7afd0831,0x4429546c}},	//   _गइल_, mtha, _ésto, _nda_,
   {{0x660406d0,0x7c29546d,0xdddc0139,0x00000000}},	//   _şika, _ider, _torţ, --,
   {{0x644d546e,0xb4d202d1,0x44292cba,0x6d45546f}},	//   _abai, वत्_, _ada_, otha,
   {{0x6d455470,0x442902ea,0x7afb0086,0x321a00ee}},	//   ntha, _bda_, _huut, _repy_,
   {{0x6d450297,0x44295471,0x7afb2ed8,0x644d009e}},	//   itha, _cda_, _kuut, _cbai,
   {{0x44295472,0x629c4c34,0x439300d8,0x7afb5473}},	//   _dda_, thro, даўс, _juut,
   {{0x7afb1ba4,0x6d455474,0x2bdc0534,0xb5aa00fd}},	//   _muut, ktha, _बरसा, ائیے_,
   {{0x044601d3,0xa187110a,0x7afb5475,0x6f0d0051}},	//   _дейн, обра_, _luut, epac,
   {{0x7c2901d2,0x644d0211,0x6d450c9c,0xdddc1575}},	//   _nder, _gbai, dtha, _norš,
   {{0x7afb0626,0x6d450297,0x2caf0120,0x7f4400f7}},	// [4f40] _nuut, etha, digd_, utiq,
   {{0x6d455476,0x7c295477,0x442916dc,0x7f445478}},	//   ftha, _ader, _zda_, rtiq,
   {{0x7f445479,0x91e6547a,0xed5a0a2b,0x225811ad}},	//   stiq, _фоне, рое_, merk_,
   {{0x8236006c,0x4429547b,0x7f44547c,0x59c400ab}},	//   _ارکا, _xda_, ptiq, _लुगर,
   {{0x6d450094,0x7c29001e,0xdee6547d,0x7ae1009e}},	//   atha, _dder, _моми, _bhlt,
   {{0x6da60011,0x6d45547e,0x7c29547f,0x752f004e}},	//   _дига, btha, _eder, ńczy,
   {{0xdd92006c,0xdddc00ea,0x6d455480,0xb05b31ea}},	//   _غور_, _forš, ctha, _fjäd,
   {{0xf8ba00c8,0xd90d00f8,0x6ee90009,0xdddc02f6}},	//   ুষ্ঠ, این_, _džbu, _gorš,
   {{0xda0b00a1,0xa3aa0006,0x225811ad,0x44295481}},	//   _स्वत_, _गेल_, kerk_, _rda_,
   {{0x442901a8,0x2b4600d7,0x68fa00a8,0x09e60c87}},	//   _sda_, mtoc_, _tutd, _дозн,
   {{0x7c29054e,0xa80600d8,0x6f0d5482,0x00000000}},	//   _yder, _дзел, zpac, --,
   {{0x6f0d5483,0x290e5484,0xe4a701e0,0xbfa300cc}},	//   ypac, mpfa_, ірно, _biể,
   {{0x443f00ea,0xbbb831d7,0x00000000,0x00000000}},	//   ļu_, _अशोक, --, --,
   {{0x6d4500e9,0x443f5485,0x00000000,0x00000000}},	//   ytha, żu_, --, --,
   {{0x26cc15a2,0x34955486,0x44295487,0x60d600e9}},	//   modo_, _накр, _tda_, flym,
   {{0x644d3fba,0x44295488,0xd5b900d4,0x6d4501e8}},	//   _ubai, _uda_, _усі_, vtha,
   {{0x68e2009d,0x22583ede,0x4aca1a0c,0x6d450090}},	// [4f50] _mhod, berk_, ाकाव, wtha,
   {{0xa2b40086,0x7afb03a6,0x7d6b18e0,0x20f80409}},	//   _обыч, _ruut, ишев_, _ačiu_,
   {{0x68e2024e,0x6d455489,0x7afb127d,0xdddc0009}},	//   _ohod, utha, _suut, _porš,
   {{0x6d45548a,0x7afb0f67,0xaefb0284,0x2b5f38bc}},	//   rtha, _puut, _brùt, _psuc_,
   {{0x0f790779,0x6d45548b,0xcb691676,0x3f790070}},	//   _האָב, stha, сале_, _האָס,
   {{0x24893889,0x533800a5,0x60cd034d,0x7ce3018d}},	//   _loam_, קנון_, loam, kõrg,
   {{0x26cc548c,0x68e20284,0x7d24002d,0x752f0067}},	//   dodo_, _bhod, _офте, ączk,
   {{0x68e20f86,0x60cd548d,0x7afb548e,0x7c29548f}},	//   _chod, noam, _tuut, _uder,
   {{0x68e200e0,0x00000000,0x00000000,0x00000000}},	//   _dhod, --, --, --,
   {{0x26cc002a,0x776901dd,0x68e200ee,0x60cd2257}},	//   godo_, rvex, _ehod, hoam,
   {{0x22585490,0x68e21861,0xd46a0cc7,0x60cd02ee}},	//   verk_, _fhod, бине_, koam,
   {{0x22583d7d,0x2a653025,0x649a2fc1,0x68e2009f}},	//   werk_, _halb_, стор_, _ghod,
   {{0x68e95491,0x26cc5492,0x22581e7e,0x2489021d}},	//   mmed, bodo_, terk_, _doam_,
   {{0x68e95493,0x2cbf013c,0x68e20237,0x98a0010b}},	//   lmed, _ljud_, _zhod, čią_,
   {{0x409617e3,0x5bb8111a,0x24895494,0x66dd0118}},	//   прат, _अश्व, _foam_, cèka,
   {{0x03261906,0xb05b022a,0x68e95495,0x23600221}},	//   _един, _skär, nmed, _tsij_,
   {{0x44225496,0x2d875497,0x28cc018d,0x225803c4}},	// [4f60] mak_, änen_, ावति, perk_,
   {{0x44225498,0x22160421,0x60d60055,0x78bb00f4}},	//   lak_, _эфир, slym, hnuv,
   {{0x442206a2,0x60cd002a,0x60d6011e,0x78bb0506}},	//   oak_, boam, plym, knuv,
   {{0x44225499,0x60cd0015,0x68e9092f,0xa3b10253}},	//   nak_, coam, jmed, _टेड_,
   {{0x68e2549a,0x442206a2,0x00000000,0x00000000}},	//   _rhod, iak_, --, --,
   {{0x44222bab,0x68e215b5,0x68e9549b,0x00000000}},	//   hak_, _shod, emed, --,
   {{0x4422549c,0x2007006a,0xceb302b5,0xda650c74}},	//   kak_, śnie_, _טיש_, باني,
   {{0x4422549d,0x7ce300be,0x78bb00f4,0x6f0d0118}},	//   jak_, võrg, gnuv, _èncè,
   {{0x44221760,0x68e205cd,0x3f80549e,0x00000000}},	//   dak_, _vhod, nxiu_, --,
   {{0x60cd549f,0x59a7007c,0x442254a0,0x24570023}},	//   zoam, _केकर, eak_, _ầm_,
   {{0x1dbe05f7,0x26cc00d8,0x68e954a1,0x442254a2}},	//   ्थित, rodo_, bmed, fak_,
   {{0x442254a3,0x68e254a4,0x7c220b5b,0x00000000}},	//   gak_, _uhod, naor, --,
   {{0xb4bd063f,0x2489021d,0x60cd07bb,0x00000000}},	//   _आदी_, _voam_, voam, --,
   {{0x1dbe0d1f,0xaadc06fe,0xcfc40033,0x7ce3018d}},	//   ्थात, यतिक, ্ধান, põrg,
   {{0x31c42b8e,0x7c2205ee,0x765a0763,0x60cd54a5}},	//   еств, kaor, mety, toam,
   {{0x442254a6,0x63a91449,0x765a54a7,0x753a54a8}},	//   cak_, úens, lety, mutz,
   {{0x290c0370,0x60cd358d,0x386619fd,0xf3ff0183}},	// [4f70] _ltda_, roam, _maor_, ldão_,
   {{0x60cd54a9,0x765a54aa,0xaefb01da,0x290c0107}},	//   soam, nety, _brùr, _otda_,
   {{0x753a02bf,0xf3ff0279,0x68e954ab,0x60cd54ac}},	//   nutz, ndão_, ymed, poam,
   {{0x765a54ad,0x00000000,0x00000000,0x00000000}},	//   hety, --, --, --,
   {{0x753a506f,0x68e92c09,0x04b6016b,0x7ce3018d}},	//   hutz, vmed, וּסט_, võrd,
   {{0x442254ae,0x9f960052,0x2a65003c,0x88bc00b8}},	//   zak_, _חדשה_, _qalb_, _dvěm,
   {{0x44220ec1,0x20f854af,0x68e954b0,0x64ab0355}},	//   yak_, _učit_, tmed, přih,
   {{0x2cbf046a,0xd7090171,0x442201d7,0x38661861}},	//   _ujud_, оние_, xak_, _caor_,
   {{0xcb3401d3,0x44220147,0x78bb0225,0x386626c9}},	//   _петъ, vak_, rnuv, _daor_,
   {{0x442254b1,0x68e954b2,0x78bb021d,0xa3c306bc}},	//   wak_, smed, snuv, ्थन_,
   {{0x442254b3,0x68e954b4,0x753a06a2,0xe5a531fb}},	//   tak_, pmed, gutz, фини,
   {{0x7e6754b5,0x442206a2,0x68360457,0x66dd0118}},	//   _lajp, uak_, rüdü, cèkn,
   {{0x442254b6,0x765a54b7,0xb3831eb9,0xd62954b8}},	//   rak_, bety, влял, _доле_,
   {{0x7e6754b9,0x7ea054ba,0x6d550051,0x753a0065}},	//   _najp, _köpe, _opza, butz,
   {{0xaca30019,0x2d4700be,0x21670d6e,0x00000000}},	//   _chừn, jõe_, мири_, --,
   {{0x98a00a78,0x25d60070,0xe0da02a4,0xf8dd00be}},	//   čić_, _קוקן_, іва_, मतिय,
   {{0x4420002d,0x0443002d,0xf26a034b,0x6d550228}},	// [4f80] _iei_, _реын, _дипл_, _apza,
   {{0xf7673872,0x442008a6,0x3f80002a,0x00000000}},	//   _یا_, _hei_, rxiu_, --,
   {{0xa0a615c0,0xa2ad0026,0x629e0036,0x00000000}},	//   _жанд, ुचर्, _ilpo, --,
   {{0x44200a93,0x80dc0033,0xa3d20577,0x00000000}},	//   _jei_, _মূর্, _वडा_, --,
   {{0x7c2254bb,0xfaa6141d,0x26c300cd,0xd5cf25d8}},	//   raor, мадо, čjoj_, _सुसज,
   {{0x442054bc,0x3866006e,0x7c2203d0,0x00000000}},	//   _lei_, _saor_, saor, --,
   {{0xd90d0148,0x2f04022a,0x44202f4b,0x765a2442}},	//   میل_, _hög_, _oei_, vety,
   {{0x442054bd,0x7ea00282,0x00000000,0x00000000}},	//   _nei_, _döpe, --, --,
   {{0x6f0202aa,0x765a54be,0xb6f40431,0x569400af}},	//   íoch, tety, нзиј, еапт,
   {{0x7c2054bf,0x753a2543,0x69961172,0x644400ec}},	//   _hemr, tutz, _орех, _acii,
   {{0x442054c0,0xf76f01ca,0x2f04008a,0xce3700a5}},	//   _bei_, های_, _lög_, ואית_,
   {{0x44200012,0x765a54c1,0x753a06a2,0xf3ff0279}},	//   _cei_, sety, rutz, rdão_,
   {{0x44202f6b,0xd7e206bc,0x4992006c,0x7d09011c}},	//   _dei_, _परिच, _سیکر, _česm,
   {{0x80dc0083,0x7d0321c0,0xddd500ac,0x753a54c2}},	//   _মূল্, ínsk, _rozž, putz,
   {{0xd6570bed,0xd5af54c3,0xe63b00a5,0xd4db0079}},	//   _חיות_, _рс_, _ותוכ, _وبعض_,
   {{0x7c2054c4,0x442054c5,0x629e00ec,0x660d0506}},	//   _nemr, _gei_, _elpo, _đaki,
   {{0x645d54c6,0xe3b00118,0x7e6754c7,0x00000000}},	// [4f90] mesi, _پري_, _pajp, --,
   {{0x44200120,0x7d1c00e5,0xaca300cc,0x00000000}},	//   _zei_, _bwrs, _thừn, --,
   {{0x7e67006d,0x7d1c099e,0x00000000,0x00000000}},	//   _vajp, _cwrs, --, --,
   {{0x645d54c8,0x8b6b0029,0x6e2e03d0,0x4420021d}},	//   nesi, ņēmē, _edbb, _xei_,
   {{0x511f0006,0x7e6704c4,0x628e00cd,0xaefb01da}},	//   _बबुआ_, _tajp, žnoš, _grùp,
   {{0xa9692235,0x2d470279,0x09b00033,0x7d1c099e}},	//   зика_, põe_, _ছড়া, _fwrs,
   {{0x645d54c9,0x7c2000da,0xac190b3b,0x00000000}},	//   kesi, _femr, _нову_, --,
   {{0x645d54ca,0x6e250159,0xe3b800d0,0x7c2000e0}},	//   jesi, lahb, ğız_, _gemr,
   {{0x442054cb,0x59e10035,0xbb190079,0x6444009e}},	//   _rei_, _फरवर, _رياض_, _rcii,
   {{0x44203945,0xba7704a3,0x7c2000da,0x45851b5d}},	//   _sei_, _تارت, _zemr, егов,
   {{0x04463e3d,0xd46a15d5,0x4815010b,0x00000000}},	//   ненн, пине_, _змес, --,
   {{0x645d54cc,0x64ca3efe,0xf77102de,0xd46a1765}},	//   gesi, रवेश, _مات_, чиме_,
   {{0xe72e54cd,0x44202252,0xaca30028,0x569501c8}},	//   _ще_, _vei_, _chứn, _падт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442054ce,0x81d80033,0xf09f009e,0xbbdc00b4}},	//   _tei_, ়েন_, _blà_, _बर्क,
   {{0x645d54cf,0x20e802b1,0xf41f0421,0x00000000}},	//   cesi, ißig_, ljän_, --,
   {{0x67290083,0x96a600b4,0x8fa33f20,0x6f1d099e}},	// [4fa0] nsej, टोकॉ, гате, _cwsc,
   {{0x6da654d0,0x764154d1,0x7c2043f3,0x69b0007c}},	//   низа, ngly, _semr, _अइली,
   {{0xe3bf0391,0x20060391,0x7c2054d2,0x20070035}},	//   maña_, ñois_, _pemr, śnia_,
   {{0xac0754d3,0x61e10ab6,0x0ca90037,0x99620355}},	//   енца_, ülle, وطني_, tíže_,
   {{0xc5f80080,0xeb971c36,0x1dd000ab,0x7cfa0355}},	//   ldēt_, ниц_, _तुरत, _důra,
   {{0x996654d4,0x645d54d5,0x6e2500d7,0xef110070}},	//   етил, zesi, cahb, _כּל_,
   {{0xdca63d35,0x645d1889,0x672b00d4,0xed5700c3}},	//   _зави, yesi, _avgj, _пор_,
   {{0xd90d00f8,0x645d0042,0x68f9099e,0x00000000}},	//   زیه_, xesi, _ciwd, --,
   {{0xb9070429,0xdca354d6,0x645d54d7,0xe3bf01ed}},	//   _मी_, _сати, vesi, kaña_,
   {{0x645d54d8,0xa96a0fb4,0x95ca34b5,0x76413d14}},	//   wesi, _низа_, зума_, ggly,
   {{0x7d0954d9,0xd5ba4232,0x645d54da,0xe3bf0138}},	//   _česk, яси_, tesi, daña_,
   {{0x7afa54db,0xddc700ea,0x779200d1,0x00000000}},	//   _hitt, _sajū, _میبا, --,
   {{0x645d363a,0x087702b5,0x200901e8,0x7afa54dc}},	//   resi, _רעדט_, vcai_, _kitt,
   {{0x7afa003c,0x877b134d,0xe3bf0453,0x3ce7046c}},	//   _jitt, _מאדי, gaña_, _छीने_,
   {{0x7afa54dd,0xf09f01f7,0x00000000,0x00000000}},	//   _mitt, _plà_, --, --,
   {{0x7afa54de,0x7bde004e,0x645d01f4,0x69da1e8b}},	//   _litt, ępuj, qesi, _myte,
   {{0x9f340185,0xe3bf00de,0x6e2554df,0x00000000}},	// [4fb0] леті, baña_, tahb, --,
   {{0x7afa54e0,0xa3aa03e2,0x6eba052f,0x3f87011c}},	//   _nitt, _गेट_, ्वगु, ćnu_,
   {{0x81d80083,0xeab10df3,0x2009028b,0x69da2a5e}},	//   ়েব_, یعت_, pcai_, _nyte,
   {{0x7c8454e1,0x7afa01d6,0xa3e800be,0x61e502a7}},	//   луче, _aitt, _भरम_, _izhl,
   {{0x7afa54e2,0x69da54e3,0x5fe41645,0xdcee023a}},	//   _bitt, _ayte, _бірж, _grbč,
   {{0x69da54e4,0x7afa0133,0xc5f80228,0x00000000}},	//   _byte, _citt, ndēs_, --,
   {{0x7afa4d67,0x7f4d035f,0xa96601e0,0x291e0090}},	//   _ditt, ltaq, вища_, _cwta_,
   {{0x7afa00fb,0xa3c30fbf,0xe3bf0300,0x672954e5}},	//   _eitt, ्था_, zaña_, tsej,
   {{0x7f4d013b,0x69c80176,0x81d70033,0x7afa54e6}},	//   ntaq, _exde, িধি_, _fitt,
   {{0x67290ac8,0x7afa54e7,0xd6ce07f6,0x7c2d0093}},	//   rsej, _gitt, يقي_, ðarf,
   {{0x672954e8,0x64a6316a,0x1fde0084,0x9aa4006c}},	//   ssej, вана, _मर्ड, _حملو,
   {{0x7afa54e9,0x7bdb001c,0x81d70033,0x22940523}},	//   _zitt, _kyuu, িধা_, _läkt_,
   {{0xe3bf2b83,0xccf202b5,0x386d29b2,0x7ea001ff}},	//   taña_, יכט_, mder_, _löpa,
   {{0x386d0075,0x644100c7,0x00000000,0x00000000}},	//   lder_, ėlia, --, --,
   {{0xaca3098b,0xe3bf1e6e,0xa01b013c,0xe5a201e0}},	//   _nhữn, raña_, _onöd, _вищи,
   {{0x3a27010d,0xe3bf0300,0xafe654ea,0x92b20033}},	//   hanp_, saña_, вобл, টকে_,
   {{0xe3bf1166,0xb05b06d7,0x64560232,0x386d54eb}},	// [4fc0] paña_, _tjän, _ibyi, ider_,
   {{0xb05b06d7,0x386d016e,0x00000000,0x00000000}},	//   _hjäl, hder_, --, --,
   {{0x7bdb0118,0x443201c0,0x2d9c016f,0x7afa0b17}},	//   _ayuu, _kdy_, áve_, _ritt,
   {{0x7afa54ec,0x386d54ed,0x6aca54ee,0x6aa154ef}},	//   _sitt, jder_, ाक्र, _allf,
   {{0xef170086,0x69da0a2d,0x8c43031a,0x46d10066}},	//   _имя_, _syte, рече, हवाह,
   {{0x386d29a4,0x63890031,0x61e90355,0xdb1100b5}},	//   eder_, _hënë, řele, ágáb,
   {{0x69da01d2,0x7afa54f0,0x98c63626,0x27e00009}},	//   _qyte, _vitt, ксил, _šin_,
   {{0x7afa54f1,0xfce60a55,0x629c0031,0x443254f2}},	//   _witt, _робо, hkro, _ndy_,
   {{0x7afa54f3,0xc6f80ebb,0x473403fa,0xa01b0298}},	//   _titt, нних_, ћнос, _koör,
   {{0x443254f4,0x7afa54f5,0x629c54f6,0x645604fb}},	//   _ady_, _uitt, jkro, _abyi,
   {{0xceb30052,0x2294007c,0x629c431e,0x7c2d008d}},	//   שית_, _läks_, dkro, ðarg,
   {{0x79b70052,0x63890031,0x629c54f7,0x00000000}},	//   _בלבד_, _nënë, ekro, --,
   {{0xa3e8073f,0x443205ae,0x00000000,0x00000000}},	//   _भरण_, _ddy_, --, --,
   {{0x28ae0006,0x443254f8,0x78a219cd,0x70bd1604}},	//   जोरि, _edy_, _hlov, ्क्ल,
   {{0xe2f801e0,0x78a254f9,0xb05b013c,0x403554fa}},	//   тері_, _klov, _fjäl, левс,
   {{0x443254fb,0x30a454fc,0x3a2702e9,0x7f4d54fd}},	//   _gdy_, арув, zanp_, ttaq,
   {{0xe3bf09ab,0x26de3367,0x2d8e02b1,0x1eab0405}},	// [4fd0] maño_, olto_, äfen_, وائي_,
   {{0x7f4d2bf4,0xa3e854fe,0x78a20a17,0x2ebf170c}},	//   rtaq, _भरत_, _llov, ्वेत,
   {{0x386d54ff,0x7f4d5500,0x78a200cb,0x4432001e}},	//   yder_, staq, _olov, _ydy_,
   {{0x6acb052f,0x27e65501,0xe7e20325,0x23690055}},	//   िव्र, _ozon_, _परंप, _ksaj_,
   {{0x6f020079,0x00000000,0x00000000,0x00000000}},	//   íoct, --, --, --,
   {{0x386d3adc,0x78a25502,0x2a7e055c,0x00000000}},	//   wder_, _alov, _cntb_, --,
   {{0x27e6006c,0x78a200fe,0x79a70382,0x00000000}},	//   _azon_, _blov, ърде, --,
   {{0x2ca65503,0x386d5504,0xa8250d4f,0x7c2d008d}},	//   chod_, uder_, اکان, ðard,
   {{0x386d5505,0xfbb70067,0x00000000,0x00000000}},	//   rder_, _अधिम, --, --,
   {{0xb05b06d7,0x386d3574,0x7ea001ff,0x78a2081b}},	//   _själ, sder_, _löpn, _elov,
   {{0x236900da,0x39150969,0x69c400af,0x78a20a8a}},	//   _asaj_, _смер, şier, _flov,
   {{0x3a251ad1,0xe3bf00de,0x79b6011d,0x952200fd}},	//   _help_, gaño_, _גלעד_, حکوم,
   {{0x29055506,0x629c0124,0x753a0065,0x00000000}},	//   _hula_, tkro, artz, --,
   {{0x29055507,0x2d7300cb,0x2ebf035d,0x00000000}},	//   _kula_, _oće_, ्वोत, --,
   {{0x29055508,0x629c039b,0xe3bf0300,0x42e70009}},	//   _jula_, rkro, baño_, умро_,
   {{0x29055509,0x629c550a,0x41d2021a,0xa0672faf}},	//   _mula_, skro, _दुःस, ласа_,
   {{0x2905550b,0xa3e80d43,0x3fe6146b,0xc0e3010b}},	// [4fe0] _lula_, _भरि_, ужав, сотк,
   {{0xa3c33e9e,0x11d61301,0x290500f6,0x00000000}},	//   ्थर_, _متجد, _oula_, --,
   {{0x2176550c,0x88bc01c0,0x2ca6550d,0x2a6c009e}},	//   _супр, _květ, thod_, _radb_,
   {{0x64462bab,0x6adc0e62,0xa3e80f06,0x673b550e}},	//   ngki, यत्र, _भरा_, kruj,
   {{0x2905550f,0x60c45510,0x6d4101ff,0x6ab82ea7}},	//   _aula_, mnim, _ålan, tivf,
   {{0x78a25511,0x29055512,0x60c45513,0xaa585514}},	//   _slov, _bula_, lnim, тику_,
   {{0x60c45515,0x24800254,0x2905022f,0x3a2501ef}},	//   onim, _onim_, _cula_, _delp_,
   {{0x290503be,0x47340947,0x6f06022f,0x673b0009}},	//   _dula_, анис, _kukc, fruj,
   {{0x7c930082,0xec13006c,0x290501a2,0xf0930397}},	//   _القص, _چوہد, _eula_, מנה_,
   {{0x24800dc3,0x05b2021a,0x2905017b,0x64460051}},	//   _anim_, ुपलब, _fula_, egki,
   {{0xe3bf1111,0x60c41be2,0x24190f99,0x00000000}},	//   taño_, knim, коны_, --,
   {{0x60c45516,0xa3c300c0,0x13f501e0,0x7e6e0228}},	//   jnim, ्थल_, изня, _labp,
   {{0x60c45517,0x6eeb1c28,0x3a255518,0x2f0d07c0}},	//   dnim, lübe, _yelp_, _oľga_,
   {{0x24805519,0x6d5c27a8,0xc6270083,0x236902c6}},	//   _enim_, _opra, _মাথা_, _vsaj_,
   {{0x6eeb551a,0x81dd0083,0x30eb1888,0x29050176}},	//   nübe, তেন_, ефан_, _xula_,
   {{0x30150bfe,0x60c4551b,0x23690221,0xdddc0168}},	//   рдар, gnim, _tsaj_, _borž,
   {{0x6d5c551c,0x6d4e009f,0x442b551d,0xe4502ac4}},	// [4ff0] _apra, _aqba, mac_, _رضي_,
   {{0x32550810,0x442b551e,0x88bc00b8,0x3eba0079}},	//   _твор, lac_, _zvět, gipt_,
   {{0x60c4008b,0x7cd900b5,0x6722030d,0x00000000}},	//   bnim, نڈرز_, _lwoj, --,
   {{0x442b505f,0x60c4063b,0xb19a00a5,0x00000000}},	//   nac_, cnim, _ייתכ, --,
   {{0xcb69551f,0x2905004f,0x76580314,0x7ea01b4b}},	//   тале_, _sula_, _obvy, _köpl,
   {{0xeb9618b9,0x290549c2,0x7c2d008d,0x00000000}},	//   риш_, _pula_, ðarb, --,
   {{0xe50901a5,0x0dc802ce,0xa2d60cf1,0xdd9400c7}},	//   _mặc_, _бути_, णवत्, _лары,
   {{0x442b5520,0x38ba26e3,0x673b5521,0x290501e9}},	//   jac_, tūra_, truj, _vula_,
   {{0x8b581b15,0x442b5522,0x6d5c01c0,0x7d070116}},	//   _مجلس_, dac_, _zpra, _hujs,
   {{0x88bc000c,0x290500a7,0x60c408b7,0x248000d5}},	//   _svět, _tula_, znim, _snim_,
   {{0x3ced006d,0x673b012f,0x05cf00b4,0x60c45523}},	//   _khev_, sruj, _सुखब, ynim,
   {{0xa3c3012f,0x442b5524,0x7c2b5525,0xe7ff26c6}},	//   ्थं_, gac_, nagr, _उलटा_,
   {{0x60c4068b,0x87e74073,0x6e3500d5,0x00000000}},	//   vnim, _сюже, _odzb, --,
   {{0x6e2700b8,0x7ea0027d,0xe50900e2,0x00000000}},	//   _nejb, _röpo, _cặc_, --,
   {{0x442b5526,0x60c40693,0x6f060035,0x7c2b0dfd}},	//   bac_, tnim, _sukc, kagr,
   {{0x442b5527,0xa3b102e4,0x80660431,0x7c2b27ba}},	//   cac_, _टेक_, јваж, jagr,

   {{0xa3c3012f,0xb4c402cb,0xa0670cac,0x60c45528}},	// [5000] ्थः_, ्वी_, шата_, rnim,
   {{0x2d9a5529,0x60c4552a,0x7d070055,0x539b016b}},	//   type_, snim, _bujs, _סייו,
   {{0x69da00a1,0x6e27008c,0x823b00a5,0xd23b076b}},	//   _पुढी, _dejb, _בעיצ, _בגיל,
   {{0xeb9a0d36,0x7d090a23,0x6d5c108a,0xfce301e0}},	//   кие_, _čest, _vpra, оохо,
   {{0x3ced006d,0x78bb027a,0x6d5c0067,0x7cfa007e}},	//   _dhev_, diuv, _wpra, _hůrk,
   {{0x2ed11371,0x7ea0017b,0x00000000,0x00000000}},	//   तकृत, _köpm, --, --,
   {{0x6d5c552b,0x6722006a,0x81d800c8,0x442b00a8}},	//   _upra, _swoj, ়ের_, yac_,
   {{0x8c430b46,0x6eeb02c9,0x672202e9,0x442b552c}},	//   _месе, rübe, _pwoj, xac_,
   {{0x442b0537,0x6eeb033b,0xcb672725,0x7ea00282}},	//   vac_, sübe, _кате_, _löpm,
   {{0xf708098b,0x7d00552d,0x442b004e,0x60c90207}},	//   _của_, _hims, wac_, čemi,
   {{0x7d00552e,0x442b552f,0x45d40424,0x5e79016b}},	//   _kims, tac_, сонс, אָרד,
   {{0x6722006a,0x78a91502,0x395e028b,0x08fa0a72}},	//   _twoj, chev, _ipts_, _شراب_,
   {{0x442b551e,0xbf9b0370,0x20070067,0x00000000}},	//   rac_, _agên, śnik_, --,
   {{0x7c2b5530,0x442b2523,0x395e00e7,0xdddc035f}},	//   zagr, sac_, _kpts_, _borż,
   {{0x64402b83,0x7c2b5531,0x45440a72,0xddce00ea}},	//   ómic, yagr, _انعق, _dabū,
   {{0xd5fb0052,0xd25101ca,0x8d87042c,0x7d00023c}},	//   _בפור, _کند_, یشان, _nims,
   {{0xe5090023,0x7c2b5532,0x81d80033,0x9e070dec}},	// [5010] _tặc_, vagr, ়েল_, ачел,
   {{0x7d000a24,0x44290006,0xd9040118,0x4fc42327}},	//   _aims, _hea_, _يی_, іста,
   {{0xdef85533,0x3ced006d,0x5d550b61,0x3eb801ef}},	//   рыт_, _phev_, скет, _dmrt_,
   {{0x3ced0221,0x44290124,0x32110067,0x00000000}},	//   _qhev_, _jea_, lczy_, --,
   {{0x44290012,0xa3dd1db6,0x395e0159,0x7d000a8a}},	//   _mea_, _तुम_, _apts_, _dims,
   {{0x44295534,0xbbb702e4,0x3e5700b8,0x7c2b5535}},	//   _lea_, _अधीक, _dětí_, sagr,
   {{0xec6b2351,0x44295536,0x3ced0221,0x78a904a7}},	//   _ирак_, _oea_, _thev_, thev,
   {{0xc31d0b52,0x6d455537,0xb7bd0043,0x644d006f}},	//   _তিনি_, muha, laţi, _ncai,
   {{0x6d451fd9,0x7c290159,0x78a9337b,0x995400d5}},	//   luha, _ieer, rhev, rýše_,
   {{0x7c290903,0x7d000169,0x78a901f4,0x644d5538}},	//   _heer, _zims, shev, _acai,
   {{0x44295539,0x6d450cfb,0x7c29553a,0x00000000}},	//   _bea_, nuha, _keer, --,
   {{0xb4c40e1d,0x44290012,0x443e02c9,0x7c29553b}},	//   ्वे_, _cea_, ßt_, _jeer,
   {{0x7c293953,0x4429553c,0x6d450cca,0x7ce300be}},	//   _meer, _dea_, huha, tõrj,
   {{0x7c29553d,0x6d45553e,0xdddc0069,0x2ed104aa}},	//   _leer, kuha, _porż, तकोत,
   {{0x44290453,0x91e62aac,0x6d4500ab,0x00000000}},	//   _fea_, сове, juha, --,
   {{0x7c29553f,0x644d004f,0x6d4509df,0x3eb82dca}},	//   _neer, _gcai, duha, _smrt_,
   {{0x7d000496,0x4fea3a49,0xdfea021d,0x7f4a0037}},	// [5020] _rims, уман_, удад_, طلاق_,
   {{0xb7bd002d,0x44293e4e,0x60dd5540,0xe45f0421}},	//   gaţi, _zea_, _eksm, nnön_,
   {{0x7c295541,0x60dd022e,0x6d455542,0x2b5f0395}},	//   _beer, _fksm, guha, _apuc_,
   {{0x7c29013a,0x3b8603d0,0x30860037,0x6915009f}},	//   _ceer, йлег, _الحف, _mġed,
   {{0x7c2d008d,0x0f35002d,0x6d45021d,0x00000000}},	//   ðara, _мэря, auha, --,
   {{0x6d455543,0xb7bd0043,0x427a0070,0x224a055c}},	//   buha, caţi, ראַג, ngbk_,
   {{0xfce65544,0x7c295545,0x6d45012f,0x69150069}},	//   _гово, _feer, cuha, _nġed,
   {{0x7c295546,0xb4c407df,0x3ae90037,0xc8663ec2}},	//   _geer, ्वो_, rúpa_, стки,
   {{0x44295547,0x4fbb0070,0x644d009e,0x4c35010b}},	//   _rea_, ָציא, _rcai, _фэст,
   {{0xed4f00f5,0x76b8002d,0x644d004f,0x44293b06}},	//   _تھے_, рлор_, _scai, _sea_,
   {{0x4429007c,0x7c29018e,0x2fc70023,0x6aba0124}},	//   _pea_, _yeer, ̃ng_, _imtf,
   {{0xf1c00019,0xb7bd002d,0x4d7b0070,0x32110067}},	//   _ương_, zaţi, ארטע, wczy_,
   {{0x44295548,0xc6270083,0x6d455549,0x3d0f0067}},	//   _vea_, _মারা_, zuha, _तूने_,
   {{0x6d45554a,0x4429554b,0x46f600c3,0xddc70116}},	//   yuha, _wea_, _учет, _lajš,
   {{0x51844cb5,0x30a7554c,0x349529fd,0x3211004e}},	//   пута, брав, _макр, rczy_,
   {{0xfd4d00e8,0x4429554d,0xddc702b2,0xd3a7002d}},	//   _thoạ, _uea_, _najš, _гроп,
   {{0x59df0c67,0x7c2908b5,0xb7bd0043,0x6d451da1}},	// [5030] _पुनर, _reer, taţi, wuha,
   {{0x6d4510cd,0x2fc701a5,0x7c29554e,0x2aab054e}},	//   tuha, ăng_, _seer, _købe_,
   {{0x62850a45,0xb7bd0043,0xe5090023,0xa3c30d34}},	//   _inho, raţi, _lặn_, ्थक_,
   {{0x6d453ca2,0xa3bd0bc1,0x6aa80051,0x00000000}},	//   ruha, _आधा_, _aldf, --,
   {{0x7c2931a1,0x2aab01cf,0x62970024,0xe50900cc}},	//   _veer, _løbe_, _koxo, _nặn_,
   {{0x7c29201e,0xfbd007a9,0x6d45554f,0xbdfb00b5}},	//   _weer, رتن_, puha, _مرزا_,
   {{0x7c295550,0x9d182f7c,0x629701ed,0xb05b01ff}},	//   _teer, _гост_, _moxo, _djäv,
   {{0x62970088,0xddc702a7,0x98bc0228,0x00000000}},	//   _loxo, _gajš, tuvā_, --,
   {{0xdddc0723,0x62850298,0xe50900e2,0x7ae300d5}},	//   _karş, _onho, _cặn_, plnt,
   {{0x8699004c,0xe5090023,0x62850044,0x00000000}},	//   ртит_, _dặn_, _nnho, --,
   {{0xaca30019,0xdddc0644,0x00000000,0x00000000}},	//   _chủn, _marş, --, --,
   {{0x2b40507a,0x39473203,0x628501b4,0x2aab008c}},	//   šice_, muns_, _anho, _døbe_,
   {{0x39473f34,0x6297063c,0x7cea00ac,0x00000000}},	//   luns_, _boxo, kýrn, --,
   {{0xe5a55551,0xe0df02d0,0x629701ef,0x00000000}},	//   _мили, _akò_, _coxo, --,
   {{0x4096010c,0xc61600a5,0x629709b3,0x00000000}},	//   орат, _וחצי_, _doxo, --,
   {{0xd0071099,0x6ab60567,0x62853a89,0x00000000}},	//   жете_, _अग्र, _enho, --,
   {{0x6297002a,0xdd010355,0xddc70116,0x00000000}},	// [5040] _foxo, štěs, _rajš, --,
   {{0x7c2d008d,0x629701a3,0x69150069,0x7ea001ff}},	//   ðarn, _goxo, _mġeb, _köpi,
   {{0xa01b0ef0,0x00000000,0x00000000,0x00000000}},	//   _knöl, --, --, --,
   {{0x2377064e,0x00000000,0x00000000,0x00000000}},	//   _امید_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdddc1505,0x5f2724ee,0x62973a94,0x2ea600b5}},	//   _garş, _форм_, _xoxo, _بھری_,
   {{0xa2cd21b2,0x39472cc9,0xda65004f,0xdca632a6}},	//   _सदस्, guns_, ثاني, _дави,
   {{0x7cf15552,0x2902022a,0x2aab008c,0x00000000}},	//   gård, öka_, _røbe_, --,
   {{0xdb240a86,0xe666257f,0xb866006c,0x3ce63927}},	//   _روای, отно, ماکو, mlov_,
   {{0x7c225553,0x39470279,0xe50900e2,0x6440003e}},	//   lbor, buns_, _vặn_, ómin,
   {{0x39475554,0x291a031d,0x95ca059d,0x00000000}},	//   cuns_, ípad_, рупа_, --,
   {{0x7c225555,0xd7fa2c93,0x1b1d0083,0x3ce6008c}},	//   nbor, _кул_, _নিতে_, nlov_,
   {{0x04b8006c,0x7c225556,0x290c2d89,0x00000000}},	//   تھوں_, ibor, _huda_, --,
   {{0x290c06b3,0xaca300e2,0xaabc06fe,0x6fd800ab}},	//   _kuda_, _thủn, ्चिक, _भुइं,
   {{0x290c5557,0x7c225558,0x3ce6308a,0x8afd0355}},	//   _juda_, kbor, klov_, _upře,
   {{0x290c5559,0x3ce61bd8,0xe5030066,0x213e0079}},	//   _muda_, jlov_, _रूचि_, átha_,
   {{0x4abc0302,0x9f591879,0x290c555a,0x7c22555b}},	// [5050] ्चाव, _også_, _luda_, dbor,
   {{0xdddc0669,0x51872e1b,0xf3ff0132,0x3ce60cc1}},	//   _qarş, _дума, leão_, elov_,
   {{0x8027004f,0x290c3efa,0xbc1912ea,0x00000000}},	//   _ورحم, _nuda_, білі_, --,
   {{0xfe1b22c7,0x00000000,0x00000000,0x00000000}},	//   _प्रस_, --, --, --,
   {{0x290c555c,0x7cf1013c,0x443b555d,0xf41f0421}},	//   _auda_, vård, _mdq_, ljäs_,
   {{0x8f9a0d85,0x27190033,0x2e480421,0x6ef00110}},	//   _הישי, _দিলো_, _мясо_, täbe,
   {{0x81dd00c8,0x7c22555e,0x77620042,0x290c555f}},	//   তের_, bbor, _apox, _cuda_,
   {{0x290c5560,0x394703e6,0x81d80033,0x6d57006d}},	//   _duda_, runs_, ়েক_, mtxa,
   {{0x7c3b5561,0xb05b0282,0xf3ff021d,0x6d570065}},	//   _idur, _hjäs, deão_, ltxa,
   {{0xca740037,0x443b0815,0x7c3b0069,0x7e7501ed}},	//   _يالغ, _adq_, _hdur, _jazp,
   {{0x6fd8009a,0x290c01a3,0x1dbd00e7,0x6d5701a3}},	//   _भुईं, _guda_, ्पित, ntxa,
   {{0x895a02b8,0x7c3b007a,0x00000000,0x00000000}},	//   _לדעת, _jdur, --, --,
   {{0x35520088,0x4375081b,0x00000000,0x00000000}},	//   ونیز, мурт, --, --,
   {{0x290c0273,0xb77a00a5,0x1dab170c,0x1dbd1371}},	//   _yuda_, _לאנש, चनात, ्पात,
   {{0xd1790a55,0x64a65562,0x703a03ad,0x3ce600ee}},	//   ості_, _нака, йчас_, ylov_,
   {{0x7c2d0093,0x7c3b0371,0x00000000,0x00000000}},	//   ðarl, _ndur, --, --,
   {{0xa3d00243,0x60c102d0,0x7c225563,0x9f5800a8}},	// [5060] _शशि_, èlma, vbor, _özüm_,
   {{0x7c3b0b51,0xee3a010b,0xb05b0523,0x42ea002d}},	//   _adur, ёне_, _bjäs, _ымпо_,
   {{0x929b0052,0xe29b0122,0x429b00a5,0x6e930037}},	//   _היית, _השיר, _הסיב, علما,
   {{0xedd30312,0xdcb901e0,0x00000000,0x00000000}},	//   ريند, ощі_, --, --,
   {{0x290c5564,0x3ce63a29,0x200700b8,0x7c3b0069}},	//   _suda_, rlov_, ěnit_, _ddur,
   {{0x3ce61ffb,0x6d57006d,0x7c3b5565,0xb05b0282}},	//   slov_, btxa, _edur, _fjäs,
   {{0x3ce6040b,0xe50900cc,0x00000000,0x00000000}},	//   plov_, _bặm_, --, --,
   {{0x6e2e25cb,0xb05b022a,0x7e7506a2,0xaca30023}},	//   _hebb, _hjär, _zazp, _phụn,
   {{0xd6da0133,0x7f440bc8,0xbb4316c0,0xc61d0033}},	//   йто_, nriq, _петк, _দয়া_,
   {{0xa3c20437,0x7cf101b4,0x290c0009,0x7d0e0069}},	//   ्पन_, råre, _tuda_, _kubs,
   {{0x94d50370,0x443b0069,0xe6d90093,0xb05b0282}},	//   донц, _pdq_, þráð, _mjär,
   {{0xd5b700c7,0x8ec40083,0x443b2c35,0xb4e7022e}},	//   ясы_, ্তিগ, _qdq_, भते_,
   {{0x7d0e5566,0x838700d8,0x99870009,0x68e20add}},	//   _lubs, чыне, manš_, _ikod,
   {{0x27e60269,0x6e2e5567,0x2ca6028b,0x7ea00282}},	//   _iyon_, _nebb, hkod_, _köpu,
   {{0x30a75568,0x26de5569,0x7e75108a,0x27e60027}},	//   прав, moto_, _razp, _hyon_,
   {{0x61e5086d,0x6d57006d,0xc7b900b5,0x92bd0033}},	//   _vyhl, vtxa, kből_, ইকে_,
   {{0xb4d90299,0xc43c0122,0x7c2d0093,0x6e990009}},	// [5070] ़की_, _התחי, ðarm, овар_,
   {{0x26de556a,0xc332016b,0x290600cc,0xa01b0282}},	//   noto_, _שוי_, _lioa_, _knök,
   {{0x6e2e556b,0x27e6556c,0x26cc556d,0x6b800345}},	//   _debb, _lyon_, indo_, _armg,
   {{0x26de033a,0x7f4443b0,0x6e2e0065,0x6d5706a2}},	//   hoto_, briq, _eebb, rtxa,
   {{0x6e2e01d3,0x26de556e,0xb05b013c,0x60cd556f}},	//   _febb, koto_, _fjär, mnam,
   {{0x60cd5570,0x68e20e91,0xfe71042c,0xe9a900d1}},	//   lnam, _akod, _جگر_, يگان_,
   {{0x27e60269,0x24890107,0x26de5571,0xac190eb9}},	//   _ayon_, _onam_, doto_, _мову_,
   {{0x60cd5572,0x26cc5573,0xb4ac000c,0x2b400bc6}},	//   nnam, endo_, _गते_, šica_,
   {{0x60cd5574,0xa8060453,0x6e2e030d,0x00000000}},	//   inam, _riñó, _yebb, --,
   {{0x24895575,0x6f0f07e5,0x26de5576,0x60cd5577}},	//   _anam_, _mucc, goto_, hnam,
   {{0x044614a9,0x6f0f02fb,0x60cd5578,0x645d1193}},	//   менн, _lucc, knam, ffsi,
   {{0x6f07006d,0x98bc010b,0x59c300dc,0x248900a2}},	//   _lijc, tuvą_, _वेयर, _cnam_,
   {{0x68e91e54,0x7ea0013c,0x6f0f5579,0x26de557a}},	//   mled, _köpt, _nucc, boto_,
   {{0x65c534a2,0x68e9557b,0x2489557c,0xda0d0d1f}},	//   _обла, lled, _enam_, िखित_,
   {{0x81e600c8,0x91e343be,0x2cad007c,0x6e2e035f}},	//   বেন_, воре, _oled_, _rebb,
   {{0x60cd557d,0x6f0f557e,0x6e2e557f,0x7f445469}},	//   gnam, _bucc, _sebb, triq,
   {{0x6f0f2bbe,0x6d455580,0x63a001ff,0x68e95581}},	// [5080] _cucc, erha, ämnd, iled,
   {{0x24895582,0xee3a00d8,0x68e9000c,0x81dd0083}},	//   _znam_, іне_, hled, তেই_,
   {{0xd00a204b,0x60265583,0xed571fda,0x2cad5584}},	//   _мене_, _одна, дох_, _bled_,
   {{0x6e2e1f4a,0x60cd004f,0x68e9054e,0xc7b900b5}},	//   _webb, cnam, jled, tből_,
   {{0x99870c99,0x68e95585,0x60c45586,0x26de01a8}},	//   vanš_, dled, miim, yoto_,
   {{0x6d43004f,0x60c4018e,0x7d0e01e8,0x26de0132}},	//   ánac, liim, _tubs, xoto_,
   {{0x6d450297,0x6f0f5587,0x26de013a,0x7ea0017b}},	//   crha, _zucc, voto_, _döpt,
   {{0x3f820a69,0x88bc01c0,0xa7742294,0x2cad362b}},	//   _krku_, _hvěz, елич, _gled_,
   {{0x26de5588,0x9646010b,0x00000000,0x00000000}},	//   toto_, мэнд, --, --,
   {{0x60cd0e6a,0x60c45589,0x24890036,0xd6d90035}},	//   znam, hiim, _snam_, kułu_,
   {{0x68e90ffe,0x26de558a,0x60cd558b,0x60c4023c}},	//   bled, roto_, ynam, kiim,
   {{0xb4d90299,0x3f820093,0x68e92fa1,0x60c408c7}},	//   ़के_, _orku_, cled, jiim,
   {{0x2508006c,0x26de558c,0x80c10fbf,0x27e6558d}},	//   _کرتی_, poto_, रोफे, _uyon_,
   {{0x60cd099e,0x45d4558e,0x38c30107,0x00000000}},	//   wnam, _полс, _tèrè_, --,
   {{0x60cd558f,0x6f0f225a,0x7c2d0093,0x6f070051}},	//   tnam, _succ, ðark, _rijc,
   {{0x24890453,0x60cd5590,0x00000000,0x00000000}},	//   _unam_, unam, --, --,
   {{0xa3c200b4,0x9f340044,0x2bde25fe,0xfbde00be}},	// [5090] ्पण_, кеті, _फुला, _फुलम,
   {{0x60cd5591,0x3d17009f,0xf09f0023,0x291e030d}},	//   snam, _aħwa_, _giàn_, _otta_,
   {{0xa3c2009a,0x40352626,0x60cd5592,0x68e95593}},	//   ्पथ_, _пенс, pnam, yled,
   {{0x6d455594,0x20c500ea,0x6f07500f,0x3f820207}},	//   rrha, rķis_, _wijc, _frku_,
   {{0x291e018e,0x00000000,0x00000000,0x00000000}},	//   _atta_, --, --, --,
   {{0x68e95595,0xef1f0225,0xfaa710be,0xa3c2060a}},	//   wled, _itü_, ьшен, ्पत_,
   {{0x68e95596,0x00000000,0x00000000,0x00000000}},	//   tled, --, --, --,
   {{0x68e000f4,0x2b460211,0x00000000,0x00000000}},	//   gomd, broc_, --, --,
   {{0x68e95597,0x291e5598,0x1b190033,0x2b46428a}},	//   rled, _etta_, _ঠিকই_, croc_,
   {{0x68e92ba2,0x7d095599,0x60c4559a,0xef1f00be}},	//   sled, _hies, ziim, _mtü_,
   {{0x68e922c0,0x35a5487f,0x7ea0559b,0xe4c60e75}},	//   pled, ханг, _köpr, ейни,
   {{0x7c2d0093,0x7d09004b,0x00000000,0x00000000}},	//   ðarh, _jies, --, --,
   {{0x7d09559c,0x386d559d,0x850b0653,0x60c41b43}},	//   _mies, meer_, _संकट_, viim,
   {{0x386d0136,0xd6d90035,0x78a9559e,0x7ea00282}},	//   leer_, tułu_, lkev, _löpr,
   {{0x60c42119,0x6fd808b0,0x00000000,0x00000000}},	//   tiim, _भुजं, --, --,
   {{0x7d09559f,0x26c555a0,0xef1a55a1,0x78a955a2}},	//   _nies, lilo_, зма_, nkev,
   {{0x60c401a8,0x64560010,0xff2400b5,0xf8b2016b}},	// [50a0] riim, _icyi, ئبری, אשן_,
   {{0x386d0136,0x60c455a3,0x443206b5,0x7d0909b7}},	//   heer_, siim, _hey_, _aies,
   {{0x6da3034b,0x443204e2,0x386d053e,0x213a028b}},	//   лифа, _key_, keer_, _uvph_,
   {{0x26c5129d,0x7d0917a1,0x6e230a21,0x3f82011c}},	//   hilo_, _cies, ınba, _trku_,
   {{0x7d0955a4,0x629e55a5,0x386d55a6,0xaca30019}},	//   _dies, _kopo, deer_, _giọn,
   {{0x44320083,0xc3330122,0x26c503c9,0x2b460310}},	//   _ley_, רוג_, jilo_, rroc_,
   {{0x26c502dd,0x7d0955a7,0x4432022e,0x090600af}},	//   dilo_, _fies, _oey_, нчим,
   {{0x386d0a45,0x629e55a8,0x7d0955a9,0xa3c20c97}},	//   geer_, _lopo, _gies, ्पा_,
   {{0x26c50133,0x68e04659,0xc6f81422,0x3f800176}},	//   filo_, romd, мних_, nviu_,
   {{0xc6f73b8c,0x26c555aa,0x0f5700a5,0x25a542ea}},	//   нных_, gilo_, עיים_, fyll_,
   {{0xceb302da,0x386d12b0,0x443255ab,0x2f1601b4}},	//   רית_, beer_, _bey_, _læg_,
   {{0xb86500f3,0x38ba00ea,0x78a955ac,0x386d02a2}},	//   _لاهو, tūru_, ckev, ceer_,
   {{0xdcf5004e,0x7c2d0093,0x629e55ad,0x46a6010b}},	//   _urzą, ðari, _bopo, _падв,
   {{0x171b0070,0x998c00fe,0x00000000,0x00000000}},	//   _צווע, _jedů_, --, --,
   {{0xd5af2947,0x629e55ae,0x443255af,0x00000000}},	//   _сс_, _dopo, _fey_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0955b0,0x846401d3,0x8c3d027d,0xa923010b}},	// [50b0] _ries, _съще, _hoşg, ąžin,
   {{0x59b0018d,0x752d0035,0x629e0088,0x386d02a2}},	//   जनार, _łazi, _gopo, zeer_,
   {{0x7d0955b1,0x44322637,0x611c0260,0x5637016b}},	//   _pies, _yey_, _pčle, גאבע_,
   {{0x26c50888,0x38b100b5,0xef1f00be,0x7d090024}},	//   zilo_, _márc_, _ttü_, _qies,
   {{0x7d0955b2,0x386d0244,0x7f4d0183,0x7e2b00d8}},	//   _vies, veer_, quaq, _ніва_,
   {{0x7d0955b3,0xf09f01a5,0x386d152b,0x2369028b}},	//   _wies, _hoà_, weer_, _mpaj_,
   {{0x7d0955b4,0x26c503ab,0x5975005f,0x08d51d13}},	//   _ties, vilo_, тылу, кция,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386d55b5,0x443255b6,0x23690189,0x78a955b7}},	//   reer_, _rey_, _npaj_, rkev,
   {{0x386d55b8,0x78a955b9,0xa6822691,0x443255ba}},	//   seer_, skev, альд, _sey_,
   {{0x26c52dc6,0x386d1995,0xa935002d,0x19ab0f99}},	//   rilo_, peer_, _рееш, _этап_,
   {{0x7ae355bb,0x7cea008d,0x26c555bc,0x629e55bd}},	//   lont, týri, silo_, _sopo,
   {{0x629e55be,0xcc3a02b5,0x25a501ef,0x7ea00282}},	//   _popo, וערט, syll_, _oöpp,
   {{0x52750714,0x44320453,0x7cf84a2e,0xc7b900b5}},	//   лусу, _wey_, míre, mző_,
   {{0x205655bf,0xc7b9006c,0x91e602ba,0x24f6002d}},	//   ктар, lző_, тове, _ичир,
   {{0x20550dde,0x7ae33151,0xe3b20919,0x64560371}},	//   лтур, hont, _نرخ_, _ucyi,
   {{0xb2260947,0x6d4355c0,0xb4de0253,0x00000000}},	// [50c0] _импл, ánan, तकी_, --,
   {{0x3f8055c1,0xd0f40099,0x7ae30031,0x6d4b0035}},	//   rviu_, _आठवण_, jont, ągan,
   {{0xbd8a0286,0xdb08008d,0x00000000,0x00000000}},	//   بنان_, _ólét, --, --,
   {{0x673b55c2,0xdd8f0372,0x2a65055c,0xed3500af}},	//   ksuj, توم_, _ablb_, уэфэ,
   {{0x7ae355c3,0xdbcc002a,0x00000000,0x00000000}},	//   font, _póño, --, --,
   {{0x7ae355c4,0x81dd0033,0x59f800af,0x00000000}},	//   gont, তেও_, неля_, --,
   {{0xa96704bf,0x987d013b,0x00000000,0x00000000}},	//   вија_, _açıb_, --, --,
   {{0x7e7c06a2,0x7cf80391,0xd90d00f8,0x987417d0}},	//   _harp, fíre, سیه_, улиц,
   {{0xb50c0026,0xdca355c5,0x7ae355c6,0xb05b0523}},	//   _संजय_, _тати, bont, _omän,
   {{0xa3e655c7,0x7ae31adb,0x41db0035,0x7c2d008d}},	//   _बुध_, cont, _मुझस, ðarv,
   {{0xe9de021d,0x00000000,0x00000000,0x00000000}},	//   _âº_, --, --, --,
   {{0x249f064b,0x69da01a3,0xd5b80228,0x6d5e55c8}},	//   ðum_, _ixte, rzā_, itpa,
   {{0x6b8255c9,0x6d5e3c51,0x38660282,0x00000000}},	//   nvog, htpa, _ibor_, --,
   {{0x2d850009,0x63a001ff,0x7e7c1287,0x38660207}},	//   _šlem_, ämna, _narp, _hbor_,
   {{0x6234225d,0xb50c0066,0xf1a455ca,0x6d5c0024}},	//   ресу, _संचय_, артн, _nqra,
   {{0x7ae355cb,0x5597011d,0x6b8255cc,0x6d5e0938}},	//   zont, _ידוע_, kvog, dtpa,
   {{0x443955cd,0x7e7c008c,0x7ae32574,0x38660118}},	// [50d0] mas_, _barp, yont, _mbor_,
   {{0xa3c21b8f,0x717955ce,0x7e7c55cf,0x6d5e1e2e}},	//   ्पर_, _збор_, _carp, ftpa,
   {{0x7e7c0297,0xf09f0019,0x7ae355d0,0x386655d1}},	//   _darp, _toà_, vont, _obor_,
   {{0x443955d2,0x442b55d3,0x7afa0176,0xac190ed2}},	//   nas_, nbc_, _ahtt, ходу_,
   {{0x7ae355d4,0x443955d5,0xe5041db1,0x7e7c00f1}},	//   tont, ias_, रगति_, _farp,
   {{0xeb900172,0xddce00b5,0x00000000,0x00000000}},	//   تظم_, _ebbő, --, --,
   {{0x443955d6,0xdd9401c8,0xceb202b5,0x6d5e55d7}},	//   kas_, _кары, _פיל_, ctpa,
   {{0x443955d8,0x48d10083,0x7e7c148e,0x3866009e}},	//   jas_, াত্র, _zarp, _cbor_,
   {{0x69da55d9,0xe50a00e8,0x7ae355da,0xa6e500af}},	//   _exte, _mặt_, pont, лжил,
   {{0x1ab700dc,0xaab70567,0xc7b9006c,0x4ab71856}},	//   _अतिथ, _अतिक, rző_, _अतिव,
   {{0x64a60c0d,0x67220103,0x7cf80042,0xe45f0421}},	//   гана, _etoj, síre, riön_,
   {{0x443955db,0xa3c20d1f,0xb4de0099,0x0446010b}},	//   gas_, ्पल_, तके_, ыемн,
   {{0x889a0100,0xf74521e2,0x387f55dc,0xddc70af1}},	//   _רבני, _село, mdur_, _najž,
   {{0x387f00fb,0x6e350314,0x386655dd,0x443903d0}},	//   ldur_, _nezb, _zbor_, aas_,
   {{0x443955de,0xa06a55df,0x6d5e009e,0x611c021e}},	//   bas_, нава_, xtpa, _bčla,
   {{0x387f55e0,0x7e7c55e1,0x2d5c0020,0xa0b50274}},	//   ndur_, _sarp, víe_, аљуј,
   {{0x64440159,0xa4fb0122,0x387d0297,0x7e7c022e}},	// [50e0] _idii, _אלקט, _mawr_, _parp,
   {{0x425655e2,0x387d001e,0x6aa10176,0x4420008c}},	//   _стит, _lawr_, _nolf, _hfi_,
   {{0x6e350043,0x7e7c55e3,0x1636016b,0x387f1505}},	//   _dezb, _varp, רנער_, kdur_,
   {{0x6d5e55e4,0x387d001e,0x6b8255e5,0x691500ac}},	//   rtpa, _nawr_, tvog, _kšef,
   {{0x7e7c086c,0x387f55e6,0x9b940eee,0x6d5e55e7}},	//   _tarp, ddur_, рилц, stpa,
   {{0x443955e8,0x442055e9,0x6b8255ea,0x8c3d0160}},	//   zas_, _lfi_, rvog, _coşb,
   {{0x672206fe,0x443955eb,0x81e600c8,0x442017cf}},	//   _stoj, yas_, বের_, _ofi_,
   {{0xfce654e1,0xa967004f,0xa3dd0026,0xb4de000c}},	//   _собо, اميم_, _तुझ_, तको_,
   {{0x7d0255ec,0xaefb01da,0x387d099e,0x00000000}},	//   mmos, _spùi, _dawr_, --,
   {{0x443955ed,0x442055ee,0xba1a0037,0x387f00e9}},	//   was_, _afi_, _أيضا_, adur_,
   {{0xa92620b6,0xb866026e,0x387d001e,0x8b0301c0}},	//   _сдел, _ماشو, _fawr_, ířen,
   {{0xd5b718d9,0x6aa1027a,0x6f0e00fe,0x76430409}},	//   усь_, _zolf, _libc, _edny,
   {{0x6444018e,0xdfe300b4,0x00000000,0x00000000}},	//   _ddii, _कुंद_, --, --,
   {{0x78a255ef,0x3ce655f0,0x5693005f,0x8c3d00a8}},	//   _hoov, hoov_, _гашт, _xoşb,
   {{0x2b400076,0x6e35201d,0x442055f1,0x361b0070}},	//   šich_, _rezb, _ffi_, _אווד,
   {{0x44390484,0x7d021da9,0x30a403e6,0xd4680274}},	//   qas_, jmos, брув, _биће_,
   {{0xe50a0028,0x5f9403d0,0x6f0e0069,0x81e60033}},	// [50f0] _vặt_, битт, _bibc, বেল_,
   {{0xd2510164,0x78a200ab,0x387f045e,0x7cea008d}},	//   _بند_, _loov, zdur_, kýrs,
   {{0x6e350c99,0x2d8755f2,0xd011211f,0xdd1e0187}},	//   _vezb, íne_, _ولد_, _píše,
   {{0x387f01c2,0x611c011c,0x78a20103,0x00000000}},	//   xdur_, _učla, _noov, --,
   {{0x7988012f,0x2d9c177c,0x6aa155f3,0x00000000}},	//   _ardw, øver_, _polf, --,
   {{0x7d02323d,0x00000000,0x00000000,0x00000000}},	//   amos, --, --, --,
   {{0x6aa10df4,0x59df0006,0x7c2d0093,0x9ed8052c}},	//   _volf, _पुखर, ðars, _смрт_,
   {{0x6aa155f4,0x52d255f5,0xe7f029ad,0x00000000}},	//   _wolf, _सद्स, _चरखा_, --,
   {{0x387f55f6,0x752400f4,0x6eeb02b1,0x00000000}},	//   rdur_, _čiza, sübu, --,
   {{0x05650f68,0x4420198d,0xb05b013c,0x46f503e6}},	//   авон, _sfi_, _smäl, јчит,
   {{0x99620187,0x6b893340,0x00000000,0x00000000}},	//   píše_, _hreg, --, --,
   {{0x6b8955f7,0x385816e6,0x638655f8,0x3ea30282}},	//   _kreg, _مشهد_, агма, _lojt_,
   {{0xa3e60d2a,0x36d502c8,0x00000000,0x00000000}},	//   _बुश_, _кодр, --, --,
   {{0x2327021d,0x290f010d,0x764301b4,0x7d0255f9}},	//   рори_, _higa_, _udny, zmos,
   {{0xe29722bb,0x7d021ca2,0x290f55fa,0x6f0e023a}},	//   шар_, ymos, _kiga_, _ribc,
   {{0x2b400759,0x290f00d7,0xdd2f01c0,0xd0260210}},	//   šici_, _jiga_, _běžn, рмай,
   {{0x1fa72258,0xaec655fb,0x24920168,0x00000000}},	// [5100] акти_, абал, _inym_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248001e8,0x6b8955fc,0x7d0255fd,0x656100f6}},	//   _kaim_, _areg, tmos, ntlh,
   {{0xb4c43914,0x3b862e50,0x1b1d0033,0xab2a55fe}},	//   _एगो_, илег, _নিজে_, вода_,
   {{0x24800221,0x6b8955ff,0x7d020147,0x3ea300fe}},	//   _maim_, _creg, rmos, _fojt_,
   {{0x78a20006,0x290f02d4,0x3ce60189,0x24800221}},	//   _soov, _aiga_, soov_, _laim_,
   {{0x8c9601c8,0x9d43002d,0xada60328,0x6b8901d5}},	//   _краі, _мерд, _тавл, _ereg,
   {{0x7afd0029,0x24805600,0x7cf800b8,0x290f0124}},	//   _īste, _naim_, bíra, _ciga_,
   {{0x290f5601,0x7c2d5602,0x6b892e65,0x7cf8002a}},	//   _diga_, ñare, _greg, círa,
   {{0x290f2129,0x4aaa04bc,0x1b1d0033,0x27ef01ff}},	//   _eiga_, _कविव, _নিচে_, _dygn_,
   {{0x2480022e,0x290f5603,0x78a200be,0x00000000}},	//   _baim_, _figa_, _toov, --,
   {{0xe7865604,0x2480021d,0x7f4d013b,0x60d60067}},	//   _вуко, _caim_, yraq, jnym,
   {{0x248001a9,0xe8d70122,0x00000000,0x00000000}},	//   _daim_, _דואר_, --, --,
   {{0x290f023a,0x2d8a015e,0x17570070,0x00000000}},	//   _ziga_, _orbe_, _כסדר_, --,
   {{0x26cc04a5,0x6ac40cc5,0x290f1815,0x4de600a1}},	//   mido_, _वगैर, _yiga_, _जुलै_,
   {{0x74350947,0x7f4d00f6,0x45b700a5,0x00000000}},	//   _униф, traq, _כפול_, --,
   {{0x7eb20185,0x00000000,0x00000000,0x00000000}},	// [5110] _væpn, --, --, --,
   {{0x26cc5605,0x6b8901d2,0x7f4d0d99,0x81e60083}},	//   nido_, _rreg, rraq, বেই_,
   {{0xa184010b,0xafdb0b3e,0x6b8901cb,0x00000000}},	//   _дыял, _idøm, _sreg, --,
   {{0x40950082,0x26cc01dd,0x248001e8,0x8c3d00d0}},	//   _الحر, hido_, _xaim_, _boşa,
   {{0x26cc25a7,0x290f5606,0xfbd00037,0x2d8a5607}},	//   kido_, _riga_, وته_, _erbe_,
   {{0x60cd5608,0x290f5609,0x26cc0831,0xe50a0023}},	//   liam, _siga_, jido_, _lặp_,
   {{0x26cc2140,0x290f560a,0x272301ba,0x6b89560b}},	//   dido_, _piga_, kčný_, _wreg,
   {{0x60cd560c,0x6b8901d2,0x3949560d,0x00000000}},	//   niam, _treg, čas_, --,
   {{0x26cc560e,0x290f00ab,0x46e90c7e,0x6b8947ed}},	//   fido_, _viga_, лдин_, _ureg,
   {{0x26cc365e,0x60cd0382,0x60d6560f,0xa4f900b5}},	//   gido_, hiam, znym, یکٹر_,
   {{0x290f49c2,0x60cd01c8,0x67295610,0x3cff006f}},	//   _tiga_, kiam, spej, _khuv_,
   {{0xe50a01a5,0x232a426a,0x24805611,0x290f0553}},	//   _cặp_, ломи_, _qaim_, _uiga_,
   {{0x26cc12d1,0x60cd5612,0x24805613,0x68e95614}},	//   bido_, diam, _vaim_, moed,
   {{0x26cc1423,0x26c71d11,0x68e9001e,0xd6260274}},	//   cido_, _umno_, loed, _лоше_,
   {{0x3f8b05f5,0x60cd5615,0x2480116e,0x60260f9d}},	//   _arcu_, fiam, _taim_, йдва,
   {{0xe50a0028,0x60cd5616,0x672d0484,0x24800079}},	//   _gặp_, giam, _ħajj, _uaim_,
   {{0x2d8a0759,0xddd5008b,0xff2700b5,0x00000000}},	// [5120] _srbe_, _razš, مبلی, --,
   {{0x68e902c7,0x1eaa06ca,0x4422029e,0xee370572}},	//   hoed, داري_, lck_, йну_,
   {{0x60cd01d3,0xc27b0100,0xa63a0070,0x2bc00099}},	//   biam, _גריי, רגער, _शेजा,
   {{0x60cd5617,0x26cc03e6,0x2d8a082d,0x7d1b008b}},	//   ciam, zido_, _vrbe_, _čust,
   {{0x44270669,0x68e9001e,0x09b000e7,0x00000000}},	//   _ən_, doed, जन्य, --,
   {{0x26cc043f,0xd37b00a5,0x00000000,0x00000000}},	//   xido_, טרנט, --, --,
   {{0x26cc478a,0x2d8a4f40,0xda653f25,0x68e900e9}},	//   vido_, _urbe_, تاني, foed,
   {{0xa3b825d8,0x68e95618,0x26cc011e,0x6cd6186e}},	//   चना_, goed, wido_, _اقرا,
   {{0x26cc1423,0xf09f0019,0x2fc01bb3,0xb8d00380}},	//   tido_, _giàu_, nzig_, _ऐक_,
   {{0x60cd5619,0x6e3e561a,0xda660833,0x87e30421}},	//   ziam, napb, _داري, яюще,
   {{0x26cc0aca,0xa5f82ead,0x7cf8561b,0x68e92cfa}},	//   rido_, рену_, níro, boed,
   {{0x7c22561c,0x7aea561d,0x6d430037,0x2b40011c}},	//   ncor, loft, ánai, šicu_,
   {{0x60cd561e,0x2fc001e4,0x611c0107,0x94030d2a}},	//   viam, jzig_, _dčlm, रेंच_,
   {{0x569427ac,0x60cd0035,0x7aea03d0,0x00000000}},	//   _факт, wiam, noft, --,
   {{0x60cd561f,0x3f8b5620,0x7c220051,0x00000000}},	//   tiam, _srcu_, kcor, --,
   {{0x7cf825a8,0x7aea0223,0x00000000,0x00000000}},	//   díro, hoft, --, --,
   {{0x60cd5621,0x7c220118,0x40340086,0x2aab01b4}},	// [5130] riam, dcor, яетс, _købt_,
   {{0x765a5622,0x60cd5623,0x7c220223,0x443b163e}},	//   ngty, siam, ecor, _heq_,
   {{0x443b00da,0x60cd5624,0x3cff5625,0x257a00ea}},	//   _keq_, piam, _phuv_, _jūl_,
   {{0xaca30019,0x61fa38b0,0x00000000,0x00000000}},	//   _miện, ütle, --, --,
   {{0xeb994697,0xfd100bdf,0x68e91516,0xe47c02b5}},	//   рил_, رجم_, voed, טראכ,
   {{0x93fc0070,0x443b01ef,0x7c223cba,0x7cf825a8}},	//   אלדי, _leq_, acor, bíro,
   {{0x4422022a,0xaa560202,0x3cff01e8,0x7cf801dd}},	//   yck_, цију_, _thuv_, círo,
   {{0x81fb0083,0xd0fb0d00,0x7c225626,0x81e60083}},	//   _আলাপ_, ्षिण_, ccor, বেক_,
   {{0x68e9001e,0x78bb01ff,0x00000000,0x00000000}},	//   roed, rhuv, --, --,
   {{0x7c3b41f9,0x78bb5627,0x68e95628,0xf09f00f1}},	//   _heur, shuv, soed, _fhàg_,
   {{0x7c3b5629,0xa2af01c0,0xe5a510ac,0x38aa0211}},	//   _keur, ुसन्, цини, _cùrs_,
   {{0x4422562a,0x443b009e,0x7c3b08c7,0x240a07e5}},	//   uck_, _ceq_, _jeur, инни_,
   {{0x7c3b562b,0xe7392349,0x7cf800b5,0x00000000}},	//   _meur, _тел_, zíro, --,
   {{0x7c3b02e1,0x67d8016b,0x00000000,0x00000000}},	//   _leur, _פֿײג, --, --,
   {{0x64a65454,0x7cf80042,0x611c021e,0x00000000}},	//   _мака, xíro, _tčlm, --,
   {{0x7c3b562c,0x92da0083,0x443b00d7,0x806600d8}},	//   _neur, ়তে_, _geq_, ўваж,
   {{0xee3a562d,0x611c021e,0x00000000,0x00000000}},	// [5140] ина_, _kčlk, --, --,
   {{0x2fc002b1,0x7cf825a8,0x00000000,0x00000000}},	//   rzig_, tíro, --, --,
   {{0x7c3b106c,0xa0a61499,0xa06a1126,0x10a60210}},	//   _beur, _данд, _кана_, _динн,
   {{0x61fe562e,0x7c3b37a5,0x2fc001ae,0x7afd00ea}},	//   _izpl, _ceur, pzig_, _īsta,
   {{0x7c22562f,0x7c3b5630,0x7524044d,0x7aea0a8a}},	//   rcor, _deur, _čizm, toft,
   {{0x7c225631,0x7cf82eef,0x6d5701dd,0x3a250107}},	//   scor, píro, buxa, _cflp_,
   {{0x7c3b1d22,0x7aea5632,0x6e3c0395,0x80c100b4}},	//   _feur, roft, _ierb, रोके,
   {{0x6e3c5633,0xbebb00da,0x7c3b5634,0x00000000}},	//   _herb, _atëh, _geur, --,
   {{0xd6da0021,0x6e3c5635,0xd7fa0131,0x7d1c5636}},	//   ито_, _kerb, шук_, _hurs,
   {{0x6e3c025c,0x7aea01f4,0x7c3b5637,0x443b05f0}},	//   _jerb, qoft, _zeur, _seq_,
   {{0x69150311,0x24190328,0x6e3c1221,0x611c0107}},	//   _všec, йоны_, _merb, _dčlk,
   {{0x92da0083,0x7d1c0116,0xef1f033b,0x443b0176}},	//   ়তো_, _murs, _früh_, _qeq_,
   {{0x7d1c0029,0x7bc25638,0x443b01f4,0x6e3c0345}},	//   _lurs, nzou, _veq_, _oerb,
   {{0xd6d9004e,0x7d1c0147,0x00000000,0x00000000}},	//   kuły_, _ours, --, --,
   {{0x7d1c3b19,0x27200023,0x7e770523,0x30a7338e}},	//   _nurs, _hòn_, vexp, орав,
   {{0xfbbc00b4,0x6ab701d1,0xa3e60035,0x92bd0083}},	//   ्छाम, _अत्र, _बुक_, েকে_,
   {{0x6e3c2694,0x7c3b01f7,0xb4e70066,0x200f00ab}},	// [5150] _berb, _reur, बकी_, ägi_,
   {{0x7c3b03ad,0x27205639,0x6e3c001e,0x7d1c563a}},	//   _seur, _mòn_, _cerb, _burs,
   {{0x7c3b563b,0x6e3c08f8,0x62850159,0x6fdd0785}},	//   _peur, _derb, _iaho, _यशवं,
   {{0x645d563c,0x7d1c563d,0x317a02b5,0x6aba563e}},	//   ngsi, _durs, _פארד, _altf,
   {{0x628518ad,0x7c3b0955,0x2019563f,0x6aa85640}},	//   _kaho, _veur, _igsi_, _bodf,
   {{0x628515c2,0x6e3c5641,0x7d1c0054,0x62875642}},	//   _jaho, _gerb, _furs, ndjo,
   {{0xf2d400c2,0x62855643,0x7c3b5644,0x201e00af}},	//   ועס_, _maho, _teur, _ştii_,
   {{0x6e3c0291,0x6d455645,0x38b1008d,0x764a00e9}},	//   _zerb, msha, _kári_, _adfy,
   {{0x272000e8,0x6e3c5646,0x6f1d5647,0x6aa85648}},	//   _còn_, _yerb, _jusc, _fodf,
   {{0x628501c0,0x6726003e,0x6f1d1fc9,0x86994a7c}},	//   _naho, íkja, _musc, стит_,
   {{0x6d453326,0xf3e91804,0x6e2502b1,0x69ce0207}},	//   nsha, _עף_, ichb, _žbev,
   {{0xf2c902b5,0x7f440248,0x6285010d,0x6d455649}},	//   _גע_, ysiq, _aaho, isha,
   {{0x6285564a,0x272001a5,0x6d450312,0xc879564b}},	//   _baho, _gòn_, hsha, meş_,
   {{0x6d45564c,0xe619564d,0xc879564e,0x628500a2}},	//   ksha, _удк_, leş_, _caho,
   {{0x6285190b,0x272002e9,0x7641564f,0xdddc0043}},	//   _daho, _zòn_, maly, _marţ,
   {{0x6f1d0152,0x6e3c5650,0x93463db0,0xc879027d}},	//   _busc, _serb, _ение, neş_,
   {{0x6e3c5651,0x7d1c5652,0x6f1d5653,0xef175654}},	// [5160] _perb, _surs, _cusc, зму_,
   {{0x1fb502ce,0x6f1d15e8,0x7c2d0453,0x7d1c5655}},	//   єстр, _dusc, ñarn, _purs,
   {{0x6e3c0ddf,0xc27b01f3,0x7f440248,0x127b0070}},	//   _verb, _פרטי, ssiq, _פאטע,
   {{0x13b000c8,0x6e3c02c9,0x6f1d0390,0xfca90098}},	//   _চেয়, _werb, _fusc, يانو_,
   {{0x6e3c120d,0xfe700332,0x6d455656,0x6f1d027a}},	//   _terb, _لگا_, asha, _gusc,
   {{0x3f8202ee,0x7d1c5657,0x7bc2076c,0x7641003e}},	//   _isku_, _turs, rzou, jaly,
   {{0x76415658,0x6f1d01ae,0xfe550416,0x69dc5659}},	//   daly, _zusc, _زینب_, _žreb,
   {{0x4ddb00a5,0xc173025a,0x00000000,0x00000000}},	//   _החלו, גחה_, --, --,
   {{0xb60502a7,0x00000000,0x00000000,0x00000000}},	//   _lušč, --, --, --,
   {{0x7641565a,0x35b44e6d,0x00000000,0x00000000}},	//   galy, дбор, --, --,
   {{0x69c3006a,0x62850086,0xc8792108,0x00000000}},	//   czne, _raho, beş_, --,
   {{0x62850927,0x2eb90066,0xa3b8012f,0xbec300ea}},	//   _saho, _इत्त, चनं_, _ķīmi,
   {{0x7641565b,0x6285565c,0xd70600c3,0x38b800f6}},	//   baly, _paho, _езди, _héro_,
   {{0x6f1d565d,0x764a01b4,0xb05b033b,0x88bc0355}},	//   _rusc, _udfy, _kläg, _stěh,
   {{0x6f1d565e,0x6285565f,0x291e0224,0x62875660}},	//   _susc, _vaho, _juta_, rdjo,
   {{0x557702b5,0x6f1d5661,0x62855662,0x291e5663}},	//   _זעהן_, _pusc, _waho, _muta_,
   {{0x62855664,0x6d450526,0x291e5665,0x44295666}},	// [5170] _taho, wsha, _luta_, _ifa_,
   {{0x6d455667,0x80c1111a,0x6e25033b,0x644d0211}},	//   tsha, रोजे, uchb, _hdai,
   {{0x7c2d2b83,0x6f155668,0x6e253ac5,0x3f8206a2}},	//   ñaro, _vizc, rchb, _esku_,
   {{0x7bf90adb,0xe45f01ff,0x6e25033b,0x6d455669}},	//   онер_, ngö_, schb, rsha,
   {{0x291e0e7d,0x6d45566a,0x2d9c013c,0x68e4300b}},	//   _auta_, ssha, äver_, čidl,
   {{0x291e09df,0x28ca0722,0x69c30588,0x1ee7014a}},	//   _buta_, ़ोसि, tzne, _روزی_,
   {{0x7641566b,0x69230009,0x644d566c,0xc879566d}},	//   valy, _eđen, _odai, teş_,
   {{0xe9d001cb,0xfc330071,0x291e1034,0x442943dc}},	//   دغه_, _سحر_, _duta_, _nfa_,
   {{0xc879566e,0xf7080019,0x69c307cf,0x7c291d75}},	//   reş_, _hủy_, szne, _ifer,
   {{0x4429566f,0x644d5670,0x291e5671,0x00000000}},	//   _afa_, _adai, _futa_, --,
   {{0xb05b022a,0x291e5672,0xdddc5673,0xa50a5674}},	//   _kläd, _guta_, _karš, жена_,
   {{0x2d9100cb,0x44294b2f,0xb6050a66,0x87b90043}},	//   _mrze_, _cfa_, _rušč, _мулт_,
   {{0xdddc0a09,0xaca301a5,0x38b800f7,0x386d0345}},	//   _marš, _chỉn, _zéro_, mfer_,
   {{0x44295675,0x291e5676,0x386d5677,0x78ab4bba}},	//   _efa_, _yuta_, lfer_, _hogv,
   {{0x7c295678,0x77695679,0x4429567a,0xa18703fa}},	//   _ofer, ltex, _ffa_, мбра_,
   {{0xf1b80484,0xdddc00d8,0x7c2d05c9,0xc5f200a5}},	//   ġġ_, _narš, ñarl, _שדה_,
   {{0x4de60035,0xd4691ee1,0x386d567b,0x98a600cd}},	// [5180] _जुड़े_, _رحيم_, ifer_, žiće_,
   {{0x2d91011c,0xb605010b,0x442908c7,0x77690051}},	//   _brze_, _tušč, _zfa_, itex,
   {{0xdddc567c,0x7cf80279,0x201e002d,0x64490093}},	//   _barš, líri, _ştiu_, ðeig,
   {{0xa3e211b5,0x386d01e4,0x2d910124,0x44290453}},	//   _दशा_, jfer_, _drze_, _xfa_,
   {{0x291e567d,0x3f821c12,0x7c2901ed,0x776901e9}},	//   _suta_, _usku_, _dfer, jtex,
   {{0x291e567e,0x386d509c,0x2bd200a1,0x776903da}},	//   _puta_, efer_, _देणा, dtex,
   {{0x7c29001e,0x386d567f,0xe2a7008d,0x78ab5680}},	//   _ffer, ffer_, æðir_, _bogv,
   {{0x52bb05f7,0xb05b013c,0xdddc00ea,0x291e08c7}},	//   _उत्स, _gläd, _garš, _vuta_,
   {{0x78ab0009,0x291e01cb,0x77695681,0xc7c600c3}},	//   _dogv, _wuta_, gtex, ьски,
   {{0x442901a2,0x291e5682,0xc6f70f99,0x2002034d}},	//   _sfa_, _tuta_, мных_, _mzki_,
   {{0x44295683,0x2bd20914,0x186a03e6,0xda6500ce}},	//   _pfa_, _देता, _мажи_, _سالي,
   {{0x7cf80079,0xb8930037,0x200202a7,0x00000000}},	//   fíri, _للمع, _ozki_, --,
   {{0x4429055c,0xb05b0282,0x00000000,0x00000000}},	//   _vfa_, _omär, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29060028,0x22435684,0x69230009,0x80c80033}},	//   _khoa_, rajk_, _nđel, রচন্,
   {{0xd78801a5,0xe45f00a6,0x92cf0083,0xaca30023}},	//   _kể_, riös_, ষকে_, _thỉn,
   {{0xa29500d8,0x332001f7,0x7c2d0453,0x22b80107}},	// [5190] _запі, _guix_, ñarm, _fٍk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2901ae,0x6d5a013c,0x68e25685,0x386d3c30}},	//   _pfer, _åtal, _ojod, yfer_,
   {{0x77690118,0x6fd00099,0x68e20118,0xfc3000bc}},	//   ytex, _ठेवू, _njod, لحه_,
   {{0x7769009e,0x24895686,0x22580df3,0x24c10033}},	//   xtex, _maam_, _عجیب_, _উদাহ,
   {{0x4aa80409,0x24895687,0x29065688,0x8c3d0139}},	//   мкін_, _laam_, _ahoa_, _moşi,
   {{0xd940010b,0x68e203d0,0x00000000,0x00000000}},	//   ацыi_, _bjod, --, --,
   {{0x2489201e,0x26de5689,0x69151840,0x7769568a}},	//   _naam_, ento_, _všeo, ttex,
   {{0x386d568b,0x236901e8,0xb8e7022e,0x7cf801ef}},	//   rfer_, _nqaj_, _उत_, xíri,
   {{0xd70603ad,0x386d568c,0x2cad3368,0x26de0159}},	//   нные_, sfer_, _hoed_, gnto_,
   {{0x68e2568d,0x386d033b,0x2cbf568e,0x38b100fe}},	//   _fjod, pfer_, _klud_, _bárt_,
   {{0x7cf8002a,0x77690118,0x332001f7,0x38b100ac}},	//   tíri, ptex, _puix_, _páru_,
   {{0x2cad11ad,0x68fb0225,0xa3f5010b,0x24893660}},	//   _moed_, mlud, вярш, _daam_,
   {{0x290d568f,0x00000000,0x00000000,0x00000000}},	//   lmea_, --, --, --,
   {{0xf6520319,0x248901bf,0x11d501e0,0x3d1800be}},	//   _עצה_, _faam_, вітр, _बूझे_,
   {{0x7cf84a74,0xb05b013c,0x3ce90067,0x25d6016b}},	//   píri, _smär, टकों_, _רוקן_,
   {{0x64460f1a,0x48fa0070,0x00000000,0x00000000}},	// [51a0] maki, פּלא, --, --,
   {{0x64465690,0x2a650260,0x6f070069,0x611c0107}},	//   laki, _nclb_, _chjc, _bčlt,
   {{0xd00f006c,0x248901e8,0x68fb48d9,0x2cbf00ee}},	//   للہ_, _yaam_, klud, _blud_,
   {{0x64465691,0x8fa65692,0x2cad00e9,0x68fb5693}},	//   naki, _заме, _coed_, jlud,
   {{0xfbd201cb,0x69150097,0x2cad0090,0x00000000}},	//   دتا_, _všel, _doed_, --,
   {{0x64461982,0x60c40279,0xd7880023,0x629800b5}},	//   haki, lhim, _rể_, _óvod,
   {{0x64465694,0x2d9e0124,0xff072d93,0x317a016b}},	//   kaki, _štef_, _черк_, לאַד,
   {{0x2cad201e,0x6d5e5695,0x7e7e5696,0x7d032193}},	//   _goed_, mupa, lepp, ïnst,
   {{0x6d5e5697,0x64465698,0xe66613f8,0x248936bd}},	//   lupa, daki, нтно, _raam_,
   {{0x24890626,0x26de0382,0x6b82276d,0x8c3d00af}},	//   _saam_, unto_, mwog, _roşi,
   {{0xd5b75699,0x68fb0254,0x49ba006c,0x6d5e569a}},	//   еся_, blud, _عائد_, nupa,
   {{0x68fb0052,0x7e7e13ee,0x6446569b,0xd78800e2}},	//   clud, hepp, gaki, _tể_,
   {{0x5ef506fe,0x60c4569c,0xf09f0284,0x7e7e569d}},	//   ्तम्_, dhim, _bhàn_, kepp,
   {{0x6d5e569e,0x8caa0324,0x00000000,0x00000000}},	//   kupa, _झकझो, --, --,
   {{0x6446569f,0x248956a0,0x6d5e56a1,0xf09f0211}},	//   baki, _taam_, jupa, _dhàn_,
   {{0x6d5e0f1a,0x60c40b04,0xd5fb0397,0xb5fb0317}},	//   dupa, ghim, _מפור, _מלוכ,
   {{0xf1b90029,0x443956a2,0x00000000,0x00000000}},	// [51b0] ņš_, mbs_, --, --,
   {{0xdd950086,0xaca30019,0x2cad022e,0xb05b01ff}},	//   казы, _thịn, _soed_, _bläc,
   {{0xe2a7008a,0x2cad00be,0x443900f6,0x00000000}},	//   æður_, _poed_, obs_, --,
   {{0x2bd20864,0xec1500bf,0x69150009,0xc5f30070}},	//   _देहा, نواد, _pšem, אדע_,
   {{0x2cad03bc,0xbc180185,0x00000000,0x00000000}},	//   _voed_, ніші_, --, --,
   {{0x644656a3,0x6d5e0406,0xeb960227,0xb05b15e8}},	//   zaki, bupa, тиш_, _fläc,
   {{0x64460600,0x2cad0024,0x6d5e2e0f,0x7ae4002a}},	//   yaki, _toed_, cupa, éita,
   {{0xa3c10429,0x2bd20ceb,0x2919013c,0x644601b7}},	//   ंना_, _देवा, ösa_, xaki,
   {{0x644656a4,0x7d0901d7,0x290d56a5,0x38660069}},	//   vaki, _ihes, rmea_, _dcor_,
   {{0x644656a6,0xa695192f,0x60c401f4,0x68fb56a7}},	//   waki, триј, zhim, slud,
   {{0x644656a8,0x7d1b56a9,0xf09f00e2,0x00000000}},	//   taki, _kius, _nhào_, --,
   {{0x8934004f,0x60c40031,0x00000000,0x00000000}},	//   _إعلا, xhim, --, --,
   {{0x7d09000e,0x387f56aa,0x78a956ab,0xf09f00e2}},	//   _mhes, meur_, mjev, _phàn_,
   {{0x78a91851,0x387f56ac,0x644656ad,0x6d5e0c47}},	//   ljev, leur_, saki, yupa,
   {{0x644656ae,0xf09f01a5,0x60c456af,0x442b00d7}},	//   paki, _chào_, thim, bcc_,
   {{0x78a90169,0x387f56b0,0x8c3d01d6,0x764311e9}},	//   njev, neur_, _koşu, _heny,
   {{0x764327df,0x60c40ec0,0x0e6656b1,0x4420217c}},	// [51c0] _keny, rhim, ккан, _igi_,
   {{0x60c456b2,0x6d5e56b3,0xb0c61649,0x752356b4}},	//   shim, tupa, रोजग, _kunz,
   {{0x2b4d105d,0x7643149f,0x629e56b5,0x78bb127d}},	//   _avec_, _meny, _inpo, kkuv,
   {{0x6d5e120d,0x7e7e56b6,0x628e56b7,0x764356b8}},	//   rupa, sepp, ldbo, _leny,
   {{0x2bd202cb,0x7d1b149f,0x78a906fd,0x44204164}},	//   _देशा, _dius, djev, _mgi_,
   {{0x628e56b9,0x7cf856ba,0xc8820095,0x386656bb}},	//   ndbo, víru, mişə_, _scor_,
   {{0x387f56bc,0xada3095d,0x6df6004f,0x7d1b028b}},	//   feur_, _карл, _شكرا, _fius,
   {{0x7d1b0133,0x78a956bd,0x44202cb7,0x387f56be}},	//   _gius, gjev, _ngi_, geur_,
   {{0x6f1c56bf,0xaca301a5,0x764356c0,0x8c3d56c1}},	//   _kirc, _giốn, _beny, _coşu,
   {{0x442056c2,0x75230027,0x6f1c0024,0x76432e6a}},	//   _agi_, _bunz, _jirc, _ceny,
   {{0x76430260,0x387f0626,0x6f1c5652,0xceb3134d}},	//   _deny, beur_, _mirc, ייז_,
   {{0x442056c3,0x387f00f7,0x628e56c4,0x7cf80097}},	//   _cgi_, ceur_, edbo, píru,
   {{0x443956c5,0x317a0024,0x764356c6,0x442045e3}},	//   rbs_, _appz_, _feny, _dgi_,
   {{0x7643142f,0x752307c9,0x26c501ba,0x442056c7}},	//   _geny, _funz, chlo_, _egi_,
   {{0x764824ef,0x171b0070,0x442b0090,0x550700af}},	//   mady, _קווע, pcc_, _ичиа,
   {{0x629e02d0,0x76430054,0x76485527,0x6f1c56c8}},	//   _enpo, _zeny, lady, _airc,
   {{0x7643000e,0x7d090297,0x7d1b01d3,0xb4c10084}},	// [51d0] _yeny, _rhes, _rius, ूफी_,
   {{0x6f1c225a,0xfe7007f8,0x539a0122,0x7d0901f4}},	//   _circ, قدم_, _ניתו, _shes,
   {{0x6f1c56c9,0x387f56ca,0x7d1b56cb,0x5dd50079}},	//   _dirc, yeur_, _pius, دقائ,
   {{0x8c3d00af,0x6f1c3909,0x387f00a2,0x4420009e}},	//   _noşt, _eirc, xeur_, _xgi_,
   {{0x387f378b,0x7d1b01dd,0x7648010d,0x752d0124}},	//   veur_, _vius, kady, _čazm,
   {{0x6d580237,0x6915010b,0xf09f009e,0x00000000}},	//   ávac, _išei, _mhàm_, --,
   {{0x387f56cc,0x7d090052,0x78a901f4,0x7c240496}},	//   teur_, _thes, tjev, žira,
   {{0x764356cd,0x7d094354,0x752309aa,0x00000000}},	//   _seny, _uhes, _runz, --,
   {{0x7643124f,0x387f56ce,0x78a956cf,0x8c3d0095}},	//   _peny, reur_, rjev, _qoşu,
   {{0x387f56d0,0xb7bd0043,0x6b8956d1,0xceb40095}},	//   seur_, ncţi, _iseg, qqət_,
   {{0x04460de9,0x78a90c21,0xd46a56d2,0x387f00f7}},	//   ленн, pjev, нине_, peur_,
   {{0x76432176,0x3f4f0029,0xf7710a42,0x75230009}},	//   _weny, kļu_, _هات_, _vunz,
   {{0x765c004e,0x764856d3,0x7e9b0029,0xe91800d4}},	//   óryc, bady, _kāpē, _році_,
   {{0x291d11e9,0xf09f01f7,0x764308c7,0x752340b5}},	//   _hiwa_, _anà_, _ueny, _tunz,
   {{0x2729064b,0x291d56d4,0x442000f6,0x7ae301a6}},	//   _hún_, _kiwa_, _tgi_, innt,
   {{0x291d272d,0xdfd2004f,0x442000bf,0x656156d5}},	//   _jiwa_, ميز_, _ugi_, mulh,
   {{0x272956d6,0x3f4f0029,0x6f1c00ea,0x291d56d7}},	// [51e0] _jún_, gļu_, _pirc, _miwa_,
   {{0x6da60011,0x291d44da,0x27290023,0x6e46414b}},	//   лиза, _liwa_, _mún_, انام,
   {{0x6b8956d8,0x6f1c56d9,0x272956da,0x2d96004b}},	//   _aseg, _virc, _lún_, ырас,
   {{0x5fd500a1,0x9b6a4ae8,0x1b4a4de5,0x6b890069}},	//   _ठेवल, ешка_, езди_, _bseg,
   {{0xb05b0301,0x2d8701b4,0x656156db,0x6f1c0036}},	//   _klän, æner_, hulh, _tirc,
   {{0x69ca0110,0x61fe0103,0x408600fd,0x00000000}},	//   tzfe, _kypl, _جھڑپ_, --,
   {{0x27290083,0x6b8956dc,0xa96704bf,0x80b800dc}},	//   _aún_, _eseg, гија_, _इकाइ,
   {{0x37e80083,0x7ae3184f,0x27290023,0x69dc0093}},	//   _পরবর, annt, _bún_, _þrem,
   {{0x291d11e9,0x27290023,0x7648459f,0x888100f8}},	//   _diwa_, _cún_, tady, زیون,
   {{0x27290037,0x4ab820af,0x55742bfc,0xaab8035d}},	//   _dún_, _अविव, агот, _अविक,
   {{0x764856dd,0x656103e6,0xdef702b5,0x61fe0282}},	//   rady, gulh, רמיט_, _nypl,
   {{0x7648190b,0x26d900f7,0xf09f00e2,0xf74602ee}},	//   sady, ésor_, _phàm_, _бедо,
   {{0xf09f01a5,0xfbc40026,0xaab8052f,0xb05b017b}},	//   _giày_, वनिम, _अवाक, _blän,
   {{0x248d0936,0x291d0054,0x65943379,0x2d8a0031}},	//   žem_, _ziwa_, _ваку, _osbe_,
   {{0x291d030d,0x5a9b016b,0x6561021d,0x61fe1019}},	//   _yiwa_, עשלא, culh, _cypl,
   {{0x955307f6,0x61fe0067,0xb05b56de,0xfbc405f8}},	//   _اخوا, _dypl, _elän, वनाम,
   {{0x1ee700d1,0x2d9856df,0xb05b0523,0x7ae3008d}},	// [51f0] هوری_, _arre_, _flän, ynnt,
   {{0xaca30019,0x63a202c4,0xb05b19ee,0x7f4d542a}},	//   _phỏn, _šong, _glän, rsaq,
   {{0x7f4d0024,0x9e070c88,0xa2a2007e,0x6b8956e0}},	//   ssaq, учал, खार्, _sseg,
   {{0x20070095,0x6fd037e8,0x00000000,0x00000000}},	//   ənin_, _सेकं, --, --,
   {{0x2d980332,0x90982021,0x20c700ab,0x6d4a003e}},	//   _erre_, _свят_, _võid_, áfar,
   {{0x291d05ca,0x272956e1,0x6b89008b,0x00000000}},	//   _siwa_, _rún_, _vseg, --,
   {{0x611500d8,0x7bdc0096,0x20c700be,0x291d0067}},	//   _sąly, _śrut, _tõid_, _piwa_,
   {{0x6b89006d,0x52d100be,0x00000000,0x00000000}},	//   _tseg, सफुस, --, --,
   {{0x6a671144,0x29030080,0x7e9b0029,0xaca300cc}},	//   _مطال, ēja_, _tāpē, _ghền,
   {{0x49050299,0x81bb0083,0x681b0029,0x656156e2}},	//   _हीरो_, _আইন_, _rādī, tulh,
   {{0x291d224e,0x27e00093,0x64a6004b,0x81c300ea}},	//   _tiwa_, _þinn_, аана, šēji,
   {{0x656103e6,0x232a07e5,0xb05b013c,0x272956e3}},	//   rulh, коми_, _slän, _tún_,
   {{0xf745355e,0xb05b56e4,0x2aab0b41,0x7afa03d0}},	//   _тело, _plän, _søby_, _yktt,
   {{0x61fe0ff2,0x656156e5,0x00000000,0x00000000}},	//   _pypl, pulh, --, --,
   {{0xa3e20b35,0x614608ce,0xe2970d6e,0x00000000}},	//   _दशक_, реба, јас_, --,
   {{0x92d600c8,0x61fe1840,0x91e301e0,0x00000000}},	//   িকে_, _vypl, іоте, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5200] --, --, --, --,
   {{0xee3756e6,0x00000000,0x00000000,0x00000000}},	//   ину_, --, --, --,
   {{0x720602fd,0x0d8608ce,0x71a6034b,0x3f8b0160}},	//   _خودم, рлен, _танз, _escu_,
   {{0x3f8b0345,0x00000000,0x00000000,0x00000000}},	//   _fscu_, --, --, --,
   {{0x92e80033,0x9abc035f,0x60c300af,0x00000000}},	//   বতী_, _liċe, _înma, --,
   {{0xd9542ac4,0x27e0010b,0x00000000,0x00000000}},	//   منتخ, _žino_, --, --,
   {{0x8c4612f3,0x5ef5021a,0x2d9856e7,0x98c60d6e}},	//   _вебе, ्तर्_, _urre_, исил,
   {{0xb4c5018d,0x7c2d0453,0xfce656e8,0xf4c10033}},	//   _एते_, ñart, _тобо, _উদ্ব,
   {{0xc6a6316d,0xab2a0112,0x7d0256e9,0xc6f803fa}},	//   арни, _роза_, mlos, лних_,
   {{0x6d5e0051,0x00000000,0x00000000,0x00000000}},	//   orpa, --, --, --,
   {{0x7aed0248,0xd82f0012,0x7d0256ea,0x00000000}},	//   éate, _мэ_, olos, --,
   {{0x7d0202c9,0x18a318cd,0xf8da0722,0x9abc003c}},	//   nlos, _махм, _बगिय, _diċe,
   {{0xe7950118,0x66e630ad,0x6d5e02b1,0x00000000}},	//   _هاوک, _кода, hrpa, --,
   {{0x7d0202c9,0x60c656eb,0x6d5e003d,0x1dc60e61}},	//   hlos, _alkm, krpa, लनात,
   {{0x854601c8,0x7d0220d7,0x2d850300,0x691500ac}},	//   _тэле, klos, _álex_, _všev,
   {{0x30a40370,0x3ce602c4,0x63a20228,0x361b024b}},	//   орув, jnov_, _šone, _בווד,
   {{0x6d580237,0x6d5e56ec,0x98af0009,0x00000000}},	// [5210] ávan, erpa, žaće_, --,
   {{0x69150009,0xc8791505,0x00000000,0x00000000}},	//   _ušev, mişe_, --, --,
   {{0x20c70ccf,0x63bd31cb,0x78a256ed,0x518741f8}},	//   _võib_, lysn, _onov, _тупа,
   {{0xf3ff0132,0xe7b801d1,0xb05b01ff,0x61fb027b}},	//   ngão_, ेनाप, _kläm, ğuld,
   {{0x307a02b5,0x69de01ba,0x799a56ee,0x61fb0457}},	//   _גארנ, úpen, _artw, şuld,
   {{0xe8e000e2,0x28a9022e,0x00000000,0x00000000}},	//   ướt_, काभि, --, --,
   {{0x6915024e,0x7c2d1111,0x7d0256ef,0x6ca70834}},	//   _ošet, ñars, blos, _краж,
   {{0x9abc0484,0x7d0256f0,0x19b800af,0xb05b017b}},	//   _riċe, clos, рушь_, _oläm,
   {{0x4432022e,0x78a256f1,0x6c6a00b5,0xcb3402fb}},	//   _rfy_, _dnov, _حلقہ_, _метъ,
   {{0x78a20292,0x6b9b56f2,0x38b82919,0x00000000}},	//   _enov, _irug, _sért_, --,
   {{0x8afa0070,0x00000000,0x00000000,0x00000000}},	//   _עפעק, --, --, --,
   {{0x6b9b56f3,0x3915477b,0xf41f00c3,0xe799097f}},	//   _krug, _умер, ydät_, _مختص_,
   {{0xf09f0211,0x00000000,0x00000000,0x00000000}},	//   _ghài_, --, --, --,
   {{0x78a20e6a,0x216a0d46,0x23271dd0,0x673b56f4}},	//   _znov, лиги_, сори_, mpuj,
   {{0x20564f87,0xb05b03ad,0x7d02027a,0x3ce656f5}},	//   йтар, _eläm, ylos, ynov_,
   {{0x257100fb,0x92e80033,0x6b9b02d7,0xb05b191b}},	//   mál_, বতে_, _orug, _fläm,
   {{0x543b02b5,0x600a0144,0x8fa356f6,0x257100b5}},	// [5220] _געפא, унам_, пате, lál_,
   {{0x5286004f,0x6d5e01a0,0x2bdb0a40,0x00000000}},	//   _الدك, trpa, _मेधा, --,
   {{0x25712d87,0x7d020a78,0x3ce60355,0x6b9b56f7}},	//   nál_, tlos, tnov_, _arug,
   {{0x6b9b4d3e,0xab2a3e19,0x6d5e0c6f,0xd5fa016b}},	//   _brug, года_, rrpa, אפער,
   {{0x7d0256f8,0x2bd256f9,0x2bdb0066,0x6b9b0090}},	//   rlos, _देखा, _मेदा, _crug,
   {{0x7d0214f0,0x6b9b56fa,0x78a217ee,0x6da62f72}},	//   slos, _drug, _snov, _лига,
   {{0xf41f191b,0x6b9b56fb,0x00000000,0x00000000}},	//   ndär_, _erug, --, --,
   {{0x6b9b56fc,0x47342d4d,0x257105f6,0x9abc0024}},	//   _frug, онис, dál_, _biċc,
   {{0x6b9b56fd,0x31980260,0x78a20116,0xdddc0409}},	//   _grug, _lčz_, _vnov, _jarž,
   {{0x8c3d06d3,0x7e7c0107,0xdd1c00ac,0x00000000}},	//   _inşa, _jbrp, nážn, --,
   {{0x7c2d0759,0xf76f00f8,0x257156fe,0x00000000}},	//   žare, وای_, gál_, --,
   {{0x78a21bd8,0x24190421,0x68eb01ed,0x320100ee}},	//   _unov, ионы_, _gjgd, _ryhy_,
   {{0x6915124b,0x2f0f033b,0x2efa0110,0x33290051}},	//   _všet, lüge_, kopf_, _quax_,
   {{0x776000e5,0x7ae4004f,0xa49b0176,0x00000000}},	//   mrmx, éith, clòn, --,
   {{0x26de56ff,0x6d581d85,0x225f027d,0x692300cd}},	//   mito_, ával, ğuk_, _uđet,
   {{0x764a02c7,0x6915024e,0xdddc2b6c,0x00000000}},	//   _hefy, _ušet, _barž, --,
   {{0x9ed95700,0x29041c55,0x6d580029,0x63a90bf3}},	// [5230] амат_, ilma_, šval, åend,
   {{0x6b9b01d2,0x59a80162,0xdddc00d8,0x00000000}},	//   _rrug, कमार, _darž, --,
   {{0x62875701,0x764a0107,0xdd9b0f8f,0x26de021d}},	//   mejo, _mefy, ыша_, iito_,
   {{0xd5fb02b5,0xe9a900bf,0x62875702,0x6b9b0254}},	//   נפאר, یگان_, lejo, _prug,
   {{0x26de5703,0x60cd5704,0x76580097,0x61ef00e2}},	//   kito_, mham, _odvy, ânlư,
   {{0x60cd5705,0x62875706,0x6b9b053e,0x8f34562d}},	//   lham, nejo, _vrug, _херц,
   {{0x26de5707,0x644f5708,0x00000000,0x00000000}},	//   dito_, kaci, --, --,
   {{0x644f5520,0x60cd5709,0x6b9b570a,0x66c40107}},	//   jaci, nham, _trug, _bòko,
   {{0x6b9b570b,0x26de009f,0x28d8198f,0x752a01ae}},	//   _urug, fito_, बोधि, _aufz,
   {{0x257105fa,0x96d400b4,0xb886002a,0x764a099e}},	//   tál_, योलॉ, tuíñ, _cefy,
   {{0x34aa05c2,0x20c90026,0x764a570c,0x60cd08c7}},	//   авно_, रसाध, _defy, kham,
   {{0x2571570d,0x69151615,0x673b00c3,0x62950228}},	//   rál_, _všes, ppuj, edzo,
   {{0x26de18e0,0x60cd000e,0x98f4036b,0x232a3174}},	//   bito_, dham, _عثما, роги_,
   {{0x26de0042,0x68fb0086,0xb05b01ff,0x68e934ae}},	//   cito_, loud, _fläk, lned,
   {{0x90b602cc,0x644f003a,0x7641570e,0xdd1c0e06}},	//   ољаш, baci, mbly, vážn,
   {{0x644f4df4,0x60cd43c9,0x33660a71,0x68fb570f}},	//   caci, gham, _двиг, noud,
   {{0x67233eeb,0x68e93084,0x2f0f033b,0x62875710}},	// [5240] _kinj, ined, züge_, bejo,
   {{0x68fb04ce,0xdddc00d8,0x67235711,0x672b0051}},	//   houd, _varž, _jinj, _mugj,
   {{0xc27b0100,0x68fb0107,0x527b0d85,0x67235712}},	//   _דריי, koud, _דניא, _minj,
   {{0x60cd5713,0x67235714,0xdd1c0187,0xfbdb1282}},	//   cham, _linj, sážn, _मेहम,
   {{0x99a50009,0x26de04fb,0x60c45715,0x66035716}},	//   _čuše_, yito_, mkim, _lynk,
   {{0x644f5717,0x60c45718,0x26de0138,0x539b0d85}},	//   zaci, lkim, xito_, יינו,
   {{0x26de5719,0x66030223,0x7c2f571a,0x3eb80211}},	//   vito_, _nynk, _širš, _iort_,
   {{0x764a0297,0x644f2651,0x60c400d8,0x68e9035b}},	//   _sefy, xaci, nkim, gned,
   {{0x26de571b,0x3eb81b54,0xb05b013c,0x672320b3}},	//   tito_, _kort_, _släk, _binj,
   {{0x6723571c,0xddde002d,0x60c4571d,0x3eb80051}},	//   _cinj, cepţ, hkim, _jort_,
   {{0x67230484,0x3eb8571e,0x6287431a,0x60c4571f}},	//   _dinj, _mort_, vejo, kkim,
   {{0x26de5720,0x3eb808c8,0x26cc0031,0x9f5900ac}},	//   sito_, _lort_, shdo_, _lysá_,
   {{0x26de5721,0x6d58024e,0x75244ae0,0x62875722}},	//   pito_, ávaj, _diiz, tejo,
   {{0x25470332,0x644f5723,0x3eb802c4,0xe5721b15}},	//   ből_, saci, _nort_, _قطع_,
   {{0x644f3ec3,0x7524073a,0x26dc0371,0x62955724}},	//   paci, _fiiz, _imvo_, rdzo,
   {{0x62875725,0x68e05726,0x22460009,0x22b40225}},	//   sejo, nimd, _đoke_, _aşkı_,
   {{0x44295727,0x60cd5728,0x3eb81875,0x628700de}},	// [5250] _iga_, rham, _bort_, pejo,
   {{0x60cd5729,0xdd9b572a,0x3eb8572b,0x644d009e}},	//   sham, ише_, _cort_, _heai,
   {{0x3eb802c9,0x68e90297,0x644d00d7,0x60cd572c}},	//   _dort_, yned, _keai, pham,
   {{0x60c4572d,0x6ab80067,0x00000000,0x00000000}},	//   ckim, _अवॉर, --, --,
   {{0x44291188,0x65680245,0x644d0037,0xeb992aac}},	//   _mga_, hudh, _meai, сил_,
   {{0x644d572e,0xda7b172a,0x6568572f,0x3eb85730}},	//   _leai, ряд_, kudh, _gort_,
   {{0xceb20779,0x44295731,0x67234dbf,0x672b01f4}},	//   _אים_, _oga_, _rinj, _sugj,
   {{0x44295732,0x67235733,0xa3cb162b,0x66035734}},	//   _nga_, _sinj, लना_, _rynk,
   {{0x76410297,0x67235735,0x68e95736,0x68fb5737}},	//   tbly, _pinj, rned, roud,
   {{0x44295738,0x2547006c,0xddde05cd,0x68e95739}},	//   _aga_, től_, lepš, sned,
   {{0x442901a2,0x6723573a,0x7641573b,0x60c4573c}},	//   _bga_, _vinj, rbly, ykim,
   {{0x25470332,0x81e90083,0x44294204,0x644d2e75}},	//   ről_, _বরং_, _cga_, _ceai,
   {{0x6723573d,0x66030b88,0x00000000,0x00000000}},	//   _tinj, _wynk, --, --,
   {{0x4429573e,0xf67502b5,0x386d1123,0x6568573f}},	//   _ega_, _זײַט_, lger_, budh,
   {{0x2f144b47,0x60c403ad,0x20c700ab,0x505a0104}},	//   lägg_, tkim, _võin_, йшая_,
   {{0x386d5740,0xf9920779,0xddde0c21,0x55ba0122}},	//   nger_, ערן_, jepš, _למצו,
   {{0x60c45741,0x3eb820ac,0x386d5742,0x61fb027b}},	// [5260] rkim, _port_, iger_, ğula,
   {{0x7c295743,0x60c45744,0xd00f004f,0x26c5010b}},	//   _ager, skim, الك_, nklo_,
   {{0xf09f0211,0x3eb8242f,0x68e02f80,0x3f8f008d}},	//   _chàs_, _vort_, yimd, ægur_,
   {{0x3eb801ae,0xf53602b5,0x386d1a43,0x00000000}},	//   _wort_, לטער_, jger_, --,
   {{0x3eb81c9e,0x6e3b027d,0x386d062c,0xb09b024b}},	//   _tort_, _şube, dger_, _היכר,
   {{0x386d5745,0x7c295746,0x656800f8,0x3eab003c}},	//   eger_, _eger, yudh, ċità_,
   {{0x2480042a,0x68e01d1b,0x7c2d00f4,0x26dc0345}},	//   _obim_, timd, žara, _rmvo_,
   {{0x386d0075,0x200f02b1,0x00000000,0x00000000}},	//   gger_, ügig_, --, --,
   {{0x644d0bc8,0x68e000d0,0x7b09008a,0x4429013a}},	//   _reai, rimd, ðstö, _rga_,
   {{0x692a0311,0x24805747,0x68e05748,0x644d0079}},	//   _před, _abim_, simd, _seai,
   {{0xceb30052,0x6aa8054e,0x59860bef,0x45d40166}},	//   תית_, _indf, _хлеб, фонс,
   {{0x65685749,0xc9850037,0x00000000,0x00000000}},	//   rudh, _تشكي, --, --,
   {{0x28a9043b,0x46a6574a,0x656800e0,0x644d574b}},	//   कारि, _надв, sudh, _veai,
   {{0x4429574c,0x97134747,0x00000000,0x00000000}},	//   _wga_, _зміц, --, --,
   {{0x4429010d,0x27320019,0x4ddc0722,0x867b00a5}},	//   _tga_, _hân_, _गेलै_, _הרוו,
   {{0x442901ca,0xd498002d,0x6aba00f6,0x00000000}},	//   _uga_, _ерь_, _lotf, --,
   {{0xf09f0211,0xaabe06bc,0x00000000,0x00000000}},	// [5270] _bhàr_, ्साक, --, --,
   {{0x20070228,0xf09f0284,0x6aba574d,0x27323f14}},	//   āni_, _chàr_, _notf, _mân_,
   {{0x2732574e,0x386d574f,0xad270312,0x00000000}},	//   _lân_, yger_, سراو, --,
   {{0xd01000b5,0x5fde046c,0x6aa85750,0x00000000}},	//   ئلے_, _नेवल, _andf, --,
   {{0x05de19db,0x7aed000d,0xa09a00a5,0x629701ed}},	//   _फेसब, éato, _וירט, _kaxo,
   {{0xf09f009e,0xa01b0282,0x00000000,0x00000000}},	//   _ghàr_, _eböc, --, --,
   {{0x386d0fe8,0x28a90d34,0xb60700d5,0x98a500ec}},	//   tger_, कालि, _miší, _aulā_,
   {{0x386d5751,0x26f7035d,0x7c295752,0xb4bc007c}},	//   uger_, ुत्र_, _uger, _आके_,
   {{0x27325753,0x386d52a5,0xcd020035,0x6aba4a11}},	//   _cân_, rger_, _dość_, _fotf,
   {{0x273200e8,0x0575004f,0x63a20009,0x79960035}},	//   _dân_, واجد, _šono, ływa,
   {{0x7ae30104,0x2bbd046c,0x386d01ff,0x00000000}},	//   mint, ्नवा, pger_, --,
   {{0x7ae31385,0xcd02004e,0x69c300e9,0x2f1400b9}},	//   lint, _gość_, myne, mäge_,
   {{0x1e0a19db,0x7e0a035d,0x69c35754,0x2f1415e8}},	//   _वर्ष_, _वर्ग_, lyne, läge_,
   {{0x7ae35755,0x0693006c,0x62970176,0xe0df021e}},	//   nint, _ساتھ, _caxo, _amò_,
   {{0xdb2600a8,0xb0c95756,0x75d21c2d,0x69c35757}},	//   şqçi, रसंग, _ليوا, nyne,
   {{0x7ae35758,0xf09f01da,0x9fca5759,0x00000000}},	//   hint, _shàr_, огба_, --,
   {{0x7ae3575a,0xd007014d,0x629700ac,0x31780067}},	// [5280] kint, дете_, _faxo, strz_,
   {{0xbefa018d,0x7ae3010b,0x9d4605e1,0x69c3382a}},	//   ्तेन_, jint, дежд, kyne,
   {{0x7ae31009,0x6aba575b,0xdcfc013a,0x00000000}},	//   dint, _rotf, _aprā, --,
   {{0x7c2d0169,0x69c3575c,0x7c830421,0x04040831}},	//   žarn, dyne, вуше, রেণী_,
   {{0xe7e800c8,0x7ae3575d,0x6d6700d8,0x6aba02c4}},	//   _পর্য, fint, _įraš, _potf,
   {{0x7ae3575e,0x6d5700a8,0x00000000,0x00000000}},	//   gint, bsxa, --, --,
   {{0x273201a5,0x7bc20cd4,0x00000000,0x00000000}},	//   _sân_, syou, --, --,
   {{0x7ae3412a,0x692a00b8,0xa3be01d1,0xcc8713df}},	//   aint, _přeb, _इथं_, _обсе_,
   {{0x692a0355,0xb05b02b1,0xfce310e3,0x00000000}},	//   _břec, _gläu, _рото, --,
   {{0x7ae3575f,0x273201a5,0x6aa8029e,0xcaa60698}},	//   cint, _vân_, _undf, _تصري,
   {{0x27e900fb,0xb05b01ff,0x7afd008e,0x62971c7a}},	//   _þann_, _klät, _ísta, _raxo,
   {{0x27325760,0x692a000c,0x22460009,0xa2c10026}},	//   _tân_, _třeb, _đoka_, रॉन्,
   {{0xd91b1abe,0x00000000,0x00000000,0x00000000}},	//   _וואל, --, --, --,
   {{0x0ccb0026,0x0576211b,0x20c700be,0x00000000}},	//   _ात्म, _قاعد, _võim_, --,
   {{0xdb0001f4,0x26ce0107,0x41e412ea,0x00000000}},	//   _armë, _ilfo_, віта, --,
   {{0x7ae35761,0x62970051,0x50645762,0x00000000}},	//   zint, _waxo, ктуа, --,
   {{0x62975763,0x3cf20084,0x7ae35764,0x00000000}},	// [5290] _taxo, ंचने_, yint, --,
   {{0x20c70ccf,0x7ae30065,0x443900b5,0x66c40260}},	//   _kõik_, xint, lcs_, _bòki,
   {{0x7ae35765,0x2578006c,0xb05b033b,0x3d2900f8}},	//   vint, nél_, _blät, ستای_,
   {{0x7ae35766,0x213e0037,0x44395767,0x80270079}},	//   wint, íthe_, ncs_, _يرحم,
   {{0x60d602da,0x7ae35768,0x443901f7,0x69c300e9}},	//   _נושא_, tint, ics_, wyne,
   {{0xdb25006c,0x69c35769,0xe8020066,0x49951d91}},	//   _épül, tyne, _लड़ा_, ешит,
   {{0x64460035,0xb05b0523,0x98a50160,0x66cd00ee}},	//   ybki, _flät, _nulă_, _núka,
   {{0x7ae3576a,0x2f1402c9,0x69c3576b,0x2578576c}},	//   sint, räge_, ryne, dél_,
   {{0x69c3576d,0x692a01c0,0x7c3b0661,0x00000000}},	//   syne, _přec, _ifur, --,
   {{0x98a50160,0xb65900c3,0x7ae30055,0x00000000}},	//   _bulă_, чших_, qint, --,
   {{0xaaac01c0,0xa50a576e,0xe576002d,0x00000000}},	//   चारक, зена_, нзэ_, --,
   {{0x92bc00c8,0xcdda0070,0xdb0001f7,0x00000000}},	//   _আগে_, פֿיר, _armè, --,
   {{0x31c800be,0x61fb01d6,0x78ab576f,0x7c3b10a2}},	//   रन्ध, şull, _ingv, _mfur,
   {{0x387f4dcf,0x60cf0069,0xf6790070,0x66cd07c0}},	//   lfur_, _alcm, _זאַמ, _fúka,
   {{0xd13202de,0x7c3b008d,0x00000000,0x00000000}},	//   امر_, _ofur, --, --,
   {{0x387f5770,0xa2c100a1,0x60260800,0x44395771}},	//   nfur_, रॉब्, едба, ccs_,
   {{0xd00f0082,0x6e3b01d6,0x6fd601e0,0x00000000}},	// [52a0] ملف_, _şuba, хівц, --,
   {{0x63a45772,0x7c3b0232,0x4df600c3,0xb05b1788}},	//   _irin, _afur, няет, _bläs,
   {{0x63a4008a,0xb05b5773,0x629c0345,0x00000000}},	//   _hrin, _plät, mdro, --,
   {{0x628e5774,0x63a43bd1,0x00000000,0x00000000}},	//   lebo, _krin, --, --,
   {{0x26061a75,0xaaac1bb5,0x63a20207,0x4abe0354}},	//   _सुनी_, चालक, _šonj, ्सलव,
   {{0x629c5775,0x63a400f8,0xb05b1477,0x7c3b007b}},	//   ndro, _mrin, _fläs, _efur,
   {{0x7c3b0297,0xa3e704cc,0x629c4d72,0x9c8302f6}},	//   _ffur, _येन_, idro, ščar,
   {{0x63a45776,0x25785777,0xf1b30122,0x628e13b5}},	//   _orin, vél_, רסה_, hebo,
   {{0x7d0214e7,0x63a40159,0xb05b033b,0x629c0345}},	//   moos, _nrin, _klär, kdro,
   {{0x628e1736,0x6d5c022f,0x78ab1f9d,0x257800fd}},	//   jebo, _kvra, _engv, tél_,
   {{0x63a44fed,0x628e032b,0x00000000,0x00000000}},	//   _arin, debo, --, --,
   {{0x629c5778,0x7d025475,0x00000000,0x00000000}},	//   edro, noos, --, --,
   {{0x44395779,0x63a4577a,0xdb00577b,0x68e20010}},	//   rcs_, _crin, _armé, _imod,
   {{0x56931368,0x628e09b0,0x4439577c,0x69a44532}},	//   _башт, gebo, scs_, किपी,
   {{0x63a4577d,0x30a70086,0xa0a754ea,0x7d02577e}},	//   _erin, нрав, ншал, koos,
   {{0x629c577f,0x69d80bc6,0x00000000,0x00000000}},	//   adro, izve, --, --,
   {{0x29060657,0x6d5c5780,0xe3150370,0x7d0242f9}},	// [52b0] _mkoa_, _avra, _имињ, doos,
   {{0xdef84cc4,0x7c3b009f,0x2bdb0d53,0x79880345}},	//   ных_, _sfur, _मेगा, _opdw,
   {{0x6285006d,0x63a4025c,0x2d875781,0xf6530070}},	//   _ibho, _zrin, ïne_, רצע_,
   {{0x9e0400af,0x7d02073a,0x69a408b0,0x69d80228}},	//   учул, goos, किनी, dzve,
   {{0x6d5c5782,0x660a0345,0x6d4e021d,0xb05b0523}},	//   _evra, _lyfk, _ewba, _flär,
   {{0x68e2001e,0x2906010d,0xda620eb1,0xd056013b}},	//   _amod, _akoa_, авши, diyə,
   {{0xdef4010b,0x212b5783,0x69ce02b1,0x00000000}},	//   _спры, _kich_, _übel, --,
   {{0x6d455784,0x629c12ad,0x7c3b5785,0x628e0035}},	//   mpha, zdro, _ufur, zebo,
   {{0x212b02bf,0x387f5786,0x629c5787,0x6d5c0097}},	//   _mich_, rfur_, ydro, _zvra,
   {{0x2cad0314,0x2cbf0120,0x68e20036,0x212b5788}},	//   _hned_, _houd_, _emod, _lich_,
   {{0xb9b543ff,0x628e5789,0x63a428c3,0xd46a578a}},	//   _جماع, vebo, _srin, мине_,
   {{0x212b1298,0x6285033b,0x32cf027d,0x7f44000d}},	//   _nich_, _abho, _rüya_, ypiq,
   {{0x75650332,0x628e578b,0x62850036,0x6568578c}},	//   ریکہ_, tebo, _bbho, ardh,
   {{0x212b0284,0x63a4578d,0x6b890282,0x629c578e}},	//   _aich_, _vrin, _mpeg, udro,
   {{0x628e578f,0x232709b5,0x68e200d7,0x212b5790}},	//   rebo, тори_, _ymod, _bich_,
   {{0x628e038d,0x307501f2,0x55f600a5,0x68e25791}},	//   sebo, луус, _במצב_, _xmod,
   {{0x212b5792,0x7d025793,0x290d1624,0x6d5c0254}},	// [52c0] _dich_, voos, ilea_, _svra,
   {{0x212b02c7,0x7f4401f4,0x2cad00e5,0x66cd0168}},	//   _eich_, rpiq, _aned_, _múko,
   {{0x212b021e,0x2cbf0b88,0x6b892dea,0xe1f700af}},	//   _fich_, _boud_, _apeg, _агэ_,
   {{0x0b8a1362,0xcb6a0dee,0xbb4600d8,0x22580185}},	//   дски_, даде_, ведк, lark_,
   {{0x6d455794,0xa3c2007c,0x2bb70099,0x6bd6083a}},	//   apha, ंहि_, _आपणा, ختار,
   {{0x212b04ce,0xdd920a86,0x6e435795,0x225806f7}},	//   _zich_, _پور_, _верз, nark_,
   {{0x6d455796,0x610c01ae,0xdee30374,0x7d025797}},	//   cpha, eßli, _тори, poos,
   {{0x2cbf5798,0x588600d8,0x079803fa,0xa3c200be}},	//   _goud_, тыка, евић_, ंहा_,
   {{0x6c7b02b5,0x776901ef,0x00000000,0x00000000}},	//   _קאמפ, grex, --, --,
   {{0x2b460443,0x291f0054,0x290d01ed,0x00000000}},	//   mpoc_, amua_, alea_, --,
   {{0xd5b700d4,0x290d01b7,0x1e5700a5,0xaa370070}},	//   вся_, blea_, כשיר_, _סטאק_,
   {{0x77ca1303,0x68e25799,0x77690042,0x6568579a}},	//   _олег_, _umod, brex, rrdh,
   {{0x2258579b,0x212b3e54,0x29040116,0x00000000}},	//   fark_, _rich_, moma_, --,
   {{0x212b0446,0x2904579c,0x25fd0084,0x9abc0069}},	//   _sich_, loma_, _रुकी_, _biċi,
   {{0x7aed02e1,0x31c4392c,0xe71700a5,0x66c40260}},	//   éati, аств, _שחור_, _dòkt,
   {{0x2904579d,0x9abc0069,0x2ebd0ed1,0x395e00ee}},	//   noma_, _diċi, ोस्त, _mvts_,
   {{0x2cbf04e0,0x2258579e,0x212b0176,0x3015579f}},	// [52d0] _roud_, bark_, _vich_, удар,
   {{0x2cbf00b8,0x290d01d7,0x290440c4,0x6d4557a0}},	//   _soud_, zlea_, homa_, tpha,
   {{0x290457a1,0xa3e702cb,0x6b8957a2,0x290d028b}},	//   koma_, _येत_, _speg, ylea_,
   {{0x0ce100c8,0x60d657a3,0x776900d7,0x290457a4}},	//   যক্ত, chym, yrex, joma_,
   {{0x290457a5,0xfbd000ad,0x692a01c0,0x6d580093}},	//   doma_, يته_, _přen, ávar,
   {{0x49990340,0x3f992c6b,0x291f006d,0x6d454a11}},	//   етия_, _issu_, wmua_, ppha,
   {{0xc879045e,0x6d5857a6,0x49bb00d1,0x290457a7}},	//   lişi_, švar, باشد_, foma_,
   {{0x60cd1627,0x290425b0,0x2cad001e,0x6ca454d4}},	//   nkam, goma_, _uned_, _круж,
   {{0x2fc91a02,0x60cd57a8,0x290d1fb7,0x7d0957a9}},	//   nyag_, ikam, rlea_, _ikes,
   {{0x60cd1d11,0x776957aa,0x290d01d7,0x752d01ef}},	//   hkam, rrex, slea_, _aiaz,
   {{0x7d1b0464,0x60cd1361,0xf87501b2,0x290d0453}},	//   _khus, kkam, _مهاج, plea_,
   {{0xc3290052,0x60cd1b86,0xaca30023,0x69da0070}},	//   _זו_, jkam, _khốn, _אַדו,
   {{0x60cd57ab,0x7d0907e3,0x225857ac,0x7d1b3991}},	//   dkam, _mkes, tark_, _mhus,
   {{0x68e957ad,0xb05b022a,0xdb20016f,0x320c0035}},	//   lied, _släp, _štúd, żdym_,
   {{0x60d64a5c,0x7d1b00ab,0x60cd0345,0xf65600a5}},	//   thym, _ohus, fkam, _עסקי_,
   {{0x60cd1c3f,0x68e957ae,0x7d0904fb,0x00000000}},	//   gkam, nied, _nkes, --,
   {{0xef1a57af,0x03a60009,0x443200b5,0x10a3218b}},	// [52e0] ема_, _сипо, _igy_, щитн,
   {{0x68e957b0,0x539b0122,0x93b70122,0x29041499}},	//   hied, _טיפו, _עליו_, zoma_,
   {{0xc27b0779,0x645657b1,0xc0e60369,0x629e011e}},	//   _אריי, _keyi, _бонк, _iapo,
   {{0x7d1b148b,0x629e57b2,0x60cd13a2,0x3a3e01a2}},	//   _chus, _hapo, ckam, _sftp_,
   {{0x629e3ffc,0xaca301a5,0x59b60fcf,0x78bb57b3}},	//   _kapo, _chốn, _अपहर, djuv,
   {{0x67210254,0x00000000,0x00000000,0x00000000}},	//   jmlj, --, --, --,
   {{0x629e57b4,0x68e957b5,0xca7500c7,0x3f8057b6}},	//   _mapo, fied, ручы, ltiu_,
   {{0x629e57b7,0x6d5e3ade,0xaaa404bc,0xeb9a145f}},	//   _lapo, mspa, _गोरक, _пиб_,
   {{0x6d5e57b8,0x290457b9,0x752d1702,0x47342123}},	//   lspa, roma_, _riaz, јнос,
   {{0x290457ba,0xcaa6004f,0x60cd20ea,0xdb000097}},	//   soma_, _حصري, zkam, _krmí,
   {{0x68e957bb,0x752d01d3,0x5886004b,0x645657bc}},	//   bied, _piaz, _была, _beyi,
   {{0x68e92140,0x799a142f,0xd7fa0036,0x60cd0110}},	//   cied, _istw, _пул_, xkam,
   {{0x64560669,0x60cd00ac,0x752d57bd,0xa3cf00be}},	//   _deyi, vkam, _viaz, वैं_,
   {{0x443257be,0x629e57bf,0x533457c0,0x6d5e57c1}},	//   _egy_, _capo, серт, kspa,
   {{0x160b0e1d,0x765a57c2,0xd5af027a,0x403503e6}},	//   _सुपर_, maty, _ус_, иевс,
   {{0x6d5e5030,0x645604d4,0x765a57c3,0x7c2d1942}},	//   dspa, _geyi, laty, žari,
   {{0x7aea02df,0x3e6b2701,0xce6b00aa,0x6f1c009e}},	// [52f0] kift, ешен_, еред_, _bhrc,
   {{0xc879008f,0x9e1501c8,0x7d1b57c4,0x799a57c5}},	//   rişi_, адзі, _shus, _ostw,
   {{0x999e01c8,0x3d951460,0x6d5e57c6,0xdd9105bc}},	//   _metų_, риер, gspa, توا_,
   {{0x765a081b,0x645600a8,0x1df50f8a,0x692a06fe}},	//   haty, _xeyi, _आशीष_, _břem,
   {{0x3f800955,0xa3e50311,0x629e57c7,0x68e901ba}},	//   ctiu_, पछि_, _yapo, vied,
   {{0x68e90755,0x629e0391,0x7aea0bf3,0xa9695759}},	//   wied, _xapo, gift, вика_,
   {{0x08d50340,0x68e957c8,0x7d1b00f1,0x69ca57c9}},	//   иция, tied, _thus, gyfe,
   {{0x08c5150e,0xaca30028,0x7d1b000e,0x2d81055c}},	//   рбин, _thốn, _uhus, mthe_,
   {{0x68e957ca,0x645602e9,0x799a57cb,0x2d810f0a}},	//   ried, _reyi, _estw, lthe_,
   {{0x6b9b57cc,0xfaf30e0c,0xa6e5145f,0x8c3d438e}},	//   _isug, _اثر_, ржол, _başg,
   {{0x68e957cd,0x2d8157ce,0x645602e9,0x7aed000d}},	//   pied, nthe_, _peyi, éatu,
   {{0x2d810514,0x629e57cf,0x03a61583,0x493a00a5}},	//   ithe_, _sapo, аимо, _סגנו,
   {{0x629e57d0,0x765a57d1,0x07470142,0x81e30033}},	//   _papo, baty, _схем, _ফুল_,
   {{0xe5a557d2,0xdb0003e6,0x6d5e57d3,0x8c3d0160}},	//   _вики, _irmã, yspa, _haşd,
   {{0x20560043,0x645657d4,0x451a00af,0x273b57d5}},	//   итар, _teyi, _иция_, _hên_,
   {{0x6d5e037d,0x629e57d6,0x2d814e8b,0x443200fd}},	//   vspa, _wapo, dthe_, _ugy_,
   {{0x629e3ead,0x6d5e00a5,0x44260023,0x41270dee}},	// [5300] _tapo, wspa, _ào_, рото_,
   {{0x6d5e50e9,0xf8d20b35,0x3f801544,0x20c700be}},	//   tspa, _तत्प, rtiu_, _sõit_,
   {{0x273b00e8,0x3f801e97,0x2d810079,0x13cb0033}},	//   _lên_, stiu_, gthe_, _লইয়,
   {{0x692a00b8,0xeb0e1e82,0x3f800392,0x00000000}},	//   _přem, ित्त_, ptiu_, --,
   {{0x273b00e8,0x7aea2f92,0xac070c8d,0x765a1187}},	//   _nên_, tift, анца_, yaty,
   {{0x99661c1b,0x4ed500d8,0x6d5e57d7,0x41ba0fff}},	//   атил, _люст, pspa, _उपास,
   {{0x7aea57d8,0xaca301a5,0x2d810079,0x8c3d013b}},	//   rift, _chồn, cthe_, _başd,
   {{0x273b0028,0x291d1392,0x692a0355,0x00000000}},	//   _bên_, _chwa_, _zřej, --,
   {{0x69d50332,0x765a00d8,0xd90d00d1,0xbb4357d9}},	//   _üzen, taty, ریه_, _метк,
   {{0xb6c60382,0x69ca0223,0x4b7b076b,0x00000000}},	//   рсий, pyfe, _באמו, --,
   {{0x765a57da,0xdcfc3e96,0x24890159,0x6b8257db}},	//   raty, _sprę, _pbam_, ltog,
   {{0x765a57dc,0xf48502fd,0x57ea257f,0xdb0000af}},	//   saty, حادی, _идем_, _urmâ,
   {{0x765a57dd,0x61fe0523,0x386601ed,0x00000000}},	//   paty, _axpl, _idor_, --,
   {{0x81e800c8,0x00000000,0x00000000,0x00000000}},	//   _বড়_, --, --, --,
   {{0x171b00c2,0xf1a42263,0x92581362,0x95ca0274}},	//   _שווע, ортн, раст_, _јула_,
   {{0x273b01a5,0x403400c3,0x00000000,0x00000000}},	//   _yên_, жетс, --, --,
   {{0x645d57de,0x692a01c0,0xc0580044,0x2287141d}},	// [5310] masi, _přej, ріс_, _кунг,
   {{0x645d57df,0x7e7c0176,0x539c00a5,0xfda70274}},	//   lasi, _ccrp, _ייחו, ијем,
   {{0x62951a71,0x66cd008d,0x20070035,0xf1a4195c}},	//   mezo, _súkk, łni_, _дрян,
   {{0x645d57e0,0x76580086,0x69dc0093,0x20c700ab}},	//   nasi, _levy, _þrey, _võis_,
   {{0x2d810044,0x61fb2f80,0x00000000,0x00000000}},	//   sthe_, ğulu, --, --,
   {{0x645d0388,0x765857e1,0x629557e2,0x61fb3a05}},	//   hasi, _nevy, nezo, şulu,
   {{0x645d57e3,0x49930a86,0xceb202b5,0x2d9c08c8}},	//   kasi, تیار, _ציל_, ævet_,
   {{0x6b9b0159,0x645d57e4,0x629501e9,0x98ac0139}},	//   _tsug, jasi, hezo, _rudă_,
   {{0x6b8257e5,0xa49b02e9,0x6d4100f7,0x6b9b57e6}},	//   ctog, vlòp, _élab, _usug,
   {{0x4ec50083,0xab280274,0x629557e7,0x00000000}},	//   _এগুল, _вођа_, jezo, --,
   {{0xdb260148,0x09e50083,0x765857e8,0x629502a7}},	//   _اولی, _পুরা, _devy, dezo,
   {{0x273b00e8,0x6aa157e9,0xdb00043f,0xf8db0006}},	//   _tên_, _half, _irmá, _बतिय,
   {{0x6aa157ea,0xb05b013c,0x398157eb,0x889a00a5}},	//   _kalf, _poän, lós_, _תבני,
   {{0x629557ec,0x8c1a0122,0x645d0103,0x00000000}},	//   gezo, טורי, aasi, --,
   {{0xf8db006a,0x645d57ed,0x98db10b7,0xa06a576e}},	//   _बताय, basi, _बताए, лава_,
   {{0xaca30019,0x645d1e11,0xdb090b88,0xc0e32368}},	//   _khổn, casi, _breë, поск,
   {{0x629557ee,0x6d470029,0xdb0901e4,0x0e66005f}},	// [5320] bezo, _atja, _creë, йкан,
   {{0x692a01c0,0xfca904a3,0xe45f0093,0x00000000}},	//   _přek, یانو_, gjöf_, --,
   {{0x39814a12,0x00000000,0x00000000,0x00000000}},	//   jós_, --, --, --,
   {{0x2703009a,0x6b8257ef,0xdd8f0180,0x26d90031}},	//   रकुर_, ttog, عون_, ësoj_,
   {{0xdb0057f0,0x8c3d01d6,0x6b7400d4,0x2cb700ac}},	//   _armá, _başb, ілку, _šedé_,
   {{0x645d57f1,0x39a70019,0x6aa12665,0x2d9c08c8}},	//   zasi, _bđs_, _calf, æves_,
   {{0x6b8200d8,0x645d57f2,0x6444018e,0x644f0067}},	//   stog, yasi, _ofii, ybci,
   {{0x1d0a0274,0x7aed000d,0x160b0066,0x64440103}},	//   _себи_, éatr, _सुधर_, _nfii,
   {{0x645d57f3,0x386602a7,0xaca3055c,0x00000000}},	//   vasi, _vdor_, _chổn, --,
   {{0x645d0657,0x6444001c,0x6aa1099e,0x398157f4}},	//   wasi, _afii, _galf, bós_,
   {{0x645d57f5,0x62950693,0x398101f7,0xe7b60105}},	//   tasi, vezo, cós_, _گمشد,
   {{0x2ed5018d,0x6aa157f6,0xf79a06ee,0xa92657f7}},	//   _धत्त, _zalf, _منصب_, _удел,
   {{0x645d57f8,0x629557f9,0x31d107df,0x00000000}},	//   rasi, tezo, सन्ध, --,
   {{0x645d57fa,0xadfa0fcf,0x6444030d,0x6aa101f7}},	//   sasi, ्थान_, _efii, _xalf,
   {{0x692a000c,0x62950055,0xd5af0763,0x363301b2}},	//   _přeh, rezo, _эс_, _عروس,
   {{0x957c006a,0x316c016f,0x629557fb,0x60c657fc}},	//   rząd, ádza_, sezo, _cokm,
   {{0x62950391,0x78a2002f,0x6d4729f1,0xdb090359}},	// [5330] pezo, _maov, _stja, _freè,
   {{0x63ad57fd,0x60c6030d,0xf44800fd,0x00000000}},	//   _iran, _eokm, _پلیٹ_, --,
   {{0x403501c8,0x6aa157fe,0x00000000,0x00000000}},	//   _менс, _ralf, --, --,
   {{0x78a200f4,0x2d5800af,0x00000000,0x00000000}},	//   _naov, сиць_, --, --,
   {{0x2d9c054e,0x25630644,0x2f0f033b,0x09d100e7}},	//   æver_, zıl_, fügt_, तन्य,
   {{0x63ad00f8,0x398157ff,0x256300a8,0x00000000}},	//   _mran, tós_, yıl_, --,
   {{0x6aa15800,0x78a200e2,0xfd130fab,0x8c3d0139}},	//   _valf, _baov, _فجر_, _caşc,
   {{0x63ad120d,0x39815801,0x69d5006c,0x3ea30a3f}},	//   _oran, rós_, _üzem, _hajt_,
   {{0x6aa1099e,0x00000000,0x00000000,0x00000000}},	//   _talf, --, --, --,
   {{0x46e92b4b,0x7d0b17ad,0x66e500d4,0x7c2d01a0}},	//   рдон_, logs, іона, žars,
   {{0xceb40d85,0x8c3d0139,0x00000000,0x00000000}},	//   ליץ_, _gaşc, --, --,
   {{0x81c10083,0xa50a37e1,0xdd7a00a5,0x00000000}},	//   ্ছা_, рема_, סטרל, --,
   {{0x25630723,0x68eb00d7,0x2bac0084,0x60c601ba}},	//   sıl_, _imgd, चिया, _rokm,
   {{0x63ad41eb,0xe5710ae7,0x3ea35010,0x60c65802}},	//   _dran, _قطب_, _najt_, _sokm,
   {{0x63ad5803,0x64445804,0xd765006c,0x3333009f}},	//   _eran, _tfii, _انڈی, _dixx_,
   {{0x26c70090,0xddc70035,0x2f1400ab,0x236d0520}},	//   _hono_, _wejś, mägi_, šeja_,
   {{0xaec64cf3,0x26c700bf,0x04040033,0xa3e700a1}},	// [5340] обал, _kono_, রেজী_, _येऊ_,
   {{0xafdb0b41,0x26c7057a,0x3ea35805,0xd048013b}},	//   _iføl, _jono_, _cajt_, _əməy,
   {{0x26c75806,0x63ad024e,0xa2a33e8a,0xb22600af}},	//   _mono_, _zran, _छोट्, _фмнл,
   {{0xa3c100a1,0x00000000,0x00000000,0x00000000}},	//   ूनच_, --, --, --,
   {{0x78a20019,0x7ed600d4,0xd0f90067,0x3ea35807}},	//   _raov, _дівч, ्करण_, _fajt_,
   {{0x440207ba,0xf96a53f6,0x290000c7,0x8c3d0139}},	//   _लखनऊ_, арий_, čiam_, _paşc,
   {{0xad670009,0x78a20207,0x00000000,0x00000000}},	//   _марз_, _paov, --, --,
   {{0xe81e0722,0x6cd60037,0x478a39fa,0x8c3d0160}},	//   _परदा_, _بقرا, асом_, _vaşc,
   {{0x26c75808,0x291800ea,0x27e905e2,0xd6d00037}},	//   _bono_, ēra_, _žanr_, فقة_,
   {{0x26c73e05,0x857400c3,0x2480013a,0x78a20cdf}},	//   _cono_, плох, _acim_, _waov,
   {{0x63ad5809,0xa2be00ab,0x26c7580a,0x957c004e}},	//   _sran, शान्, _dono_, dząc,
   {{0x63ad580b,0xd05f0095,0x2ca6580c,0x394e0d3c}},	//   _pran, biqə, ndod_, mpfs_,
   {{0x26c71f3b,0x692a06fe,0x63ad013b,0x33330282}},	//   _fono_, _břev, _qran, _pixx_,
   {{0x26c700ee,0x24800055,0x8c3d10b1,0x00000000}},	//   _gono_, _ecim_, _maşa, --,
   {{0x63ad580d,0x692a01c0,0x518450f1,0x248001f7}},	//   _wran, _dřev, мута, _fcim_,
   {{0x63ad580e,0x3ea3580f,0x69a1021a,0x00000000}},	//   _tran, _sajt_, _कैफी, --,
   {{0x63ad5810,0xdddc0168,0x7d0b008d,0x00000000}},	// [5350] _uran, _herň, vogs, --,
   {{0xddab0d30,0x957c004e,0x7f4d0095,0x00000000}},	//   ител_, cząc, rpaq, --,
   {{0x80c70083,0x3ea354b5,0x26d90055,0xf2d2016b}},	//   রোগ্, _vajt_, ësoi_, _נעט_,
   {{0x8c3d01d6,0x8f355811,0xd5fb0070,0xd2510609}},	//   _başa, _немц, ספאר, _تنگ_,
   {{0x2129012f,0x3ea35812,0x00000000,0x00000000}},	//   mmah_, _tajt_, --, --,
   {{0x7f3a0052,0x8c3d0510,0x07190066,0x2129028b}},	//   _לעשו, _daşa, _नींव_, lmah_,
   {{0x26c701cb,0x7c970037,0x00000000,0x00000000}},	//   _rono_, _وشرا, --, --,
   {{0x26c70021,0x270300b4,0x47c52725,0x01fc00a5}},	//   _sono_, रक्र_, збив, יפול,
   {{0x26c75161,0xacda0070,0xf7710037,0x00000000}},	//   _pono_, _פֿלי, راة_, --,
   {{0x21290fef,0x3a7400af,0xdddc00fe,0xafdb008c}},	//   hmah_, _олур, _berň, _rføl,
   {{0x383537f8,0x21295813,0x5afa0070,0xf409011d}},	//   _енер, kmah_, _פלעצ, _עפ_,
   {{0x8c3d036a,0x656e0037,0x64410035,0xdb0002b1}},	//   _yaşa, ábha, ślin, _ermä,
   {{0xf7490514,0x69ce0446,0x26c72ed9,0x692a01c0}},	//   _التي_, _über, _tono_, _přev,
   {{0x26de0076,0x2bac022e,0x07a2005f,0x3cff0282}},	//   chto_, चिता, _чашн, _ljuv_,
   {{0x76ba00a5,0x957c0067,0x00000000,0x00000000}},	//   _למספ, rząc, --, --,
   {{0x68fb008a,0xa50701d3,0x24800c7f,0x957c0035}},	//   nnud, _неща_, _ucim_, sząc,
   {{0x2ca4028b,0x75240065,0x8e3a0427,0x00000000}},	// [5360] _ramd_, _ihiz, مسار_, --,
   {{0x68fb00ee,0x44205814,0x2ca450b2,0x6fb30037}},	//   hnud, _izi_, _samd_, عملا,
   {{0x68fb0b3e,0x3cff0523,0xdb090160,0x823b024b}},	//   knud, _bjuv_, _preî, _לעיצ,
   {{0x6446297a,0x8c3d5815,0x00000000,0x00000000}},	//   ncki, _paşa, --, --,
   {{0x2ca65816,0xdb090392,0x3cdd0035,0x6d4100a2}},	//   rdod_, _creï, _खतरे_, _élan,
   {{0x05cb0299,0x60c40a78,0x60d600d5,0x386000f4}},	//   ाहाब, ljim, lkym, _žir_,
   {{0xd910042c,0x752401b7,0x00000000,0x00000000}},	//   پیش_, _ohiz, --, --,
   {{0x60c401cc,0xa3cc007c,0xdca31b50,0x60d6037c}},	//   njim, लहा_, _паси, nkym,
   {{0x44205817,0xed35005f,0x00000000,0x00000000}},	//   _nzi_, _цэрэ, --, --,
   {{0x21295818,0xfa670ebb,0x7e7e011e,0x75245819}},	//   zmah_, _наук_, ngpp, _ahiz,
   {{0x26060907,0x4420581a,0xceb300a5,0xd5ae00b5}},	//   _सुखी_, _azi_, גית_, اہب_,
   {{0x48e31fff,0x75242206,0x44200160,0x00000000}},	//   _похв, _chiz, _bzi_, --,
   {{0x442000e7,0x60c4103c,0xa81a00b5,0x00000000}},	//   _czi_, djim, _اتار_, --,
   {{0x27f70187,0xa19500d8,0x752401a3,0x236d08b7}},	//   šená_, магч, _ehiz, šejo_,
   {{0x4420581b,0x26dc0051,0x2f14018d,0x00000000}},	//   _ezi_, _ilvo_, nägu_, --,
   {{0xd5fb0122,0x60c401f4,0x3d060035,0x75240139}},	//   _לפור, gjim, षकों_, _ghiz,
   {{0x21292083,0x657a581c,0x00000000,0x00000000}},	// [5370] rmah_, luth, --, --,
   {{0x290d0054,0x692a00b8,0x21290bf0,0x3f142aba}},	//   zoea_, _křes, smah_, едус,
   {{0x645f0031,0x00000000,0x00000000,0x00000000}},	//   _keqi, --, --, --,
   {{0x60d60168,0x60c41bd8,0x645f009f,0x2369008c}},	//   ckym, cjim, _jeqi, _kvaj_,
   {{0x0b4401e0,0x6f0200f7,0xfaa5082a,0x657a581d}},	//   енін, éocc, дало, huth,
   {{0x657a573f,0x4fd60122,0x98af0107,0x00000000}},	//   kuth, _חושב_, _vigč_, --,
   {{0xa2be021a,0x3f89581e,0xdd94010b,0x6446581f}},	//   शात्, ltau_, _пары, ycki,
   {{0x23690537,0x26dc0279,0x657a5820,0x00000000}},	//   _ovaj_, _alvo_, duth, --,
   {{0x3f895821,0x7c3b5822,0x68fb5823,0xb8f50066}},	//   ntau_, _igur, rnud, _सक_,
   {{0x68fb5824,0x3f8900c7,0x692a00fe,0x657a05f5}},	//   snud, itau_, _břes, futh,
   {{0xf7710609,0x657a5825,0x692a00b8,0x645f0031}},	//   راک_, guth, _přet, _beqi,
   {{0x661d0355,0xb4ca0f06,0xf9900037,0x44202381}},	//   řsko, ोसे_, _حبك_, _pzi_,
   {{0x78a902d4,0x36693072,0x94d3010b,0x00000000}},	//   mdev, _дало_, тоўц, --,
   {{0x657a01ef,0xc72402ce,0xe8e00019,0x78a95826}},	//   buth, _здій, ượt_, ldev,
   {{0x692a01c0,0x7c3b3591,0x00000000,0x00000000}},	//   _třet, _ogur, --, --,
   {{0x387f5827,0x7c3b4309,0x78a95828,0x2b4d0187}},	//   ngur_, _ngur, ndev, _otec_,
   {{0x442001d5,0x60c45829,0xdb0901ef,0x60d6010b}},	// [5380] _uzi_, rjim, _areí, rkym,
   {{0x63a4582a,0x290001c8,0x7c3b582b,0x66c40107}},	//   _isin, čiai_, _agur, _bòky,
   {{0x63a4012f,0xdb090831,0x629c582c,0xc0e6010b}},	//   _hsin, _creí, mero, _жонк,
   {{0xdb00006c,0x628e582d,0x2b4d099e,0x63a4582e}},	//   _ismé, lfbo, _btec_, _ksin,
   {{0xab9a0a86,0x78a9582f,0x3f89001e,0xbb431d88}},	//   تخار_, ddev, ctau_, вечк,
   {{0x63a4000e,0x657a046a,0xed5a5830,0x78a90382}},	//   _msin, yuth, _мог_, edev,
   {{0x78a91e7e,0x7c3b007a,0x2b4d021d,0x00000000}},	//   fdev, _fgur, _etec_, --,
   {{0x387f5831,0x63a45832,0x2b58006c,0xdb090139}},	//   ggur_, _osin, _فیصد_, _creâ,
   {{0x63a41815,0xb8f600ab,0x2b4d021d,0x47340328}},	//   _nsin, _हव_, _gtec_, ннис,
   {{0x629c5833,0x692a000c,0x66cd016f,0x7c3b5834}},	//   jero, _přes, _súkr, _zgur,
   {{0x9e770122,0x78a95835,0x58860409,0x6aa84b31}},	//   וגיה_, bdev, _жыла, _iadf,
   {{0x657a009c,0x6aa800e5,0x00000000,0x00000000}},	//   ruth, _hadf, --, --,
   {{0x629c5836,0x63a4006c,0x657a4283,0x2b4d0310}},	//   fero, _csin, suth, _xtec_,
   {{0x81cd00c8,0xd5b0042c,0x7f4400a8,0xf79300d8}},	//   _শেষ_, _مفت_, dqiq, _рашэ,
   {{0x8c3d08ca,0x63a45837,0x23c501f4,0x6d4e009f}},	//   _başl, _esin, _bëjë_, _ntba,
   {{0xe7d205f7,0x3f895838,0x6ee00282,0x00000000}},	//   _तथाप, ttau_, _nöbb, --,
   {{0x6d4e0080,0x6aba0a81,0x6d5c01cb,0x8c3d013b}},	// [5390] _atba, _ontf, _awra, _daşl,
   {{0x629c5839,0xdef80733,0xbefb07df,0xbf15004f}},	//   cero, мых_, ्वेन_, رواب,
   {{0x8c950044,0x3f891990,0x2d870248,0x5c751e9c}},	//   ерлі, stau_, îne_, елет,
   {{0xd0100332,0x7e6e0a8a,0x200f00be,0x00000000}},	//   الے_, _edbp, ügis_, --,
   {{0x007600a5,0xdcfc00ea,0x6d5c0b77,0x6aa8583a}},	//   _אתרי_, _aprē, _ewra, _badf,
   {{0x6aa8583b,0x00000000,0x00000000,0x00000000}},	//   _cadf, --, --, --,
   {{0x8c3d0463,0x6d5c001e,0x213901f4,0xf9910d93}},	//   _yaşl, _gwra, _kish_, ابت_,
   {{0x6aba02c9,0x7c3b583c,0x629c583d,0x7e651221}},	//   _entf, _ugur, zero, lahp,
   {{0x62851b66,0x78a9583e,0x629c583f,0x692a00b8}},	//   _ocho, rdev, yero, _přer,
   {{0x629c5840,0x2139026e,0x63a40051,0xb4ca01c0}},	//   xero, _lish_, _rsin, ोस्_,
   {{0x629c5841,0x63a4001c,0x78a90310,0x67385842}},	//   vero, _ssin, pdev, _divj,
   {{0x62855843,0x2edc057c,0x629c5844,0x21390c6f}},	//   _acho, _यत्त, wero, _nish_,
   {{0x629c5845,0x36d55846,0xdcf500ea,0x934300c3}},	//   tero, _подр, _apzī, лняе,
   {{0xe0df02d0,0x6b890069,0x00000000,0x00000000}},	//   _alò_, _mqeg, --, --,
   {{0x7e650a4e,0xf8d300be,0x77690282,0x91e633ce}},	//   dahp, _तवाय, lsex, хове,
   {{0x67385847,0x63a45848,0xe45f5849,0xe0df01a6}},	//   _zivj, _tsin, ljön_, _clò_,
   {{0x63a40052,0x2139584a,0xe0df3036,0xd00732f6}},	// [53a0] _usin, _dish_, _dlò_, еете_,
   {{0xef17584b,0x629c01f4,0x21390b88,0x00000000}},	//   ему_, qero, _eish_, --,
   {{0x20190159,0x8c3d027d,0x213900a5,0x6aa8584c}},	//   _eysi_, _taşl, _fish_, _radf,
   {{0xfce3081b,0x213901ef,0x71a300d8,0x1636016b}},	//   лохо, _gish_, _саюз, גנער_,
   {{0xdb090211,0x7bdd00a8,0xbc6707a9,0x00000000}},	//   _breà, _üsul, رمون_, --,
   {{0x610500d8,0x79a61283,0x00000000,0x00000000}},	//   mėla, ерие, --, --,
   {{0x7c9614c6,0x6ee00332,0x6d4e03d0,0x67380009}},	//   _прац, _több, _utba, _rivj,
   {{0xe8760d4f,0x3eaa01ae,0x6738584d,0x38af00b5}},	//   راعظ, _habt_, _sivj, yörű_,
   {{0x6ec422f2,0xdb0901f7,0xfce3584e,0xa09b025a}},	//   रापु, _freà, _сото, ליקט,
   {{0xc66a00c3,0x6aba0282,0x00000000,0x00000000}},	//   чшие_, _untf, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6285584f,0x26d90031,0x3eaa005f,0x00000000}},	//   _scho, ësor_, _labt_, --,
   {{0x21390107,0x00000000,0x00000000,0x00000000}},	//   _rish_, --, --, --,
   {{0x29000a93,0x247101a5,0x213901e9,0x00000000}},	//   čiau_, ễm_, _sish_, --,
   {{0x59a608a9,0x62850187,0xd6270274,0x6ec4022e}},	//   _कैमर, _vcho, _поље_, रानु,
   {{0x62850035,0x00000000,0x00000000,0x00000000}},	//   _wcho, --, --, --,
   {{0x2d98142f,0x6285139b,0xd25100d1,0x26ce00ee}},	// [53b0] _apre_, _tcho, _پنج_, _kofo_,
   {{0x62855850,0x9e07002d,0x21395851,0xe7b1018d}},	//   _ucho, нчел, _wish_, जितप,
   {{0x21390c6f,0x00000000,0x00000000,0x00000000}},	//   _tish_, --, --, --,
   {{0x2b49061b,0x00000000,0x00000000,0x00000000}},	//   íaco_, --, --, --,
   {{0xdb095852,0x5c141ac5,0x98af0139,0xfb8601cb}},	//   _areá, льшу, _ligă_, ندوی,
   {{0x3a3e021d,0xbb520037,0x60cf00e2,0x395e099e}},	//   _cgtp_, جنوب, _hocm, _bwts_,
   {{0x692a01c0,0xdb0901dd,0x00000000,0x00000000}},	//   _přep, _creá, --, --,
   {{0x644d0211,0x0c7200f8,0x776909af,0x00000000}},	//   _nfai, _نگهد, tsex, --,
   {{0x2d0400d8,0xdb09009e,0x00000000,0x00000000}},	//   _сярг, _treà, --, --,
   {{0xda670594,0xf1b33421,0xdb09002a,0xcf92011d}},	//   _سائي, ुमान, _freá, סטי_,
   {{0xa50a0dc8,0x77690132,0xb8950037,0xb05b017b}},	//   дена_, ssex, _للاع, _gnäg,
   {{0x434607c1,0x81e00033,0x8e3600a5,0x00000000}},	//   кемв, _দখল_, כנתא_, --,
   {{0xe72e23b6,0x26ce1214,0x6ec40099,0x00000000}},	//   _ве_, _fofo_, रामु, --,
   {{0x8c3d0723,0xf1aa01cb,0xd25200b5,0x644d00e5}},	//   _başk, وازه_, شنر_, _efai,
   {{0x45d2192f,0x644d001e,0x00000000,0x00000000}},	//   _војс, _ffai, --, --,
   {{0x2eda01c0,0x8c3d013b,0x78ab4283,0x00000000}},	//   णस्त, _daşk, _jagv, --,
   {{0x1e860b3a,0x2d980012,0x3f99028b,0x7ae10098}},	// [53c0] клам, _spre_, _cpsu_, _ollt,
   {{0xd37b0100,0x321a5853,0xed5a0210,0xdfcf004f}},	//   _קריט, _typy_, дож_, غيل_,
   {{0xdca600c3,0x0d863648,0x181e2478,0x2d0d175f}},	//   кажи, тлен, _पर्व_, िकूल_,
   {{0x7ae15854,0x78ab0298,0x3ce00098,0x63b65855}},	//   _allt, _nagv, óiv_, _kryn,
   {{0x28c525d8,0x3eab00c3,0x3a9800af,0x3eaa08c8}},	//   वानि, öitä_, еклэ_, _tabt_,
   {{0xc4de021a,0xdb090138,0x5b13010b,0x00000000}},	//   मसुख, _preá, аміт, --,
   {{0x996306d8,0x3f800a39,0x78ab08c8,0x2d98023a}},	//   атыл, luiu_, _bagv, _upre_,
   {{0x7ae1099e,0x2bb40387,0x00000000,0x00000000}},	//   _ellt, ूमदा, --, --,
   {{0x3f805856,0xbb4632f2,0xb8fa00be,0x00000000}},	//   nuiu_, _резк, _ठक_, --,
   {{0x7d020bcc,0x02d11f57,0x00000000,0x00000000}},	//   lnos, _सकेन, --, --,
   {{0xaaab0066,0x24f91482,0x00000000,0x00000000}},	//   _टोटक, енны_, --, --,
   {{0x7d025857,0x63b65858,0x290000d8,0xd7fa00af}},	//   nnos, _bryn, čias_, _оул_,
   {{0x69d50723,0x56940f16,0x63b600e9,0x00000000}},	//   _üzer, _балт, _cryn, --,
   {{0x78ab022f,0x7d025859,0x68e200ac,0x60cf0312}},	//   _zagv, hnos, _hlod, _socm,
   {{0x69d8006c,0x68e2585a,0x7d02585b,0x2b440051}},	//   nyve, _klod, knos, _lumc_,
   {{0x7d020252,0x28c5018d,0x63b6099e,0x8637076b}},	//   jnos, वायि, _fryn, _ברוב_,
   {{0x3f80585c,0xb4df0084,0x63b6585d,0x68e2585e}},	// [53d0] guiu_, णसी_, _gryn, _mlod,
   {{0x628900cb,0x644900d8,0x8c3d585f,0x59d2018d}},	//   đeos, žeid, _iaşi, तहार,
   {{0x28c506bc,0x60cf002d,0x63ba00ea,0x29060118}},	//   वामि, _tocm, ātne, _ojoa_,
   {{0x657a09bb,0x3f800132,0x2d58002d,0x69b85860}},	//   irth, buiu_, тиць_, ्मनी,
   {{0x78a00223,0x64410067,0x00000000,0x00000000}},	//   demv, śliw, --, --,
   {{0x8c3d0043,0xa927016f,0x28c51cc3,0x2489009e}},	//   _maşi, _obľú, वाभि, _lcam_,
   {{0x7d025861,0x68e2167f,0x69d85862,0x2ba30380}},	//   bnos, _blod, gyve, _खैरा,
   {{0x7d0228e8,0x3ea10006,0x3ce6024e,0x68e25863}},	//   cnos, leht_, chov_, _clod,
   {{0xdcfc004b,0xb05b0523,0x68e200e5,0x00000000}},	//   _aprė, _knäb, _dlod, --,
   {{0x68e25864,0xeb0e00dc,0x7ae103c1,0x00000000}},	//   _elod, ाकृत_, _ullt, --,
   {{0x68e2038d,0x2cbf0249,0x49470012,0x69d802a2}},	//   _flod, _knud_, _рэзб, cyve,
   {{0x68e24759,0x63b6001e,0x2a650065,0x78a00176}},	//   _glod, _pryn, _helb_, cemv,
   {{0x657a5865,0x2d8101ae,0x39451c1c,0x2a65007a}},	//   arth, huhe_, _huls_, _kelb_,
   {{0x7d020116,0x6449043f,0x68e20393,0x43435866}},	//   znos, ñeir, _zlod, серв,
   {{0x7d0221c7,0x91e35867,0x2a655868,0xdb090183}},	//   ynos, боре, _melb_, _ereç,
   {{0xc4862b9e,0x1eaa0220,0x20551578,0x3ce6006f}},	//   _слик, کاري_, итур, xhov_,
   {{0x7d020bcc,0xd36f0037,0x291f5869,0x212b009e}},	// [53e0] vnos, _فهي_, ilua_, _dhch_,
   {{0x3ea1033b,0x7d0201a7,0x3f800015,0x00000000}},	//   geht_, wnos, ruiu_, --,
   {{0x6b9b0176,0xed574054,0x3ce6006d,0x3945000d}},	//   _apug, гох_, thov_, _nuls_,
   {{0x0b8a0f94,0x2cad099e,0x5c0640b4,0x00000000}},	//   ески_, _caed_, ляла, --,
   {{0x7d0204c3,0x62811ec0,0x254c01c0,0x7af8586a}},	//   rnos, ólog, _měla_, tivt,
   {{0x3ce6586b,0x68e203b7,0x4ed502fb,0x3945013a}},	//   shov_, _slod, _кюст, _buls_,
   {{0x7d02308b,0x39451db3,0x00000000,0x00000000}},	//   pnos, _culs_, --, --,
   {{0x58d4071d,0x02d1000c,0x3ce601e8,0xd90d02fd}},	//   роит, _सक्न, qhov_, ویل_,
   {{0x6cc3002d,0x68e20051,0x00000000,0x00000000}},	//   _уйта, _vlod, --, --,
   {{0x24890602,0x2a65033b,0x78a00345,0xb05b01ff}},	//   _scam_, _gelb_, semv, _knäc,
   {{0x21200528,0x2906012f,0x6b82586c,0x9e7b0070}},	//   klih_, _tjoa_, luog, ענטפ,
   {{0xdb0900c9,0x657a004f,0x2db702b5,0x291f0279}},	//   _preç, rrth, אלטן_, clua_,
   {{0xf3ff0183,0x8c3d0139,0x254c007e,0x00000000}},	//   raão_, _paşi, _děla_, --,
   {{0xf41f01ff,0x00000000,0x00000000,0x00000000}},	//   ffär_, --, --, --,
   {{0x31c442c2,0x8c3d00a8,0x3866023a,0xe7e200ab}},	//   бств, _vaşi, _keor_, गनवा_,
   {{0x6ad100a1,0x212005e2,0x9055586d,0x6b82023c}},	//   _तक्र, glih_, рвац, kuog,
   {{0x81cd0083,0x38660a4e,0x3ea101ae,0x2ef506d8}},	// [53f0] _শেখ_, _meor_, teht_, азар,
   {{0xbd6b2d93,0x4429586e,0x38660a24,0x26de586f}},	//   ерде_, _iza_, _leor_, nkto_,
   {{0x71270071,0x752d5870,0x709500d8,0x6b9b38c0}},	//   _مرحل, _khaz, _канф, _spug,
   {{0x2d815871,0x4c950370,0x629502a2,0x38660211}},	//   ruhe_, ридс, lfzo, _neor_,
   {{0xfb35010b,0x98a60168,0x752d034d,0x00000000}},	//   андэ, _choč_, _mhaz, --,
   {{0x60cd1c12,0x450b0083,0x38691635,0x44295872}},	//   ljam, রতিক_, _žar_, _mza_,
   {{0x60cd00d8,0x6ee05873,0xdb002b82,0x09e510a4}},	//   ojam, _möbl, _armó, ройн,
   {{0x44295874,0x6d5501d7,0x2cbf3347,0x28c50bad}},	//   _oza_, _itza, _unud_, वाधि,
   {{0x7d1b03cb,0x6d475875,0x7e670009,0x44295876}},	//   _ikus, _huja, _kejp, _nza_,
   {{0x6d475877,0x8c3d01d6,0x752d5878,0x596701d3}},	//   _kuja, _başv, _ahaz, _бъда,
   {{0x44292fe7,0x28c53e30,0xe4c62a66,0x6aa306f3}},	//   _aza_, वादि, айни, menf,
   {{0x3869064b,0x6d475879,0x6aa3587a,0x26de0159}},	//   _þar_, _muja, lenf, akto_,
   {{0x7d091254,0x89342087,0x68e9587b,0x6d47587c}},	//   _mjes, _اعلا, mhed, _luja,
   {{0x7d09003a,0x60cd0029,0x644f0382,0x7e6701c0}},	//   _ljes, ejam, acci, _nejp,
   {{0x7d1b09d6,0x21203c1a,0xa06a587d,0x4429587e}},	//   _okus, tlih_, кава_, _eza_,
   {{0x752d587f,0x68e95880,0x68fb5881,0x7d0901f4}},	//   _ghaz, nhed, niud, _njes,

   {{0x0e6614a1,0x27ed349f,0x03a63869,0x6d555882}},	// [5400] икан, nzen_, _типо, _atza,
   {{0x442032c4,0x6d475883,0x63a90723,0x27ed5884}},	//   _iyi_, _buja, çene, izen_,
   {{0x7c2901c2,0x6aa35885,0xc27b0100,0x68e9053e}},	//   _azer, denf, _בריי, khed,
   {{0xf767128b,0x6ec4018d,0x6d475886,0x60cd0035}},	//   _وا_, राहु, _duja, cjam,
   {{0x7c29004e,0x27ed0a75,0x7d0901f4,0x68e95887}},	//   _czer, jzen_, _djes, dhed,
   {{0x6aa35888,0x7d1b5889,0x7c2900ea,0x7983588a}},	//   genf, _ekus, _dzer, funw,
   {{0x38660b4c,0x27ed0120,0x7c29588b,0xaa650210}},	//   _peor_, ezen_, _ezer, стік,
   {{0x68e9588c,0xa3e6164f,0x68fb02fb,0x44200103}},	//   ghed, पना_, giud, _oyi_,
   {{0x6d400468,0x4420588d,0x65630024,0x6d4700cd}},	//   _iima, _nyi_, _awnh, _zuja,
   {{0x7d1b00b8,0x644401da,0x645d01e8,0x5bb40099}},	//   _zkus, _agii, wbsi, ूमीव,
   {{0x6d40588e,0x4420588f,0x38660a39,0x27ed0065}},	//   _kima, _ayi_, _teor_, azen_,
   {{0x68e95890,0x6d4008eb,0x68fb5891,0x44200371}},	//   ched, _jima, ciud, _byi_,
   {{0xdcfc0029,0x6d405892,0x645d5893,0x44204204}},	//   _aprī, _mima, rbsi, _cyi_,
   {{0x6d405894,0x35f700f8,0x00000000,0x00000000}},	//   _lima, ارید_, --, --,
   {{0x60cd0443,0xc1050037,0x62875895,0x44200a21}},	//   tjam, موسي, rgjo, _eyi_,
   {{0x6d4033c7,0x6d47029d,0xe63b0397,0x955300d1}},	//   _nima, _ruja, _בתוכ, _بخوا,
   {{0x44295896,0x60cd5897,0x6d475898,0x692a01c0}},	// [5410] _uza_, rjam, _suja, _břez,
   {{0x63ad2a69,0x6d475899,0x51872123,0x7d1b589a}},	//   _isan, _puja, _кума, _skus,
   {{0x7d09589b,0x7c2907a8,0x27ed00b5,0x6d40589c}},	//   _pjes, _szer, zzen_, _bima,
   {{0xbd180a55,0x6d40589d,0x6d47589e,0x8d742499}},	//   ації_, _cima, _vuja, زاما,
   {{0x7c201973,0x6d4005c6,0x7d09589f,0x28c5111a}},	//   _cymr, _dima, _vjes, वासि,
   {{0xd9450204,0xa9690192,0x6d4758a0,0x63ad000e}},	//   беки, гика_, _tuja, _msan,
   {{0x7d09025c,0x63ad010d,0xa3a908a9,0x6aa358a1}},	//   _tjes, _lsan, _गैस_, renf,
   {{0x27ed58a2,0x6d4058a3,0x7d1b58a4,0x8c3d027d}},	//   tzen_, _gima, _ukus, _başt,
   {{0x7c2002c7,0x8aa705c2,0x68e958a5,0x27ed58a6}},	//   _gymr, _вред, rhed, uzen_,
   {{0x39b50080,0x27ed58a7,0x06c9325e,0x28c5073f}},	//   _tās_, rzen_, угой_, वाहि,
   {{0x63ad58a8,0x44260080,0x6d40007b,0x99d9004f}},	//   _asan, _šo_, _yima, _حواء_,
   {{0x7d190035,0x03a618ea,0x74bf00b4,0x44200107}},	//   nows, бимо, षागृ, _pyi_,
   {{0x386d0c61,0x291d034d,0x00000000,0x00000000}},	//   maer_, _ikwa_, --, --,
   {{0x386d32f5,0x59bd035d,0xd6db00af,0x8c1a011d}},	//   laer_, ्मपर, _ште_, רושי,
   {{0x63ad58a9,0x69dc01d6,0x7d19004e,0x41b50133}},	//   _esan, _üret, kows, остт,
   {{0x386d19b2,0x8c3d0225,0x00000000,0x00000000}},	//   naer_, _yaşt, --, --,
   {{0x6d4058aa,0x44260028,0x7d190067,0x692a00b8}},	// [5420] _rima, _áo_, dows, _přez,
   {{0x6d4058ab,0x52aa03fa,0xdcfe00ac,0x00000000}},	//   _sima, _свом_, rupč, --,
   {{0xa0a62bfa,0x6d4058ac,0x291d018e,0x6f1c02a7}},	//   _ланд, _pima, _okwa_, _vkrc,
   {{0x237f2d5b,0xfb1900b5,0xdcfe00cd,0x98be0395}},	//   šuje_, یروں_, pupč, _mută_,
   {{0xb05b017b,0x00000000,0x00000000,0x00000000}},	//   _knän, --, --, --,
   {{0x6f1c011c,0x6e3a008d,0x7c2000ac,0x3eb101b7}},	//   _ukrc, _útbo, _vymr, _gazt_,
   {{0xa96709ea,0x6d401722,0x7d191140,0x8c3d045e}},	//   бија_, _tima, bows, _başs,
   {{0xa3a90006,0x6d4058ad,0x175402fb,0x8c3d00af}},	//   _गईल_, _uima, овия, _paşt,
   {{0xb8d00380,0x7b0758ae,0x69b8018d,0x7bc60116}},	//   _ओस_, órtá, ्मही, _škuf,
   {{0xb6c603ad,0x6753004f,0x2ca614d8,0x6d4100f7}},	//   ссий, أخير, leod_, _élar,
   {{0x63ad01a8,0x7ae8008c,0x00000000,0x00000000}},	//   _ssan, _ildt, --, --,
   {{0x6fc80c97,0x386d07a6,0x63ad00b8,0xe4eb0079}},	//   रमां, caer_, _psan, اعده_,
   {{0x28c50bc1,0x254c00b8,0x80cc021a,0x00000000}},	//   वारि, _tělo_, हाने, --,
   {{0xe81d02e4,0x3f8058af,0x6105010b,0x248d0035}},	//   _पडता_, driu_, mėli, żem_,
   {{0x31c404bf,0xa3a900b1,0x6105010b,0x63ad0118}},	//   пств, _गैर_, lėli, _wsan,
   {{0x63ad58b0,0x3f800391,0x2545013a,0x00000000}},	//   _tsan, friu_, _cēlu_, --,
   {{0x63ad22f0,0x2ca600ab,0x6105010b,0x7afa0103}},	// [5430] _usan, deod_, nėli, _omtt,
   {{0x7c2600ac,0xfbc30033,0x7b1f021d,0x00000000}},	//   _úkry, ্নমত, nêut, --,
   {{0xd0d50036,0x957c004e,0x386d00d7,0x741501df}},	//   _донъ, cząt, yaer_, _دوکا,
   {{0x3f8058b1,0x2d9301a3,0x6105010b,0x00000000}},	//   briu_, rtxe_, kėli, --,
   {{0x7d1958b2,0x3f8012c3,0xa2be0099,0x39c00160}},	//   rows, criu_, शाच्, _lăsă_,
   {{0x4ea70043,0x6105010b,0x386d016e,0x3ea5014c}},	//   _урма, dėli, waer_, _últ_,
   {{0xda780fa4,0x28c50440,0xf8c5021a,0x386d0d51}},	//   сяч_, वालि, वालय, taer_,
   {{0xa3a90035,0x7ae858b3,0x98be0160,0xf54900cc}},	//   _गईं_, _eldt, _rută_, _bấn_,
   {{0x386d0a8c,0x98be00af,0xf5490023,0x46e9141d}},	//   raer_, _sută_, _cấn_, идин_,
   {{0x81c20033,0xb6a50a46,0xf54900e2,0x0a680d6e}},	//   ্নত_, циол, _dấn_, _грци_,
   {{0x7ac40421,0x64a61858,0xd6291a8e,0xb88307c0}},	//   _эсте, оана, роне_, _príď,
   {{0xf2c90122,0x39930279,0x657c0093,0x291d04fb}},	//   _בע_, mãs_, árha, _ukwa_,
   {{0x3993021d,0x00000000,0x00000000,0x00000000}},	//   lãs_, --, --, --,
   {{0x7b1f0279,0x55e527eb,0x00000000,0x00000000}},	//   cêut, _молб, --, --,
   {{0xc5d51112,0x32431108,0x00000000,0x00000000}},	//   _філь, дерг, --, --,
   {{0x3f8058b4,0x957c0067,0xafe6399d,0x00000000}},	//   triu_, rząt, ообл, --,
   {{0xb05b0523,0x00000000,0x00000000,0x00000000}},	// [5440] _inäl, --, --, --,
   {{0x9e5a0210,0x3f800015,0x00000000,0x00000000}},	//   рраф_, rriu_, --, --,
   {{0x412a01e0,0x6da60037,0xb05b0523,0x00000000}},	//   _воно_, تمام, _knäl, --,
   {{0x0c260a87,0x3f8058b5,0xc7b900b5,0x3993021d}},	//   омен, priu_, kvő_, dãs_,
   {{0x8c3d01c2,0x00000000,0x00000000,0x00000000}},	//   _başq, --, --, --,
   {{0xe81d0035,0xf21f0324,0x610500c7,0x00000000}},	//   _पड़ा_, _मुड़_, vėli, --,
   {{0xfce62462,0x3993021d,0x7bc60207,0x8c3d013b}},	//   _дово, gãs_, _škud, _daşq,
   {{0x6d5e0086,0x3942312a,0x7c2f021d,0x3aeb03d0}},	//   mppa, öks_, _ºcrp, _røpe_,
   {{0x6d5e1a9d,0xc6f800d4,0x629e08b7,0x3b1e0118}},	//   lppa, йних_, _obpo, _tktq_,
   {{0xf54900e8,0xd6da1962,0x6b8258b6,0xab2a0009}},	//   _vấn_, рти_, mrog, _тоза_,
   {{0x81df0083,0xbb3b0070,0x94050095,0x00000000}},	//   _দেন_, _כעמי, ələ_, --,
   {{0xf54901a5,0x98a60171,0xd5b800ec,0x9c830097}},	//   _tấn_, _фиде, rvā_, _účtu,
   {{0x7b1f0279,0x25a900cd,0x6b820098,0x00000000}},	//   pêut, _ćale_, nrog, --,
   {{0x050b0083,0xdb0001ae,0x6b820952,0x2545013a}},	//   রতের_, _ermö, irog, _cēls_,
   {{0x306b0fb4,0xbbc6021a,0x00000000,0x00000000}},	//   ијан_, लमुक, --, --,
   {{0x6ab70099,0x394c0176,0xb05b01ff,0x00000000}},	//   _आफ्र, _muds_, _gnäl, --,
   {{0xd8d70070,0x6e3a05ee,0x00000000,0x00000000}},	// [5450] קומט_, _útbj, --, --,
   {{0x6235235d,0x394c0b88,0x00000000,0x00000000}},	//   _непу, _ouds_, --, --,
   {{0x6d5e0159,0x60c60069,0xde190079,0x00000000}},	//   gppa, _fnkm, حقات_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef930ef5,0x09b3009a,0x6b8239c5,0x7ba70037}},	//   _زیاد, ंट्य, grog, تصام,
   {{0x39930132,0xe80e0e61,0x00000000,0x00000000}},	//   tãs_, ापना_, --, --,
   {{0x26c90023,0xc27c0070,0x3ebe008d,0xa49b009e}},	//   _đao_, ברוי, _ótta_, anòi,
   {{0x6b820962,0xab950279,0x00000000,0x00000000}},	//   brog, _набљ, --, --,
   {{0x8cc10067,0x23690359,0x00000000,0x00000000}},	//   _रोयो, _nwaj_, --, --,
   {{0xb05b013c,0x00000000,0x00000000,0x00000000}},	//   _snäl, --, --, --,
   {{0x394c33d4,0x28f900af,0x7d0b00cc,0x00000000}},	//   _guds_, _лежь_, ongs, --,
   {{0x499a00a5,0xa50a03e6,0x00000000,0x00000000}},	//   _לשעב, сема_, --, --,
   {{0xddd5006c,0x394c0009,0x7d0b58b7,0x00000000}},	//   _mező, _zuds_, ings, --,
   {{0x78a958b8,0xfbd200a5,0x8c1a076b,0x00000000}},	//   leev, עתם_, מורי, --,
   {{0x26c758b9,0x59bd046c,0x81df0033,0x00e40118}},	//   _inno_, ्मिर, _দেব_, وتری,
   {{0xaac70084,0x61e103d0,0x00000000,0x00000000}},	//   लाँक, ølla, --, --,
   {{0x23690069,0x00000000,0x00000000,0x00000000}},	// [5460] _gwaj_, --, --, --,
   {{0x63a458ba,0x78a9006d,0x8cc10127,0x00000000}},	//   _ipin, heev, _रोबो, --,
   {{0x629c0526,0x32db0122,0x6d5e58bb,0x6b8200e9}},	//   mfro, _החינ, uppa, wrog,
   {{0x315700c2,0x6b8258bc,0xf5490019,0x78a9008b}},	//   _מיטן_, trog, _nấm_, jeev,
   {{0xaac7004e,0x2b45022f,0x394c0090,0x63a458bd}},	//   लांक, _bilc_, _suds_, _jpin,
   {{0x628e58be,0xb4e907df,0x99661412,0x63a458bf}},	//   ngbo, _यत्_, птил, _mpin,
   {{0xada358c0,0xf54901a5,0x394c012f,0x6da32447}},	//   _парл, _bấm_, _quds_, _пира,
   {{0x26c70133,0x6d5c58c1,0xf5490019,0x6d4e2f31}},	//   _anno_, _itra, _cấm_, _iuba,
   {{0x6d4e58c2,0x3ce60bc9,0x7d024206,0x2d570069}},	//   _huba, mkov_, mios, _għeb_,
   {{0x6d4e2f38,0x7d0258c3,0x3ce658c4,0x6f1e00cd}},	//   _kuba, lios, lkov_, nopc,
   {{0x629c0118,0x394c022e,0xa2d0170c,0x63a458c5}},	//   dfro, _uuds_, दान्, _apin,
   {{0x6d4e58c6,0x3ce658c7,0x7d0258c8,0x26c70044}},	//   _muba, nkov_, nios, _enno_,
   {{0x6d4e58c9,0x629c58ca,0xa8470ca8,0x254c01c0}},	//   _luba, ffro, _علوم_, _měli_,
   {{0x6d5c58cb,0x569309ea,0xa77b0122,0x7d0258cc}},	//   _otra, _зашт, _פרופ, hios,
   {{0x63a40fce,0xa69b0122,0x39460932,0x2d78336f}},	//   _epin, _השופ, _kios_, jče_,
   {{0x6aaa58cd,0x7d0201a3,0x7bc005ee,0x3ebf58ce}},	//   heff, jios, _ormu, _şut_,
   {{0x7d0258cf,0x84980ad9,0x394658d0,0x3ce6338b}},	// [5470] dios, _رئيس_, _mios_, dkov_,
   {{0x6d4e58d1,0x3946006b,0x629c0051,0x00000000}},	//   _buba, _lios_, cfro, --,
   {{0x6d4e58d2,0x7bc05398,0x7d0258d3,0x394600d7}},	//   _cuba, _armu, fios, _oios_,
   {{0x7d0258d4,0xeae50066,0x78a9006d,0xe81d29ce}},	//   gios, कस्त_, xeev, _पडला_,
   {{0x21291201,0x6d5c58d5,0x6f1e0176,0x2b4500ee}},	//   mlah_, _etra, bopc, _pilc_,
   {{0x2d780009,0xf54900e2,0x39460312,0x00000000}},	//   bče_, _sấm_, _aios_, --,
   {{0x6d4e58d6,0x3ce601ba,0x7bc058d7,0xb0e10066}},	//   _guba, bkov_, _ermu, _नवाग,
   {{0x21290f1a,0x3ce615ce,0x8c3d00a8,0x67280223}},	//   nlah_, ckov_, _abşe, eldj,
   {{0x394658d8,0x212920fb,0x7bc002c4,0x78a9018e}},	//   _dios_, ilah_, _grmu, reev,
   {{0x21290ec0,0x3ced58d9,0x3cff01e8,0x6d4e01d5}},	//   hlah_, _hlev_, _hmuv_, _yuba,
   {{0x3946004a,0x21290f1a,0x6d5c58da,0x34aa2626}},	//   _fios_, klah_, _xtra, овно_,
   {{0x59a622a3,0x63a40159,0x69c10065,0x00000000}},	//   _कैटर, _ppin, _irle, --,
   {{0x4c9a02b8,0x212958db,0x00000000,0x00000000}},	//   חברו, dlah_, --, --,
   {{0x660509c0,0x7d0258dc,0x6d5a0248,0x69c100cb}},	//   _опла, zios, _étag, _krle,
   {{0x4615026e,0x4343014d,0x212944ce,0x290d17c3}},	//   _توغر, терв, flah_, onea_,
   {{0x6d4e58dd,0x7d02043f,0x629c0298,0x290d1ba3}},	//   _ruba, xios, sfro, nnea_,
   {{0xd24f0332,0x3ce62ce5,0x2730009e,0x63a4000e}},	// [5480] انہ_, vkov_, làna_, _upin,
   {{0x443207df,0x6d5c0088,0x3ced58de,0x6d4e58df}},	//   _izy_, _ptra, _alev_, _puba,
   {{0x550206bb,0x3ced2172,0x3ce658e0,0x7d020dfa}},	//   _लगाए_, _blev_, tkov_, tios,
   {{0x25d60779,0x7e6e58e1,0xfce30b46,0x447b0070}},	//   ווען_, _webp, кохо, ַנצע,
   {{0x394658e2,0x6b99006d,0xdb1b0310,0x5f76186e}},	//   _rios_, gtwg, _cruï, _تاجر,
   {{0x6d4e58e3,0x45060083,0x7d0258e4,0x3ce658e5}},	//   _tuba, ৈতিক_, sios, skov_,
   {{0x6d5c58e6,0x6aaa58e7,0x7d020328,0x3ce60bc9}},	//   _utra, reff, pios, pkov_,
   {{0x3eb83368,0x57b40021,0xdd8f0172,0x6aaa55e7}},	//   _hart_, ебит, _خوف_, seff,
   {{0x69c158e8,0x3eb858e9,0xb7be0083,0x6449010b}},	//   _erle, _kart_, েন্ট, žeik,
   {{0x6a830e88,0xddce2686,0x752458ea,0x98a300ea}},	//   _алфа, _nebū, _akiz, ējā_,
   {{0x3eb858eb,0xceb30122,0x212900d7,0x394658ec}},	//   _mart_, דית_, ylah_, _tios_,
   {{0x3eb800da,0x6723023a,0xa4d501e0,0xe7862a2d}},	//   _lart_, _eknj, хомі, _жуко,
   {{0x44320755,0x29040a78,0xd94358ed,0x21290009}},	//   _czy_, mima_, _реци, vlah_,
   {{0x290458ee,0x63bd008c,0x752401a8,0x00000000}},	//   lima_, rvsn, _ekiz, --,
   {{0x2129005d,0x98a6004e,0xf2043242,0x7d000160}},	//   tlah_, _choć_, вято, _omms,
   {{0x290428d2,0x21290ac8,0x3eb80223,0x43950274}},	//   nima_, ulah_, _aart_, _заис,
   {{0x3eb80408,0x212903c3,0x26dc00d8,0x6d58031d}},	// [5490] _bart_, rlah_, _kovo_, ívan,
   {{0x442958ef,0x21290ce8,0x290458f0,0x3eb858f1}},	//   _iya_, slah_, hima_, _cart_,
   {{0x290458f2,0x21290ac8,0x61e1022a,0xfbd000f8}},	//   kima_, plah_, älld, یته_,
   {{0x29040537,0xd2510ef5,0x442909d6,0x00000000}},	//   jima_, _جنگ_, _kya_, --,
   {{0x290401cc,0x80cc060a,0x3eb803d0,0xf04400c3}},	//   dima_, हारे, _fart_, _аэро,
   {{0x26dc58f3,0x78a20122,0xb06200ab,0x69c108b7}},	//   _novo_, _abov, _äärm, _prle,
   {{0x60dd58f4,0xa2d001d1,0x44290273,0x6b8b3184}},	//   _kosm, दात्, _lya_, sugg,
   {{0x290458f5,0x290d0043,0x442958f6,0x644d0286}},	//   gima_, unea_, _oya_, _ngai,
   {{0x442904fa,0x290d58f7,0x60dd0031,0x291f428c}},	//   _nya_, rnea_, _mosm, roua_,
   {{0x644d4c34,0x26dc539a,0x60dd58f8,0x7c2958f9}},	//   _agai, _covo_, _losm, _iyer,
   {{0x44293069,0x290458fa,0x26dc011e,0xb8f50033}},	//   _aya_, bima_, _dovo_, _হত_,
   {{0x29040254,0x4429203d,0x09bd0864,0xd75600d1}},	//   cima_, _bya_, ्मीय, بلیت_,
   {{0x4429070b,0x644d0176,0x00000000,0x00000000}},	//   _cya_, _dgai, --, --,
   {{0x68e958fb,0x44290159,0x60dd01da,0x78bb00ab}},	//   lked, _dya_, _aosm, lduv,
   {{0x28d304aa,0x60dd58fc,0x569204bf,0x6721030a}},	//   थापि, _bosm, _сајт, molj,
   {{0x69c0084b,0x78bb58fd,0x672158fe,0x69dc0443}},	//   विती, nduv, lolj, _àree,
   {{0x7c2958ff,0x3eb8504e,0x60dd02a7,0x442901a8}},	// [54a0] _nyer, _part_, _dosm, _gya_,
   {{0x29045900,0x78b9006d,0x67215901,0x139b00a5}},	//   zima_, _lawv, nolj, _צביע,
   {{0x7c294ab2,0x3eb80044,0x68e95902,0x2904276d}},	//   _ayer, _vart_, kked, yima_,
   {{0x61e15903,0x7c290010,0x3eb85904,0x80ca0083}},	//   älle, _byer, _wart_, রসঙ্,
   {{0x29040537,0x28d32095,0x3eb85905,0x44290221}},	//   vima_, थानि, _tart_, _xya_,
   {{0x940400a8,0xdb1b01ef,0x7c290031,0xdb090138}},	//   ümə_, _fruí, _dyer, _breñ,
   {{0xfbd800c8,0x67215906,0x6d490160,0x00000000}},	//   _দেখত, dolj, _fiea, --,
   {{0x7c290031,0x6d49009e,0x26dc023a,0x63b6017b}},	//   _fyer, _giea, _sovo_, _osyn,
   {{0x7c290332,0x6d5a02e1,0x26dc03e6,0x4733026b}},	//   _gyer, _étab, _povo_, گريز,
   {{0x44290232,0xf1d00026,0x67211f3d,0xf1e00026}},	//   _rya_, हमान, golj, नहान,
   {{0x44290269,0x23605907,0x29045908,0xdb095909}},	//   _sya_, _atij_, pima_, _greñ,
   {{0x399a00da,0xd7fa002d,0x2ba7046c,0x78a208c7}},	//   mës_, _нул_, _गहमा, _ubov,
   {{0x66e63de5,0x672102dd,0x248002c7,0x399a00da}},	//   _пода, bolj, _ddim_, lës_,
   {{0x442919c6,0x2fc0590a,0x26dc07e5,0x2480013b}},	//   _vya_, dvig_, _uovo_, _edim_,
   {{0x60dd590b,0x399a01d2,0x28c509b1,0x5184049f}},	//   _posm, nës_, वाचि, лута,
   {{0x88bd006a,0x644d590c,0x28d323db,0x24800024}},	//   mośc, _ugai, थायि, _gdim_,
   {{0x81df00c8,0x399a00da,0xff5321a0,0x61e101ff}},	// [54b0] _দেশ_, hës_, اخر_, ällb,
   {{0x399a01d2,0x6aba0009,0x68e900b5,0x7c29590d}},	//   kës_, _natf, zked, _ryer,
   {{0x88bd006a,0xe314004f,0x399a00da,0x6d490029}},	//   nośc, _حبيب, jës_, _piea,
   {{0x307900c2,0x399a01f4,0x7c290107,0x67211757}},	//   _קאָנ, dës_, _pyer, zolj,
   {{0x06b70083,0x2d57007a,0xeb990384,0x7c940088}},	//   জাতি, _għen_, фил_, اشما,
   {{0x6aba0602,0x88bd004e,0xfaa5590e,0x78b90221}},	//   _catf, kośc, тако, _sawv,
   {{0x67210888,0x399a01f4,0x6ca7010b,0x9e34034b}},	//   volj, gës_, _праж, _берч,
   {{0xdddc01d6,0x657a08c8,0xddc70207,0x88bd0067}},	//   _herş, dsth, _gejš, dośc,
   {{0x68e91123,0x24800069,0x67212898,0x78bb00ab}},	//   rked, _rdim_, tolj, rduv,
   {{0x68e9590f,0x0ab418dd,0x2caf0120,0x9b440dc0}},	//   sked, _محمد, legd_, _منقو,
   {{0x940c01c2,0x67215910,0x399a01f4,0x657a309a}},	//   ədə_, rolj, cës_, gsth,
   {{0x67215911,0xe94500d1,0x6fc40246,0x9f400036}},	//   solj, _شرای, रिमू, nziò_,
   {{0x67215912,0x3f89006d,0x6c7a0070,0x00000000}},	//   polj, jrau_, וארפ, --,
   {{0x59c506fe,0x3f895913,0x00000000,0x00000000}},	//   विपर, drau_, --, --,
   {{0x40965914,0x412a5915,0x6b9b009f,0x00000000}},	//   крат, дово_, _lqug, --,
   {{0x3f895916,0x7e690207,0x00000000,0x00000000}},	//   frau_, _đepa, --, --,
   {{0x3f895917,0x61433dd9,0xd007224a,0x399a01f4}},	// [54c0] grau_, рета, вете_, zës_,
   {{0x2fc05918,0x45140083,0x6133027d,0x1eaa5919}},	//   rvig_, _সঠিক_, rçla, باري_,
   {{0xdd8f0c9e,0x127b02b5,0x9d4601d3,0xaefb0211}},	//   قول_, _קאטע, вежд, _stùc,
   {{0x399a01d2,0x13e600c8,0x7afd01c8,0x3f89001e}},	//   vës_, _পেয়, _įsta, brau_,
   {{0x8b961a72,0x6aba0009,0xe4570070,0x88bd0067}},	//   треч, _patf, דינט_, zośc,
   {{0x399a01d2,0x6e9600bc,0x9f4000b5,0x63a9591a}},	//   tës_, _جلسا, rzió_, çeni,
   {{0xf54a00e2,0x02a4021a,0xa0260282,0x00000000}},	//   _hấu_, ख्यभ, _fröå, --,
   {{0x399a01d2,0xfce30c87,0x52df27c6,0xb9e301e0}},	//   rës_, _косо, _नक्स, ріши,
   {{0x88bd006a,0x8afd000c,0x399a00da,0xfce35915}},	//   wośc, _stře, sës_, _тото,
   {{0x399a01f4,0x310200be,0x88bd0035,0x657a02b1}},	//   pës_, रोतः_, tośc, tsth,
   {{0x7bc2591b,0xa2c6112b,0x399a0031,0x00000000}},	//   lvou, ायन्, qës_, --,
   {{0x657a345d,0x3f89016e,0x88bd0067,0x5d7b016b}},	//   rsth, yrau_, rośc, ואטק,
   {{0x7bc20a45,0xf54a0019,0x657a0044,0x8c3d1008}},	//   nvou, _nấu_, ssth, _başy,
   {{0x2caf0120,0x00000000,0x00000000,0x00000000}},	//   zegd_, --, --, --,
   {{0x7bc60168,0x2b4c0069,0x00000000,0x00000000}},	//   _škul, _midc_, --, --,
   {{0x50640395,0x3f89591c,0x3b07013b,0xf54a00cc}},	//   итуа, trau_, zinq_, _bấu_,
   {{0xa2d007b5,0xf54a01a5,0x926b00af,0xab5d0024}},	// [54d0] दाश्, _cấu_, _орна_, _arżn,
   {{0xf54a0028,0x3f89591d,0x00000000,0x00000000}},	//   _dấu_, rrau_, --, --,
   {{0xa2d00931,0x00000000,0x00000000,0x00000000}},	//   दार्, --, --, --,
   {{0x273900f7,0x506400d4,0xdb00591e,0x645d591f}},	//   mène_, _втра, _osmó, ncsi,
   {{0xceeb064e,0xac8454ea,0x09bd01d1,0x273900f7}},	//   _قرآن_, ргіл, ्म्य, lène_,
   {{0x8f9a0122,0xd9d70083,0x62955920,0xf54a00e2}},	//   _אישי, তনসম, ngzo, _hất_,
   {{0xf2d400c2,0xeaf30084,0x3b0700a8,0x39b7013b}},	//   יעס_, _अतीत_, rinq_, _kəsə_,
   {{0x8cca0026,0xa5020099,0x00000000,0x00000000}},	//   _सोपो, _लगेच_, --, --,
   {{0xf54a01a5,0xf7710c9e,0x6d554d2d,0x6e3a008d}},	//   _mất_, حاب_, _huza, _útbr,
   {{0x6d5508e1,0xc987326d,0xb05b0523,0x00000000}},	//   _kuza, _ауди, _knäs, --,
   {{0x66055921,0x6d55009f,0x00000000,0x00000000}},	//   упна, _juza, --, --,
   {{0x6d550979,0x26ce02d0,0xa8790070,0x9a9900ea}},	//   _muza, _enfo_, _װאַר, žādā,
   {{0xe72e0424,0x6d5501d7,0x7ae15922,0x06df0033}},	//   _ге_, _luza, _kolt, যোগি,
   {{0xc7b200a5,0x81df0033,0x7ae10421,0x6d550107}},	//   _לבד_, _দেই_, _jolt, _ouza,
   {{0x7ae15923,0xf54a0019,0x27395924,0x6d555925}},	//   _molt, _bất_, gène_, _nuza,
   {{0x61e1013c,0xb4db0443,0xf54a0019,0xe61000f8}},	//   älla, rmàc, _cất_, _بشه_,
   {{0x7e751298,0x251b00a5,0xb348003c,0x30751397}},	// [54e0] _bezp, _רופא, _agħż, русс,
   {{0x4df603ad,0x6d555926,0x2bc7018d,0x7e7500ee}},	//   ляет, _buza, लिना, _cezp,
   {{0x80bf05a6,0x80d30033,0x4bda00b5,0x6d555927}},	//   _लोके, _সতর্, کباد_, _cuza,
   {{0x2d870b4c,0xf54a0019,0x7bc20d35,0x6d550207}},	//   ánea_, _tấu_, tvou, _duza,
   {{0x7ae15928,0x7fd503d0,0xc879008f,0xb3480069}},	//   _bolt, _кірі, daş_, _egħż,
   {{0x7bc25929,0x7ae123e8,0x00000000,0x00000000}},	//   rvou, _colt, --, --,
   {{0x3f92592a,0x13ad0033,0x6d55592b,0xee3745ac}},	//   luyu_, খিয়, _guza, _бнр_,
   {{0x61e1008c,0x8c46547d,0x7ae1005f,0x00000000}},	//   ølli, _бебе, _eolt, --,
   {{0x6d55024e,0x3f9201d6,0x7ae1592c,0x00000000}},	//   _zuza, nuyu_, _folt, --,
   {{0x7ae1023a,0x7f4e003c,0x6d4201ed,0x00000000}},	//   _golt, _jibq, lmoa, --,
   {{0x97d7006c,0x645a00b8,0xd88400d1,0xc8790448}},	//   نظیر_, ětin, _نهای, baş_,
   {{0x7ae100b5,0x3f92592d,0xfbb80026,0x69c8592e}},	//   _zolt, kuyu_, _इनाम, _irde,
   {{0xf54a00e8,0x2bc70440,0x090600b5,0x69c800d5}},	//   _rất_, लिया, _لڑکی_, _hrde,
   {{0x88bd0035,0x7f4e007a,0x7e690207,0x00000000}},	//   nośn, _nibq, _đepo, --,
   {{0xd13b1a77,0x6e2e0282,0x69d84863,0x00000000}},	//   еха_, _nybb, nxve, --,
   {{0x6d55592f,0x68e25930,0x2739000d,0x555100fd}},	//   _ruza, _jood, rène_, _گھیر,
   {{0x68e25931,0x3f4d0009,0xf54a0023,0x27392a5a}},	// [54f0] _mood, _džun_, _vất_, sène_,
   {{0x200d064b,0x68e20006,0x3f8701cc,0x63ad5932}},	//   _þeim_, _lood, čnu_, _ipan,
   {{0xf54a0028,0xcb400009,0xadb50ebc,0x62850024}},	//   _tất_, _armя, рбеш, _idho,
   {{0xa3e900b4,0x68e20136,0x6e2e0a8a,0xf54a00e2}},	//   _यथा_, _nood, _dybb, _uất_,
   {{0x69c842e0,0x7ae15933,0x6d5a02e1,0xc879008f}},	//   _arde, _polt, _étan, vaş_,
   {{0x63ad289f,0x6d5526bd,0xdefb01c8,0x2bc71ede}},	//   _mpan, _tuza, _чым_, लिबा,
   {{0x7ae15934,0x68e20136,0xdb00054e,0x6d55002f}},	//   _volt, _bood, _opmæ, _uuza,
   {{0x7785087b,0x7ae13797,0x63ad1aa5,0x88c9170e}},	//   ализ, _wolt, _opan, тлив_,
   {{0x68e25935,0xccf20122,0x7ae15936,0x69c85937}},	//   _dood, _וכן_, _tolt, _erde,
   {{0xe7390202,0x7d0b5938,0x2cbf00b9,0xa3b00035}},	//   ђен_, ligs, _haud_, _टैग_,
   {{0xe5a51dd0,0x63ad5939,0x68e2593a,0x69c8030a}},	//   шини, _apan, _food, _grde,
   {{0x7bc9593b,0x7d0b593c,0x68e23b19,0x6285593d}},	//   _kreu, nigs, _good, _adho,
   {{0x61e1022a,0x63ad593e,0x2cbf3913,0xb7671d67}},	//   älln, _cpan, _maud_, _стей,
   {{0x2cbf593f,0xf77000bf,0x386d02c9,0xcb1202b5}},	//   _laud_, _راه_, lber_, ַלן_,
   {{0x63ad23ca,0x7d0b02b3,0xc1e000b4,0x11d501e0}},	//   _epan, kigs, नहेग, бітр,
   {{0x394f5940,0x386d5941,0x3d1f0035,0x628503c1}},	//   _jigs_, nber_, यकों_, _edho,
   {{0x386d01ae,0x7d0b5942,0x212b008c,0xaf065943}},	// [5500] iber_, digs, _dkch_, апал,
   {{0x543b0070,0x386d0225,0x394f0069,0xe37b00a5}},	//   _בעפא, hber_, _ligs_, _שריר,
   {{0x386d035f,0xa0a65944,0x7d0b01ae,0xdcff00b8}},	//   kber_, _канд, figs, _úvěr,
   {{0x0b8a23d7,0x7b6600c7,0xdca63b8b,0x7bc95945}},	//   вски_, атке, ради, _breu,
   {{0x7bc95946,0x2cbf1f1d,0x69c833c1,0x68e24b11}},	//   _creu, _daud_, _srde, _rood,
   {{0x7bc95947,0x2ba70084,0x68e2007c,0x6d4206a2}},	//   _dreu, _गहरा, _sood, smoa,
   {{0x68e25948,0xf9e90083,0xf2890070,0xb05b01ff}},	//   _pood, _কেবল_, אָפֿ, _knäp,
   {{0x7bc95949,0xa7741a24,0x394f594a,0x2cbf0176}},	//   _freu, блич, _cigs_, _gaud_,
   {{0x68e2594b,0x7bc9594c,0x6fc90035,0x5fc905a2}},	//   _vood, _greu, रियं, रियल,
   {{0x2cbf0221,0x68e2594d,0x81bc0033,0x69c823e5}},	//   _zaud_, _wood, _আপন_, _trde,
   {{0x386d594e,0xd5b7594f,0xd6d7325e,0x68e2007c}},	//   bber_, ася_, рты_, _tood,
   {{0x186a5950,0x2ca6001e,0x3f8000c7,0x6fc937e8}},	//   _ради_, nfod_, ksiu_, रिमं,
   {{0xda780038,0x8af900a8,0x07da00f8,0x00000000}},	//   _keď_, bləğ, _جذاب_, --,
   {{0x59bd05f8,0x2bc7012f,0x00000000,0x00000000}},	//   ्मचर, लिता, --, --,
   {{0xb6cb0332,0x3f820069,0xda780168,0x31c45951}},	//   _جانے_, _avku_, _meď_, оств,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ad5952,0xdcfc20f1,0x752d5953,0x2cbf2e04}},	// [5510] _upan, _cvrč, _ikaz, _raud_,
   {{0x28a623f0,0x2cbf006f,0xf54a01a5,0x2d870b4c}},	//   क्ति, _saud_, _hấp_, áneo_,
   {{0x386d5954,0x7d0b01ae,0x8af90095,0x2cbf012f}},	//   yber_, tigs, nləş, _paud_,
   {{0x7c87095d,0x237f00cd,0x6fc40808,0x00000000}},	//   руже, šuju_, रिशू, --,
   {{0x67285955,0x752d0054,0x2cbf00a2,0x7d0b2c9a}},	//   kodj, _mkaz, _vaud_, rigs,
   {{0x7bc95956,0xf54a0023,0x7d0b5957,0x394f12ff}},	//   _vreu, _lấp_, sigs, _sigs_,
   {{0x752d5958,0xceb20122,0x7db40037,0x394f0cec}},	//   _okaz, _מים_, _وصفا, _pigs_,
   {{0x7bc95959,0x4c940421,0xc9150083,0xac9410be}},	//   _treu, _мисс, াত্ত_, _масш,
   {{0x7d09595a,0x394f053e,0x386d595b,0x7c84002d}},	//   _imes, _vigs_, rber_, _фусе,
   {{0x752d595c,0x7d1b595d,0x6728595e,0x7c3b595f}},	//   _akaz, _hjus, godj, _izur,
   {{0x77690042,0x2d815960,0x25ae021d,0xf54a00cc}},	//   spex, nshe_, _cpfl_, _bấp_,
   {{0xf54a00e8,0x3f8000c7,0x23c300b4,0x00000000}},	//   _cấp_, ysiu_, शिंद, --,
   {{0xa85600a5,0x6728003d,0x7d095961,0x7c3b0069}},	//   _הינה_, bodj, _mmes, _jzur,
   {{0x7d1b5962,0x7c3b000e,0x62635963,0x752d0103}},	//   _ljus, _mzur, звра, _ekaz,
   {{0x27ed5964,0x7d09027a,0x6edb04e9,0xf5950037}},	//   lyen_, _omes, नानु, _العج,
   {{0xf54a01a5,0x7d1b0207,0xa5640833,0x09bc0033}},	//   _gấp_, _njus, _بدون, _অপমা,
   {{0x27ed142f,0x7c3b000e,0x27ff01ed,0x3f80010b}},	// [5520] nyen_, _nzur, nzun_, usiu_,
   {{0x7d1b0747,0x7d095965,0x7e565966,0xdfcf004f}},	//   _ajus, _ames, стац, عيل_,
   {{0x3f800310,0x68fb00d7,0x3cf40066,0xe1f200d1}},	//   ssiu_, khud, ंसले_, _رسد_,
   {{0xf54a00e2,0x2d830124,0x67282d00,0xa1360919}},	//   _xấp_, _dvje_, zodj, _درخش,
   {{0x2ca60297,0x27ed0d75,0x61ee0183,0x28bd05f8}},	//   rfod_, jyen_, lybl, ्यनि,
   {{0x7d095967,0x27ed02e9,0x64410095,0x7d1b007e}},	//   _emes, dyen_, əlid, _ejus,
   {{0xa2d906bc,0x67282518,0xda7801ba,0xde0300af}},	//   मात्, vodj, _veď_, _епри,
   {{0x60c45968,0xdca30011,0x68fb5969,0x442000e2}},	//   ndim, _наси, ghud, _oxi_,
   {{0x27ed0332,0xda7801c0,0x60c4596a,0x2000596b}},	//   gyen_, _teď_, idim, nzii_,
   {{0xf76f2e36,0xaae50098,0x8b2600d8,0xc6f71db7}},	//   راً_, _وسلو, _удзе, йных_,
   {{0x4432596c,0x6728596d,0x7d0900e9,0x6b8203d0}},	//   _ayy_, rodj, _ymes, lsog,
   {{0x27ed0c1f,0x8af901c2,0x61ee596e,0x629e009e}},	//   byen_, rləş, dybl, _acpo,
   {{0x7e7e0626,0xf54a0019,0xddd50107,0x672802a7}},	//   kapp, _vấp_, _egzň, podj,
   {{0x64560332,0x2d810031,0xa2d90d41,0x60c40051}},	//   _egyi, yshe_, माध्, edim,
   {{0x752d078a,0x7e7e0223,0x24990159,0xf54a00e2}},	//   _tkaz, dapp, pgsm_, _tấp_,
   {{0x752d15d8,0x44200069,0x39ae013b,0x00000000}},	//   _ukaz, _fxi_, _kəsb_, --,
   {{0x14d60d91,0xa2d90b35,0x6133027d,0x24891008}},	// [5530] धारण, माद्, nçli, _idam_,
   {{0x6d400d9f,0x7d09596f,0x9e1501c8,0x2bc702cb}},	//   _ahma, _smes, одзі, लिसा,
   {{0x28bd0066,0x27ed02d0,0x60c40160,0x7c3b00b5}},	//   ्यमि, zyen_, bdim, _szur,
   {{0x2d8101e9,0x248901a2,0x7a4200b5,0x00000000}},	//   rshe_, _jdam_, zíté, --,
   {{0x2d8100d7,0x7d0908b7,0x00000000,0x00000000}},	//   sshe_, _vmes, --, --,
   {{0x7e7e5970,0x28a60518,0x6d4000be,0xa8a7027b}},	//   capp, क्सि, _ehma, şmüş_,
   {{0xdd940104,0x6d580038,0x24890381,0x68fb00cc}},	//   _нары, ívat, _odam_, thud,
   {{0x7d095971,0x27ed02d0,0x27ff06a2,0x2369021e}},	//   _umes, tyen_, tzun_, _otaj_,
   {{0x23690221,0xe8f61112,0x7c3b2d08,0x69ce0093}},	//   _ntaj_, іль_, _uzur, _áben,
   {{0x27ed5972,0x458528a1,0xd7090086,0x3dc60035}},	//   ryen_, огов, рное_, łowe_,
   {{0x27ed5973,0x60c40409,0x7a4200b5,0x443200c3}},	//   syen_, ydim, ríté, _syy_,
   {{0x7a42006c,0x03a60086,0x7e7e325f,0x81df0033}},	//   síté, оимо, zapp, থনা_,
   {{0xdd0c004e,0x7a4200b5,0xe0df0284,0x7ccd0228}},	//   _późn, píté, _mhòd_, mērķ,
   {{0x36690202,0x61ee0392,0x66ff00b4,0x2489013b}},	//   _тако_, tybl, _ोगिक_, _edam_,
   {{0xd5ac0332,0x23695974,0x2cad5975,0x2d8701ba}},	//   _یہی_, _etaj_, _obed_, šnej_,
   {{0x4420006f,0x60c400d8,0x463a02b5,0x7e7e0bac}},	//   _txi_, udim, _דעצע, wapp,
   {{0x7e7e5976,0x44320159,0x8fa3107b,0x00000000}},	// [5540] tapp, _uyy_, мате, --,
   {{0xa3e70299,0x6d4001f4,0x23b300f8,0x20005977}},	//   पहर_, _shma, _کمیس, rzii_,
   {{0x7e7e43f5,0xbc6a03c7,0x6da35978,0x049300b5}},	//   rapp, لمان_, диха, _علیح,
   {{0x629c5979,0x60c400a8,0x2bca0370,0xe0df0284}},	//   lgro, qdim, илеп_, _chòd_,
   {{0x7e7e597a,0x387f1ba6,0x63a61b1c,0x8bb616e6}},	//   papp, daur_, ntkn, تصاص,
   {{0x629c597b,0x6b821511,0x6d58002a,0x99661353}},	//   ngro, rsog, ívas, отил,
   {{0x14ca0035,0x387f012f,0x6b820024,0xcb0700ce}},	//   ियाण, faur_, ssog, تيون_,
   {{0x6d5c597c,0x387f597d,0x37aa41f8,0x629c016e}},	//   _iura, gaur_, атон_, hgro,
   {{0x28a60567,0xd7fa2ad1,0x6d5c597e,0x629c1472}},	//   क्षि, руй_, _hura, kgro,
   {{0x3f92012f,0x7e7c0176,0x6bd70037,0x7bc0005f}},	//   iryu_, _jerp, _بوكس_, _ismu,
   {{0x6d5c597f,0xa2d90026,0x7e7c5980,0x248900e7}},	//   _jura, मास्, _merp, _pdam_,
   {{0x6d5c5981,0x30c50083,0x550701c8,0x629c313b}},	//   _mura, _এক্স, ічна, egro,
   {{0x6d5c5982,0x81af0083,0x38cb0609,0x3866016e}},	//   _lura, ওয়া_, _خالی_, _ifor_,
   {{0x28a6114e,0x2d87000c,0xf8a606fe,0x629c0345}},	//   क्रि, ánek_, क्रय, ggro,
   {{0x7ae8054e,0x38665983,0xa8ee01c0,0x00000000}},	//   _modt, _kfor_, _जवाफ_, --,
   {{0x63a401f4,0x7bc01b39,0x7ae85984,0x7e7c5985}},	//   _fqin, _osmu, _lodt, _aerp,
   {{0x7e7c1201,0x6d5c5986,0x28bd035d,0xdced00ea}},	// [5550] _berp, _aura, ्यति, ākļo,
   {{0x6d5c5987,0x7e7c0034,0x629c01da,0x539a0122}},	//   _bura, _cerp, cgro, _פיתו,
   {{0x7e7c0a8c,0x7bc0010b,0xcddb0274,0x31352519}},	//   _derp, _asmu, шња_, _неор,
   {{0x6d5c5988,0x7afa5989,0xe7bc112b,0x00000000}},	//   _dura, _altt, ्टाप, --,
   {{0x3af51ac5,0xe0df5790,0xa2d00099,0x7afa055c}},	//   зяйс, _fiòr_, दाच्, _bltt,
   {{0x6d5c598a,0x9b68010b,0x00000000,0x00000000}},	//   _fura, ішча_, --, --,
   {{0x6d5c598b,0x7bc001f7,0xe8df00e2,0x00000000}},	//   _gura, _esmu, _ngợm_, --,
   {{0x28bd09b1,0x629c598c,0x28a6258f,0xddc7023a}},	//   ्यधि, zgro, क्लि, _kejž,
   {{0x7f5d02e1,0x2d9e013c,0xfbbf017f,0x7ae80b3e}},	//   _jusq, _äter_, _एनिम, _fodt,
   {{0x6d5c0a4e,0x387f598d,0x7e6504f4,0x7ae800d4}},	//   _yura, saur_, nchp, _godt,
   {{0x6d5c598e,0xc8a600b4,0xd629081b,0x38660090}},	//   _xura, _कॉकट, соне_, _ffor_,
   {{0x629c598f,0x2ec80354,0x00000000,0x00000000}},	//   wgro, _रफ्त, --, --,
   {{0x629c4f47,0x08760070,0x81e80033,0xdb1b03d0}},	//   tgro, _זענט_, _মেং_, _bruø,
   {{0x254d00b8,0xfbbd0033,0x36c401e0,0x00000000}},	//   _měly_, _আপাত, _обіг, --,
   {{0x629c5990,0xbbb80302,0x867a00a5,0x5bb80ac4}},	//   rgro, _इन्क, _הרצו, _इन्व,
   {{0x6d5a1010,0x7f5d1b73,0x629c09a6,0xc0e33d56}},	//   _étai, _busq, sgro, носк,
   {{0x6d5c5112,0x629c5991,0xa2d90ed1,0x7f5d02d7}},	// [5560] _sura, pgro, माश्, _cusq,
   {{0x6d5c0a4e,0xdfcf0037,0xaec307fa,0x543600fd}},	//   _pura, ديك_, нбул, _ورکر,
   {{0x7e7c0b37,0xf8bd2095,0xa2d90d53,0x6d5c5992}},	//   _verp, ्याय, मार्, _qura,
   {{0x6d5c045e,0x409600c3,0x6fc955f5,0x7e7c1192}},	//   _vura, _эрот, रिशं, _werp,
   {{0x7e7c1201,0x6d5c3540,0x20570d85,0x60c608dd}},	//   _terp, _wura, _מיכל_, _iakm,
   {{0x6d5c5993,0x60c65994,0x98a400ea,0x254d00fe}},	//   _tura, _hakm, domā_, _děly_,
   {{0x2bb80035,0x6d5c4ab4,0x00000000,0x00000000}},	//   _इनका, _uura, --, --,
   {{0x61e1152c,0xae1b00a5,0x7ae3006d,0xc8fc0033}},	//   älli, _הולכ, ajnt, ুক্ত_,
   {{0x60c61cad,0x2d9a5701,0x69c101d7,0x387d00e5}},	//   _makm, lupe_, _esle, _dewr_,
   {{0xd6da4359,0x60c65995,0x25613bda,0x862603d4}},	//   сти_, _lakm, _ból_, зьме,
   {{0xf99246c5,0x2fc70023,0x2d9a0159,0xcfb70033}},	//   _سبا_, ̉ng_, nupe_, ুৎপন,
   {{0x3eba0223,0x00000000,0x00000000,0x00000000}},	//   hept_, --, --, --,
   {{0x395e01a3,0xa2d9012f,0xc8c71a95,0xb4cd02b4}},	//   _huts_, माल्, _روون_, _रफी_,
   {{0x66e32aca,0x28da0d1f,0x2d9a25ff,0xa15928cf}},	//   _поча, भावि, kupe_, жаву_,
   {{0x7f55022e,0x60c6027d,0x256105f6,0x2d9a0176}},	//   _rizq, _bakm, _gól_, jupe_,
   {{0x395e5996,0xd2500754,0x6ab9143a,0x2d9a5997}},	//   _muts_, انِ_, _इस्र, dupe_,
   {{0xe3b00088,0x60c6179a,0x395e00b9,0x00000000}},	// [5570] _یری_, _dakm, _luts_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d875998,0x7e655999,0x395e0f00,0x78a200ee}},	//   éne_, rchp, _nuts_, _ocov,
   {{0x7e65599a,0x6e3500ac,0x8c3d0395,0x00000000}},	//   schp, _vyzb, _obşt, --,
   {{0xfbab093c,0x7bc60124,0x395e02ee,0x00000000}},	//   стей_, _škur, _auts_, --,
   {{0x3eba49f7,0x395e00f7,0x60c60051,0x3dc60067}},	//   cept_, _buts_, _zakm, łowa_,
   {{0xa9c40037,0x2d9a00f7,0xceb20070,0x395e024b}},	//   فزيو, cupe_, _שיל_, _cuts_,
   {{0x6ca42076,0x25612ac4,0x28da0ac4,0x395e01f7}},	//   _пруж, _ról_, भाषि, _duts_,
   {{0x2561599b,0x752f0035,0x2903010b,0x7b190043}},	//   _sól_, docz, ėja_, _доар_,
   {{0x09bc00c8,0xca4800d1,0x2561599c,0x3eb1023a}},	//   _অপরা, _کلمه_, _pól_, _jbzt_,
   {{0x69c10274,0xf2120084,0x395e599d,0x00000000}},	//   _usle, _डेढ़_, _guts_, --,
   {{0x3eba01ae,0x6b890044,0x00000000,0x00000000}},	//   zept_, _kveg, --, --,
   {{0x290f0069,0x60c64c91,0xe72e1954,0x395e02a7}},	//   _imga_, _rakm, _ае_, _zuts_,
   {{0x78bb0009,0x25612c89,0x28bd05f7,0x853d010b}},	//   leuv, _tól_, ्यवि, ntėj,
   {{0x60c600d7,0xb0c90035,0x752f0035,0x00000000}},	//   _pakm, ाएंग, bocz, --,
   {{0x78bb599e,0x26c70010,0x69ce0099,0x6b890207}},	//   neuv, _hano_, थिती, _oveg,
   {{0x26c7599f,0xc32601af,0x03262374,0x3eba002d}},	// [5580] _kano_, _омик, _один, tept_,
   {{0x248059a0,0x2d9a59a1,0x26c759a2,0x68eb00e0}},	//   _heim_, tupe_, _jano_, _logd,
   {{0x26c759a3,0x60c659a4,0x6b8959a5,0x80a60035}},	//   _mano_, _takm, _aveg, _छापे,
   {{0x2d870132,0x26c700ac,0xc17300a5,0x3eba1202}},	//   ânea_, _lano_, _שחר_, sept_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf96a215e,0x27e00484,0x290f011e,0x78a259a6}},	//   орий_, _ħin_, _amga_, _scov,
   {{0x200d064b,0x68eb59a7,0xbea3179c,0x3da700af}},	//   _þeir_, _bogd, _шарк, _окро_,
   {{0xa3de000c,0x26c7073a,0x7cde0139,0x69343c96}},	//   णमा_, _aano_, _dărâ, رکار,
   {{0x68eb59a8,0x7d0201a2,0x26c701a8,0x200400a8}},	//   _dogd, mhos, _bano_, _ümid_,
   {{0x7d0259a9,0x752f0035,0x0b4300af,0x3ce65237}},	//   lhos, wocz, _анун, ljov_,
   {{0x248002bf,0x26c759aa,0x151500c3,0x75d40037}},	//   _beim_, _dano_, едня, ريحا,
   {{0x7d024a20,0x290f011e,0x38cb0594,0x2ebb0433}},	//   nhos, _gmga_, _وانی_, _उस्त,
   {{0x26c759ab,0x27e004d4,0x752f0035,0x8afd0355}},	//   _fano_, _çin_, rocz, _stři,
   {{0xf54a0028,0x2fc059ac,0x26c759ad,0xe60f09b9}},	//   _mấy_, dwig_, _gano_, اشی_,
   {{0xf54a0028,0x3946006d,0x92585451,0x752f0035}},	//   _lấy_, _khos_, дарт_, pocz,
   {{0x6441013b,0x00000000,0x00000000,0x00000000}},	//   əlin, --, --, --,
   {{0x741515f8,0x26c702b3,0x80a50355,0xf54a0023}},	// [5590] _سودا, _yano_, ङ्गे, _nấy_,
   {{0xf3ff0279,0x26c71702,0x8afd0355,0xa3be02b4}},	//   lcão_, _xano_, _kuře, ीटर_,
   {{0x6b8959ae,0x7d0259af,0xe2a70093,0x673a0051}},	//   _sveg, fhos, áður_, iltj,
   {{0x7d0259b0,0xf54a0023,0x2b5f0069,0xf3ff0183}},	//   ghos, _bấy_, _puuc_, ncão_,
   {{0xf54a0023,0x3f9b00a8,0x6ac80831,0x00000000}},	//   _cấy_, ququ_, লানো, --,
   {{0x68eb59b1,0x3946011e,0xdb1b0037,0x539c0317}},	//   _sogd, _ahos_, _tsuí, קסוא,
   {{0x7d0259b2,0x26c759b3,0x394601da,0xfe54010b}},	//   bhos, _rano_, _bhos_, _акрэ,
   {{0x26c759b4,0xc7c80028,0x6b8959b5,0x673a2193}},	//   _sano_, _bố_, _tveg, eltj,
   {{0x26c759b6,0xc7c801a5,0x39460221,0x78bb0248}},	//   _pano_, _cố_, _dhos_, reuv,
   {{0xeab00037,0x3ea159b7,0x6e2a0031,0x7cde0395}},	//   _نعم_, nght_, _ëmbë, _tărâ,
   {{0x3ea159b8,0x2bc70d91,0x6d5a0248,0x26c715a2}},	//   ight_, लिका, _état, _vano_,
   {{0xed59000c,0x290f0159,0x26c701a8,0x673a11cc}},	//   _již_, _umga_, _wano_, altj,
   {{0x394d59b9,0xdd0c006a,0x26c7000e,0x24800176}},	//   mmes_, _różn, _tano_, _veim_,
   {{0x394d59ba,0xb6a50036,0x0ece0026,0x00000000}},	//   lmes_, _чикл, _होंड, --,
   {{0x394d0443,0x28a6111b,0x8afd00fe,0x00000000}},	//   omes_, क्कि, _kuřb, --,
   {{0x7d020298,0x250800b5,0xafe601f5,0x273901cb}},	//   xhos, _زرعی_, нобл, dèni_,
   {{0x1e960185,0xc95200a5,0x291f59bb,0x00000000}},	// [55a0] ерер, רמן_, inua_, --,
   {{0xf8bd057c,0xe8bd022e,0x394d59bc,0x2fc059bd}},	//   ्युप, ्युच, hmes_, rwig_,
   {{0xf54a0023,0x2fc0033b,0x394d2791,0xe0da0279}},	//   _sấy_, swig_, kmes_, _евн_,
   {{0xa6de00e8,0xfd660023,0x3ea101ed,0x913601e0}},	//   _nhưn, _khuấ, aght_, _їхні,
   {{0x28c30567,0x21200528,0x99bc0083,0x7d0259be}},	//   वजनि, mnih_, _অপেক, rhos,
   {{0x212002dd,0xada600d8,0x7d0259bf,0xda661301}},	//   lnih_, _пагл, shos, راتي,
   {{0xc7c8098b,0x7d020082,0x39463c9d,0x6e433ab9}},	//   _số_, phos, _phos_, _берз,
   {{0x99d313cf,0x394d59c0,0xa6de00e2,0x6444030d}},	//   اتوا, gmes_, _chưn, _ozii,
   {{0xf76f00d1,0x7d00007c,0xf772381f,0x69dc0009}},	//   یای_, _ilms, داع_, _šred,
   {{0x09e61641,0x394d005f,0x7524023c,0x45d41d77}},	//   _позн, ames_, _ajiz, воос,
   {{0xceb30122,0x6444001c,0x212000f4,0x6723005f}},	//   אית_, _azii, knih_, _djnj,
   {{0x21200888,0xc7c801a5,0x3f89001e,0xe7860009}},	//   jnih_, _tố_, ysau_, _зуко,
   {{0x21200888,0x258600b8,0xf7f334d9,0xe0df009e}},	//   dnih_, _bílá_, _مسود, _bhòn_,
   {{0x02cb018d,0x644100a8,0xb7db076b,0x00000000}},	//   ायेन, əlil, _מקדי, --,
   {{0xa2c60f0d,0x2120082d,0x644459c1,0x00000000}},	//   ायज्, fnih_, _ezii, --,
   {{0x212002f6,0xa63b00a5,0xe63b00a5,0xb4db0392}},	//   gnih_, _מגור, _מתוכ, gmàt,
   {{0xa9230097,0x101700d1,0xe0df009e,0xed590116}},	// [55b0] ížil, ربرد, _fhòn_, _riž_,
   {{0x8e274b34,0x3ea10122,0x61e1013c,0x3f4d0009}},	//   нфед, ught_, älls, _ažur_,
   {{0x2120068b,0x62873e0e,0x3f8959c2,0x00000000}},	//   bnih_, majo, ssau_, --,
   {{0x5ce44b41,0x21202a9f,0x628759c3,0xa2d91ad0}},	//   люча, cnih_, lajo, माक्,
   {{0x60cd0269,0xfaa559c4,0x2cbd2ea2,0x60dd43c1}},	//   mdam, вало, rewd_, _insm,
   {{0x60cd59c5,0xe3b40070,0x7d005577,0x00000000}},	//   ldam, רױס_, _elms, --,
   {{0x60cd00d8,0xf2d40070,0x394d59c6,0x09e559c7}},	//   odam, טעס_, tmes_, тойн,
   {{0x60cd0d19,0x628759c8,0x6f1702d7,0x3cff00ee}},	//   ndam, hajo, lixc, _uluv_,
   {{0x394d59c9,0x5ef800b8,0xf7711062,0x66e50009}},	//   rmes_, _एवम्_, جاب_, вопа,
   {{0x212002dd,0x394d59ca,0x60cd59cb,0x628759cc}},	//   znih_, smes_, hdam, jajo,
   {{0x628759cd,0x60cd59ce,0x60dd0afc,0x00000000}},	//   dajo, kdam, _onsm, --,
   {{0x29041a25,0xdb1b06a2,0xb8150431,0xc3290319}},	//   chma_, _iruñ, _идеј, _וו_,
   {{0x212002dd,0x6d491093,0x60cd01a8,0x68e9003a}},	//   vnih_, _mhea, ddam, mjed,
   {{0x68e959cf,0xe6110e3a,0x60dd0260,0x28a72b22}},	//   ljed, _پشت_, _ansm, _गाडि,
   {{0x212002dd,0x5eca0083,0x6d4901b7,0x00000000}},	//   tnih_, রামে, _ohea, --,
   {{0x7fd60210,0x60cd59d0,0x68e951fc,0x68fb1998}},	//   кізі, gdam, njed, nkud,
   {{0x21200888,0x628759d1,0xfe72183b,0xb4db0443}},	// [55c0] rnih_, bajo, لدا_, rmàt,
   {{0x21201851,0x60cd01da,0x656300c3,0x6d49024b}},	//   snih_, adam, _kunh, _ahea,
   {{0x6d49003b,0x656300c9,0xe1260812,0x21200528}},	//   _bhea, _junh, _амни, pnih_,
   {{0x6d4959d2,0x656359d3,0xeb9a0009,0x6d5b0211}},	//   _chea, _munh, дид_, _ciua,
   {{0x6d4909e3,0x6d5b046a,0x26cc001e,0xdca31457}},	//   _dhea, _diua, yddo_, рачи,
   {{0x6d490107,0x69ce046c,0xfe4659d4,0x00000000}},	//   _ehea, थिली, _анго, --,
   {{0x65631a71,0x6d491093,0xe5670071,0xcec301c0}},	//   _nunh, _fhea, _خط_, ářů_,
   {{0x6d4904d6,0x68e901f4,0x6d5b009e,0x20040093}},	//   _ghea, gjed, _giua, _ýmis_,
   {{0xaae20378,0x7c3b00b5,0x6287081b,0x6e3c017b}},	//   पादक, _gyur, yajo, _hyrb,
   {{0x81b90083,0x60cd00c5,0x29040b26,0x7f5c0024}},	//   চিত_, zdam, shma_, _jirq,
   {{0xdb1b59d5,0x656359d6,0x68e90470,0x60cd59d7}},	//   _usuá, _cunh, bjed, ydam,
   {{0x65631a71,0xdddc01cc,0xb4bf0581,0x69c859d8}},	//   _dunh, _održ, ीये_, _isde,
   {{0xd706097c,0x628759d9,0x60cd59da,0x6563055c}},	//   _изди, tajo, vdam, _eunh,
   {{0xd5b000d1,0x656359db,0xb4db0176,0x2d9a00f4}},	//   _هفت_, _funh, gmàr, krpe_,
   {{0x36330105,0x33580043,0x30a70746,0x656302fc}},	//   _پروس, тарэ_, крав, _gunh,
   {{0x442959dc,0x628759dd,0x60cd0409,0xf3670036}},	//   _txa_, sajo, udam, _итон,
   {{0x6287254b,0x6d5b01f7,0xbed91018,0x14190079}},	// [55d0] pajo, _riua, ндах_, _سيدة_,
   {{0x60cd59de,0x7f5c000d,0xdf390037,0x656359df}},	//   sdam, _cirq, ركات_, _yunh,
   {{0x6d490094,0x628559e0,0x7c3b59e1,0x2492001e}},	//   _phea, _ieho, _syur, _ydym_,
   {{0xdd9401c8,0x6e3c59e2,0xada401e0,0x00000000}},	//   рацы, _dyrb, раїл, --,
   {{0x68e90c0a,0x62852243,0xeb9959e3,0x2d9a0036}},	//   vjed, _keho, хил_, arpe_,
   {{0x628559e4,0x93fc0070,0x6d4959e5,0x63ad0024}},	//   _jeho, ולדי, _whea, _mqan,
   {{0x3c930e3a,0x6d4901de,0x68e9012e,0xdddc571a}},	//   _نیاز, _thea, tjed, _zdrž,
   {{0x6d5a0248,0xb4bf021a,0x628559e6,0x7c2901d7}},	//   _étap, ीयो_, _leho, _txer,
   {{0x69c812c3,0x68e959e7,0x7b9900d1,0xa2d90355}},	//   _esde, rjed, _سپاس_, माञ्,
   {{0x68e959e8,0x62852eef,0x68fb59e9,0x65630279}},	//   sjed, _neho, skud, _punh,
   {{0x941e01c2,0xe0df009e,0x00000000,0x00000000}},	//   ətə_, _phòl_, --, --,
   {{0xf2c90100,0x5a0c02b5,0x97c527f6,0xdddc0139}},	//   _מע_, _קלאַ, _مقصو, _herţ,
   {{0x628559ea,0x48e00035,0x644100a8,0xe0df00e2}},	//   _beho, कारो_, əlik, _chòm_,
   {{0xe363465e,0x62850139,0xddde02c4,0x386d00f4}},	//   скри, _ceho, hapš, lcer_,
   {{0x628559eb,0x021900d4,0xd04f00a8,0xf53f0542}},	//   _deho, віть_, _incə, blå_,
   {{0x386d59ec,0x26000026,0xe0df009e,0x00000000}},	//   ncer_, शनरी_, _cnò_, --,
   {{0xafe30665,0x61430166,0x7f5c02d7,0x00000000}},	// [55e0] ботл, сета, _pirq, --,
   {{0x628559ed,0x28da0026,0x6d4300a2,0x82360d93}},	//   _geho, _मोनि, înan, _مرجا,
   {{0xaae20355,0x00000000,0x00000000,0x00000000}},	//   पासक, --, --, --,
   {{0x163602b5,0xd24f0088,0x7e4b00b5,0x628501ed}},	//   אנער_, _ژنی_, رسلہ_, _zeho,
   {{0x925a00bf,0xdddc053d,0xaff5006c,0x628559ee}},	//   _تشکر_, _udrž, _پہلا_, _yeho,
   {{0x69c80042,0x386d0183,0x3f8200ee,0xbb830037}},	//   _psde, ecer_, _iwku_, حلوي,
   {{0x14aa00a1,0x7bc90395,0x690701ed,0x5eca0033}},	//   _काढण, _eseu, _oñed, রাদে,
   {{0xed5712a2,0x6b4401f7,0xdbca00be,0x395d099e}},	//   _бос_, cògn, _sõõr, _ciws_,
   {{0x1d070086,0x9985004b,0x00000000,0x00000000}},	//   _сети_, _bylų_, --, --,
   {{0x569400ed,0x35b41102,0x00000000,0x00000000}},	//   јант, абор, --, --,
   {{0xe8142188,0x628559ef,0xdbca007c,0x8f370070}},	//   _तेरा_, _reho, _võõr, רטיג_,
   {{0x386d59f0,0x2ca603be,0x69170043,0x628500fd}},	//   ccer_, ngod_, nţel, _seho,
   {{0x3eb81635,0x62850a66,0xab00008d,0x00000000}},	//   _obrt_, _peho, _þjóð_, --,
   {{0xf53f2895,0x59b801d1,0x00000000,0x00000000}},	//   slå_, _आहार, --, --,
   {{0x628559f1,0x00000000,0x00000000,0x00000000}},	//   _veho, --, --, --,
   {{0xa2d900b8,0x2eff00a2,0xa07503d0,0x26ce007e}},	//   माङ्, _œuf_, ргач, _hafo_,
   {{0x628559f2,0x3f15010b,0xa2951958,0x351c0d85}},	// [55f0] _teho, адас, _капі, _רוחנ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8afc004e,0xddde0207,0x7bc90345,0x00000000}},	//   _międ, tapš, _sseu, --,
   {{0x1c1600ab,0x00000000,0x00000000,0x00000000}},	//   _देहल_, --, --, --,
   {{0x6a85081b,0x2b5e009e,0xa92700d5,0x92e70033}},	//   алла, _bitc_, _ležé, পসী_,
   {{0x60cf59f3,0x26ce59f4,0x7bc9023a,0x794c0345}},	//   _hacm, _nafo_, _vseu, hûwd,
   {{0x7e74006c,0x53380070,0x1af90033,0xa2ad0577}},	//   _چاہئ, אנגן_, ্চলে_, _जान्,
   {{0x386d0211,0x60cf59f5,0x1c1629ad,0x00000000}},	//   ucer_, _jacm, _देवल_, --,
   {{0x60cf59f6,0x2f04013c,0x2ca059f7,0x394300ea}},	//   _macm, _höga_, óide_, ējs_,
   {{0xc987395b,0x386d03e6,0x46f50043,0x28a7000c}},	//   _буди, scer_, рчит, _गावि,
   {{0xa50a0896,0x26ce01ef,0xe0df021e,0x8afc0067}},	//   вена_, _dafo_, _chòk_, _sięg,
   {{0x69dc0aca,0x27e002c4,0xc8c80647,0x7dd000b5}},	//   _área, _šine_, _مومن_, lósá,
   {{0x888c02b5,0x7ae10051,0xa6c9326d,0xdddc023a}},	//   _טראַ, _knlt, _алла_, _merš,
   {{0x39ae00a8,0xaaa906fe,0xd336002d,0x26ce099e}},	//   _səsi_, च्चक, рэмы, _gafo_,
   {{0x216a0812,0x00000000,0x00000000,0x00000000}},	//   тиби_, --, --, --,
   {{0x61e1022a,0x602659f8,0x6448013b,0x00000000}},	//   ålla, адба, ədin, --,
   {{0x8fa6014d,0x1e861303,0x8e860421,0x00000000}},	// [5600] разе, илам, игае, --,
   {{0xbe85004f,0x2fcb0815,0x2f040282,0x27e014a0}},	//   مجمو, _dscg_, _böga_, _áine_,
   {{0xdddc0009,0x4aa9021a,0x127b0070,0x729b00a5}},	//   _berš, च्छव, _שאטע, _בסיס,
   {{0x8fa659f9,0x2b5e59fa,0x00000000,0x00000000}},	//   _каме, _sitc_, --, --,
   {{0xaae2000c,0xa2ad021a,0x2b5e00d7,0x2ca63c42}},	//   पालक, _जाम्, _pitc_, rgod_,
   {{0x60c459fb,0x2ca600e9,0x99d60037,0x2f04017b}},	//   leim, sgod_, لتعا, _föga_,
   {{0x7945006a,0x2ca60159,0x26ce0207,0x00000000}},	//   równ, pgod_, _rafo_, --,
   {{0x60c459fc,0xdca30eb4,0x940c00a8,0xdddc023a}},	//   neim, _маси, şdə_, _gerš,
   {{0xfaa60ffd,0x6d42055c,0x26ce030d,0x00000000}},	//   _вазо, mloa, _pafo_, --,
   {{0x60c414ca,0xd6da110a,0x6d4259fd,0x00000000}},	//   heim, тти_, lloa, --,
   {{0x3ed902b5,0x4ed90070,0xa2c50355,0x5ed90070}},	//   אַרא, אַרנ, ाजस्, אַרװ,
   {{0x69da06a2,0x61fc0d51,0x250900f8,0x00000000}},	//   _irte, dyrl, اردی_, --,
   {{0xd70a0812,0x29060421,0x442d59fe,0x60c44749}},	//   _инде_, _iloa_, çe_, deim,
   {{0x81c30080,0x656603fa,0x28da14ab,0x47330118}},	//   ņēmu, _књиж, _मोति, _وروز,
   {{0x28bd022e,0x6d4201a3,0xdbd10093,0x31680279}},	//   ्यचि, kloa, _lýðr, ишто_,
   {{0x6d42002d,0x69da59ff,0x00000000,0x00000000}},	//   jloa, _mrte, --, --,
   {{0xa1585a00,0x6e6743f0,0x6d420065,0x00000000}},	// [5610] рату_, атеж, dloa, --,
   {{0xa8570122,0xc43c00a5,0x29060176,0x73fa016b}},	//   שימה_, _בתחי, _lloa_, _תּקו,
   {{0xdddc5a01,0x23695a02,0x28a705e7,0x68e20103}},	//   _perš, _huaj_, _गालि, _onod,
   {{0x2369006f,0x60c40312,0x657a0098,0x68e401da}},	//   _kuaj_, ceim, ipth, _òidh,
   {{0x69da1024,0x24890176,0x236900da,0xee870086}},	//   _arte, _meam_, _juaj_, _выбо,
   {{0x23691020,0x68e25a03,0x8d770df3,0x248901a6}},	//   _muaj_, _anod, _نارا, _leam_,
   {{0x23690189,0xa3a93893,0x6ef301c0,0x29060009}},	//   _luaj_, खंड_, _výbě, _bloa_,
   {{0x24890395,0x6d420bf7,0x77855a04,0x6d34002d}},	//   _neam_, cloa, близ, _десф,
   {{0x69da5a05,0x23690107,0xe7390f94,0xe0df00cc}},	//   _erte, _nuaj_, леи_, _chòi_,
   {{0x7c240079,0x68e25a06,0x959700af,0xd7060421}},	//   úire, _enod, аӂиу_, йные_,
   {{0x24895a07,0x00000000,0x00000000,0x00000000}},	//   _beam_, --, --, --,
   {{0x7bdb1e0d,0xb0d600b4,0x60c401ef,0x2fc90345}},	//   _kruu, _ढोंग, xeim, kwag_,
   {{0x387f1e07,0x23690221,0xb4c8004e,0x61e1013c}},	//   mbur_, _cuaj_, _उसी_, ålln,
   {{0x23695a08,0x777b01dd,0xa2ad00a1,0x64480095}},	//   _duaj_, mpux, _जाण्, ədil,
   {{0x6d42043d,0x60c45a09,0x00000000,0x00000000}},	//   yloa, teim, --, --,
   {{0x78a93102,0x26c50b4c,0x2369006d,0x387f0069}},	//   ngev, lelo_, _fuaj_, nbur_,
   {{0x60c45a0a,0x2fc9334c,0x00000000,0x00000000}},	// [5620] reim, gwag_, --, --,
   {{0x26c50f08,0xb33b01d6,0x2cad0176,0x6d4200e2}},	//   nelo_, nuçl, _aced_, wloa,
   {{0x628e5a0b,0xa2ad0808,0x236901e8,0x25a505b9}},	//   mabo, _जात्, _zuaj_, null_,
   {{0x26c54903,0x236901e8,0x2fc90008,0x7bdb38b9}},	//   helo_, _yuaj_, bwag_, _bruu,
   {{0x26c55a0c,0x2369006d,0x78a919c1,0x25a55a0d}},	//   kelo_, _xuaj_, dgev, hull_,
   {{0x26c5029d,0x628e5a0e,0xe8e006fe,0x25a55a0f}},	//   jelo_, nabo, पञ्च, kull_,
   {{0x7bdb018e,0x00000000,0x00000000,0x00000000}},	//   _eruu, --, --, --,
   {{0x628e5a10,0x78a95a11,0xa7742349,0x69da008b}},	//   habo, ggev, олич, _vrte,
   {{0x7d025a12,0x628e5a13,0x7bdb3784,0x63a609e7}},	//   mkos, kabo, _gruu, jukn,
   {{0x23695a14,0x25a55a15,0x63a6005d,0x26c55a16}},	//   _ruaj_, full_, dukn, gelo_,
   {{0xd6d7342d,0x69da03cb,0x628e5a17,0x25a55a18}},	//   сты_, _urte, dabo, gull_,
   {{0x7d025a19,0x236901e8,0x07a65a1a,0x68e25a1b}},	//   nkos, _puaj_, _гадн, _unod,
   {{0x14aa09a8,0x2369006f,0x26c55a1c,0xf09f009e}},	//   _कारण, _quaj_, belo_, _blàn_,
   {{0x26c55a1d,0x628e5a1e,0x25a55a1f,0x7d025a20}},	//   celo_, gabo, bull_, hkos,
   {{0x24890b2f,0x25a50443,0x41e41958,0x7d025a21}},	//   _team_, cull_, піта, kkos,
   {{0x23690d4b,0x673a0443,0x628e0430,0xa2d90518}},	//   _tuaj_, lotj, aabo, _फोर्,
   {{0x752d02c2,0x628e5a22,0x63a6028b,0x673a0051}},	// [5630] _ijaz, babo, cukn, ootj,
   {{0x628e5a23,0x2fc90173,0x644d5a24,0x7d0236a1}},	//   cabo, rwag_, _izai, ekos,
   {{0x2fc9043d,0x7bc004ff,0x7d0201bf,0x00000000}},	//   swag_, _apmu, fkos, --,
   {{0x30a70086,0x26c50817,0x7bdb00ab,0x3ce41628}},	//   _уров, zelo_, _pruu, _cnmv_,
   {{0x26c50430,0x25a50055,0x752d034d,0x161a021a}},	//   yelo_, zull_, _mjaz, _फेसर_,
   {{0x38660297,0x499907b4,0x26c5092e,0x2cad0345}},	//   _agor_, атия_, xelo_, _wced_,
   {{0x26c50202,0x78a90244,0x28da0ca1,0x198602fb}},	//   velo_, tgev, _मोहि, общи_,
   {{0xb4c8006a,0x628e5a25,0xe8f90272,0x26c532b4}},	//   _उसे_, zabo, рли_, welo_,
   {{0x387f44d1,0x78a90a75,0x7c842e50,0x656a01ae}},	//   rbur_, rgev, _хусе, _aufh,
   {{0x80d20083,0x7d090009,0x25a55a26,0x78a903c4}},	//   হায্, _hles, tull_, sgev,
   {{0x8afc0755,0x628e5a27,0x26c55a28,0xe4c64ae6}},	//   _więc, vabo, relo_, ойни,
   {{0x63a65a29,0x26c503e0,0x628e5a2a,0x25a55a2b}},	//   tukn, selo_, wabo, rull_,
   {{0x80d20083,0x26c55a2c,0x752d02d0,0x7d1b001c}},	//   হাম্, pelo_, _djaz, _mmus,
   {{0x27ff067f,0x25a501f4,0x63a65a2d,0x7d095a2e}},	//   myun_, pull_, rukn, _lles,
   {{0x628e5a2f,0x63a60ec0,0x7d1b09d6,0x39ae0095}},	//   rabo, sukn, _omus, _həsr_,
   {{0xdfd20ef2,0x69c15a30,0xb1461112,0x63a6501c}},	//   ويز_, _mple, інал, pukn,
   {{0xef1a5a31,0x628e5a32,0x4fea12a2,0x00000000}},	// [5640] ама_, pabo, шман_, --,
   {{0x7d095a33,0x69c15a34,0x27ed12c3,0x752d458c}},	//   _ales, _ople, ixen_, _zjaz,
   {{0x6f1e5a35,0x7d025a36,0x69c10221,0x7dc6183b}},	//   ripc, tkos, _nple, تقان,
   {{0xf7670b82,0xdd8f5a37,0x7643001e,0x7d095a38}},	//   _يا_, ئون_, _myny, _cles,
   {{0x7d025a39,0x6b4412c3,0x69c15a3a,0x60d6010b}},	//   rkos, lògi, _aple, mdym,
   {{0x60d600d8,0x7d1b5a3b,0x7d095a3c,0x69c10079}},	//   ldym, _emus, _eles, _bple,
   {{0xa2ad02cb,0xf98f00ad,0x25a80066,0xd90d03c5}},	//   _जास्, نبي_, _कमेण, گین_,
   {{0xd7c800bf,0x60d6010b,0xdcfc0254,0x7d090523}},	//   موعه_, ndym, _tvrđ, _gles,
   {{0xd90d0357,0x2ef80afc,0x27ff0159,0x656a0223}},	//   دین_, _korf_, gyun_, _sufh,
   {{0x212900f4,0x7d1b0067,0x28da046c,0x2ef800a2}},	//   znah_, _zmus, _मोरि, _jorf_,
   {{0x7643001e,0x77630051,0x673a5a3d,0x65640103}},	//   _cyny, _dinx, rotj, _biih,
   {{0x290d5a3e,0xe9ff0019,0x37e600c3,0x657500b5}},	//   chea_, _hiếm_, _моег, ízha,
   {{0xe9ff0028,0x8d5b02b5,0x77630042,0x60d6016e}},	//   _kiếm_, יכטי, _finx, ddym,
   {{0x9943027d,0x764300e9,0x356a00af,0x2ef80069}},	//   _kış_, _fyny, _крин_, _norf_,
   {{0x32052eef,0x212900d6,0x76435a3f,0x64b30355}},	//   ály_, tnah_, _gyny, _přič,
   {{0xf8bc0035,0x752d2875,0x644d01a3,0x77630031}},	//   ्जिय, _ujaz, _tzai, _zinx,
   {{0x21291201,0xc05b02ce,0x644d00ea,0x32050355}},	// [5650] rnah_, рів_, _uzai, šly_,
   {{0x21293ae0,0x79450035,0x753d5a40,0x7d09149d}},	//   snah_, tówk, losz, _sles,
   {{0x2d875a41,0x2ef85a42,0xe0df0284,0xf8bc07df}},	//   ène_, _dorf_, _bhòt_, ्जाय,
   {{0x753d2130,0x27ff028b,0xe0df009e,0x79450035}},	//   nosz, yyun_, _chòt_, rówk,
   {{0x35cc0243,0x999e00b8,0x69c156fa,0xe9ff00e2}},	//   ़बड़, _bytů_, _sple, _biếm_,
   {{0x7945004e,0x6d405a43,0xeb961b50,0xa96905ac}},	//   mówi, _ekma, чиш_, бика_,
   {{0x753d5a44,0x8afd00fe,0x00000000,0x00000000}},	//   kosz, _juři, --, --,
   {{0x7763043f,0x7d1b070b,0x6ca45a45,0x9943027d}},	//   _sinx, _umus, _оруж, _dış_,
   {{0x5b1516ac,0x6d5925e8,0x65640421,0x47c20421}},	//   _емат, mmwa, _riih, ебыв,
   {{0x656403ad,0x2904010d,0x290d002f,0xd7090c9d}},	//   _siih, akma_, shea_, сное_,
   {{0x69c100cd,0x27ff41fa,0x00000000,0x00000000}},	//   _uple, syun_, --, --,
   {{0x6b892107,0x753d006c,0x9cf90033,0x3e160070}},	//   _kweg, gosz, _আগুন_, פֿיל_,
   {{0x43750948,0x65640086,0x77635a46,0x00000000}},	//   дуст, _viih, _tinx, --,
   {{0x6b89313a,0x8afd00fe,0xe6890037,0xd066013b}},	//   _mweg, _buři, _انثى_, əqəl,
   {{0x67215a47,0xa2ad0066,0x6b89073a,0xcaf40099}},	//   milj, _जार्, _lweg, _अवघड_,
   {{0x6f1c0124,0x00000000,0x00000000,0x00000000}},	//   _smrc, --, --, --,
   {{0x44260279,0x60d607b1,0x5c260831,0x00000000}},	// [5660] _ão_, rdym, _বর্গ_, --,
   {{0xe0df0260,0x67215a48,0x9f5f008d,0xb4cc00b4}},	//   _akòd_, nilj, órða_, _रघु_,
   {{0x02fb011d,0x42fb00a5,0x6b89030d,0x291d0103}},	//   _הלימ, _ההיס, _aweg, _omwa_,
   {{0xccf9004e,0x61e1054e,0xc8da0722,0x656e0037}},	//   _coś_, ælle, _मोंट, íbhi,
   {{0x1c16007c,0x672129fc,0x2ef81032,0xead411c5}},	//   _देखल_, kilj, _torf_, доль,
   {{0x291d0107,0x6d59030d,0x672100f4,0x3f800409}},	//   _amwa_, amwa, jilj, mpiu_,
   {{0x67212bc6,0x99d30037,0x3f8001ef,0x9943013b}},	//   dilj, فتيا, lpiu_, _qış_,
   {{0x8b661d05,0x68f90103,0xdc3c0097,0x2d680395}},	//   _فاطم, _cowd, _háčk, _eşec_,
   {{0xed5709cc,0x67215a49,0x6b895a4a,0x6ef20d51}},	//   _хот_, filj, _gweg, _sæby,
   {{0x8b650312,0x95ca5a4b,0x9f9b033b,0x67210009}},	//   _قالم, бума_, _läßt_, gilj,
   {{0x7ae8054e,0xd90f01c8,0xfaa3004b,0xe947006c}},	//   _indt, _зь_, _чахо, _کرلی,
   {{0x7afa2b25,0xdc3c00fe,0x00000000,0x00000000}},	//   _hott, _láčk, --, --,
   {{0x67215a4c,0x753d3a5f,0x7afa5a4d,0x66e60dba}},	//   bilj, rosz, _kott, _нода,
   {{0x6721029d,0x7afa5a4e,0x660100ac,0x2d980b3e}},	//   cilj, _jott, bylk, _ovre_,
   {{0x31c45a4f,0x2d9c0370,0x7afa02ce,0x76bb0122}},	//   нств, ável_, _mott, _המופ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88bd0035,0x403400c3,0x9f0400fd,0xd5b800ea}},	// [5670] liśc, еетс, کولو, ltā_,
   {{0x7afa01d3,0x6b890232,0x427507f2,0xdce00009}},	//   _nott, _rweg, _югос, _dimč,
   {{0xd5b800ea,0x6b890067,0x6441048f,0x88bd1140}},	//   ntā_, _sweg, şlid, niśc,
   {{0x67211bd8,0xd5b800ea,0xb3b100b4,0x00000000}},	//   zilj, itā_, _जमाख, --,
   {{0x7afa5a50,0x2d985a51,0xbfa800af,0x00000000}},	//   _bott, _evre_, _нтре_, --,
   {{0xd5b80029,0xaa880037,0x7afa5a52,0x6ea700b4}},	//   ktā_, كنهم_, _cott, _चाटु,
   {{0x7afa5a53,0x68f92852,0x9e34002d,0x2d980103}},	//   _dott, _powd, _зерч, _gvre_,
   {{0x7ae84371,0x2cbf012f,0x290b0079,0xa3cd07b5}},	//   _endt, _ubud_, óca_, रबा_,
   {{0x3cf00187,0x67215912,0x7afa1b50,0x2d9e013c}},	//   ťové_, tilj, _fott, _åter_,
   {{0x7afa5a54,0xd75600b5,0x1dd1258f,0x667300d1}},	//   _gott, وليت_, _सनात, رگتر,
   {{0x672147ff,0x64a62861,0xe81d007c,0xcb1200a5}},	//   rilj, мана, _बेरा_, _שלב_,
   {{0x67210888,0xb9250cd1,0x92ea0033,0x291d0027}},	//   silj, _تفصي, _মতে_, _umwa_,
   {{0x67210024,0x00000000,0x00000000,0x00000000}},	//   pilj, --, --, --,
   {{0x2bc00299,0xf6250166,0x88bd0035,0x00000000}},	//   _एहसा, _одло, biśc, --,
   {{0x61465a55,0xc7b900b5,0x443e0067,0xc5d501e0}},	//   дева, ltő_, łt_, _ціль,
   {{0xdb025a56,0x70a80099,0xdc3c0097,0xd01200b5}},	//   troë, गलेल, _sáčk, نلز_,
   {{0xc7b9006c,0xdc3c00ac,0x4aae0099,0xe0df0211}},	// [5680] ntő_, _páčk, _घालव, _phòr_,
   {{0x2bd40084,0x8fa30810,0x3f8000c7,0x00000000}},	//   _धनबा, тафе, rpiu_, --,
   {{0x8236006c,0xa06a5a57,0xdd8f0c26,0x00000000}},	//   _زردا, _мана_, لول_, --,
   {{0x0c2603ad,0x7afa07c9,0x6c8304a3,0xb80d00be}},	//   ммен, _sott, پلوم, िनाम_,
   {{0xe7d80083,0x28a70461,0xe81d21a8,0xeb973810}},	//   _তথ্য, _गाजि, _बेला_, дич_,
   {{0x7afa0069,0x00000000,0x00000000,0x00000000}},	//   _qott, --, --, --,
   {{0x2d6801d6,0x28bc06fe,0x7afa0093,0x2d9800a2}},	//   _eğer_, ्जलि, _vott, _uvre_,
   {{0x92ea00c8,0xa02201d6,0xf1b3024b,0x00000000}},	//   _মতো_, _şöyl, דסה_, --,
   {{0xb8d60325,0x629e1298,0x7afa5a58,0x88bd004e}},	//   _जा_, _odpo, _tott, wiśc,
   {{0x35f40b46,0x7ae808c8,0xabfb00a5,0xa7b500fd}},	//   епор, _undt, _והמר, ڈشیڈ,
   {{0x6b820345,0x00000000,0x00000000,0x00000000}},	//   lpog, --, --, --,
   {{0xd5b80029,0x27e90009,0x2eea021d,0xa8063464}},	//   rtā_, _šane_, _lnbf_, _озел,
   {{0xd5b80029,0x00000000,0x00000000,0x00000000}},	//   stā_, --, --, --,
   {{0x17540b7d,0x65941bdf,0xd70302fb,0xd5b800ec}},	//   _явля, _заку, _изчи, ptā_,
   {{0x26cc0453,0x00000000,0x00000000,0x00000000}},	//   medo_, --, --, --,
   {{0x26cc22d3,0x6ec106d9,0x690702d7,0x656e0098}},	//   ledo_, र्नु, _añej, íbhu,
   {{0x6b8203ab,0x6f0e00ac,0x9f5548da,0x00000000}},	// [5690] jpog, _blbc, евач, --,
   {{0xb0df065a,0x741600e0,0x3ed50037,0x00000000}},	//   _पोरग, _سوپا, عقار, --,
   {{0x4ad9021a,0xaad906fe,0x00000000,0x00000000}},	//   _योगव, _योगक, --, --,
   {{0xa3d60722,0x399a00ea,0x2d8100a2,0xa2bb143a}},	//   _सनम_, dīs_, rphe_, श्र्,
   {{0x60cd5a59,0x26cc5a5a,0x3f790070,0x50645212}},	//   meam, kedo_, _מאָס, _атра,
   {{0x62950657,0x60cd0a32,0x26cc003d,0xba750118}},	//   nazo, leam, jedo_, راتت,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60cd5a5b,0x62955a5c,0x7b140176,0xe7bd0067}},	//   neam, hazo, _nàuf, ्बलप,
   {{0x62955a5d,0xf7712604,0x7d0400c3,0x20040225}},	//   kazo, داب_, öise, _ümit_,
   {{0x6d4b5a5e,0x60cd066a,0x6b9b0010,0x45850217}},	//   llga, heam, _ivug, нгов,
   {{0x62955a5f,0x6ec10bad,0x60cd0421,0x00000000}},	//   dazo, र्यु, keam, --,
   {{0x29d10124,0x00000000,0x00000000,0x00000000}},	//   _iša_, --, --, --,
   {{0xe72e075c,0x60cd5a60,0x26cc5a61,0xb8072149}},	//   _бе_, deam, bedo_, _تباه,
   {{0x6ec10246,0x26cc09ca,0x62955a62,0x6b9b01d5}},	//   र्मु, cedo_, gazo, _mvug,
   {{0xa18a0021,0xa50a16c0,0x68eb0118,0x00000000}},	//   ябва_, _нека_, _kngd, --,
   {{0x61e1054e,0x644101ae,0x60cd4420,0x644000be}},	//   ælla, ßlic, geam, ümis,
   {{0x8fa3233a,0x4fa31654,0xb4cc0253,0x62950371}},	// [56a0] лате, литв, रजी_, bazo,
   {{0x5f462149,0x629502d7,0x6d4b3456,0x00000000}},	//   رنال, cazo, elga, --,
   {{0x6b9b0232,0x60cd1b4a,0x7bde00ea,0xdcf40ce9}},	//   _avug, beam, āpum, šači,
   {{0xc8ae0084,0xe5720070,0x6ec1022e,0x00000000}},	//   _टाइट, אַס_, र्बु, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290f2b26,0x399a0029,0x68eb1fd9,0x6d4b5a63}},	//   _alga_, tīs_, _angd, alga,
   {{0x26cc5a64,0x13c90083,0x6b820228,0x9966516d}},	//   vedo_, শিয়, spog, нтил,
   {{0xa9675a65,0xdb025a66,0xdcfe00ea,0x2d9a021d}},	//   нија_, croî, rspē, mspe_,
   {{0x26cc5a67,0x399a00ea,0x62955a68,0x752601ed}},	//   tedo_, sīs_, yazo, dikz,
   {{0x68eb5a69,0x8afc0035,0xb33b0225,0x00000000}},	//   _engd, _mięk, nuçt, --,
   {{0x62955a6a,0x60cd002f,0x1a9b0070,0xdb0b0118}},	//   vazo, yeam, _זיבע, dugè,
   {{0x26cc5a6b,0x2ca00037,0xa3cd5a6c,0x62950e4e}},	//   sedo_, óidh_, रबल_, wazo,
   {{0x04670086,0x62955a6d,0xdceb011c,0xd49800af}},	//   этом, tazo, šići, эрэ_,
   {{0x6d4200be,0x00000000,0x00000000,0x00000000}},	//   hooa, --, --, --,
   {{0x623400af,0x60cd5a6e,0xdb025a6f,0x6d4201ed}},	//   геру, team, ntoñ, kooa,
   {{0x62955a70,0xdddc0f27,0x00000000,0x00000000}},	//   sazo, _berž, --, --,
   {{0x62955a71,0xf8c2057c,0x60cd4c34,0xbfa800af}},	// [56b0] pazo, व्यय, ream, етхе_,
   {{0x60cd5a72,0x69c85a73,0xdddc023a,0xdb1b0225}},	//   seam, _opde, _derž, _ipuç,
   {{0x6b9b003a,0x63bd462c,0x60cd5a74,0x63af0e31}},	//   _svug, ltsn, peam, lucn,
   {{0x394601e8,0x764a001e,0xeb0905f7,0xc0ab0037}},	//   _nkos_, _myfy, वस्त_, _عاجل_,
   {{0x4ea704bf,0x69c85a75,0xdc3b0069,0xbec700ec}},	//   _прва, _apde, _bàġi, _adīš,
   {{0xfe700125,0x9f3502ce,0xaa4901fd,0x4ea7022b}},	//   _هدف_, _регі, мпла_, _ярма,
   {{0x9f3401e0,0xae1e00a1,0x8f3401e0,0x7c2d0093}},	//   _сері, _येऊन_, _серц, úarb,
   {{0x69a20d53,0x22451dab,0x00000000,0x00000000}},	//   _गिरी, ýlky_, --, --,
   {{0x6b9b0010,0x63af030a,0x00000000,0x00000000}},	//   _uvug, jucn, --, --,
   {{0xa2ad1856,0x63af5a76,0xb8e80026,0x3946220d}},	//   _जाग्, ducn, _लॉ_, _ekos_,
   {{0x290f0dc3,0x3cff0009,0x764a001e,0x270107b5}},	//   _tlga_, _kouv_, _cyfy, _लकीर_,
   {{0x68eb0b87,0xb4ac5a77,0x2f04013c,0x2d470279}},	//   _ungd, खले_, _högt_, mões_,
   {{0x2d470279,0x63af011c,0x395f00b9,0x394d5a78}},	//   lões_, gucn, mmus_, mles_,
   {{0x394d5a79,0x395f5a7a,0x764a00e9,0x2be2012f}},	//   lles_, lmus_, _fyfy, पिता,
   {{0x320c024e,0x764a00e9,0x63bd02a2,0x2d47021d}},	//   ády_, _gyfy, atsn, nões_,
   {{0x8afc004e,0xdddc00d8,0x25de1b8f,0x394d01dd}},	//   _pięk, _perž, गिरी_, nles_,
   {{0x394d259e,0x752401d5,0x2d470132,0x395f5a7b}},	// [56c0] iles_, _imiz, hões_, imus_,
   {{0x395f5a7c,0x00000000,0x00000000,0x00000000}},	//   hmus_, --, --, --,
   {{0x8afc004e,0x394d5a7d,0x2d9c00fd,0xe0df0260}},	//   _więk, kles_, éve_, _ikòn_,
   {{0x2d470132,0xdca6021d,0x6da35a7e,0x63a903e0}},	//   dões_, тади, рица, šene,
   {{0x2f040093,0xdd0c0035,0x6bd30079,0x7524030d}},	//   _sögu_, _półn, لتور, _mmiz,
   {{0x394d0bc8,0xf9c60d13,0x394647c2,0x69c80042}},	//   eles_, вщин, _skos_, _ppde,
   {{0x2d470132,0x2bd40066,0x75245a7f,0x6c860037}},	//   gões_, _धनवा, _omiz, _للأم,
   {{0x395f30bc,0xa2a20b35,0x31600107,0x3cff30e9}},	//   gmus_, कृत्, nmiz_, _gouv_,
   {{0xab665a80,0x1dda00b4,0xb4db0176,0x00000000}},	//   _авал, णिकत, ilàt, --,
   {{0x394d5a81,0x75245a82,0x7d005a83,0x395f5a84}},	//   ales_, _amiz, _homs, amus_,
   {{0xd6d702ee,0x394d5a85,0xceb30122,0x7d005a86}},	//   тты_, bles_, בית_, _koms,
   {{0x394d5a87,0xdcfc00cd,0x75240124,0x98a31e46}},	//   cles_, _otrč, _cmiz, _вице,
   {{0x7d001be0,0x693100f8,0x3944010b,0x27e05a88}},	//   _moms, _دکور, moms_, _éin_,
   {{0x7d00006d,0x63af0506,0x39445a89,0x629a0a20}},	//   _loms, rucn, loms_, ótop,
   {{0x57570122,0xa3e30066,0x67280024,0x4ac40d91}},	//   _שבוע_, _नज़र_, midj, ल्यव,
   {{0x26dc02a2,0x39445a8a,0x51840009,0xe1340409}},	//   _havo_, noms_, рура, ансы,
   {{0x2d470279,0x26dc5a8b,0x63a90009,0x27e60118}},	// [56d0] zões_, _kavo_, šenb, _jron_,
   {{0x3f144ae6,0x395f4b1d,0x3f9b5a8c,0x7524031d}},	//   адус, zmus_, rsqu_, _zmiz,
   {{0x8d740dc0,0x39445a8d,0x395f5a8e,0x2d4703e6}},	//   لانا, koms_, ymus_, xões_,
   {{0x26dc0036,0x39442791,0x27e60523,0x644d0118}},	//   _lavo_, joms_, _oron_, _kyai,
   {{0x212938bf,0x39445a8f,0xfaa55a90,0x7d0010dd}},	//   miah_, doms_, гало, _doms,
   {{0x21291034,0x2d470279,0x26dc12ba,0xf1c70099}},	//   liah_, tões_, _navo_, _लहान,
   {{0x27e62922,0x60dd5a91,0x395f05f6,0x394d5a92}},	//   _aron_, _kasm, tmus_, tles_,
   {{0x27e65a93,0x21290e9c,0x2d470279,0x394d5a94}},	//   _bron_, niah_, rões_, ules_,
   {{0x20095a95,0x2d4703e6,0x27e60211,0x60dd5a96}},	//   nyai_, sões_, _cron_, _masm,
   {{0x395f5a97,0x394d5a98,0x26dc0382,0x60dd5a99}},	//   smus_, sles_, _cavo_, _lasm,
   {{0x88bd004e,0x26dc0036,0x212900d7,0x6d5b4c28}},	//   liśm, _davo_, kiah_, _khua,
   {{0xda1c009a,0x60dd2676,0x39441c9e,0x27e65a9a}},	//   _भेटत_, _nasm, coms_, _fron_,
   {{0x21291b0f,0x656d00d7,0x26dc310c,0xef280644}},	//   diah_, _diah, _favo_, lmüş_,
   {{0x68fb5a9b,0x6d5b006d,0x2009028b,0x26dc010b}},	//   ljud, _lhua, dyai_, _gavo_,
   {{0x6d495a9c,0x21290ac8,0xbbc00355,0x60dd5a9d}},	//   _okea, fiah_, _शङ्क, _basm,
   {{0xdd000080,0x656d471b,0xdddc003c,0x00000000}},	//   ītīb, _giah, _verż, --,
   {{0x2d8300da,0x7d0003d0,0x2f1601b4,0x60dd0031}},	// [56e0] _atje_, _roms, _læge_, _dasm,
   {{0x6d5b0210,0xdc4300d5,0x63a90a66,0xb4db01f7}},	//   _ahua, _céčk, šenc, blàs,
   {{0x6d5b1093,0x20090ce8,0x21290034,0x7e5609e4}},	//   _bhua, ayai_, biah_, утац,
   {{0x6d5b006e,0x656d012f,0x69ba0266,0x672802a7}},	//   _chua, _xiah, _एमबी, zidj,
   {{0x6d5b5a9e,0x5b2600d8,0xac970bdf,0xda7a010b}},	//   _dhua, лька, انها_, няй_,
   {{0xeef6002d,0x9e6600f8,0xdc4300fe,0x00000000}},	//   _сямэ, _مازن, _géčk, --,
   {{0x6d5b0014,0x2fc05a9f,0x26dc5aa0,0x6728022f}},	//   _fhua, ltig_, _ravo_, vidj,
   {{0x26dc0a93,0x6d5b04e6,0x60c40359,0x6d4901ed}},	//   _savo_, _ghua, nfim, _gkea,
   {{0x2fc05aa1,0x39445aa2,0x78a20252,0x971400af}},	//   ntig_, roms_, _vdov, имиц,
   {{0x2fc001ae,0x2129028b,0xf77f0279,0x24800132}},	//   itig_, ziah_, íça_, _afim_,
   {{0x68fb022a,0x644d124f,0x644101c2,0xceb30122}},	//   bjud, _syai, əliy, זית_,
   {{0x69da1ee4,0x78a25aa3,0x2ed10d00,0x27e601a6}},	//   _iste, _udov, _हस्त, _tron_,
   {{0x60dd5aa4,0x26dc00d8,0x656d5aa5,0xaac400b4}},	//   _rasm, _tavo_, _viah, ल्थक,
   {{0xe81d3e72,0x59b80785,0x60dd5aa6,0x2129028b}},	//   _बेटा_, _इमार, _sasm, wiah_,
   {{0x2129012f,0x656d5aa7,0x2fc0053e,0x00000000}},	//   tiah_, _tiah, etig_, --,
   {{0x2fc0038d,0xdbd100ab,0x70af0099,0x60dd007a}},	//   ftig_, _püüa, टलेल, _qasm,
   {{0x212906b3,0x2fc05aa8,0x200f006c,0x6d5b006f}},	// [56f0] riah_, gtig_, ági_, _rhua,
   {{0x69da5aa9,0x6d5b5aaa,0xf09f0014,0x60dd0130}},	//   _oste, _shua, _clàr_, _wasm,
   {{0x60dd5aab,0x2129253e,0x6d5b0221,0x5c752031}},	//   _tasm, piah_, _phua, алет,
   {{0x6d5b0189,0x62971d35,0x212900d7,0x60dd0079}},	//   _qhua, _hexo, qiah_, _uasm,
   {{0x69da5aac,0xec780185,0x2ba70274,0x00000000}},	//   _aste, упі_, ујев, --,
   {{0x3f895aad,0x6d5b01cb,0x00000000,0x00000000}},	//   mpau_, _whua, --, --,
   {{0xd2b80122,0xf2d40070,0x1dc900ab,0x690701ed}},	//   אלות_, מעס_, _रहित, _oñet,
   {{0x629700da,0xb90520a6,0x2be2018d,0x7c3b01a3}},	//   _lexo, рзик, पिशा, _txur,
   {{0x68fb5aae,0xf71901c8,0x69da0147,0xe8f629d6}},	//   rjud, віны_, _este, рлы_,
   {{0x62970d9b,0x81cc0083,0xd70900c3,0x290d5aaf}},	//   _nexo, লিত_, тное_, skea_,
   {{0xdce95ab0,0x28c20099,0x00000000,0x00000000}},	//   _lieč, व्हि, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce9016f,0xdb1b4469,0x9cd600a5,0xd45601d3}},	//   _nieč, _aqué, בורה_, ртнь,
   {{0x69da5ab1,0x26c70221,0x00000000,0x00000000}},	//   _yste, _ubno_, --, --,
   {{0xe29741bf,0x40965454,0xa2a231d7,0x395d0221}},	//   рас_, ират, कृष्, _khws_,
   {{0x387f128f,0x63a9103a,0x2fc05ab2,0x7bdb5ab3}},	//   ncur_, šena, ttig_, _osuu,
   {{0x60c45ab4,0x06d80083,0x21670b07,0xd0072aac}},	// [5700] rfim, তারি, рити_, аете_,
   {{0xef1711c5,0x2fc05ab5,0x386001a6,0x26c50282}},	//   аму_, rtig_, _ùire_, nflo_,
   {{0x629c5ab6,0x2fc05ab7,0xdcfc02d4,0xda7800ac}},	//   maro, stig_, _atrā, _naďa_,
   {{0xbc6a00e0,0x00000000,0x00000000,0x00000000}},	//   نمان_, --, --, --,
   {{0xfbd205f5,0x3f5402b1,0x00000000,0x00000000}},	//   تتا_, läum_, --, --,
   {{0x629c4bd2,0xa3ce1f57,0x00000000,0x00000000}},	//   naro, _रहन_, --, --,
   {{0x6da312f3,0x629c0042,0x7bdb001c,0xada332e2}},	//   _мира, iaro, _esuu, _марл,
   {{0x58d8263b,0x4ddb00a5,0x290205ee,0x3b863f20}},	//   удия_, _בחלו, ðka_, _влаг,
   {{0x629c5ab8,0xd7fa002d,0xc60e10aa,0xe0df5ab9}},	//   karo, туй_, ान्य_, _chòy_,
   {{0x629c5aba,0xa9a601d3,0xe6664a35,0x1c1f00b4}},	//   jaro, _вижд, итно, _मेटल_,
   {{0x69da5abb,0x0f570122,0x7bc25abc,0x00000000}},	//   _uste, שיים_, ltou, --,
   {{0x7bc201bf,0xd7e601e0,0x7c35008d,0x201e0160}},	//   otou, _віко, _áfrý, _știa_,
   {{0x7bc25abd,0x6297002a,0x00000000,0x00000000}},	//   ntou, _pexo, --, --,
   {{0x629c5abe,0xdce95abf,0x8237186e,0x20e300e2}},	//   garo, _rieč, لرزا, _ổi_,
   {{0x7bc202ee,0x00000000,0x00000000,0x00000000}},	//   htou, --, --, --,
   {{0x7bc203d0,0x09c30033,0x00000000,0x00000000}},	//   ktou, ্মচা, --, --,
   {{0x25de0299,0xa3ce00ab,0x00000000,0x00000000}},	// [5710] गिकी_, _रहय_, --, --,
   {{0x629c0f56,0x02a75ac0,0x6578006d,0x8afc0035}},	//   caro, _трим, _kuvh, _mięs,
   {{0xdcfc0029,0xa3df1746,0x7bdb018e,0x00000000}},	//   _strā, णिक_, _ssuu, --,
   {{0xd7a60243,0xdb0b0831,0xa3ce0324,0xc5790070}},	//   _खिंच, rugí, _रहम_, אָסט,
   {{0x2bda035d,0x00000000,0x00000000,0x00000000}},	//   _मैदा, --, --, --,
   {{0xa2bb021a,0x00000000,0x00000000,0x00000000}},	//   श्च्, --, --, --,
   {{0x29d800e2,0x00000000,0x00000000,0x00000000}},	//   _cũa_, --, --, --,
   {{0x629c5ac1,0xf77f0183,0x02a7022e,0x00000000}},	//   zaro, íço_, कृतभ, --,
   {{0x7bc22948,0x7c240037,0x629c00a8,0x8afc0035}},	//   ctou, úirt, yaro, _pięt,
   {{0x629c5ac2,0x46f500c3,0x387f5ac3,0xa3ce00ab}},	//   xaro, счит, scur_, _रहब_,
   {{0x395d006d,0x7ae1239a,0x160e111a,0x671d0066}},	//   _thws_, _ialt, ानगर_, योगक_,
   {{0x7ae15ac4,0x629c5ac5,0x25aa29e3,0x5a0c016b}},	//   _halt, waro, ábla_, _שלאַ,
   {{0x7ae15ac6,0x087602b5,0x69c35ac7,0x66e55ac8}},	//   _kalt, _הענט_, ltne, _гола,
   {{0x446302fb,0x2bfa0099,0x00000000,0x00000000}},	//   явяв, ्हतं_, --, --,
   {{0x7ae15ac9,0x629c51c8,0x7b32004e,0x6eca057c}},	//   _malt, raro, sług, स्फु,
   {{0x645a0669,0x629c5aca,0xd132004f,0x6fac22d4}},	//   ətin, saro, أمر_, _चिदं,
   {{0xdce0004b,0x00000000,0x00000000,0x00000000}},	// [5720] _gimę, --, --, --,
   {{0x1ea922c4,0x63a40b43,0x7ae15acb,0x93fb011d}},	//   لامي_, _ivin, _nalt, _עליי,
   {{0x69c30009,0x6146010b,0x63a4008c,0x00000000}},	//   jtne, _гена, _hvin, --,
   {{0xdca34b66,0x63a42172,0x7ae15acc,0x7bc2081b}},	//   заци, _kvin, _aalt, ttou,
   {{0x5c9701c8,0xed4f0088,0x2d080fd1,0xd9e052cf}},	//   скія_, رپه_, _वकील_, पट्ट,
   {{0x7bc202e1,0x5f065118,0x7ae10502,0x60d65acd}},	//   rtou, _узга, _calt, leym,
   {{0x7bc201c0,0x7ae15ace,0xf2d302b8,0x4ab900af}},	//   stou, _dalt, פעה_, ручя_,
   {{0x7ae10608,0x63a45acf,0x7bc25ad0,0x61e1082b}},	//   _ealt, _ovin, ptou, ælli,
   {{0xfaa61109,0xaaba05bc,0x17fa0037,0x63a4030d}},	//   _газо, _مدار_, ارعة_, _nvin,
   {{0xd6da5ad1,0x7ae133aa,0x644100a3,0x00000000}},	//   ути_, _galt, şlik, --,
   {{0x63a45ad2,0x29e7012e,0x862600d8,0x24f90bbc}},	//   _avin, _gđa_, сьпе, анны_,
   {{0x2d730254,0x7ae15ad3,0x7b320067,0xf4844bfe}},	//   _kćer_, _zalt, słud, зурн,
   {{0x443f5ad4,0x07e900b5,0x7ae15ad5,0x63a4004b}},	//   çu_, _پرنٹ_, _yalt, _cvin,
   {{0x63a90672,0xdc3700c2,0x443f0484,0x659400d8}},	//   šeno, מאכט_, ħu_, _даку,
   {{0x63a404d4,0x68e2034d,0x00000000,0x00000000}},	//   _evin, _kaod, --, --,
   {{0x863700a5,0x60d6003e,0x4155010b,0x623400af}},	//   _לרוב_, geym, івас, чесу,
   {{0x63a40478,0x752f004e,0x68e2009e,0x6e9903e6}},	// [5730] _gvin, micz, _maod, ивар_,
   {{0x752f004e,0xa3e60722,0xa3ce007c,0x27e92190}},	//   licz, फिर_, _रहत_, _šank_,
   {{0x63a400ee,0xf3cb00bf,0x2d875ad6,0x00000000}},	//   _zvin, _شبکه_, ëne_, --,
   {{0x752f006a,0x81cc0083,0x6aa80090,0x68e25ad7}},	//   nicz, লিশ_, _addf, _naod,
   {{0xdcfc0043,0x5ee10033,0x00000000,0x00000000}},	//   _stră, নাবে, --, --,
   {{0x69c35ad8,0x3d95039e,0x539c02b5,0x81cc0083}},	//   ttne, _мигр, ניוו, লির_,
   {{0x7ae15ad9,0xaac42149,0x68e25ada,0x00000000}},	//   _valt, ستون, _baod, --,
   {{0x77853471,0x7ae15adb,0xe7a9036c,0x2bd902fd}},	//   олиз, _walt, авил_, _پارک_,
   {{0x6d4b0332,0x69c35adc,0x68e2473f,0x7ae15add}},	//   moga, stne, _daod, _talt,
   {{0x6d4b5ade,0x6b890232,0x7ae1009e,0x00000000}},	//   loga, _iteg, _ualt, --,
   {{0xceb200c2,0xcb680312,0x752f004e,0x68e20014}},	//   ויי_, _امله_, ficz, _faod,
   {{0x752f004e,0x6d4b1ba6,0xa3e603e2,0x671d0355}},	//   gicz, noga, फिल_, योजक_,
   {{0xe72e5adf,0x636002c9,0x39a50228,0x00000000}},	//   _же_, höne, lēs_, --,
   {{0x6d4b5ae0,0x1b7a0070,0xe2975ae1,0x6b89002f}},	//   hoga, יטשע, жар_, _mteg,
   {{0x6d4b5ae2,0x91e330cc,0x39a500ea,0x00000000}},	//   koga, море, nēs_, --,
   {{0x63a40307,0xf8d90992,0x6b895ae3,0x78bb5ae4}},	//   _tvin, ढ़िय, _oteg, nguv,
   {{0x60d65ae5,0x6d4b5ae6,0xa3ce007c,0x6b892506}},	// [5740] reym, doga, _रहि_, _nteg,
   {{0x60d60260,0x0cd60033,0x27e2008d,0x00000000}},	//   seym, _সচেত, ækni_, --,
   {{0xec7a5ae7,0x6d4b07ed,0x6b895ae8,0x6f070156}},	//   апе_, foga, _ateg, _dojc,
   {{0xa3ce0755,0xf09f0028,0x6d4b5ae9,0x92b60609}},	//   _रहा_, _hoàn_, goga, _احکا,
   {{0xdb1b5aea,0x653b0070,0x00000000,0x00000000}},	//   _equí, סענד, --, --,
   {{0x6360006c,0xf7670372,0x00000000,0x00000000}},	//   lönb, _زا_, --, --,
   {{0x6d4b5aeb,0x6b89018e,0xa3ce007c,0x66df00c7}},	//   boga, _eteg, _रहऽ_, iškė,
   {{0x984f0463,0x8c460ea0,0x97a607bb,0x9f4001f7}},	//   _ağır_, _дебе, орол, lvià_,
   {{0x8afc0067,0x00000000,0x00000000,0x00000000}},	//   _chęc, --, --, --,
   {{0xe5c603ad,0x752f004e,0x3ce600ee,0xab270043}},	//   осмо, wicz, ldov_, _доуа_,
   {{0xd5b7311c,0x6d430248,0x88ac0033,0x7c2234af}},	//   ося_, énag, ক্ষক, lzor,
   {{0x6eca111a,0x3ce65aec,0x7d025aed,0xb86500b5}},	//   स्तु, ndov_, njos, _کامو,
   {{0x66e612a2,0x00000000,0x00000000,0x00000000}},	//   _мода, --, --, --,
   {{0x672a0093,0x752f5aee,0x6d4b5aef,0x00000000}},	//   _umfj, sicz, zoga, --,
   {{0x31c411c5,0x398301d6,0x6d4b5af0,0x645a0095}},	//   мств, _kısa_, yoga, ətim,
   {{0x2eed5af1,0x6d4b002a,0x2ee3035f,0x00000000}},	//   _şef_, xoga, _sajf_, --,
   {{0x6d4b0370,0x752d5af2,0xb7ed0035,0xa37b00be}},	// [5750] voga, _imaz, जियम_, kvõi,
   {{0x7c221cb0,0x6d4b5af3,0x6b8903d0,0x78a00027}},	//   dzor, woga, _rteg, hamv,
   {{0x6b891e54,0x57b702cb,0x6ec1198f,0x673a11cc}},	//   _steg, _आम्ह, र्गु, intj,
   {{0x7bf90b25,0x6f070035,0x752d01ed,0x9f0500fd}},	//   йнер_, _wojc, _jmaz, _کوسو,
   {{0x6d4b5af4,0x4fc41126,0x752d001c,0x2bbb0037}},	//   roga, _осра, _mmaz, شاشة_,
   {{0x37c200c8,0x31695af5,0x673a01e4,0x6d4b5af6}},	//   ্টার, lmaz_, jntj, soga,
   {{0xeda403d0,0x5ee10083,0xeab00037,0x752d018e}},	//   _ошто, নাদে, ئعه_, _omaz,
   {{0xe8f90573,0x316904d4,0x50cb00b4,0x39a50029}},	//   сли_, nmaz_, ाभिष, rēs_,
   {{0x63a90496,0x6b895af7,0x7c220035,0x9a8738bb}},	//   šenj, _uteg, czor, _дуел,
   {{0x1dd2000c,0x752d5af8,0x7d090d35,0x7d1b008a}},	//   _सहमत, _amaz, _hoes, _hlus,
   {{0x7d1b5af9,0x7d095afa,0xceb20070,0x64480095}},	//   _klus, _koes, עיט_, ədiy,
   {{0x7d095afb,0x04465159,0x673a0fdb,0x00000000}},	//   _joes, земн, antj, --,
   {{0x7d095afc,0x8c4600a8,0x27e90079,0xa87a024b}},	//   _moes, _peşə, _éan_, _האנר,
   {{0x752d3483,0x394d5afd,0x3ce65afe,0x7d1b5aff}},	//   _emaz, loes_, zdov_, _llus,
   {{0xf77000f8,0x7d1b01a8,0x7c22027a,0x62635b00}},	//   _شاه_, _olus, zzor, евра,
   {{0x752d022f,0x044602fb,0x64430067,0x7d1b00e0}},	//   _gmaz, _нейн, _śnie, _nlus,
   {{0xe0431e56,0xf09f00e8,0x65645b01,0xa067029f}},	// [5760] енти, _toàn_, _ihih, зата_,
   {{0x7d1b2efa,0x394d5b02,0x752d00a0,0x8c3d027d}},	//   _alus, hoes_, _zmaz, _keşf,
   {{0x7d095b03,0xf29700a5,0x71a3010b,0xee3a0200}},	//   _boes, _מכיר_, _паэз, љне_,
   {{0xdd8f0041,0x7c2206a2,0x2d87061b,0xdb1b0392}},	//   اون_, tzor, ínea_, _aquà,
   {{0x629e0ce8,0x98a400d8,0x7d090122,0x63a658be}},	//   _kepo, nimą_, _does, nskn,
   {{0x7d1b4578,0x7c225b04,0xada61654,0x63a655e4}},	//   _elus, rzor, _нагл, iskn,
   {{0xf98f0413,0x7c22006c,0x394d001e,0xf41f0ef0}},	//   هبي_, szor, foes_, nbär_,
   {{0x629e5b05,0xfce30f94,0x39830095,0xa37b00ab}},	//   _lepo, _посо, _qısa_, svõi,
   {{0x98a400d8,0x3d11021a,0x00000000,0x00000000}},	//   jimą_, _थकते_, --, --,
   {{0x629e531e,0x752d00b8,0x291f5b06,0x65644826}},	//   _nepo, _smaz, ahua_, _ahih,
   {{0x27200028,0x78a00010,0x394d12ba,0x6448013b}},	//   _lòng_, pamv, boes_, şdil,
   {{0x291f5b07,0x394d0279,0xe97b00a5,0xe99500d1}},	//   chua_, coes_, _הנאש, _آهنگ,
   {{0x399a010b,0x65640cdf,0x272000e2,0x212001cb}},	//   lūs_, _dhih, _nòng_, dhih_,
   {{0x629e0a8a,0x00000000,0x00000000,0x00000000}},	//   _cepo, --, --, --,
   {{0x629e0aca,0x658801c0,0x2d5c02d7,0x31690457}},	//   _depo, _běhe, víen_, tmaz_,
   {{0xe63b0122,0x752d410a,0x25d70070,0x2720055c}},	//   _לתוכ, _umaz, _זוהן_, _bòng_,
   {{0x7d095b08,0xc05b00d4,0x224d0035,0x31695b09}},	// [5770] _roes, сів_, łek_, rmaz_,
   {{0x629e5b0a,0x272001a5,0x7d1b1f2e,0xe7ed021a}},	//   _gepo, _dòng_, _slus, जिता_,
   {{0x753d02b1,0xdcf502d4,0x00000000,0x00000000}},	//   onsz, _auzā, --, --,
   {{0x291f5b0b,0x6ec10f17,0x65640055,0xdb0b02b1}},	//   xhua_, र्जु, _xhih, zugä,
   {{0xdb1b0279,0x3b0932f6,0xed5800d4,0x60cd03d0}},	//   _aquá, жело_, чої_, mfam,
   {{0x60cd01f7,0x7d090173,0x62870067,0x82345b0c}},	//   lfam, _woes, ncjo, _آریا,
   {{0x2fc95b0d,0x7d090a45,0xe9d900d4,0xdea4006c}},	//   ltag_, _toes, іки_, _سینی,
   {{0xa3ce3914,0x7d1b01d6,0x60cd1bb3,0x27ff01a3}},	//   _रहल_, _ulus, nfam, txun_,
   {{0xb8d50e04,0x2fc95b0e,0x62870067,0xdb1902b1}},	//   _जय_, ntag_, kcjo, ttwä,
   {{0x65645b0f,0x2fc901ae,0x05a90086,0x7c240014}},	//   _shih, itag_, овой_, ùire,
   {{0x6aa35b10,0xdb2600bf,0xdbd70421,0x394d5b11}},	//   manf, _تولی, säät, poes_,
   {{0x6aa35b12,0xdbd700c3,0x98a400c7,0x00000000}},	//   lanf, päät, timą_, --,
   {{0x629e5b13,0x5f00012f,0xe3b20037,0x7a1300fe}},	//   _pepo, राम्_, خرج_, _dětš,
   {{0x63a604ca,0x6aa30938,0x06e10083,0x68e93af4}},	//   rskn, nanf, বাহি, lded,
   {{0x3cfe0302,0x60cd5b14,0xa2cd022e,0x27200023}},	//   _रचले_, ffam, द्ध्, _sòng_,
   {{0x68e91c98,0x4f9603e6,0x65640027,0x6b9b0103}},	//   nded, држу, _uhih, _owug,
   {{0x2fc902b3,0x8fa307b0,0x629e5791,0x27ed5b15}},	// [5780] gtag_, кате, _tepo, nven_,
   {{0xfe725b16,0x27200028,0xdb1b002a,0xa2cd0099}},	//   ندا_, _vòng_, _opuñ, द्द्,
   {{0x60cd1471,0xa3e60e6f,0x6aa32129,0x6ce601e0}},	//   bfam, फिक_, danf, діле,
   {{0x68e908c8,0x6b9b0371,0x272000e2,0x00000000}},	//   jded, _bwug, _tòng_, --,
   {{0x27ed04ce,0x68e95b17,0xd24f103b,0x9b6a2e50}},	//   jven_, dded, _منی_, ошка_,
   {{0x6d595b18,0x291d030d,0xdcfc0069,0x6aa305aa}},	//   alwa, _alwa_, _kurċ, ganf,
   {{0x81cc00c8,0x27ed0120,0x1dd23d9e,0x999e010b}},	//   লিক_, even_, _सहित, _rytų_,
   {{0x63a9016f,0xa967052c,0x68e95b19,0x399a010b}},	//   šeni, мија_, gded, rūs_,
   {{0x5ee10083,0x2d5c0310,0x00000000,0x00000000}},	//   নারে, níem_, --, --,
   {{0x291d00e9,0x6b6300af,0x00000000,0x00000000}},	//   _elwa_, _акуа, --, --,
   {{0x27ed01f7,0x60cd0225,0x7afa0328,0xdb1900e0}},	//   aven_, yfam, _intt, duwè,
   {{0x6b8014b2,0x291d021e,0x249f0093,0x00000000}},	//   _kumg, _glwa_, úum_, --,
   {{0x7a13000c,0x7ae80c47,0x69ca5b1a,0x2fc95b1b}},	//   _větš, _kadt, ltfe, xtag_,
   {{0xbcfd0023,0x27200107,0x2d5c0392,0x00000000}},	//   _nhũn, _bòne_, díem_, --,
   {{0x69ca5b1c,0x09dc018d,0x7ae8008c,0x60cd5b1d}},	//   ntfe, _मनोय, _madt, tfam,
   {{0x2fc95b1e,0x00000000,0x00000000,0x00000000}},	//   ttag_, --, --, --,
   {{0x40345b1f,0x8c3d0160,0xe7bc0083,0x60cd1b04}},	// [5790] ветс, _keşe, _অনুয, rfam,
   {{0x63bd1096,0x2d872cad,0x7ae85b20,0x067b0070}},	//   musn, íneo_, _nadt, ַנדל,
   {{0xc175487d,0x68e95b21,0x2fc95b22,0x7cd903fe}},	//   _площ, yded, stag_, змер_,
   {{0x61e55b23,0x7afa5b24,0xdd9400d8,0x69ca0137}},	//   _ishl, _antt, тацы, dtfe,
   {{0x7ae85b25,0xeb99151d,0x00000000,0x00000000}},	//   _badt, чил_, --, --,
   {{0x7afa0176,0xdcf500af,0xa3d7063f,0x69ca5b26}},	//   _cntt, _buză, _सहन_, ftfe,
   {{0x6d5902e9,0x6aa35b27,0x63602919,0xe9d103fc}},	//   plwa, ranf, könn, اغت_,
   {{0x7afa2a5d,0x6aa30110,0x7d0400c3,0x6b9b0371}},	//   _entt, sanf, öist, _twug,
   {{0x6c5416ac,0x68e95b28,0x63bd5b29,0x69c8007a}},	//   _акту, rded, jusn, _eqde,
   {{0x63bd5b2a,0x27e90116,0x00000000,0x00000000}},	//   dusn, _šans_, --, --,
   {{0x777802d7,0x8c3d00af,0x4c99016b,0x00000000}},	//   _divx, _deşe, ּבֿו, --,
   {{0x6aa10b19,0x899600a5,0xa3e400ab,0xf2c91804}},	//   _helf, _נכנס_, _ननद_, _לע_,
   {{0x2d9c0152,0x7bcb3f34,0x74160bdf,0x7981010d}},	//   ávez_, ntgu, روسا, _hulw,
   {{0x66e20009,0x5ecf00c8,0xe9ff0028,0x7981018e}},	//   _боша, _হোসে, _giảm_, _kulw,
   {{0x7658010b,0x6aa15b2b,0x216a5b2c,0x00000000}},	//   _gyvy, _melf, зиви_, --,
   {{0x63bd5b2d,0x7981018e,0x691c02d7,0xc57a00a5}},	//   busn, _mulw, _léen, _צרפת,
   {{0x09dc00e7,0xd175004b,0xc56900bc,0x9f4000c3}},	// [57a0] _मन्य, тыры, _تحول_, yviä_,
   {{0xe9e50028,0x6fb303c7,0xceea010b,0x6b805b2e}},	//   _đúng_, املا, ядзе_, _rumg,
   {{0xdd8f234a,0x823604e8,0x2d9c20d0,0x429b02b8}},	//   مول_, _سردا, ève_, _מסיב,
   {{0x25e70084,0x2ca00037,0x7bcb5b2f,0xe6bd0edf}},	//   _जननी_, úid_, ftgu, ्भुज,
   {{0x6aa15b30,0x80c900a1,0xa3e604bc,0xfb85132d}},	//   _belf, _हॉटे, फिट_, نگلی,
   {{0x7981018e,0x853d00d8,0x6aa1001e,0x69ca01e0}},	//   _bulw, gsėj, _celf, ttfe,
   {{0x6aa15b31,0x3f820657,0x2d550c71,0x6f0e00d5}},	//   _delf, _huku_, tået_, _iobc,
   {{0x2c57004e,0x3f825b32,0xdcfc5b33,0x613b0328}},	//   _będą_, _kuku_, _kurč, mälä,
   {{0x0b4609c0,0x63bd024e,0x613b0328,0x8c430336}},	//   _знан, xusn, lälä, _бете,
   {{0x3f825b34,0x6f0e049a,0x2ca602b3,0x6aa1016e}},	//   _muku_, _jobc, laod_, _gelf,
   {{0x613b00c3,0x3f825b35,0x69ba0026,0x7981030d}},	//   nälä, _luku_, _एमटी, _gulw,
   {{0x6aa104ce,0x765800d5,0x81c80831,0x00000000}},	//   _zelf, _vyvy, োটা_, --,
   {{0x8c3d0723,0x3f825b36,0x9f4200fe,0xdcee013a}},	//   _teşe, _nuku_, _eské_, _atbī,
   {{0x63bd005d,0x612300ab,0x60c601ef,0x613b00c3}},	//   rusn, _mõle, _ackm, kälä,
   {{0x63bd0f1a,0x3f8241cc,0xf09f0019,0x15f30698}},	//   susn, _auku_, _hoài_, _مسيح,
   {{0x3f820452,0x365b0122,0x63bd1f3d,0x636000b5}},	//   _buku_, _מכונ, pusn, lönl,
   {{0xb4dd1033,0x27e61d35,0xa3ce00ab,0x64a40274}},	// [57b0] ड़ी_, _json_, _रहए_, _сања,
   {{0x63ad5b37,0xc43c0122,0x26de5b38,0x20070a78}},	//   _ivan, _מתחי, neto_, ćni_,
   {{0xf09f0019,0x25f60026,0x63ad008d,0x612300be}},	//   _loài_, एमटी_, _hvan, _põld,
   {{0x6aa15b39,0x78a208c2,0xa2cd0d41,0x6f0e00ac}},	//   _self, _neov, द्र्, _eobc,
   {{0x26de5b3a,0x490400be,0x691c0168,0x79810b77}},	//   keto_, वानो_, _péen, _sulw,
   {{0x26de5b3b,0x3ce902c6,0x50180166,0x6f0e02a7}},	//   jeto_, žav_, _џорџ_, _gobc,
   {{0x7bcb2d73,0x94120095,0x2d850248,0x6aa15b3c}},	//   stgu, _deyə_, _île_, _velf,
   {{0x8d740098,0x3ea30009,0x63ad0533,0xd5b802d4}},	//   _ماقا, _hejt_, _ovan, drā_,
   {{0x6aa15b3d,0x3ea323cc,0x2d830116,0x612300be}},	//   _telf, _kejt_, _huje_, _kõlb,
   {{0x2d830506,0x7981073a,0x00000000,0x00000000}},	//   _kuje_, _tulw, --, --,
   {{0x63ad5b3e,0xb4dd00ab,0x2d8324fc,0xd6295b3f}},	//   _avan, ड़ू_, _juje_, фоне_,
   {{0x38350c8d,0x33335b40,0x63ad0051,0x2d8320b0}},	//   _инер, _amxx_, _bvan, _muje_,
   {{0x26de5b41,0x68eb011e,0x290f24ad,0x7784010b}},	//   beto_, _iagd, _ioga_, _бліз,
   {{0x3f82022f,0x26de5b42,0x656f006d,0x68eb2326}},	//   _ruku_, ceto_, amch, _hagd,
   {{0x3f820464,0x290f5b43,0xf2a32252,0xdcfc02c4}},	//   _suku_, _koga_, рисп, _surč,
   {{0x3f823c7e,0x216716c0,0xddc70035,0x68eb5b44}},	//   _puku_, виси_, _wyjś, _jagd,
   {{0x68eb5b45,0x290f5b46,0x7083081b,0x2d915b47}},	// [57c0] _magd, _moga_, ргуз, _atze_,
   {{0x3f8213c6,0x68eb5b48,0xfbe70083,0x2d835b49}},	//   _vuku_, _lagd, পমাত, _buje_,
   {{0x63ad5b4a,0xdee35b4b,0x1b200033,0x2d550df7}},	//   _zvan, рохи, _বদলে_, våer_,
   {{0x3f8200d1,0x290f5b4c,0x68eb149b,0xdcfc0bcc}},	//   _tuku_, _noga_, _nagd, _turč,
   {{0xe7bc00c8,0x613b0328,0x99410035,0x78a2018d}},	//   _অন্য, sälä, kół_, _reov,
   {{0x60c45b4d,0xf09f0023,0x7b140310,0x3ea304c4}},	//   lgim, _roài_, _nàut, _gejt_,
   {{0x290f5b4e,0x6da35b4f,0x26de5b50,0x13db0033}},	//   _boga_, _виса, veto_, দিয়,
   {{0x60c45b51,0x23b220d8,0x26de5b52,0x248000d7}},	//   ngim, _जिंद, weto_, _ngim_,
   {{0x68eb5b53,0x26de5b54,0xf80300d8,0xc8f20066}},	//   _dagd, teto_, ачэн, _अफीम_,
   {{0xd6da5b55,0xd5b800ea,0x63ad02c4,0x248001f4}},	//   фти_, trā_, _rvan, _agim_,
   {{0x63ad5b56,0x5ebb00a5,0xc9d50416,0x55750adb}},	//   _svan, וזיק, _مملک, лгот,
   {{0xb4dd0b4a,0x27200176,0x69da5b57,0x43952d7a}},	//   ड़े_, _dòna_, _ipte, ламс,
   {{0x26de5b58,0xe72f00bf,0xaac923db,0x1c0222a7}},	//   peto_, صصی_, _रामक, लमिल_,
   {{0x2d875b59,0x59c622c7,0x68e05b5a,0x63ad0103}},	//   ínek_, रंपर, lemd, _vvan,
   {{0x02d2057c,0x290f5b5b,0x00000000,0x00000000}},	//   द्धभ, _yoga_, --, --,
   {{0x74150d93,0x290f0391,0x63ad5b5c,0x60c4141b}},	//   _موبا, _xoga_, _tvan, ggim,
   {{0x691c0248,0x2fc016df,0x6d42082d,0x63ad5b5d}},	// [57d0] _réel, guig_, dnoa, _uvan,
   {{0x63a90076,0x4fc40431,0x39460044,0x68e00345}},	//   šens, јста, _ljos_, hemd,
   {{0x39460033,0x02a400d8,0x3cff00a1,0x4ac90099}},	//   _ojos_, _трым, ळाले_, _राबव,
   {{0xa3d700a1,0x2fc05b5e,0x00000000,0x00000000}},	//   _सहा_, buig_, --, --,
   {{0x290f5b5f,0x3ea30009,0x7b1401f7,0x62800355}},	//   _roga_, _tejt_, _nàus, ěmov,
   {{0x6b6501c8,0xe1f00332,0x68eb054e,0xa2d637e8}},	//   ыкла, _اسی_, _sagd, म्प्,
   {{0x68eb12d7,0x1cbb004f,0x9f340044,0x38660107}},	//   _pagd, _يارب_, _тері, _azor_,
   {{0xb4dd0084,0x89d60609,0xa9665b60,0xa2da00b4}},	//   ड़ो_, اوير_, лища_, _पॉन्,
   {{0x6ec70722,0x6eca00b1,0x6588007e,0x00000000}},	//   ालपु, स्कु, _běho, --,
   {{0x3cff006d,0x3866011e,0x290f002f,0x68eb0345}},	//   _hnuv_, _dzor_, _woga_, _wagd,
   {{0x290f0202,0x64a6356c,0x68eb5b61,0x00000000}},	//   _toga_, лана, _tagd, --,
   {{0xb4be0302,0x2f1600fb,0xdcfc00ea,0x290f5b62}},	//   आले_, _hægt_, _kurā, _uoga_,
   {{0xf7f404e8,0x9f401725,0x7c2b02b1,0xa3bb021a}},	//   _پسند, rviú_, nzgr, आंग_,
   {{0x395f136b,0xb6a5027a,0x78a900ab,0x6d930069}},	//   llus_, _сикл, laev, _iħaf,
   {{0x321e024e,0x395f5b63,0x200f00be,0x00000000}},	//   áty_, olus_, ägin_, --,
   {{0x2fc05b64,0x46cf0d91,0x00000000,0x00000000}},	//   tuig_, त्रह, --, --,
   {{0x60c45b65,0xe3b2006c,0x321e0187,0x752425d1}},	// [57e0] rgim, _ارب_, šty_, _iliz,
   {{0xa2e603e6,0x26c5359a,0x139b0d85,0x75360097}},	//   _соод, nglo_, _רביע, _hmyz,
   {{0x629c1423,0x75240254,0x7bdb135c,0x683a0a8a}},	//   mbro, _kliz, _apuu, _kødø,
   {{0xe45f022a,0xd00a5b66,0x0c260eee,0xdcfc02d4}},	//   mför_, _земе_, лмен, _burā,
   {{0x6d425b67,0x395f5b68,0xdb5a0ed2,0x75243436}},	//   rnoa, dlus_, нюк_, _mliz,
   {{0xbda603c7,0x6d420009,0x395f00be,0x6d4a5b69}},	//   _محرو, snoa, elus_, éfab,
   {{0xe45f022a,0xe60716e6,0xfc3f008a,0x27200107}},	//   nför_, _اش_, _þín_, _bònn_,
   {{0x391405c2,0x395f00e9,0x612300ab,0xa3e40864}},	//   рмир, glus_, _kõla, नबा_,
   {{0x68e05b6a,0xed350409,0x629c5b6b,0x00000000}},	//   remd, _тэрэ, kbro, --,
   {{0x4734010e,0x68e0200b,0x75245b6c,0x38661efc}},	//   рнос, semd, _aliz, _vzor_,
   {{0x752405e2,0x0f5702b8,0xd6d7021f,0x6aaa5b6d}},	//   _bliz, ריים_, уты_, maff,
   {{0x6aaa5b6e,0x395f5b6f,0x64751f6a,0x629c32c5}},	//   laff, clus_, игну, ebro,
   {{0x386601f2,0x658800b8,0xb79603fa,0x6d93007a}},	//   _uzor_, _těho, _срећ, _għaf,
   {{0x56945b70,0x6aaa18f9,0x629c5b71,0xa01b01ff}},	//   _такт, naff, gbro, _oför,
   {{0x3495083e,0x22590421,0x316b0200,0x2d5c0176}},	//   _кайр, тивы_, ешао_, líeu_,
   {{0x6aaa58a7,0x316002e9,0x5184002d,0xa2d600b4}},	//   haff, gliz_, сура, म्ब्,
   {{0x6aaa5b72,0x656d5b73,0x629c5b74,0xcebb0200}},	// [57f0] kaff, _ihah, bbro, еље_,
   {{0x7bc25b75,0x656d0159,0x673a43cc,0x78a90225}},	//   duou, _hhah, nitj, zaev,
   {{0x395f11c7,0x6aaa31bc,0x7bdb12ba,0xddc70228}},	//   ylus_, daff, _spuu, _izjū,
   {{0x8d745b76,0xdb0202d7,0x61fa008d,0x7c2b5b77}},	//   مانا, droñ, ætle, tzgr,
   {{0xd7e6004f,0x63af0037,0x673a5b78,0x656d009e}},	//   _بك_, nscn, kitj, _mhah,
   {{0x645a002d,0x6aaa5b79,0x673a0055,0x00000000}},	//   ştig, gaff, jitj, --,
   {{0x395f007c,0xdb0251c8,0x2f1601b4,0xdb0b0453}},	//   tlus_, groñ, _vægt_, nsgé,
   {{0xe8f9031a,0x63bd28c2,0x629c1e85,0xc27c0070}},	//   тли_, krsn, zbro, ערהי,
   {{0x6d5b012f,0x7bdb002f,0x644d009e,0x395f00b9}},	//   _ikua, _upuu, _nxai, rlus_,
   {{0x656d5b7a,0x21295b7b,0x75240097,0x6aaa2d29}},	//   _ahah, hhah_, _sliz, caff,
   {{0x75240c1f,0x656d0069,0xf5064187,0x2b1a012f}},	//   _pliz, _bhah, азно, _भवतु_,
   {{0x69c35b7c,0x2129012f,0x69673b94,0x656d27d2}},	//   mune, jhah_, _صداق, _chah,
   {{0x656d5b7d,0x289a02b5,0x212900bf,0x69c35b7e}},	//   _dhah, _סיסא, dhah_, lune,
   {{0xa3c70299,0xa3d75b7f,0x661a1298,0x684400d4}},	//   _उमर_, _सहर_, bytk, _уніа,
   {{0x63bd0014,0x6d490453,0x7ae35b80,0xdcfc0395}},	//   arsn, _ojea, ient, _jură,
   {{0xe45f06d7,0x6d5b0221,0x75245b81,0xe9ff00e2}},	//   rför_, _nkua, _uliz, _giấm_,

   {{0x7ae35b82,0x69c35b83,0x27295b84,0x316001b7}},	// [5800] kent, hune, _cúng_, rliz_,
   {{0x7ae32997,0x69c35b85,0x2129006d,0x656d012f}},	//   jent, kune, ahah_, _zhah,
   {{0x7ae33fbd,0x72080332,0x291f00c3,0x69c300ab}},	//   dent, _صفحہ_, kkua_, june,
   {{0x63a45b86,0x7bc20e8f,0x47dc0083,0xeb9a5b87}},	//   _kwin, tuou, বিতী, вид_,
   {{0x7ae35b88,0xb92a01a5,0xeb06244d,0x6aaa01a8}},	//   fent, _thuế_, ичко, taff,
   {{0x7ae35b89,0x63a45b8a,0x69c35b8b,0x6d5b5b8c}},	//   gent, _mwin, fune, _ekua,
   {{0x69c35b8d,0xa2ce0433,0x19a7005f,0x673a5b8e}},	//   gune, _तान्, атып_, vitj,
   {{0x212003ab,0xa3d71ef5,0x7d0002d7,0xdb020138}},	//   nkih_, _सहल_, _unms, rroñ,
   {{0x673a01f4,0x69c300a2,0x00000000,0x00000000}},	//   titj, aune, --, --,
   {{0x656d3dc2,0x63bd0a78,0x69c35b8f,0x89d601e0}},	//   _shah, vrsn, bune, _відш,
   {{0x673a00da,0x6d930484,0x61e701e8,0xceb300a5}},	//   ritj, _għad, xwjl, חית_,
   {{0x673a0443,0x63a4018c,0x6aa800e9,0x00000000}},	//   sitj, _bwin, _hedf, --,
   {{0xd794004f,0x2d5c1725,0xe0df0260,0x212008b7}},	//   _التخ, líes_, _djòl_, dkih_,
   {{0x63a40b0d,0x6ed81579,0x3cfd0084,0x673a01f4}},	//   _dwin, न्मु, _रोने_, qitj,
   {{0x63a45b90,0x27290019,0x6aa80bf3,0x212900bf}},	//   _ewin, _súng_, _medf, thah_,
   {{0x644d01a9,0xdb1902e9,0x767b00a5,0xa5080274}},	//   _txai, ntwò, _בטוח, _већа_,
   {{0x7ae35b91,0xc05b0a55,0x64480095,0x69c306a2}},	// [5810] yent, тів_, şdir, zune,
   {{0x7ae35b92,0x6d5b5b93,0x21295b94,0x64a70084}},	//   xent, _skua, shah_, _ख़ुश,
   {{0x7ae35b95,0x63a45b96,0xe2a70093,0x2d87000d}},	//   vent, _zwin, íður_, êne_,
   {{0x7ae35b97,0x753d006c,0x21201b8d,0x0d8400d8}},	//   went, nisz, ckih_, ілін,
   {{0xa2ce0e61,0x5f770088,0x2d9a0036,0x06ac0033}},	//   _ताम्, _ناسر, appe_, _খানি,
   {{0x69c35b98,0x8ccc0461,0x6285009f,0x2d5c01f7}},	//   tune, _हाथो, _jgho, fíes_,
   {{0xd2b800a5,0x6aa8016e,0xdb090132,0x290d0009}},	//   בלות_, _dedf, _uveí, tjea_,
   {{0x69c35b99,0xe0df02d0,0x0905002d,0x6d5b002f}},	//   rune, _akòz_, спин, _ukua,
   {{0x6d59004e,0x69c35b9a,0x3cfd0035,0x2bda0416}},	//   mowa, sune, _रोये_, _مالک_,
   {{0x69c35b9b,0x291f38e5,0x628500e9,0x63a404fb}},	//   pune, skua_, _ngho, _rwin,
   {{0x99850514,0x63a45b9c,0x58d500af,0xa2ce0099}},	//   _الصو, _swin, _гоет, _ताब्,
   {{0x753d0332,0x6d595b9d,0x62851c8b,0x6b811a47}},	//   gisz, nowa, _agho, _hilg,
   {{0x6b8900c8,0xdcf50029,0x6b815b9e,0x49040066}},	//   _jueg, _atzī, _kilg, वारो_,
   {{0x6b81003c,0x6d595b9f,0xe69542c5,0x6d93007a}},	//   _jilg, howa, _الغد, _mħab,
   {{0x6d59006a,0x6b890083,0x212002dd,0x412a0948}},	//   kowa, _lueg, tkih_, гово_,
   {{0x62850b3e,0x753d3bda,0x00000000,0x00000000}},	//   _egho, cisz, --, --,
   {{0x6d59006a,0x212002a7,0x612a0093,0x63a45ba0}},	// [5820] dowa, rkih_, _nýle, _uwin,
   {{0x21201851,0x6b815ba1,0x2fd201ff,0xbeaa00d1}},	//   skih_, _nilg, rtyg_, اهان_,
   {{0xc33302b5,0x248d024e,0x6d595ba2,0x6aa80147}},	//   _מוז_, žeme_, fowa, _redf,
   {{0x6d59004e,0x395d0221,0x6b81001e,0x2d5c0453}},	//   gowa, _nkws_, _ailg, víes_,
   {{0x6b8108a1,0x4c560037,0x00000000,0x00000000}},	//   _bilg, حضار, --, --,
   {{0x6b815ba3,0xd788055c,0x00000000,0x00000000}},	//   _cilg, _bển_, --, --,
   {{0x6d595ba4,0xbea302fb,0x6b81004b,0x00000000}},	//   bowa, _хаск, _dilg, --,
   {{0x3eaa04ce,0x6b890033,0x6d59004e,0xee37002d}},	//   _hebt_, _fueg, cowa, _унс_,
   {{0x6b81035f,0x0c261b4f,0x5ecf0033,0x6d930024}},	//   _filg, _уман, _হোটে, _għab,
   {{0x6b815ba5,0x2d8a5ba6,0x95d80370,0x8afc0035}},	//   _gilg, _kube_, адот_, _chęt,
   {{0x9f400831,0x2f5b0317,0x753d00b5,0x2d8a00be}},	//   lvió_, רדינ, tisz, _jube_,
   {{0x6ed800b8,0x3eaa033b,0x2fc00075,0x555900d8}},	//   न्तु, _lebt_, krig_, рамя_,
   {{0x48e30035,0x6d43000d,0x753d00b5,0x2b5e0225}},	//   _फ़ोटो_, énai, risz, _kktc_,
   {{0x2fc01cfb,0x6d595ba7,0x87b7011d,0xa5f85ba8}},	//   drig_, zowa, _פלוס_, _веку_,
   {{0x2d8a5ba9,0x79822971,0x6d590054,0x6f150f86}},	//   _nube_, _kiow, yowa, _rozc,
   {{0x61fa003e,0x2fc05baa,0x90995bab,0x00000000}},	//   ætla, frig_, рват_, --,
   {{0x506733d8,0x2d9801f7,0x2d8a00f7,0xe7ed0066}},	// [5830] ства, _atre_, _aube_, ड़िया_,
   {{0x2d8a5bac,0x6b890453,0x6d590067,0x00000000}},	//   _bube_, _rueg, wowa, --,
   {{0x6d59006a,0xe7ea0035,0xa2ce25de,0x6b81008c}},	//   towa, _जैसा_, _तात्, _rilg,
   {{0x2d8a5bad,0x6b813acd,0x0dc80183,0x20c70279}},	//   _dube_, _silg, суфи_, _усог,
   {{0x6d590755,0x2d9802e1,0x6b890382,0x2fc00176}},	//   rowa, _etre_, _queg, crig_,
   {{0x6d59006a,0x612a024e,0x6ed80c57,0x699507e5}},	//   sowa, _výle, न्दु, орих,
   {{0x80ac00c8,0x6d595bae,0x2d8a01a0,0xa91c0168}},	//   _ছাত্, powa, _gube_, _guľk,
   {{0x3f8b012e,0x6b815baf,0xf41f00c3,0x2bd1021a}},	//   _kucu_, _wilg, kyä_, _समपा,
   {{0x2d8a003a,0x6b812d11,0xe0df0107,0x798200d1}},	//   _zube_, _tilg, _ajòk_, _diow,
   {{0x2caf1281,0xeab100fd,0x2d980185,0x00000000}},	//   lagd_, _آٹا_, _ytre_, --,
   {{0x6123007c,0x36690610,0x3f8b06d4,0x672108b7}},	//   _põll, рано_, _lucu_, rklj,
   {{0x27e0002d,0xe0df0107,0x26dc0103,0x3f83080a}},	//   _ţine_, _djòk_, _ebvo_, _liju_,
   {{0x3f8b0160,0x9cd600a5,0x27e90118,0x00000000}},	//   _nucu_, חורה_, _èan_, --,
   {{0x59dd0ca1,0x7c2401a6,0x60cf5bb0,0x2fc05bb1}},	//   _महार, ùiri, _accm, vrig_,
   {{0x637201b4,0x636000fd,0x00000000,0x00000000}},	//   hæng, dönt, --, --,
   {{0x3f8b00d7,0x09be0033,0x2fc05bb2,0x2d8a0371}},	//   _bucu_, _আহমা, trig_, _rube_,
   {{0x78ab0332,0x3f8b0ec0,0x2d8a0020,0x2fc05bb3}},	// [5840] _megv, _cucu_, _sube_, urig_,
   {{0xe6b704aa,0xdfcf02de,0x2fc05bb4,0xf41300b5}},	//   _आयोज, ئيل_, rrig_, _آؤٹ_,
   {{0x0caa027a,0xee3a03fa,0x00000000,0x00000000}},	//   атли_, јне_, --, --,
   {{0xdca3136a,0xed5a00c3,0x00000000,0x00000000}},	//   даци, шое_, --, --,
   {{0xed4f00b5,0xfbcf0833,0x3f830207,0x0b9329fe}},	//   ڑھے_, نتو_, _fiju_, وجود,
   {{0x9f4000de,0xada65bb5,0x0efa00d8,0x2d8a3ebe}},	//   rvió_, _магл, _тэмы_, _tube_,
   {{0xcebf00b8,0xdd920609,0x9f4002d7,0x69c129ad}},	//   _úřad_, _آور_, svió_, रंगी,
   {{0x481424c8,0x637201b4,0xed570a7c,0xf1e20067}},	//   змис, lænd, _дос_, _पहनन,
   {{0x8c430009,0xc17302b8,0xfbd1000c,0x78ab00ea}},	//   _жете, וחה_, _समयम, _degv,
   {{0x27ef0168,0x00000000,0x00000000,0x00000000}},	//   _dsgn_, --, --, --,
   {{0x7bc2309a,0x2d85006c,0x612300ab,0x636001ae}},	//   lrou, _élet_, _sõlm, höns,
   {{0xe4e702ce,0x2bb10461,0xf41f00c3,0xd7fa0dec}},	//   ціон, ुंचा, tyä_, _вук_,
   {{0x39490ce9,0x2906081b,0x636026be,0x2d8405f0}},	//   čast_, _inoa_, yönt, _mime_,
   {{0x7c2f0723,0x2b030066,0xa3dc04aa,0x63b600c7}},	//   _ücre, लाएँ_, _ठहर_, _dvyn,
   {{0xd13b01d3,0x3f8b566d,0xf41f00c3,0x2d840211}},	//   аха_, _sucu_, syä_, _oime_,
   {{0x2d84007c,0x7bc25bb6,0x3f8300f4,0x2729021d}},	//   _nime_, krou, _siju_, _iúna_,
   {{0x3f835bb7,0x63601b7a,0xb287002d,0x00000000}},	// [5850] _piju_, tönt, _мынк, --,
   {{0x2d8402e1,0x26cc5bb8,0x6e67389d,0x21cb002d}},	//   _aime_, ngdo_, отеж, _кымп_,
   {{0x272901ba,0x8c3d5bb9,0x0dcb0819,0x0cd65bba}},	//   _júna_, _ieşi, рузи_, ठभूम,
   {{0x5c754ea4,0x2d845bbb,0x62950067,0x00000000}},	//   плет, _cime_, lczo, --,
   {{0x7bc25bbc,0x799a003c,0x60cd0054,0x78ab5bbd}},	//   grou, _attw, mgam, _regv,
   {{0x60cd5bbe,0xdefb01c8,0x29065bbf,0x2fc9006d}},	//   lgam, _тым_, _anoa_, muag_,
   {{0x272900fb,0x13e40083,0x2fc95bc0,0x38690009}},	//   _núna_, মিয়, luag_, _šar_,
   {{0x7bc25bc1,0x24895a67,0x2d840409,0x8c3d0139}},	//   brou, _ngam_, _gime_, _leşi,
   {{0x853d01c8,0xd90c00bf,0x2572024e,0x7bc24c7a}},	//   ipėd, شیو_, nále_, crou,
   {{0x2489006e,0x2d8433ee,0x6b9b5bc2,0x8aa700af}},	//   _agam_, _zime_, _itug, _фрад,
   {{0xf9f9064e,0x2fc901e8,0x50cb252b,0xfaa800f3}},	//   _دفاع_, huag_, िलाष, _ذهني_,
   {{0x6d4b5bc3,0x60cd01f4,0x01d10033,0x691c000d}},	//   nnga, jgam, াবাদ, _dées,
   {{0x8c3d008f,0x68e95bc4,0x60cd0d51,0x9d1a0070}},	//   _beşi, meed, dgam, צושט,
   {{0xe2974ae8,0x68e95bc5,0x69c30afc,0x27ed02d0}},	//   зар_, leed, orne, mwen_,
   {{0xc69200c2,0x6d4b39c5,0x27ed5bc6,0x27290079}},	//   _טאג_, knga, lwen_, _gúna_,
   {{0x39915bc7,0x55ba0052,0x2cad35dd,0x60cd32e1}},	//   _más_, _המקו, _need_, ggam,
   {{0x48dd045c,0xd0070af5,0x637201b4,0x69c3033b}},	// [5860] क्यो_, пете_, tænd, hrne,
   {{0x68e918e7,0x7bc25bc8,0x6d4b5bc9,0x2d845bca}},	//   heed, vrou, enga, _sime_,
   {{0x3991114d,0x44220173,0x6b9b1642,0x68e900be}},	//   _nás_, lyk_, _atug, keed,
   {{0x7bc25bcb,0x60cd00ee,0x6d4b2487,0x68e9013a}},	//   trou, cgam, gnga, jeed,
   {{0x68e900b9,0x2d8402c4,0x69c35bcc,0x8c3d01d6}},	//   deed, _vime_, erne, _yeşi,
   {{0x6d4b5bcd,0xf7670493,0x6b9b004f,0x3991004f}},	//   anga, _سا_, _dtug, _bás_,
   {{0x2d845bce,0xdca6031a,0x68e95bcf,0x27ed0051}},	//   _time_, _нави, feed, ewen_,
   {{0x07980202,0x44225bd0,0x7bc25bd1,0x2d84006b}},	//   овић_, kyk_, prou, _uime_,
   {{0x69c30d24,0xb8d40084,0x6d421e86,0xba3c00c7}},	//   arne, _जज_, mioa, _neįv,
   {{0x6d425bd2,0x44225bd3,0x39910037,0x1037011d}},	//   lioa, dyk_, _fás_, פטים_,
   {{0x39915bd4,0x7c2202d0,0xba9b0122,0x60cd027d}},	//   _gás_, lyor, _הסבי, ygam,
   {{0x7aea5bd5,0x6d421fbf,0x68e900a5,0x00000000}},	//   left, nioa, ceed, --,
   {{0x7c225bd6,0x645a002d,0x2fc901e8,0x8c3d027d}},	//   nyor, ştin, xuag_, _peşi,
   {{0x612300ab,0x7aea5bd7,0x490400b8,0x69d812ba}},	//   _tõlk, neft, वाको_, otve,
   {{0xe9ff00e8,0x69d85bd8,0x69ca0069,0xd6db0122}},	//   _phẩm_, ntve, nufe, _החול,
   {{0x46d800b4,0x7aea5bd9,0x613133d4,0x60cd00c7}},	//   ब्रह, heft, _målg, ugam,
   {{0x752d01ed,0xa0540210,0x205400af,0x2cad09e8}},	// [5870] _ilaz, евті, ектя, _reed_,
   {{0x51875bda,0x7aea0124,0x69d810c0,0x6d4b5bdb}},	//   _нума, jeft, ktve, wnga,
   {{0x27ed0c1f,0x9f40008e,0xe9ff01a5,0x6b9b5bdc}},	//   zwen_, rvið_, _thẩm_, _stug,
   {{0x39915bdd,0x69c31bd8,0x6d421fbf,0x6d4b002f}},	//   _rás_, vrne, gioa, unga,
   {{0x6d932251,0x68e90033,0x386600d7,0x752d011c}},	//   _għan, veed, _nyor_, _mlaz,
   {{0x69d85bde,0x68e95bdf,0x39910097,0x6d4b0450}},	//   ftve, weed, _pás_, snga,
   {{0x442249d3,0x27ed0069,0x68e95be0,0x2cad00ab}},	//   zyk_, wwen_, teed, _teed_,
   {{0x3991086d,0x6d420043,0x7c2204fb,0xc2e90033}},	//   _vás_, cioa, byor, খাটি_,
   {{0x68e95be1,0x27ed0a75,0xf1b80484,0xf09402b5}},	//   reed, uwen_, ġġi_, ענץ_,
   {{0x27ed5be2,0x7d1b0052,0x752d3998,0xa3d70517}},	//   rwen_, _hous, _alaz, _सहज_,
   {{0x7bcb5be3,0x7d1b5be4,0x442256dd,0x68e900be}},	//   lugu, _kous, wyk_, peed,
   {{0xc3295be5,0x7d1b2911,0x44225be6,0xd46a3669}},	//   _דו_, _jous, tyk_, жиме_,
   {{0x394d12c3,0xd90f006c,0x7bcb1292,0x395f5be7}},	//   mnes_, _لیں_, nugu, mous_,
   {{0x395f5be8,0x6d4203cb,0x7d1b5be9,0x44225bea}},	//   lous_, zioa, _lous, ryk_,
   {{0x394d00c8,0x7bcb3908,0x44221627,0x7ae10069}},	//   ones_, hugu, syk_, _mblt,
   {{0x394d5beb,0x752d029d,0x7d1b0086,0x7bcb25b6}},	//   nnes_, _glaz, _nous, kugu,
   {{0xef1a4bf1,0x394d5bec,0xdb0b0332,0xa06701b8}},	// [5880] ома_, ines_, zsgá, дата_,
   {{0xe7e507ba,0x395f28c3,0x7bcb5bed,0x9f4b027a}},	//   _कहना_, hous_, dugu, _uscì_,
   {{0x7d1b5bee,0x2d9c00da,0x394d5bef,0x6d425bf0}},	//   _bous, ëve_, knes_, tioa,
   {{0x7d1b5bf1,0x395f12c3,0x2d9c0029,0x53d20325}},	//   _cous, jous_, īve_, _तमाश,
   {{0x6d425bf2,0x7bcb5bf3,0x7d1b5bf4,0x7d0907ff}},	//   rioa, gugu, _dous, _dnes,
   {{0x394d5bf5,0x7d095bf6,0x6d425bf7,0x69d802ce}},	//   enes_, _enes, sioa, ttve,
   {{0x7aea5bf8,0x395f5bf9,0x7d1b5bfa,0x7bcb0029}},	//   reft, fous_, _fous, augu,
   {{0xa2be10aa,0x394d5bfb,0x69d80173,0x69ca01ae}},	//   वृत्, gnes_, rtve, rufe,
   {{0x6d4007c9,0x6f1c5bfc,0x2002012f,0xc8bf0066}},	//   _imma, _korc, _jrki_, _एयरट,
   {{0x394d5bfd,0x65645bfe,0x69d85bff,0x752d0520}},	//   anes_, _akih, ptve, _slaz,
   {{0x6f1c5c00,0x645a002d,0x395f5c01,0x752d35f9}},	//   _morc, ştil, bous_, _plaz,
   {{0x2ca60c7c,0x6b88011e,0x394d063b,0x657600e9}},	//   nbod_, _hidg, cnes_, _chyh,
   {{0x248d1bfc,0x273201a5,0x752d003d,0x1af10831}},	//   žemo_, _nâng_, _vlaz, চারে_,
   {{0x6d93048c,0x613104ca,0x6f1c1751,0x6b880024}},	//   _bħal, _måle, _norc, _jidg,
   {{0x6d400103,0x20025c02,0x7bcb5c03,0xd5af002d}},	//   _omma, _arki_, zugu, _шс_,
   {{0x752d01cc,0x39445c04,0x6d93009f,0x645a000d}},	//   _ulaz, nims_, _dħal, écié,
   {{0x6f1c048f,0x7d1b5c05,0x2ca65c06,0x613104c1}},	// [5890] _borc, _rous, dbod_, _nåle,
   {{0x6d405c07,0x394d5c08,0xce6b2e76,0x7d1b5c09}},	//   _amma, znes_, оред_, _sous,
   {{0x7d1b2870,0x6d932251,0x68e20478,0x6f1c02a8}},	//   _pous, _għal, _obod, _dorc,
   {{0x63ad0a15,0x7bcb5c0a,0x6d5a0093,0x613104c1}},	//   _kwan, tugu, _ítal, _båle,
   {{0xbbeb2087,0x6f1c2c2e,0x6b8810c3,0x6131013c}},	//   ترام_, _forc, _bidg, _våld,
   {{0x63ad43dd,0x26e300c8,0x394d01a2,0x7bcb0010}},	//   _mwan, _কোনো_, wnes_, rugu,
   {{0x7d1b5bee,0x394d5c0b,0x7bcb007c,0xa2d70d43}},	//   _tous, tnes_, sugu, _बान्,
   {{0x7d095c0c,0x394d5c0d,0x7bcb5c0e,0x21295c0f}},	//   _unes, unes_, pugu, nkah_,
   {{0x394d5c10,0x8b670082,0x395f5c11,0xd7e600c3}},	//   rnes_, _قائم, rous_, емые_,
   {{0x395f5c12,0x394d5c13,0x21290ad6,0x25720037}},	//   sous_, snes_, hkah_, dála_,
   {{0x63ad5c14,0x394d5c15,0x2d91023a,0x61312172}},	//   _awan, pnes_, _juze_, _målb,
   {{0x63ad3d10,0x2d915c16,0x67b9250f,0x68e200fe}},	//   _bwan, _muze_, _فاتح_, _gbod,
   {{0x78270789,0x25720037,0x68fb009f,0xdcfc00ea}},	//   _تعال, gála_, mdud, _strī,
   {{0x3d060e1d,0x27320012,0x68f9001e,0x68fb0e78}},	//   _सोने_, _când_, _hawd, ldud,
   {{0x2ca60297,0xc7b9006c,0x21290034,0xc0e62698}},	//   ybod_, lső_, fkah_, новк,
   {{0x68fb1201,0x6f1c5c17,0xaadf00b4,0x4adf012f}},	//   ndud, _sorc, प्तक, प्तव,
   {{0x63ad5c18,0x68f90090,0x291d0035,0xdb0b0093}},	// [58a0] _gwan, _mawd, _mowa_, yrgð,
   {{0x2d915c19,0x27325c1a,0x68fb00a8,0x629200a0}},	//   _buze_, _vâng_, hdud, ékoľ,
   {{0xaac910aa,0x63ad5035,0x61315c1b,0xecea1583}},	//   _राजक, _zwan, _såle, здел_,
   {{0x6f1c081f,0x0b8a11b9,0x8fa624da,0x82370118}},	//   _worc, пски_, _паме, _سرپا,
   {{0x6f1c5c1c,0xdb9701c8,0xead41a6d,0x6123007c}},	//   _torc, евіч_, воль, _põlv,
   {{0x45160033,0x27e6009e,0x6d930069,0x5ec70831}},	//   াসিক_, _rpon_, _mħaj, র্বে,
   {{0x394412c3,0x2d910124,0x6b88026a,0x68f90090}},	//   tims_, _guze_, _vidg, _bawd,
   {{0x6d403679,0x68fb18ad,0x88840118,0x8c3d00af}},	//   _umma, gdud, نیان, _peşt,
   {{0x3944010b,0x20005c1d,0x3d060066,0x291d0027}},	//   rims_, nvii_, _सोये_, _dowa_,
   {{0x63ad5c1e,0x3f8a000e,0x394401f7,0x660300d5}},	//   _rwan, _jibu_, sims_, _brnk,
   {{0x63ad5c1f,0x66030e5e,0x18a6144b,0x2732002d}},	//   _swan, _crnk, _заем, _rând_,
   {{0x80e00b52,0x7afa5c20,0x291d0ac8,0x63ad36e0}},	//   _পোস্, _hatt, _gowa_, _pwan,
   {{0x67d4002d,0x27e60122,0x657d01e9,0x00000000}},	//   _ролу, _upon_, rmsh, --,
   {{0xe7e50299,0x25725c21,0x7afa035f,0x938800c3}},	//   _कहता_, rála_, _jatt, есса_,
   {{0x31c407c1,0x7afa5c22,0x4ac90096,0x63ad012f}},	//   лств, _matt, _राघव, _wwan,
   {{0x63ad5c23,0x3f8a0054,0x21291c26,0x2d910124}},	//   _twan, _aibu_, ukah_, _ruze_,
   {{0x2d9103fd,0xa3e5007c,0x63ad5c24,0x6d93048c}},	// [58b0] _suze_, _नहि_, _uwan, _għaj,
   {{0x7afa0b87,0x212954d2,0xa85700a5,0x2d910207}},	//   _natt, skah_, תימה_, _puze_,
   {{0x22640187,0x238a00a0,0x62350043,0xbf9b0298}},	//   čské_, žujú_, _рену, _grên,
   {{0x2d9102d7,0xa3e507b5,0x7afa0421,0x00000000}},	//   _vuze_, _नहा_, _aatt, --,
   {{0x7afa5c25,0x255600ea,0x291d0088,0x27320160}},	//   _batt, nāla_, _rowa_, _zâne_,
   {{0xbbd108b6,0x68f9035f,0x2fc9011e,0x0c2400d8}},	//   _समीक, _sawd, mrag_, ымін,
   {{0x7afa1217,0x628801f2,0xe9ff0019,0xbe650bdf}},	//   _datt, ždov, _thậm_, _شهري,
   {{0x2cbf01cb,0x8d7701cb,0x00000000,0x00000000}},	//   _udud_, _سازا, --, --,
   {{0x7afa5c26,0x68fb5c27,0xdc1300a8,0xe8f61385}},	//   _fatt, rdud, pşır, тлы_,
   {{0x7afa5c28,0x27ff05ee,0xecd10387,0x00000000}},	//   _gatt, rvun_, _हाँफ, --,
   {{0x64a65914,0x25ae099e,0x291d0103,0x5bd1018d}},	//   кана, _cwfl_, _towa_, _समुव,
   {{0xe89401c8,0x7afa4ce3,0x2b4744e4,0x2fc903bc}},	//   _баць, _zatt, linc_, krag_,
   {{0x7afa34df,0x78a95c29,0x2bc90066,0x00000000}},	//   _yatt, mbev, _रिफा, --,
   {{0x03a303ad,0x2b470069,0x20000036,0x66030a69}},	//   риро, ninc_, vvii_, _trnk,
   {{0x3f8a005d,0x80e00083,0xe29715df,0x798b1815}},	//   _ribu_, _পোষ্, тас_, _kigw,
   {{0x78a90c7c,0x3f8a1f8a,0x2b47023a,0xa2ce021a}},	//   nbev, _sibu_, hinc_, _ताक्,
   {{0xf8b200c2,0x21670b3b,0x2fc901cb,0x54a50037}},	// [58c0] ישן_, тити_, grag_, _صحيف,
   {{0x6123007c,0x6d930024,0x798b0298,0x20005c2a}},	//   _sõlt, _għak, _ligw, rvii_,
   {{0x7afa5c2b,0xb6060300,0x425600ed,0x612300be}},	//   _ratt, _ibáñ, _штит, _põlt,
   {{0x7afa1cf9,0x80e00033,0x2fc93458,0x00000000}},	//   _satt, _পোর্, brag_, --,
   {{0xeb970072,0x7afa5c2c,0x30750395,0x612300be}},	//   вич_, _patt, _бурс, _võlt,
   {{0x7afa007a,0x00000000,0x00000000,0x00000000}},	//   _qatt, --, --, --,
   {{0x7afa06d7,0x3cfd0324,0x798b4264,0xe45f5c2d}},	//   _vatt, _रोके_, _bigw, ngör_,
   {{0x7afa5c2e,0x5ec70083,0x1bea0279,0x00000000}},	//   _watt, র্দে, _одби_, --,
   {{0x798b0297,0x7afa5c2f,0x00000000,0x00000000}},	//   _digw, _tatt, --, --,
   {{0xa2d706d9,0x613115ed,0x255600ea,0x00000000}},	//   _बाध्, _måla, vāla_, --,
   {{0x2d8c00fd,0xa37b0183,0x00000000,0x00000000}},	//   _édes_, ntõe, --, --,
   {{0xb4ad0a44,0x64bf0026,0x77920a86,0xc4bf0d53}},	//   गरे_, ्लेश, _پیدا, ्लेख,
   {{0xd6d20e3a,0xe9ff0019,0x38cb0987,0x61310523}},	//   _نقش_, _thảm_, _زانی_, _nåla,
   {{0x2d87244b,0x70cb01c0,0x44395c30,0x569300d8}},	//   ínez_, िल्ल, rzs_, _кашт,
   {{0x442d0a23,0x5224004b,0x673d0055,0x798b0027}},	//   še_, афта, ësje, _yigw,
   {{0x2fc95c31,0x39984045,0x69ca0037,0x30a403e6}},	//   trag_, _més_, irfe, ирув,
   {{0xaad2004e,0x6f0e00d7,0x7059027a,0xa0750274}},	// [58d0] _सांक, _bnbc, хаар_, угач,
   {{0x656f5c32,0x61f900d8,0x985500a8,0xa2f501e0}},	//   llch, _зноў_, _ləğv_, _споч,
   {{0x399800f7,0xe8df0023,0x656f5c33,0x2b475c34}},	//   _nés_, hiền_, olch, vinc_,
   {{0xdcfc0095,0xf65300a5,0xd01000b5,0x00000000}},	//   _vurğ, בצע_, حلے_, --,
   {{0x798b003c,0xfc30017e,0xc05b01e0,0x656f5c35}},	//   _rigw, يحه_, _цін_, ilch,
   {{0xab6401c8,0xc5e90033,0x798b4734,0x00000000}},	//   авіл, গিতা_, _sigw, --,
   {{0xa9695c36,0x798b0107,0x2b47026b,0x00000000}},	//   ника_, _pigw, rinc_, --,
   {{0xe9ff0019,0x6c8500b5,0x39980320,0x8d7400b5}},	//   _chạm_, _ملزم, _dés_, _ناقا,
   {{0x78a913dc,0x6c555c37,0x2b490037,0x090201f1}},	//   rbev, _скау, éacs_, спын,
   {{0x656f5c38,0x46f52839,0x78a95030,0x39980310}},	//   elch, учит, sbev, _fés_,
   {{0x458632f6,0x2b450176,0x2d8d0118,0x27295c39}},	//   лгов, _imlc_, _kiee_, _júni_,
   {{0x4adf0a90,0xaadf065f,0x03a610e3,0x629c012f}},	//   प्रव, प्रक, лимо, wcro,
   {{0x66e532a6,0x290f5c3a,0xc98400af,0xbf9b00f6}},	//   _бола, _inga_, _туфи, _brêm,
   {{0xcc3a00c2,0x656f00f1,0xa3d5007c,0xdc3a0070}},	//   געשט, alch, _हमर_, געשר,
   {{0x6d930024,0x2d8d021d,0x00000000,0x00000000}},	//   _iħaw, _oiee_, --, --,
   {{0x26f3021a,0x21760279,0x6131038d,0x00000000}},	//   _असुर_, ѓувр, _påla, --,
   {{0xb4d008b0,0xe0df009e,0x00000000,0x00000000}},	// [58e0] शली_, _smòc_, --, --,
   {{0x63a45c3b,0xe8d00311,0xbf9b03e6,0x65665c3c}},	//   _itin, _सञ्च, _grêm, lokh,
   {{0x290f010d,0x61460384,0x255600ea,0x63a4009e}},	//   _onga_, _бена, nālo_, _htin,
   {{0xa37b03e6,0x290f0008,0x273200af,0x39981186}},	//   rtõe, _nnga_, _mâna_, _rés_,
   {{0x77f210aa,0xa37b0370,0x399801ef,0x60d600e9}},	//   _अनेक_, stõe, _sés_, mgym,
   {{0x81c900c8,0x290f5c3d,0x39980f84,0x63a40054}},	//   োবর_, _anga_, _pés_, _mtin,
   {{0xe9ff0028,0x82970122,0x656f001e,0xa3d60141}},	//   _phạm_, נדקס_, ylch, ांड_,
   {{0xa9670798,0x63a40051,0x69ca0069,0x63bd01ff}},	//   лија_, _otin, rrfe, yssn,
   {{0x3d1102cb,0x28d500b4,0xfaa61129,0x473432a6}},	//   णारे_, _धारि, _базо, инис,
   {{0xd6da263c,0x58370086,0x290f5c3e,0x28a40266}},	//   хти_, узья_, _enga_, _ग्रि,
   {{0x63a45c3f,0x49ca010c,0xa2ce00a1,0xaa930b82}},	//   _atin, _член_, _ताज्, _المث,
   {{0x9f4900fb,0xa2d70d53,0xd6ac0083,0x63a4009e}},	//   hvað_, _बाह्, _খাওয, _btin,
   {{0xbf9b0370,0x39460042,0x78bd008d,0x3eba0223}},	//   _prêm, _imos_, ðsve, kapt_,
   {{0x39460221,0x63a400ce,0x6d93003c,0x00000000}},	//   _hmos_, _dtin, _għaw, --,
   {{0x2d9c0370,0x356b09eb,0x5fc70006,0x613801ef}},	//   ível_, _прин_, _लिहल, _xílg,
   {{0xddcb003c,0x3d18021a,0xc4460118,0x00000000}},	//   ċiżj, फाफे_, ایین_, --,
   {{0x3ecb0274,0x27320395,0x00000000,0x00000000}},	// [58f0] ећем_, _zâna_, --, --,
   {{0x6360006c,0x9ed800af,0x3cfd0d43,0x00000000}},	//   köny, лмут_, _रोजे_, --,
   {{0x2d8d00d7,0x62880097,0xa3cd0026,0x60ce01fb}},	//   _piee_, ždor, शंक_, _şimş,
   {{0x3946022e,0xe7e5007c,0x00000000,0x00000000}},	//   _nmos_, _कहला_, --, --,
   {{0x6e952491,0xfe7000b5,0x8d740037,0x613103c1}},	//   _вигу, _ہدف_, حالا, _hålo,
   {{0xa3d65c40,0xeb960227,0x9f350044,0x290f011e}},	//   ांत_, шиш_, _тегі, _snga_,
   {{0x2bd105a6,0x00000000,0x00000000,0x00000000}},	//   _समका, --, --, --,
   {{0x5ec70083,0xa925020a,0x2b990176,0x61310532}},	//   র্শে, рдил, _tèc_, _målo,
   {{0x6d4b5c41,0xead51ac5,0x64c800c7,0x00000000}},	//   miga, _возь, nčių, --,
   {{0x3cff0d4b,0x6d4b5c42,0x39465c43,0xe9ff0019}},	//   _hauv_, liga, _emos_, _nhầm_,
   {{0xbb84004f,0x3cff01e8,0x7c2b5c44,0x656600b5}},	//   _اللي, _kauv_, lygr, tokh,
   {{0x290f5c45,0x6d4b5c46,0xe9d0017e,0x693300f8}},	//   _unga_, niga, _رغم_, _دکتر,
   {{0xe72e5c47,0x3cff0221,0x613800fe,0x00000000}},	//   _де_, _mauv_, _jíle, --,
   {{0xb6a53945,0x6d4b5c48,0x46a50798,0x3cff5c49}},	//   _тикл, higa, _такв, _lauv_,
   {{0x6d4b5c4a,0xa2d70d53,0x00000000,0x00000000}},	//   kiga, _बार्, --, --,
   {{0x6d4b02f6,0x10a65c4b,0x6723012f,0x00000000}},	//   jiga, риан, _honj, --,
   {{0x6d4b5c4c,0x67235c4d,0x63a44583,0xcf46027a}},	// [5900] diga, _konj, _utin, анай,
   {{0x613106d7,0xe7f80380,0x6d4b3049,0x3f8e0093}},	//   _håll, ्टता_, eiga, öfu_,
   {{0xbca6026e,0x67235c4e,0x46dd0026,0x61381725}},	//   لماي, _monj, _मानह, _píld,
   {{0xb64c02b5,0x672302d0,0xfce6534c,0x61385c4f}},	//   עגאָ, _lonj, родо, _bíle,
   {{0x3cff006d,0x2ca90f56,0x69c14541,0x613800b8}},	//   _dauv_, ñada_, _avle, _cíle,
   {{0xa9c60ae1,0x61385c50,0x9f420107,0xf7670037}},	//   асик, _díle, _eskò_, _ذا_,
   {{0x6d4b5c51,0xd6bb0083,0x3946012f,0x3eb80139}},	//   biga, ংলায, _pmos_, _iert_,
   {{0x6d4b25e4,0x752401d7,0x3eb80a76,0xb4d0018d}},	//   ciga, _noiz, _hert_, शलो_,
   {{0x67235c52,0x14a725de,0x69c101d6,0xa2d70b54}},	//   _bonj, _क्षण, _evle, _बाल्,
   {{0x67234518,0x7d005c53,0x47344b66,0xf1bf016f}},	//   _conj, _hams, снос, žšie_,
   {{0x5f17021a,0x3eb80332,0x672301cc,0x7d005c54}},	//   नात्_, _mert_, _donj, _kams,
   {{0x7d025c55,0x2d985c56,0x7d005c57,0x354730ed}},	//   ndos, _mure_, _jams, рхов,
   {{0xb79603fa,0x7d021f39,0xe9ff00e2,0x25a90124}},	//   _трећ, idos, _phầm_, _čale_,
   {{0x6d4b4318,0x67235c58,0x7d0200c3,0x2bc9111b}},	//   ziga, _gonj, hdos, _रिसा,
   {{0x6d4b010a,0x9f400223,0x61310282,0x48dd29ad}},	//   yiga, atië_, _fåll, क्को_,
   {{0x752406a2,0x672301f4,0x44b5052c,0x7d005c59}},	//   _goiz, _zonj, _убис, _nams,
   {{0x3eb85c5a,0x3cff01e8,0xe9ff0019,0x656d5c5b}},	// [5910] _bert_, _rauv_, _thầm_, _ikah,
   {{0x3eb85c5c,0x2d985c5d,0x3cff01e8,0x6d4b5c5e}},	//   _cert_, _bure_, _sauv_, wiga,
   {{0x3cff0189,0x7d005c5f,0x6d4b0cec,0x2bc9162b}},	//   _pauv_, _bams, tiga, _रिहा,
   {{0xe1f01aa6,0x7d005c60,0x3cff0189,0x61383346}},	//   _کسی_, _cams, _qauv_, _píle,
   {{0x6d4b5c61,0x2d985c62,0xfc050923,0x3cff0221}},	//   riga, _eure_, спло, _vauv_,
   {{0x3eb85c63,0x6d4b5c64,0x3da70370,0x2d983413}},	//   _gert_, siga, _враб, _fure_,
   {{0x2d980291,0x6d4b5c65,0x3cff01e8,0xdef800d8}},	//   _gure_, piga, _tauv_, _тыя_,
   {{0x67235c66,0xe9a8004f,0x7d005c67,0x656d010a}},	//   _sonj, جدون_, _gams, _nkah,
   {{0xb8ff0fcd,0x6d495c68,0x2d980291,0x3ea10037}},	//   _ता_, _imea, _zure_, ocht_,
   {{0x3f995c69,0x2572008d,0x656d2a13,0x49b800b5}},	//   _musu_, máli_, _akah, _چاند_,
   {{0x3ea102c9,0x67235c6a,0x1e3a0070,0x7524008b}},	//   icht_, _vonj, ָגרא, _poiz,
   {{0xc32901f3,0x200b5c6b,0xb895004f,0x2fc00297}},	//   _או_, _orci_, _الإع, ysig_,
   {{0x394d5c6c,0x6723022e,0x3f990054,0x291f1476}},	//   mies_, _tonj, _nusu_, mjua_,
   {{0x673a0120,0x3f910a23,0xdce202c4,0x6d930024}},	//   chtj, _nizu_, ploć, _jħas,
   {{0x2bd10299,0x200b027a,0xa5ce0803,0x43430265}},	//   _समझा, _arci_, _थियौ, черв,
   {{0x3eb85c6d,0x3f4f00ea,0x3ea10bf7,0x2fc05c6e}},	//   _sert_, kļus_, echt_, tsig_,
   {{0x4e9602aa,0x2d985c6f,0xb4b400b4,0x2fc01511}},	// [5920] مشار, _sure_, टरी_, usig_,
   {{0x2d985c70,0x6d495c71,0x3f995c72,0x2fc0053e}},	//   _pure_, _amea, _dusu_, rsig_,
   {{0x3eb80a55,0x2fc00588,0xea000023,0x3f9101d7}},	//   _vert_, ssig_, _đắk_, _dizu_,
   {{0x3ea10082,0x394d5c73,0x61fe5912,0x3eb801ae}},	//   acht_, jies_, _ispl, _wert_,
   {{0x394d5c74,0x6d5b022e,0xe6070a86,0x3f99022e}},	//   dies_, _djua, _کش_, _gusu_,
   {{0x2d985c75,0x21201851,0x63b6001e,0x7d0201f4}},	//   _ture_, ljih_, _mwyn, sdos,
   {{0x394d5c76,0x7d005c77,0x79a300d8,0x00000000}},	//   fies_, _tams, прые, --,
   {{0x394d5c78,0x2120068b,0x6d5b0031,0x7d000205}},	//   gies_, njih_, _gjua, _uams,
   {{0x98a30274,0x00000000,0x00000000,0x00000000}},	//   чиње, --, --, --,
   {{0x19ba5c79,0xfe6f006c,0x7bc21a99,0xcafc5c7a}},	//   _будь_, _آگے_, msou, _एसिड_,
   {{0x394d5c7b,0xd9465c7c,0xb996004f,0x27ef01ed}},	//   bies_, _лежи, _الصب, _epgn_,
   {{0x673a01d2,0x394d5c7d,0x316901a3,0x63b6016e}},	//   shtj, cies_, xoaz_, _bwyn,
   {{0xdb09008a,0x63b6001e,0xb97b0070,0x61fe0fa8}},	//   _kveð, _cwyn, _ענדי, _aspl,
   {{0x799a25b0,0x6aba17ad,0x3f995c7e,0x6d93007a}},	//   _kutw, _jetf, _rusu_, _mħar,
   {{0x3f991034,0xe9ff0023,0x5a9b0070,0x417701b2}},	//   _susu_, _thấm_, רשלא, مارس,
   {{0xa3d60567,0x29045c7f,0x799a2d06,0x3f995c80}},	//   ांश_, ndma_, _mutw, _pusu_,
   {{0x61fe5c81,0x645a0723,0x63b6001e,0x2d860051}},	// [5930] _espl, ştir, _gwyn, dmoe_,
   {{0x3ea102c9,0x394d5c82,0x6d495c83,0x799a0f00}},	//   ucht_, zies_, _smea, _outw,
   {{0x2ca90f56,0x70950009,0x2cbd006d,0x20040478}},	//   ñado_, _манф, tawd_, _šmit_,
   {{0x3ea102c9,0x394d5c84,0x200b1269,0x5c751578}},	//   scht_, xies_, _trci_, олет,
   {{0xb6070076,0xeab92bfc,0xab5d007a,0x200b0139}},	//   _koší, айл_, _avża, _urci_,
   {{0x394d5c85,0x9abc0024,0x799a44fa,0x447c016b}},	//   wies_, _doċo, _butw, אנדע,
   {{0x394d5c86,0xf2d40070,0x6aba008c,0x613103d0}},	//   ties_, לעס_, _detf, _nålk,
   {{0x5d540fbb,0x6d495c87,0x9ce700b5,0x63725c88}},	//   _екст, _umea, _دورے_, ræni,
   {{0x394d5c89,0xf71900d8,0xe8df0019,0x6aba0523}},	//   ries_, аіны_, hiện_, _fetf,
   {{0x394d5c8a,0x6d93003c,0xa6990274,0x6d5a0093}},	//   sies_, _għar, шњих_, _ítar,
   {{0x6d590345,0xab8400d8,0x799a010a,0x394d5c8b}},	//   onwa, _хутк, _gutw, pies_,
   {{0x29030080,0x6b9b5c8c,0x63b6001e,0x6aba0051}},	//   ējas_, _kuug, _pwyn, _zetf,
   {{0x69c3242f,0x255600ea,0xaae005a6,0x00000000}},	//   lsne, nāli_, _नामक, --,
   {{0xcb9a0070,0x68e95c8d,0x6b9b4463,0x6d59033b}},	//   יסשט, lfed, _muug, hnwa,
   {{0xcb125c8e,0x320c0355,0x212008b7,0x6d930024}},	//   ולם_, ídy_, tjih_, _lħaq,
   {{0x69c35c8f,0x6138008a,0x6d590051,0x753d5c90}},	//   isne, _bíla, jnwa, chsz,
   {{0xfe7800d8,0x2120008b,0x25a025c4,0x6d5802d7}},	// [5940] _šį_, rjih_, _čili_, évam,
   {{0xef175431,0x3ced0176,0x49100067,0x69c312b6}},	//   ому_, _abev_, _दोनो_, ksne,
   {{0x6aba5c91,0xe4d30416,0x7bc200e0,0x69c35c92}},	//   _retf, _عقید, wsou, jsne,
   {{0x69c35c93,0x6b815c94,0x799a007b,0x6138008d}},	//   dsne, _ahlg, _rutw, _fíla,
   {{0x0ee200b4,0x69c35c95,0x00000000,0x00000000}},	//   _पापड, esne, --, --,
   {{0x6b9b01a2,0x79a61f27,0xaff902b5,0x6d593456}},	//   _duug, орие, _פּרי, anwa,
   {{0x7bc24869,0x68e95c96,0x6131008c,0x69c35c97}},	//   ssou, ffed, _bålh, gsne,
   {{0x2bd20f39,0x63a9002d,0x20070035,0x6b8101ed}},	//   _सिपा, ţeni, łnie_, _ehlg,
   {{0x25720187,0x290201ba,0xd83a00c7,0x6d93035f}},	//   nálu_, ľka_, рэй_, _għaq,
   {{0x29020e6a,0xf72a09eb,0xc8ca04a3,0x6a160037}},	//   žka_, рций_, _چوان_, _وبار,
   {{0xff7b02b5,0x28ab0cf1,0x5ec70033,0x7e9b00a5}},	//   שטימ, _ट्वि, র্কে, יסיו,
   {{0x2009010b,0x00000000,0x00000000,0x00000000}},	//   yvai_, --, --, --,
   {{0x2bd20240,0x69d85c98,0x00000000,0x00000000}},	//   _सिफा, luve, --, --,
   {{0xdcfc01c8,0x491201c0,0x48f400b8,0x2fd20345}},	//   _turė, थाको_, ्यको_, dryg_,
   {{0x69d85c99,0x61381d2b,0xf5b30037,0x1b040033}},	//   nuve, _síla, _قصيد, লাপে_,
   {{0xa2d711b5,0x6edd00a1,0x79820118,0x909902fb}},	//   _बाक्, _पाहु, _jhow, сват_,
   {{0xe5720779,0x4fd50fa7,0x257200d5,0x00000000}},	// [5950] _אַז_, яжат, gálu_, --,
   {{0x69d85c9a,0x6131082b,0x20095c9b,0x69c302ee}},	//   kuve, _måli, rvai_, ysne,
   {{0x69d85c9c,0x6b9b00b9,0x68e900e9,0x200900c7}},	//   juve, _suug, yfed, svai_,
   {{0x69d85c9d,0x6b9b00be,0x00000000,0x00000000}},	//   duve, _puug, --, --,
   {{0x69c3016e,0xbf9b00a2,0xeb995024,0xfaa528ac}},	//   wsne, _crêt, щил_, пало,
   {{0x7982012f,0x69c35c9e,0x257200b5,0x62830097}},	//   _ahow, tsne, lált_, _únos,
   {{0x69d85c9f,0x69c30f00,0xd2b800a5,0x00000000}},	//   guve, usne, חלות_, --,
   {{0x69c35ca0,0x2572006c,0x79825ca1,0x00000000}},	//   rsne, nált_, _chow, --,
   {{0x7982009e,0x69c35ca2,0x2bd20992,0x1bd50086}},	//   _dhow, ssne, _सिया, _хозя,
   {{0x6131022a,0x28ab1fe0,0x7bd9001c,0xa2d704aa}},	//   _dåli, _ट्रि, muwu, _बाग्,
   {{0x4ae002e4,0xb9e700d4,0x3669257f,0xa50a0d28}},	//   _नातव, _фізи, сано_, бена_,
   {{0x79820211,0x00000000,0x00000000,0x00000000}},	//   _ghow, --, --, --,
   {{0xc9520122,0x889a00a5,0x61380093,0x00000000}},	//   _אמא_, _הבני, _bíln, --,
   {{0x443e0067,0x00000000,0x00000000,0x00000000}},	//   ąt_, --, --, --,
   {{0xd252006c,0x61380355,0x661c19ee,0x37bd0033}},	//   رنر_, _díln, ärkt, _আমির,
   {{0x25aa054d,0x5fc7007c,0x613103d0,0x3f83018d}},	//   íble_, _लिखल, _målw, _ahju_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5960] --, --, --, --,
   {{0xdfcf0c26,0x37bd0083,0x7bd9089b,0x257200ac}},	//   ايل_, _আমার, duwu, rálu_,
   {{0x6edd0006,0xe29b00a5,0xa0a60ddc,0x69d8002a}},	//   _पारु, _לשיר, _нанд, xuve,
   {{0xbf9b0248,0xdca35ca3,0xd2dc00dc,0x25721e6b}},	//   _prêt, еаци, _बाँझ, máls_,
   {{0x798200e9,0x628300b8,0xa80601ef,0xc50d016b}},	//   _rhow, _únor, _mañó, ילאָ,
   {{0x79824f73,0x69d85ca4,0x20025ca5,0xbb4318e2}},	//   _show, tuve, _iski_, нечк,
   {{0x7d7a00f8,0x613806fe,0x00000000,0x00000000}},	//   _همسر_, _jílo, --, --,
   {{0x61310c60,0x00000000,0x00000000,0x00000000}},	//   _påli, --, --, --,
   {{0x255600ea,0x2d840421,0x00000000,0x00000000}},	//   nālu_, _ihme_, --, --,
   {{0x6b66021f,0x9b460c36,0xb8d30067,0x200d00f4}},	//   _экза, _عناو, _ज्_, _šeik_,
   {{0x3d110099,0x2572008d,0x7ec700fd,0x24805ca6}},	//   णाचे_, jáls_, lépí, _azim_,
   {{0x4a7b02b5,0xa80605c9,0xda650037,0xba3700a5}},	//   _פראב, _cañó, _غالي, _מטבח_,
   {{0x200201f2,0x5ec70033,0x257200b5,0x25a0023a}},	//   _nski_, র্টে, vált_, _čilu_,
   {{0x3b050095,0x661c06d2,0x9abc003c,0x61380355}},	//   _xalq_, ärks, _soċj, _bílo,
   {{0x200201d7,0x61310df7,0x24800103,0x61380355}},	//   _aski_, _målv, _ezim_, _cílo,
   {{0x672a1c1c,0x59dd0099,0x00000000,0x00000000}},	//   _hofj, नंतर, --, --,
   {{0xb4d90e9b,0x656f006a,0x5f950340,0x257200b5}},	// [5970] ाली_, moch, диат, rált_,
   {{0xd24e0332,0x63ad5ca7,0x09b20083,0x26de0409}},	//   اچی_, _itan, _ঘটনা, ngto_,
   {{0x200201d6,0xdce9003c,0x00000000,0x00000000}},	//   _eski_, _jieħ, --, --,
   {{0x7bd95ca8,0x236100e2,0x00000000,0x00000000}},	//   tuwu, _hjhj_, --, --,
   {{0x69c8053c,0xc1720416,0x22070355,0x00000000}},	//   _avde, _شگفت, bíhá_, --,
   {{0x63ad0657,0x68e20042,0x212b01ae,0xb4d9045c}},	//   _mtan, _acod, _hoch_, ालु_,
   {{0x656f5ca9,0x2bc90fd1,0xaac40413,0x63ad0008}},	//   koch, _रिका, رتون, _ltan,
   {{0x26de0228,0x63ad5caa,0xf8ae0118,0x00000000}},	//   egto_, _otan, لکه_, --,
   {{0xe521012f,0x7989046a,0x63ad01d0,0x212b4749}},	//   यानि_, rmew, _ntan, _moch_,
   {{0x212b111c,0x68e2334e,0x2bd207ba,0xfbd20461}},	//   _loch_, _ecod, _सिता, _सितम,
   {{0x63ad5cab,0x6f07030a,0x7a350037,0xfd640023}},	//   _atan, _majc, _تفاص, _nhuộ,
   {{0x212b0446,0x656f5cac,0xdce9007a,0x5ec70033}},	//   _noch_, goch, _dieħ, র্চে,
   {{0xa2b202b4,0x2cbf00f1,0x7bc900f6,0x00000000}},	//   _अभद्, _meud_, _jveu, --,
   {{0x6f075cad,0x68fb5cae,0x2cbf0284,0x25560228}},	//   _najc, leud, _leud_, vālu_,
   {{0xe2975caf,0xfd6401a5,0x656f5cb0,0x91e32349}},	//   дар_, _chuộ, boch, коре,
   {{0x656f4bcf,0x212b00e9,0x2cbf00e9,0x255600ea}},	//   coch, _coch_, _neud_, tālu_,
   {{0x212b02bf,0xa49400bf,0x6f0740f1,0x1b040033}},	// [5980] _doch_, _سیست, _bajc, লাতে_,
   {{0x6f070009,0x03d70070,0x394f0024,0x27320160}},	//   _cajc, _קוים_, _lmgs_, _pâni_,
   {{0x831b02b5,0x68fb0086,0xa3d6035d,0x61460c94}},	//   _וויז, keud, ांक_, _жена,
   {{0xa2aa0299,0x212b5cb1,0x2cbf00f1,0x6131008c}},	//   जुर्, _goch_, _ceud_, _bålu,
   {{0xe4e60387,0x68fb5cb2,0x20020506,0x0b8a0dc8}},	//   _कानि_, deud, _uski_, оски_,
   {{0x656f5cb3,0x68e25cb4,0x8f7500d8,0x644601a3}},	//   zoch, _scod, _зусі, izki,
   {{0x62980076,0x656f0054,0x9f4b01f7,0x255600ea}},	//   _úvod, yoch, _escó_, nāls_,
   {{0x3f980291,0x60c45cb5,0x4ae0018d,0x3d06007c}},	//   _hiru_, naim, _नावव, _सोचे_,
   {{0x6f07006d,0x656f5cb6,0x3f980176,0xdce9007a}},	//   _yajc, voch, _kiru_, _sieħ,
   {{0x60c45cb7,0x6446004e,0x63ad02c4,0x656f5cb8}},	//   haim, dzki, _rtan, woch,
   {{0x63ad5cb9,0x3f9817ee,0xd5b71397,0x613801ef}},	//   _stan, _miru_, мся_, _píll,
   {{0xb4d91729,0x2bd200a1,0x6d425cba,0x60c45cbb}},	//   ाले_, सळपा, nhoa, jaim,
   {{0xdce9048c,0x60c45cbc,0x212b2c60,0x41a40035}},	//   _wieħ, daim, _roch_, _खूबस,
   {{0xf64f00f5,0xc87f02c9,0xdce9003c,0x212b5cbd}},	//   ائی_, üße_, _tieħ, _soch_,
   {{0x43945cbe,0x656f5cbf,0x6f070791,0xc8080023}},	//   тарс, poch, _rajc, _hở_,
   {{0x60c41201,0x613808bf,0x3f98013a,0x63ad5cc0}},	//   gaim, _fílm, _airu_, _ttan,
   {{0xe8113e72,0x3f150009,0x3f981b0f,0xbf9b000d}},	// [5990] ़िया_, ндас, _biru_, _crêp,
   {{0x212b021e,0xc8080028,0xfd640028,0x63ad00ea}},	//   _woch_, _mở_, _thuộ, ķinā,
   {{0x212b04ce,0x7bc915a9,0x3f9806a2,0xc8080023}},	//   _toch_, _sveu, _diru_, _lở_,
   {{0x27ff001e,0xd9f800a1,0x60c45cc1,0x00000000}},	//   ywun_, ंबईत_, caim, --,
   {{0xc8080019,0x60cf0176,0x2564242d,0x6f0707e7}},	//   _nở_, _idcm, nıla_, _tajc,
   {{0xfbd001ca,0x3f98023a,0x752d0160,0x394f0024}},	//   شته_, _giru_, _loaz, _smgs_,
   {{0xa3df3272,0x18a50208,0x2cbf009e,0x00000000}},	//   दूत_, найм, _teud_, --,
   {{0x6d425cc2,0xb4d92177,0x2572003e,0xc80800cc}},	//   choa, ालो_, jálp_, _bở_,
   {{0x68fb5cc3,0x0bd50037,0x291900a8,0x2fc95cc4}},	//   reud, _سياح, ısa_, nsag_,
   {{0x7c8419f0,0xc8080023,0x7d09052a,0x7d1b42f6}},	//   _русе, _dở_, _haes, _hnus,
   {{0x7d0939c5,0x752d5cc5,0x7d1b1b99,0xd5ae03fc}},	//   _kaes, _boaz, _knus, یفی_,
   {{0x613102df,0x64460137,0x255600ea,0x777a01ed}},	//   _måls, tzki, vāls_, altx,
   {{0xd90f040d,0x7d095cc6,0x60c45cc7,0x752d57aa}},	//   _میں_, _maes, vaim, _doaz,
   {{0xa8560122,0x395f00e1,0x66e50043,0x6446583d}},	//   _אינה_, lnus_, _чока, rzki,
   {{0x26c51942,0x60c45cc8,0x7d1b0371,0x64465cc9}},	//   malo_, taim, _onus, szki,
   {{0x395f5cca,0x752d01a3,0x3f985ccb,0x7d1b02ea}},	//   nnus_, _goaz, _siru_, _nnus,
   {{0x60c45ccc,0x03960ea1,0x01631205,0x62a5012e}},	// [59a0] raim, _проя, укто, _štoš,
   {{0x26c55ccd,0x60c45cce,0x61310523,0x752d01b7}},	//   nalo_, saim, _båls, _zoaz,
   {{0x3f9800ab,0xb3450031,0xdb0903bc,0x26c501ef}},	//   _viru_, saçë, _ateï, ialo_,
   {{0x395f006d,0xdd1100a8,0x7c2201a3,0x7d1b009e}},	//   jnus_, rüşd, txor, _cnus,
   {{0x26c55ccf,0xe52104aa,0xe0df021e,0x62810501}},	//   kalo_, याति_, _blòf_, ýlov,
   {{0xdd3101c2,0x26c51851,0x06d50083,0x23a6016f}},	//   _təşk, jalo_, ত্তি, _môj_,
   {{0xc8080028,0x2bd20f39,0x7d1b5cd0,0x7c22002a}},	//   _sở_, _सिवा, _fnus, sxor,
   {{0x65640bc6,0x395f33c2,0x61310282,0x25640be2}},	//   _njih, gnus_, _hålr, yıla_,
   {{0xb9085cd1,0x6d40066e,0x752d36b4,0x9a6a0609}},	//   _बा_, _ilma, _roaz, _کمال_,
   {{0x26c55cd2,0x47342c0f,0x78a90382,0xc8080023}},	//   galo_, тнос, acev, _vở_,
   {{0x0f570052,0x7d0901a2,0x0ae90580,0x613103db}},	//   תיים_, _yaes, _ترقي_, _målr,
   {{0x07a60573,0x2564242d,0x613806fe,0x00000000}},	//   _задн, tıla_, _dílk, --,
   {{0x26c544c4,0x295700c2,0xdb0001f4,0x69ca0210}},	//   balo_, _אסאך_, _numë, lsfe,
   {{0xdb00013c,0x25640be2,0xd9f40099,0x6b9a035f}},	//   _utmä, rıla_, _आहात_, _jitg,
   {{0x6d4008d2,0x6b9a02bf,0x69ca5cd3,0x92685451}},	//   _olma, _mitg, nsfe, ерта_,
   {{0x6f1c0160,0x867b00a5,0xab660067,0x00000000}},	//   _anrc, _מרוו, leżą, --,
   {{0x4ae0065a,0x69ca01f2,0xdfd115dc,0x7d0932f0}},	// [59b0] _नांव, hsfe, شيا_, _raes,
   {{0x6d405cd4,0xa3d60bc1,0x7d095cd5,0x69ca0282}},	//   _alma, _हित_, _saes, ksfe,
   {{0x7d0901d3,0x2fc95cd6,0xde190079,0x6dac10b1}},	//   _paes, ssag_, بقات_, _ağab,
   {{0x26c50169,0x6285008b,0x69ca1058,0x00000000}},	//   zalo_, _izho, dsfe, --,
   {{0x9f4001dd,0x69d85cd7,0x26c501a8,0x657d1d22}},	//   stiá_, erve, yalo_, ilsh,
   {{0xe0df0284,0x6b9a0107,0x212908b7,0xdf47010b}},	//   _blòg_, _citg, ljah_, _чэмп,
   {{0x78a9002d,0x69ca5cd8,0x00000000,0x00000000}},	//   tcev, gsfe, --, --,
   {{0x2129219c,0x1a6800f8,0x6d585cd9,0x395f0009}},	//   njah_, رینی_, évat, unus_,
   {{0x26c55cda,0x395f4526,0x78a95cdb,0x69d84a26}},	//   talo_, rnus_, rcev, arve,
   {{0x78a90382,0x395f24a5,0x65765cdc,0xdb000392}},	//   scev, snus_, _skyh, _numè,
   {{0x26c51851,0x99d42087,0x69d8011c,0xdcea0139}},	//   ralo_, _متنا, crve, _înăs,
   {{0x26c51f70,0x21295cdd,0xb4ac1404,0x03a60d9e}},	//   salo_, jjah_, गडे_, кимо,
   {{0x26c51ada,0x2129022e,0x7bcb5cde,0x628501e9}},	//   palo_, djah_, nsgu, _azho,
   {{0x43755cdf,0x290d0291,0x27ed5ce0,0x49192160}},	//   густ, ldea_, mten_, भाको_,
   {{0x27ed02bf,0xdb000118,0x27320395,0x00000000}},	//   lten_, _dumè, _vânt_, --,
   {{0x290d5ce1,0x27ed5ce2,0xf8b30067,0xa3df00b4}},	//   ndea_, oten_, ीरिय, दंश_,
   {{0x27ed5ce3,0xd5ac006c,0xdb09171c,0xe0df0260}},	// [59c0] nten_, _وہی_, _ateí, _amòs_,
   {{0x27ed5ce4,0x4095151c,0x45240033,0x127a0037}},	//   iten_, урст, _পতিক_, _يحدث_,
   {{0x27ed5ce5,0x200d0080,0x1e960043,0x333b0d85}},	//   hten_, _šeit_, трар, _חתימ,
   {{0x27ed5ce6,0x63a45ce7,0x6b9a0443,0x6dac0644}},	//   kten_, _kuin, _sitg, _ağac,
   {{0x27ed5ce8,0x6b9a5ce9,0x69ca5cea,0xead45ceb}},	//   jten_, _pitg, wsfe, голь,
   {{0x63a45cec,0x27ed0c61,0x69ca5ced,0x291d030d}},	//   _muin, dten_, tsfe, _anwa_,
   {{0x2d965cee,0x27ed5cef,0x61ee5cf0,0x6b9a0009}},	//   _арас, eten_, ntbl, _vitg,
   {{0x27ed5cf1,0x69ca5cf2,0x61385cf3,0x69d85cf4}},	//   ften_, rsfe, _bíli, rrve,
   {{0x27ed5cf5,0x69ca5cf6,0x61380183,0x1be700c3}},	//   gten_, ssfe, _cíli, _идти_,
   {{0x6b9a201e,0x77910609,0x61380079,0x779200d1}},	//   _uitg, مینا, _díli, جیتا,
   {{0xdb0002e1,0x27ed5cf7,0xa2c123db,0x2cad00e9}},	//   _numé, aten_, वरस्, _yfed_,
   {{0x29240187,0x63a43287,0xa92700d8,0x291d010d}},	//   ávač_, _buin, gužė, _gnwa_,
   {{0x27ed5cf8,0x67d42f65,0x63a45cf9,0x0ee20591}},	//   cten_, _солу, _cuin, _पांड,
   {{0x63a404d6,0xf76f5cfa,0xf09f009e,0x61ee0bf7}},	//   _duin, _واو_, _sgà_, ftbl,
   {{0x671f0084,0x35a303e6,0x61310a8a,0x00000000}},	//   बारक_, _кајг, _bålp, --,
   {{0x63a40a32,0x12e30033,0x6285008b,0xe8070099}},	//   _fuin, য়েদ, _vzho, वटचा_,
   {{0x403403ad,0x212902c2,0x61ee012f,0xdb005cfb}},	// [59d0] аетс, rjah_, atbl, _eumé,
   {{0x44390086,0x02b7051d,0xdb0000f7,0x00000000}},	//   mys_, _अभिभ, _fumé, --,
   {{0x27ed0291,0x44395cfc,0xb05b01ae,0x13b80083}},	//   zten_, lys_, _geän, _জিয়,
   {{0x27ed5cfd,0x7bcb0523,0x7e7c099e,0x00000000}},	//   yten_, tsgu, _dyrp, --,
   {{0x44395cfe,0x27ed5cff,0x9f59017b,0x50da00a5}},	//   nys_, xten_, _asså_, _אקרא,
   {{0x7bcb0282,0x7ae3006d,0xe816363d,0xc43c0070}},	//   rsgu, ugnt, तिना_, ותדי,
   {{0x2b89016f,0x61380037,0x7bcb0282,0x44395d00}},	//   júce_, _síli, ssgu, hys_,
   {{0x09f6004f,0x4439010b,0x753d0051,0x613800ee}},	//   افية_, kys_, jksz, _píli,
   {{0x290d3448,0x6d590468,0xe8f60f99,0x27ed5d01}},	//   rdea_, miwa, улы_, uten_,
   {{0x6d595d02,0x44395d03,0xfb87527b,0x26c30279}},	//   liwa, dys_, _рыбн, újo_,
   {{0x28dc1e79,0x63a443ca,0xa01b0086,0x4439034d}},	//   _याचि, _suin, _hyöd, eys_,
   {{0x6d5939cf,0x63a400f1,0x6e210443,0x44394ccc}},	//   niwa, _puin, _àlbu, fys_,
   {{0x63a45d04,0x44395d05,0xd45601e0,0x00000000}},	//   _quin, gys_, утнь, --,
   {{0x6d595d06,0x03a35d07,0x91e60432,0x00000000}},	//   hiwa, сиро, логе, --,
   {{0x6d595d08,0x324310e3,0xc5d500d4,0xdde20124}},	//   kiwa, берг, _сіль, _žužu,
   {{0x63a45d09,0x6d595d0a,0x78bb00d8,0x61ee21cc}},	//   _tuin, jiwa, nbuv, rtbl,
   {{0xe8160992,0x6d595d0b,0x00000000,0x00000000}},	// [59e0] तिया_, diwa, --, --,
   {{0x06d50083,0x73062d4d,0xdcf40009,0x2bc6021a}},	//   ত্রি, _споз, ćačk, रीफा,
   {{0x2bc61ea9,0x6d5902d7,0x00000000,0x00000000}},	//   रीना, fiwa, --, --,
   {{0x869a0070,0xd7d40035,0xe81601c0,0x6d595d0c}},	//   גיעז, _दिलच, तिमा_, giwa,
   {{0xa2ba166b,0x9f4000c3,0xafe34ed5,0x00000000}},	//   ्रप्, ttiä_, _лоял, --,
   {{0x69c100e9,0x60c60345,0xe0df021e,0x00000000}},	//   _bwle, _hekm, _glòb_, --,
   {{0x44395d0d,0x00000000,0x00000000,0x00000000}},	//   zys_, --, --, --,
   {{0xaea10644,0x9f400086,0x443900c3,0x6d595d0e}},	//   ğışl, stiä_, yys_, ciwa,
   {{0x3b861099,0xbc660202,0x273b01a5,0x6b46008a}},	//   _благ, _свак, _kênh_, _aðge,
   {{0x17f7004f,0xbb7600c3,0x237a0009,0x370609e9}},	//   ارية_, _субъ, _nkpj_, учив,
   {{0xb5210433,0x44395d0f,0xab930082,0xa2ba22a3}},	//   यालय_, wys_, _اللغ, ्रन्,
   {{0x4439247f,0x3ce60e42,0x98a60c46,0x60c6023a}},	//   tys_, ngov_, _сиде, _nekm,
   {{0xe73a0424,0x38cb13cf,0x00000000,0x00000000}},	//   _пед_, _سانی_, --, --,
   {{0x44395d10,0x569408ce,0x237a009f,0x6d595d11}},	//   rys_, _калт, _ckpj_, ziwa,
   {{0x443f5d12,0x44395d13,0xd5af00af,0x60c603d0}},	//   šu_, sys_, _ыс_, _bekm,
   {{0x6d59012f,0x2eea021d,0xb35700b5,0x0ee20726}},	//   xiwa, _acbf_, ئیگا_, _पाउड,
   {{0x2bc601c0,0x9f55145c,0x909902fb,0x6f0e0067}},	// [59f0] रीमा, авач, тват_, _babc,
   {{0x6d594ca0,0x4ae002b4,0x00000000,0x00000000}},	//   wiwa, _नागव, --, --,
   {{0x6d590dc3,0x78a21942,0x539a00a5,0xe3b025d9}},	//   tiwa, _ogov, _שיתו, _وری_,
   {{0x61385d14,0x7a1c0139,0x55bb32e3,0x00000000}},	//   _sílv, _mătă, גמאו, --,
   {{0x9f49004f,0x6d595d15,0x6f0e0107,0x00000000}},	//   ltaí_, riwa, _fabc, --,
   {{0x6d591f18,0x78a22656,0xbe0500b5,0x200b511c}},	//   siwa, _agov, _پورٹ, _isci_,
   {{0x2ba10581,0xdea40e3a,0x2d875d16,0x6d590118}},	//   _ओंका, _ایمی, ïnes_, piwa,
   {{0x7c395d17,0x8cc816e6,0x7d020952,0x61385d18}},	//   pywr, _موفق_, ceos, _fílu,
   {{0x9f490082,0xaae727f6,0xa2ba012f,0x3ce00098}},	//   htaí_, _مساو, ्रम्, óive_,
   {{0x2d9e01ef,0x78a230f9,0x7a1c00af,0x9f59021d}},	//   _éter_, _egov, _bătă, _assú_,
   {{0x24892edd,0x2d8d006d,0xaa672695,0x8af700a8}},	//   _azam_, _khee_, _стак, şəsi,
   {{0x7a1c0160,0xf8b000b5,0x20195d19,0x00000000}},	//   _dătă, _ٹکٹ_, _orsi_, --,
   {{0x5ed00083,0x61380037,0x60c60345,0x290f005f}},	//   স্টে, _mílt, _rekm, _iaga_,
   {{0x290f5d1a,0x60c65d1b,0x66e20274,0x3ce61a8a}},	//   _haga_, _sekm, _доша, zgov_,
   {{0x290f007b,0x24892001,0xf6790070,0x60c65d1c}},	//   _kaga_, _ezam_, _באַמ, _pekm,
   {{0x2bc60099,0x26c7016e,0xa2b2012f,0x00000000}},	//   रीडा, _heno_, _अभक्, --,
   {{0x290f5d1d,0x26c75d1e,0x6f0e006f,0xf0a700af}},	// [5a00] _maga_, _keno_, _pabc, ркул_,
   {{0x290f2129,0xdce901ba,0x200b009e,0x2019023a}},	//   _laga_, _cieľ, _dsci_, _drsi_,
   {{0x26c75d1f,0x386900fb,0x32db02b8,0x60c602c6}},	//   _meno_, _þarf_, _בחינ, _tekm,
   {{0x290f09df,0xe5f60070,0x2d9f009e,0x61385d20}},	//   _naga_, יזער_, _ciue_, _pílu,
   {{0x7d025d21,0x3ce65d22,0x2d9f0176,0x2d8d009e}},	//   reos, rgov_, _diue_, _dhee_,
   {{0x26c75d23,0x38600e46,0xc60c0083,0x7d025d24}},	//   _neno_, _žiro_, ষমতা_, seos,
   {{0x290f5d25,0xe607006c,0x613801ef,0x2bd20803}},	//   _baga_, _بش_, _fílt, _सिका,
   {{0xf98f017e,0x27fd0069,0xfce302c4,0x2d950421}},	//   وبي_, _bpwn_, _мосо, _грус,
   {{0xb8fe0bc1,0x8c43411f,0x290f5d26,0x1ae603ad}},	//   _तय_, _дете, _daga_, _возм,
   {{0x6618024e,0x290f289b,0xaae020ab,0x26c7008b}},	//   _prvk, _eaga_, _नाटक, _ceno_,
   {{0x290f5d27,0x63b65d28,0x33330024,0x00000000}},	//   _faga_, _atyn, _roxx_, --,
   {{0x78a201cc,0x25a00211,0x26c7030d,0xb05b0282}},	//   _ugov, _ciil_, _eeno_, _deäj,
   {{0x61fe5d29,0x26c70952,0x25720187,0x29040176}},	//   _appl, _feno_, nály_, mema_,
   {{0x29045d2a,0x39465d2b,0x290f1459,0x21225d2c}},	//   lema_, _hlos_, _zaga_, _ankh_,
   {{0x26cc1423,0x27e45d2d,0x2bc60d60,0x7afa0103}},	//   mado_, lumn_, रीता, _mbtt,
   {{0x26cc0aca,0xa37b0279,0x9f490037,0x29040d19}},	//   lado_, drõe, rtaí_, nema_,
   {{0x9f490037,0x8387037c,0x4ea70ebc,0x00000000}},	// [5a10] staí_, _выне, ареа, --,
   {{0x26cc1423,0x26c758d3,0x394601ef,0x61380093}},	//   nado_, _xeno_, _llos_, _bíls,
   {{0x26cc1be9,0x29045d2e,0x2b89016f,0xadf51c1b}},	//   iado_, kema_, júca_, спеш,
   {{0x2bd20299,0x29045d2f,0x12160070,0x61380079}},	//   _सिखा, jema_, _פֿיר_, _díls,
   {{0x26cc5d30,0x290f0703,0x29045d31,0x60cd5d32}},	//   kado_, _raga_, dema_, maam,
   {{0x60cd5d33,0x290f5808,0x26cc5d34,0x39465d35}},	//   laam, _saga_, jado_, _alos_,
   {{0x290f4d67,0xdd9b002d,0x26cc2140,0xd20a016b}},	//   _paga_, _аша_, dado_, ָלפֿ,
   {{0x29045d36,0x39465d37,0x26cc09ca,0x257200b5}},	//   gema_, _clos_, eado_, bály_,
   {{0x290f5d38,0x26cc21a4,0x25a000e7,0xc15800a5}},	//   _vaga_, fado_, _riil_, ישהו_,
   {{0x26cc21a4,0xbb85004f,0x60cd4ea5,0xdb19033b}},	//   gado_, _الطي, haam, nswü,
   {{0x290f5d39,0x49da00b5,0x26c73f5d,0x25a00a8a}},	//   _taga_, _مانگ_, _veno_, _piil_,
   {{0x60cd127d,0x26c72e1a,0x29045a64,0x20090298}},	//   jaam, _weno_, cema_, kwai_,
   {{0xe72e03ad,0xa3df55f5,0x00000000,0x00000000}},	//   _ее_, दंग_, --, --,
   {{0x26cc0147,0x9f400037,0x68e95d3a,0x39460009}},	//   cado_, stiú_, lged, _zlos_,
   {{0x25a0043d,0x5ede0033,0x9f400183,0x4adf018d}},	//   _tiil_, ন্ডে, quié_, _नयनव,
   {{0x661c01b4,0xa37b0132,0x51b9002d,0x00000000}},	//   ærke, vrõe, рыря_, --,
   {{0x75245d3b,0xa2ba01d1,0x644f0067,0x6d4b0118}},	// [5a20] _iniz, ्रद्, czci, dhga,
   {{0x2bab0299,0x32465674,0x75360282,0x00000000}},	//   _चढ़ा, _геог, _hoyz, --,
   {{0xa75a0779,0x61fe5d3c,0x200900d7,0x139b011d}},	//   נדער, _uppl, awai_, _תביע,
   {{0x26cc0aca,0xa3df0084,0xeabf0019,0x0c260823}},	//   zado_, दूक_, _đùa_, ймен,
   {{0x26cc5d3d,0x6b46008a,0x68e91472,0xd57b0070}},	//   yado_, _aðga, dged, אָגר,
   {{0xf7671c04,0x26cc0f84,0x257205fa,0x29045d3e}},	//   _را_, xado_, rály_, wema_,
   {{0x26cc2140,0x29045d3f,0x68e95d40,0x00000000}},	//   vado_, tema_, fged, --,
   {{0x2be0009a,0x68e92aa1,0x26cc4df5,0x6d4b5d41}},	//   _निपा, gged, wado_, chga,
   {{0x26cc1423,0x29045d42,0xdb010132,0x39465d43}},	//   tado_, rema_, _milê, _vlos_,
   {{0x290419c6,0xeb9a0009,0x3ae800d1,0x60cd5d44}},	//   sema_, _сиз_, _خبری_, zaam,
   {{0x26cc2132,0x60cd25b4,0x29040dae,0xe816018d}},	//   rado_, yaam, pema_, तिहा_,
   {{0x26cc5d45,0xdb02043f,0x6d4201d7,0x39465d46}},	//   sado_, mpoñ, nkoa, _ulos_,
   {{0x26cc1ec0,0xb8960082,0x60cd5d33,0x6d4201a3}},	//   pado_, _الشع, vaam, ikoa,
   {{0x60cd2eb8,0x5ede0033,0x75240103,0x2be0074f}},	//   waam, ন্তে, _eniz, _निना,
   {{0x60cd5d47,0x644f0035,0xdce900ea,0x6fa200be}},	//   taam, szci, _pieļ, _कंजू,
   {{0x777a5d48,0x00000000,0x00000000,0x00000000}},	//   lotx, --, --, --,
   {{0x60cd5d49,0x69dc0d51,0x00000000,0x00000000}},	// [5a30] raam, _æref, --, --,
   {{0x60cd5d4a,0x9f5202d0,0x23b80d47,0xdb000176}},	//   saam, ntyè_, _اديب_, _numà,
   {{0x6d4b00e9,0x60cd00c3,0x68e95d4b,0xfbc6112b}},	//   thga, paam, yged, रीसम,
   {{0x6d420118,0x00000000,0x00000000,0x00000000}},	//   gkoa, --, --, --,
   {{0x777a01a3,0xd59c016b,0x00000000,0x00000000}},	//   kotx, אבאל, --, --,
   {{0x5f940382,0x3da70ded,0xeb991cf7,0x7ae70402}},	//   _ният, _граб, шил_, сюдж,
   {{0x68e93dd0,0xdb0005c9,0x777a0065,0x00000000}},	//   tged, _atmó, dotx, --,
   {{0x5ede0083,0x656d450c,0x05240033,0x00000000}},	//   ন্দে, _njah, _পত্র_, --,
   {{0xfbe0157d,0x68e95d4c,0xdd94004b,0x6d495d4d}},	//   _नियम, rged, _хаты, _ilea,
   {{0xf77114ac,0x68e95d4e,0x75241c1a,0x7c2601a0}},	//   باب_, sged, _sniz, _škrg,
   {{0xa2ba0967,0xf5061f39,0x63bd0051,0x68e90051}},	//   ्रस्, озно, epsn, pged,
   {{0xc3290052,0x2bc6017a,0x2f0a0035,0x2be000b8}},	//   _בו_, रीवा, mógł_, _निमा,
   {{0x395f2681,0x656d00e0,0x00000000,0x00000000}},	//   mius_, _djah, --, --,
   {{0x395f5d4f,0x394d0370,0x6d420291,0x957d004e}},	//   lius_, lhes_, zkoa, stąp,
   {{0xe29a204b,0x69dc1b2f,0x2be03e9e,0xe81100ab}},	//   рав_, _året, _निभा, ़िका_,
   {{0x2bcf11b5,0xa2ba012f,0x75245d50,0x395f5d51}},	//   _सौभा, ्रह्, _uniz, nius_,
   {{0xdb0101d2,0x00000000,0x00000000,0x00000000}},	// [5a40] _cilë, --, --, --,
   {{0x6d495d52,0x25e002e4,0x6d5b1049,0x395f005f}},	//   _alea, _किमी_, _amua, hius_,
   {{0x395f00d8,0x10a601af,0x00000000,0x00000000}},	//   kius_, _минн, --, --,
   {{0x6d493594,0xa2ba035d,0x6d5b0055,0x00000000}},	//   _clea, ्रव्, _cmua, --,
   {{0xa01b5d53,0x6d4909c3,0x394d5d54,0xdb0110af}},	//   _szöv, _dlea, dhes_, _kilè,
   {{0x6d425d55,0xdb010107,0x6d5b5d56,0xddea00e0}},	//   skoa, _jilè, _emua, _پرسه_,
   {{0x6d490312,0x8fa35d57,0x6d5b0211,0xc333011d}},	//   _flea, _царе, _fmua, ווג_,
   {{0x394d359d,0x6d4909bb,0x395f5d58,0x6840004f}},	//   ghes_, _glea, gius_, _nádú,
   {{0xdb020391,0x2bc600b4,0x00000000,0x00000000}},	//   spoñ, रीशा, --, --,
   {{0x656d0703,0xdb0001ef,0x9abc0024,0xec37024b}},	//   _sjah, _fumá, _inċo, _ואמר_,
   {{0x2bc61fc3,0xd0130083,0xdb0000d5,0xceb332e3}},	//   रीरा, সময়_, _gumá, וית_,
   {{0x395f5d59,0x394d5d5a,0xe9b7006c,0xd90e0a86}},	//   cius_, ches_, _بچوں_, _شیخ_,
   {{0xd7ef0082,0xb718224a,0xd11b0826,0x00000000}},	//   _لكن_, _голф_, _पोषण_, --,
   {{0xa2ba5d5b,0x00000000,0x00000000,0x00000000}},	//   ्रष्, --, --, --,
   {{0xdb010260,0x656d5d5c,0x00000000,0x00000000}},	//   _dilè, _tjah, --, --,
   {{0x656d3e4a,0x00000000,0x00000000,0x00000000}},	//   _ujah, --, --, --,
   {{0x657d5d5d,0xa2ba00e7,0x2eab0274,0x00000000}},	// [5a50] mosh, ्रश्, ањен_, --,
   {{0x657d5d5e,0x6d49184f,0xa2950eb9,0x3ea70c71}},	//   losh, _slea, _напі, ønt_,
   {{0x6d495d5f,0xa01b006c,0x6d4800c7,0x00000000}},	//   _plea, _gyön, _įdar, --,
   {{0x63ad19c6,0x395f0443,0xd5fb0070,0x394d0031}},	//   _kuan, xius_, שפאר, xhes_,
   {{0x63ad5d60,0x395f5d61,0xdb005856,0x63a55d62}},	//   _juan, vius_, _sumá, _kihn,
   {{0x657d5d63,0x63ad5d64,0xdb0100fd,0xf3ed0831}},	//   hosh, _muan, _kilé, _ওনার_,
   {{0x395f5d65,0x2bd702cb,0xeaf8004f,0x63ad5d66}},	//   tius_, _ठिका, ترنت_, _luan,
   {{0xdb0100d5,0xe0df0107,0x6d5b5d67,0xb3dc07b5}},	//   _milé, _amòz_, _umua, _बिलख,
   {{0x395f1bda,0x657d5d68,0x63ad11f0,0x6b4f1f8b}},	//   rius_, dosh, _nuan, _nøgg,
   {{0x395f5d69,0x67385d6a,0x394d5d6b,0x28c9021a}},	//   sius_, _covj, shes_, ररहि,
   {{0x395f1ca2,0x62855d6c,0x394d00f7,0x63ad0176}},	//   pius_, _nyho, phes_, _auan,
   {{0xa3d7006a,0x657d5d6d,0xdb010176,0xdcfb00cd}},	//   ाओं_, gosh, _silè, _okuč,
   {{0x63ad00c8,0x9fd600c8,0xdb015d6e,0x00000000}},	//   _cuan, _সঙ্গ, _ailé, --,
   {{0x63ad5d6f,0x7bc9002f,0xdb010118,0x63a50118}},	//   _duan, _mweu, _bilé, _cihn,
   {{0x628502c7,0x213920e2,0x3cff024e,0x657d2cec}},	//   _cyho, _bosh_, _obuv_, bosh,
   {{0x55da00c2,0x25e002cb,0x200200e7,0x386005e2}},	//   _פֿונ, _किती_, _ppki_, _žiri_,
   {{0x63ad5d70,0xa3d60e1d,0xb4d80b7a,0x68fb046a}},	// [5a60] _guan, _हिट_, ाणी_, ifud,
   {{0xdce9029d,0x44205d71,0xa01b0086,0x68fb012f}},	//   _dječ, _iri_, _työn, hfud,
   {{0x6285001e,0x76410090,0x4420023a,0xdb0100e0}},	//   _gyho, nyly, _hri_, _gilé,
   {{0x8fa619f8,0x44205d72,0x2be020ab,0x66030260}},	//   _наме, _kri_, _निदा, _mpnk,
   {{0x2bcf0026,0x60c431ed,0x63ad5d73,0x7c2603c9}},	//   _सौदा, mbim, _xuan, _škrb,
   {{0x60c40a93,0x7bc90297,0xf1a90118,0x6b4f0185}},	//   lbim, _dweu, _دایه_, _nøgd,
   {{0x657d5d74,0x3eaa012f,0x68fb5d75,0x00000000}},	//   yosh, _igbt_, ffud, --,
   {{0x44200012,0x67385d76,0x4ddb0122,0x23dc0d2a}},	//   _ori_, _sovj, _לחלו, _बिंद,
   {{0x6738029d,0xebe31a31,0xb904000c,0x7bc9016e}},	//   _povj, _потп, _भए_, _gweu,
   {{0x63ad0452,0x44270028,0x95d80370,0xa3b00380}},	//   _ruan, _ăn_, одот_, _ओढ़_,
   {{0x44205d77,0x657d5d78,0x63ad5d79,0x3abb00a5}},	//   _ari_, tosh, _suan, _המבנ,
   {{0x63ad0723,0x44205d7a,0xe0df0107,0x628500ee}},	//   _puan, _bri_, _elòj_, _ryho,
   {{0x63ad5d7b,0x657d5d7c,0x4ad004cc,0x44205d7d}},	//   _quan, rosh, _सजाव, _cri_,
   {{0xdce9044d,0x442000e9,0xa3a40431,0x657d5671}},	//   _rječ, _dri_, ејск, sosh,
   {{0x44205d7e,0xb90901a5,0x657d5d7f,0xdce900cb}},	//   _eri_, _nghề_, posh, _sječ,
   {{0x6285024e,0x60f901c8,0x4420593a,0x26ce016e}},	//   _vyho, ўная_, _fri_, _hefo_,
   {{0xf4850e3a,0x6b4f008c,0xe81f0826,0x63a50139}},	// [5a70] _تاثی, _høge, बिया_, _tihn,
   {{0xdce9029d,0x3f14059d,0x2bcf0067,0x26ce021e}},	//   _vječ, ндус, सीफा, _jefo_,
   {{0x8cf500d8,0x7c200a8a,0x2139099e,0xc5f800ea}},	//   дзец, _armr, _tosh_, ntē_,
   {{0x6b4f0a8a,0x00000000,0x00000000,0x00000000}},	//   _møge, --, --, --,
   {{0xfc4601a5,0x1be901e0,0x6dac00af,0x76415d80}},	//   _đích_, ідки_, _aşad, zyly,
   {{0xdb0906d3,0x4ad700b5,0x7982030d,0xac7403fc}},	//   _önün, ساتھ_, _akow, رانش,
   {{0xa3b42207,0x60cf5d81,0x2fcb5d82,0x25bc0345}},	//   _जून_, _kecm, _hwcg_, _ntvl_,
   {{0x3a3a01ff,0xe51d046c,0x00000000,0x00000000}},	//   äppa_, _बोलि_, --, --,
   {{0x24c50083,0x02bf012f,0x25ae02b1,0x00000000}},	//   ্লাহ, ्राभ, _aufl_, --,
   {{0xb4e619db,0x6b4f054e,0x7982022e,0x70aa04bc}},	//   कल्प_, _bøge, _ekow, _कल्ल,
   {{0x26ce0359,0x6ad30033,0x44200147,0x60dd02a7}},	//   _defo_, _সাপো, _sri_, _odsm,
   {{0x4420125d,0xb4d800a1,0x26dc0118,0x52c602b4}},	//   _pri_, ाणे_, _edvo_, वर्स,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2be014ab,0x79895d83,0x889a00a5,0x9f40000d}},	//   _निसा, llew, _ובני, prié_,
   {{0x03a303ad,0x798908c7,0x6b4f008c,0x26c55d84}},	//   тиро, olew, _gøge, mblo_,
   {{0x44205d85,0x61e100b5,0xa01b00c3,0x00000000}},	//   _tri_, álla, _työl, --,
   {{0x44205d86,0x60c45d87,0xa3ba00b5,0xcbe80033}},	// [5a80] _uri_, rbim, _بابر_, _গন্ধ_,
   {{0x257900b5,0x00000000,0x00000000,0x00000000}},	//   dély_, --, --, --,
   {{0x2be00fc3,0xe29a5d88,0x25bc01f7,0x79895d89}},	//   _निहा, _фан_, _xtvl_, klew,
   {{0x25e0006a,0xe8df0019,0x2fc00d35,0x2bcf0026}},	//   _किसी_, _trộm_, ppig_, _सौहा,
   {{0xdca31574,0x798904a6,0x00000000,0x00000000}},	//   ваци, dlew, --, --,
   {{0x9f405d8a,0x79890054,0xe4570070,0x7d0b00be}},	//   rtió_, elew, וינט_, aegs,
   {{0x9f405d8b,0x2be00d00,0xdee30166,0x26ce0051}},	//   stió_, _निवा, _јоси, _refo_,
   {{0xa8140c0e,0xb8140431,0x26ce0103,0x9963005f}},	//   едиш, едиј, _sefo_, ктыл,
   {{0x6b4f0022,0x36d42626,0x2afb007c,0xa91d00cd}},	//   _søge, нопр, ल्हु_, dožd,
   {{0xeeeb01a5,0x9989044d,0x4b260bdf,0x7bc25d8c}},	//   _đừng_, ćaš_, _تعرف, mpou,
   {{0x79895d8d,0x00000000,0x00000000,0x00000000}},	//   blew, --, --, --,
   {{0xc86603fe,0xc5f80029,0x69d85d8e,0xa01b00c3}},	//   _отли, rtē_, msve, _syöm,
   {{0x2492004e,0x69d85d8f,0xc5f800ea,0xc87f02b1}},	//   _czym_, lsve, stē_, üßt_,
   {{0x69d802c4,0x6b4f0b3e,0x00000000,0x00000000}},	//   osve, _tøge, --, --,
   {{0xe8160632,0xe60f0098,0xd13b5d90,0x442d00af}},	//   तिका_, _نشي_, оха_, ţe_,
   {{0x5ec800c8,0x69d802c9,0x00000000,0x00000000}},	//   _লাগে, isve, --, --,
   {{0x2be00380,0x7bc200d5,0xa01b00c3,0x60cf0228}},	// [5a90] _निषा, jpou, _työm, _vecm,
   {{0xa91d219c,0x64405d91,0x69d806f0,0x7d0b0c55}},	//   može, ämie, ksve, wegs,
   {{0xa91d031d,0x25a90107,0x69d85d92,0x7d0b5d93}},	//   lože, _kial_, jsve, tegs,
   {{0x656f5d94,0x2be0020c,0x69d85d95,0x429a32e3}},	//   nnch, _निशा, dsve, _מסתב,
   {{0x7bc40043,0x656f5d96,0x7d0b4cae,0xa91d3f01}},	//   ţiun, inch, regs, nože,
   {{0x98af004e,0xcbe006fe,0x69d85d97,0x656f02b1}},	//   _mogą_, _निरञ, fsve, hnch,
   {{0x8d77183b,0x69d81d89,0x533802b5,0xf985021d}},	//   _قارا, gsve, ונגן_, нгко,
   {{0x3f810187,0x25a9009e,0x6e9453b7,0x2d7800cd}},	//   lohu_, _nial_, _рису, včeg_,
   {{0x24892851,0x2d9d09d6,0x7989053e,0xa0e300ea}},	//   _nyam_, mmwe_, rlew, dēļā_,
   {{0x656f03e6,0xe7310037,0x27e20097,0xa91d030a}},	//   ench, اصة_, ákna_, dože,
   {{0x24890464,0x2b89016f,0x25a95d98,0x00000000}},	//   _ayam_, júci_, _bial_, --,
   {{0x92c100c8,0xdb01171c,0x2b8901ba,0x79800051}},	//   ুলো_, _milí, dúci_, comw,
   {{0xf9920100,0x3f8101f4,0xab5d0024,0x00000000}},	//   _ערד_, kohu_, _awżi, --,
   {{0x212b02fb,0x883a011d,0x656f0767,0xa91d00f4}},	//   _anch_, _מתנו, anch, sožd,
   {{0x25a91a07,0x27ed01a3,0x00000000,0x00000000}},	//   _fial_, luen_, --, --,
   {{0xa91d1834,0x41e11604,0xa01b00fd,0x00000000}},	//   ložb, _फिरस, _gyök, --,
   {{0xd0075d99,0x27ed5d9a,0x65660dc3,0x9f40008d}},	// [5aa0] нете_, nuen_, mikh, ftið_,
   {{0xe1fa0d36,0x65665d9b,0xa01b0086,0xf45700a5}},	//   _его_, likh, _myöh, _נייר_,
   {{0xdb011c02,0x64465d9c,0x7bdb001c,0x798040e9}},	//   _cilí, lyki, _avuu, yomw,
   {{0x7bc20298,0x27ed5d9d,0xa2ba48cd,0x41bb00a5}},	//   tpou, kuen_, ्रक्, _מצטע,
   {{0x61ee5d9e,0x60d60cca,0xdb015d9f,0x69da0065}},	//   lubl, maym, _eilí, _svte,
   {{0x69d85da0,0x27ed5da1,0xdb010079,0x00000000}},	//   tsve, duen_, _filí, --,
   {{0xfce6189d,0x7bc25da2,0x7bdb030d,0x61ee013b}},	//   _пово, spou, _evuu, nubl,
   {{0xeeeb01a5,0x69d85da3,0x6446010b,0xf41f00c3}},	//   _đứng_, rsve, kyki, yvä_,
   {{0x27ed4df4,0x69d83858,0x7980035f,0x394f027a}},	//   guen_, ssve, romw, _dlgs_,
   {{0x79803069,0xd6da2294,0x61ee5da4,0x64465da5}},	//   somw, чти_, kubl, dyki,
   {{0x24895da6,0xa3d3175f,0x25a900d7,0x61ee023a}},	//   _syam_, हीन_, _pial_, jubl,
   {{0xb4eb5da7,0x656f00fe,0x61ee00cd,0xeabf0023}},	//   मले_, unch, dubl, _đùi_,
   {{0x25a91bae,0x9abc0069,0x9f400093,0xd4045da8}},	//   _vial_, _anċi, ytið_, ляри,
   {{0x61e100b5,0x00000000,0x00000000,0x00000000}},	//   állo, --, --, --,
   {{0x61ee1851,0xa01b0086,0x41e412ea,0x8afc0067}},	//   gubl, _työk, літа, _zmęc,
   {{0xfc4601a5,0xa91d011c,0x8ecd0831,0x00000000}},	//   _đính_, pože, _লাইগ, --,
   {{0xd3a75da9,0x7a1301c2,0x3f815daa,0xb4bf0ed1}},	// [5ab0] _проп, _vətə, tohu_, ेरी_,
   {{0x20e10023,0xdb010132,0x00000000,0x00000000}},	//   ỗi_, _milã, --, --,
   {{0x3f8101f4,0x27ed01d7,0x02bf0026,0x9f40008d}},	//   rohu_, zuen_, ्रीन, rtið_,
   {{0x9f400093,0x3f815dab,0x00000000,0x00000000}},	//   stið_, sohu_, --, --,
   {{0x752d002f,0x9f40008d,0x8d743e7c,0x00000000}},	//   _mnaz, ptið_, دالا, --,
   {{0x8c421bfd,0x3f98009e,0x65660a21,0x6d4a0031}},	//   реше, _ghru_, zikh, ëfar,
   {{0x7bd90bf7,0xce940036,0x7ceb5dac,0xdb010079}},	//   sswu, _баръ, görü, _uilí,
   {{0x27ed03cb,0xf2bf0380,0x9d18386a,0xdb080359}},	//   tuen_, ्रुघ, _пост_, _lidè,
   {{0x5b1518d0,0xa91d008b,0x61ee5dad,0x7d1b005f}},	//   _имат, tožb, zubl, _iaus,
   {{0x7d1b0408,0x752d5dae,0x27ed5daf,0x7c842b4d}},	//   _haus, _anaz, ruen_, _сусе,
   {{0x6b835db0,0x7d1b5db1,0x65661581,0x752d0024}},	//   mong, _kaus, tikh, _bnaz,
   {{0x7d1b5db2,0x64465db3,0xd46a03e6,0x6b830147}},	//   _jaus, tyki, диме_, long,
   {{0x27ed48ba,0x7d1b5db4,0x656621a3,0x44240079}},	//   quen_, _maus, rikh, ím_,
   {{0x7d1b5db5,0x6b835233,0x65665db6,0xfbc600b4}},	//   _laus, nong, sikh, रीटम,
   {{0x2d78003d,0x64465db7,0x62633cef,0x6b832206}},	//   nčec_, syki, авра, iong,
   {{0x6b835db8,0x61ee5db9,0x69c10069,0x6d4b0051}},	//   hong, rubl, _mtle, jkga,
   {{0xa067150d,0x6b835dba,0xef1a0086,0x61fc1505}},	// [5ac0] вата_, kong, мма_, strl,
   {{0x6b835dbb,0x7c26063b,0xdb080260,0x6d4b0345}},	//   jong, _škro, _gidè, ekga,
   {{0x7d1b5dbc,0x6b835dbd,0xf2d30bed,0xdb1b0176}},	//   _baus, dong, _דעת_, _atuï,
   {{0xfce65dbe,0x69de01fe,0xbca601cb,0xdb000249}},	//   тодо, špek, نماي, _humø,
   {{0x6b4f0b3e,0x6b8316b1,0x6d9802d7,0x3f981cdd}},	//   _søga, fong, víad, _thru_,
   {{0x6b835dbf,0x7ceb0225,0xef1f0067,0x00000000}},	//   gong, törü, ążce_, --,
   {{0x2b8901ba,0xdce204d9,0x6f1c0079,0x00000000}},	//   júcu_, lioč, _iarc, --,
   {{0x6f1c5dc0,0x7d1b00d8,0xdce20254,0x6d4b033b}},	//   _harc, _gaus, dnoć, ckga,
   {{0x6d401093,0xdca30dd0,0x5d67155f,0x6b832004}},	//   _ioma, _вати, _ритм_, bong,
   {{0x6d405dc1,0x752d0d5c,0x7d1b10ec,0x6b835dc2}},	//   _homa, _snaz, _zaus, cong,
   {{0xd00b00c8,0x7d1b01ed,0xa4d50746,0x00000000}},	//   রিয়_, _yaus, лоні, --,
   {{0xb4bf5dc3,0x7d025dc4,0x6d405dc5,0xdb080359}},	//   ेरे_, nfos, _joma, _sidè,
   {{0x6d405dc6,0x183601b2,0x7c225dc7,0xdb010183}},	//   _moma, _جراح, nvor, _hilá,
   {{0x6d405dc8,0x52bf3d0a,0x36d45dc9,0x6564073a}},	//   _loma, ्रेस, _сокр, _emih,
   {{0xa91d1851,0x96f70957,0xa2ba035d,0x7c260b67}},	//   loža, _شعور_, ्रज्, _škrl,
   {{0x6d405dca,0x752d5671,0x6b835dcb,0x7c225dcc}},	//   _noma, _unaz, zong, kvor,
   {{0x6f1c48ba,0x6b83203d,0x7d1b45e6,0x76480409}},	// [5ad0] _barc, yong, _raus, lydy,
   {{0x7d1b5dcd,0x7c220506,0xdb0852af,0x6d4001da}},	//   _saus, dvor, _fidé, _aoma,
   {{0x3ea7022a,0x6d405dce,0x6b835dcf,0x7c220223}},	//   änt_, _boma, vong, evor,
   {{0x6d405dd0,0x68e201d2,0x6b835dd1,0x6f1c5dd2}},	//   _coma, _ndod, wong, _earc,
   {{0x6f1c5dd3,0x6b83412c,0x7c2258a6,0x6b4f0c71}},	//   _farc, tong, gvor, _døgn,
   {{0x7d1b158c,0x7afc033b,0x2019018d,0x31690065}},	//   _waus, _örtl, _issi_, liaz_,
   {{0x7d1b5dd4,0xa3d302cb,0x6d400359,0x2d8700f7}},	//   _taus, हीत_, _foma, înes_,
   {{0x6d405dd5,0x6b835dd6,0xdb0101ef,0x316901d7}},	//   _goma, song, _dilá, niaz_,
   {{0x6b835dd7,0x5c7510b8,0x8cc90026,0xa91d02c4}},	//   pong, _слат, _ह्यो, goža,
   {{0xdce25dd8,0x6d400120,0xdb0101ef,0x52bf1119}},	//   tnoć, _zoma, _filá, ्रोस,
   {{0x8c420723,0x50d30253,0x20192e1a,0x69c15dd9}},	//   _öğre, तराष, _lssi_, _utle,
   {{0xa91d2d17,0xdce20506,0x201902ee,0x6b5401f7}},	//   boža, rnoć, _ossi_, _vàge,
   {{0x2d8f0082,0xdce2003a,0x27e901dd,0x394d390c}},	//   ilge_, snoć, _ían_, mkes_,
   {{0x291d5dda,0x291f01d7,0x6d5a00c7,0x00000000}},	//   _hawa_, ldua_, _įtam, --,
   {{0x291d5ddb,0x20194d67,0x6d981fca,0x7c221550}},	//   _kawa_, _assi_, níac, zvor,
   {{0xdb085ddc,0x291f5ddd,0x6f1c0043,0x02bf1e79}},	//   _vidé, ndua_, _sarc, ्रॉन,
   {{0x6d401b70,0x27ff00e0,0x291d00d1,0xe0df5dde}},	// [5ae0] _roma, ntun_, _mawa_, _alòs_,
   {{0x6d400054,0x6b4f054e,0x291d5ddf,0xdfcf0b8d}},	//   _soma, _søgn, _lawa_, سيم_,
   {{0x6d4018b0,0x20190102,0x6f1c13fb,0x63b60019}},	//   _poma, _essi_, _varc, _huyn,
   {{0x7c220912,0xed572f44,0x291d5de0,0x6d40027c}},	//   tvor, лох_, _nawa_, _qoma,
   {{0x0b8a0610,0x6f1c5de1,0x399a01f4,0xac180bfa}},	//   нски_, _tarc, nëse_, толу_,
   {{0x8c430500,0x7c22479d,0x6d405de2,0x256b02d0}},	//   сеље, rvor, _woma, _kòlè_,
   {{0x2be01d78,0x291d5de3,0x7c221cee,0x394d5de4}},	//   _निका, _bawa_, svor, fkes_,
   {{0xdb010332,0x21205de5,0xdca603d6,0x6b4f0044}},	//   _vilá, ndih_, _баби, _høgl,
   {{0x20005de6,0xed572ac7,0xcaf617bd,0x291d2789}},	//   ntii_, _сот_, _مساب, _dawa_,
   {{0xa91d04c3,0x316901a3,0xa01b00c3,0xda5a002d}},	//   roža, ziaz_, _työv, _преш_,
   {{0xd5b703ad,0xa37b03e6,0x5575225d,0x64400086}},	//   лся_, nsõe, игот, ämin,
   {{0x291d00a7,0xa91d5de7,0x23af009f,0x394d05aa}},	//   _gawa_, ložn, _ażja_, ckes_,
   {{0x67d4002d,0x6fb00084,0x765a5de8,0x261000ab}},	//   _толу, _अंगू, szty, _तनकी_,
   {{0x77f70052,0x20190069,0x6b4f01b4,0xae05007c}},	//   _עמוד_, _rssi_, _nøgl, _रहलन_,
   {{0x31c45de9,0x291d5dea,0xf3ff0279,0x0d040461}},	//   йств, _yawa_, stã_, रभाष_,
   {{0x201900e7,0x38690620,0x9f5200c3,0x26190067}},	//   _pssi_, _žari_, htyä_, _बनती_,
   {{0x2be00299,0xc05b00d4,0xfbe00f0d,0x316901a3}},	// [5af0] _निगा, хів_, _निगम, riaz_,
   {{0x7a0a01c2,0x2bcf14ab,0x316901b7,0x00000000}},	//   _mətb, _सौगा, siaz_, --,
   {{0xc332012b,0x4429053d,0xc208006c,0xb7c300af}},	//   _ווי_, _hra_, _یقین_, ăţil,
   {{0x20190221,0x2be004bc,0xdb260105,0xa37b00be}},	//   _tssi_, _निखा, یونی, ssõd,
   {{0x291d07ee,0x60cd5deb,0x20000043,0x00000000}},	//   _rawa_, mbam, ctii_, --,
   {{0x291d5dec,0x60cd5ded,0xdce90009,0x15e50026}},	//   _sawa_, lbam, _ojeć, _किलर_,
   {{0xba7700d1,0x44295dee,0x291d0371,0x394d5def}},	//   داشت, _lra_, _pawa_, tkes_,
   {{0x44295df0,0x6d9801dd,0x39451f39,0x27ff5df1}},	//   _ora_, ríac, рниг, ttun_,
   {{0x44295df2,0x394d5df3,0xa91d01a0,0x6d982dd3}},	//   _nra_, rkes_, božn, síac,
   {{0x753d006a,0x394d5df4,0x7c295df5,0x6a1700b5}},	//   ejsz, skes_, _irer, _مبصر,
   {{0x44295df6,0x27ff5df7,0x291d5df8,0x394d481a}},	//   _ara_, stun_, _tawa_, pkes_,
   {{0x44295df9,0x6e212a87,0x399a01f4,0x6d5a010b}},	//   _bra_, _álbu, tëse_, _įtak,
   {{0xf770042c,0x99840082,0x7d095dfa,0x60cd0121}},	//   _کان_, _النو, _mbes, dbam,
   {{0x44295dfb,0x331901c8,0x27ed5dfc,0x399a0031}},	//   _dra_, ліся_, mren_, rëse_,
   {{0x29d30012,0x44295dfd,0xc5d502ce,0xa91d0097}},	//   nţa_, _era_, _тіль, nožo,
   {{0x442923a1,0x90c606d8,0x92d600c8,0x256b02d0}},	//   _fra_, рбае, হলে_, _vòlè_,
   {{0x44295dfe,0x657d006c,0x212002f6,0x2fc91292}},	// [5b00] _gra_, érhe, rdih_, gpag_,
   {{0x20005dff,0x7d095e00,0x27ed0065,0x6dac564b}},	//   rtii_, _abes, iren_, _eşal,
   {{0x27ed02bf,0x20005e01,0x60cd5e02,0x7c295e03}},	//   hren_, stii_, bbam, _arer,
   {{0x44290a93,0x0c265e04,0xa37b0279,0xdb0905ee}},	//   _yra_, имен, rsõe, _steð,
   {{0xa37b0370,0x9f520086,0x27ed5e05,0xa91d571a}},	//   ssõe, ttyä_, jren_, tožn,
   {{0xd90d00b5,0x7d095e06,0x161501c0,0x69dc1b99}},	//   ہیم_, _ebes, तबार_, _ærek,
   {{0x27ed5e07,0x12e902b5,0xa91d08b7,0xdee327de}},	//   eren_, אַפּ, rožn, _фоси,
   {{0xa01b0086,0x7c292a5a,0x7d090044,0x9f520421}},	//   _työt, _frer, _gbes, styä_,
   {{0xd83a005f,0xdce9029d,0x27ed5e08,0xdb01017b}},	//   тэй_, _sjeć, gren_, _bilä,
   {{0x60cd1b97,0x44295e09,0x9abc0024,0x6b5400f1}},	//   zbam, _rra_, _baċe, _fàga,
   {{0xe8fa5e0a,0x27ed33aa,0x4429310f,0x093600b5}},	//   _але_, aren_, _sra_, _پراج,
   {{0x44295e0b,0x997503ad,0x69ca02c9,0x7a0a0095}},	//   _pra_, _лучш, mpfe, _tətb,
   {{0x75c100ea,0xb4b70066,0x27ed01ed,0x53475e0c}},	//   _rēze, _जली_, cren_, ахва,
   {{0x44290626,0x83870409,0x389b025a,0x645d5e0d}},	//   _vra_, рыме, _סיגנ, rzsi,
   {{0xe16703fa,0xdcfb011c,0x6dac027d,0x61ee0207}},	//   ађан, _ukuć, _aşam, grbl,
   {{0x44295e0e,0x00000000,0x00000000,0x00000000}},	//   _tra_, --, --, --,
   {{0x60cd5e0f,0x61ee0a81,0x90992746,0x00000000}},	// [5b10] rbam, arbl, уват_, --,
   {{0x2be00af9,0xbf021282,0x7d095e10,0x61ee0207}},	//   _निजा, र्लभ_, _sbes, brbl,
   {{0xf1e102e4,0xa3d300a1,0x2d7803c9,0x27ed27c3}},	//   _फिटन, हीर_, rčen_, zren_,
   {{0xa2cb1b8f,0x27ed1370,0x611502ee,0x00000000}},	//   _त्त्, yren_, _удму, --,
   {{0xdb1b021d,0x00000000,0x00000000,0x00000000}},	//   _atuá, --, --, --,
   {{0x6d595e11,0x6b740183,0x27ed5e12,0xab643c77}},	//   shwa, олчу, vren_, овіл,
   {{0xa969389d,0xa01b5e13,0x6d9801ef,0x6b4f03d0}},	//   лика_, _työs, mían, _høgk,
   {{0x27ed5e14,0x991500d4,0x7d095e15,0x7c2903c1}},	//   tren_, ські, _ubes, _trer,
   {{0x27ed57b0,0xccf200a5,0x2d8d0159,0x7d0401a6}},	//   uren_, _מכן_, _ikee_, òise,
   {{0x27ed03cb,0x9a870036,0x6d98002a,0xdb010282}},	//   rren_, _куел, nían, _bilå,
   {{0xe81c0299,0x67210a16,0xaa950037,0x070903fc}},	//   _बैठा_, rdlj, _الاث, نيکي_,
   {{0x05565de9,0x7c262406,0x38690620,0x2d7802c4}},	//   стоя, _škri, _žaru_, jčel_,
   {{0x6c7902b5,0xa3d30253,0x69de0207,0x00000000}},	//   ראָפ, हील_, špet, --,
   {{0x660100e5,0x2be000a1,0x61f5013b,0x1c1e0099}},	//   ptlk, _निघा, fuzl, _मैफल_,
   {{0x450d0083,0xe5a65e16,0x2d8d4ee8,0x15460340}},	//   ষয়ক_, _лики, _okee_, _гейм,
   {{0x31bc00b5,0x216706e4,0x00000000,0x00000000}},	//   _víz_, биси_, --, --,
   {{0x41270133,0x7d0100b5,0x61ee0009,0x10a31403}},	// [5b20] щото_, záró, srbl, зитн,
   {{0xa01b0086,0x798911ad,0xf0a72028,0x31bc00b5}},	//   _pyör, hoew, скул_, _tíz_,
   {{0x216a0e9f,0x00000000,0x00000000,0x00000000}},	//   _бини_, --, --, --,
   {{0xd5fa02b5,0xdb08024e,0xb5fa02b5,0x6b4f008c}},	//   טפער, _vidí, טלעכ, _høgh,
   {{0x6d98002a,0xdd8f00bc,0x06f91856,0x9f4000c3}},	//   bían, روه_, ्भाव_, triä_,
   {{0x2122012f,0x6d980042,0xdfcf0037,0xa01b0421}},	//   _hakh_, cían, _سيف_, _työr,
   {{0x0f570070,0x6b4f008c,0x00000000,0x00000000}},	//   _פילם_, _møgh, --, --,
   {{0xa51702cb,0xb4b70084,0xed5718cd,0x69ca02b1}},	//   _तसेच_, _जले_, _лос_, rpfe,
   {{0xa3b40084,0xeafa004f,0x37aa2e50,0x64a705f7}},	//   _जंग_, _مرات_, лтон_, _गणेश,
   {{0x501b00a5,0xa91d2190,0x9f49008d,0x00000000}},	//   נויו, nožj, ntað_, --,
   {{0xa2b9473a,0xb0b800ab,0x00000000,0x00000000}},	//   ्डस्, _अलंग, --, --,
   {{0x9f47114d,0x3a2c007b,0x61f501fb,0x00000000}},	//   čné_, _irdp_, vuzl, --,
   {{0xa3d30ccf,0x5896064e,0x25a05e17,0x1c1e1ede}},	//   हीं_, _اجاز, _dhil_, पिटल_,
   {{0x39460639,0x96ba434c,0x661c01b4,0x9f400132}},	//   _hoos_, _суду_, ærks, ssiê_,
   {{0xe5c62afc,0x26de2796,0x39465e18,0x6d9842ae}},	//   _усло, mato_, _koos_, vían,
   {{0x26de5e19,0x394628c5,0x25a00284,0x20e3060a}},	//   lato_, _joos_, _ghil_, गणेश_,
   {{0x3946006f,0x656f5e1a,0x9ed91578,0x61f510b1}},	// [5b30] _moos_, mich, имат_, suzl,
   {{0x656f5e1b,0x26de18e0,0x39465e1c,0x644f5e1d}},	//   lich, nato_, _loos_, myci,
   {{0x6d983f73,0x26de0036,0x644f004b,0x00000000}},	//   rían, iato_, lyci, --,
   {{0x656f5e1e,0x7ae831b2,0xeea80009,0x26de5e1f}},	//   nich, _addt, стук_, hato_,
   {{0x07080907,0x26de5e20,0x6b4f008c,0x69c80228}},	//   वभाव_, kato_, _høgi, _atde,
   {{0x656f5e21,0xdea4103b,0x26de007e,0x6d9801ef}},	//   hich, _کیمی, jato_, bíao,
   {{0x9f490514,0x2d9f0019,0x39465e22,0x656f5e23}},	//   nraí_, _thue_, _boos_, kich,
   {{0x394630bc,0x656f5e24,0x57e90145,0x47c51e5b}},	//   _coos_, jich, адим_, обив,
   {{0x5fe21db6,0xf8ae00bf,0xa91d0076,0xc8b3006c}},	//   _पिछल, نکه_, ložk, _ہلاک,
   {{0x26de01d3,0x5fe20066,0x79890feb,0x06095e25}},	//   gato_, _पिघल, soew, анок_,
   {{0xb8ff0b52,0x656f5e26,0x39460221,0xf8bf0b06}},	//   _তা_, fich, _foos_, ñés_,
   {{0x656f5e27,0x39460051,0x9f490079,0x75c100ec}},	//   gich, _goos_, draí_, _cēza,
   {{0x66e50cb5,0x26de5e28,0x6d9801ef,0xa91d00d5}},	//   _дола, bato_, díal, hožk,
   {{0x26de0133,0x7a0a01c2,0x68fb5e29,0xa91d0187}},	//   cato_, _mətn, lgud, kožk,
   {{0x9f49004f,0x22470fa7,0xe77800b5,0x25a02b66}},	//   graí_, опри_, _دلوں_, _thil_,
   {{0x68fb5e2a,0x24800189,0x3cff006d,0x644f0035}},	//   ngud, _txim_, _ncuv_, byci,
   {{0x67235e2b,0x9f495d9f,0xdb010952,0x7b1107c0}},	// [5b40] _kanj, ttað_, _dilú, _kľuč,
   {{0x672309df,0x44205e2c,0xb3580332,0x752401d7}},	//   _janj, _isi_, _ایسا_, _haiz,
   {{0x67235e2d,0x442001a2,0x61460370,0x7bc95d31}},	//   _manj, _hsi_, _дена, _ateu,
   {{0x67230f1a,0x6d980042,0x9f49008a,0x629e02c6}},	//   _lanj, ríao, stað_, _izpo,
   {{0x39465e2e,0x75245e2f,0x442001c0,0x60c40254}},	//   _roos_, _maiz, _jsi_, mcim,
   {{0x3946250a,0x656f5e30,0x67235e31,0x26de24ab}},	//   _soos_, zich, _nanj, xato_,
   {{0x26de0133,0x39465e32,0x2d7858c4,0x656f0107}},	//   vato_, _poos_, nček_, yich,
   {{0x44205e33,0x752416d7,0x60c45e34,0xdb0808c0}},	//   _osi_, _naiz, ncim, _didá,
   {{0x67233e99,0x656f5e35,0x442009d6,0x6d9800de}},	//   _banj, vich, _nsi_, níam,
   {{0x656f0b7b,0x67235e36,0x103700a5,0x8c1b00a5}},	//   wich, _canj, קטים_, _דומי,
   {{0x26de5e37,0x3946006d,0x656f5e38,0x67235e39}},	//   rato_, _toos_, tich, _danj,
   {{0x26de02fb,0x60c4011c,0xe7f300a1,0x6d425e3a}},	//   sato_, jcim, _आमचा_, njoa,
   {{0x656f5e3b,0x26de5e3c,0x6db70009,0x6d981725}},	//   rich, pato_, _ućav, víal,
   {{0x656f5e3d,0x68e05e3e,0x672309df,0x44201c58}},	//   sich, lamd, _ganj, _dsi_,
   {{0x44202686,0x75242001,0x9f400037,0x777a01e8}},	//   _esi_, _faiz, briú_, mntx,
   {{0x9f490082,0x67235e3f,0x752401d7,0x7c2013a6}},	//   rraí_, _zanj, _gaiz, _osmr,
   {{0x656d18ad,0x6723041b,0x9f490079,0x629e0065}},	// [5b50] _imah, _yanj, sraí_, _ezpo,
   {{0x752406a2,0x3dd8016e,0x6b5d0107,0x26dc023a}},	//   _zaiz, _bwrw_, _kège, _jevo_,
   {{0x7bc914e8,0x777a01a3,0xe13500c3,0x3dd8016e}},	//   _steu, intx, _енны, _cwrw_,
   {{0x6d982170,0x26dc37cb,0x3dd8099e,0x4420052a}},	//   bíam, _levo_, _dwrw_, _ysi_,
   {{0x9f400831,0x68e05e40,0x656d0430,0x6d980181}},	//   guió_, damd, _mmah, cíam,
   {{0x656d0430,0x777a006d,0xa91d4220,0x4fd600a5}},	//   _lmah, jntx, moži, _מושב_,
   {{0x67235e41,0x7c265e42,0x656d00d1,0x7de0006c}},	//   _ranj, _škrt, _omah, _vásá,
   {{0x67231164,0x627c0100,0x60dd003a,0x777a01d7}},	//   _sanj, ינונ, _jesm, entx,
   {{0x60dd130c,0x67230053,0x6d5b00b9,0x7bc90054}},	//   _mesm, _panj, _ilua, _uteu,
   {{0x656d070b,0x6d5b01a9,0x75245e43,0x44201eb3}},	//   _amah, _hlua, _saiz, _rsi_,
   {{0x67235e44,0x26dc547d,0x44205e45,0x6d5b5e46}},	//   _vanj, _devo_, _ssi_, _klua,
   {{0x60dd0097,0x6723595c,0x68e000af,0x2d785e47}},	//   _nesm, _wanj, camd, vček_,
   {{0x752401c8,0x60c40a78,0x6d5b006d,0x777a01e8}},	//   _vaiz, vcim, _mlua, bntx,
   {{0x4420108a,0x2bdd07df,0x6d982278,0xa37b00be}},	//   _vsi_, नीया, víam, ssõn,
   {{0x75245e48,0x60c43485,0x26f9051d,0x44200067}},	//   _taiz, tcim, ्भीर_, _wsi_,
   {{0x442001a9,0x216754e1,0x27e65e49,0x629e3247}},	//   _tsi_, писи_, _yvon_, _vzpo,
   {{0xb4d80e1d,0x44205e4a,0x557702b5,0x2fd900e5}},	// [5b60] िरी_, _usi_, _מעקן_, _cwsg_,
   {{0x6d9808c0,0x60c4031a,0xc2ea0332,0x60dd007c}},	//   ríam, scim, _اعظم_, _eesm,
   {{0x6d495660,0x60c40254,0x395f5e4b,0x9cca0104}},	//   _boea, pcim, khus_, была_,
   {{0x6b4f008c,0x6d5b009d,0x60dd237e,0x6d4901f7}},	//   _møgu, _clua, _gesm, _coea,
   {{0x6d5b006d,0x6d420086,0x395f5e4c,0x6b4f0a8a}},	//   _dlua, rjoa, dhus_, _løgu,
   {{0x6d5b5e4d,0xa09b0317,0x00000000,0x00000000}},	//   _elua, _ליכט, --, --,
   {{0x6d5b0098,0x68e0027d,0x27e65e4e,0x00000000}},	//   _flua, tamd, _svon_, --,
   {{0x6d5b009c,0x8b6600f8,0x6d49009f,0xd91a01e0}},	//   _glua, _کارم, _goea, ськ_,
   {{0x68e00269,0x7c20201d,0x6b5d0118,0x36d409cc}},	//   ramd, _usmr, _sège, мопр,
   {{0x68e011b4,0x656d0168,0x00000000,0x00000000}},	//   samd, _smah, --, --,
   {{0xe7e80006,0x26dc02d7,0xd9f00066,0xd6d700c3}},	//   _टटका_, _vevo_, _घटित_, чты_,
   {{0xd5b700c3,0xc7c6431b,0x00000000,0x00000000}},	//   ясь_, _ески, --, --,
   {{0x60dd5e4f,0x1b1f0083,0x00000000,0x00000000}},	//   _resm, পারে_, --, --,
   {{0xda2000a1,0x7c2d0095,0x2fcb0009,0x60dd5e50}},	//   _मनात_, çirə, _rtcg_, _sesm,
   {{0x60dd5e51,0x6234002d,0x56935e52,0xa19501e0}},	//   _pesm, неру, _пашт, давч,
   {{0x9f470311,0xf67b0122,0xa91d5e53,0xd34701cb}},	//   ční_, _לאומ, toži, _کیسه_,
   {{0x60dd0237,0x00000000,0x00000000,0x00000000}},	// [5b70] _vesm, --, --, --,
   {{0x657d5e54,0xa91d3788,0x6d5b09bb,0x6d49012f}},	//   lnsh, roži, _slua, _soea,
   {{0x6d5b006f,0x7a0a0095,0xe0d0006c,0x6d5a010b}},	//   _plua, _qətl, ئزہ_, _įtar,
   {{0x61f50944,0xa91d00a0,0x657d02ce,0xcc99145c}},	//   mrzl, poži, nnsh, овец_,
   {{0x21395e55,0x69da007a,0x45270033,0x2bdd00b4}},	//   _insh_, _awte, যাপক_, _नौशा,
   {{0x2009010b,0xb6070168,0x6b4f0a8a,0x00000000}},	//   mtai_, _jaší, _nøgt, --,
   {{0x395f5e56,0xf4130033,0x20095e57,0x6d495e58}},	//   thus_, িটির_, ltai_, _toea,
   {{0x21290464,0x17c947ea,0x62971d35,0xdce908b7}},	//   ndah_, огии_, _myxo, _kmeč,
   {{0x395f5e59,0xf53f0c61,0x2129486e,0x98bd0035}},	//   rhus_, rmål_, idah_, _nową_,
   {{0x2d8f5e5a,0x200900d8,0xb6070187,0x395f45cd}},	//   loge_, itai_, _naší, shus_,
   {{0x7ae35e5b,0x395f5e5c,0x63bf02d7,0xdb030079}},	//   mant, phus_, _auqn, nmní,
   {{0x200901c8,0xa2cb018d,0xb4d831d7,0x2d8f5e5d}},	//   ktai_, तुस्, िरे_, noge_,
   {{0x6b54009e,0x26c70ddb,0x660d0124,0xc9740cd1}},	//   _bàgh, _tfno_, _ćaku, _ثالث,
   {{0x657d5e5e,0x2129325b,0x629701ff,0x00000000}},	//   ansh, edah_, _byxo, --,
   {{0x3d0e1f57,0x6dbe016f,0xe0df01a6,0x2bdd09b1}},	//   ण्डे_, _vďak, _beò_, नीता,
   {{0x7ae35e5f,0xe0df01da,0x2d1c00a1,0x2d780009}},	//   hant, _ceò_, _नसेल_, lčev_,
   {{0x628542ed,0x63b700ac,0xe0df0211,0xb4ea0569}},	// [5b80] _exho, _fixn, _deò_, मणी_,
   {{0x7ae35e60,0x2d7802f6,0xef1700c3,0x443204fb}},	//   jant, nčev_, мму_, _iry_,
   {{0x4432114d,0x7bdb073a,0xdb010079,0x6b4f11cb}},	//   _hry_, _awuu, _ghlé, _løgs,
   {{0x44320626,0x61fc037a,0xdcfb0009,0x7ae35e61}},	//   _kry_, murl, _fjuč, eant,
   {{0x7ae35e62,0x6c1a1d05,0x29c301ed,0x9abc003c}},	//   fant, تتاح_, _aña_, _faċl,
   {{0x7ae31581,0xfca900ff,0xd04f013b,0x00000000}},	//   gant, سانو_, _necə, --,
   {{0x61fc5e63,0x290d0ddf,0x7bdb001c,0xdce902a7}},	//   nurl, ffea_, _ewuu, _zmeč,
   {{0xbea35e64,0x2d8f0831,0xf70e0023,0x6b540443}},	//   _раск, coge_, _củng_, _màgi,
   {{0x7ae30a7a,0xaacf0ea3,0x4acf0d60,0xdb0800c3}},	//   bant, _स्वक, _स्वव, _pidä,
   {{0xddc90043,0x61fc5e65,0x795c01cb,0x45d401e0}},	//   _înţe, kurl, _déwa, ноос,
   {{0x4432021d,0x7bc05e66,0xdceb0029,0x61fc028b}},	//   _ary_, _humu, ligā, jurl,
   {{0x7bc05e67,0x44325474,0x61fc5e68,0xdb0100ac}},	//   _kumu, _bry_, durl, _milý,
   {{0x7bc01eee,0xdb015e69,0x44323161,0x212900f4}},	//   _jumu, _shlé, _cry_, vdah_,
   {{0x289b0052,0x7bc05e6a,0xd04f00a8,0x6b4f0044}},	//   _וידא, _mumu, _gecə, _høgr,
   {{0x44320273,0x7bc04839,0xa2cb0af6,0xb6070187}},	//   _ery_, _lumu, तुष्, _vaší,
   {{0x7ae35e6b,0x20095e6c,0x00000000,0x00000000}},	//   zant, ttai_, --, --,
   {{0x7ae35e6d,0x4432006a,0x7bc05e6e,0xc05b02ce}},	// [5b90] yant, _gry_, _numu, ців_,
   {{0x20090e99,0x7ae35e6f,0x628501a9,0xdce9012e}},	//   rtai_, xant, _txho, _rjeđ,
   {{0x20095e70,0x61fc023a,0x8af7013b,0x7c260207}},	//   stai_, curl, şəki, _škrp,
   {{0x7ae35e71,0xa2cb05f8,0x7bc05e72,0xe5100019}},	//   want, तुर्, _bumu, _lặng_,
   {{0x4fc40328,0xa3d300a1,0x44320176,0x0c7500f8}},	//   _асса, हीच_, _xry_, رگرد,
   {{0xe51001a5,0x7bc00d94,0xfaa52bfc,0xdce90124}},	//   _nặng_, _dumu, нало, _vjeđ,
   {{0x7ae3028b,0x78a2013a,0x6b4f008c,0x00000000}},	//   rant, _azov, _søgs, --,
   {{0xd2b802b8,0x7bc00395,0xa49b02d0,0x78a200ee}},	//   ולות_, _fumu, nfòs, _bzov,
   {{0x7bc05e73,0x798200f8,0x66e5324a,0x6d595e74}},	//   _gumu, _djow, нопа, mkwa,
   {{0xb4d823db,0xd7090086,0x6d595e75,0x399a01f4}},	//   िर्_, чное_, lkwa, hësh_,
   {{0xcf9202b8,0x6dac06d3,0x7ae10023,0x29c30453}},	//   רטי_, _işar, _ielt, _uña_,
   {{0x6d595e76,0x7ae15e77,0x7bc03b3d,0x44325e78}},	//   nkwa, _helt, _yumu, _pry_,
   {{0x7ae15e79,0x649a5e7a,0x6d59073a,0x69c15e7b}},	//   _kelt, ятор_, ikwa, _hule,
   {{0x61fc362b,0x69c15e7c,0x6b540955,0xa2cb0026}},	//   turl, _kule, _pàgi, तुल्,
   {{0xf67902b5,0x69c15e7d,0x6d595e7e,0x7ae1190f}},	//   _מאַמ, _jule, kkwa, _melt,
   {{0xdb015e7f,0x644003ad,0x44325e80,0x69c12cb7}},	//   _kiló, ämis, _try_, _mule,
   {{0x69c15e81,0xb0aa0026,0x61fc5e82,0xb4be0380}},	// [5ba0] _lule, चेंग, surl, ेडी_,
   {{0xdceb00ea,0x69c100f6,0x6d59439e,0x799b0296}},	//   vigā, _oule, ekwa, hluw,
   {{0x7bc05e83,0xe29a1e9c,0x17560070,0x69c15e84}},	//   _sumu, _хан_, עסער_, _nule,
   {{0x9f471840,0x7bc000a7,0x6d592656,0x63620345}},	//   čná_, _pumu, gkwa, _dône,
   {{0xdca30cd0,0x7ae11024,0xe50500b1,0x69c15e85}},	//   гаци, _belt, ष्टि_, _aule,
   {{0x69c15e86,0x6d59001c,0x79820051,0x7ae15e87}},	//   _bule, akwa, _sjow, _celt,
   {{0x7ae102df,0x3ea302c4,0x69c15e88,0xbea35e89}},	//   _delt, _бирг, _cule, _барк,
   {{0x7bc05e8a,0x69c15e8b,0xd90e03c5,0x799b5e8c}},	//   _tumu, _dule, صیت_, gluw,
   {{0x7ae15e8d,0x7c240463,0x69c1229c,0xd90d02fd}},	//   _felt, çird, _eule, تین_,
   {{0x7c225e8e,0x7ae15e8f,0x7a0a013b,0x00000000}},	//   mwor, _gelt, _ləti, --,
   {{0x69c15e90,0x3a2501ef,0x399a0055,0xa4d501e0}},	//   _gule, _gslp_, hësi_, коні,
   {{0x7a0a01c2,0x7d025e91,0xdb012a87,0x7ae15e92}},	//   _nəti, ngos, _filó, _zelt,
   {{0xe5100028,0xf4840b46,0x38cb0647,0x69c101ae}},	//   _tặng_, гурн, _رانی_, _zule,
   {{0xdbc70006,0xb4bb02fd,0x6f1e0124,0x69c1023c}},	//   _tööt, _کاغذ_, jepc, _yule,
   {{0xd05601c2,0xf1a708ae,0x399a01f4,0x225800b8}},	//   mayə, еран, tësh_, _čeká_,
   {{0x7c222d1a,0xf8e007b5,0xd05600a8,0x256200ee}},	//   kwor, नरिय, layə, _póle_,
   {{0x442f2ea0,0x7d025e93,0x399a01f4,0xdb0101ef}},	// [5bb0] _ég_, dgos, rësh_, _xiló,
   {{0x2d840c21,0x7f4e006d,0xd0560095,0x68e25e94}},	//   _ajme_, _cobq, nayə, _leod,
   {{0xf7730070,0x7c220345,0x399a0055,0x98af005f}},	//   נקע_, ewor, pësh_, _ingą_,
   {{0x7ae15e95,0x7a0a01c2,0x69c15e96,0x9f4000de}},	//   _selt, _gəti, _rule, frió_,
   {{0x69c15e97,0x6d595e98,0x7ae100c3,0xd0560095}},	//   _sule, rkwa, _pelt, kayə,
   {{0x20195e99,0x69c15e9a,0x25a900fe,0x00000000}},	//   _ipsi_, _pule, _lhal_, --,
   {{0x7ae15e9b,0x68e25e9c,0xc3340d85,0xda620eb1}},	//   _velt, _beod, טוס_, ивши,
   {{0x7ae15e9d,0x9f405e9e,0x69c15e9f,0x991500d4}},	//   _welt, brió_, _vule, тькі,
   {{0x212b0014,0x68e25ea0,0x7c220526,0x7ae15ea1}},	//   _mach_, _deod, cwor, _telt,
   {{0x69c15ea2,0x25a90291,0x20195ea3,0xd7630220}},	//   _tule, _ahal_, _mpsi_, اندی,
   {{0xdb0102e9,0x391500d1,0x25a9035f,0x799b5ea4}},	//   _filò, _لواز, _bhal_, pluw,
   {{0x212b5ea5,0x25a95ea6,0x20190703,0x98af005f}},	//   _nach_, _chal_, _opsi_, _angą_,
   {{0x25a90211,0x00000000,0x00000000,0x00000000}},	//   _dhal_, --, --, --,
   {{0x987a02b5,0x2d78082d,0x27ff0768,0x03a641f8}},	//   _קאסט, nčer_, muun_, тиго,
   {{0xe2971bfd,0x212b001e,0xf7961b15,0x27ff0086}},	//   вар_, _bach_, _جنوب_, luun_,
   {{0x399a01f4,0x7c225ea7,0x25a90484,0x212b5ea8}},	//   tësi_, ywor, _ghal_, _cach_,
   {{0xf5770082,0x212b5ea9,0x7c22598f,0x27ff0421}},	// [5bc0] _جميع_, _dach_, xwor, nuun_,
   {{0x93fb168d,0xd36f004f,0x212b5eaa,0x394f0cd5}},	//   _קליי, _وهي_, _each_, _logs_,
   {{0x212b5916,0x20190069,0x2ee300ee,0xdb01007e}},	//   _fach_, _epsi_, _dejf_, _chlí,
   {{0x212b41f0,0x7c225eab,0x27ff03ad,0xdb010079}},	//   _gach_, twor, kuun_, _dhlí,
   {{0x7d025eac,0x0b8a0b46,0x399a01f4,0x2d8c1f51}},	//   rgos, мски_, qësi_, _ídem_,
   {{0x6713114e,0x9f400831,0x7d022278,0xa3da0127}},	//   त्मक_, rrió_, sgos, डीए_,
   {{0x35c60324,0x394f008c,0x656601ef,0xd05600a8}},	//   _रूढ़, _bogs_, khkh, vayə,
   {{0xdb090033,0xf98f004f,0x6da60eb4,0x212b0023}},	//   _dueñ, يبي_, _риба, _xach_,
   {{0xc17302b8,0x6dac0095,0x394f00a5,0x97a60d9e}},	//   יחה_, _uşaq, _dogs_, крол,
   {{0x5ba70012,0x95d803e6,0x394f0a8a,0x02be0e6f}},	//   _акум_, ндот_, _eogs_, ्डोन,
   {{0xb9080b52,0x0f5700a5,0x6b7b100a,0x35b505a1}},	//   _বা_, דיים_, _קרבנ, лбор,
   {{0xd6da0033,0x6d98002a,0x8a79016b,0xa91d00ac}},	//   _দাওয, mías, _אָנק, sožr,
   {{0x212b5ead,0x161e02b4,0x00000000,0x00000000}},	//   _rach_, _बनकर_, --, --,
   {{0x212b5eae,0x27f901ba,0x31620160,0x6b540176}},	//   _sach_, ásne_, _alkz_, _tàgu,
   {{0x31c4117a,0xab5d003c,0x9abc007a,0x81cb0033}},	//   иств, _juża, _baċi, রীন_,
   {{0x248901e8,0x29041265,0xf3ff0132,0x656600e2}},	//   _txam_, ngma_, puã_, chkh,
   {{0x3f15005f,0x212b5eaf,0xf3ff021d,0x00000000}},	// [5bd0] лдас, _vach_, quã_, --,
   {{0x44295eb0,0xdb1a00da,0x2ee30031,0x1616007c}},	//   _isa_, _ditë, _qejf_, _तहार_,
   {{0x733a02b5,0x212b5eb1,0x9abc003c,0xed59003d}},	//   _װערס, _tach_, _faċi, _liže_,
   {{0xff5f00af,0x6d980a54,0x14e3035d,0x212b5eb2}},	//   _atît_, días, परिण, _uach_,
   {{0xdb090033,0xed590254,0x2019404e,0xf044002d}},	//   _sueñ, _niže_, _upsi_, _кэро,
   {{0x44295eb3,0x3d0800ab,0x256200ee,0x00000000}},	//   _msa_, _हाथे_, _móla_, --,
   {{0x291f002f,0xdb0105ed,0x60cd002a,0x6362021d}},	//   teua_, _uhlí, ocam, _jôna,
   {{0x44290d4c,0xc879002d,0xa9250f68,0xdda800af}},	//   _osa_, laşi_, удил, _атул_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c295eb4,0xed59044d,0x27ff136b,0x6d980042}},	//   _iser, _diže_, ruun_, bías,
   {{0x44295eb5,0x6d9801dd,0xa50a2211,0x394f01ff}},	//   _asa_, cías, нена_, _togs_,
   {{0x25625eb6,0x60cd00ee,0x26ce0107,0xd76302fd}},	//   _bóla_, jcam, _effo_, انگی,
   {{0xe72e5eb7,0x60cd35e2,0x7c29035f,0x7d09009f}},	//   _ле_, dcam, _jser, _mces,
   {{0x27ed5918,0x752f004e,0x60cd5eb8,0x490f0066}},	//   msen_, adcz, ecam, थ्रो_,
   {{0x67210888,0x44295eb9,0x27ed0304,0x6b5d5a41}},	//   melj, _esa_, lsen_, _règl,
   {{0x68e9012f,0x7c295eba,0xc879002d,0x752d5ebb}},	//   naed, _oser, eaşi_, _gaaz,
   {{0x27ed5ebc,0xa0674ae8,0x7a0a0095,0x7c295ebd}},	// [5be0] nsen_, гата_, _hətt, _nser,
   {{0x7d095ebe,0x27ed114b,0x32460202,0x37c50033}},	//   _aces, isen_, _беог, _এবার,
   {{0x277600c2,0x7c2944da,0x68e90a8a,0x27ed45d4}},	//   נגען_, _aser, kaed, hsen_,
   {{0x27ed5ebf,0x60cd07e5,0x7d0901f7,0x67215ec0}},	//   ksen_, ccam, _cces, helj,
   {{0x5ee300c8,0x7c29006c,0x67215157,0x27ed5ec1}},	//   _পারে, _cser, kelj, jsen_,
   {{0x27ed5ec2,0x67210a78,0x6be3004f,0xdb0101a6}},	//   dsen_, jelj, حكوم, _chlà,
   {{0x67214d49,0x7c295ec3,0xa3b5004e,0x27ed5ec4}},	//   delj, _eser, जगत_, esen_,
   {{0x68e9099e,0x63be5ec5,0x6d980391,0x6b83055c}},	//   gaed, _lipn, rías, anng,
   {{0x6d40153c,0x27ed5ec6,0x31570070,0x7b0900c3}},	//   _inma, gsen_, טיקן_, ästö,
   {{0x656434de,0xcab90033,0x2562006c,0x60cd5ec7}},	//   _alih, ঁড়ফ, _róla_, zcam,
   {{0x49060180,0x44295ec8,0x27ed5ec9,0xc7c80019}},	//   _مواق, _ssa_, asen_, _bốc_,
   {{0x65955eca,0xc5f80029,0x27ed0909,0xc7c80023}},	//   раму, dzēt_, bsen_, _cốc_,
   {{0xb99307f8,0xc993004f,0x672103c9,0xc7c80023}},	//   _النب, _النظ, belj, _dốc_,
   {{0x6721042a,0x660100b8,0x65641a89,0x44295ecb}},	//   celj, bulk, _elih, _vsa_,
   {{0x60cd5ecc,0xdb1a2154,0x6d405ecd,0xd6270274}},	//   tcam, _cité, _onma, _боје_,
   {{0x44290189,0x7aea02c9,0x29ca0028,0xc7c801a5}},	//   _tsa_, haft, _mùa_, _gốc_,
   {{0x60cd0890,0x44295ece,0x9f405ecf,0xdfd10079}},	// [5bf0] rcam, _usa_, ksiä_, زيا_,
   {{0xa2d4057c,0x2b090243,0x63be011e,0x7d0907e5}},	//   बुद्, _साधु_, _gipn, _sces,
   {{0x7aea06d4,0x539c00a5,0x7a0a0095,0x60cd0375}},	//   daft, _איזו, _xətt, pcam,
   {{0x67215ed0,0x7c290065,0xeb1d0067,0x68e903c2}},	//   zelj, _pser, फ़्त_, xaed,
   {{0x8c4512da,0x1aee00c8,0x3b090202,0x777a01a3}},	//   реле, চ্ছে_, вело_, kitx,
   {{0x6d405ed1,0x92190066,0x5f140d1f,0x29ca00e2}},	//   _enma, _पहाड़_, न्द्_, _bùa_,
   {{0xdb01004f,0x06e30083,0x27ed01ed,0xf8e0012f}},	//   _chlá, _মালি, wsen_, नरूप,
   {{0x27ed5ed2,0x7d090506,0x7c295ed3,0x8e840037}},	//   tsen_, _uces, _tser, _الفه,
   {{0x67210888,0x27ed5ed4,0x68e95ed5,0x69d80051}},	//   telj, usen_, raed, apve,
   {{0x27ed5ed6,0xb8fc258f,0x66015ed7,0xf77118dd}},	//   rsen_, _त्_, tulk, تاب_,
   {{0x27ed5ed8,0x67215ed9,0xcb6845fd,0x316900d7}},	//   ssen_, relj, _حمله_, khaz_,
   {{0x67215eda,0x27ed5edb,0xc9844ea4,0xd8760118}},	//   selj, psen_, _лучи, امیت_,
   {{0x672103ab,0x66015edc,0x61ee0090,0xa3b100a1}},	//   pelj, sulk, wsbl, _ओळख_,
   {{0x394d5edd,0xb4e50084,0x386d03d0,0x43750009}},	//   ljes_, _पड़ी_, mzer_, буст,
   {{0xc7c801a5,0xe29a2846,0x386d5ede,0xa3da0026}},	//   _tốc_, тав_, lzer_, डीज_,
   {{0x629e024e,0x261a0084,0x395f010b,0x394d5edf}},	//   _vypo, _बहती_, nkus_, njes_,

   {{0x629e006a,0x386d4315,0x3fc8042c,0x395f1715}},	// [5c00] _wypo, nzer_, ادری_, ikus_,
   {{0x629e027e,0x386d01ae,0x395f00ab,0x394d01f4}},	//   _typo, izer_, hkus_, hjes_,
   {{0x394d5ee0,0x395f007c,0x324620c3,0xdd8f00fd}},	//   kjes_, kkus_, _тенг, ڈول_,
   {{0xf1bf098b,0x29ca0023,0xab5d0069,0xdd8f11c0}},	//   _giá_, _rùa_, _bużo, وول_,
   {{0x394d5ee1,0xdd1300fd,0xac074cd3,0x386d5ee2}},	//   djes_, تونخ, инца_, jzer_,
   {{0xdce600c1,0x395f00ea,0x386d02d4,0xdb010098}},	//   ımın, ekus_, dzer_, _phlá,
   {{0x7aea22b1,0x394d5ee3,0x636b033b,0xca4800d1}},	//   raft, fjes_, _fünf, العه_,
   {{0x6d401b9f,0x07130964,0xed57049f,0x7aea2aab}},	//   _unma, त्सव_, _кос_, saft,
   {{0xed571a72,0x6af604cd,0x7aea008c,0x777a01a3}},	//   _тот_, _نثار, paft, titx,
   {{0xab5c0029,0x394d00de,0x27f900a0,0x7a0a0160}},	//   _biļe, ajes_, ásna_, _aște,
   {{0x56944ca2,0x777a5ee4,0x3160013b,0x394d0051}},	//   сант, ritx, kkiz_, bjes_,
   {{0x69c85ee5,0x394d1c3a,0x7ae8008c,0x777a01b7}},	//   _iude, cjes_, _hedt, sitx,
   {{0xb7d42086,0x69c85ee6,0x9f47016f,0x636b5ee7}},	//   _اقتب, _hude, čnú_, _jüng,
   {{0x69c85ee8,0x6b980009,0x938800c3,0x236500b5}},	//   _kude, novg, асса_, ólj_,
   {{0x69c80012,0x7ae85ee9,0x2b090d43,0x96b70274}},	//   _jude, _medt, _सासु_, _кућу_,
   {{0x69c85eea,0xeeeb0019,0x92580009,0x7ae804c1}},	//   _mude, _đựng_, шаст_, _ledt,
   {{0x657d4b98,0xb4e306bc,0xed590ce9,0xdb0106f2}},	// [5c10] mish, धरी_, _niža_, _kilô,
   {{0x69c80a45,0x657d5eeb,0x394d01f4,0x645d5eec}},	//   _oude, lish, zjes_, mysi,
   {{0x645d0122,0x75d300af,0x657d023c,0xa1955eed}},	//   lysi, _găzd, oish, _ганч,
   {{0x657d5eee,0x00000000,0x00000000,0x00000000}},	//   nish, --, --, --,
   {{0x645d5eef,0x6b5d0176,0xac2716bc,0xf538016b}},	//   nysi, _hègi, рфек, יטאר_,
   {{0x69c80097,0x657d3d6d,0x7dd3035f,0x636b02b1}},	//   _bude, hish, _aħse, _düng,
   {{0x657d5ef0,0x394d5ef1,0x9f490037,0x395f5ef2}},	//   kish, tjes_, nsaí_, tkus_,
   {{0x386d5ef3,0x657d5ef4,0x248d0035,0x636b1ee3}},	//   tzer_, jish, żemy_, _hünd,
   {{0x256200c8,0x657d5ef5,0x394d00da,0xdcfb02c4}},	//   _sólo_, dish, rjes_, _ajuć,
   {{0x394d5ef6,0x395f5473,0x386d01ae,0x69c80183}},	//   sjes_, skus_, rzer_, _fude,
   {{0x386d0332,0x394d5ef7,0x657d5ef8,0x7bc1010d}},	//   szer_, pjes_, fish, _iilu,
   {{0x7a7a00c2,0x657d0232,0x645d5ef9,0xf2c90070}},	//   _גרעס, gish, fysi, _טע_,
   {{0x7bc15efa,0x7d1b4aca,0x69c801ae,0x7bc90392}},	//   _kilu, _mbus, _zude, _jueu,
   {{0x69c85efb,0x80d50266,0x04fa0033,0xd88600fd}},	//   _yude, युसे, েজের_, _چھین_,
   {{0x657d5efc,0x7d1b0273,0x69c80391,0x7bc900a2}},	//   bish, _obus, _xude, _lueu,
   {{0x671302e4,0x7c3b5efd,0x7bc146c7,0x657d01d5}},	//   त्रक_, _orur, _lilu, cish,
   {{0xef1a4e5d,0x9f400037,0x80aa4a29,0x636b5efe}},	// [5c20] лма_, msiú_, ував_, _bünd,
   {{0x7bc15eff,0x9f40004f,0x7d1b5f00,0x27ff1ea7}},	//   _nilu, lsiú_, _abus, irun_,
   {{0xb3bb0122,0x7dd30024,0xb7ff0033,0x7c3b0371}},	//   _תמיכ, _aħsb, ্বিত_, _arur,
   {{0x69c85f01,0xdb1b008a,0x442001ed,0x75264d95}},	//   _rude, _stuð, _kpi_, nekz,
   {{0x69c829de,0x9f400037,0x442008c7,0x636b02b1}},	//   _sude, isiú_, _jpi_, _fünd,
   {{0x636b06d0,0x7d1b5f02,0x657d5ef0,0xc7c80019}},	//   _günd, _ebus, zish, _bốn_,
   {{0x657d5f03,0x7ae810db,0x6a130037,0x645d0067}},	//   yish, _vedt, كبير, zysi,
   {{0x3f9a5f04,0x44202d3b,0x636b033b,0x7bc15f05}},	//   lopu_, _opi_, _zünd, _eilu,
   {{0x657d569c,0x96ea0131,0x7bc11d11,0xdce9044d}},	//   vish, льна_, _filu, _smeć,
   {{0x657d16fe,0x69c85f06,0x7bc15f07,0x35f42a24}},	//   wish, _tude, _gilu, опор,
   {{0x44205f08,0x657d5f09,0x69c803ad,0xa3be0632}},	//   _api_, tish, _uude, ेदन_,
   {{0xd5675f0a,0x6b5d0443,0x443b0a07,0x44205f0b}},	//   стоп, _règi, _prq_, _bpi_,
   {{0x657d5f0c,0xdb1a0183,0x636b0508,0x974300cd}},	//   rish, _lití, _lüne, _šćep,
   {{0x657d16b3,0x645d5f0d,0x44205f0e,0xdb0802d0}},	//   sish, rysi, _dpi_, _zidò,
   {{0x4420142f,0x657d000e,0xdce9042a,0xa77b0122}},	//   _epi_, pish, _umeć, _תרופ,
   {{0x657d00da,0x636b007c,0x9f49004f,0x44200703}},	//   qish, _sünd, rsaí_, _fpi_,
   {{0x9f553b8b,0x2d870355,0xd3270d13,0x20005f0f}},	// [5c30] овач, énem_, _льни, grii_,
   {{0x80d905f8,0x27e60103,0x78a2034d,0x00000000}},	//   _फ्रे, _mwon_, _myov, --,
   {{0x20000395,0x7bc1325f,0xab5d009f,0x7bc900a2}},	//   arii_, _rilu, _fużj, _sueu,
   {{0xa69b0070,0x7c3b5f10,0x9c395f11,0x02b500b4}},	//   נשאפ, _prur, ипет_, ंधीन,
   {{0x7bc90052,0x442001a2,0x6aa152c7,0xf1a40144}},	//   _queu, _xpi_, _sylf, _хрэн,
   {{0xc1ed5f12,0x76450093,0x443900ec,0x09b300e7}},	//   _जबाब_, _áhyg, ivs_, ुद्य,
   {{0x27e62111,0x636b06d0,0x81cb0083,0xafdb0a8a}},	//   _awon_, _güne, রীর_, _brøg,
   {{0x7d1b070b,0xc7c801a5,0x7bc100f8,0x7c3b01f4}},	//   _ubus, _vốn_, _wilu, _trur,
   {{0x7c3b01d5,0x7d040037,0x69c201d7,0x44392544}},	//   _urur, óise, _dioe, jvs_,
   {{0x27ff01d7,0xc7c80019,0x75d3002d,0x70c60253}},	//   rrun_, _tốn_, _răzb, _वल्ल,
   {{0xaa670836,0xc7c80023,0x27e600e0,0xda020354}},	//   _утак, _uốn_, _ewon_, रूआत_,
   {{0x69c2027a,0x27e60359,0x261a00ab,0x6eac0067}},	//   _gioe, _fwon_, _बहरी_, _झरसु,
   {{0x33330484,0x78a20160,0x00000000,0x00000000}},	//   _baxx_, _gyov, --, --,
   {{0x43755f13,0x44200345,0x69c201a3,0xfbd20277}},	//   пуст, _vpi_, _zioe, ותך_,
   {{0x6b840037,0x03a30ae6,0x7989023c,0x53a31a15}},	//   éigi, фиро, onew, фарб,
   {{0x442005ca,0xe0da075c,0x20004776,0x61435f14}},	//   _tpi_, рва_, trii_, меса,
   {{0x88bd004e,0xd00a1676,0x291d0a15,0x3f9a1f45}},	// [5c40] ześn, резе_, _mbwa_, topu_,
   {{0x7c240463,0x799b0120,0x7989009e,0x2d8d2889}},	//   çirm, houw, hnew, _ajee_,
   {{0x644100ea,0x79893540,0x291d01a8,0x4e2a1099}},	//   ālie, knew, _obwa_, роен_,
   {{0x68eb326f,0xcbd50083,0x2000002d,0xafdb1217}},	//   _negd, _হয়েছ, prii_, _brød,
   {{0xead42a82,0x79895f15,0x09d200a1,0x6e290009}},	//   поль, dnew, सऱ्य, _ćebe,
   {{0x7989406e,0x636b5f16,0x2d780009,0x291d0103}},	//   enew, _tüne, nčez_, _abwa_,
   {{0x8e550210,0xf96a0043,0x798900e9,0x6b8d0079}},	//   _етті, ирий_, fnew, éaga,
   {{0xa37b0132,0xfafa02fd,0x26c7055c,0x298a1d77}},	//   mpõe, _چراغ_, _agno_, јско_,
   {{0x6da3263b,0xbb4a02fd,0x68eb5f17,0x274a1858}},	//   _цита, _پلان_, _degd, ачно_,
   {{0x256200fb,0x636b02c9,0x8b660fda,0x64e30ec5}},	//   _fólk_, _münc, _بارم, पर्श,
   {{0x799b3440,0x79895f18,0xdb1a0183,0x33330069}},	//   bouw, bnew, _titâ, _raxx_,
   {{0x69da5f19,0x4439005f,0xe45f00c3,0xdb1a0139}},	//   _itte, tvs_, työ_, _uitâ,
   {{0xd5b82698,0xccf300a5,0x94ab1052,0x00000000}},	//   юсь_, וכר_, ртна_, --,
   {{0x44395f1a,0x798043dd,0x39465f1b,0x6eda022e}},	//   rvs_, limw, _hnos_, _प्लु,
   {{0x67285f1c,0x2d87006c,0xf8ad0580,0x62340fc5}},	//   medj, ének_, _لکی_, меру,
   {{0x34950757,0xd5cf00ab,0x67285f1d,0x443901ed}},	//   _найр, _संतज, ledj, pvs_,
   {{0x656f0a32,0x66081061,0x3a3e0107,0x5067010b}},	// [5c50] mhch, ludk, _lrtp_, цтва,
   {{0x6728029d,0x69da392c,0x798001d5,0x2bbd0260}},	//   nedj, _otte, himw, _gňch_,
   {{0x7989008c,0x798006b1,0xa91d030a,0x660800be}},	//   ynew, kimw, liže, nudk,
   {{0x8d741dbf,0xf653011d,0x656f00e2,0x2b45009e}},	//   وانا, וצע_, nhch, _snlc_,
   {{0x69da5f1e,0x636b0723,0x60d602b5,0xdb1a0392}},	//   _atte, _günc, _מורא_, _bità,
   {{0x3946130f,0xab290c94,0x3c1e0029,0x2129289c}},	//   _anos_, сока_, dāvā_, leah_,
   {{0x66081096,0x79895f1f,0x1df8021f,0xaa560274}},	//   judk, tnew, _меры_, зију_,
   {{0x3f815f20,0xab5d003c,0x2bcb00b4,0xafdb03d0}},	//   lihu_, _mużi, ाददा, _trød,
   {{0x02a809a3,0x69da2e04,0x656f0094,0xa91d01cc}},	//   _गर्न, _ette, dhch, jiže,
   {{0x3ced01a9,0x79895f21,0x2d9d5f22,0x25a02129}},	//   _heev_, snew, lowe_, _skil_,
   {{0x637015e5,0xe5a65a1a,0x79895f23,0x79800979}},	//   _häng, зини, pnew, bimw,
   {{0x2d9d0035,0x63705f24,0x291d01d5,0xdb1a0132}},	//   nowe_, _käng, _ubwa_, _titã,
   {{0xe7391d99,0x33d50185,0x67281f31,0xed5908b7}},	//   _гел_, діст, bedj, _mož_,
   {{0x63705f25,0x69da1875,0x3ced55f0,0x69d60093}},	//   _mäng, _ytte, _leev_, _ógeð,
   {{0x63705f26,0x2d9d004e,0x32430dba,0xd2aa1397}},	//   _läng, kowe_, нерг, скве_,
   {{0x9f470d88,0xc6920122,0x290d5f27,0x3ced006d}},	//   čný_, _ראה_, ngea_, _neev_,
   {{0x2d9d004e,0x20095f28,0xdb1a3536,0xdb010098}},	// [5c60] dowe_, guai_, _litá, _dhlú,
   {{0x161f0324,0x79805f29,0x3f810027,0x00000000}},	//   _बहार_, zimw, gihu_, --,
   {{0x7bdb01a8,0x1d2600af,0x00000000,0x00000000}},	//   _atuu, змем, --, --,
   {{0x3ced006f,0xed5901c0,0x2d9d5f2a,0xdb010079}},	//   _ceev_, _což_, gowe_, _ghlú,
   {{0x32185f2b,0x3ced0221,0x3f810e85,0x320a0e7d}},	//   ltry_, _deev_, bihu_, luby_,
   {{0x88bd004e,0xdb1a05c9,0x6c830037,0xafdb0a8a}},	//   reśl, _bitá, علوم, _frøb,
   {{0xfce65f2c,0x32180122,0x2d9d5f2d,0xdb1a0187}},	//   _ново, ntry_, bowe_, _citá,
   {{0x637015e5,0x636b01c2,0xf1be5f2e,0x443206fe}},	//   _händ, _müna, ्दिन, _osy_,
   {{0x6370315b,0xa3be00be,0x67282a9c,0x798001d5}},	//   _gäng, ेदा_, tedj, rimw,
   {{0x29d105ee,0x45d41b50,0x7980262b,0x00000000}},	//   _fáa_, моос, simw, --,
   {{0xaadb0052,0x2eaa022e,0x656f0094,0x44320ac8}},	//   _החבר, _करोत, thch, _asy_,
   {{0x39460083,0x2c20006a,0x6370306a,0xa91d5f2f}},	//   _unos_, _यहां_, _länd, tiže,
   {{0x443f0391,0xf8bf0501,0x9f5202d7,0x321801ed}},	//   íu_, žér_, nuyó_, etry_,
   {{0x4acc0253,0xa91d08b7,0x2d9d0035,0xc1c505f8}},	//   ाशिव, riže, zowe_, वद्ग,
   {{0x80a20380,0x32180159,0x656f0036,0x2d9d2004}},	//   _कुबे, gtry_, phch, yowe_,
   {{0x20091096,0xdb010211,0x636b018d,0x00000000}},	//   tuai_, _dhlù, _düna, --,
   {{0x656d5f30,0x63705f31,0x30151ad4,0xed590116}},	// [5c70] _ilah, _bänd, ьдар, _rož_,
   {{0x3ced006f,0x2d9d5f32,0x2903010b,0x63701ca0}},	//   _seev_, wowe_, ėjai_, _räng,
   {{0x7bdb06ba,0x63705f33,0x20090f1a,0x3ced0189}},	//   _stuu, _säng, suai_, _peev_,
   {{0x6b5d0fce,0x00000000,0x00000000,0x00000000}},	//   _nègr, --, --, --,
   {{0xa1560bed,0x2d9d004e,0xca6b0210,0xac092659}},	//   _חברה_, rowe_, _бiлi, інка_,
   {{0x656d5f34,0x2d9d004e,0x7c9400bf,0x8c420c46}},	//   _llah, sowe_, رشنا, теше,
   {{0x3ced01a9,0x656d54d2,0x80c20033,0x2d9d0035}},	//   _teev_, _olah, ষুদ্, powe_,
   {{0x9f520453,0x7d5500d8,0xdb1a5f35,0x3eae02b1}},	//   buyó_, _ўвах, _vitá, üfte_,
   {{0x637003ad,0x6d490341,0xdd9400d8,0x290d0395}},	//   _häne, _inea, _чаты, rgea_,
   {{0x656d300c,0x6d490211,0x63620183,0x6b840098}},	//   _alah, _hnea, _tôni, éigt,
   {{0x656d1d8a,0x637000be,0x6d5b2a5a,0x00000000}},	//   _blah, _jäne, _koua, --,
   {{0x6b835f36,0x443245d1,0x6d5b00f7,0x00000000}},	//   ling, _psy_, _joua, --,
   {{0x637001ff,0x6b835f37,0x6d5b5f38,0x6d490139}},	//   _läne, oing, _moua, _mnea,
   {{0x7c240669,0x36695f13,0x6d5b00a2,0x656d0103}},	//   çiri, _мало_, _loua, _elah,
   {{0xc7b20122,0x6d4901a3,0x63705f39,0xb602008d}},	//   _שבו_, _onea, _ränd, þátt,
   {{0x6b835f3a,0x6370013c,0x320a00ac,0xb35800b5}},	//   hing, _sänd, ruby_, _کیسا_,
   {{0x3218024b,0xb4ea0534,0x00000000,0x00000000}},	// [5c80] stry_, यरी_, --, --,
   {{0x6b835f3b,0xf09f0176,0x6d49416a,0x656d0116}},	//   jing, _acàs_, _anea, _zlah,
   {{0x6b835306,0x63705f3c,0x6d5b00a2,0x9f4902b1}},	//   ding, _vänd, _boua, spaß_,
   {{0xbc6a017e,0x9f520453,0x6370033b,0x973c00cd}},	//   يمان_, tuyó_, _däne, moće,
   {{0x6b835f3d,0x6d5b5f3e,0x69d70391,0x6370013c}},	//   fing, _doua, íxen, _tänd,
   {{0x6b835f3f,0xf76729fe,0x7c2d5f40,0x6d491024}},	//   ging, _شا_, çara, _enea,
   {{0xfb1900b5,0x7f5c0a4a,0x3a255856,0x6b5d00f6}},	//   سروں_, _iorq, _cplp_, _pègr,
   {{0x383412dc,0xed430923,0xc7c80019,0xa3b50084}},	//   енир, _инсп, _hối_, _छीन_,
   {{0xc2f40083,0x6b835f41,0x26ca011c,0x3ce6023a}},	//   _জানি_, bing, žbom_, mbov_,
   {{0xf4140083,0xb9050035,0xe0df0107,0xab5d0024}},	//   িবার_, _ब्_, _anòl_, _bużu,
   {{0x656d5f42,0xc7c801a5,0xc9560086,0x6d5b055c}},	//   _plah, _mối_, _отды, _youa,
   {{0x7bc849c2,0xc7c80019,0x7f5c015e,0x00000000}},	//   _hidu, _lối_, _lorq, --,
   {{0x7bc85f43,0x9f4012c3,0x656d5f44,0xe73a3537}},	//   _kidu, nsió_, _vlah, _мед_,
   {{0xb4af0006,0x7f5c009f,0x7bc8023c,0x00000000}},	//   _करी_, _norq, _jidu, --,
   {{0xc7c801a5,0x3d0f0243,0x7bc85f45,0xa91d030a}},	//   _nối_, _डाले_, _midu, liža,
   {{0x6b835f46,0x656d02b3,0x7bc85f47,0xdb01021e}},	//   zing, _ulah, _lidu, _eklè,
   {{0x46d20084,0x6d5b3d65,0xa91d05e2,0xa29f1bb5}},	// [5c90] _सलाह, _roua, niža, _खुर्,
   {{0x6d495f48,0xc7c80019,0x63620132,0x7bc804fb}},	//   _snea, _bối_, _bônu, _nidu,
   {{0x6b835f49,0x6d5b5f4a,0xdb1a03ad,0xc3320070}},	//   ving, _poua, _mitä, _גוי_,
   {{0x6b835f4b,0xc7c80019,0x63701cb5,0x62970024}},	//   wing, _dối_, _väne, _ixxo,
   {{0x7f5c5f4c,0xa91d0254,0x7bc85f4d,0x256200ac}},	//   _forq, jiža, _bidu, _gólu_,
   {{0x6738022f,0x7bc80118,0xed59023a,0x21390147}},	//   _navj, _cidu, _miži_, _hash_,
   {{0x7bc806df,0x4ea45f4e,0x21392a2b,0xc7c80019}},	//   _didu, _арта, _kash_, _gối_,
   {{0x6b835f4f,0x26181010,0xb4af02cb,0xdce92f70}},	//   sing, déo_, _करू_, _kleč,
   {{0x7bc85f50,0x6b831b39,0xed59011c,0x636b00ab}},	//   _fidu, ping, _niži_, _rünn,
   {{0x636b5f51,0x7bc8043d,0xbbcb06d9,0xdce95f52}},	//   _sünn, _gidu, ादीक, _mleč,
   {{0xe6160144,0xa29f00a9,0xb81c0831,0x00000000}},	//   ндэ_, _खुल्, তিগত_, --,
   {{0x6e2700d7,0x7bc85f53,0xed590207,0xb4ea02b4}},	//   _mpjb, _zidu, _biži_, यरे_,
   {{0x2d8f19fd,0x00000000,0x00000000,0x00000000}},	//   inge_, --, --, --,
   {{0x2903010b,0xed590520,0x31690065,0x00000000}},	//   ėjau_, _diži_, ekaz_, --,
   {{0x7f5c00d7,0x21390147,0x00000000,0x00000000}},	//   _rorq, _bash_, --, --,
   {{0x67380c21,0xc7c80019,0x21395f54,0x9f400138}},	//   _zavj, _rối_, _cash_, mpié_,
   {{0x7f5c2140,0x75245f55,0x636b0be2,0x21390147}},	// [5ca0] _porq, _ibiz, _güno, _dash_,
   {{0x64440069,0xe3b20037,0xcb0e252b,0x316901b7}},	//   _irii, _حرب_, _साइड_, akaz_,
   {{0xe8ac143a,0xdce22190,0x7bc85f56,0x1ea90987}},	//   _चर्च, skoč, _ridu, وامي_,
   {{0x64441c55,0x7bc800ab,0xdce90009,0x6b8100e5}},	//   _krii, _sidu, _fleč, _amlg,
   {{0xdce90c99,0x7bc800ab,0x75245f57,0x6aa808c8}},	//   _gleč, _pidu, _mbiz, _sydf,
   {{0xc7c80028,0x9f400955,0x2d8f5bdf,0xa91d0124}},	//   _tối_, rsió_, ange_, viža,
   {{0x7bc85f58,0x9f400955,0xf9c65f59,0x99662123}},	//   _vidu, ssió_, нщин, етпл,
   {{0x67380470,0x7bc85f5a,0xdca6272c,0x2d8700b5}},	//   _savj, _widu, _заби, énet_,
   {{0xb4af0b4a,0xdb1a03ad,0x7bc8005d,0x764300e9}},	//   _करे_, _pitä, _tidu, _arny,
   {{0x26180248,0x75245f5b,0x7bdf0181,0xa91d00f4}},	//   téo_, _abiz, íque, riža,
   {{0x569405f2,0x64445512,0x75240103,0x6440003e}},	//   тант, _arii, _bbiz, æmin,
   {{0xe4a70b00,0xa91d0254,0x64445f5c,0xe0df0107}},	//   ерго, ližn, _brii, _pnòm_,
   {{0x6444009e,0xe7865604,0x21390147,0x00000000}},	//   _crii, _пуко, _rash_, --,
   {{0x636b0d6f,0xafdb390d,0x752401a8,0x65b60355}},	//   _günl, _brøn, _ebiz, váhe,
   {{0xb5a702ce,0xa5d7004f,0xdce9156f,0xdcfb008b}},	//   _прий, _كبير_, _sleč, _smuč,
   {{0x64440557,0xdce95f5d,0xafdb1f8b,0x00000000}},	//   _frii, _pleč, _drøn, --,
   {{0x6444013a,0x5ee20033,0x63620183,0xc05b01e0}},	// [5cb0] _grii, _পয়ে, _côns, чів_,
   {{0xa91d02c6,0x752f0035,0xdce9067b,0x2139024b}},	//   jižn, lecz, _vleč, _wash_,
   {{0xdce90c0a,0xafdb0909,0x213901f4,0x07180246}},	//   _smeđ, _grøn, _tash_, _दानव_,
   {{0x753d0332,0x2d8f4512,0x752f0035,0x3eaa08c8}},	//   ndsz, unge_, necz, _dybt_,
   {{0xb4af0953,0x5bcb0d34,0xaacc0722,0x44295f5e}},	//   _करो_, ादेव, ाशंक, _jpa_,
   {{0x996c00b8,0xb4af00be,0x6f150067,0x1ee703fc}},	//   měř_, _करै_, _uczc, _سوری_,
   {{0x2d870033,0x533800a5,0x00000000,0x00000000}},	//   énes_, גנון_, --, --,
   {{0x44295f5f,0x752f0067,0x00000000,0x00000000}},	//   _opa_, jecz, --, --,
   {{0x44295f60,0xdce900fe,0x20092388,0x00000000}},	//   _npa_, _hleď, nrai_, --,
   {{0x7c295f61,0x75240036,0xab6234c3,0xe6450382}},	//   _iper, _sbiz, şürm, веоп,
   {{0x391505c2,0x44295112,0xa50a5f62,0xb8c829ad}},	//   _амер, _apa_, мена_, _खु_,
   {{0x64445f63,0x200901c8,0x442900f1,0x2903010b}},	//   _prii, krai_, _bpa_, ėjas_,
   {{0x68e95f64,0xe72e0370,0x7c2901ef,0xe0df021e}},	//   mbed, _ке_, _jper, _enòk_,
   {{0x20095f65,0x69cb09fe,0x44295f66,0x7c29018c}},	//   drai_, _hige, _dpa_, _mper,
   {{0xd2990210,0x69cb1d6a,0xcb120319,0x20095f67}},	//   етті_, _kige, ילם_, erai_,
   {{0x68e959bd,0x6444465c,0x973c00cd,0x752404fb}},	//   nbed, _trii, moća, _ubiz,
   {{0x2fca028b,0x64445f68,0x69cb5f69,0x64a60274}},	// [5cc0] _pibg_, _urii, _mige, _јапа,
   {{0x69cb5f6a,0xda2100b4,0xafdb01e0,0x00000000}},	//   _lige, _महंत_, _trøn, --,
   {{0x7c295f6b,0x81dc00c8,0x20093829,0x4f952d93}},	//   _aper, _ঠিক_, arai_, урту,
   {{0x69cb5f6c,0xc7c80023,0xafdb11cb,0x008602c4}},	//   _nige, _hốt_, _krøl, _алмо,
   {{0xed59011c,0x68e95f6d,0x0ffa083a,0x00000000}},	//   _nižu_, dbed, _تعجب_, --,
   {{0x752f004e,0xdee35f6e,0x68e954f1,0x69cb239a}},	//   zecz, _вори, ebed, _aige,
   {{0x69cb050f,0xa91d18b0,0x7c295f6f,0xc7c80023}},	//   _bige, rižn, _eper, _mốt_,
   {{0x68e90298,0xed5900ee,0xd90e02fd,0x58380382}},	//   gbed, _bižu_, زیت_, езия_,
   {{0x61e90129,0xa5c7008d,0xb4e30f9c,0xdb015f70}},	//   ćeli, _ljóð, _क्षय_, _chló,
   {{0x69cb5f71,0xed590df4,0x61fe01ba,0xc7c80023}},	//   _eige, _dižu_, _ovpl, _nốt_,
   {{0x44295f72,0x752f004e,0x69cb5f73,0xaaa90d12}},	//   _spa_, tecz, _fige, _चुपक,
   {{0x7982004e,0x69cb5f74,0xeeeb0023,0xafdb0a8a}},	//   _umow, _gige, _đọng_, _brøl,
   {{0xc45800c3,0x752f5cc9,0x94a80352,0x9f40008d}},	//   виях_, recz, втра_, ysið_,
   {{0xd90e07a8,0xa5c7008a,0x20095f75,0x69cb0b69}},	//   _ایک_, _bjóð, vrai_, _zige,
   {{0x69cb01d5,0xdb1a00ee,0xc7c800e2,0x2d840a8c}},	//   _yige, _bitú, _dốt_, _omme_,
   {{0x20095f76,0x04675f77,0x0eeb0518,0xbeeb111a}},	//   trai_, _атом, टर्स_, टर्न_,
   {{0x7ff42e36,0x25a9046a,0x44295f78,0x29d85f79}},	// [5cd0] لسلا, _ikal_, _upa_, _léa_,
   {{0x63700303,0x68e90bec,0x65b6024e,0x20095f7a}},	//   _täna, zbed, máha, rrai_,
   {{0x4fc438d0,0x637009bf,0xf41f03ad,0x7c295f7b}},	//   рста, _känn, ltä_, _sper,
   {{0x5bcb48cd,0x63705f7c,0x2009027a,0x5c75584e}},	//   ाद्व, _jänn, prai_, ллет,
   {{0x63705f7d,0x69cb5f7e,0xf41f03ad,0x8d7700f8}},	//   _männ, _rige, ntä_, _یارا,
   {{0x69cb0b41,0xf41f0086,0x63705f7f,0x2d845f80}},	//   _sige, itä_, _länn, _emme_,
   {{0x69cb5f81,0x68e956ec,0xdb010211,0xdb030055}},	//   _pige, tbed, _bhlò, lonë,
   {{0x644100ea,0xdb010284,0xe9a900f8,0xd2b800a5}},	//   ālij, _chlò, رگان_, כלות_,
   {{0x68e95f82,0xccf20122,0x7c295f83,0x9f8d00d5}},	//   rbed, _לכן_, _uper, _lží_,
   {{0x68e95f84,0xc2e90083,0x25a904f6,0x69cb04fb}},	//   sbed, কৃতি_, _akal_, _wige,
   {{0x8f9c0122,0xcb6800d1,0xc7c80023,0x69cb5f85}},	//   ויזי, _جمله_, _rốt_, _tige,
   {{0xc7c80019,0xc9840dc8,0x973c02c4,0xceb2100a}},	//   _sốt_, _кучи, roća, מיי_,
   {{0x973c0a78,0x3dcd00d7,0xa5c70093,0x636b0457}},	//   moćn, _miew_, _sjóð, _günk,
   {{0xdb1a2675,0x79892069,0x3dcd028b,0x31be111b}},	//   _sitú, liew, _liew_, ्द्ध,
   {{0xe29732a6,0x412a4e5d,0x637000ab,0xafdb0c71}},	//   гар_, ново_, _fänn, _drøm,
   {{0x7989004e,0x973c011c,0x00e400f8,0x00000000}},	//   niew, noćn, شتری, --,
   {{0xc7c80028,0xd0071bc0,0xafdb008c,0x00000000}},	// [5ce0] _tốt_, лете_, _frøm, --,
   {{0xe0df02d0,0xb4c20026,0xef170274,0xdb030093}},	//   _efò_, ्खी_, лму_, llnæ,
   {{0x69c05f86,0x394f50a1,0xdb030279,0x9d4601d3}},	//   ymme, _ongs_, ponê, лежд,
   {{0xdb035f87,0x29d800f6,0x79890345,0x00000000}},	//   lonè, _réa_, jiew, --,
   {{0x6acc0569,0x2d9e5f88,0x7af85f89,0x79890afc}},	//   ाश्र, _ítem_, tavt, diew,
   {{0x394f03bc,0xdb01009e,0x00000000,0x00000000}},	//   _angs_, _shlò, --, --,
   {{0xbf100d53,0x7af803c1,0x2cad0147,0x00000000}},	//   ालीन_, ravt, _eyed_, --,
   {{0xdd92040d,0x6e935f8a,0xf41f03ad,0x6da6083e}},	//   _اور_, _الفا, ytä_, _сиба,
   {{0xd6d00082,0xdb0302e9,0xa7741fff,0x8c4305f2}},	//   يقة_, konè, илич, _лете,
   {{0x25a90b41,0x10370122,0x65b65f8b,0x394f0069}},	//   _skal_, נטים_, váha, _engs_,
   {{0xda650594,0xb806060a,0xdb0301f7,0x0f5700a5}},	//   _پالي, _शिवम_, donè, איים_,
   {{0x1a9b0779,0xf41f03ad,0xafdb0d51,0x00000000}},	//   _איבע, ttä_, _drøj, --,
   {{0x6370022a,0x69da0006,0x00000000,0x00000000}},	//   _vänn, _पंडी, --, --,
   {{0xa6660d93,0x25bb5f8c,0xf41f02ee,0xd6cf0413}},	//   _مطبو, _whql_, rtä_, _فقه_,
   {{0xf41f3dee,0x637000c3,0x5f1a0033,0xdb0a021d}},	//   stä_, _tänn, ড়াও_, lmfó,
   {{0x3f98003c,0x65b60093,0x810f0761,0x00000000}},	//   _ajru_, páha, िलेख_, --,
   {{0x2ef53d56,0xdb030176,0x9c86005f,0xafdb008c}},	// [5cf0] изар, bonè, _jačė, _trøm,
   {{0x200702dd,0x26ca0187,0x3dcd5f8d,0x26de5f8e}},	//   čni_, žbou_, _siew_, ncto_,
   {{0x2cad02c2,0x63a70031,0xa7fd00b5,0x75d30395}},	//   _syed_, mojn, gyűj, _păzi,
   {{0x63a701f4,0x973c011c,0x00000000,0x00000000}},	//   lojn, koćo, --, --,
   {{0x3dcd5f8f,0x79890052,0x9c8701cb,0xdca50431}},	//   _view_, view, دشاه, јали,
   {{0xfbd000d1,0x63a700da,0xab2937a3,0xaed405d8}},	//   سته_, nojn, тока_, _горш,
   {{0x79890173,0xdd9b00d8,0xc33400a5,0x00000000}},	//   tiew, _зша_, מוס_, --,
   {{0x20b90e04,0xa805215b,0x7c3e004e,0x63a70031}},	//   _आराध, азил, łpra, hojn,
   {{0x23a50f0d,0x63a75f90,0x7989053e,0x00000000}},	//   ओवाद, kojn, riew, --,
   {{0x79895f91,0x7c3b3ed7,0x63a701f4,0x7c9400b5}},	//   siew, _isur, jojn, _اشفا,
   {{0x63a701f4,0x61e20009,0xafdb0d51,0xdb03040f}},	//   dojn, _čolo, _brøk, joné,
   {{0xe5a609d0,0xdb035f92,0xdb080260,0xe4c607e5}},	//   рими, doné, _akdè, ийни,
   {{0x7d040037,0x61e50ca5,0x68fb5f93,0x7d1b02d7}},	//   óisi, _athl, maud, _mcus,
   {{0x63a75f94,0x27ff5f95,0x656f5f96,0x66e52a9a}},	//   gojn, msun_, akch, _тока,
   {{0xdb1a00da,0x0cb23779,0x443b1bae,0xdb035f97}},	//   _shtë, _जर्म, _esq_, goné,
   {{0x00e64219,0x68fb00d8,0xdb0302e9,0x656f0110}},	//   ржан, naud, sonè, ckch,
   {{0x63a70169,0xe0430c8d,0x27ff5f98,0x9f86010b}},	// [5d00] bojn, онти, nsun_, агад,
   {{0xfe720037,0xc3fb02b8,0x65640051,0xdb0301ef}},	//   يدا_, _שליש, _hoih, boné,
   {{0x7c3b16ab,0x776301dd,0x68fb5f99,0x1fb510b0}},	//   _asur, _monx, kaud, сстр,
   {{0x61463425,0xe29b0122,0x7763043f,0xc7c80023}},	//   _тема, _ישיר, _lonx, _lốp_,
   {{0x3a2c00d7,0x68fb5f9a,0x442202a7,0xaf080831}},	//   _spdp_, daud, ntk_, র্ষণ_,
   {{0xc5eb0083,0xa3b60355,0x7d1b581e,0x00000000}},	//   _কিনা_, जति_, _ecus, --,
   {{0x7c3b005f,0x6b8a03bc,0x3f8f175d,0x2002008c}},	//   _esur, rifg, ègue_, _hvki_,
   {{0xada300d8,0x63a701f4,0x7d1b0037,0x68fb5f9b}},	//   _дасл, zojn, _gcus, gaud,
   {{0x44200189,0xa3b60c97,0x497300d4,0x2000002d}},	//   _nqi_, जता_, ільс, nsii_,
   {{0xe568012b,0x6d405f9c,0x7763043f,0x2000081b}},	//   _אַ_, _hama, _conx, isii_,
   {{0x2d9e02e1,0x68fb37c9,0x9f5d00d1,0x6370013c}},	//   _êtes_, baud, éwé_, _vänl,
   {{0x6d405f9d,0x356b0ddc,0x6d425f9e,0x68fb05c9}},	//   _jama, трон_, ndoa, caud,
   {{0x6d405f9f,0x7c2202ce,0x63a700da,0x61e5013c}},	//   _mama, ntor, tojn, _sthl,
   {{0x6d405fa0,0x7c225fa1,0x27e60009,0x7c2d5fa2}},	//   _lama, itor, _iton_, çari,
   {{0x63a75fa3,0x7c225fa4,0x60cc0095,0x92685fa5}},	//   rojn, htor, ənmə, арта_,
   {{0x6d405fa6,0x63a700da,0xdb035fa7,0x44f50214}},	//   _nama, sojn, roné, _упис,
   {{0xdefb03ad,0x7c2200da,0xdfd10037,0x63a70060}},	// [5d10] вые_, jtor, سيا_, pojn,
   {{0x7d1b02fb,0x6d400103,0xdb030b4c,0xd9d70033}},	//   _scus, _aama, poné, _সবসম,
   {{0x6d402d06,0x7c225fa8,0x2ef80453,0x00000000}},	//   _bama, etor, _derf_, --,
   {{0x6d405fa9,0x29065faa,0x27e65fab,0xbd1800d4}},	//   _cama, _ndoa_, _oton_, иції_,
   {{0x8c452201,0x92d900c8,0x8d740332,0x6d405fac}},	//   селе, ারী_, غاما, _dama,
   {{0xa03a02b5,0x6d405fad,0x2ef80345,0x68fb023c}},	//   _געשפ, _eama, _gerf_, waud,
   {{0x7c2207e5,0x6d405fae,0xf1bf01a5,0x27e602b3}},	//   ator, _fama, _khá_, _aton_,
   {{0x6d405faf,0x2d8e000d,0xa3d72e33,0x00000000}},	//   _gama, éfet_, िदा_, --,
   {{0x7c22449a,0x68fb5fb0,0x973c0009,0x00000000}},	//   ctor, raud, moćj, --,
   {{0x6d405fb1,0x8aa72626,0xfbd00a72,0x27ff5fb2}},	//   _zama, _кред, _قتل_, rsun_,
   {{0x6d405fb3,0x44395fb4,0x27ff5fb5,0x9a87271c}},	//   _yama, ews_, ssun_, _туал,
   {{0x6d405fb6,0xf1bf0019,0x290200b5,0x27e60055}},	//   _xama, _nhá_, ókat_, _fton_,
   {{0xa91d18b0,0xc8da0070,0x65b600b5,0x5f0a01d1}},	//   jiži, _עקסט, sáho, ाणम्_,
   {{0x3cfd0221,0x395f5fb7,0x386d013b,0x43755fb8}},	//   hawv_, ljus_, myer_, оуст,
   {{0x63700328,0x386d01e9,0x4422076e,0xf675016b}},	//   _hänk, lyer_, stk_, _לײַט_,
   {{0xf1bf5fb9,0x6593052c,0xdfd20037,0x7c225fba}},	//   _chá_, _нају, كير_, ytor,
   {{0xf1bf0082,0x386d5fbb,0x75d3002d,0x2ef828c9}},	// [5d20] _dhá_, nyer_, _văzu, _perf_,
   {{0x6d405fbc,0x395f0006,0x65bd0640,0x20005c2a}},	//   _sama, hjus_, réhe, rsii_,
   {{0x6d405fbd,0x637006d7,0x386d01f4,0xdfcf0c26}},	//   _pama, _länk, hyer_, ريم_,
   {{0x7c223945,0x6d405fbe,0x2ef8053e,0x68f9099e}},	//   ttor, _qama, _werf_, _newd,
   {{0x6d425fbf,0xcb6a5fc0,0x0b8a0d28,0x6d4000af}},	//   rdoa, ладе_, лски_, _vama,
   {{0x6d40340d,0x386d0c47,0x68e2027a,0x31600207}},	//   _wama, dyer_, _sfod, ljiz_,
   {{0x6d405fc1,0x63ab002a,0x3f8a0a04,0x5a3401e0}},	//   _tama, _ígne, _imbu_, інит,
   {{0x7c220392,0x63700301,0xdb010355,0x8d9602e7}},	//   ptor, _bänk, _vklá, _الرش,
   {{0xdb1a00fd,0x00000000,0x00000000,0x00000000}},	//   _kitü, --, --, --,
   {{0x8b650514,0xdce003fd,0x7d040093,0xfafe00ea}},	//   _والم, _momč, ðisf, šība_,
   {{0x4a9a00d8,0x68f90024,0xdb010355,0x636b5fc2}},	//   _стаў_, _fewd, _uklá, _münt,
   {{0x7afa5fc3,0x63700282,0xd5b81a6d,0x443900e9}},	//   _hett, _fänk, йся_, tws_,
   {{0x684600af,0x44391cb3,0x69da002f,0x260400b4}},	//   _ында, uws_, _hute, _विकी_,
   {{0x69da5fc4,0xf7480088,0x4439016e,0x2fd9009e}},	//   _kute, _ضلعي_, rws_, _rusg_,
   {{0x7afa5fc5,0xf1bf01a5,0x56933f97,0x4439006f}},	//   _mett, _phá_, _нашт, sws_,
   {{0x92d900c8,0x69da53e1,0x3f8a03da,0x3cfd006d}},	//   ারে_, _mute, _ambu_, xawv_,
   {{0x69da5fc6,0x657d004f,0xc7b900b5,0x636b00b5}},	// [5d30] _lute, mhsh, ktől_, _bünt,
   {{0x7afa0a55,0x644d06a2,0xdce05fc7,0x69da5fc8}},	//   _nett, _irai, _domč, _oute,
   {{0x69da5fc9,0x3a3e0a4e,0x3cfd01e8,0xdb1a01ef}},	//   _nute, _nstp_, tawv_, _litó,
   {{0x3f8a5fca,0x644d0abe,0xdce00107,0xd5b90228}},	//   _embu_, _krai, _fomč, ktām_,
   {{0x69da5fcb,0x7afa5fcc,0x07180066,0x752d251e}},	//   _aute, _bett, _दांव_, _mbaz,
   {{0x7afa105d,0x661d006a,0x69da5c64,0x3cfd006d}},	//   _cett, ński, _bute, sawv_,
   {{0x7afa27fe,0x657d00d7,0x63701535,0x752d3607}},	//   _dett, khsh, _sänk, _obaz,
   {{0x69da5fcd,0x644d5fce,0x636b01ae,0xdb030b4c}},	//   _dute, _orai, _küns, moní,
   {{0x7afa191b,0x7d095fcf,0xb9010a5e,0x657d00da}},	//   _fett, _ides, _दल_, dhsh,
   {{0x2d8f5fd0,0x69da5fd1,0x752d0198,0x7afa5fd2}},	//   lige_, _fute, _abaz, _gett,
   {{0x69da5fd3,0x644d5fd4,0xda080312,0x752d5fd5}},	//   _gute, _arai, _هيله_, _bbaz,
   {{0x637006d7,0x2d8f5fd6,0x7afa0a75,0x29d10254}},	//   _tänk, nige_, _zett, _išao_,
   {{0x644d5fd7,0x69da0291,0x7afa5fd8,0x32110067}},	//   _crai, _zute, _yett, erzy_,
   {{0x752d06a2,0x2d8f20c0,0xdb030355,0xb4db0176}},	//   _ebaz, hige_, koní, ldàl,
   {{0x644d5fd9,0x27ed5fda,0x7d095fdb,0x2129028b}},	//   _erai, lpen_, _odes, ffah_,
   {{0x644d5fdc,0x7d095fdd,0x2d8f5fde,0xf53f33d4}},	//   _frai, _ndes, jige_, slår_,
   {{0x2d8f5fdf,0x1f6612f8,0x42d600d8,0x644d5fe0}},	// [5d40] dige_, окам, _міну, _grai,
   {{0x7d095fe1,0xdb034e5c,0x27ed5fe2,0x6e250176}},	//   _ades, foní, ipen_, fthb,
   {{0xee3a2c51,0x7afa5fe3,0x07210835,0x2d8f5fe4}},	//   рне_, _rett, _मानव_, fige_,
   {{0x7afa18f1,0x7bc15fe5,0x2d8f5fe6,0xdce000ee}},	//   _sett, _ahlu, gige_, _tomč,
   {{0x7afa5c2b,0x69da5fe7,0x636b2307,0x27ed0120}},	//   _pett, _sute, _güns, jpen_,
   {{0x69da5fe8,0x09b400a1,0x7bc15fe9,0xd9b40e61}},	//   _pute, ुष्य, _chlu, ुष्ट,
   {{0x27ed0a75,0x7e230d44,0x7bc10211,0x2d960ef3}},	//   epen_, _одрж, _dhlu, _драс,
   {{0x7afa5fea,0x3a3e022e,0xdca60f08,0x2d8f00cb}},	//   _wett, _vstp_, _даби, cige_,
   {{0x7afa5feb,0xdce90c99,0xbdc900b5,0xfc035fec}},	//   _tett, _sleć, _اگلے_, _опто,
   {{0xd6da5fed,0x69da5fee,0xdb1a0370,0x7bc10094}},	//   шти_, _tute, _vitó, _ghlu,
   {{0x657d00da,0x644d5fef,0xd5bb002d,0x69da18af}},	//   thsh, _srai, исм_, _uute,
   {{0x644d5ff0,0x1bfe0066,0x758b00c3,0x7bc100d5}},	//   _prai, _उबाल_, рсов_, _zhlu,
   {{0xf7462a0b,0xdb032a04,0x65bd0118,0x00000000}},	//   _медо, zoní, géha, --,
   {{0x644d02e1,0x2d8f5ff1,0xe7372e50,0x657d0c6f}},	//   _vrai, zige_, _меч_, shsh,
   {{0x644d00e9,0x2129012f,0x44320036,0x320500b5}},	//   _wrai, tfah_, _epy_, ély_,
   {{0x644d4805,0xab5d0035,0xa91d010b,0x59ca0099}},	//   _trai, _duży, sižv, ागिर,
   {{0x644d5ff2,0x2d8f5ff3,0x64410029,0xb0c50035}},	// [5d50] _urai, vige_, ālis, लेंग,
   {{0x9f490093,0x2d8f11ad,0xdb030184,0x00000000}},	//   gsað_, wige_, toní, --,
   {{0x2d8f5ff4,0x636b02c9,0x27ed06a2,0x14c70ed1}},	//   tige_, _wüns, zpen_, रेरण,
   {{0xb23a00c2,0xf53802b5,0x7bc10874,0x27ed5ff5}},	//   _פערז, ַטור_, _shlu, ypen_,
   {{0x2d8f0b6e,0x515a00a5,0x7d0901f4,0x61e200cd}},	//   rige_, _הכרו, _vdes, _čoli,
   {{0x2d8f5ff6,0xaa45005f,0x00000000,0x00000000}},	//   sige_, зекл, --, --,
   {{0xef2300ea,0x00000000,0x00000000,0x00000000}},	//   _ceļš_, --, --, --,
   {{0x7d095ff7,0x9d180eee,0xe29c00a5,0x69c25ff8}},	//   _udes, _мост_, ישור, _choe,
   {{0x2d8d5ff9,0x69e100cd,0x27ed5ffa,0xdb1a0176}},	//   _imee_, _šveđ, upen_, _vitò,
   {{0x27ed5ffb,0x637001ff,0x80c000b4,0x00000000}},	//   rpen_, _hänv, लेटे, --,
   {{0x3ce05ffc,0x29d10254,0x27ed5ffd,0x3218024b}},	//   žive_, _ušao_, spen_, xury_,
   {{0x7aba0122,0x69c201bf,0x64a60d10,0x3aba024b}},	//   _הצעו, _ghoe, зама, _המענ,
   {{0x69c95ffe,0x46ab0006,0x2d9f08c7,0x5fbd0d41}},	//   mmee, _घुरह, _mjue_, ्गाल,
   {{0x32181556,0xe82000fa,0x00000000,0x00000000}},	//   tury_, _ममता_, --, --,
   {{0xaacb114e,0x03a30036,0x4acb00b8,0x02c300af}},	//   ाधिक, хиро, ाधिव, ейро,
   {{0x69c95fff,0xe0da01d3,0x2d9f034d,0x00000000}},	//   nmee, сва_, _njue_, --,
   {{0x21671f7e,0xd00a002d,0x00000000,0x00000000}},	// [5d60] чити_, сезе_, --, --,
   {{0xa3bf0266,0x2d9f08c7,0x69c96000,0x00000000}},	//   ेषण_, _ajue_, hmee, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21a600af,0x41bf06fe,0x71a60f08,0x256200d5}},	//   _химм, ्षणस, _хамз, _póly_,
   {{0x69c91fe7,0x00000000,0x00000000,0x00000000}},	//   dmee, --, --, --,
   {{0xdce00029,0x69c200a5,0x00000000,0x00000000}},	//   _domā, _shoe, --, --,
   {{0xafdb0a8a,0x69c90051,0x00000000,0x00000000}},	//   _frøs, fmee, --, --,
   {{0xd90d0164,0x69c96001,0x7e9b00a5,0xafdb0044}},	//   لیم_, gmee, _הסלו, _trøt,
   {{0x6da33f6e,0xd8230202,0xeafa00e0,0x63ae00f4}},	//   _чита, едњи, _هرات_, kobn,
   {{0x69c907bd,0x25a06002,0x3ce600a0,0x25b70ac4}},	//   amee, _ajil_, lcov_, ृष्ण,
   {{0x69c96003,0x00000000,0x00000000,0x00000000}},	//   bmee, --, --, --,
   {{0x3ce6016f,0x7d026004,0x212200e2,0xdb036005}},	//   ncov_, naos, _nckh_, moná,
   {{0x94ab1d13,0x00000000,0x00000000,0x00000000}},	//   стна_, --, --, --,
   {{0x63ae080f,0x39466006,0xa85732e3,0x00000000}},	//   gobn, _haos_, _מידה_, --,
   {{0x82a46007,0xf64f00b5,0xa3dd1604,0xf8ad4574}},	//   еште, _مئي_, _तूर_, _مکی_,
   {{0x673a6008,0xdb0a022a,0x2d9c006c,0xb5a400d8}},	//   letj, llfä, ével_, _прый,
   {{0x661a6009,0x394600f8,0x8c3d00a8,0xfbcc00dc}},	// [5d70] lutk, _maos_, _oxşa, ाषाम,
   {{0xdb03290b,0x673a600a,0xafdb11cb,0xdce00228}},	//   koná, netj, _brør, _romā,
   {{0x661a18b0,0xb4bd1db1,0x00000000,0x00000000}},	//   nutk, _अरु_, --, --,
   {{0x8c3d0095,0x3ce6006d,0x9f490037,0x6fd805e7}},	//   _axşa, gcov_, mpaí_, _भूकं,
   {{0x673a0352,0xbb452a67,0xcb690d6e,0x661a600b}},	//   ketj, делк, жале_, hutk,
   {{0x661a0034,0x65bd0187,0x9f05600c,0x0721112b}},	//   kutk, kého, _زورو, _माधव_,
   {{0x661a0ec0,0x9e34004c,0x39460159,0x69c9600d}},	//   jutk, _перч, _baos_, tmee,
   {{0xeeeb00e8,0x7d021b67,0x2d9f002f,0xdb0a033b}},	//   _động_, caos, _ujue_, elfä,
   {{0xa3bf009a,0x69c9600e,0xfc300ca8,0x2b450160}},	//   ेषा_, rmee, _محل_, _talc_,
   {{0x69c9600f,0x799b0b35,0x378900d4,0xeaf800d1}},	//   smee, snuw, ібно_, _فرمت_,
   {{0xe5a66010,0xf1bf0099,0x63700421,0x69c9018d}},	//   дини, ्षान, _mänt, pmee,
   {{0x2d9d6011,0x6abe02b1,0x201b0055,0x00000000}},	//   nnwe_, üpfe, kuqi_, --,
   {{0x63ae00a0,0x673a0c71,0xc3270033,0xd5dd021a}},	//   tobn, betj, য়নি_, _नूरज,
   {{0x661a0d1c,0xb4ae0026,0x81e50033,0x291f0065}},	//   butk, _कडी_, _নিজ_, lgua_,
   {{0x63ae08c2,0x661a488f,0x07a2027a,0x00000000}},	//   robn, cutk, _шашн, --,
   {{0x291f6012,0x85060987,0x76430409,0x00000000}},	//   ngua_, _کوکن, _isny, --,
   {{0x3ce601ba,0x291f0107,0x61e20009,0x00000000}},	// [5d80] vcov_, igua_, _čolu, --,
   {{0x2be11163,0x644425e8,0x00000000,0x00000000}},	//   _पढ़ा, _isii, --, --,
   {{0x216a027a,0xa1c637a3,0xdb1a00b5,0x6d9100ac}},	//   _дини_, _обод, _kitö, rťan,
   {{0x6d910187,0xa3dd007c,0xdb0300fd,0x00000000}},	//   sťan, _तूँ_, voná, --,
   {{0x7d026013,0x394600f8,0xdd8f0698,0x3ce65977}},	//   raos, _raos_, جون_, rcov_,
   {{0x3ce66014,0x637000ab,0xcb670274,0x394601cb}},	//   scov_, _tänu, даље_, _saos_,
   {{0x637001ff,0x673a6015,0x7d020159,0x3ce600a0}},	//   _häns, vetj, paos, pcov_,
   {{0xd91000bf,0x6370022a,0xdb036016,0x317b0070}},	//   ایش_, _käns, roná, ַרימ,
   {{0xb4bd6017,0x673a6018,0xa3dd00ab,0x3eb80523}},	//   _अरे_, tetj, _तूं_, _hyrt_,
   {{0x7d00022a,0x661a4e84,0x6370013c,0x75246019}},	//   _hems, tutk, _mäns, _aciz,
   {{0x637036d0,0x6444018e,0x7d000093,0xaadb00a5}},	//   _läns, _asii, _kems, _וחבר,
   {{0x661a601a,0x7d0002c4,0x673a601b,0x65bd00ac}},	//   rutk, _jems, setj, rého,
   {{0x2904601c,0x673a0051,0x00000000,0x00000000}},	//   mama_, petj, --, --,
   {{0x2904601d,0x661a601e,0xf77200b5,0x7d000c6f}},	//   lama_, putk, _جاؤ_, _lems,
   {{0xd8480028,0x03200243,0x659501c8,0x64440086}},	//   _họ_, _बारह_, _паку, _esii,
   {{0x212000bf,0x2fd81c8b,0x200f0132,0xdb0300ac}},	//   ggih_, _airg_, ágio_, dlný,
   {{0x03c703e6,0x00940043,0x6ab90033,0x00000000}},	// [5d90] _осом, витэ, েখযো, --,
   {{0x2904601f,0x753d00b5,0x201b012f,0x656d00e2}},	//   hama_, lesz, ruqi_, _hoah,
   {{0x29046020,0x6370022a,0xd8480023,0x9d1500af}},	//   kama_, _vänt, _lọ_, едеч,
   {{0x290408b3,0x29d105d3,0x3eb80c66,0x656d0009}},	//   jama_, _však_, _dyrt_, _joah,
   {{0x201b0095,0xed5800d4,0xd8480023,0x7d006021}},	//   quqi_, ьої_, _nọ_, _dems,
   {{0x4429028b,0x7d000051,0x00000000,0x00000000}},	//   _mqa_, _eems, --, --,
   {{0x3ce0024e,0x62870484,0x2d8700f7,0x7d00079a}},	//   živa_, nzjo, ènes_, _fems,
   {{0xd8480023,0x291f08c7,0x00000000,0x00000000}},	//   _bọ_, ugua_, --, --,
   {{0x44290189,0x753d5a40,0x291f6022,0xd8480023}},	//   _nqa_, desz, rgua_, _cọ_,
   {{0x7d000865,0x6d4b0542,0x6d49016e,0x200900c7}},	//   _zems, ldga, _haea, isai_,
   {{0x29040147,0x7c2b6023,0xf1db00be,0x656d03d0}},	//   bama_, ltgr, _मंगन, _boah,
   {{0x290401cc,0xc3290052,0x6d4b6024,0x753d15ee}},	//   cama_, _לו_, ndga, gesz,
   {{0x7c2b6025,0x200f2278,0x6d49179a,0x00000000}},	//   ntgr, ágil_, _maea, --,
   {{0x68e96026,0x6b830023,0x61a806fe,0x00000000}},	//   lced, nhng, कक्ष, --,
   {{0x69d96020,0x753d00b5,0x00000000,0x00000000}},	//   _kiwe, besz, --, --,
   {{0x68e96027,0x7c2b6028,0x69d908c7,0x6444023f}},	//   nced, ktgr, _jiwe, _tsii,
   {{0x69d96029,0x644408c7,0x7d00423c,0x7c290024}},	// [5da0] _miwe, _usii, _rems, _nqer,
   {{0x6d5b602a,0x2904602b,0x6370022a,0x69d9602c}},	//   _anua, zama_, _väns, _liwe,
   {{0x29040aee,0x2009005d,0x27760070,0xdcfb0069}},	//   yama_, asai_, עגען_, _gluċ,
   {{0x69d9602d,0x2ac600b8,0xd5b900ea,0x7c2b0f8e}},	//   _niwe, _líbí_, stāv_, ftgr,
   {{0x29040d38,0x6d4900e9,0x4f3400b5,0x320a602e}},	//   vama_, _daea, _لڑائ, lsby_,
   {{0x753d004e,0x68e90132,0x29041d50,0x69d9023c}},	//   zesz, eced, wama_, _aiwe,
   {{0x81e20083,0x3ebe008a,0x7d00027d,0x7c2b0051}},	//   নীর_, _átt_, _tems, atgr,
   {{0x6d4900e9,0xb4db0176,0x00000000,0x00000000}},	//   _gaea, ldàv, --, --,
   {{0x290408c6,0x6287602f,0x69d96030,0x753d006c}},	//   rama_, zzjo, _diwe, vesz,
   {{0x2904397b,0x6d621269,0x69d902b1,0xdb0100e0}},	//   sama_, štač, _eiwe, _njlè,
   {{0x29040521,0x672100b4,0xdb0a01ef,0x753d00b5}},	//   pama_, _मारक_, nofí, tesz,
   {{0x7bda6031,0x68e902fb,0xaaa90f8a,0x69d9073a}},	//   _hitu, cced, _चुटक, _giwe,
   {{0x7bda6032,0x753d3a5f,0x32186033,0x00000000}},	//   _kitu, resz, erry_, --,
   {{0x442b00ec,0x644f00ea,0x9f400036,0x7bda6034}},	//   rtc_, rvci, ppiù_, _jitu,
   {{0x7bda6035,0x320a1522,0x442b00e2,0x4789010b}},	//   _mitu, gsby_, stc_, _ўсім_,
   {{0xb6bb0122,0x61d81397,0x05770c74,0xa535002d}},	//   _מצוי, емся_, _ساعد, _рнич,
   {{0xe13400af,0x7bda0074,0x00000000,0x00000000}},	// [5db0] ынты, _oitu, --, --,
   {{0xa3090332,0x20096036,0x7bda569f,0xf53f013c}},	//   _کرکے_, rsai_, _nitu, leå_,
   {{0x6d9101ba,0xe717011d,0xcfa40279,0x00000000}},	//   sťam, תחבר_, ушти, --,
   {{0x5c75079d,0x7c2b6037,0x7bda3f83,0x63bf0355}},	//   клет, ttgr, _aitu, ůzně,
   {{0x8c45263b,0x7bda6038,0x6d4b6039,0x69da0035}},	//   теле, _bitu, rdga, _पंजी,
   {{0x7bda603a,0x9f9401ae,0x69d90054,0x7bc8009e}},	//   _citu, mäß_, _siwe, _chdu,
   {{0x7bda603b,0x3da701c8,0xfebb0df3,0xdcfb0187}},	//   _ditu, _зраб, _راست_, _hluč,
   {{0xb4e00e04,0x7bda603c,0x00000000,0x00000000}},	//   _तले_, _eitu, --, --,
   {{0xf7711b31,0x7bda603d,0xa802005f,0xa3dd0084}},	//   لاد_, _fitu, азыл, _तंग_,
   {{0x7bda603e,0x68e9026e,0xd5b900ea,0x1a6500fd}},	//   _gitu, sced, ktās_, _لیتی_,
   {{0xcfe80033,0xab840f99,0x6b81003e,0x00000000}},	//   _পিছন, _сутк, _illg, --,
   {{0xa3e60cf1,0x7bda5e00,0x7bc801f4,0x3169028b}},	//   _बंद_, _zitu, _zhdu, jjaz_,
   {{0xe8180755,0x394d603f,0x7bda007b,0x00000000}},	//   _दिया_, mdes_, _yitu, --,
   {{0xc88308ca,0x394d6040,0x972401b2,0x66e2052c}},	//   ığı_, ldes_, _مفهو, _коша,
   {{0x69dc00b5,0x00000000,0x00000000,0x00000000}},	//   _éret, --, --, --,
   {{0x320a6041,0xdcfb00fe,0x00000000,0x00000000}},	//   rsby_, _bluč, --, --,
   {{0x394d6042,0x00e30081,0xdb1a0086,0xdee61158}},	// [5dc0] ides_, ржун, _yhtä, вози,
   {{0xef170370,0xd5b900ea,0x13a800f8,0x6456007b}},	//   кму_, stāt_, _سنجی_, _iryi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8102c9,0x394d6043,0xdd8f0286,0xdce900f4}},	//   _allg, jdes_, يول_, _bleđ,
   {{0x3d070429,0x7bda049b,0x394d6044,0x3ce05e42}},	//   हणजे_, _pitu, ddes_, živo_,
   {{0xfca900ce,0x7bda0c6f,0x09ca057c,0xdee60214}},	//   رانو_, _qitu, ाग्य, _јови,
   {{0x7bda6045,0x394d03bc,0x79a60dee,0x00000000}},	//   _vitu, fdes_, крие, --,
   {{0x29020093,0x394d6046,0x7bda0a5a,0x00000000}},	//   úka_, gdes_, _witu, --,
   {{0xebe602ce,0x8c430009,0xdce902c4,0xa3b26047}},	//   _розп, _кете, _gleđ, टका_,
   {{0x394d0443,0x7bda0160,0x00000000,0x00000000}},	//   ades_, _uitu, --, --,
   {{0xf53f01ff,0xfaa30009,0x64560027,0x6ad00033}},	//   teå_, _кафо, _aryi, _স্রো,
   {{0xceb30052,0xd9460202,0x9f420031,0x00000000}},	//   יית_, _једи, _bukë_, --,
   {{0x481301e0,0x64563161,0x00000000,0x00000000}},	//   _вміс, _cryi, --, --,
   {{0xdb0a0176,0x64566048,0x00000000,0x00000000}},	//   nofà, _dryi, --, --,
   {{0xdcfb01cc,0x79826049,0xd5b900ea,0x00000000}},	//   _sluč, _klow, utās_, --,
   {{0xc6d90070,0xdcfb0207,0x00000000,0x00000000}},	//   _אַפר, _pluč, --, --,
   {{0xd5b900ea,0x636b033b,0x69da00ab,0x371c046c}},	// [5dd0] stās_, _münz, _पूछी, _माफ़ी_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b5604a,0x394d01b4,0x645a00ea,0x657d01a2}},	//   mozn, ydes_, ātie, oksh,
   {{0x96240831,0x00000000,0x00000000,0x00000000}},	//   _বনাম_, --, --, --,
   {{0xe4ff0355,0x5bdd21b2,0xfbaf01c0,0x00000000}},	//   _štěň, मदेव, टवलम, --,
   {{0x447c02b5,0x7982018e,0x63b51f3d,0x399a00ea}},	//   ונדע, _alow, nozn, zīst_,
   {{0xe8000722,0x61e50086,0x7f9402ee,0x7982604b}},	//   लीसा_, _juhl, _тарх, _blow,
   {{0x394d604c,0x4a74005f,0xca7400c7,0x657d0223}},	//   udes_, рышт, рушы, jksh,
   {{0x63b5604d,0x00000000,0x00000000,0x00000000}},	//   kozn, --, --, --,
   {{0x7c3b604e,0x00000000,0x00000000,0x00000000}},	//   _ipur, --, --, --,
   {{0xf77101ca,0x443b00d7,0x7982604f,0x63b56050}},	//   لاگ_, _apq_, _flow, dozn,
   {{0x78a46051,0x7a7a0070,0xda7a0070,0x64560312}},	//   _žive, _ארעס, _אנער, _pryi,
   {{0xf773132d,0x68fb6052,0x1b060083,0x81ac0083}},	//   _پاش_, mbud, _রাতে_, গতম_,
   {{0xade306bc,0x68fb0c61,0x289a0070,0x636b027d}},	//   गदान_, lbud, _אינא, _küny,
   {{0x443b0118,0xafdb0044,0x00000000,0x00000000}},	//   _epq_, _esøk, --, --,
   {{0x64566053,0x7c3b0159,0xd5b215f8,0x00000000}},	//   _tryi, _opur, _دفع_, --,
   {{0x7dda00b8,0xefca00c3,0x63b52443,0xfbc300b8}},	// [5de0] _důsl, елал_, bozn, षताम,
   {{0x442209df,0x7dda01c0,0x7dec013b,0x68fb013b}},	//   muk_, _půso, _ağsa, hbud,
   {{0x7c3b6054,0x2b5e0107,0x7e56010b,0x00000000}},	//   _apur, _rntc_, ытац, --,
   {{0xac0a6055,0x2b4c1766,0x3f83009f,0x56b6016b}},	//   енда_, _sadc_, _elju_, אפען_,
   {{0x44226056,0xeb9a2e2d,0x68fb6057,0xdca31073}},	//   nuk_, нид_, dbud, баци,
   {{0xdee36058,0xcb672d4d,0x79826059,0x636b0448}},	//   _гори, лаче_, _slow, _büny,
   {{0x442200f8,0xb4db0443,0x99870009,0x7c3b0ad8}},	//   huk_, ndàr, _šiši_, _epur,
   {{0x636b3410,0x4422605a,0x661a0097,0xd7fa0274}},	//   _düny, kuk_, vrtk, нуо_,
   {{0xba1800f8,0x4422605b,0x7f4e006d,0xc17302b8}},	//   ريکا_, juk_, _kabq, מחה_,
   {{0x44220614,0x9f403a89,0x3f9a06b3,0x68fb3436}},	//   duk_, mpió_, nipu_, abud,
   {{0x7c224523,0x3ce95fde,0x63b5605c,0x06d70083}},	//   luor, žave_, vozn, _দ্বি,
   {{0x443b0118,0x4422605d,0x61e5027b,0x39400079}},	//   _ppq_, fuk_, _ruhl, _úis_,
   {{0x44220d4f,0x63b5605e,0x657d605f,0x61e500a0}},	//   guk_, tozn, rksh, _suhl,
   {{0xb8650a86,0x61e5063b,0x69cb0031,0x00000000}},	//   _خامو, _puhl, _zhge, --,
   {{0x63b52898,0xf1a76060,0x68e202c4,0x27e60160}},	//   rozn, гран, _kgod, _huon_,
   {{0xeeeb0019,0x7c226061,0x50f5031a,0x27e6034d}},	//   _đống_, kuor, рзат, _kuon_,
   {{0x44226062,0x6d426063,0x200f006c,0x68e2002f}},	// [5df0] cuk_, deoa, égi_, _mgod,
   {{0xeeab0043,0x27e60023,0x2d840036,0x68fb6064}},	//   нтек_, _muon_, _alme_, zbud,
   {{0x7f4e006d,0x4fc441e4,0x68fb001e,0x1eab147f}},	//   _dabq, сста, ybud, رائي_,
   {{0x68e254f2,0x7c220036,0x5bdd022e,0x714710be}},	//   _ngod, fuor, मद्व, _схож,
   {{0x27e66065,0x7c220036,0xab295049,0xf3ff0183}},	//   _nuon_, guor, вола_, ixão_,
   {{0xaa151b78,0x447c02b5,0xab62037a,0x3f83012e}},	//   афиј, ענגע, şünm, _ulju_,
   {{0x44226066,0x27e6099e,0x00000000,0x00000000}},	//   zuk_, _auon_, --, --,
   {{0x27e66067,0x44226068,0xfaf800ea,0xdb0a00ac}},	//   _buon_, yuk_, _vnīa_, rofá,
   {{0x7c876069,0x77853ef3,0x7c22027a,0x4b272499}},	//   _суве, илиз, cuor, _معاف,
   {{0x7d0b606a,0x78a4606b,0x6c840082,0x25a90006}},	//   lags, _živc, _الكم, _ajal_,
   {{0x39150609,0x442209df,0xa8060138,0x00000000}},	//   _نواز, wuk_, _peñó, --,
   {{0x44221760,0x7d0b149b,0x38600254,0x28d206fe}},	//   tuk_, nags, _šire_, देहि,
   {{0x99d40bf5,0x25a90031,0x7de50409,0x00000000}},	//   _اتلا, _djal_, _dėsi, --,
   {{0x68e2606c,0x4422606d,0x7d0b008a,0x799b023c}},	//   _zgod, ruk_, hags, liuw,
   {{0x44220464,0xe297027a,0xd19600c9,0x7d0b0008}},	//   suk_, аар_, ашањ, kags,
   {{0x442206d4,0x91c30066,0x27e6010d,0x394f03bc}},	//   puk_, _वीआई, _yuon_, _jags_,
   {{0xe0da149e,0x55bb0052,0x7d0b5d8f,0xd00a1676}},	// [5e00] тва_, _במקו, dags, тезе_,
   {{0x6fc201ba,0x7c2200c3,0xa3ba0cd1,0xafdb0a8c}},	//   môck, vuor, _جابر_, _krøy,
   {{0x3f9a00cd,0x6f0700fe,0xcd060268,0x00000000}},	//   ripu_, _dejc, ачли, --,
   {{0x16360779,0x7c22393e,0x3f9a103c,0x628e007e}},	//   ינער_, tuor, sipu_, mzbo,
   {{0x6c540cd0,0xcb6a23d7,0x6d4219b2,0xdca63924}},	//   склу, каде_, reoa, шади,
   {{0xe4570070,0x7c2201a3,0x6d4213cc,0x5bb70746}},	//   יינט_, ruor, seoa, алія_,
   {{0x80db0083,0x68e202c4,0xbea302c8,0x7d0b067f}},	//   যুদ্, _pgod, _дарк, bags,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab66606e,0x394f4cfe,0x2cbf0b04,0x7c224831}},	//   _квал, _dags_, _gyud_, quor,
   {{0x10370122,0x765807c0,0x27e600cc,0x00000000}},	//   סטים_, _prvy, _vuon_, --,
   {{0x9a6a0180,0x394f0a8a,0x69c00009,0x5a964c7b}},	//   _جمال_, _fags_, plme, _траф,
   {{0xd6d7010b,0x68e2129f,0xd5b802ce,0x27e60086}},	//   шты_, _ugod, ися_, _tuon_,
   {{0x28d206bc,0x0f110033,0xf76f01cb,0xd91b025a}},	//   देशि, স্টঃ_, سای_, _יואל,
   {{0x39442b26,0xf743606f,0x38cb04a3,0x00000000}},	//   lems_, _мечо, _شانی_, --,
   {{0xdce000b8,0xdcef0124,0x41e701e0,0x25a9021d}},	//   _pomě, _šeče, ріга, _tjal_,
   {{0x3f982971,0x3944004b,0x25a900ac,0x26db00a5}},	//   _amru_, nems_, _ujal_, _בקומ,
   {{0xc31c0083,0x752d0095,0x3f15004b,0x0f150402}},	// [5e10] দ্ধি_, _icaz, йдас, ймаю,
   {{0xeeeb00e8,0x7d1d00f5,0x5eab0083,0x67280282}},	//   _đồng_, _össz, _করবে, ngdj,
   {{0x7d0b6070,0xdfd801d3,0xe3b00427,0x6f070355}},	//   tags, рът_, _تري_, _vejc,
   {{0xb6d902b5,0x8d741301,0x00000000,0x00000000}},	//   אַנט, يانا, --, --,
   {{0xa3ae020c,0x7d0b6071,0x394f2f97,0x1fe50033}},	//   _कदम_, rags, _rags_, _পৌরস,
   {{0x7f85004f,0xdb030248,0x3dcd16df,0x644d0054}},	//   _السن, onné, _whew_, _msai,
   {{0x394f00de,0x7d0b121e,0x752d002d,0x9f400036}},	//   _pags_, pags, _ocaz, ppiò_,
   {{0x21296072,0x78a4068b,0xe818073f,0x644d6073}},	//   ngah_, _živa, _दिशा_, _osai,
   {{0x2d9d035a,0xa3b70581,0x798903bc,0x74220033}},	//   miwe_, जवा_, rhew, _ফন্ট_,
   {{0x7d09476c,0xab740082,0x9b74004f,0x2d9d6074}},	//   _hees, _والإ, _والص, liwe_,
   {{0xd90f07a8,0xf1c71e79,0x7d096075,0x394f6076}},	//   _ہیں_, लतान, _kees, _tags_,
   {{0x7d0918af,0xaca30019,0x7bc3463d,0x2d9d01d5}},	//   _jees, _ngừn, llnu, niwe_,
   {{0x7d091c45,0x2b1b000c,0xe7392b33,0x3f81022e}},	//   _mees, _नयाँ_, _бел_, kkhu_,
   {{0x7d096077,0x2d9d037b,0xd8d632e3,0x628e02b1}},	//   _lees, hiwe_, _פוסט_, tzbo,
   {{0xa2bb035d,0xf7700919,0x2d9d08bd,0x27ed00da}},	//   _शुद्, _تان_, kiwe_, lqen_,
   {{0x7d090029,0x21295465,0x3ce00121,0x2d9d08c7}},	//   _nees, ggah_, živi_, jiwe_,
   {{0xa0670cac,0xa3d80fd1,0x3d0b0026,0x65640dc3}},	// [5e20] бата_, िषद_, ारने_, _inih,
   {{0xdfcf0c74,0x290d03d0,0x00000000,0x00000000}},	//   فيق_, haea_, --, --,
   {{0x6564114d,0x7d096078,0xa91d00c7,0x2d9d4f1e}},	//   _knih, _bees, sižy, fiwe_,
   {{0x10a605f2,0xe81800a1,0xe3bf01dd,0x2d9d0010}},	//   _гимн, _दिला_, muña_, giwe_,
   {{0xe3bf0b4c,0x7d09053e,0xdca302f3,0xbf9b0298}},	//   luña_, _dees, паци, _kwêl,
   {{0xdd92103b,0x3f9800c5,0x543b016b,0x00000000}},	//   _کور_, _umru_, רעסא, --,
   {{0x3ce90496,0x7d0902e6,0x8e86004f,0x39446079}},	//   žava_, _fees, _الأه, tems_,
   {{0x7d090136,0x2d9d01d5,0x65640103,0x57f41c20}},	//   _gees, ciwe_, _nnih, опит,
   {{0xa3d8178c,0x3944607a,0xdb180055,0x00000000}},	//   िषा_, rems_, novë, --,
   {{0x5eab0083,0x752d002d,0x6564607b,0x7d095b18}},	//   _করতে, _scaz, _anih, _zees,
   {{0x7d09018e,0x2012012f,0x6ac60ca8,0xe3bf02d7}},	//   _yees, hsyi_, _اقام, juña_,
   {{0x290d006d,0x657602d7,0x26c200ea,0xdb180055}},	//   caea_, _coyh, āko_, kovë,
   {{0xb4e900ab,0xdb1a0097,0x32110035,0x00000000}},	//   _बली_, _akté, wszy_, --,
   {{0x2d9d607c,0xf41f00c3,0x00000000,0x00000000}},	//   ziwe_, rrä_, --, --,
   {{0x1b7b0070,0x43940368,0x00000000,0x00000000}},	//   נטלע, чарс, --, --,
   {{0x35a4395d,0x644d607d,0x60f91397,0x32110035}},	//   _најг, _tsai, рная_, rszy_,
   {{0x644d607e,0xdb180031,0x2129607f,0x00000000}},	// [5e30] _usai, govë, rgah_, --,
   {{0x7d096080,0x3f876081,0x32110035,0xe3bf01ef}},	//   _sees, ónu_, pszy_, buña_,
   {{0x2d9d035a,0x9f400093,0xf3eb0033,0xe3bf0138}},	//   tiwe_, rpið_, _কবির_, cuña_,
   {{0x05c90567,0xa1596082,0x2012022e,0xd5c90ac4}},	//   रतिब, _таму_, bsyi_, रतिज,
   {{0x78a4024e,0x2d9d6083,0xdc6911d0,0x7d091ea6}},	//   _živn, riwe_, ралд_, _vees,
   {{0x7d096084,0x823404cd,0x2d9d3776,0xdb180176}},	//   _wees, _بریا, siwe_, novè,
   {{0x7d096085,0x28db021a,0x00000000,0x00000000}},	//   _tees, मेनि, --, --,
   {{0xa3e90325,0x09e20945,0x7de5010b,0x386000cd}},	//   यदा_, мощн, _dėst, _šira_,
   {{0x02fb021a,0x52fb01c0,0xacf800af,0x7bc300d5}},	//   ्राह_, ्राउ_, _ынту_, plnu,
   {{0xbca400ad,0x00000000,0x00000000,0x00000000}},	//   _عملي, --, --, --,
   {{0x65bd00b8,0x637002b1,0x29190580,0x05aa0421}},	//   véhr, _tänz, _نقاد_, ивой_,
   {{0x2b4000cd,0x2b476086,0xe8210099,0x95961645}},	//   đice_, lenc_, _मिपा_, ішні,
   {{0x2ec60d00,0x98c7004f,0x00000000,0x00000000}},	//   _वर्त, _اغان, --, --,
   {{0xf1bf00a0,0xd3ba01e0,0xdb015eec,0xe3bf01ef}},	//   _aká_, румі_, _eklö, tuña_,
   {{0xe79600f8,0x2b470176,0xa3e6052f,0x00000000}},	//   _بانک, ienc_, _बंक_, --,
   {{0xe3bf0caa,0x649a03e6,0x65c30c46,0x00862788}},	//   ruña_, _втор_, _обща, олбо,
   {{0x387f16ab,0x4f0a0009,0x386d01ef,0x00000000}},	// [5e40] nyur_, инан_, nxer_, --,
   {{0xbc6a0609,0xe3bf0042,0xe29a081b,0x201c00f4}},	//   یمان_, puña_, _вао_, čvi_,
   {{0xdb1801d2,0x63bc3589,0x2b476087,0xbeaa2149}},	//   sovë, morn, denc_, جهان_,
   {{0x63bc3bc7,0x302a3392,0x973c012e,0xdb180097}},	//   lorn, _комп_, miće, mové,
   {{0xdb186088,0x973c0254,0xa3ae0096,0x00000000}},	//   lové, liće, _कदा_, --,
   {{0x63bc0fa8,0xdb9700d8,0x00000000,0x00000000}},	//   norn, овіч_, --, --,
   {{0xdd920427,0xdb186089,0x973c011c,0x00000000}},	//   _قوس_, nové, niće, --,
   {{0x63bc608a,0xdb03608b,0xb4e9608c,0x00000000}},	//   horn, fonó, _बले_, --,
   {{0xd90d00f8,0x973c00cd,0xdb180097,0x00000000}},	//   ایه_, hiće, hové, --,
   {{0x3dc60122,0xb8d200dc,0xdb180314,0x63bc608d}},	//   llow_, _ऐश_, kové, jorn,
   {{0x63bc608e,0x4422608f,0x973c011c,0xdb180097}},	//   dorn, erk_, jiće, jové,
   {{0x37e60036,0xa2bb04bc,0x7d0211ad,0xdb180187}},	//   _додг, _शुष्, nbos, dové,
   {{0x63bc6090,0x3dc60159,0xe821021a,0x7d020298}},	//   forn, ilow_, _मिया_, ibos,
   {{0x63bc6091,0x7d0200f4,0xfbca00b8,0x00000000}},	//   gorn, hbos, ितिम, --,
   {{0xa2bb021a,0x44226092,0x973c011c,0xdb186093}},	//   _शुश्, ark_, giće, gové,
   {{0xdb18013c,0x3f8a6094,0x7d020051,0x00000000}},	//   llvä, _albu_, jbos, --,
   {{0x63bc0097,0xfbca01c0,0x00000000,0x00000000}},	// [5e50] born, िताम, --, --,
   {{0xdb180187,0x24840c71,0x973c011c,0x7c2201ed}},	//   bové, ømme_, biće, dror,
   {{0x78a4108a,0xdea1006c,0xc3320319,0xdcef0009}},	//   _živl, ریری, _אוי_, šeča,
   {{0x5bc300e7,0x7c2202b1,0x00000000,0x00000000}},	//   षत्व, fror, --, --,
   {{0xdfdb0133,0xe3b00357,0x661d004e,0x2b476095}},	//   _във_, _سری_, ąski, tenc_,
   {{0x9f4301f4,0x92bf0083,0x50da0122,0x7d026096}},	//   _mijë_, েশী_, _לקרא, abos,
   {{0x2b476097,0x7c220036,0x3179608b,0x00000000}},	//   renc_, aror, _kosz_, --,
   {{0x63bc0252,0xdb036098,0x386d0443,0x44226099}},	//   zorn, tonó, txer_, yrk_,
   {{0x7d1b0371,0xdb18031d,0x5b3300af,0x973c00f4}},	//   _idus, zové, _омаӂ, ziće,
   {{0xdb03609a,0x386d002a,0x6a67104b,0x00000000}},	//   ronó, rxer_, _وطال, --,
   {{0x63bc02dd,0xa2bb19db,0x98ab06d3,0x387f0a2d}},	//   vorn, _शुल्, ıcı_, syur_,
   {{0x973c0a78,0x7c24004f,0xdb030037,0x00000000}},	//   viće, áirg, inní, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb18024e,0x27ff00bf,0x973c0254,0x9f430055}},	//   tové, mpun_, tiće, _dijë_,
   {{0x7d1b0a78,0x63bc609b,0x31790051,0x7d02609c}},	//   _odus, rorn, _bosz_, ybos,
   {{0xdb180187,0x3166548d,0x63bc609d,0x973c011c}},	//   rové, ñoz_, sorn, riće,
   {{0x27ff06b3,0x7bc102c4,0x53a60086,0x973c0254}},	// [5e60] npun_, _oklu, _наиб, siće,
   {{0x7778006d,0x7d1b609e,0xdb0a013c,0x98a6011c}},	//   _xovx, _adus, llfö, šiće_,
   {{0x27ff02c2,0xee3a609f,0xdd8f0e3a,0xe1f700af}},	//   hpun_, сне_, گون_, _нгэ_,
   {{0x27ff046a,0x7c2260a0,0xdd9901e0,0x25a20355}},	//   kpun_, tror, оші_, nikl_,
   {{0x7d0260a1,0xdd8f0c26,0x00000000,0x00000000}},	//   rbos, دون_, --, --,
   {{0x7d1b0086,0x27ff00d7,0x7d024996,0x7c2260a2}},	//   _edus, dpun_, sbos, rror,
   {{0x61e600f4,0xed5a3e10,0x6e430009,0x00000000}},	//   _kikl, _лов_, _перз, --,
   {{0x7bc160a3,0x645a00ea,0x6f0e0211,0x61e60024}},	//   _eklu, ātij, _hebc, _jikl,
   {{0x61e660a4,0xdcfb0124,0x7c240098,0x7dda0355}},	//   _mikl, _sluć, áird, _důst,
   {{0x1b0f0b52,0xdcfb0254,0x35f460a5,0x5fbe01c0}},	//   _সাথে_, _pluć, мпор, ्तिल,
   {{0xb3470132,0x7bdf000d,0x7c2400c7,0x2d863436}},	//   _liçõ, ïque, šird, okoe_,
   {{0x2bca021a,0x61e660a6,0xb7d7006c,0xc7b900fd}},	//   ितवा, _nikl, _ہونا_, lről_,
   {{0x6fbe0785,0x5fbe0931,0x00000000,0x00000000}},	//   ्तां, ्ताल, --, --,
   {{0x7dda01c0,0x2d86012f,0x9f430031,0x00000000}},	//   _zůst, hkoe_, _vijë_, --,
   {{0x20070254,0x6d4060a7,0xa3ae3b23,0x00000000}},	//   ćnim_, _obma, _कदर_, --,
   {{0x5eab0083,0x25a205e2,0x31c40370,0x59dc0099}},	//   _করলে, cikl_, есув, मगिर,
   {{0x78a460a8,0x92bf0083,0xceeb04e8,0x61e607d4}},	// [5e70] _živj, েশে_, مران_, _dikl,
   {{0x44390029,0x442b3c8c,0x7dca0093,0x6d40033b}},	//   mts_, muc_, sýsl, _abma,
   {{0x443960a9,0x7f550ddb,0xa19500d8,0x0dcb05c7}},	//   lts_, _vazq, _жанч, буди_,
   {{0x7bc11587,0x260129ad,0x7d1b009f,0x00000000}},	//   _sklu, वीटी_, _qdus, --,
   {{0x443960aa,0x442b16e0,0x657d01f4,0x7dda0355}},	//   nts_, nuc_, ërhy, _růst,
   {{0x443960ab,0x61e601d7,0x69c21192,0xbb4202fb}},	//   its_, _zikl, _akoe, вешк,
   {{0x442b60ac,0x443960ad,0x1b060033,0xdce80225}},	//   huc_, hts_, _রাখে_, _çoğa,
   {{0x44390080,0x9f4302e9,0xe8180461,0x7d1b60ae}},	//   kts_, _sijè_, _दिखा_, _udus,
   {{0x6d4b0f1a,0x27ff0f1a,0x4439035f,0x442b0506}},	//   mega, upun_, jts_, juc_,
   {{0x442b60af,0x6d59095a,0x27ff60b0,0xe61902c4}},	//   duc_, ldwa, rpun_, одо_,
   {{0x25a260b1,0x27ff60b2,0x443949f5,0x442b000d}},	//   tikl_, spun_, ets_, euc_,
   {{0x6d4b60b3,0x6d5960b4,0x64a600c7,0x7c240254}},	//   nega, ndwa, дама, šire,
   {{0x443960b5,0xe72e2101,0x61e6003c,0x7c2b4f4a}},	//   gts_, _ие_, _rikl, nugr,
   {{0x69c960b6,0x6d4b60b7,0x61e660b8,0x69db5119}},	//   llee, hega, _sikl, lmue,
   {{0x0caa004e,0x46d10437,0x61e660b9,0x69c90103}},	//   _कश्म, _हरिह, _pikl, olee,
   {{0x6d4b60ba,0x27e760bb,0x69c93a22,0x27ef0159}},	//   jega, _hinn_, nlee, _kugn_,
   {{0x44390052,0x6d4b60bc,0x69c906a2,0x6f0e006d}},	// [5e80] cts_, dega, ilee, _pebc,
   {{0x6d5960bd,0x290f60be,0x20000139,0x7f800095}},	//   edwa, _lega_, rpii_, _nöqt,
   {{0x27e760bf,0x61e660c0,0x69c960c1,0x6d4b60c2}},	//   _minn_, _tikl, klee, fega,
   {{0x27e760c3,0x3ea70082,0x290f60c4,0x6d4b60c5}},	//   _linn_, únta_, _nega_, gega,
   {{0x6f0e0189,0x69c90345,0xc7b900b5,0x6aa600e7}},	//   _tebc, dlee, tről_, गप्र,
   {{0x290f007c,0xaa584b92,0x69c260c6,0x69c900ec}},	//   _aega_, зику_, _skoe, elee,
   {{0x6d4b60c7,0xcf570d85,0x6da6174b,0x25a00553}},	//   bega, _קבלת_, _жива, _omil_,
   {{0xd90d09b9,0x290f60c8,0x443960c9,0x27e701da}},	//   میم_, _cega_, yts_, _ainn_,
   {{0x6cc3005f,0x290f60ca,0x274a0086,0x6da30603}},	//   _айта, _dega_, очно_, _рита,
   {{0x27e70a24,0xf69804bf,0x80db0083,0x61fe0254}},	//   _cinn_, звој_, যুক্, _otpl,
   {{0x69c90276,0xdce00080,0xe5353b4d,0x44394ef0}},	//   blee, _tomē, нень, wts_,
   {{0x27e700fb,0x7bca60cb,0x69c960cc,0x442b0139}},	//   _einn_, llfu, clee, tuc_,
   {{0x443960cd,0x27e703d0,0x20070254,0x61fe0a09}},	//   uts_, _finn_, ćnik_, _atpl,
   {{0x27e7005f,0x443960ce,0x25a060cf,0xf8ad006c}},	//   _ginn_, rts_, _emil_, _چکی_,
   {{0x443960d0,0xeb9102b5,0x7d0d008d,0x7c2b033b}},	//   sts_, אָן_, ðask, zugr,
   {{0x69c060d1,0x4439504d,0x6d4b01a3,0xd5b900ea}},	//   nome, pts_, xega, irāk_,
   {{0x629a01ba,0x4fd55b87,0x909902fb,0xc2eb0037}},	// [5e90] útor, ежат, чват_, _وعدم_,
   {{0xdceb07fc,0x6d4b01a8,0x69c901a3,0x325560d2}},	//   čičk, wega, zlee, _звор,
   {{0x69c0251e,0x4fc4034b,0x6d4b60d3,0x3d0b05b7}},	//   kome, тста, tega, ारले_,
   {{0x69c0004e,0x7c2b60d4,0x00000000,0x00000000}},	//   jome, tugr, --, --,
   {{0x69c060d5,0x6d4b60d6,0x290f60d7,0x6d5d008d}},	//   dome, rega, _rega_, _ósam,
   {{0x290f60d8,0x7c2b60d9,0x7c3901a2,0x6d4b3df4}},	//   _sega_, rugr, rtwr, sega,
   {{0xb4bc0302,0x6d4b60da,0x27e70014,0x290f2a31}},	//   _अड्_, pega, _rinn_, _pega_,
   {{0x27e760db,0x69c060dc,0x973c042a,0x2d8d012f}},	//   _sinn_, gome, vića, _ulee_,
   {{0x290f60dd,0x69c960de,0xb7bd0043,0x69db60df}},	//   _vega_, rlee, luţi, rmue,
   {{0x69c906a2,0xe73903fa,0x20070254,0x25a00b41}},	//   slee, чео_, ćnih_, _smil_,
   {{0x27e760e0,0x290f108a,0xaa95004f,0x69c92069}},	//   _vinn_, _tega_, _ثلاث, plee,
   {{0x69c01430,0x6a5301c2,0x27e72505,0xdb030031}},	//   come, _nəfə, _winn_, kinë,
   {{0x394d0006,0x27e760e1,0x186905a1,0x61fe009e}},	//   mees_, _tinn_, _хали_, _stpl,
   {{0x394d0173,0xed592676,0x33d51112,0x987a02b5}},	//   lees_, _laž_, віст, _מאנט,
   {{0xe5a6081b,0x32430421,0x61461a8e,0x00000000}},	//   _пики, лерг, нева, --,
   {{0x78a402dd,0x394d60e2,0x6a5300a8,0x25a009c5}},	//   _živi, nees_, _cəfə, _umil_,
   {{0xf9920779,0x8c9f004e,0xe3b203c5,0x1f662b34}},	// [5ea0] ארן_, _खेलो, _مرد_, нкам,
   {{0xdb1807a6,0x69c060e3,0xefc70012,0x6fb60037}},	//   toví, zome, елул_, رمضا,
   {{0x7dca0093,0x1d260183,0x79890b88,0x00000000}},	//   lýsi, емем, kkew, --,
   {{0xdb181df9,0x6fd0046c,0x69c001ef,0xdb030176}},	//   roví, _तीरं, xome, linè,
   {{0xac070009,0x69c060e4,0x8ba602fb,0x6fcb02b1}},	//   енча_, vome, нидж, küch,
   {{0xdb1801c0,0x69c060e5,0xb7bd002d,0x6a53013b}},	//   poví, wome, buţi, _zəfə,
   {{0x1c1c0299,0x394d053e,0xc3330317,0xe9e602fb}},	//   _निकल_, fees_, אוו_, нцио,
   {{0x394d60e6,0xdb030118,0x00000000,0x00000000}},	//   gees_, hinè, --, --,
   {{0xdcef03fd,0x57a660e7,0x00000000,0x00000000}},	//   _šeće, ешна, --, --,
   {{0x69c060e8,0x5a9660e9,0x65ab00c3,0x00000000}},	//   some, _преф, köhä, --,
   {{0x69c060ea,0x394d41c5,0x645622be,0x973c0207}},	//   pome, bees_, _asyi, bićn,
   {{0xceb30052,0x394d30bc,0x6fcb033b,0x399a0228}},	//   טית_, cees_, tück, gūst_,
   {{0xa3bd08d1,0x6fcb033b,0x00000000,0x00000000}},	//   इकल_, büch, --, --,
   {{0x6fcb02c9,0x6a5301c2,0xdb030055,0x00000000}},	//   rück, _səfə, vinë, --,
   {{0x56940210,0x216741f8,0x0d100099,0xf773016b}},	//   _шакт, нтаг, ाराष_, _תקצ_,
   {{0x3ce90888,0xdb0301f4,0xf1a4093e,0x00000000}},	//   žavi_, tinë, грун, --,
   {{0x656d60eb,0xdbd00168,0xd6df0067,0xb5070d12}},	// [5eb0] _inah, _džús, ąłem_, _व्यय_,
   {{0xb7bd0043,0xdb030031,0x00000000,0x00000000}},	//   tuţi, rinë, --, --,
   {{0x1b0f0083,0xa2950eb9,0x394d00a5,0x6a5300a8}},	//   _সালে_, _рані, yees_, _təfə,
   {{0xe8210b4a,0xdb0360ec,0x63a760ed,0xfc31103b}},	//   _मिला_, miné, lijn, لحت_,
   {{0x2fd9004f,0xd11600a5,0x394d0553,0x656d3b0a}},	//   _يوجد_, _בקרה_, vees_, _mnah,
   {{0x394d0173,0x63a7331b,0xfaa51f76,0xc4d40317}},	//   wees_, nijn, кало, נגס_,
   {{0xbd0500f7,0xdb0301ef,0x00000000,0x00000000}},	//   _créé, niné, --, --,
   {{0x7c244693,0x63a70120,0x00000000,0x00000000}},	//   šira, hijn, --, --,
   {{0xdd94004b,0xc8db02e4,0x79891c26,0x6fcb02b1}},	//   _саты, मेंट, rkew, tüch,
   {{0x394d60ee,0xfd4d0028,0x656d60ef,0xf7720594}},	//   sees_, _ngoạ, _anah, لاپ_,
   {{0x394d60f0,0x6d5b60f1,0x63a70187,0x6fcb01ae}},	//   pees_, _kaua, dijn, rüch,
   {{0xe5a628cc,0x7bc360f2,0x81b60083,0xdb035c21}},	//   тими, lonu, _চীন_, diné,
   {{0x6d5b19c6,0x399a00c2,0xdb1860f3,0x69d90027}},	//   _maua, _קינד, lová, _ihwe,
   {{0x6d5b4e1f,0x7bc360f4,0xdb0360f5,0x8c130033}},	//   _laua, nonu, finé, _সমান_,
   {{0xdb1860f6,0x7dd80098,0x80df0033,0x45d60f8c}},	//   nová, líse, _ফ্ল্, _ицит,
   {{0xfe720105,0x38600bc6,0x6d5b01ed,0x7bc30bf7}},	//   یدا_, _širi_, _naua, honu,
   {{0xe3ba0714,0xdb18053d,0x7bc360f7,0x91e3081e}},	// [5ec0] _оби_, hová, konu, роте,
   {{0xcfb500c8,0xe0d760f8,0xdb1801c0,0xdfcf017e}},	//   _জীবন, тву_, ková, قيق_,
   {{0x7bc360f9,0x1fb5066d,0x6d5b60fa,0xe3b20e3a}},	//   donu, устр, _baua, _مرگ_,
   {{0x5bca60fb,0xdb1801c0,0x3f910009,0x6d930225}},	//   ित्व, dová, _elzu_, _açab,
   {{0xeb9a29e5,0x6d5b01a3,0xb4db0176,0x9f49008d}},	//   мид_, _daua, leàr, ppað_,
   {{0x7bc3300e,0x661a4e99,0xa3c4018d,0xbd0500f6}},	//   gonu, ystk, ौति_, _préé,
   {{0x5ee000c8,0xcb670274,0x6d5b009e,0x00000000}},	//   _প্রে, таје_, _faua, --,
   {{0x69d90297,0x6d5b60fc,0x41d831d7,0x386900f4}},	//   _chwe, _gaua, _भीमस, _šara_,
   {{0xdb340a86,0x8c4603fa,0x69d90118,0xa3c401c0}},	//   _مذاک, _језе, _dhwe, ौता_,
   {{0x656d0187,0x81d80083,0x7f5c0176,0x69d90103}},	//   _snah, াদি_, _jarq, _ehwe,
   {{0x7f5c048e,0xdb180333,0xdb0360fd,0xdce0010b}},	//   _marq, cová, ronô, _pomė,
   {{0x891a09b9,0x661a60fe,0x63a760ff,0x2b06021a}},	//   _آغاز_, rstk, wijn, _स्तु_,
   {{0x6dbc0c21,0x81d80083,0xd87301cb,0x26c20067}},	//   mčad, াদা_, _ناوب, łko_,
   {{0x623503e6,0xc7a30036,0xdb036100,0xc4d30066}},	//   легу, _кичк, tiné, _सरीख,
   {{0x248d0a0b,0x394600d7,0x63a73bc8,0x91c70200}},	//   šem_, _kbos_, rijn, вљал,
   {{0x7bc36101,0x656d6102,0xe5c400d4,0x6dbc00cd}},	//   zonu, _unah, _всьо, nčad,
   {{0x7bc30463,0xdb03004f,0xdb1801c0,0x63a76103}},	// [5ed0] yonu, siné, zová, pijn,
   {{0x2fc76104,0x7f5c6105,0x248400c3,0x00000000}},	//   ông_, _carq, ämme_, --,
   {{0x7f5c0176,0x7bc36106,0x63a5009e,0x20020225}},	//   _darq, vonu, _imhn, _etki_,
   {{0xdb1800b8,0x7bc8095f,0x6dbc0009,0x9f4a021e}},	//   vová, _akdu, jčad, _libè_,
   {{0x7f5c00d7,0x7c240a23,0xa3b800bf,0x68fb00a8}},	//   _farq, širn, _سایر_, vcud,
   {{0x28c6007c,0x442b184f,0x09cb21b2,0xdb186107}},	//   _लड़ि, irc_, ात्य, tová,
   {{0xa9a54406,0x442b009e,0x7bc36108,0x7bc800fe}},	//   ликд, hrc_, ronu, _dkdu,
   {{0xdb1801c0,0xdcfb2ff1,0x3866165f,0x98af0069}},	//   rová, _kouč, _bror_, _jagħ_,
   {{0x7bc36109,0xdb1800b8,0xf7712604,0x63a50211}},	//   ponu, sová, ماد_, _omhn,
   {{0x68fb610a,0xdb1800b8,0x3d0b021a,0x7bc30be2}},	//   scud, pová, ारके_, qonu,
   {{0x6f15610b,0xe61600af,0x386601ed,0xab840d46}},	//   _mezc, лдэ_, _eror_, _тутк,
   {{0x3ce92c3f,0x78b9006d,0x6f1500fe,0x1db3022e}},	//   žavu_, _txwv, _lezc, ंचित,
   {{0xf74532fa,0xdce9022f,0x28f800c3,0x3866029e}},	//   _бело, _oneč, _речь_, _gror_,
   {{0xf773146d,0xe7392101,0x395f610c,0x63a50211}},	//   _خاص_, _чек_, ldus_, _cmhn,
   {{0x395d0221,0xe29a0dba,0x442b0719,0x321e0501}},	//   _kaws_, хав_, arc_, éty_,
   {{0x395f610d,0x7d190035,0xdcfb00d5,0x00000000}},	//   ndus_, jaws, _bouč, --,
   {{0x7f5c1ea3,0xdb01006c,0xdfd212de,0xd17500c7}},	// [5ee0] _parq, _emlé, مير_, шыры,
   {{0x4420610e,0x7f5c610f,0xdcfb0097,0x2e3c0079}},	//   _ivi_, _qarq, _douč, tíf_,
   {{0x11d60164,0x6fd001ff,0x442051f1,0x00000000}},	//   _متحد, läck, _hvi_, --,
   {{0x7bda00da,0x427b0070,0x515608ce,0x127b016b}},	//   _shtu, _נאכג, _стоу, _נאכע,
   {{0x395f0297,0x7f5c027a,0x6d420160,0x6b816110}},	//   ddus_, _tarq, rfoa, _bolg,
   {{0x6b816111,0x7c2400cd,0x8f7601e0,0xdce90116}},	//   _colg, širo, _сумі, _gneč,
   {{0x6b816112,0x2d9c0248,0x2611008b,0x44206113}},	//   _dolg, èves_, jšo_, _lvi_,
   {{0x31606114,0x395d6115,0x7d0d008a,0xfce649b8}},	//   ndiz_, _caws_, ðast, _бобо,
   {{0x6b8102bf,0x395d01a9,0xa3c40311,0x5b3621a0}},	//   _folg, _daws_, एका_, _معار,
   {{0x973c011c,0x75240065,0x2ca70274,0x395f6116}},	//   mićk, _adiz, _скуп_, adus_,
   {{0x9f4a004f,0xd6d00c26,0x44206117,0x35b509a5}},	//   _cibé_, تقد_, _avi_, ибор,
   {{0x3866165f,0xd6d7021f,0x672302c4,0x394611e9}},	//   _tror_, ыты_, _ednj, _ubos_,
   {{0x98a32c49,0x5eab0083,0xe4a76118,0x442000ee}},	//   _лице, _করছে, урно, _cvi_,
   {{0x75246119,0x442000d8,0x395d0221,0x8cd70066}},	//   _ediz, _dvi_, _zaws_, _बरसो,
   {{0x442b2734,0xdcfb000c,0x4420611a,0x395d006d}},	//   src_, _souč, _evi_, _yaws_,
   {{0x442b005f,0x6fd0611b,0x395d0221,0x48db01c0}},	//   prc_, läch, _xaws_, खेको_,
   {{0x0f150eb1,0x7ff7611c,0xdce000ec,0x973c0207}},	// [5ef0] имаю, اسرا, _domī, jićk,
   {{0x6fd001ae,0x644d0cca,0x7d19611d,0x973c00f4}},	//   näch, _ipai, waws, dićk,
   {{0x4420012f,0x644e008b,0x6b810223,0xf41f0328}},	//   _zvi_, čniš, _rolg, lsä_,
   {{0x6b811217,0x7d0e0023,0x7982030d,0xb05500fd}},	//   _solg, _đbsc, _noow, _پھرت,
   {{0x395d01a9,0xf41f03ad,0x6b81006c,0x61f70185}},	//   _raws_, nsä_, _polg, _huxl,
   {{0x395d611e,0x2009611f,0x6a85081b,0x7d19010d}},	//   _saws_, mpai_, илла, saws,
   {{0x6b81137b,0x395d6120,0x6fd002b1,0x83380070}},	//   _volg, _paws_, däch, טאגס_,
   {{0xca740409,0x2ba602e4,0x395d6121,0x395f6122}},	//   сушы, कोबा, _qaws_, udus_,
   {{0x3f836123,0x395f6124,0x5d84500b,0x66046125}},	//   _koju_, rdus_, _القل, _čika,
   {{0x395f011e,0x4420013a,0x61ef0176,0x00000000}},	//   sdus_, _rvi_, _licl, --,
   {{0x44200537,0x395d0189,0x644d6126,0x3f834340}},	//   _svi_, _taws_, _apai, _moju_,
   {{0x61ef6127,0x657d01f4,0x8afc0035,0x629c008b}},	//   _nicl, gjsh, _wnęt, vzro,
   {{0x6d490082,0x290d0657,0xf8070043,0xdff1052f}},	//   _mbea, mbea_, _счен, _अंगद_,
   {{0x66e51a82,0x6fd0022a,0x889a00a5,0x79820051}},	//   _кола, räck, _בבני, _zoow,
   {{0x644d06a2,0x6fd01173,0x629c0254,0xf53f01b4}},	//   _epai, säck, uzro, rnår_,
   {{0x6fba1371,0xd13200ad,0x44203a62,0x602601e0}},	//   ्वभू, تمر_, _tvi_, идба,
   {{0x3f8315d7,0xcef6192f,0x208700d4,0x61ef0381}},	// [5f00] _boju_, ачењ, айти_, _dicl,
   {{0xdb036128,0x973c00cd,0x61ef0211,0x10a30012}},	//   finí, vićk, _eicl, циун,
   {{0xed5a02ce,0x76411c9b,0xee3a609f,0x6d490211}},	//   кож_, ntly, тне_, _bbea,
   {{0x3d100066,0x6d49009e,0x61ef00a2,0x2b5e0282}},	//   ारें_, _cbea, _gicl, _satc_,
   {{0x61e46129,0x6d490211,0xdb030132,0x3ad500cc}},	//   mmil, _dbea, dinâ, _áp_,
   {{0x3f83012f,0x61e4612a,0x973c00f4,0xa49b01f7}},	//   _goju_, lmil, rićk, mbòt,
   {{0x34d305a6,0x973c0207,0x00000000,0x00000000}},	//   _सर्द, sićk, --, --,
   {{0x61e4612b,0x6fd0033b,0x61ef04cb,0x973c00f4}},	//   nmil, wäch, _xicl, mići,
   {{0x61e41e16,0x973c00cd,0x7dd8002a,0xa2cd0067}},	//   imil, lići, císa, _दुन्,
   {{0x2d84612c,0xfaa6612d,0x7982073a,0x61e413b8}},	//   _home_, _казо, _woow, hmil,
   {{0x2d8418d4,0x6fd001ae,0x7982612e,0x61e4612f}},	//   _kome_, räch, _toow, kmil,
   {{0x61e400cd,0x6fd0033b,0x7c2d00f4,0xf41f0421}},	//   jmil, säch, šare, tsä_,
   {{0xb44701c8,0x94a86130,0x61ef0036,0x00000000}},	//   шэнк, атра_, _ricl, --,
   {{0xa5c70093,0x2484013c,0x2d846131,0x61e46132}},	//   _blóð, ämma_, _lome_, emil,
   {{0xf41f3dee,0xf1a76133,0x25fd0066,0x764108c7}},	//   ssä_, аран, _रूपी_, ctly,
   {{0x2d846134,0x3d10004e,0x3ce00187,0x973c00cd}},	//   _nome_, ारों_, živy_, dići,
   {{0xc1040082,0x25a96135,0xdce90069,0x69c70099}},	// [5f10] توقي, _imal_, _ileħ, ावती,
   {{0x9951024e,0x68f500b8,0x20096136,0x973c0506}},	//   _máš_, ězdi, rpai_, fići,
   {{0x2d846137,0xdef8005f,0x61ef3811,0xede700d8}},	//   _bome_, рыу_, _ticl, аўдн,
   {{0x2d846138,0x386902b2,0xd2561804,0xdb0a0093}},	//   _come_, _šarm_, _פשרה_, nnfæ,
   {{0x9951024e,0x2d840147,0x00000000,0x00000000}},	//   _náš_, _dome_, --, --,
   {{0x2bbb0082,0x973c0207,0x09af0099,0xebc70200}},	//   خاصة_, bići, जच्य, шљен,
   {{0xfee500c8,0x5e95004f,0x2d846139,0xb222008a}},	//   _প্রধ, _الأط, _fome_, _áætl,
   {{0xd2b802da,0x7dd8016f,0x7e620067,0xdb010098}},	//   ילות_, písa, łopc, _imlí,
   {{0x98a528cc,0xf8a900d1,0x290d613a,0xf719010b}},	//   сипе, دگاه_, rbea_, ліны_,
   {{0x25a920fb,0x995100ac,0xda67132d,0x61e40987}},	//   _amal_, _dáš_, _پائي, zmil,
   {{0xdce90069,0x85ea0012,0x61e4613b,0xdb030176}},	//   _bleħ, лдов_, ymil, minà,
   {{0x76410b88,0xceb20319,0x25a9009e,0x857a03e6}},	//   rtly, ליי_, _cmal_, усот_,
   {{0xa5c7008d,0x76410090,0x00000000,0x00000000}},	//   _slóð, stly, --, --,
   {{0x25a9613c,0x00000000,0x00000000,0x00000000}},	//   _emal_, --, --, --,
   {{0xe297613d,0x61e40987,0x412a0ade,0x2bba022e}},	//   бар_, tmil, лово_, ेवता,
   {{0xc243613e,0x61e4613f,0x973c00cd,0x00000000}},	//   янск, umil, vići, --,
   {{0xe0da051b,0x61e46140,0xa3ba014a,0x03a60421}},	// [5f20] ува_, rmil, _مادر_, _гипо,
   {{0x2d840052,0x61e46141,0xe47b0122,0x973c00cb}},	//   _some_, smil, _עריכ, tići,
   {{0x44222895,0xc7d600a5,0xdb030443,0x6ab60099}},	//   lsk_, צועי_, dinà, _अखेर,
   {{0x628e010b,0x973c00cd,0xafdb0a8a,0x00000000}},	//   mybo, rići, _spøt, --,
   {{0x44220532,0x653b02b5,0x996c01c0,0xdb0100b5}},	//   nsk_, רענד, těž_, _emlí,
   {{0x442201e0,0x973c0124,0xdb030392,0x00000000}},	//   isk_, pići, ginà, --,
   {{0x2d840537,0x628e6142,0x660400f4,0xdb0a6143}},	//   _tome_, nybo, _čiko, nifé,
   {{0xed5a02ce,0x6f1e0187,0xd90d0e3a,0x799b0008}},	//   _щоб_, lapc, نیم_, ghuw,
   {{0x628e0187,0x9f4a007e,0x00000000,0x00000000}},	//   hybo, _libí_, --, --,
   {{0x99510076,0x7d0201d3,0x63ae046a,0x628e00d8}},	//   _váš_, lcos, jibn, kybo,
   {{0xd90f081b,0x799b022e,0x41c80355,0x9f940421}},	//   _нь_, bhuw, लवास, mää_,
   {{0xdb036144,0x628e010b,0x7d026145,0x799b0120}},	//   miná, dybo, ncos, chuw,
   {{0xdb034743,0x6f1e006c,0x94ab6146,0x9f51021d}},	//   liná, kapc, утна_, _dizê_,
   {{0x56940786,0xa85700a5,0x63ae0693,0x7c2201ed}},	//   _малт, _לידה_, gibn, isor,
   {{0x1b1d0083,0x7c220c6f,0xdb030097,0xdb0a3576}},	//   _নামে_, hsor, niná, rifè,
   {{0x44220a8a,0x7c22229e,0x00000000,0x00000000}},	//   bsk_, ksor, --, --,
   {{0x7d02011e,0x9f9400c3,0x69ab0067,0x00000000}},	// [5f30] dcos, kää_, _जगसी, --,
   {{0x3255195a,0x7c226147,0xf3ff0279,0x5edd0033}},	//   _двор, dsor, lvão_, _বলবে,
   {{0xdb030334,0x2bdc0630,0xdfd802fb,0xdcfb0139}},	//   jiná, यतना, сът_, _nouă,
   {{0xdb034743,0xfe70004f,0x3cd51583,0x973c0009}},	//   diná, عدل_, ожес, miću,
   {{0x46cf0084,0x913a02b5,0x7c221e54,0xa2cd07b5}},	//   _सुनह, _דערק, gsor, _दुत्,
   {{0x7e620035,0x7bca099e,0x6d93021d,0xdb031da9}},	//   łopa, gofu, _içam, finá,
   {{0xfbd00c74,0xdb036148,0x49990a2b,0x2a6c08c7}},	//   رته_, giná, ития_, _crdb_,
   {{0x44224d03,0xe8f91158,0x7d020ccb,0xe9d92123}},	//   ysk_, шли_, ccos, јки_,
   {{0x6a4a00a8,0x7c226149,0x628e1140,0x2eb923e3}},	//   _vəfa, csor, zybo, _आशुत,
   {{0x6dbc0877,0x99801cc4,0x799b01d5,0x464906e4}},	//   nčan, čiš_, shuw, азон_,
   {{0x98b90092,0x7d1b0173,0xcb1202b8,0x00000000}},	//   ısı_, _keus, _חלב_, --,
   {{0x24ea224a,0x3cf00084,0x1dc904e9,0x7d1b023c}},	//   имни_, ुँचे_, िकित, _jeus,
   {{0x4424614a,0x628e614b,0x7d1b614c,0x291f0160}},	//   ém_, wybo, _meus, maua_,
   {{0x44220044,0x628e00d8,0x7d1b614d,0x7c240079}},	//   rsk_, tybo, _leus, áiri,
   {{0x63ae046a,0x2d9d012f,0x15461b96,0x5275002d}},	//   ribn, khwe_, _дейм, путу,
   {{0x63ae614e,0x7c240a78,0x7c22614f,0x7bca6150}},	//   sibn, širi, ysor, zofu,
   {{0xef1a6151,0xdb0300b8,0x7bca0054,0x7413026e}},	// [5f40] има_, ziná, yofu, _قويا,
   {{0xafdb0568,0x65646152,0x291f6153,0x7dec00c1}},	//   _spør, _haih, haua_, _işsi,
   {{0xa2e61dc2,0x65646154,0x9f9403ad,0x7d1b1d22}},	//   _фонд, _kaih, vää_, _beus,
   {{0xdb03024e,0x7d1b01da,0x216a0185,0xb6ba00a5}},	//   viná, _ceus, _тими_, בצעי,
   {{0x9f940d36,0x65642ef9,0x64463e17,0x7d02027a}},	//   tää_, _maih, ntki, rcos,
   {{0x7c226155,0x7d02407a,0xdb0305f6,0x656400c3}},	//   rsor, scos, tiná, _laih,
   {{0x6446007c,0x7bca6156,0x7d1b01da,0x9f9400c3}},	//   htki, rofu, _feus, rää_,
   {{0x9f9403ad,0xdb036157,0x7d1b5546,0x7c2d6158}},	//   sää_, riná, _geus, šara,
   {{0xa3da004e,0xb9020722,0x46cf00ab,0x6f1c6159}},	//   ़ता_, _धर_, _सुबह, _kerc,
   {{0x7d1b1a7f,0x399801cb,0x776300e2,0x64460137}},	//   _zeus, _désa_, _canx, dtki,
   {{0x6f1c40d4,0x4efb02b5,0x65643fba,0x9f510107}},	//   _merc, יליג, _baih, _dizè_,
   {{0x6564009e,0xd49b0185,0x00000000,0x00000000}},	//   _caih, арг_, --, --,
   {{0xe7860c06,0x69c700a1,0xf3ff0132,0x77630065}},	//   _муко, ावरी, rvão_, _fanx,
   {{0x8c4805f9,0x77630310,0x657600b5,0x9f510055}},	//   mağı, _ganx, _enyh, _vizë_,
   {{0x6dbc0af1,0x65950dfc,0x92680426,0x8c48045e}},	//   včan, _наку, орта_, lağı,
   {{0x65c42b9e,0x60f910b0,0x6b88593a,0x6f1c0098}},	//   _обја, сная_, _lodg, _aerc,
   {{0x7d1b615a,0x6f1c615b,0xfbca0355,0x8c48045e}},	// [5f50] _reus, _berc, ाकाम, nağı,
   {{0x4439615c,0x6f1c615d,0xdfd10082,0x7d1b615e}},	//   mus_, _cerc, ريا_, _seus,
   {{0x4439615f,0x6dbc03c9,0xdb030225,0x7d1b0345}},	//   lus_, rčan, linç, _peus,
   {{0x753d6160,0xdce0037a,0x6d400176,0x44396161}},	//   ngsz, _almı, _ccma, ous_,
   {{0x6f1c001e,0xaf370088,0x6dbc01a0,0x3d0a0084}},	//   _ferc, _ورست, pčan, ाड़े_,
   {{0xf1bf064b,0x2d9d25bf,0x291f0054,0x7d1b002f}},	//   _hjá_, shwe_, waua_, _weus,
   {{0x44396162,0x6fba20af,0x69c4010b,0x77630176}},	//   hus_, ्वरू, čien, _ranx,
   {{0x6dbc04c3,0x77636163,0xf1bd0761,0x8d7700ce}},	//   nčal, _sanx, ्किन, _باسا,
   {{0x44396164,0xa3bd09a3,0x65640034,0xa2cd00ab}},	//   jus_, ेका_, _raih, _दुस्,
   {{0x44396165,0x6d596166,0xe73903fa,0x6d4b6167}},	//   dus_, lewa, љен_, lfga,
   {{0xb9010083,0x656402ee,0x6dbc0009,0x9f4300ee}},	//   _দল_, _paih, kčal, _bijú_,
   {{0x6d596168,0x8c4800a8,0x995107c0,0x2c5d0260}},	//   newa, bağı, _báť_, _kňd_,
   {{0x8c480d6f,0xe72e09eb,0x656403ad,0x77630042}},	//   cağı, _пе_, _vaih, _tanx,
   {{0x24446169,0x291d000e,0x61c40b35,0x212b00ee}},	//   röm_, _hewa_, वक्ष, _adch_,
   {{0x64460755,0xf770064e,0x443901c8,0x67210a78}},	//   stki, _جان_, aus_, malj,
   {{0x6f1c616a,0xdb032119,0x00000000,0x00000000}},	//   _serc, linä, --, --,
   {{0x6f1c0dbb,0x21203101,0x671f0084,0xe53b00a5}},	// [5f60] _perc, raih_, _मजाक_, _התפר,
   {{0x6721616b,0x7c390051,0x291d616c,0x6d4b616d}},	//   nalj, duwr, _lewa_, efga,
   {{0x6d593889,0x5ee10099,0xd24f1a95,0x02fb00a5}},	//   fewa, _करण्_, _ینی_, _ללימ,
   {{0x6d59616e,0x7e620035,0x6721616f,0x127b0070}},	//   gewa, łopo, halj, _האטע,
   {{0x25fd0084,0x0b8a01d3,0x6e250051,0x00000000}},	//   _रूसी_, йски_, ashb, --,
   {{0x2c5d0107,0xa13600f8,0x672100f4,0x00000000}},	//   _dňd_, _برگش, jalj, --,
   {{0x67214978,0x9ea700c9,0x6d590e54,0x4bd900d8}},	//   dalj, _евра_, bewa, цьця_,
   {{0x6d592400,0x8c4611a7,0x8c480644,0x44396170}},	//   cewa, _небе, tağı, yus_,
   {{0x291d1b0f,0xdb0a004f,0xdca36171,0xdce0082d}},	//   _dewa_, lifí, _зати, _kamč,
   {{0x44396172,0x6721080f,0xdce00627,0x8c48027b}},	//   vus_, galj, _jamč, rağı,
   {{0x4439053e,0x3f8a043d,0x9f4b0036,0xe5355087}},	//   wus_, _mobu_, _cucù_, мень,
   {{0xa2cd6173,0xdb030279,0x7c24011c,0x00000000}},	//   _दुष्, tinç, širu, --,
   {{0x67211d6d,0xddce3b48,0x00000000,0x00000000}},	//   balj, _arbū, --, --,
   {{0xf1bf00fb,0x66b402d5,0x6d590035,0x67216174}},	//   _sjá_, _облу, zewa, calj,
   {{0x44396175,0xa2cd1163,0x61fe6176,0xf2c41e92}},	//   sus_, _दुश्, _cupl, естн,
   {{0x59cc03de,0xdb0a002a,0xdb1a0225,0x3ebf0207}},	//   ाविर, difí, _aktü, _ćut_,
   {{0xa2cd162b,0xfbdc0355,0x752d0291,0x61fe01ef}},	// [5f70] _दुर्, यताम, _idaz, _eupl,
   {{0x44296177,0xa85700a5,0x00000000,0x00000000}},	//   _iva_, הימה_, --, --,
   {{0xb81e0c57,0x3f8a031d,0x6f05021d,0x442902ce}},	//   _मौसम_, _dobu_, rchc, _hva_,
   {{0xdb1a3dd8,0xf1a70847,0x9cb501b2,0x44290044}},	//   _októ, _хрон, ومات, _kva_,
   {{0x291d0069,0x6c8500fd,0x200b01ed,0x6b650757}},	//   _rewa_, بلشم, _utci_, дкла,
   {{0x6dbc02f6,0x291d2b63,0x44296178,0xdce000ee}},	//   nčaj, _sewa_, _mva_, _gamč,
   {{0xbe880043,0x6e2500e7,0x752d011c,0xdb0a01ef}},	//   _есте_, qshb, _odaz, cifí,
   {{0x442903fa,0xdb180187,0x7d041e6e,0x752d1568}},	//   _ova_, mový, ñist, _ndaz,
   {{0x7c24004f,0xdb18024e,0xf53f035b,0xf77118dd}},	//   áirt, lový, dgå_, ناد_,
   {{0x6fbf022e,0x386f0051,0x5fbf175f,0x00000000}},	//   ्विं, _vrgr_, ्विल, --,
   {{0x6721003c,0x44296179,0x7c29617a,0xa2cd0084}},	//   ralj, _ava_, _hver, _दुल्,
   {{0x44293913,0x67211f3d,0x7c294b19,0x260101ef}},	//   _bva_, salj, _kver, _vóo_,
   {{0x61fe617b,0x5fbf04bc,0x6fbf00a1,0x67210d38}},	//   _supl, ्वाल, ्वां, palj,
   {{0x4429117f,0x28e2018d,0x798b0ec0,0xdb18024e}},	//   _dva_, _परति, _hogw, kový,
   {{0x3f8a04c3,0x7d090176,0x386d38d1,0xdb180187}},	//   _robu_, _ofes, lver_, jový,
   {{0x7c29617c,0x3f8a0200,0xdb18053d,0x7dd80093}},	//   _over, _sobu_, dový, rísk,
   {{0x4429617d,0x386d252d,0xb17b017b,0xdce00207}},	// [5f80] _gva_, nver_, _ihål, _pamč,
   {{0x386d5aa0,0x61fe617e,0xdd8f01df,0xdb0a2278}},	//   iver_, _tupl, یول_, tifí,
   {{0xdfcf0514,0x28af045c,0x7c292704,0xdb1a02e9}},	//   جيل_, _जेसि, _aver, _oktò,
   {{0x7bc10160,0x4429323d,0xdb0a28ab,0x7c2902b1}},	//   _ajlu, _yva_, rifí, _bver,
   {{0x386d0120,0x7dd82278,0xdb0a01dd,0x6dbc0009}},	//   jver_, nísi, sifí, lčak,
   {{0x7d09617f,0x7c296180,0xdb180314,0x39980118}},	//   _efes, _dver, bový, _péso_,
   {{0x7c290052,0x394d6181,0x7d0900e9,0xdb180097}},	//   _ever, ffes_, _ffes, cový,
   {{0x394200ab,0x6e220009,0x798b00ee,0xd91a01e0}},	//   üks_, ćobd, _cogw, цьк_,
   {{0x7c290484,0x660d338b,0x6dbc01ba,0x26160324}},	//   _gver, _čaka, yčaj, _भौजी_,
   {{0x7dd82eae,0x00000000,0x00000000,0x00000000}},	//   dísi, --, --, --,
   {{0x442922b2,0x7c29016f,0x2bcb0026,0x6dbc0009}},	//   _sva_, _zver, िवरा, jčak,
   {{0x56932374,0x9f9f0223,0x7c292bd0,0x00000000}},	//   тают, _véél_, _yver, --,
   {{0xf8e206bb,0x2edb3123,0xdb180187,0x9abc007a}},	//   _परिय, _भर्त, zový, _deċe,
   {{0x237a0279,0x75fe00ea,0x44290103,0x00000000}},	//   _cnpj_, _līzi, _vva_, --,
   {{0x6fbf022e,0x6dbc0009,0xdce200a0,0x00000000}},	//   ्वसं, rčaj, jkoľ, --,
   {{0xd5b8081b,0x44296182,0xf8e20084,0x5edd0083}},	//   _осы_, _tva_, _पराय, _বললে,
   {{0x44296183,0x2d860088,0x00000000,0x00000000}},	// [5f90] _uva_, djoe_, --, --,
   {{0xdb18024e,0x7c292955,0x00000000,0x00000000}},	//   tový, _rver, --, --,
   {{0x63b530ec,0x7c290533,0xdde20207,0x75fe005f}},	//   mizn, _sver, _šušu, _dūzg,
   {{0xdb18024e,0x386d08c8,0x63b56064,0x629501ef}},	//   rový, yver_, lizn, myzo,
   {{0x61ed5f7f,0x80270041,0xdb180187,0xdb0301dd}},	//   mmal, _ترجم, sový, minú,
   {{0x61ed6184,0x63b55582,0xa3df0387,0x69c20183}},	//   lmal, nizn, तति_, _ajoe,
   {{0xd90f0a86,0x61ed6185,0x69c201e0,0xa3c00387}},	//   لیا_, omal, _bjoe, ंचत_,
   {{0xa2d60299,0x61ed10b1,0x9f5905d3,0x7c296186}},	//   _मुफ्, nmal, _musí_, _tver,
   {{0x386d1010,0xa2d65dc3,0x7c296187,0xa3df0517}},	//   uver_, _मुन्, _uver, तता_,
   {{0xbf1d0084,0x7dd86188,0x61ed6189,0x63b5003d}},	//   _फ़ोन_, vísi, hmal, jizn,
   {{0x7d045ed9,0x81d60083,0x61ed618a,0x386d618b}},	//   žise, িগত_, kmal, sver_,
   {{0xb8e50b52,0x7dd81111,0x386d03d0,0x6dbc0124}},	//   _এর_, tísi, pver_, včak,
   {{0x61ed00ea,0x00000000,0x00000000,0x00000000}},	//   dmal, --, --, --,
   {{0x69db618c,0x7dd82eae,0xf7450370,0x61ed618d}},	//   llue, rísi, _чеко, emal,
   {{0x2176618e,0x7dd80300,0x9f590176,0xdb0a0183}},	//   нуар, sísi, _cusí_, nifá,
   {{0x61ed618f,0x6b530381,0x9f5900d5,0x600a0be8}},	//   gmal, lıgı, _dusí_, знам_,
   {{0x63b56190,0x75266191,0x3fe642f1,0x69db380c}},	// [5fa0] bizn, makz, ежав, ilue,
   {{0x63b56192,0x2d9f0086,0x61ed6193,0x69db0bf7}},	//   cizn, _alue_, amal, hlue,
   {{0x2d9f6194,0xdee66195,0x59cf1cce,0x00000000}},	//   _blue_, хожи, हकार, --,
   {{0x61bd0c67,0xde036196,0xbd6701e0,0xd2b70070}},	//   ्कृष, упци, ерше_, _טלית_,
   {{0x2004002d,0x7f1a010b,0x00000000,0x00000000}},	//   _îmi_, _ніву_, --, --,
   {{0x9f5801d2,0x69c202a2,0xaa665451,0xa3c000ab}},	//   _mirë_, _sjoe, етик, ंचि_,
   {{0xdee332ff,0x9f5801f4,0x2d9f5366,0x69db6197}},	//   _бори, _lirë_, _flue_, flue,
   {{0x20020010,0x68e20024,0x2d9f0147,0x00000000}},	//   _kuki_, _pzod, _glue_, --,
   {{0xa3c00429,0x6da328ea,0x752601a3,0x6bda00b5}},	//   ंचा_, _сита, dakz, _فورس_,
   {{0x27f80583,0xc6a60043,0x999f0029,0x61ed00c1}},	//   örn_, ерми, ārši_, zmal,
   {{0x63b56198,0x61ed6199,0x6d9301ed,0x69c2619a}},	//   vizn, ymal, _eçau, _tjoe,
   {{0x6d420291,0x69db619b,0x61ed013b,0x7cf60225}},	//   ngoa, clue, xmal, _gürü,
   {{0x19b70070,0x660404d9,0x58930647,0x00000000}},	//   _אפאר_, _čiku, _مجوز, --,
   {{0x38660176,0x27e7009e,0x00000000,0x00000000}},	//   _isor_, _ghnn_, --, --,
   {{0x7cf606d3,0x66730125,0x69c05461,0x2002619c}},	//   _yürü, _مدير, onme, _auki_,
   {{0x26db02b8,0x62950035,0x250900d1,0x69c02129}},	//   _מקומ, ryzo, _غربی_, nnme,
   {{0x69c0619d,0x40340fb4,0x00000000,0x00000000}},	// [5fb0] inme, летс, --, --,
   {{0x7c2d02dd,0x200f0080,0xdb030138,0x4439055c}},	//   šark, īgi_, sinú, mrs_,
   {{0x4fc4619e,0x44390107,0x88bd0035,0x61ed033e}},	//   уста, lrs_, jaśn, pmal,
   {{0xdce000ec,0x442b0443,0x38660176,0x4439293c}},	//   _samā, osc_, _osor_, ors_,
   {{0xdce000ea,0xcb690af4,0x44390555,0x38660069}},	//   _pamā, дале_, nrs_, _nsor_,
   {{0x7cf606d0,0x39460176,0x6d4201d7,0xbbcb1cce}},	//   _sürü, _acos_, agoa, िवेक,
   {{0x660d0f3e,0xab2807f8,0xdb0a008a,0xdddc00b5}},	//   _čako, رسول_, kifæ, _errő,
   {{0x4439619f,0xa3e30084,0x69c061a0,0x00000000}},	//   krs_, _फीस_, gnme, --,
   {{0xdce000ec,0x442b61a1,0x76580409,0x00000000}},	//   _tamā, jsc_, _apvy, --,
   {{0x8aa761a2,0x93e00243,0x39462dea,0x443900ea}},	//   _пред, _खींच_, _ecos_, drs_,
   {{0x443961a3,0xe5a64697,0x442b002d,0x9f580107}},	//   ers_, вини, esc_, _dirè_,
   {{0x9f580055,0x39460098,0x00000000,0x00000000}},	//   _pirë_, _gcos_, --, --,
   {{0x5fd1084b,0x7dd861a4,0x25a0023a,0x752601b7}},	//   तकाल, míst, _vlil_, rakz,
   {{0x7dd80473,0x33d50560,0x6a4a0095,0x00000000}},	//   líst, гіст, _səfi, --,
   {{0x25e30953,0x442b0037,0x799b0054,0x7c2d0009}},	//   _टीवी_, asc_, okuw, šarh,
   {{0x395f01aa,0x7dd83d46,0xa2d60066,0x2002067f}},	//   neus_, níst, _मुण्, _puki_,
   {{0x660361a5,0x4439021d,0xf5930037,0x000400b5}},	// [5fc0] _hunk, crs_, _خليج, اثری,
   {{0x991e0d1f,0x672361a6,0x660361a7,0x752401ae}},	//   _यज्ञ_, _jenj, _kunk, _heiz,
   {{0x67231760,0x752453e2,0x44200051,0x395f00c3}},	//   _menj, _keiz, _hwi_, keus_,
   {{0xdd990044,0x6603100b,0x442061a8,0x200261a9}},	//   нші_, _munk, _kwi_, _tuki_,
   {{0x7dd81408,0x395f091d,0xcfaa0d82,0x69ab0084}},	//   díst, deus_, _قاسم_, _जगजी,
   {{0x3946002d,0x672359c1,0x752401a3,0x442037df}},	//   _scos_, _nenj, _leiz, _mwi_,
   {{0x260600a1,0x386901f2,0x660302d7,0x4420021e}},	//   _संधी_, _šarp_, _nunk, _lwi_,
   {{0x752411c6,0x7dd81eab,0x443961aa,0x2d9c0029}},	//   _neiz, gíst, yrs_, īves_,
   {{0xf1b302da,0x69c061ab,0x4420021e,0x66030453}},	//   יסה_, rnme, _nwi_, _aunk,
   {{0x660361ac,0x99890293,0x6723117f,0xdb1a5c2d}},	//   _bunk, čaš_, _cenj, _aktö,
   {{0xa3d6009a,0x659561ad,0x443900e9,0x672361ae}},	//   िकन_, гану, wrs_, _denj,
   {{0x9f582d8d,0x660361af,0x443900ea,0x442024fc}},	//   _diré_, _dunk, trs_, _bwi_,
   {{0x4439105d,0x442d0248,0x38660043,0x7dd82cd6}},	//   urs_, ée_, _usor_, líss,
   {{0x61bd178c,0x44200297,0x225a012f,0x672361b0}},	//   ्क्ष, _dwi_, _bppk_, _genj,
   {{0xa2d60e6f,0xf772006c,0x81be0033,0x7dd861b1}},	//   _मुद्, _ماں_, েতন_, níss,
   {{0x7c2d61b2,0x672861b3,0x442002d0,0x7c2b00e9}},	//   šari, ladj, _fwi_, ysgr,
   {{0x25b90009,0xdb0a003e,0x44200088,0x656d0069}},	// [5fd0] misl_, nnfó, _gwi_, _iaah,
   {{0xf0e300c0,0xcebb03fa,0x656d393e,0x672861b4}},	//   _खरीद_, мље_, _haah, nadj,
   {{0x656d02ee,0xdfd801d3,0xa2951645,0xf3f00037}},	//   _kaah, тът_, _сані, _بأي_,
   {{0x7c2b61b5,0x7dd861b6,0xf6530319,0x656d0328}},	//   tsgr, díss, יצע_, _jaah,
   {{0x656d00c3,0x21290ec0,0x7dd860c8,0x40840f2a}},	//   _maah, maah_, víst, _курб,
   {{0xdd030dac,0x656d3c63,0x21292dd4,0x61fd10b1}},	//   ırıl, _laah, laah_, _hisl,
   {{0x61fd61b7,0x7dd861b8,0x672361b9,0x395f61ba}},	//   _kisl, tíst, _renj, teus_,
   {{0x67230f1a,0x7c2b0051,0x656d1a99,0x660361bb}},	//   _senj, psgr, _naah, _runk,
   {{0x61fd4693,0x67230388,0x752461bc,0x660301c8}},	//   _misl, _penj, _reiz, _sunk,
   {{0x660361bd,0x672861be,0x395f61bf,0x212961c0}},	//   _punk, gadj, seus_, haah_,
   {{0x656d030d,0x6723008a,0x44200260,0xcb1200a5}},	//   _baah, _venj, _swi_, _הלב_,
   {{0xe81e0bc1,0x8aa44ed5,0x2d9d003c,0x67230793}},	//   _मौका_, _труд, nkwe_, _wenj,
   {{0x21290034,0x69d961c1,0xd6d40083,0x672361c2}},	//   daah_, _ikwe, _হৃদয, _tenj,
   {{0x61fd61c3,0x660361c4,0x290d002d,0x9f583645}},	//   _aisl, _tunk, lcea_, _tiré_,
   {{0x44200602,0x61fd6167,0xdb030037,0x6d4961c5}},	//   _wwi_, _bisl, ghné, _ocea,
   {{0xd2e400c4,0x290d002d,0x6dbc1a9b,0x2167021d}},	//   _गरीब_, ncea_, nčat, лиси_,
   {{0x31600029,0x6a4a0095,0x44200dc3,0x3f9101ef}},	// [5fe0] reiz_, _həft, _uwi_, _bozu_,
   {{0x6d490012,0xa3cf021a,0x61fd1b42,0x33661f7e}},	//   _acea, षकः_, _eisl, _свог,
   {{0x52765eca,0x69d909d6,0x3f9161c6,0x656d0054}},	//   _супу, _okwe, _dozu_, _yaah,
   {{0x5bdc01d1,0x6dbc0097,0x69d961c7,0x7dd80a4f}},	//   यत्व, jčat, _nkwe, víss,
   {{0xa3ab007c,0x6ed40026,0x00000000,0x00000000}},	//   _खतम_, _बुरु, --, --,
   {{0x437602b5,0x09cc1e82,0x0a6a0f36,0x69d961c8}},	//   רײַן_, ाव्य, ерии_, _akwe,
   {{0xad5a61c9,0x00000000,0x00000000,0x00000000}},	//   _прах_, --, --, --,
   {{0x6d490082,0x7bc361ca,0x383400ca,0x7dd861cb}},	//   _gcea, annu, анир, ríss,
   {{0xfce307bc,0xa2d60653,0x656d0421,0xf0b7016b}},	//   _гото, _मुस्, _raah, ָליר_,
   {{0x3857004f,0x69d90024,0x656d61cc,0x7dd80176}},	//   اشيد_, _ekwe, _saah, píss,
   {{0x672861cd,0x7fd702b5,0x764161ce,0x656d0328}},	//   radj, רויס_, guly, _paah,
   {{0xceb30052,0x672861cf,0xdb01000d,0x6a4a013b}},	//   מית_, sadj, _allè, _dəft,
   {{0xa3c000a1,0xdb180132,0x656f1ab9,0x249f0093}},	//   ंचं_, vivê, rdch, áum_,
   {{0x656d61d0,0x644f61d1,0x60dd00ee,0x00000000}},	//   _waah, rtci, _rysm, --,
   {{0x61fd61d2,0x6dbc61d3,0xdb970070,0x3f910124}},	//   _pisl, nčas, נדלט_, _rozu_,
   {{0x7059005f,0x80d30083,0xb1151357,0xdb030187}},	//   кабр_, _দৃষ্, рмаш, diný,
   {{0x61fd61d4,0x60f9325e,0x7bda0f3a,0xf8e2252b}},	// [5ff0] _visl, тная_, _oktu, _परोप,
   {{0xb4c31649,0x9f410037,0x61fd165a,0x6d493818}},	//   ्थी_, lmhú_, _wisl, _scea,
   {{0x6dbc024e,0x80d30033,0x3f9161d5,0x62670c36}},	//   jčas, _দৃশ্, _vozu_, _صادق,
   {{0x7bda61d6,0x61fd000e,0x6dbc156f,0xac192ad7}},	//   _aktu, _uisl, dčas, воду_,
   {{0x7a1100ea,0x6dbc0334,0x8b250c46,0x68e401da}},	//   _māte, včat, адле, _ùidh,
   {{0x69d961d7,0x0ed00099,0x00000000,0x00000000}},	//   _skwe, _तुकड, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a0a0067,0x5fbf06fe,0x00000000,0x00000000}},	//   _tętn, ्वकल, --, --,
   {{0xf09202b5,0x290d0043,0x6dbc00d5,0x0fb9143a}},	//   ַנט_, rcea_, rčat, _आषाढ,
   {{0x76411487,0xe8f6005f,0xe1ff0392,0xb60700d5}},	//   tuly, шлы_, _lió_, _neší,
   {{0x6dbc00cd,0xdb18008d,0x00000000,0x00000000}},	//   mčar, fnvæ, --, --,
   {{0x69d90565,0x58d50133,0xa2d601d1,0x2875037c}},	//   _ukwe, _коет, _मुष्, _выкр,
   {{0xdb0161d8,0xdd1401ba,0x00000000,0x00000000}},	//   _allé, núši, --, --,
   {{0x6dbc0121,0x764100a8,0xa6950274,0xe73912b1}},	//   nčar, puly, _вриј, _рек_,
   {{0xa2d60953,0x412a1129,0x41b61457,0x36690210}},	//   _मुश्, ково_, асат, _райо_,
   {{0xe1ff01f7,0xdb180031,0xd9f7021a,0x00000000}},	//   _ció_, tivë, ुदित_, --,

   {{0xa2d60e96,0xe1ff2b39,0x02db0035,0x21673e00}},	// [6000] _मुर्, _dió_, _मुठभ, шити_,
   {{0xef175950,0x2b990118,0x2d8000ea,0xa49b0176}},	//   иму_, _kècu_, ķiem_, rcòt,
   {{0x63bc0ce9,0xe8e2045c,0x9e6650f1,0x433b1804}},	//   mirn, _पर्च, рвед, _בעיב,
   {{0xe1ff01a5,0x6b810107,0x63bc61d9,0x6d4f01fb}},	//   _gió_, _anlg, lirn, _öcal,
   {{0x2ca00514,0x629c0211,0x7d0400ea,0x00000000}},	//   áid_, lyro, žiso, --,
   {{0x63bc003e,0xc47700a5,0x649b076b,0x00000000}},	//   nirn, יתנו_, כסנד, --,
   {{0xead800d8,0x2ca00009,0xeb970d6e,0xdb1800ac}},	//   ымкі_, šid_, риј_, nivé,
   {{0x7c662292,0x63bc1201,0x7d0d0453,0x0c3a0079}},	//   _پارل, hirn, ñast, _لكرة_,
   {{0xa3d604aa,0xbee600a1,0x629c233c,0x63bc61da}},	//   िका_, _करुन_, hyro, kirn,
   {{0x4734392c,0x3dc60024,0x6dbc00f4,0xdb1800be}},	//   щнос, lnow_, pčas, tovõ,
   {{0xeb9703fa,0xa2d60e96,0x6f790070,0x3f790070}},	//   _њих_, _मुल्, אָרג, אָרע,
   {{0x998001c8,0xb86603fc,0x5bb60761,0xdb1800d5}},	//   čių_, _ناتو, _अगुव, divé,
   {{0xb4c3051d,0xdb031d2b,0x5edd0033,0xe1ff445a}},	//   ्थे_, cinó, _বলছে, _rió_,
   {{0xbee60429,0x998901ba,0x63bc003e,0x7bd861db}},	//   _करून_, čať_, girn, novu,
   {{0x79820122,0xe5c700c3,0x443261dc,0x3dc6055c}},	//   _know, _вспо, _evy_, know_,
   {{0x7bd82b4e,0x200f0132,0x00000000,0x00000000}},	//   hovu, ígio_, --, --,
   {{0x644012c3,0x20980733,0x88d80083,0x63bc61dd}},	// [6010] àmit, акты_, দেরক, birn,
   {{0x63bc61de,0x00000000,0x00000000,0x00000000}},	//   cirn, --, --, --,
   {{0xdb180086,0x6dbc13a6,0x7bd839ef,0xe1ff0392}},	//   invä, včar, dovu, _tió_,
   {{0x7db4010b,0x00000000,0x00000000,0x00000000}},	//   осіц, --, --, --,
   {{0x65a6008a,0x3d0f000c,0x8d740934,0x00000000}},	//   _jóha, ाडौं_, تالا, --,
   {{0xda650c74,0xdb030132,0xdcfb00cd,0x1b4900c3}},	//   ماعي, vinó, _unuč, узки_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63bc61df,0x6dbc02c4,0x26c900cd,0xdb030098}},	//   zirn, sčar, _ćao_, mhní,
   {{0xb4c30067,0x7982011e,0x629c0035,0xa2e4018d}},	//   ्थो_, _dnow, zyro, _गर्ज_,
   {{0xf7450202,0x39980093,0x7c2d00f4,0x00000000}},	//   љено, _sést_, šars, --,
   {{0xb8fe009a,0xdce00c0a,0x63bc177a,0xdb0301ef}},	//   _दु_, _pamć, virn, sinó,
   {{0x629c61e0,0xdb032df0,0x00000000,0x00000000}},	//   vyro, cinò, --, --,
   {{0x291f000e,0x63bc0093,0x7ae103c1,0xdce200cd}},	//   mbua_, tirn, _hylt, rdoć,
   {{0xb4e80299,0x629c573c,0xdb1861e1,0xa01b008a}},	//   _भरी_, tyro, tivé, _kröf,
   {{0x63bc61e2,0xd29900d4,0x1db702b4,0x6d5b073a}},	//   rirn, атті_, _आगंत, _obua,
   {{0xdb180248,0xa52600af,0x63bc61e3,0xa06a0279}},	//   rivé, _умид, sirn, лаба_,
   {{0x63bc04c3,0x351b00a5,0x61ef009e,0x629c3189}},	// [6020] pirn, _גופנ, _dhcl, syro,
   {{0x6d5b022e,0x644661e4,0x447700a5,0x65660594}},	//   _abua, muki, _פעיל_, lekh,
   {{0xe29a0eee,0x3dc661e5,0xee3a46c6,0x6d5b0211}},	//   _сан_, tnow_, уне_, _bbua,
   {{0x3f83001c,0x60c900c7,0xa3c00354,0x2b4c009e}},	//   _enju_, _žeme, ंचक_, _scdc_,
   {{0x644661e6,0x98a400ea,0xeb9a1c89,0x61e461e7}},	//   nuki, kamā_, лид_, mlil,
   {{0x2a6c0279,0x7982062c,0x3dc661e8,0x98a400ea}},	//   _psdb_, _snow, snow_, jamā_,
   {{0x6e961168,0x64463776,0x7bd861e9,0x32020118}},	//   _الزا, huki, rovu, _kiky_,
   {{0xd90e0164,0x61e461ea,0x481461eb,0x644661ec}},	//   ریت_, nlil, омис, kuki,
   {{0xa01b01ae,0x320261ed,0x644661ee,0xe8110097}},	//   _eröf, _miky_, juki, _píšť,
   {{0x644661ef,0x61e461f0,0xc3010033,0x7ae10044}},	//   duki, hlil, ্রতি_, _fylt,
   {{0x61e461f1,0xdb18013c,0x9f580176,0x91fa046c}},	//   klil, rnvä, _mirà_, ्दाज_,
   {{0x6446276d,0x320200fe,0x758b0421,0x00000000}},	//   fuki, _niky_, усов_, --,
   {{0x290661f2,0xe89407f5,0x2ec41371,0x64464ab3}},	//   _igoa_, _фаль, वपुत, guki,
   {{0x68e20027,0x00000000,0x00000000,0x00000000}},	//   _iyod, --, --, --,
   {{0xf1a74717,0x6595126e,0xb28400c3,0x6d450009}},	//   бран, _маку, пытк, đhaz,
   {{0x61e400a7,0x644661f3,0x7a1102d4,0x672a0093}},	//   glil, buki, _jāta, _hefj,
   {{0x752f004e,0x32020187,0x644661f4,0xf1941f7c}},	// [6030] macz, _diky_, cuki, чить,
   {{0xdb030037,0xb17b013c,0x752f0035,0x2d840107}},	//   thní, _skåd, lacz, _anme_,
   {{0x9f582dc4,0x660a093f,0x00000000,0x00000000}},	//   _dirà_, _jufk, --, --,
   {{0x752f004e,0xcd2b00d1,0x00000000,0x00000000}},	//   nacz, اسان_, --, --,
   {{0x67380c21,0x660a47ee,0x7ae117ad,0x68e247e7}},	//   _odvj, _lufk, _sylt, _nyod,
   {{0x212b0be2,0x7ae10345,0x2d8403d0,0x29065bad}},	//   _hech_, _pylt, _enme_, _agoa_,
   {{0x64463dec,0x68e261f5,0x7a11009e,0x661808c7}},	//   zuki, _ayod, _bāta, _ntvk,
   {{0x200b025c,0x485900d8,0x68e20107,0x64463ab1}},	//   _kuci_, ароў_, _byod, yuki,
   {{0xb4e80299,0x9f470019,0x660a01ae,0x6d4b011e}},	//   _भरे_, _điên_, _aufk, mgga,
   {{0x61e401d6,0x6d4a06d0,0x20030054,0x200b00c5}},	//   zlil, ılaş, _jiji_, _muci_,
   {{0x200b61f6,0x20030054,0x8aa72f6c,0x61e461f7}},	//   _luci_, _miji_, _урад, ylil,
   {{0x644661f8,0x2019007c,0x212b01ba,0x9f5800de}},	//   tuki, _otsi_, _nech_, _mirá_,
   {{0x92e60083,0x69db01f7,0x201901e8,0x32020036}},	//   _ফলে_, moue, _ntsi_, _riky_,
   {{0xb6a50f78,0x644661f9,0x69db61fa,0x69c9053e}},	//   _милл, ruki, loue, lnee,
   {{0x69c961fb,0x752f004e,0x61e461fc,0x644661fd}},	//   onee, bacz, tlil, suki,
   {{0x69c961fe,0x64460465,0x69db61ff,0x200b2443}},	//   nnee, puki, noue, _buci_,
   {{0x212b6200,0x200306b3,0x200b0034,0x69c900c3}},	// [6040] _dech_, _biji_, _cuci_, inee,
   {{0x61e42209,0x69c96201,0x28ca0577,0x7f866202}},	//   slil, hnee, ापति, غلان,
   {{0x20190086,0xa3e30084,0x200330be,0x6604577e}},	//   _etsi_, _फीट_, _diji_, _kiik,
   {{0xed5a38a6,0x69c913e8,0x9f5841e1,0xa01b013c}},	//   род_, jnee, _dirá_, _bröd,
   {{0x0b8a2d64,0x200b6203,0x3d2b01cb,0x66046204}},	//   иски_, _guci_, شتنی_, _miik,
   {{0x6604087a,0xdce001c0,0xf76705f5,0x00000000}},	//   _liik, _zamě, _غا_, --,
   {{0xada600c3,0x7a11013a,0x6da60b25,0xdee3081b}},	//   _давл, _pāta, _дива, _жори,
   {{0x8c4600f0,0x69c96205,0x69db00a2,0xa9c300d4}},	//   _мебе, gnee, goue, дськ,
   {{0x80dc0083,0x995800b8,0x3f986206,0x2004000d}},	//   _মৃত্, _též_, _koru_, _émis_,
   {{0x69c90103,0x81d00033,0x752f0067,0x00000000}},	//   anee, ষতি_, wacz, --,
   {{0x7a1100ea,0x3f986207,0xf09f01a5,0x69c9006f}},	//   _tāta, _moru_, _ngàn_, bnee,
   {{0x69db00a2,0x00000000,0x00000000,0x00000000}},	//   coue, --, --, --,
   {{0x66040f1a,0xf76f00bf,0x69c00086,0x212b6208}},	//   _diik, رای_, mime, _rech_,
   {{0x212b0ea5,0xfbbc09b4,0x200b6209,0x67ef01b4}},	//   _sech_, ्चिम, _ruci_, tøje,
   {{0x200b1034,0x6d4b014e,0x212b1167,0xdce001c0}},	//   _suci_, ygga, _pech_, _pamě,
   {{0x30151023,0xdb18050a,0x6604010d,0x200300bf}},	//   здар, diví, _giik, _siji_,
   {{0x9abc003c,0x3f98048f,0xd2db0066,0xfbbc0355}},	// [6050] _deċi, _boru_, _मुरझ, ्चाम,
   {{0xa2d632b1,0x69c0620a,0x7bca02c4,0x212b0bf7}},	//   _मुक्, hime, jnfu, _wech_,
   {{0x752d620b,0x69c0620c,0x69c90086,0x6d590107}},	//   _keaz, kime, ynee, tfwa,
   {{0x4429620d,0x69c0620e,0xdd91006c,0x9f5860fd}},	//   _kwa_, jime, رڈز_, _virá_,
   {{0x3f9806a2,0x4429021e,0xd1160122,0x0c2400d4}},	//   _foru_, _jwa_, _מקרה_, дмін,
   {{0xb09a0052,0x4429620f,0xeb960dc8,0xc0b60023}},	//   _הישר, _mwa_, зиш_, _lưỡi_,
   {{0x44296210,0x69c06211,0x69c96212,0x26060380}},	//   _lwa_, fime, tnee, _संगी_,
   {{0x3f980506,0x442901a8,0xa2ce09b1,0xdb030079}},	//   _zoru_, _owa_, _सशस्, ghná,
   {{0x69c96213,0x442902e9,0x66043115,0x69db6214}},	//   rnee, _nwa_, _riik, roue,
   {{0x7c29001e,0x69c96215,0x66046216,0x00000000}},	//   _iwer, snee, _siik, --,
   {{0x44296217,0x69c06218,0x67210c4b,0x7a300037}},	//   _awa_, bime, rblj, _vótá,
   {{0x69c000c9,0x44296219,0x7c29621a,0xf09f0019}},	//   cime, _bwa_, _kwer, _ngào_,
   {{0x660403ad,0xb886008d,0x442933e5,0x316901b7}},	//   _viik, rtíð, _cwa_, deaz_,
   {{0x4429621b,0x394d621c,0xf7711d6c,0xa3b60035}},	//   _dwa_, lges_, _سات_, चों_,
   {{0xa2d60967,0x386d621d,0x4429621e,0x66e2621f}},	//   _मुख्, lwer_, _ewa_, _поша,
   {{0x44290c1f,0x7d091e20,0x7c296220,0x394d6221}},	//   _fwa_, _nges, _ower, nges_,
   {{0x6ed40299,0x44290273,0x79990345,0x00000000}},	// [6060] _बुजु, _gwa_, _moww, --,
   {{0xe45700c2,0x69c041de,0x7d0902ee,0xdb186222}},	//   _צייט_, zime, _ages, tiví,
   {{0xdfcf317b,0x3f9800fb,0xa2e60e05,0x44290107}},	//   ديل_, _voru_, _хонд, _zwa_,
   {{0x24806223,0x69c06224,0x7c296225,0x2102010b}},	//   _krim_, xime, _bwer, _ačiū_,
   {{0x69c06226,0x65765418,0xdca30923,0x3f980324}},	//   vime, _mayh, наци, _toru_,
   {{0x7d096227,0x7c2919c1,0x7fd62659,0x394d02b1}},	//   _eges, _dwer, _хімі, eges_,
   {{0x89d80bdf,0x7c291ebb,0x79990069,0xe9f8010b}},	//   يوتر_, _ewer, _boww, онкі_,
   {{0xdd9203fb,0x394d03db,0x7d090103,0xed571402}},	//   _ثور_, gges_, _gges, _нос_,
   {{0x7c296228,0x752d15a1,0x8c436229,0xbb462dbb}},	//   _gwer, _reaz, _пете, _неак,
   {{0x394d622a,0x69c0622b,0x44290232,0x764818ad}},	//   ages_, sime, _rwa_, tudy,
   {{0x45d5051b,0x442902e9,0x6b88054e,0x69c0622c}},	//   донс, _swa_, _indg, pime,
   {{0x248022b3,0x442902d0,0x6b9a00e2,0x7c290b88}},	//   _brim_, _pwa_, _hotg, _ywer,
   {{0x24802b2e,0x18674419,0xdb0101ef,0xd7fa622d}},	//   _crim_, _наци_, _illá, _лук_,
   {{0x083b0122,0x75ff0080,0xb4bd0ca1,0x442902e9}},	//   _פעול, _mūzi, _आधी_, _vwa_,
   {{0xcfc40083,0xf1a72585,0x316901d7,0xdb0a2127}},	//   ্তান, пран, teaz_, lifó,
   {{0x44292fe7,0x2ba9046c,0x248000d7,0x6b9a213d}},	//   _twa_, _कत्थ, _frim_, _lotg,
   {{0x24801bc5,0x442901d5,0xe53c024b,0x31690b9b}},	// [6070] _grim_, _uwa_, _התחר, reaz_,
   {{0xedc5018d,0xdefb00c3,0x7c2904fb,0x316901ed}},	//   लच्छ, бые_, _rwer, seaz_,
   {{0x7c29622e,0xdb0101ef,0x3ea700b5,0xc7d700a5}},	//   _swer, _ollá, ánt_, לומי_,
   {{0x7c29622f,0x386d053e,0x2349042c,0xddcf0207}},	//   _pwer, ywer_, _اسکی_, žeža,
   {{0xeb991cf7,0x79990b88,0x00000000,0x00000000}},	//   жил_, _roww, --, --,
   {{0x2bdd0d1f,0x1af10033,0xdb0100fe,0x925801df}},	//   यवधा, _চলবে_, _allá, _بشیر_,
   {{0x394d162d,0x386d6230,0x00000000,0x00000000}},	//   tges_, wwer_, --, --,
   {{0x7d090b3e,0x394d6231,0x6b88033b,0xcda900d1}},	//   _uges, uges_, _endg, _بهره_,
   {{0x386d01e4,0x6b9a0282,0x7c29007b,0x00000000}},	//   uwer_, _fotg, _uwer, --,
   {{0x66150187,0x79990118,0xdb01006c,0x394d6232}},	//   ízko, _woww, _ellá, sges_,
   {{0x7bc36233,0x386d0122,0x0f580319,0x2bbc00b4}},	//   minu, swer_, ליזם_, ्चरा,
   {{0x24806234,0x80dd00ab,0xdb1800d5,0x00000000}},	//   _prim_, _मडूं, mivá, --,
   {{0xe73900c9,0x00000000,0x00000000,0x00000000}},	//   _дел_, --, --, --,
   {{0x7bc36235,0xdb0a6236,0x98140037,0x69ce0138}},	//   ninu, lifò, _أبنا, _íber,
   {{0x91e62701,0x98a400c7,0x00000000,0x00000000}},	//   дове, ramą_, --, --,
   {{0x7bc303be,0x24805e87,0x00000000,0x00000000}},	//   hinu, _trim_, --, --,
   {{0x7bc3042d,0x91e30d54,0x213200d7,0x6ac9111b}},	// [6080] kinu, тоте, rayh_, िपुर,
   {{0xdfcf004f,0x7bc36237,0x249f033b,0x00000000}},	//   ليق_, jinu, äume_, --,
   {{0x7bc36238,0xe126140e,0x7e566239,0xa2d6012f}},	//   dinu, _омни, ьтац, _मुच्,
   {{0x261303e6,0x00000000,0x00000000,0x00000000}},	//   _mão_, --, --, --,
   {{0x3ea60080,0x26130019,0x6b9a03bc,0x53d2143a}},	//   ņot_, _lão_, _potg, _सदाश,
   {{0x7bc30839,0x6ac90fbf,0xbf9b00f7,0x9f5900d5}},	//   ginu, िपूर, _quêt, _kusý_,
   {{0x261302e3,0x00000000,0x00000000,0x00000000}},	//   _não_, --, --, --,
   {{0x18740812,0xc80800cc,0x00000000,0x00000000}},	//   егия, _hởi_, --, --,
   {{0xa3c00581,0x7bc3623a,0xb4bd0067,0x00000000}},	//   ूचा_, binu, _आधे_, --,
   {{0x7bc352e6,0x261301a5,0x6b8801b4,0x26070084}},	//   cinu, _bão_, _undg, _सूजी_,
   {{0x26130279,0xae0e00c0,0x6446623b,0x00000000}},	//   _cão_, िदिन_, erki, --,
   {{0xf64f006c,0x26130279,0x7c22623c,0xfaa31c76}},	//   گئی_, _dão_, opor, _шахо,
   {{0x7c22623d,0x6440623e,0x79fb00a5,0x04c91c2d}},	//   npor, šmin, _ולאח, سوسي_,
   {{0xf1bf008a,0x2902010b,0x1af10033,0xfe0e046c}},	//   _smá_, žkas_, _চলতে_, िदास_,
   {{0xa27808f1,0x6446623f,0xdce20225,0x00000000}},	//   мбру_, arki, ydoğ, --,
   {{0x26070755,0x7bc36240,0x250903c5,0x7c226241}},	//   _सूची_, zinu, _عربی_, kpor,
   {{0x7bc36242,0x7c222381,0x7ae80a8c,0x765a128c}},	// [6090] yinu, jpor, _lydt, ltty,
   {{0x7c220e6a,0xc80800e8,0x44392f97,0x645a00af}},	//   dpor, _bởi_, mss_, ătit,
   {{0x2bdd0d91,0x7c22443d,0x44390029,0xc8080023}},	//   यवसा, epor, lss_, _cởi_,
   {{0x44390118,0x38660065,0x7c220298,0x00000000}},	//   oss_, _opor_, fpor, --,
   {{0x44396243,0x7c226244,0x7bc311f0,0x6b656245}},	//   nss_, gpor, tinu, екла,
   {{0xdb1845c2,0x25bc143a,0x765a6246,0x00000000}},	//   tivá, _उष्ण, ktty, --,
   {{0xc80800e8,0x7bc36247,0x38666248,0xdb1a00b5}},	//   _gởi_, rinu, _apor_, _ajtó,
   {{0x2bdd0517,0x7bc36249,0x44390029,0x6446624a}},	//   यवहा, sinu, kss_, yrki,
   {{0x2613051b,0x3179004e,0xf77116e6,0x7bc3624b}},	//   _são_, _masz_, هاد_, pinu,
   {{0x26130279,0xfaa73de2,0xf6250210,0x7c3b04fb}},	//   _pão_, _ошен, ндоо, _ivur,
   {{0x65c60192,0x2a650159,0x443b00a8,0x44390110}},	//   ебна, _uplb_, _avq_, ess_,
   {{0x26130370,0xb17b624c,0x9984004f,0x31790035}},	//   _vão_, _skån, _للمو, _nasz_,
   {{0xa8a70357,0x798b624d,0x160b0035,0xf74500af}},	//   _تصاو, _ingw, _संकर_, _зело,
   {{0x26130370,0x7c3b037b,0x889a00a5,0x00000000}},	//   _tão_, _mvur, _מבני, --,
   {{0x366601d3,0x387f2339,0x80ec0033,0x765a1f2c}},	//   _защо_, lvur_, _কলেজ_, ctty,
   {{0x395f00f6,0x15e80067,0x7d1b007a,0xb4db01f7}},	//   nfus_, _टीचर_, _nfus, rgàr,
   {{0xa0675051,0x65640232,0x25d70070,0x9f8603d0}},	// [60a0] ната_, _ibih, _רופן_, нгад,
   {{0x4420624e,0x7d1b5bd6,0x31ae00ee,0x00000000}},	//   _iti_, _afus, _dýza_, --,
   {{0x2f1500b5,0x7c3b007b,0x6da6538c,0xaadf0e96}},	//   _súgó_, _avur, нижа, _पुलक,
   {{0x7c22116d,0xd1ba00fd,0x44205f17,0x00000000}},	//   tpor, _راجا_, _kti_, --,
   {{0x61e60484,0x7c22624f,0x6564007b,0x7ae8029e}},	//   _ikkl, upor, _mbih, _sydt,
   {{0x44206250,0xa01b06d2,0x798b6251,0xa3d600ab}},	//   _mti_, _krön, _angw, िकट_,
   {{0x38660723,0x69050095,0x395f6252,0xed6300b8}},	//   _spor_, ərdə, ffus_, íží_,
   {{0x7c226253,0x44206254,0x44390343,0xdee36255}},	//   ppor, _oti_, yss_, _соси,
   {{0x442039a7,0x6d4001c2,0xc7c601ee,0xa3e0007c}},	//   _nti_, _idma, есни, तवा_,
   {{0x316000d7,0x656404fb,0x798b3998,0x7ae80345}},	//   hfiz_, _abih, _engw, _tydt,
   {{0x44206256,0xffb702b5,0xb90700ab,0x200a01d5}},	//   _ati_, גליש_, _मु_, _mibi_,
   {{0x7bc1016f,0x200a6257,0x798b0159,0x765a6258}},	//   _zmlu, _libi_, _gngw, rtty,
   {{0x2ca66259,0x07a6625a,0x765a3a29,0x499b00a5}},	//   nyod_, _падн, stty, _משאב,
   {{0x4439625b,0x61d91604,0xb7d70098,0x200a0371}},	//   rss_, भक्ष, _كونا_, _nibi_,
   {{0x6d4001cc,0x4420625c,0x81c90033,0xdce000ea}},	//   _odma, _eti_, _লীগ_, _kamē,
   {{0x443b006d,0x2ca60159,0xdb180196,0x4420625d}},	//   _tvq_, kyod_, livä, _fti_,
   {{0x656f625e,0x200a3182,0x00000000,0x00000000}},	// [60b0] mech, _bibi_, --, --,
   {{0x6d40625f,0xdb010086,0x200a07e5,0x75f600b8}},	//   _adma, _yllä, _cibi_, ráze,
   {{0x644f23d4,0xe3b00286,0xa01b022a,0x645d6260}},	//   luci, _دري_, _grön, ltsi,
   {{0x657d6261,0x656f6262,0x7bc100b8,0x200a0103}},	//   ndsh, nech, _smlu, _eibi_,
   {{0x645d6263,0x644f6264,0x6ac909a8,0x21291034}},	//   ntsi, nuci, िप्र, mbah_,
   {{0x61ed6265,0x200a08a1,0x69c2002a,0xcb6601b8}},	//   llal, _gibi_, _amoe, ваше_,
   {{0x9e356266,0x656f08c7,0x645d00ab,0x644f02d7}},	//   _шевч, kech, htsi, huci,
   {{0x645d6267,0x644f0bc5,0x9f4100da,0x21290200}},	//   ktsi, kuci, kohë_, nbah_,
   {{0x2129046a,0x644f6268,0x656f6269,0xf8ae00e0}},	//   ibah_, juci, dech, يکه_,
   {{0x61ed13b8,0x644f626a,0xa68502ee,0x81d70083}},	//   hlal, duci, влод, িতি_,
   {{0x4420626b,0x21290034,0x628501e8,0x2d9f053e}},	//   _sti_, kbah_, _nrho, _koue_,
   {{0x2d9f20d0,0x2129082d,0x656f626c,0x645d626d}},	//   _joue_, jbah_, gech, ftsi,
   {{0x81d700c8,0x645d626e,0x628500e9,0x33330024}},	//   িতা_, gtsi, _arho, _bexx_,
   {{0xf8b60122,0x4375579f,0x2d9f175d,0x61ed0345}},	//   _בפני_, луст, _loue_, elal,
   {{0x645d4b16,0xf77003c7,0xf1aa0833,0x200a626f}},	//   atsi, _دان_, واره_, _ribi_,
   {{0x200a02d0,0x61ed6270,0x644f374e,0x645d01e8}},	//   _sibi_, glal, buci, btsi,
   {{0x644f4df4,0x44206271,0x628501ae,0x6e3c6272}},	// [60c0] cuci, _uti_, _erho, _svrb,
   {{0x61ed6273,0x2d8d0118,0x68eb2fa1,0x00000000}},	//   alal, _anee_, _mygd, --,
   {{0x2129046a,0x2d9f175d,0x25a0027c,0x733b016b}},	//   bbah_, _boue_, _koil_, _קעטס,
   {{0x90c600d8,0x290f0703,0x25a00009,0x71a6141d}},	//   _абме, _ngga_, _joil_, _рамз,
   {{0x2d9f6274,0x61e40421,0xdb03178f,0xdb180421}},	//   _doue_, moil, chnú, yivä,
   {{0x656f004e,0x61e400c3,0x69c2213d,0xdce00228}},	//   zech, loil, _smoe, _samē,
   {{0x644f0035,0x656f002f,0x25a0009e,0x00000000}},	//   zuci, yech, _ooil_, --,
   {{0x68eb00d4,0xf2d30122,0x656f01dd,0x69340416}},	//   _bygd, יעו_, xech, اکار,
   {{0x656f6275,0x645d50e5,0x64400009,0xdb181130}},	//   vech, xtsi, šmij, tivä,
   {{0x644f0c21,0x2129046a,0x656f2299,0x645d006d}},	//   vuci, zbah_, wech, vtsi,
   {{0xe53518d9,0x61e40086,0x8f370070,0x61ed6276}},	//   лень, koil, כטיג_, ylal,
   {{0x68460de2,0xa01b022a,0xb5a703fe,0x645d6277}},	//   _анда, _bröl, трой, ttsi,
   {{0x656f6278,0x657d3b6b,0x61e46279,0x00000000}},	//   rech, rdsh, doil, --,
   {{0x644f627a,0x645d627b,0x656f627c,0x25a0009e}},	//   ruci, rtsi, sech, _eoil_,
   {{0x656f627d,0x644f0fef,0x2129486a,0x645d1b39}},	//   pech, suci, tbah_, stsi,
   {{0x62850888,0x645d627e,0x81ab0033,0x25a00608}},	//   _vrho, ptsi, কোন_, _goil_,
   {{0x61ed627f,0x2d9f00f7,0x50f52028,0xb1140763}},	// [60d0] rlal, _roue_, узат, рмуш,
   {{0x21296280,0x660d0088,0x6285300b,0x2d8d0051}},	//   sbah_, _hiak, _trho, _snee_,
   {{0xdbdc008a,0x660d6281,0x75f66282,0xe45f00c3}},	//   _ráðh, _kiak, láza, ltö_,
   {{0x61e40037,0x1c393816,0x660d0118,0x9c595cdf}},	//   coil, езды_, _jiak, ешку_,
   {{0x660d0657,0x6009010b,0xef9300f8,0x2d9f3605}},	//   _miak, _užmo, _پیاد, _voue_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68eb054e,0x75f600b5,0xaa560274,0x2d9f0b88}},	//   _sygd, háza, гију_, _toue_,
   {{0x75f60076,0x16191fe0,0x660d00ee,0x77ad01dd}},	//   káza, _नंबर_, _niak, _púxo,
   {{0x76b300a8,0x25a0009e,0x00000000,0x00000000}},	//   məyə, _roil_, --, --,
   {{0xe8f6004b,0x76b30095,0x25a06283,0x660d6284}},	//   ылы_, ləyə, _soil_, _aiak,
   {{0xadc301a5,0x660d022e,0xe5a60c06,0x35a60009}},	//   _giản, _biak, гини, ганг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660d50e0,0x61e46285,0xa78518dd,0xa01b0282}},	//   _diak, voil, _مشغو, _bröm,
   {{0xb8820314,0x69c92f3e,0x00000000,0x00000000}},	//   čítk, liee, --, --,
   {{0x61461e56,0xa01b013c,0x61e400c3,0x2bdb073f}},	//   лева, _dröm, toil, _बदना,
   {{0x660d011e,0x69c90b0d,0x00000000,0x00000000}},	//   _giak, niee, --, --,
   {{0x75f60300,0x61e46286,0x78a96287,0x1f6640b4}},	// [60e0] cáza, roil, nyev, лкам,
   {{0xb358006c,0x649700a5,0x6adf0067,0x61e4064a}},	//   _جیسا_, _עדיף_, _पु्र, soil,
   {{0x4d4a1761,0xaac30864,0x75360051,0x61e41e40}},	//   епен_, _वेलक, _keyz, poil,
   {{0xcd360365,0x00000000,0x00000000,0x00000000}},	//   اراب, --, --, --,
   {{0x799b0051,0xa5b80160,0x8ba600af,0x753600f6}},	//   djuw, _ntγm, лидж, _meyz,
   {{0x443202c7,0xdb08002a,0xdee60ddc,0xeb971403}},	//   _mwy_, _aldá, _боги, лич_,
   {{0xa2ca0bad,0x69c91192,0x00000000,0x00000000}},	//   _हेम्, fiee, --, --,
   {{0xdb08022a,0x69c900ab,0x60c9010b,0x391402c4}},	//   _omdö, giee, _žemi, шмир,
   {{0x443200e9,0x660d6288,0x6fa8021a,0x00000000}},	//   _nwy_, _riak, _गवां, --,
   {{0x473438bb,0x8b6501df,0x75f60355,0x9f580312}},	//   шнос, _نامم, váza, _bhré_,
   {{0x80cb0253,0x69c90051,0x17f70037,0xa3e800ab}},	//   _सेने, biee, درية_, यकन_,
   {{0xe9da00d4,0x7bca6289,0x69c901e4,0xe45f00c3}},	//   _яке_, lifu, ciee, ttö_,
   {{0x2bdb628a,0xe97300d1,0x81ab0033,0x660d021d}},	//   _बदमा, _دهند, কোড_, _viak,
   {{0x4432001e,0x7bca628b,0x75f6628c,0xa01b017b}},	//   _dwy_, nifu, ráza, _fröj,
   {{0x660d013a,0x171b02b5,0x6235628d,0xe45f0086}},	//   _tiak, _אווע, ребу, stö_,
   {{0x44320297,0x161900a1,0x27fc00e2,0x75f61da9}},	//   _fwy_, _नंतर_, _hhvn_, lázn,
   {{0x7bca26e0,0x00000000,0x00000000,0x00000000}},	// [60f0] kifu, --, --, --,
   {{0x7bca000e,0x2489021e,0xd10126d4,0x673a628e}},	//   jifu, _iram_, लेषण_, natj,
   {{0x24890254,0x76b300a8,0xa91d02c4,0x0dcb2123}},	//   _hram_, təyə, ldže, нуди_,
   {{0x248947dd,0x673a628f,0x657f0069,0xd65700a5}},	//   _kram_, hatj, _jaqh, ריאת_,
   {{0xa91d1b8a,0x00000000,0x00000000,0x00000000}},	//   ndže, --, --, --,
   {{0x7bca3a34,0x673a0031,0x00000000,0x00000000}},	//   gifu, jatj, --, --,
   {{0x3f910010,0x2489009e,0x00000000,0x00000000}},	//   _inzu_, _lram_, --, --,
   {{0x13d2052b,0x2489026e,0x39592d20,0x629a00c3}},	//   _सद्भ, _oram_, üss_, ätoi,
   {{0xc795021f,0x2489006f,0x69c96290,0xa91d0254}},	//   арны, _nram_, riee, jdže,
   {{0x3f8100bf,0x4432001e,0xfbd300b5,0x69c96291}},	//   ndhu_, _rwy_, _اتر_, siee,
   {{0x7bfa00c2,0x24896292,0x2c1d0083,0x69c96293}},	//   _ספעצ, _aram_, _নিয়ে_, piee,
   {{0x69330a86,0x24896294,0x4432001e,0x2d9d2a13}},	//   _اکثر, _bram_, _pwy_, njwe_,
   {{0xb4c2074f,0x673a0b88,0x75296295,0xb4c00387}},	//   ्पे_, batj, ñeza, ंछे_,
   {{0xf7710180,0xa01b01ff,0xaaa909b4,0x4aa9021a}},	//   _ذات_, _tröj, _कथाक, _कथाव,
   {{0x2489285d,0xa01b1366,0x75360225,0x00000000}},	//   _eram_, _frök, _teyz, --,
   {{0x31260763,0x24892e40,0x5bd2022e,0x7bca35a7}},	//   рдаг, _fram_, _तद्व, zifu,
   {{0x7bca01d5,0xa91d0009,0x00000000,0x00000000}},	// [6100] yifu, cdže, --, --,
   {{0x6d5b0453,0xee0e0325,0xc43b00a5,0x00000000}},	//   _acua, िद्ध_, _שתיי, --,
   {{0xdb010031,0x75f600d5,0x00000000,0x00000000}},	//   _dolë, názo, --, --,
   {{0xd1b2026b,0x932500f8,0x4c860268,0x00000000}},	//   _بیرک, _پرین, илев, --,
   {{0x272201c0,0xa2ca08b0,0xeb9a0bfa,0x6e29008b}},	//   nční_, _हेत्, кид_, _čebe,
   {{0x6d5b54cf,0xdb016296,0x2a6c009e,0x00000000}},	//   _ecua, _kolè, _ppdb_, --,
   {{0x2d966297,0x7bca6298,0x6e436299,0x673a629a}},	//   _крас, rifu, _мерз, vatj,
   {{0xdca64599,0x7bca629b,0x272200b8,0x3869002d}},	//   _каби, sifu, kční_, _ţara_,
   {{0x673a006c,0xb99700c3,0x7bca34e8,0x1d070279}},	//   tatj, рвых_, pifu, _вети_,
   {{0x07b80514,0x8706027a,0xcb6700af,0x75f61534}},	//   اهدة_, ияне, _вафе_, fázo,
   {{0x2489629c,0x673a57f4,0xdb0100e0,0x00000000}},	//   _sram_, ratj, _nolè, --,
   {{0x588601c8,0xa3c90026,0x2489629d,0xa01b033b}},	//   _выка, लोन_, _pram_, _fröh,
   {{0x39460817,0x54540421,0x00000000,0x00000000}},	//   _idos_, овят, --, --,
   {{0x9f5839d0,0xa91d00cd,0x75f62fb4,0x53340b00}},	//   _miró_, rdže, bázo, жерт,
   {{0x31c7629e,0xdb01404f,0x92020066,0x272200b8}},	//   асав, _colè, लगंज_, ační_,
   {{0x2489629f,0x4e1d0084,0xa5350f78,0x00000000}},	//   _tram_, _बंबई_, _унич, --,
   {{0x753d278b,0xd7aa111e,0x40593181,0xd01110ab}},	// [6110] masz, _चकाच, طلاح_, سلا_,
   {{0x753d00f5,0x2fc700e8,0xdf39004f,0x6d5b62a0}},	//   lasz, òng_, اكات_, _scua,
   {{0x3946010b,0xdb0100bf,0x3ea762a1,0x41b500e0}},	//   _odos_, _golè, ânt_, _همدر,
   {{0x753d00b5,0x673802a7,0xac1962a2,0x00000000}},	//   nasz, _levj, году_, --,
   {{0x2d580fa7,0x629a00a0,0x7a1102d4,0x442b00cc}},	//   ричь_, ätov, _nātr, npc_,
   {{0x6738029d,0x394662a3,0x63a562a4,0xdb0100d5}},	//   _nevj, _ados_, _john, _holé,
   {{0xe1ff0028,0x213901f4,0x753d278b,0xdb010097}},	//   _khó_, _kesh_, kasz, _kolé,
   {{0x2011000e,0x20195b20,0x213901f4,0x63a501ae}},	//   _hizi_, _kusi_, _jesh_, _lohn,
   {{0xdb010b8b,0x0dc862a5,0x39464605,0xe1ff0079}},	//   _molé, _тури_, _ddos_, _mhó_,
   {{0x20190f19,0x291f1111,0x21390055,0x279500c3}},	//   _musi_, scua_, _lesh_, сшир,
   {{0x66e562a6,0x20190118,0xa6c92d1e,0x6738009f}},	//   сона, _lusi_, улна_, _devj,
   {{0x6d593069,0x6b8162a7,0x75f662a8,0x213901f4}},	//   ngwa, _halg, rázo, _nesh_,
   {{0xdb0102e9,0xb0c70084,0xdd7a0070,0x9f580036}},	//   _solè, _रेलग, נטשל, _mirò_,
   {{0x6b81007c,0x272200b8,0xe7392d0c,0xdb010310}},	//   _jalg, rční_, _сек_, _polè,
   {{0x6b8162a9,0x213901f4,0x63a500d5,0x2c6002d0}},	//   _malg, _besh_, _dohn, zòd_,
   {{0xdb0162aa,0xe1ff0019,0x20190ecf,0x75fd00b5}},	//   _colé, _chó_, _busi_, téze,
   {{0x201162ab,0x442b1628,0x212001d6,0xe1ff0037}},	// [6120] _bizi_, cpc_, rcih_, _dhó_,
   {{0x6b81043f,0x201962ac,0xc49b00a5,0xcfaa00e0}},	//   _nalg, _dusi_, _עשית, دارم_,
   {{0x201101d6,0x0e660183,0x764162ad,0xdcfb00ee}},	//   _dizi_, скен, nsly, _dauč,
   {{0x201962ae,0x2c6002d0,0x7e4b00b5,0x6d590273}},	//   _fusi_, tòd_, اسلہ_, ggwa,
   {{0x201962af,0xeb100084,0x9f5807e5,0x20110359}},	//   _gusi_, ाश्त_, _dirò_, _fizi_,
   {{0x6b8162b0,0x2d800187,0x201162b1,0xdcfb063c}},	//   _calg, žie_, _gizi_, _gauč,
   {{0x6b8162b2,0x752406a2,0x37cd0083,0xdb030037}},	//   _dalg, _ofiz, রকার, dhnó,
   {{0x9f583dfe,0xdcfb00d5,0x7a0a06fe,0x00000000}},	//   _girò_, _zauč, _křti, --,
   {{0xa3c9006a,0x6b8162b3,0xa3e801c0,0x321a189a}},	//   लोड_, _falg, यका_, _lupy_,
   {{0xe7d60033,0x752401b7,0xdb030079,0x2fca0207}},	//   হত্য, _afiz, ghnó, _jmbg_,
   {{0x7bdf02e1,0xc986002d,0x95d90279,0x96f862b4}},	//   éque, _гули, идот_, рент_,
   {{0xd6d7142c,0xb86600f3,0x39460009,0xa3ab0026}},	//   сть_, _هاتو, _udos_, कॉन_,
   {{0x753d256c,0xb0c70581,0x63a50097,0x8b0300b8}},	//   rasz, _रेंग, _pohn, ěřen,
   {{0x9f58004f,0x38cb0416,0x75240065,0xdb030098}},	//   _bhrí_, _حامی_, _efiz, chnó,
   {{0x201962b5,0xdb0162b6,0xe1ff01a5,0x753d006c}},	//   _susi_, _polé, _phó_, pasz,
   {{0x63a502bf,0xdcfb042a,0x2011037a,0x201962b7}},	//   _wohn, _sauč, _sizi_, _pusi_,
   {{0x270e0669,0xa91d62b8,0x644062b9,0x656d62ba}},	// [6130] lən_, ndža, ámit, _ibah,
   {{0x44290382,0x20110be2,0x60c90124,0x20190345}},	//   _ita_, _qizi_, _žems, _vusi_,
   {{0x270e0095,0x201162bb,0xdb0100f7,0x81ab0033}},	//   nən_, _vizi_, _tolé, কোষ_,
   {{0x20110054,0x4ac300a1,0x201962bc,0x442962bd}},	//   _wizi_, _वेगव, _tusi_, _kta_,
   {{0xa3bd62be,0x20191246,0xa91d28a2,0x6b81007c}},	//   _आता_, _uusi_, jdža, _palg,
   {{0x1ae200c8,0x442962bf,0x270e0095,0x656d0176}},	//   গেছে_, _mta_, kən_, _lbah,
   {{0x6b8162c0,0xb16e008a,0x4ea400af,0x9f580036}},	//   _valg, _þýði, _ерта, _tirò_,
   {{0x270e0669,0x44290086,0x6b81053e,0xdce90069}},	//   dən_, _ota_, _walg, _eneġ,
   {{0x4429070b,0x6b8162c1,0x3f8362c2,0xdb030079}},	//   _nta_, _talg, _kaju_, thnó,
   {{0x7c290232,0x656d0a74,0xa3ab0026,0x752407e5}},	//   _iter, _abah, कॉम_, _sfiz,
   {{0x442962c3,0x69e701c8,0x36690370,0x64443e16}},	//   _ata_, _людз, шано_, _svii,
   {{0x7c290311,0x3f830ec0,0x96040026,0x8e27010b}},	//   _kter, _laju_, रगेट_, лiкi_,
   {{0xf7452070,0x764115ed,0x69cb1008,0x321a00ee}},	//   _дело, ssly, _imge, _supy_,
   {{0xdce002d4,0x7c2908c7,0x3f8308b7,0x270e013b}},	//   _samī, _mter, _naju_, bən_,
   {{0x442962c4,0x613a62c5,0x628350c3,0xdb1800d5}},	//   _eta_, ичар_, _šnor, jivý,
   {{0x7c2962c6,0x6d490037,0x2fca00d7,0xdb1800ac}},	//   _oter, _ndea, _smbg_, divý,
   {{0x3f830ce8,0xa2ca3874,0x7c2962c7,0x9fca021d}},	// [6140] _baju_, _हेर्, _nter, агаа_,
   {{0x248001d6,0x75f600b8,0x3f830132,0x9f580079}},	//   _isim_, kázk, _caju_, _thrí_,
   {{0x7c2962c8,0x69cb0903,0x3f836207,0xdd1c0187}},	//   _ater, _omge, _daju_, rážo,
   {{0xf53f0c61,0x80cb0099,0x442962c9,0x00000000}},	//   lkår_, _सेवे, _yta_, --,
   {{0xac0a2aa9,0xdca3316d,0x270e00a8,0x6d4900e9}},	//   анда_, маци, zən_, _ddea,
   {{0x270e01c2,0x3f830009,0xa01b013c,0x61f662ca}},	//   yən_, _gaju_, _pröv, llyl,
   {{0x0ef901c8,0x7c2944a7,0x225800be,0x68f5013b}},	//   _гэты_, _eter, nurk_, əzdi,
   {{0xdd9200f8,0x248001cc,0x298a496c,0x6e930934}},	//   _تور_, _osim_, рско_, _تلفا,
   {{0x7c290069,0x31bc00ee,0x00000000,0x00000000}},	//   _gter, _gíze_, --, --,
   {{0x69cb4f7f,0x270e0095,0x37aa135b,0xa91d0b5e}},	//   _emge, tən_, ртин_, rdža,
   {{0x442962cb,0x2d8462cc,0x656d011e,0xa2ca111a}},	//   _sta_, _kame_, _pbah, _हेल्,
   {{0x270e01c2,0x2d8462cd,0x2d8662ce,0x19fa00af}},	//   rən_, _jame_, ndoe_, _тэзь_,
   {{0x2d8462cf,0x270e01c2,0xf9d902b5,0x4429021d}},	//   _mame_, sən_, _פֿעל, _qta_,
   {{0x442962d0,0x98a30274,0x68e203d0,0x2d8433e6}},	//   _vta_, _циље, _ixod, _lame_,
   {{0xf1a71fff,0x24800086,0x3f8362d1,0xd13b01d3}},	//   оран, _esim_, _raju_, иха_,
   {{0x2d8462d2,0x224d62d3,0x442962d4,0x61f900d8}},	//   _name_, ček_, _tta_, ёнаў_,
   {{0x442962d5,0x2bdb1db9,0x31690020,0x1af10083}},	// [6150] _uta_, _बदला, rfaz_, _চলছে_,
   {{0x59ca0084,0xdb1800ac,0x00000000,0x00000000}},	//   ़ोतर, tivý, --, --,
   {{0x3f830ab5,0xdb0762d6,0x2d840c6f,0x00000000}},	//   _vaju_, ülün, _bame_, --,
   {{0x427a00c2,0x127a02b5,0x2d8400a5,0xdce9009f}},	//   _פארג, _פארע, _came_, _jneħ,
   {{0x506403fe,0xfd1001cb,0xc19a00a5,0xdce90024}},	//   _отра, نجه_, _השרי, _mneħ,
   {{0x3209021e,0x447c02b5,0x61ed052a,0xd0fa0067}},	//   lmay_, ינדע, loal, ्धरण_,
   {{0x8d77186e,0x00000000,0x00000000,0x00000000}},	//   _وارا, --, --, --,
   {{0x75f60076,0x32090260,0x2d840122,0xd90f0df3}},	//   rázk, nmay_, _game_, نیا_,
   {{0xa01b0523,0x00000000,0x00000000,0x00000000}},	//   _gröt, --, --, --,
   {{0x3b54083e,0xdb0100ac,0x2d84008b,0x61ed0065}},	//   _окур, _holí, _zame_, hoal,
   {{0x61ed081b,0xdb01053d,0xc9871ec2,0x391505a1}},	//   koal, _kolí, _муди, _емер,
   {{0x69cb345c,0x2480165a,0x25a9024b,0x59ca0067}},	//   _umge, _psim_, _coal_, ़ोदर,
   {{0x60020279,0xdce9022f,0x28f800af,0x75f61534}},	//   lôme, _obeč, _дець_, názi,
   {{0x23270227,0x225862d7,0x00000000,0x00000000}},	//   зори_, turk_, --, --,
   {{0x60020279,0xa91d02c4,0x69db521c,0x41b60382}},	//   nôme, ndžo, onue, псат,
   {{0x248001a9,0x320902b3,0x61ed01d7,0xd5b90029}},	//   _tsim_, gmay_, goal, spār_,
   {{0x2d8462d8,0x55bb0122,0x24802df5,0x66040118}},	// [6160] _rame_, _למקו, _usim_, _ihik,
   {{0x2d84230a,0xdee60ce3,0xb4b800ab,0x25a90223}},	//   _same_, пози, चनी_, _zoal_,
   {{0x644662d9,0xdb012a31,0x61ed24a1,0xa01b013c}},	//   lski, _bolí, boal, _brös,
   {{0x61ed0139,0xdb010132,0xa06a0183,0x1ea90037}},	//   coal, _colí, _лама_, غالي_,
   {{0xa2d400ab,0xdb0162da,0x6ad4112b,0x27460098}},	//   णपक्, _dolí, धप्र, níní_,
   {{0x64460104,0x60c4023c,0x2d84023c,0x7e980987}},	//   iski, mzim, _wame_, _وچار_,
   {{0xdee332a6,0xd35702b5,0x660406a2,0xdb010042}},	//   _зори, ליסי_, _ohik, _folí,
   {{0x497400af,0xa01b315b,0x644662db,0x6edb00a5}},	//   флис, _tröt, kski, _החלפ,
   {{0x60c462dc,0x6d4203d0,0xf98f0037,0x00000000}},	//   nzim, maoa, طبي_, --,
   {{0x25a962dd,0x60020279,0x644610d3,0x00000000}},	//   _soal_, lômb, dski, --,
   {{0xb8f362de,0x32091fd9,0x660405ca,0x25a90176}},	//   _हे_, ymay_, _bhik, _poal_,
   {{0x660462df,0x6446046b,0x1a9b02b5,0x18a601d3}},	//   _chik, fski, _ליבע, _наем,
   {{0xafdb0c71,0x660462e0,0x3a2c0051,0x2b4c008c}},	//   _svøm, _dhik, _htdp_, _kddc_,
   {{0x60c462e1,0x75fd00ac,0x07a3010b,0xa01b017b}},	//   dzim, cézn, _пачн, _orör,
   {{0x25a900be,0xd37801e0,0x6d42023c,0x64460381}},	//   _toal_, ччя_, kaoa, aski,
   {{0x521405f4,0x65bf01d2,0x777a06a2,0x60c4033b}},	//   едст, _bëhe, letx, fzim,
   {{0x765a62e2,0x32090225,0xf1c60066,0x27460098}},	// [6170] luty, rmay_, रोइन, cíní_,
   {{0xdb0131e5,0x61ed62e3,0x777a01a3,0xa3e807df}},	//   _solí, soal, netx, यकः_,
   {{0x4fc41174,0x60c40c2f,0x75fd00ac,0xf3ff021d}},	//   хста, azim, nézo, ltão_,
   {{0xa3c90084,0x00000000,0x00000000,0x00000000}},	//   लोर_, --, --, --,
   {{0x69c062e4,0x8ccd004e,0xf3ff03e6,0xdb0162e5}},	//   dhme, _देशो, ntão_, _volí,
   {{0x765a62e6,0x600200f7,0xeb961761,0xdb080260}},	//   kuty, tôme, диш_, _kodè,
   {{0xa01b62e7,0xdb180097,0x777a0065,0x00000000}},	//   _trös, chví, detx, --,
   {{0xdb0862e8,0x69c0035f,0x644662e9,0x3eae033b}},	//   _modè, ghme, yski, äfte_,
   {{0xdb010132,0x69db62ea,0x7d1b04a9,0x777a01ed}},	//   _bolã, rnue, _igus, fetx,
   {{0x660401d2,0x69c00009,0x46490714,0x777a01ed}},	//   _shik, ahme, озон_, getx,
   {{0x6446006a,0x31bc00d5,0x60c462eb,0x9be401e0}},	//   wski, _líza_, zzim, _чітк,
   {{0x69c062ec,0x644605e2,0xd7f80043,0xdb1a0359}},	//   chme, tski, ală_, _altè,
   {{0xb4b81db9,0x644662ed,0x777a01d7,0x7d1b023c}},	//   चने_, uski, betx, _mgus,
   {{0x765a62ee,0x395f09d8,0xa3c90387,0x7c3b0027}},	//   buty, lgus_, लोल_, _mwur,
   {{0x644662ef,0x66040031,0xe2f800b5,0x27460098}},	//   sski, _thik, سورڈ_, síní_,
   {{0x64463c1a,0x395f62f0,0x7d1b62f1,0x60db00cb}},	//   pski, ngus_, _ngus, _žuma,
   {{0xa06728f3,0x60c40a78,0xa7c600f8,0x61e10138}},	// [6180] мата_, uzim, _رژیم_, élla,
   {{0x7d1b62f2,0x60c459bc,0xe4571804,0xa2b600b4}},	//   _agus, rzim, _קייט_, _उथप्,
   {{0x442002e1,0x21490079,0xa20601e0,0x60c462f3}},	//   _hui_, áthú_, _опод, szim,
   {{0x442062f4,0x60260836,0x7c3b0371,0x00000000}},	//   _kui_, _одма, _bwur, --,
   {{0x75e806d3,0x442000f7,0x798962f5,0x0c7a00bc}},	//   mızd, _jui_, ddew, تصاب_,
   {{0x4420052e,0x7d1b01ed,0x6fc00225,0x00000000}},	//   _mui_, _egus, _böce, --,
   {{0x442062f6,0x69c062f7,0x7c3b08c7,0x6f1c0116}},	//   _lui_, thme, _ewur, _igrc,
   {{0x316062f8,0x442002e1,0x201801d7,0x75e806d3}},	//   ngiz_, _oui_, _hiri_, nızd,
   {{0xf4d900c8,0x6d4062f9,0x201862fa,0xdb0802e1}},	//   _সর্ব, _iema, _kiri_, _modé,
   {{0x69c062fb,0x201862fc,0x909b0319,0x765a62fd}},	//   shme, _jiri_, קסיק, tuty,
   {{0x6d400ce8,0x0f570052,0x201862fe,0x777a06a2}},	//   _kema, ויים_, _miri_, retx,
   {{0x6d4062ff,0xadc30019,0x20186300,0x7c202a9d}},	//   _jema, _miến, _liri_, _kumr,
   {{0x44200133,0x6d40120d,0x39445673,0x777a01d7}},	//   _cui_, _mema, mams_, petx,
   {{0xa3c9006a,0x44206301,0x6d4050e0,0xf3ff0370}},	//   लों_, _dui_, _lema, rtão_,
   {{0xf3ff00c9,0xdb010187,0x44200176,0x6d40012f}},	//   stão_, _kolá, _eui_, _oema,
   {{0x6d406302,0x4420365e,0x39441406,0x672d0009}},	//   _nema, _fui_, nams_, _đaji,
   {{0x20186303,0x7c206304,0x5f956305,0xdbd60086}},	// [6190] _biri_, _numr, ниат, _kään,
   {{0x645d6306,0x657d620c,0x20184367,0x6b8802f6}},	//   musi, lesh, _ciri_, _nadg,
   {{0x5d55081b,0x20186307,0x6d4015c5,0x39443cf1}},	//   екет, _diri_, _bema, kams_,
   {{0x62856308,0x657d6309,0x39444cd6,0xdbd63115}},	//   _isho, nesh, jams_, _lään,
   {{0x6d40630a,0x3944630b,0xeb9932f6,0x7c200079}},	//   _dema, dams_, зил_, _cumr,
   {{0x657d5f0c,0x2018630c,0x6d40007c,0xf7890132}},	//   hesh, _giri_, _eema, _maçã_,
   {{0x645d0657,0x6d4000a5,0xadc30023,0x63a801ff}},	//   husi, _fema, _giến, ödni,
   {{0x6d40630d,0x657d16b3,0x645d3bdc,0xceb20122}},	//   _gema, jesh, kusi, _גיל_,
   {{0x321935e2,0x395f630e,0x657d630f,0x645d6310}},	//   _misy_, rgus_, desh, jusi,
   {{0x6b881722,0x6d400d77,0x44206311,0x645d6312}},	//   _gadg, _zema, _rui_, dusi,
   {{0x44206313,0xf1bf0370,0x79a71e31,0x6d406314}},	//   _sui_, _olá_, _орде, _yema,
   {{0x32190964,0x4420002d,0x39446315,0x6d406316}},	//   _nisy_, _pui_, cams_, _xema,
   {{0x44206317,0x645d6318,0x62850010,0x26c56319}},	//   _qui_, gusi, _asho, szlo_,
   {{0x442000e8,0x66e5631a,0x43750b46,0xf1bf631b}},	//   _vui_, _пола, куст, _alá_,
   {{0xe2973f97,0xf7700164,0x645d01c8,0x61e90a78}},	//   нар_, _خان_, ausi, čeln,
   {{0x657d0602,0x2018631c,0x4420631d,0x62850282}},	//   cesh, _siri_, _tui_, _dsho,
   {{0x6285024e,0x6d40631e,0x394f631f,0x2f566320}},	// [61a0] _esho, _rema, _mdgs_, етес,
   {{0x047900bf,0x7bc3006d,0xfdcf0033,0x628500cc}},	//   _کلیک_, jhnu, িকোড, _fsho,
   {{0x6d402bab,0x7c206321,0x2018008b,0xdb1a000d}},	//   _pema, _sumr, _viri_, _ulté,
   {{0x10a60945,0x2018035f,0x291d6322,0x6d400031}},	//   _зимн, _wiri_, _ngwa_, _qema,
   {{0x7c20012f,0x62856323,0x6b880b88,0x3944010b}},	//   _qumr, _zsho, _padg, vams_,
   {{0xf09f098b,0xadc300e8,0x7bc36324,0xdb015c21}},	//   _ngày_, _tiến, ghnu, _solá,
   {{0x6d40542c,0x657d6325,0x39442686,0x645d2a47}},	//   _tema, yesh, tams_, zusi,
   {{0x7bc3016f,0xdbd60086,0xc5f90029,0x75fd00b5}},	//   ahnu, _sään, ntēt_, tézm,
   {{0x39446326,0x657d6327,0x7bc3006d,0xdb016328}},	//   rams_, vesh, bhnu, _volá,
   {{0x7bc302c9,0x95fb0c67,0x645d00d8,0x7648013c}},	//   chnu, ृष्ट_, vusi, tsdy,
   {{0xd6da00d4,0x657d6329,0xdbd618af,0xab6901b2}},	//   яти_, tesh, _vään, _تحقق_,
   {{0x3f8a632a,0xdb180187,0x291d4734,0x45d50ddc}},	//   _labu_, chvá, _ggwa_, томс,
   {{0x7afa632b,0x657d632c,0x8cd62f41,0xe1260033}},	//   _hytt, resh, _मेमो, বরাহ_,
   {{0x5ea60083,0x657d1eec,0x7ae4002d,0xc2c50118}},	//   _গেছে, sesh, şitu, پيري,
   {{0x645d632d,0x657d632e,0x61e11725,0x7afa1736}},	//   susi, pesh, éllo, _jytt,
   {{0x645d2c01,0x657d01f4,0x61e9632f,0x00000000}},	//   pusi, qesh, čelo, --,
   {{0x7afa0c61,0x3f8a6330,0x62850069,0x21290009}},	// [61b0] _lytt, _babu_, _wsho, rcah_,
   {{0x62850189,0x644d010b,0x60020132,0x2a720067}},	//   _tsho, _ivai, tôma, łyby_,
   {{0x62850010,0x7afa0044,0x88d40033,0x8e990037}},	//   _usho, _nytt, _হুমক, بناء_,
   {{0x644d010b,0x00000000,0x00000000,0x00000000}},	//   _kvai, --, --, --,
   {{0x7bc36331,0x644d00f6,0xdde20160,0x00000000}},	//   thnu, _jvai, _ţuţu, --,
   {{0x7afa02df,0x823400f8,0xd9c90026,0x3f8a6332}},	//   _bytt, _جریا, िफ्ट, _gabu_,
   {{0xa91d00d8,0x68fc0095,0xf9910037,0xda621eb9}},	//   ldži, ərdi, لبة_, авщи,
   {{0x597501c8,0x644d6333,0xa91d010b,0x7afa3049}},	//   тыку, _ovai, odži, _dytt,
   {{0xa91d00d8,0xa3d10066,0x3f8a0159,0x644d009e}},	//   ndži, वफा_, _yabu_, _nvai,
   {{0xa91d010b,0x752d0207,0x2be80067,0xd047013b}},	//   idži, _afaz, _जदयू_, çməs,
   {{0x644d6334,0xd7090086,0x7bc16335,0xa2d10026}},	//   _avai, ьное_, _illu, _डेल्,
   {{0x2b476336,0x291d0371,0x00000000,0x00000000}},	//   lanc_, _ugwa_, --, --,
   {{0xa91d042a,0x81d70083,0x850c0437,0xb0d00387}},	//   jdži, াকা_, सेंट_, _सेंग,
   {{0x386d0135,0x644d02a7,0x2b476337,0x69e300cd}},	//   mter_, _dvai, nanc_, šteđ,
   {{0x3f8a6338,0x386d1229,0x434301d3,0xdb016339}},	//   _rabu_, lter_, ресв, _dolç,
   {{0x3f8a2a62,0x75f600b5,0x386d633a,0x26880079}},	//   _sabu_, rázs, oter_, _أخوي_,
   {{0x386d43f6,0x7bc103ad,0x798b633b,0xa3c22088}},	// [61c0] nter_, _ollu, _magw, ंसद_,
   {{0x4432289c,0x386d633c,0x798b633d,0x00000000}},	//   _ity_, iter_, _lagw, --,
   {{0x386d04ce,0x644d5ca4,0x75f60300,0xadc3055c}},	//   hter_, _zvai, lázq, _chắn,
   {{0x7bc1633e,0x386d633f,0x069602b5,0xf2d300a5}},	//   _allu, kter_, כדעם_, _כעת_,
   {{0x386d3fd5,0xa3c90127,0xdb01013b,0x7afa1eb9}},	//   jter_, लोक_, _yolç, _sytt,
   {{0xa3c2193c,0x44320453,0x75fd00b5,0x386d6340}},	//   ंसि_, _mty_, tézk, dter_,
   {{0xe9e66341,0x3ea36342,0x798b1939,0x2900010b}},	//   кцио, _кирг, _bagw, _šia_,
   {{0x386d04ca,0xa96703fa,0x7bc16343,0x7c260118}},	//   fter_, вића_, _ellu, _ékro,
   {{0x386d6344,0xbc6a06ca,0xa3c200b1,0x798b02b3}},	//   gter_, _زمان_, ंसा_, _dagw,
   {{0x2cc404d4,0xdb0801ba,0x7afa0086,0x00000000}},	//   ırdı_, _hodí, _tytt, --,
   {{0x443200da,0x06d50083,0xa91d00d8,0x386d6345}},	//   _aty_, _সুবি, zdži, ater_,
   {{0x798b030d,0x44320159,0x386d02b1,0x00000000}},	//   _gagw, _bty_, bter_, --,
   {{0x386d6346,0x443201a5,0xdb1800ab,0x798025d1}},	//   cter_, _cty_, rivõ, memw,
   {{0x9f9a007c,0x61e60024,0x7bd86347,0xdb1800ab}},	//   _jääb_, _ajkl, nivu, sivõ,
   {{0x2418325e,0x69c212ba,0xa3c90084,0x21670409}},	//   торы_, _kloe, लोग_, ктаг,
   {{0x11d90082,0x31c46348,0xe7170100,0x200a0024}},	//   روءة_, асув, _בחור_, _ahbi_,
   {{0x349500d8,0xa91d00d8,0x7bd802f8,0xf4870208}},	// [61d0] _сапр, udži, kivu, _руйн,
   {{0xa91d2f6c,0x69c2001e,0xa2830df3,0x7bd8002f}},	//   rdži, _lloe, _پیرو, jivu,
   {{0xa91d6349,0x7bd80097,0x7e2800d8,0xa3c20964}},	//   leže, divu, віча_, ्फर_,
   {{0x386d1d2f,0x1eea0609,0xdb080176,0xdb03033b}},	//   yter_, رونی_, _codí, rknü,
   {{0x386d634a,0x6adb48cd,0x2b47634b,0x115a0070}},	//   xter_, यप्र, tanc_, _אדרע,
   {{0xadc301a5,0x798b010d,0x7aed045e,0x8f6700b5}},	//   _thắn, _sagw, şatm, _جلسے_,
   {{0x69c20d26,0xdfd40c28,0x798b2326,0x2b47023a}},	//   _bloe, _торы, _pagw, ranc_,
   {{0xceb202b5,0x24890a78,0x69c2634c,0xe9692d0c}},	//   _פין_, _osam_, _cloe, хаил_,
   {{0x386d1010,0x5c9901c8,0x7bd8634d,0xa91d025c}},	//   uter_, _якая_, bivu, ježe,
   {{0x7bc1634e,0x798b0173,0x9f58009e,0x1db900a1}},	//   _ullu, _wagw, _bhrù_, _आवडत,
   {{0x2489272d,0xb8fa073f,0x44320035,0x61e90a16}},	//   _asam_, _डे_, _sty_, čelj,
   {{0x386d44c0,0xf41f0086,0x69c2634f,0x3f810031}},	//   pter_, yvät_, _gloe, hehu_,
   {{0x3a250903,0xa01b006c,0x44240019,0x2b45023a}},	//   _hulp_, _csök, êm_, _kelc_,
   {{0xf74500c9,0x3f81025c,0x4852006c,0x2489008c}},	//   _секо, jehu_, _اپوز, _dsam_,
   {{0x24895ca4,0x2b450160,0x00000000,0x00000000}},	//   _esam_, _melc_, --, --,
   {{0xc4866350,0x44326351,0x7bd83772,0x05660142}},	//   _блик, _tty_, zivu, _свин,
   {{0x10a3562d,0xdb086352,0x7bd801d5,0x28d90066}},	// [61e0] битн, _rodí, yivu, _बेमि,
   {{0x351b0122,0x728a0202,0x2bb80803,0xdb0800ac}},	//   _אופנ, _због_, _अवधा, _sodí,
   {{0xdb086353,0x25a0022e,0x79806354,0xee3a6355}},	//   _podí, _knil_, yemw, хне_,
   {{0x65666356,0x2b4501f7,0xa91d02c4,0x6ce631ee}},	//   ngkh, _aelc_, ldžu, ліле,
   {{0x7bd8555c,0x61e46357,0x3200006d,0xdb0805ed}},	//   tivu, mnil, mliy_, _vodí,
   {{0x69c219c1,0x61e41f6f,0x61f6011e,0x9b943e1f}},	//   _sloe, lnil, loyl, рикц,
   {{0x69c26358,0x79800aee,0xed5a00d4,0xa91d022f}},	//   _ploe, temw, _пов_, ježb,
   {{0x61e46359,0x7bd80086,0x48aa30fe,0x75fd021d}},	//   nnil, sivu, етом_, pézi,
   {{0x69c20136,0x61e4635a,0x76aa0095,0x798001d5}},	//   _vloe, inil, məyi, remw,
   {{0x2bf601c8,0x76aa0095,0x61e4635b,0x7980002f}},	//   _сябр, ləyi, hnil, semw,
   {{0x61e4635c,0xa91d177a,0x61f6043d,0x00000000}},	//   knil, veže, koyl, --,
   {{0x25a000f7,0x61e40097,0x9f5f0093,0x00000000}},	//   _cnil_, jnil, ðrún_, --,
   {{0xa91d18b0,0x2fda0159,0xdb08021d,0xfbb8021a}},	//   teže, kipg_, _fodã, _अवाम,
   {{0x61e4635d,0x00000000,0x00000000,0x00000000}},	//   enil, --, --, --,
   {{0xa91d03c9,0x61e40093,0x7bdf000d,0x57fb00a5}},	//   reže, fnil, équi, _רלוו,
   {{0x24890189,0xa91d008b,0x61e4635e,0x11d40037}},	//   _tsam_, seže, gnil, متقد,
   {{0x24890279,0x2d8d0036,0x660d4583,0x4fd550b2}},	// [61f0] _usam_, _raee_, _ihak, ажат,
   {{0xb4c1134b,0x4439635f,0x600b027d,0xf36700af}},	//   ंनी_, mps_, küme, _стин,
   {{0xa3c20461,0x44396360,0xadc300e2,0x644f026e}},	//   ंसर_, lps_, _nhản, lsci,
   {{0x645d0b88,0x80d00fbf,0xe80b111e,0xf65300a5}},	//   orsi, _ठेके, _सीना_, מצע_,
   {{0xdca50923,0xcb69052c,0x644f409c,0x3f81552b}},	//   рали, вале_, nsci, pehu_,
   {{0x44390443,0x644f184f,0x645d11d9,0x660d0118}},	//   ips_, isci, irsi, _lhak,
   {{0xdce90a78,0xdb0100ee,0xadc300e2,0x660d07bd}},	//   _obeć, _holú, _chản, _ohak,
   {{0x39463b52,0x76aa0095,0x644f010b,0xa91d0009}},	//   _ceos_, cəyi, ksci, vežb,
   {{0x6d4b6361,0x60cd6362,0x39461459,0xc9a600c3}},	//   maga, nzam, _deos_, рвые_,
   {{0x6d4b6363,0x660d3370,0x6e270009,0x3a253a74}},	//   laga, _ahak, _kujb, _tulp_,
   {{0x645d29a4,0x660d022e,0x61e46364,0x39466365}},	//   ersi, _bhak, ynil, _feos_,
   {{0x6d4b6366,0x660d0657,0x58d907b0,0xe617002d}},	//   naga, _chak, _идея_, идэ_,
   {{0xe72e0b46,0xdb080037,0x61e46367,0x661f0031}},	//   _ме_, _iodá, vnil, _diqk,
   {{0x6b836368,0x6d4b0232,0x60cd6369,0x660d0065}},	//   neng, haga, dzam, _ehak,
   {{0x6d4b2aaf,0x645d636a,0x2bb8073f,0x6723042a}},	//   kaga, arsi, _अवसा, _ignj,
   {{0x6b832591,0x6d4b636b,0x69c92069,0x61e4002d}},	//   heng, jaga, nhee, unil,
   {{0x6b83636c,0x7524035a,0xdb01636d,0x78a90042}},	// [6200] keng, _igiz, _colú, nxev,
   {{0x6b83636e,0x61e402dd,0x69c95d2b,0xe80b08b6}},	//   jeng, snil, hhee, _सीमा_,
   {{0x76aa01c2,0x6d4b636f,0x61e415ce,0x7f47009f}},	//   təyi, faga, pnil, _dejq,
   {{0x6d4b3da0,0xed5a1129,0x6444030d,0x3c2b008c}},	//   gaga, тод_, _kwii, _bøv_,
   {{0x69c902ec,0x67230528,0x7d092200,0xdd8f017e}},	//   dhee, _ognj, _czes, بون_,
   {{0x6b836370,0x35a80324,0xac070009,0xdb1a314b}},	//   geng, गाड़, анча_, _altá,
   {{0x6d4b0224,0xdee3002d,0xa3be0066,0x237a00d7}},	//   baga, _дори, _आवन_, _mbpj_,
   {{0x6d4b6371,0x69c90051,0x752404fb,0x644f396a}},	//   caga, ghee, _ngiz, ysci,
   {{0x6b835ae8,0xdb081840,0x2d990b06,0x2d970187}},	//   beng, _dodá, _ósea_, ádež_,
   {{0x645d0bde,0x75241ae0,0x660d5eee,0x6b8301d5}},	//   vrsi, _agiz, _shak, ceng,
   {{0x6e200657,0x37a700af,0x60cd6372,0x7bdf00f7}},	//   _kimb, ртын_, zzam, èque,
   {{0x69c90223,0x443951d9,0x6e206373,0xaadb0122}},	//   chee, tps_, _jimb, _בחבר,
   {{0xb4c1006a,0x44390122,0x6e200b4f,0xdddc123c}},	//   ंने_, ups_, _mimb, _aprū,
   {{0x660d034d,0x44396374,0x644f6375,0x13a7006c}},	//   _whak, rps_, rsci, جنسی_,
   {{0xd6270500,0x6d4b429b,0x88e80083,0xdb0135c9}},	//   _које_, yaga, _পরিক, _solú,
   {{0xa91d0c99,0x443902c9,0x6b836376,0x6e206377}},	//   leža, pps_, zeng, _nimb,
   {{0x6d4b56f6,0x6b836378,0x656d0027,0xf8b80835}},	// [6210] vaga, yeng, _icah, ेनिय,
   {{0x60cd6379,0x6d4b637a,0x7d092785,0x667100d1}},	//   rzam, waga, _rzes, _بگیر,
   {{0x6d4b3fb0,0x6b83637b,0x6e20637c,0x60cd004e}},	//   taga, veng, _bimb, szam,
   {{0x4429637d,0x6b83637e,0x656d44d1,0x69c901e8}},	//   _kua_, weng, _jcah, xhee,
   {{0x6d4b637f,0x6b836380,0x44296381,0x7f47006d}},	//   raga, teng, _jua_, _tejq,
   {{0x44296382,0x6d4b3fb0,0x442153eb,0xa91d00cb}},	//   _mua_, saga, _jih_, ježa,
   {{0x44296383,0xdb08024e,0x69c90a75,0x0d670133}},	//   _lua_, _podá, thee, _възм,
   {{0x2bd90fc3,0x6b8309ec,0x6e206384,0x44296385}},	//   _भगवा, seng, _gimb, _oua_,
   {{0x44290514,0x6b831845,0x69c96386,0x3f916387}},	//   _nua_, peng, rhee, _kazu_,
   {{0x6e206388,0x38bc0079,0x7bca033b,0x656d0027}},	//   _zimb, _sárú_, chfu, _acah,
   {{0x44296389,0x7c29112c,0xe61a1682,0x3f91638a}},	//   _aua_, _huer, лдо_, _mazu_,
   {{0x4429638b,0xc3290319,0x3f910124,0x69c040d1}},	//   _bua_, _טו_, _lazu_, ckme,
   {{0x4429638c,0x44210537,0x69d9035f,0x69a4638d}},	//   _cua_, _bih_, _imwe, कारी,
   {{0x4429638e,0x7c290083,0xf771006c,0x6d490260}},	//   _dua_, _muer, _رات_, _leea,
   {{0x4429155d,0x4421638f,0xdb1a008c,0x21a60279}},	//   _eua_, _dih_, _eltæ, бивм,
   {{0xe80b0387,0x7c290173,0x394d6390,0x2fd80118}},	//   _सीता_, _ouer, naes_, _smrg_,
   {{0x0ce200c8,0x4429005d,0x6e205612,0x4421003c}},	// [6220] _বর্ত, _gua_, _rimb, _fih_,
   {{0x43860037,0x316901a3,0x3f910160,0x7d000345}},	//   _الدق, agaz_, _cazu_, _ryms,
   {{0x3f9102c9,0x60020370,0x7e6502c2,0x69d96391}},	//   _dazu_, nômi, guhp, _omwe,
   {{0x237f01cc,0x442901e8,0x7c290bf7,0x6d496392}},	//   đuje_, _yua_, _buer, _ceea,
   {{0x7c290083,0x44296393,0x89d800bf,0x442100d7}},	//   _cuer, _xua_, یوتر_, _yih_,
   {{0x7c290ddb,0x6e20000e,0xac251958,0x69d96394}},	//   _duer, _wimb, іфік, _amwe,
   {{0xc3330122,0x69a40567,0xe80b0726,0x6d49009e}},	//   לוג_, काली, _सीधा_, _feea,
   {{0x7c2900c8,0x3834014d,0xadc30019,0xf8d90066}},	//   _fuer, онир, _thạn, _बेहय,
   {{0xa91d6395,0x8c43271c,0x7c290147,0x7c210185}},	//   teža, _нете, _guer, _filr,
   {{0x44296396,0x7c2f02e1,0x75e800c1,0x69d90103}},	//   _rua_, _écra, sızl, _emwe,
   {{0x44296397,0x7c2901ae,0x248000d7,0x7bc801ef}},	//   _sua_, _zuer, _apim_, _ildu,
   {{0x4429637d,0xceb30052,0x6fc0022a,0x44210703}},	//   _pua_, לית_, _böck, _sih_,
   {{0x442900e8,0xe0df01a6,0xa91d24d4,0xdb010c53}},	//   _qua_, _ceòl_, ležn, _anlè,
   {{0x44290019,0x600b027d,0x00000000,0x00000000}},	//   _vua_, küma, --, --,
   {{0x44216398,0x69d90297,0x3f910035,0x4429055c}},	//   _vih_, _ymwe, _razu_, _wua_,
   {{0x44296399,0x463b00c2,0x6fc001ae,0x3f910116}},	//   _tua_, _געהע, _höch, _sazu_,
   {{0x7bc808ca,0xc6050026,0x442139bb,0xb3eb0082}},	// [6230] _oldu, रतीय_, _tih_, _معدل_,
   {{0x2fc701a5,0x00000000,0x00000000,0x00000000}},	//   óng_, --, --, --,
   {{0x6fc002c9,0x7c29639a,0xa91d025c,0xa3be0006}},	//   _möch, _suer, ježn, _आवत_,
   {{0x7c29639b,0x7bc8639c,0x29d3002d,0xa91d08b7}},	//   _puer, _aldu, nţat_, dežn,
   {{0x7c290aca,0x6d49639d,0x394d0183,0x7bc600c7}},	//   _quer, _veea, vaes_, _įkur,
   {{0xeb99135d,0xda590dfc,0x4034446e,0x00000000}},	//   рик_, ариш_, _херс, --,
   {{0x7c2902b1,0x2d9920d9,0x00000000,0x00000000}},	//   _wuer, _óseo_, --, --,
   {{0x7c29639e,0x08c5639f,0x7bc863a0,0xfbd30088}},	//   _tuer, жбин, _eldu, _کتر_,
   {{0x394d63a1,0x7c2163a2,0x00000000,0x00000000}},	//   raes_, _tilr, --, --,
   {{0xeb9b0ef5,0x29030029,0xaa5900c3,0x87b900af}},	//   _حضرت_, āja_, _вижу_, руит_,
   {{0x6b9c0caa,0x85ea12b1,0x28d91ca8,0xaa95002d}},	//   _órga, идов_, _बेरि, _фиеч,
   {{0x69d963a3,0x78a42b6c,0xe5a60043,0x26cb0067}},	//   _umwe, _šive, цими, ąco_,
   {{0xb8fe0083,0xe91900d4,0x6010081b,0xed5900d5}},	//   _দু_, _тоді_, läme, _mdž_,
   {{0xe7390431,0xa91d00f4,0x7d060b41,0x00000000}},	//   _тек_, ležo, _økse, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8c90e6f,0xa06a174b,0x7bc33315,0xb0c42135}},	// [6240] िनिय, раза_, kknu, लैंग,
   {{0x64560371,0x00000000,0x00000000,0x00000000}},	//   _ivyi, --, --, --,
   {{0xd37b02b5,0x00000000,0x00000000,0x00000000}},	//   _דריט, --, --, --,
   {{0xa3c20299,0xa06a0036,0x2c72001e,0x600b027d}},	//   ंसक_, _кама_, tâd_, rüma,
   {{0xf1b3011d,0x629e0124,0x6ab700b4,0xa3be00be}},	//   _חסר_, _hrpo, _अथॉर, _आवा_,
   {{0xa91d5e51,0x68e40d66,0x629e0124,0x749b016b}},	//   težn, _žido, _krpo, יינפ,
   {{0x3ebe63a4,0x00000000,0x00000000,0x00000000}},	//   _ætt_, --, --, --,
   {{0xa91d008b,0xa3be007c,0xea95010b,0x00000000}},	//   režn, _आवऽ_, яшчэ, --,
   {{0x6d420139,0xc2130122,0xa91d04c3,0xa3bb046c}},	//   mboa, והה_, sežn, _अकल_,
   {{0xc07b02b5,0xa91d1d7d,0x7bc80095,0x629e064a}},	//   סטיש, mežl, _uldu, _orpo,
   {{0xa91d63a5,0x600b00ab,0x2b4c0069,0x00000000}},	//   bežo, kümn, _iedc_, --,
   {{0x6d4263a6,0x6fc0033b,0xe4a70dba,0xda6500ce}},	//   nboa, _wöch, орго, _رامي,
   {{0x2ade00ab,0x629e02ee,0x6fc002b1,0x00000000}},	//   _केतु_, _arpo, _töch, --,
   {{0x6d4263a7,0x00000000,0x00000000,0x00000000}},	//   hboa, --, --, --,
   {{0x0efb02e4,0x623403e6,0x64560027,0x2b4c0160}},	//   _्रेस_, десу, _evyi, _medc_,
   {{0x225e053d,0xc0350214,0x3cdb00ab,0x600b018d}},	//   átka_, знај, _खइले_, gümn,
   {{0x657f0189,0x6d420159,0x00000000,0x00000000}},	// [6250] _ibqh, dboa, --, --,
   {{0xdb1800fb,0xdb210187,0x6d4215d8,0x00000000}},	//   mkvæ, _štít, eboa, --,
   {{0x68e400b8,0x00000000,0x00000000,0x00000000}},	//   _židl, --, --, --,
   {{0x6d4263a8,0xb50f0084,0xb17b1cdb,0x61e902c4}},	//   gboa, _सराय_, _småf, čels,
   {{0xc10511c0,0xd59c02b5,0x8c451e92,0x7bc363a9}},	//   _روسي, יבאל, челе, tknu,
   {{0x2005008d,0x00ba00a5,0x443b26f0,0xf09f021d}},	//   _óli_, _המשמ, _mtq_, _irà_,
   {{0xf1bf63aa,0x6d420260,0xa91d00f4,0x00000000}},	//   _giác_, bboa, težo, --,
   {{0xa91d63ab,0x3e75013c,0x3a2c01ef,0x7bc363ac}},	//   bežl, måt_, _dudp_, sknu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61b8018d,0x7c3b63ad,0x77f70099,0x59a900b8}},	//   _इक्ष, _itur, ुतेक_, काहर,
   {{0x3a2c008c,0x38ca00f8,0x00000000,0x00000000}},	//   _gudp_, لایی_, --, --,
   {{0xca9600a5,0x69dc010b,0x00000000,0x00000000}},	//   _מדעי_, _įreg, --, --,
   {{0xe8ee01d3,0x69cb63ae,0x6d5b023c,0x629e00f4}},	//   _чл_, _ilge, _mdua, _srpo,
   {{0x9f5a01f4,0xf8b600a5,0x889a00a5,0x629e0207}},	//   ropë_, _מפני_, _לבני, _prpo,
   {{0x7c3b03d0,0x515a010b,0x00000000,0x00000000}},	//   _ltur, йшаў_, --, --,
   {{0x7c3b06d3,0xf09f0211,0x629e0506,0x9f840be2}},	//   _otur, _brà_, _vrpo, _köç_,
   {{0x3cdb0299,0x6e3b2b6c,0xdb0163af,0x7c3b04fb}},	// [6260] _खेले_, _čuba, _koló, _ntur,
   {{0x6d5b63b0,0x629e023a,0xb886008d,0x00000000}},	//   _adua, _trpo, lsíð, --,
   {{0x7c3b63b1,0x629e02ee,0x03bb00a5,0x20e2003c}},	//   _atur, _urpo, _הציל, _sħiħ_,
   {{0x600b027d,0xf09f0036,0x26120067,0x1636016b}},	//   lüml, _frà_, _धीमी_, לנער_,
   {{0x629c03bc,0xed4f0088,0x7c3b0069,0x6d5b63b2}},	//   lvro, اپه_, _ctur, _ddua,
   {{0x69cb63b3,0x6d421a47,0xa3cc00ab,0xa91d00cd}},	//   _alge, sboa, लसि_, režl,
   {{0x7c3b036c,0xdb0800ee,0x6d4263b4,0x00000000}},	//   _etur, _hodú, pboa, --,
   {{0x89d81d6c,0x5838002d,0x3e5802d0,0x79890345}},	//   توبر_, озия_, mčt_, geew,
   {{0xa91d5818,0x600b027d,0xe8b80099,0x67d430cc}},	//   ležj, küml, ेनेच, допу,
   {{0x69c501d2,0x37aa1b09,0xdb013207,0x6e2e63b5}},	//   ëher, стин_, _coló, _kubb,
   {{0x23b02923,0xb8860093,0x994a0698,0xbb3b024b}},	//   ञानद, fsíð, _هلال_, _העבי,
   {{0xd6d7021f,0x186a12a2,0x6e2e073a,0x3dc663b6}},	//   яты_, _гади_, _mubb, nkow_,
   {{0x629c0478,0x6e2e617d,0x9f840225,0x07a6622d}},	//   evro, _lubb, _göç_, _надн,
   {{0x64921269,0x481300d4,0x6e2e0260,0x00000000}},	//   džić, _зміс, _oubb, --,
   {{0xa77b00a5,0x3a260107,0x877b011d,0x629c0345}},	//   _הרופ, _kiop_, _האוי, gvro,
   {{0x225f0009,0xdb010359,0xe51a018d,0x00000000}},	//   čuk_, _kolò, नेहि_, --,
   {{0x600b027d,0x81c10033,0x3a260160,0x98af0409}},	// [6270] büml, ্চল_, _miop_, _degė_,
   {{0xa2b51d25,0x6e2e63b7,0xdb0163b8,0x00000000}},	//   _उपप्, _bubb, _molò, --,
   {{0x7c3b63b9,0x6e2e63ba,0x51f918f0,0x25a92069}},	//   _stur, _cubb, _мною_, _knal_,
   {{0x6e2e63bb,0x216703ad,0x628563bc,0xf09f01a5}},	//   _dubb, _этог, _ipho, _trà_,
   {{0x61ed002d,0x320908dd,0xf09f0176,0x00000000}},	//   mnal, mlay_, _urà_, --,
   {{0x2ade0006,0x61ff00a8,0x3e7501ff,0x00000000}},	//   _केहु_, loql, påt_, --,
   {{0x6e2e63bd,0xf8ae00f8,0xdb1801ff,0x6ed500b4}},	//   _gubb, یکه_, jkvä, _येचु,
   {{0x61ed63be,0xa2b51a75,0x3209009e,0x78a42518}},	//   nnal, _उपन्, nlay_, _šiva,
   {{0x7c3b08bd,0xdb0163bf,0x61ed63c0,0x3a2663c1}},	//   _utur, _colò, inal, _diop_,
   {{0x2ba41649,0x62852d2e,0x600b1ca0,0x657d0298}},	//   _गोपा, _opho, kümm, efsh,
   {{0x320908dd,0x628501e8,0x657d63c2,0x59750409}},	//   klay_, _npho, ffsh, _жылу,
   {{0xceb200a5,0x61ed63c3,0x8afa00a5,0xdbd702e2}},	//   דיט_, jnal, _והעי, sääs,
   {{0x3209043d,0xb88600fb,0x61ed0187,0xdcfb0254}},	//   dlay_, rsíð, dnal, _obuč,
   {{0x660e016f,0x225e0501,0xdd1c00ac,0x21390c6f}},	//   _ďaku, átko_, nášo, _afsh_,
   {{0x23270390,0xe2972b20,0x628e01e4,0x3dcd00e9}},	//   дори_, мар_, uwbo, _olew_,
   {{0x61ed63c4,0x32090dc3,0xb686006c,0x629c11ad}},	//   gnal, glay_, _کھیل_, rvro,
   {{0x628563c5,0x41df0099,0x660463c6,0xe45f00b5}},	// [6280] _epho, _नगरस, _ikik, ször_,
   {{0x6e2e3b01,0x7e7b042a,0x320908dd,0x25a963c7}},	//   _pubb, _ćupr, alay_, _znal_,
   {{0x320963c8,0x3dcd63c9,0x6e2e0fef,0xdb08021d}},	//   blay_, _blew_, _qubb, _endê,
   {{0x7f4e63ca,0x3209123d,0xa91d008b,0x047900fd}},	//   _webq, clay_, režj, _بلیک_,
   {{0x61e41243,0x361b0070,0x6604237c,0x00000000}},	//   miil, קונד, _mkik, --,
   {{0x61e4002d,0xdb210038,0x3a26001e,0x8aa609cc}},	//   liil, _štát, _siop_, дрид,
   {{0xa93415eb,0x3f9863cb,0x6604001c,0x00000000}},	//   нейш, _iaru_, _okik, --,
   {{0xa9c302ce,0x61e40043,0xdb0163cc,0x660463cd}},	//   вськ, niil, _polò, _nkik,
   {{0x60d60602,0x3f9863ce,0x394f02ff,0x00000000}},	//   nzym, _karu_, _degs_, --,
   {{0x8c4363cf,0x660463d0,0x61ed05e2,0x3f9851ac}},	//   _рефе, _akik, znal, _jaru_,
   {{0x61e45475,0x320905dd,0x61ed63d1,0xdb1a0055}},	//   kiil, ylay_, ynal, _motë,
   {{0x61e40160,0x2bbe0099,0xdb1a0055,0x62850098}},	//   jiil, ्सवा, _lotë, _rpho,
   {{0x657d63d2,0x61e4002d,0x7c2802a7,0xdb18330b}},	//   rfsh, diil, _kidr, skvä,
   {{0x66040273,0x7c28009f,0x2ba4143a,0x00000000}},	//   _ekik, _jidr, _गोमा, --,
   {{0x5334392c,0x61e463d3,0x7c28303c,0x61ed63d4}},	//   тест, fiil, _midr, tnal,
   {{0x78a21abc,0x61e400af,0xdb1a0279,0x61ed63d5}},	//   _krov, giil, _potê, unal,
   {{0x320963d6,0x3f9849c2,0x752d0332,0xdb1a00da}},	// [6290] rlay_, _baru_, _igaz, _botë,
   {{0xed590537,0xb4cb05a2,0x661d1851,0x3f9863d7}},	//   _može_, लनी_, lmsk, _caru_,
   {{0x61e41eca,0x7982004e,0x3f9863d8,0x3209062c}},	//   biil, _obow, _daru_, play_,
   {{0xafdb01cf,0x61e40043,0x60c401d5,0x78a20282}},	//   _stød, ciil, byim, _orov,
   {{0x7c281b2f,0x394f03bc,0xed590097,0x3f98034d}},	//   _bidr, _regs_, _nože_, _faru_,
   {{0x394f63d9,0x7c2863da,0x644d002f,0x601001ff}},	//   _segs_, _cidr, _mwai, lämn,
   {{0x394f16df,0x7c282fa1,0x7982073a,0x37e40033}},	//   _pegs_, _didr, _bbow, নকার,
   {{0xa91d1615,0xed5900cb,0x752d000e,0x78a23532}},	//   leži, _bože_, _ngaz, _brov,
   {{0xb4be00a1,0xdb1a02d0,0x7c2845bd,0xed5963db}},	//   _इथे_, _lotè, _fidr, _vožd_,
   {{0xdce95dd8,0xed590009,0x61e4002d,0x660463dc}},	//   _ubeđ, _dože_, ziil, _skik,
   {{0x2bac00a1,0xd5e618c3,0x78a263dd,0x6e29023c}},	//   चारा, ежни, _erov, _kieb,
   {{0x58d50970,0xaa644e6d,0x644d073a,0x7d09001c}},	//   _поет, _штук, _bwai, _kyes,
   {{0x69c963de,0x61e4005b,0xdb080260,0x78a24f7e}},	//   mkee, viil, _andè, _grov,
   {{0x79990069,0x6e2902bf,0x69c903ad,0xa91d003a}},	//   _haww, _lieb, lkee, ježi,
   {{0x61e41be8,0x386d63df,0x0cbd00dc,0x3f9800fe}},	//   tiil, luer_, ्नुम, _raru_,
   {{0x6e29004e,0x3f9863e0,0xe126021d,0xdb1a0031}},	//   _nieb, _saru_, емби, _sotë,
   {{0x644d02c7,0x61e40043,0x7d092b6f,0x386d63e1}},	// [62a0] _gwai, riil, _nyes, nuer_,
   {{0x60d6006a,0xe47b0052,0x61e463e2,0x752d012e}},	//   rzym, _צריכ, siil, _zgaz,
   {{0xf1bf0028,0x443201a5,0x61e4002d,0x3f980029}},	//   _giáo_, _huy_, piil, _varu_,
   {{0x3f983540,0x6e29004e,0x799b0fa0,0x7d09001c}},	//   _waru_, _cieb, jduw, _byes,
   {{0x63be33dc,0xdca330ca,0x69c92f3e,0xdb082c27}},	//   _kopn, лаци, dkee, _indé,
   {{0x443200c8,0xdb1a0370,0x69c963e3,0x7d0963e4}},	//   _muy_, _hoté, ekee, _dyes,
   {{0x44325a67,0x78a263e5,0x6e2963e6,0x661d63e7}},	//   _luy_, _srov, _fieb, ymsk,
   {{0x69c911ad,0x799b0430,0x68ed63e8,0x386d0110}},	//   gkee, gduw, _žada, fuer_,
   {{0x386d4c70,0xdb1a0132,0x7999007a,0x443200cc}},	//   guer_, _moté, _daww, _nuy_,
   {{0xdb1a345b,0x00000000,0x00000000,0x00000000}},	//   _loté, --, --, --,
   {{0x644d63e9,0x69c900b9,0x00000000,0x00000000}},	//   _swai, bkee, --, --,
   {{0x78a20021,0x44320122,0xdce00095,0x386d50db}},	//   _trov, _buy_, _hamı, buer_,
   {{0xb4cb006a,0xc4580086,0x94a83b6c,0x6b9a0e5b}},	//   लने_, ниях_, нтра_, _katg,
   {{0x7bca63ea,0x443201a5,0x26c500b8,0x28d908a9}},	//   nkfu, _duy_, bylo_, _बेटि,
   {{0xd6cf63eb,0x44320118,0x6b9a1b4b,0xa91d342c}},	//   _ст_, _euy_, _matg, veži,
   {{0x9b170122,0x6b9a0029,0x752d63ec,0xbbbe0e9b}},	//   תחלה_, _latg, _ugaz, ्सुक,
   {{0x765a01c8,0x6e2963ed,0x200163ee,0x644d012f}},	// [62b0] lsty, _rieb, tohi_, _uwai,
   {{0x7c2f1010,0x6e2963ef,0xdb0863f0,0x69c901d7}},	//   _écri, _sieb, _endé, zkee,
   {{0x6e2963f1,0xa91d030a,0x69c903bc,0x765a63f2}},	//   _pieb, reži, ykee, nsty,
   {{0x7d0963f3,0x2001012f,0x765a63f4,0x44320371}},	//   _pyes, sohi_, isty, _yuy_,
   {{0xeb9963f5,0x69c901e8,0x0cbd01c0,0x00000000}},	//   дил_, vkee, ्नेम, --,
   {{0xf1bf01a5,0x6e290a8d,0x765a63f6,0xf3ff0279}},	//   _hoá_, _wieb, ksty, irão_,
   {{0x6b9a0297,0x386d0118,0x9f050220,0xa3e90324}},	//   _datg, wuer_, _شورو, _मगन_,
   {{0x386d63f7,0x765a63f8,0x7999003c,0x5eda0033}},	//   tuer_, dsty, _qaww, _বুকে,
   {{0x69c906ba,0x24890221,0x780c0099,0x87f9010b}},	//   rkee, _npam_, हतूक_, дэнт_,
   {{0x2d8f63f9,0xf3ff03e6,0x765a03bc,0x69c91b39}},	//   lege_, drão_, fsty, skee,
   {{0x2489614e,0x443201a5,0x63be0e7d,0x497563fa}},	//   _apam_, _suy_, _ropn, _алес,
   {{0x443263fb,0x89370037,0x2d9d63fc,0xf3ff0132}},	//   _puy_, _أعضا, ndwe_, frão_,
   {{0x386d63fd,0x44320028,0x63be00cd,0x88c400d1}},	//   quer_, _quy_, _popn, _متول,
   {{0xd70505e8,0x59a90026,0x765a1b84,0x2d8f63fe}},	//   _изли, काकर, bsty, hege_,
   {{0x63be008d,0xf3ff0183,0xdb1a00f6,0x00000000}},	//   _vopn, arão_, _poté, --,
   {{0x443201a5,0x01632dfa,0xf1bf055c,0x00000000}},	//   _tuy_, иксо, _coá_, --,
   {{0x63be63ff,0xf1bf01a5,0xe45a01c8,0x31725053}},	// [62c0] _topn, _giám_, _ўжо_, rgyz_,
   {{0xe0df009e,0x64466400,0x00000000,0x00000000}},	//   _reòt_, mpki, --, --,
   {{0x6b9a01ae,0x66160355,0x32466401,0x00000000}},	//   _ratg, ůzku, _шенг, --,
   {{0x8c4632ff,0x6b9a0feb,0xdb0820d9,0x6b4e0067}},	//   веде, _satg, _undé, _mógł,
   {{0x6b9a07a7,0xe0d70043,0x6c330037,0x2c0e0099}},	//   _patg, _авя_, لفنا, ितलं_,
   {{0x765a6402,0x9e660580,0x644600c7,0xce340088}},	//   ysty, _لارن, ipki, _موسک,
   {{0x6b9a01a5,0xafe30009,0xdee66403,0xa50f51ba}},	//   _vatg, _торл, _рови, _सर्च_,
   {{0xa2b5065f,0xf1bf0023,0x00000000,0x00000000}},	//   _उपस्, _xoá_, --, --,
   {{0xd7fa005f,0x0c2602c8,0x3e7c6404,0x00000000}},	//   дун_, _аман, lít_, --,
   {{0x765a6405,0x76b80012,0x00000000,0x00000000}},	//   tsty, елор_, --, --,
   {{0x6ae00083,0xdb016406,0x24896407,0xa01b01ff}},	//   _পুরো, _anlæ, _spam_, _spök,
   {{0x25bf05ee,0xed5913b1,0x60102185,0xd94632ff}},	//   ðul_, _koža_, dämm, _реди,
   {{0x765a54b2,0xed59040b,0xe0df01a6,0x00000000}},	//   ssty, _joža_, _leòr_, --,
   {{0xf3ff0279,0x765a6408,0xed5908b7,0x00000000}},	//   rrão_, psty, _moža_, --,
   {{0x59b6112b,0xf2c42294,0x3e7c01c0,0xed592801}},	//   _आचार, астн, jít_, _loža_,
   {{0x64401fca,0xa3cf074f,0x2ba454fe,0xd244002d}},	//   ímic, _शतक_, _गोसा, рэри,
   {{0x21f70484,0x248902c6,0xf194051a,0x00000000}},	// [62d0] għha_, _upam_, шить, --,
   {{0xceeb00b2,0x2d8f6409,0x00000000,0x00000000}},	//   وران_, wege_, --, --,
   {{0xc33202b8,0x2d8f3729,0x69dc00d8,0x5f94027a}},	//   _לוי_, tege_, _įren, рихт,
   {{0xed59068f,0xdb080067,0x3ea100d5,0x00000000}},	//   _boža_, _lodó, rvht_, --,
   {{0x645d2698,0x2d8f640a,0x50f42374,0x2ba407b5}},	//   nssi, rege_, _взят, _गोहा,
   {{0x2d8f3715,0x645d640b,0x00000000,0x00000000}},	//   sege_, issi, --, --,
   {{0xbed50274,0x09e501f5,0x00000000,0x00000000}},	//   _совј, локн, --, --,
   {{0x8d770118,0xdb1a0098,0x00000000,0x00000000}},	//   _جاسا, _altó, --, --,
   {{0x6d59640c,0x645d013a,0x6ce700d4,0x00000000}},	//   mawa, jssi, _ріве, --,
   {{0x6d59640d,0xdb080042,0x279500af,0xe45f0421}},	//   lawa, _codó, ушир, työn_,
   {{0x645d640e,0xdb010279,0x7f550300,0x64b400a8}},	//   essi, _colô, _mezq, _məiş,
   {{0x6d59640f,0x0446199d,0xb17b3ee4,0x00000000}},	//   nawa, лемн, _smån, --,
   {{0x6d4b6410,0x98790070,0xa8790070,0xa91d0207}},	//   ibga, _נאַט, _נאַר, težu,
   {{0x6d59280c,0xadc30019,0x387f01f4,0x60106411}},	//   hawa, _khẳn, mtur_, tämm,
   {{0x35a60036,0x387f362b,0x7bc16412,0x29c305c9}},	//   _байг, ltur_, _molu, _uñas_,
   {{0xdb014b47,0x7bc16413,0x6d596414,0x3e7c6415}},	//   _inlä, _lolu, jawa, vít_,
   {{0x6d596416,0x64a60ffd,0xa0672503,0x26011edf}},	// [62e0] dawa, _сапа, лата_, रवरी_,
   {{0x66066417,0xa4b702b8,0x7bc16418,0x387f003e}},	//   lokk, _עליה_, _nolu, itur_,
   {{0x25b700d1,0x6da66419,0x00000000,0x00000000}},	//   _شهید_, лижа, --, --,
   {{0x6d59641a,0x5bbe012f,0x2bbe09b4,0x3f9c012e}},	//   gawa, ्स्व, ्स्थ, žvu_,
   {{0x7bc1641b,0x387f00da,0x3e7c00b5,0xf64700b5}},	//   _bolu, jtur_, sít_, _گئ_,
   {{0xafe6641c,0xdfd210ab,0x7bc11c1d,0x6606641d}},	//   _согл, _ايس_, _colu, hokk,
   {{0xf6471c64,0xadc301a5,0x6606641e,0x7bc1641f}},	//   _دئ_, _chẳn, kokk, _dolu,
   {{0x656401d2,0x64440103,0x6d5900d7,0x387f008d}},	//   _ndih, _otii, cawa, ftur_,
   {{0xdb081e36,0xdca35300,0xdb01315b,0x7bc16420}},	//   _indí, _лати, _anlä, _folu,
   {{0x7bc16421,0xa09702b5,0x1c1b0437,0x807b0070}},	//   _golu, נדיק_, _पीपल_, עניצ,
   {{0x387f6422,0x96f8235d,0xc9860009,0xe5b5021f}},	//   atur_, тент_, _були, айны,
   {{0xd6d72eb3,0x645d5cf1,0xceb300a5,0x6e2200cc}},	//   уть_, tssi, ציר_, nmob,
   {{0x7bc16423,0xb4c10026,0xdb1a6128,0xdb080098}},	//   _yolu, ूने_, _motí, _todó,
   {{0x645d28e5,0x6444009e,0x6d596424,0x00000000}},	//   rssi, _dtii, zawa, --,
   {{0x6d596425,0xcb370122,0x45d56426,0x66066427}},	//   yawa, ראלי_, _войс, bokk,
   {{0xdb1a6428,0x29d80037,0x66063ffc,0x7a3e005f}},	//   _notí, _déag_, cokk, _ištę,
   {{0x9099027a,0x9f556429,0x6e35011c,0x6d59008c}},	// [62f0] ъват_, ивач, _suzb, vawa,
   {{0xdefb0d36,0x6d59642a,0x3c3902d0,0x6aa81281}},	//   ные_, wawa, _rèv_, _ordf,
   {{0x6d59642b,0x7bc1444a,0xdb1a0300,0x931500f8}},	//   tawa, _rolu, _botí, _خودش,
   {{0x6e22471f,0xdb1a002a,0x387f642c,0x00000000}},	//   gmob, _cotí, ytur_, --,
   {{0x7bc13682,0x6aa80098,0x00000000,0x00000000}},	//   _polu, _ardf, --, --,
   {{0x6d590388,0xadc30023,0x6e350156,0x7bc1013b}},	//   sawa, _phẳn, _tuzb, _qolu,
   {{0x69c20118,0x6e220036,0xdb1a0791,0xdb08021e}},	//   _booe, bmob, _fotí, _sodò,
   {{0x387f642d,0xc9a9071d,0x6e22471b,0x7bc1642e}},	//   ttur_, твие_, cmob, _wolu,
   {{0x7bc1642f,0xa92201d3,0xb17b03d0,0x00000000}},	//   _tolu, одъл, _rmål, --,
   {{0x387f6430,0x06850ddc,0xadc301a5,0xf1f90324}},	//   rtur_, агон, _thẳn, ्कड़_,
   {{0x387f00fb,0x64446431,0x66066432,0x600b0448}},	//   stur_, _stii, tokk, lüms,
   {{0xa2c40437,0x29d80037,0x7d160067,0x00000000}},	//   रहस्, _céad_, żyse, --,
   {{0x89340fab,0x394d6433,0x65640116,0x00000000}},	//   _اعما, mbes_, _vdih, --,
   {{0x394d6434,0xb6a502ce,0xf7450370,0x46a50370}},	//   lbes_, _викл, _теко, _вакв,
   {{0x76431281,0x3f930097,0x00000000,0x00000000}},	//   _utny, dexu_, --, --,
   {{0xb14611eb,0x386d0248,0xa5bb0042,0x34aa0dec}},	//   рнал, orer_, lmón, _авио_,
   {{0x439400af,0x3fe66435,0x6444023c,0x00000000}},	// [6300] _лунӂ, ажав, _utii, --,
   {{0x25a0359d,0x823600bf,0xed591635,0x5276034b}},	//   _hail_, _پردا, _božo_, _куму,
   {{0x386d02c9,0xed5a6436,0x25a06437,0xdb1a00b8}},	//   hrer_, вое_, _kail_, _potí,
   {{0x386d0c71,0x7bc56438,0x25a059e5,0x2d9f099e}},	//   krer_, öhun, _jail_, _caue_,
   {{0x25a040ad,0x2d9f01ed,0x61e10c6f,0xadc300cc}},	//   _mail_, _daue_, ëlle, _chằn,
   {{0xaa666439,0x386d03db,0x76480185,0x25a00284}},	//   атик, drer_, ypdy, _lail_,
   {{0x16060d55,0x15f81fb4,0xf1ca22c7,0x386d5b88}},	//   रवार_, ीवार_, _रवान, erer_,
   {{0x386d0279,0x298a117a,0x7e9b00a5,0x78ad02c4}},	//   frer_, тско_, _בסלו, _šava,
   {{0xb9c30082,0xdb1a03e6,0x386d643a,0x8c4332a6}},	//   تقيي, _botã, grer_, _мете,
   {{0x1ae616bc,0xc6a62746,0xf7b80274,0x3d1b07b5}},	//   _козм, арми, угој_, _बरते_,
   {{0x386d643b,0x25a0643c,0x00000000,0x00000000}},	//   arer_, _bail_, --, --,
   {{0x386d0955,0x29180095,0x25a00284,0xe8ea00af}},	//   brer_, əran_, _cail_, _имед_,
   {{0x25a0515c,0x386d000d,0x00000000,0x00000000}},	//   _dail_, crer_, --, --,
   {{0x25a0011e,0x3f8a0051,0x00000000,0x00000000}},	//   _eail_, _nbbu_, --, --,
   {{0x29d80079,0x25a0024b,0x00000000,0x00000000}},	//   _téad_, _fail_, --, --,
   {{0x3ead1038,0x4423022e,0xdce00260,0xed59023a}},	//   _čet_, smj_, _admč, _rožo_,
   {{0x660d643d,0x7a35010b,0x3f9300ac,0x00000000}},	// [6310] _ikak, _ište, texu_, --,
   {{0x6ab60d53,0x5399643e,0x337501e0,0x2d9f00be}},	//   _अपूर, _своя_, _угор, _saue_,
   {{0x394d00c7,0x660d0103,0x3f9300d5,0x00000000}},	//   ybes_, _kkak, rexu_, --,
   {{0xf2d202b5,0x237f0a78,0x386d0044,0x823413cf}},	//   _זעט_, đuju_, yrer_, _گریا,
   {{0x61ed643f,0x660d0054,0xdca5174b,0x6e3b02c4}},	//   mial, _mkak, сали, _čubu,
   {{0x82340357,0x386d00f7,0xf778003c,0xdb1a0392}},	//   _دریا, vrer_, jgħ_, _botà,
   {{0xf21c0299,0x60cd18f4,0x7a350a78,0xdcfb0254}},	//   _भीड़_, lyam, _ošte, _obuć,
   {{0xadc301a5,0x386d6440,0x82f80122,0x660d6322}},	//   _thằn, trer_, יצוב_, _nkak,
   {{0x60cd251e,0x394d6441,0x386d40ba,0x3cd50426}},	//   nyam, rbes_, urer_, _ужас,
   {{0x386d248d,0x660d4d6a,0x61ed6442,0x60100086}},	//   rrer_, _akak, hial, tämi,
   {{0xe5a6002d,0x61ed6443,0x60cd01d5,0x86980340}},	//   бини, kial, hyam, атят_,
   {{0x60cd01a8,0xed5900b8,0x386d0176,0x00000000}},	//   kyam, _jež_, prer_, --,
   {{0x60cd0010,0xb4c207b5,0xb607008d,0x18696444}},	//   jyam, ंहे_, _sláð, _сали_,
   {{0x43430ece,0x60cd0dda,0xed5900ac,0x660d6445}},	//   зерв, dyam, _lež_, _ekak,
   {{0xa3e90bc1,0x216a0dee,0x4df70167,0x25a06446}},	//   _मगर_, ливи_, ंचाई_, _tail_,
   {{0x463a02b5,0xed59000c,0xa22a6447,0x2619399b}},	//   _געקע, _než_, ужба_, léon_,
   {{0xe3b218dd,0xc2e60033,0xdb1a00d5,0xdfcf01cb}},	// [6320] _فرد_, _খুশি_, _motá, کيل_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed590612,0x6ab6021a,0x00000000,0x00000000}},	//   _bež_, _अपेर, --, --,
   {{0x629e6448,0xed5a0c74,0x261900a2,0x60cd3a34}},	//   _ispo, اشات_, héon_, byam,
   {{0x78ad0009,0x447b0070,0x69db0031,0x60cd04fb}},	//   _šavn, ָנצע, dhue, cyam,
   {{0x50433471,0x8f75010b,0xdb1a0176,0x78bb01ef}},	//   _херб, _мусі, _potà, dxuv,
   {{0xdb1a6449,0x6da6079d,0x7d1b01a3,0xada6081b}},	//   _botá, _лива, _ezus, _лавл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1a0187,0x644001ef,0xb17b362b,0x00000000}},	//   _dotá, ímil, _småk, --,
   {{0x61ed644a,0x660d644b,0x629e0254,0x61fb00f4}},	//   zial, _skak, _ospo, čuli,
   {{0x37a7005f,0xadc30023,0xdb1a00d5,0x4fbb016b}},	//   стын_, _chặn, _fotá, אזיצ,
   {{0x69db310f,0xca370319,0x89a50037,0x00000000}},	//   chue, _הנאה_, _وإنم, --,
   {{0x629e644c,0x6d4201ed,0x261900e0,0x7a3530ec}},	//   _aspo, icoa, béon_, _všte,
   {{0x3d1b0084,0x07a31ac5,0x645600e9,0x61ed0067}},	//   _बरसे_, _начн, _dwyi, wial,
   {{0xd7f8002d,0x98a4027d,0xd9ec0099,0xdb1a00fd}},	//   mnă_, mamı_, _जगात_, _eltö,
   {{0x7a350254,0x60cd644d,0x98a4037a,0x660d08a0}},	//   _ušte, tyam, lamı_, _ukak,
   {{0x629e644e,0xcb410009,0xa2b50253,0x947712f4}},	// [6330] _espo, _bolь, _उपक्, _ادعا,
   {{0x61ed644f,0x60cd01d5,0x629e023a,0xdb1f00fd}},	//   sial, ryam, _fspo, űvés,
   {{0x6e996450,0x61ed0096,0x60cd6451,0x00000000}},	//   рвер_, pial, syam, --,
   {{0x443b01f4,0x44336452,0xdb010132,0x00000000}},	//   _kuq_, _hix_, _falê, --,
   {{0xe0e400d8,0x44330345,0x61fd02a2,0xf1a4004b}},	//   _еўро, _kix_, _ijsl, _эрэн,
   {{0xaa4903e6,0x78ad00cd,0xdb1a00ee,0x00000000}},	//   апка_, _šavo, _sotá, --,
   {{0xdb1a6453,0x41e004bc,0x44336454,0x69db6455}},	//   _potá, _नतमस, _mix_, thue,
   {{0x44336456,0x49c90cd0,0x3cff006d,0x684500af}},	//   _lix_, рлин_, _txuv_, ониа,
   {{0xf771017e,0x7d1b002f,0xc7951ac5,0x6d5b016e}},	//   واد_, _uzus, орны, _ieua,
   {{0x44331bb3,0xf1bf0037,0x16650d13,0x69db0031}},	//   _nix_, _fhág_, овом, shue,
   {{0x6d5b1e2b,0x7c3b6457,0xdb010031,0xa2b522c7}},	//   _keua, _huur, _malë, _उपग्,
   {{0x8c3d0723,0x44336458,0xd7f8002d,0x7c3b1b65}},	//   _arşi, _aix_, ană_, _kuur,
   {{0x7c3b2efa,0x395f6459,0x4433007a,0xdffb39f2}},	//   _juur, maus_, _bix_, ्वाद_,
   {{0x395f645a,0xa3e40461,0x7c3b645b,0x98b20067}},	//   laus_, पों_, _muur, _żyć_,
   {{0x44330248,0x232a1199,0x7c3b2933,0xe29a0268}},	//   _dix_, рови_, _luur, шав_,
   {{0x443b2251,0x395f645c,0x6d5b645d,0x44330310}},	//   _fuq_, naus_, _neua, _eix_,
   {{0x6ab60066,0xdfd2317b,0x629e004e,0x4fea1c89}},	// [6340] _अप्र, وير_, _wspo, аман_,
   {{0x395f645e,0x6e3b00cd,0x69d90103,0xdb010183}},	//   haus_, _čubr, _llwe, _valê,
   {{0x35af1db6,0x69d901a8,0xb4ea14eb,0x2d8d0118}},	//   _जोड़, _olwe, _मधु_, _bbee_,
   {{0x7c3b3440,0x2cad2172,0x395f645f,0xbc4a0274}},	//   _buur, _bred_, jaus_, ачке_,
   {{0x2cad0012,0x395f010b,0xdb0101f4,0x307506d8}},	//   _cred_, daus_, _falë, _нурс,
   {{0xe0fb0122,0x7c3b3440,0x69d96460,0x6d426461}},	//   _כלכל, _duur, _alwe, scoa,
   {{0x98a40092,0x7c210211,0xdcf60225,0x00000000}},	//   vamı_, _dhlr, ğcıl, --,
   {{0x2cad6462,0x395f00d8,0x316001b7,0x7f5c0069}},	//   _fred_, gaus_, naiz_, _herq,
   {{0x2cad6463,0x6e3c6464,0x6141006c,0x7c21009e}},	//   _gred_, _hurb, _háló, _fhlr,
   {{0xd7f8002d,0xa5bb0300,0x69d900fe,0x6d5b0065}},	//   ună_, rmóm, _elwe, _zeua,
   {{0x212701a5,0x443b0484,0x44336465,0xd7f8002d}},	//   ̀nh_, _suq_, _rix_, rnă_,
   {{0x395f01e8,0x7c3b0a4e,0x44336466,0x6e3c6467}},	//   caus_, _yuur, _six_, _murb,
   {{0x7bc80006,0xba290172,0x6fda00a1,0x7a3500c7}},	//   _kodu, _اسلم_, णसां, _išta,
   {{0xdb016468,0x6e3c509d,0x00000000,0x00000000}},	//   _balè, _ourb, --, --,
   {{0x38661953,0x6e3c6469,0x9f840093,0xdb01428c}},	//   _hvor_, _nurb, _röð_, _calè,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0101f4,0x7f5c2c42,0x41b500b5,0x7bda279d}},	// [6350] _palë, _berq, _ہمدر, _oltu,
   {{0x7f5c61b1,0x7658006d,0x644f0443,0x4427009e}},	//   _cerq, _kwvy, mpci, _òn_,
   {{0x7c3b136d,0x6e3c1af7,0xa3b80461,0x2cad0a16}},	//   _suur, _curb, छार_, _sred_,
   {{0x2cad125d,0x6e3c646a,0xed590881,0xee380746}},	//   _pred_, _durb, _koži_, іні_,
   {{0x2fc700e8,0x63a501a2,0x7bc80950,0x395f1397}},	//   ưng_, _kahn, _bodu, vaus_,
   {{0x7bc80043,0xfaa51ba1,0x6e3c027a,0x7c3b03c4}},	//   _codu, зако, _furb, _vuur,
   {{0x63a5646b,0x6e3c646c,0x7bc80254,0x395f646d}},	//   _mahn, _gurb, _dodu, taus_,
   {{0x7c3b646e,0x08c50e9f,0x63a5646f,0x7e650031}},	//   _tuur, збин, _lahn, mshp,
   {{0xdb010736,0x395f6470,0x2cad0bde,0x6e3c0065}},	//   _malé, raus_, _ured_, _zurb,
   {{0x38666471,0x395f6472,0x7afc08b7,0xdb010118}},	//   _dvor_, saus_, _žrte, _lalé,
   {{0x395f00c3,0xe5a66473,0x02ba3e6d,0x394600e5}},	//   paus_, пини, _उपेन, _ffos_,
   {{0xdb010355,0xed590207,0x69d90345,0x00000000}},	//   _nalé, _boži_, _ulwe, --,
   {{0x63a56474,0x993a011d,0xb9c40037,0x670b00b4}},	//   _bahn, _התנה, _تقني, _सुरक_,
   {{0xc87906d3,0x63a5009e,0xdb016475,0x00000000}},	//   muş_, _cahn, _palè, --,
   {{0xc87933ef,0x63a5023a,0x8c1a00a5,0xdb01428c}},	//   luş_, _dahn, מושי, _balé,
   {{0xdb013253,0x7f5c6476,0xdddc0506,0xb466002d}},	//   _valè, _serq, _sprž, _екил,
   {{0x7f5c6477,0x9103027a,0x395d10c3,0x316001b7}},	// [6360] _perq, епте, _mews_, raiz_,
   {{0x2b8f0723,0x6e3c1b0f,0x395d0211,0x63a50282}},	//   nıcı_, _purb, _lews_, _gahn,
   {{0x6e3c0095,0x7bc86478,0x7f5c42ec,0xdb01021d}},	//   _qurb, _rodu, _verq, _falé,
   {{0x395d6479,0xdb014b1d,0x63a53adb,0x568c02b5}},	//   _news_, _galé, _zahn, שטאַ,
   {{0x7bc85ffc,0xc1730052,0xa11600d1,0x60360260}},	//   _podu, _אחר_, _روست, _fņma,
   {{0x6e3c647a,0x00000000,0x00000000,0x00000000}},	//   _turb, --, --, --,
   {{0x80d100c8,0x29d80082,0x395d0069,0x7bc8023a}},	//   _সেপ্, _déan_, _bews_, _vodu,
   {{0x6da334b5,0xada301c8,0x3f9a004e,0x7bc802b1}},	//   _писа, _пасл, lepu_, _wodu,
   {{0x290200da,0xfaf8013a,0xcb6a0336,0x00000000}},	//   çka_, _adīt_, _газе_, --,
   {{0xf1bf00e8,0xfaa63f6b,0x38660051,0x7bda00b9}},	//   _khác_, _назо, _vvor_, _ultu,
   {{0xf1190299,0xadf30026,0x63a5018d,0x04f90033}},	//   _दर्द_, _आगमन_, _rahn, _ঘরের_,
   {{0x63a50ab6,0x3946647b,0x26c25305,0x38661b97}},	//   _sahn, _ufos_, ćko_, _tvor_,
   {{0x80d10083,0x7df500c7,0x63a559f1,0x7a3500f4}},	//   _সেন্, mąst, _pahn, _ušta,
   {{0x3f9a025c,0xddce0069,0x78a20421,0x4247027a}},	//   jepu_, _aqbż, _isov, зхаб,
   {{0x61e10031,0xdb0123bb,0x63a5081b,0x96f700af}},	//   ëllo, _palé, _vahn, _нешт_,
   {{0x067b0d85,0xc2c4004f,0x63a5033b,0xed590116}},	//   _הנהל, ريقي, _wahn, _toži_,
   {{0x62870484,0xdb01647c,0x63a5647d,0x7a0100ea}},	// [6370] stjo, _valé, _tahn, nēta,
   {{0x30142349,0x644d647e,0xe9e20035,0x00000000}},	//   едур, _itai, leźć_, --,
   {{0x7f450110,0xf1bf00cc,0x00000000,0x00000000}},	//   rchq, _chác_, --, --,
   {{0xfe700125,0xf1bf0019,0x660f35e2,0x78a201a0}},	//   ادل_, _giáp_, nock, _osov,
   {{0x0db8004f,0x2b8f00d0,0x656d08c7,0xa3e4046c}},	//   ثالث_, yıcı_, _mdah, पोक_,
   {{0x660f647f,0x395d028b,0xb17b28a6,0x644d0cdf}},	//   hock, _sews_, _blåg, _mtai,
   {{0x2b5e011e,0x656d55a8,0x6e9448d0,0x78a200f4}},	//   _detc_, _odah, _пиру, _asov,
   {{0x656d6480,0x660f0523,0xd2b8011d,0xfaf00833}},	//   _ndah, jock, ללות_, دثه_,
   {{0x644d0221,0x2b8f033e,0x6d496481,0x00000000}},	//   _ntai, tıcı_, _ifea, --,
   {{0x656d04fb,0x2bd900fd,0xe64501af,0xc8796482}},	//   _adah, _بارک_, меоп, ruş_,
   {{0x644d6483,0x9f840006,0x2b8f0644,0xf41f081b}},	//   _atai, _töö_, rıcı_, ttän_,
   {{0xb8f30033,0x8cc1046c,0x7a350409,0x00000000}},	//   _হই_, लमपो, _išto, --,
   {{0x60106484,0x45d300d8,0x656d0024,0x7a0100ea}},	//   kämp, тоўс, _ddah, cēta,
   {{0xe78709c0,0x69cb26c4,0x644d0037,0xdb180093}},	//   _худо, _hoge, _dtai, rkvö,
   {{0x69cb6485,0x644d0248,0xd252026b,0x60101788}},	//   _koge, _etai, ئنر_, dämp,
   {{0xed596486,0x69cb6487,0x3f9a002f,0x644d01da}},	//   _kožu_, _joge, wepu_, _ftai,
   {{0x69cb1cb3,0x3eb101ae,0x2007008b,0xdce9007a}},	// [6380] _moge, _arzt_, čnin_, _ddeċ,
   {{0x249701ca,0x69cb6488,0x6f1a0970,0xe29a0274}},	//   _کنید_, _loge, оцес_, _дао_,
   {{0x29d8004f,0x7a010029,0x69cb0298,0x0d8600c3}},	//   _béal_, zēta, _ooge, длен,
   {{0x69cb4d3e,0x00000000,0x00000000,0x00000000}},	//   _noge, --, --, --,
   {{0xdca305c2,0xac0a0009,0x8c431501,0x9588010b}},	//   каци, онда_, вече, _grąž,
   {{0xdb086489,0xf1bf0019,0xa91d00d8,0xafdb035b}},	//   _indú, _thác_, igžd, _støv,
   {{0x69cb648a,0x1600049c,0xb17b1736,0xfe430210}},	//   _boge, ोकार_, _flåd, _ансо,
   {{0x69cb648b,0x78a21e85,0xdb1a00a0,0xed590207}},	//   _coge, _psov, _kotú, _božu_,
   {{0x69cb0210,0xfcaa103b,0x00000000,0x00000000}},	//   _doge, _بازو_, --, --,
   {{0xb8e606bb,0x6d44016f,0x29180029,0x7a010029}},	//   _उप_, žiad, āra_, rēta,
   {{0x644d648c,0xa3b80066,0xa5bb021d,0x00000000}},	//   _stai, छाई_, imóv, --,
   {{0xa2cd022e,0xd6d70328,0xafdb01e0,0x00000000}},	//   सहस्, фть_, _utøv, --,
   {{0x443f01a5,0x3a26022a,0xb8f30083,0xd943648d}},	//   êu_, _ihop_, _হে_, _речи,
   {{0x69cb648e,0x660f648f,0xacd90070,0x00000000}},	//   _zoge, sock, פֿרי, --,
   {{0x3a2614f3,0x69cb6490,0xa19500d4,0x2607052c}},	//   _khop_, _yoge, навч, _очиг,
   {{0x656d6491,0x78ad0009,0xdb1a0079,0x00000000}},	//   _udah, _šavi, _botú, --,
   {{0x92c100c8,0x644d6492,0xb17b1cdb,0x3f83023a}},	// [6390] ্ছে_, _utai, _smås, _pcju_,
   {{0x25a91516,0x7a256493,0x00000000,0x00000000}},	//   _haal_, móte, --, --,
   {{0x25a96494,0xd35600a5,0xf3ff0132,0x00000000}},	//   _kaal_, _איתי_, lsão_, --,
   {{0x201a027a,0x41d30099,0x2d5800af,0xc05b01e0}},	//   alpi_, _सविस, диць_, _міг_,
   {{0xf3ff0370,0x25a96495,0xe81101c0,0x644b29e0}},	//   nsão_, _maal_, ठकमा_, _égid,
   {{0x69cb22f7,0x7afc0254,0x6a851e38,0xd01b0279}},	//   _soge, _žrta, елка, _ффм_,
   {{0x8d770413,0x41d300ab,0x69cb0160,0xb6060e06}},	//   _يارا, _सवास, _poge, _hláš,
   {{0xb6060187,0xb17b0a8a,0x3a260147,0x00000000}},	//   _kláš, _flåe, _chop_, --,
   {{0x69cb6496,0x2d9d3069,0xe8f909c0,0x799b016e}},	//   _voge, mewe_, яли_, reuw,
   {{0x2d9d6497,0xeb900041,0x69cb0b42,0x612a00b5}},	//   lewe_, _نظم_, _woge, lölé,
   {{0x25a96498,0x69cb6499,0x7ac45a4f,0x7a3500f4}},	//   _baal_, _toge, _исце, _ušto,
   {{0x2d9d0010,0xa95400d4,0xa5bb02d7,0xa50a1a12}},	//   newe_, _акці, zmóv, зема_,
   {{0x25a903bc,0x67d52344,0xdb01649a,0xdb0600b5}},	//   _daal_, _поду, _malí, ümöl,
   {{0xc7a21402,0xdb010042,0x2d9d649b,0xbf1f0099}},	//   _бишк, _lalí, hewe_, _भरून_,
   {{0xcb1202b5,0xb7da0122,0x41b61765,0x25a901d9}},	//   ָלן_, _מקסי, нсат, _faal_,
   {{0x25a9649c,0x6723649d,0xdb0100ac,0xb17b038d}},	//   _gaal_, _iznj, _nalí, _smår,
   {{0x656600d7,0x34b3004f,0x69c000a1,0x602603e6}},	// [63a0] makh, _مميز, वाती, едаа,
   {{0x6566649e,0xdee62f4c,0x7524007b,0x25a901e4}},	//   lakh, нози, _iziz, _zaal_,
   {{0x24460028,0xee3a3649,0xdb01024e,0xb17b01b4}},	//   _hôm_, чне_, _balí, _slåe,
   {{0xafdb1123,0x443a15b7,0x2d9d649f,0xdb010138}},	//   _støt, _hip_, gewe_, _calí,
   {{0xf1bf0019,0x61f6027d,0xdb0100d5,0x61e4026e}},	//   _khán_, miyl, _dalí, mhil,
   {{0x3a2606b5,0xfaa608ae,0x3d2b0118,0x443a64a0}},	//   _shop_, ешин, ستنی_, _jip_,
   {{0xed5a01b8,0x2d9664a1,0x65660159,0x79800298}},	//   _нов_, _прас, kakh, tgmw,
   {{0x660454b5,0x61e464a2,0x61f6027d,0xdb0101f7}},	//   _njik, nhil, niyl, _galí,
   {{0x7e7e64a3,0x7524041b,0x656600d6,0x244600e2}},	//   lupp, _nziz, dakh, _nôm_,
   {{0xa5bb433e,0x25a964a4,0x66041845,0x443a64a5}},	//   ológ, _saal_, _ajik, _nip_,
   {{0x7524046d,0x7e7e01ff,0x25a964a6,0x69c000b8}},	//   _aziz, nupp, _paal_, वादी,
   {{0x7c3a108a,0x48e60f8c,0xc8a800be,0x2446055c}},	//   _hitr, _поев, _कनपट, _bôm_,
   {{0x99e904e8,0x61e40054,0xf41f0523,0x25a903bc}},	//   _تعلق_, dhil, stäm_, _vaal_,
   {{0xf3ff0370,0xf8b31899,0x443a64a7,0xf1bf0019}},	//   rsão_, _תשס_, _cip_, _chán_,
   {{0x7c3a64a8,0xf3ff00c9,0x25a90136,0x752464a9}},	//   _mitr, ssão_, _taal_, _eziz,
   {{0x7c3a64aa,0xda100e6f,0x61e464ab,0x20071851}},	//   _litr, ावित_, ghil, čnim_,
   {{0x2c20012f,0x20980104,0x248900a2,0x522400af}},	// [63b0] यतां_, нкты_, _uqam_, уфра,
   {{0x7c3a64ac,0x251c00c2,0x661d64ad,0xdb0100de}},	//   _nitr, _צוזא, llsk, _salí,
   {{0x2d9d0010,0x61e464ae,0x63ad00ea,0x7e7e017b}},	//   tewe_, bhil, ļinā, gupp,
   {{0x61e464af,0x7c3a64b0,0xdb1a64b1,0x443a3c8f}},	//   chil, _aitr, _intè, _zip_,
   {{0xdca5195a,0x2d9d64b2,0xdb010138,0xdb0800f6}},	//   тали, rewe_, _valí, _hadè,
   {{0x7c28009e,0xeb961e46,0x443a0392,0xdb0864b3}},	//   _chdr, виш_, _xip_, _kadè,
   {{0x7c3a64b4,0x2fc70093,0x2d9d002f,0xed590116}},	//   _ditr, öngu_, pewe_, _anže_,
   {{0x7c3a64b5,0xdb0800f6,0x00000000,0x00000000}},	//   _eitr, _madè, --, --,
   {{0x7c3a64b6,0x6d592f7e,0xdb010132,0x6d4400a0}},	//   _fitr, mbwa, _balã, žiac,
   {{0x7c3a043d,0xdb010183,0x6566034d,0x6e3b009e}},	//   _gitr, _calã, wakh, _hiub,
   {{0x65661ea7,0xba740609,0x61e402ee,0xe7390279}},	//   takh, _مانت, yhil, ќен_,
   {{0x7d1b3588,0xdd990260,0x7c3a64b7,0x75e60067}},	//   _kyus, _akňz_, _zitr, _mózg,
   {{0x65660f1a,0xf1bf0019,0x60c464b8,0xdb1a0359}},	//   rakh, _phán_, xxim, _antè,
   {{0x443a0069,0x6b8364b9,0x656601e0,0xe81907b5}},	//   _qip_, ngng, sakh, _नीचा_,
   {{0x443a64ba,0x61e463fe,0xdb080176,0xf1bf0023}},	//   _vip_, thil, _cadè, _cháo_,
   {{0x66042edd,0x24460019,0x6e3b1ccb,0x69c964bb}},	//   _ujik, _tôm_, _niub, njee,
   {{0xa06764bc,0xdb1a0c1f,0xe0431d40,0x7d1b64bd}},	// [63c0] ката_, _entè, инти, _nyus,
   {{0x764315c4,0x61e464be,0xafdb0b41,0x61f62c7c}},	//   _kuny, shil, _stør, siyl,
   {{0x7c3a64bf,0x7d1b0dc3,0x387f64c0,0x656464c1}},	//   _ritr, _ayus, huur_, _keih,
   {{0x7e7e1e54,0x973c03fa,0x764322e5,0xf7670987}},	//   rupp, meće, _muny, _ھا_,
   {{0xdd8f517b,0xdc2a00f8,0xdb1a64c2,0x6e3b64c3}},	//   تون_, وسته_, _inté, _diub,
   {{0xfbcf026e,0x656464c4,0xdb0101f7,0x387f0a43}},	//   قتى_, _leih, _balà, duur_,
   {{0x628e64c5,0xdb0813cf,0xdb010176,0x9aa30037}},	//   ntbo, _kadé, _calà, لموو,
   {{0x6e3b64c6,0xdb0103e6,0x225e053d,0x7c3a0035}},	//   _giub, _salã, átky_, _witr,
   {{0x7c3a64c7,0x8c460ece,0x6d4001a2,0x77632984}},	//   _titr, _резе, _igma, _benx,
   {{0x764364c8,0x7c3a03c4,0x00000000,0x00000000}},	//   _buny, _uitr, --, --,
   {{0x973c0254,0x764301f7,0xdb010310,0xdce900ea}},	//   jeće, _cuny, _galà, _ideā,
   {{0x764364c9,0x973c0a78,0x7a250035,0xdb0801cb}},	//   _duny, deće, rótc, _radè,
   {{0x661d013c,0x628e64ca,0x6d40010d,0x64440118}},	//   rlsk, etbo, _mgma, _cuii,
   {{0x200702dd,0xdb01006c,0x201800e7,0xdb1a64cb}},	//   čnik_, _halá, _nkri_, _anté,
   {{0x569464cc,0x6d4002e9,0xdce20009,0x179b00a5}},	//   _сайт, _ogma, daoč, _חיוב,
   {{0x291801d6,0x6d40010d,0x656401ed,0x6444021d}},	//   ğraf_, _ngma, _geih, _fuii,
   {{0x6234002d,0x628e00ee,0x7a2501ef,0xa5bb29e3}},	// [63d0] рету, atbo, nóta, rlód,
   {{0xa5bb0082,0xdb1a08bf,0xdefb0086,0x6e2964cd}},	//   slód, _enté, мые_, _sheb,
   {{0x628e012f,0xf7730319,0x6f1c016e,0x7d1b00e0}},	//   ctbo, שקע_, _cyrc, _syus,
   {{0x20180c1f,0xf1bf01a5,0x201301ef,0x6e3b0069}},	//   _ekri_, _khám_, soxi_, _qiub,
   {{0xbc1901c8,0x6d400176,0x7a25008d,0xf1bf00a0}},	//   нікі_, _dgma, jóta, _iná_,
   {{0xe5041ae9,0x7a3500d8,0x387f1e7e,0xdb010176}},	//   रपति_, _išti, vuur_, _palà,
   {{0xfb8400d8,0xbe8803fa,0xdb0164ce,0x6e3b0079}},	//   рычн, _исте_, _balá, _tiub,
   {{0x387f1c45,0xf8a93997,0xc3340d85,0x764304fb}},	//   tuur_, евик_, סוק_, _runy,
   {{0x69c900c3,0x656401ae,0xf1bf64cf,0x69db0031}},	//   rjee, _reih, _mná_, rkue,
   {{0x68e9006a,0x764364d0,0x387f0345,0x47c51a56}},	//   rzed, _puny, ruur_, убов,
   {{0x200702dd,0x49751c6b,0x68e9256c,0xaa5500ed}},	//   čnih_, _блес, szed, _свеш,
   {{0x26191010,0x7a25008d,0x00000000,0x00000000}},	//   déos_, bóta, --, --,
   {{0x973c0b16,0x69c03010,0xdb1a0097,0x2bc70517}},	//   veće, वारी, _motý, लापा,
   {{0x656401ae,0x394d64d1,0x386d4486,0xf1bf0211}},	//   _weih, lces_, mser_, _aná_,
   {{0xe2972526,0x386d31cb,0x973c0a78,0x76431187}},	//   лар_, lser_, teće, _uuny,
   {{0x394d64d2,0x386d64d3,0xafdb03d0,0x00000000}},	//   nces_, oser_, _støp, --,
   {{0x628e0557,0x386d64d4,0x59b60084,0x973c0254}},	// [63e0] stbo, nser_, _अफसर, reće,
   {{0xd848098b,0x973c0200,0x53a60274,0x386f0051}},	//   _học_, seće, _саоб, _mvgr_,
   {{0x2bc70517,0x6d400159,0x394d0067,0x00000000}},	//   लाना, _pgma, kces_, --,
   {{0xc27b0779,0x386d03db,0xfcaa0088,0xa15502fb}},	//   _ארטי, kser_, فاتو_, _върш,
   {{0x386d054e,0xd8480023,0xdb1a0097,0x291d64d5}},	//   jser_, _mọc_, _dotý, _nywa_,
   {{0xdb0164d6,0x394d64d7,0xd84801a5,0x386d054e}},	//   _salá, eces_, _lọc_, dser_,
   {{0xdb0164d8,0x386d081c,0xdee664d9,0x291d0118}},	//   _palá, eser_, _сови, _aywa_,
   {{0xdd9203c7,0x98740c9f,0x6d400cca,0x394f0392}},	//   _دور_, алиц, _ugma, _cfgs_,
   {{0x1d07191f,0xcd062e14,0x9997002d,0x00000000}},	//   _бети_, _спай, укыт_, --,
   {{0x08970514,0x1897004f,0x97a60012,0x7a256331}},	//   اضيع_, اضية_, урил, róta,
   {{0xdb0100f5,0x6c330082,0xd8480023,0x386d3702}},	//   _talá, _افلا, _bọc_, aser_,
   {{0x394d64da,0xd946192f,0xd8480023,0x386d000b}},	//   cces_, _седи, _cọc_, bser_,
   {{0xd8480019,0xf8a800ab,0xb17b0282,0xa8560d6e}},	//   _dọc_, _कनिय, _blån, _стеј,
   {{0x25ad01c0,0xdce064db,0x2bc7022e,0x60360107}},	//   žel_, _nemč, लाया, _fņmi,
   {{0x6b950225,0x268a0037,0x75280067,0x00000000}},	//   _özge, _أختي_, ędza, --,
   {{0xf1bf0019,0x7a350009,0x3f980024,0x7a0100ea}},	//   _thám_, _pšti, _abru_, vētk,
   {{0x2bc70026,0x3f980345,0xb17b008c,0x00000000}},	// [63f0] लामा, _bbru_, _flån, --,
   {{0x1e0d0035,0x1aea0831,0x00000000,0x00000000}},	//   िक्ष_, _কখনই_, --, --,
   {{0xa1954738,0x7a350f27,0x5f1800be,0x9ac5073a}},	//   _канч, _ištv, _बुद्_, _kiŋŋ,
   {{0x386d02db,0x0dc8029f,0xdd95010b,0x6d44010b}},	//   yser_, лучи_, рады, žian,
   {{0xd2640080,0x6b655e52,0x55780070,0x7a3564dc}},	//   _viņš_, акла, רעדן_, _ušti,
   {{0xeb994f94,0x207a0070,0xdb1a0183,0x9ac5030d}},	//   тик_, _באשא, _notó, _liŋŋ,
   {{0x7a0100ea,0x543c0070,0x2bc70d91,0x00000000}},	//   lēti, געגא, लाबा, --,
   {{0x386d64dd,0x28b1111b,0x00000000,0x00000000}},	//   tser_, जिलि, --, --,
   {{0x394d43b2,0xdb1a0b4c,0x386d5d82,0xf1bf00ee}},	//   rces_, _botó, user_, _ahák_,
   {{0x386d452e,0x2cb82087,0xdb1a01ef,0xa7650823}},	//   rser_, _حافظ_, _cotó, шкод,
   {{0x7d160067,0xdb010a8a,0xe97500f8,0x00000000}},	//   żyst, _salæ, _نهاد, --,
   {{0x386d5056,0xdb08002a,0x1959021f,0xdb0108c8}},	//   pser_, _endó, _рады_, _palæ,
   {{0xdb1a64de,0xb17b01ff,0xb8fa0831,0x9879016b}},	//   _fotó, _plån, _ডে_, _סאַט,
   {{0xdb0164df,0xa4060033,0xdb1a0067,0x00000000}},	//   _calç, োগ্য_, _gotó, --,
   {{0x98140079,0xdce0021e,0x00000000,0x00000000}},	//   _ابنا, _remč, --, --,
   {{0xd84801a5,0x65bb03ad,0x24f601e0,0xdce0021e}},	//   _họa_, _vähä, _вчор, _semč,

   {{0x1f66219f,0x973c0a78,0x7bc164e0,0xe0df0260}},	// [6400] икам, meća, _onlu, _agòb_,
   {{0x2f5664e1,0x65bb03ad,0xa3ea00ab,0x7a353b1a}},	//   ртас, _tähä, _मति_, _ištu,
   {{0xd37b1899,0x37e70033,0xdfcf11c0,0xdb1a0260}},	//   _בריט, _পদার, بيل_, _lotò,
   {{0x629e64e2,0x06960070,0x7a010228,0x00000000}},	//   _ippo, ידעם_, bēti, --,
   {{0x9cf603fa,0xdb1a01f7,0xdb0101fb,0xa5bb00b5}},	//   јчеш, _notò, _yalç, nlóa,
   {{0x629e012f,0xb18800d5,0x0ca6046c,0x63530355}},	//   _kppo, _feťá, _गनीम, mění,
   {{0x3ce000cd,0xada60210,0xb4db0310,0x09af0831}},	//   šiv_, _кавл, ncàr, কানা,
   {{0x973c0280,0xf41f0a48,0x7bc100f6,0x00000000}},	//   jeća, ltät_, _enlu, --,
   {{0xc7c664e3,0xfce321e2,0x629e012f,0xdb1a64e4}},	//   асни, _дото, _lppo, _intí,
   {{0x629e4912,0x2ca9000d,0x387900b5,0xdb0800d5}},	//   _oppo, çade_, ásra_, _hadí,
   {{0xec1364e5,0x09e61728,0xd8480023,0x8c1b00a5}},	//   _بولد, _кожн, _dọa_, _יומי,
   {{0xdb1a0310,0xe8fa021d,0xdb010523,0xc98325ef}},	//   _fotò, _иле_, _dalä, _души,
   {{0x629e64e6,0x534703fa,0x4dc80033,0x69c20298}},	//   _appo, ихва, _শতাং, _inoe,
   {{0x61e60345,0x26f701df,0xdb1a0139,0x1bf800b4}},	//   _alkl, اریخ_, _intâ, ्चिल_,
   {{0x69c21472,0x25b000c3,0xdb010282,0x00000000}},	//   _knoe, öllä_, _galä, --,
   {{0x31c400d4,0xf1bf0019,0x51870370,0x7a250093}},	//   осув, _khái_, јува, jótl,
   {{0x629e027a,0xb4db0176,0x00000000,0x00000000}},	// [6410] _eppo, rcàs, --, --,
   {{0x7a010080,0x3d1a004e,0xdb1a1c02,0x61e6008c}},	//   rēti, _बड़े_, _antí, _elkl,
   {{0x6fc90026,0x442303c9,0xdb0800ee,0x98bd007a}},	//   राबं, mlj_, _badí, _mewġ_,
   {{0x442364e7,0x00000000,0x00000000,0x00000000}},	//   llj_, --, --, --,
   {{0x6aba64e8,0x59c50ea3,0xf1bf0023,0x29d80098}},	//   _artf, वासर, _nhái_, _léas_,
   {{0x2bc7021a,0x69c264e9,0x3b093379,0x00000000}},	//   लाधा, _anoe, лело_, --,
   {{0x6fc40067,0x7eb000b5,0x00000000,0x00000000}},	//   रारू, rópá, --, --,
   {{0x3ebe0093,0xf9910037,0xdb030055,0x00000000}},	//   _átta_, سبب_, lenë, --,
   {{0x973c01cc,0x44230009,0x5ef90033,0xf1bf055c}},	//   veća, klj_, _অডিও_, _chái_,
   {{0x7d040079,0x7d1e0035,0x59c500b8,0xdb0102b1}},	//   úise, ępst, वाहर, _palä,
   {{0xc4d00355,0x7cfd0249,0x38ca00d1,0xdce000ea}},	//   सङ्ख, _færø, نایی_, _iemā,
   {{0x1a6400b5,0x8afa0070,0xb17b10dd,0xa2cb00b8}},	//   _بیٹی_, _גלעז, _blåm, हमन्,
   {{0x49b82e36,0xf74500af,0xd8480023,0xdb0103d0}},	//   _خالد_, _лело, _tọa_, _dalå,
   {{0xf8b60052,0x973c042a,0xb05b15e8,0x395f64ea}},	//   _לפני_, seća, _kräf, lbus_,
   {{0xd5ad006c,0x973c01f2,0x12b80083,0xdb1a021d}},	//   رہی_, lećn, ীন্দ, _intã,
   {{0x798964eb,0xa5bb043f,0x68ec0092,0xa3b8135e}},	//   ngew, llón, _öldü, _घोर_,
   {{0xb4db12c3,0xdb0864ec,0x25fd0035,0x395f0065}},	// [6420] scàr, _radí, _लगती_, ibus_,
   {{0xe0df0260,0xd12f028f,0x798902b1,0x6d560225}},	//   _afòs_, رمل_, hgew, ıyam,
   {{0x629e64ed,0x6e22279c,0x6d4400d8,0xdb0801ef}},	//   _uppo, tlob, žiam, _padí,
   {{0xdfd20594,0x79890120,0xf41f64ee,0x00000000}},	//   _کيس_, jgew, stät_, --,
   {{0x798964ef,0xa136004f,0x973c025c,0x6e224404}},	//   dgew, _دردش, jećn, rlob,
   {{0xd8480019,0x69c203c4,0x6e22201d,0x22b802d0}},	//   _bọn_, _snoe, slob, _kčk_,
   {{0x79891cee,0x200f00a2,0x22420bd1,0x6e2201f7}},	//   fgew, égie_, _kikk_, plob,
   {{0xf1bf0019,0x6281011c,0x7989237e,0x201a03c9}},	//   _phái_, šlog, ggew, lopi_,
   {{0xdd8f00b5,0x224200be,0x8b961f7c,0x29d80098}},	//   _سول_, _mikk_, _греч, _béar_,
   {{0x224201e0,0x00000000,0x00000000,0x00000000}},	//   _likk_, --, --, --,
   {{0x501b0122,0xd8480019,0x442302f6,0xf41f01ff}},	//   רויו, _gọn_, vlj_, ktär_,
   {{0xdb1a0370,0xf1bf0028,0x35e700d8,0xdce00029}},	//   _entã, _thái_, сцов, _zemā,
   {{0x999f04d4,0x39460159,0x81de0033,0x29d80098}},	//   lmuş_, _igos_, তফা_, _féar_,
   {{0xf64f006c,0xa5bb002a,0x29d80079,0x00000000}},	//   بئی_, clón, _géar_, --,
   {{0x999f0463,0x201a64f0,0x7a35010b,0x9f5a00f7}},	//   nmuş_, dopi_, _ištr, cipé_,
   {{0x2242006c,0x2a8e0095,0x3ebf2190,0xd9a600be}},	//   _cikk_, _həbs_, _čut_, _खसोट,
   {{0x656f64f1,0x7a0800b8,0x660d0207,0x00000000}},	// [6430] mach, větl, _ijak, --,
   {{0x656f0f46,0x752d01cc,0x53994a2f,0xf3670fa7}},	//   lach, _izaz, _твоя_, _утин,
   {{0x543c00c2,0x39461d11,0x61e300af,0x2d8d0176}},	//   _געזא, _ogos_, _înlo, _pcee_,
   {{0x656f64f2,0x63a764f3,0x645d64f4,0x62876455}},	//   nach, lejn, opsi, mujo,
   {{0x61ed64f5,0x7a350a78,0x629564f6,0xdb1a0176}},	//   mhal, _oštr, ltzo, _antà,
   {{0x656f64f7,0xdb0364f8,0x61ed64f9,0x320964fa}},	//   hach, lené, lhal, lnay_,
   {{0xdce90200,0x798964fb,0x656f64fc,0x629501a3}},	//   _odeć, tgew, kach, ntzo,
   {{0x61ed0044,0xdb080176,0x395f0008,0x660d5a5a}},	//   nhal, _dadà, ubus_, _njak,
   {{0x656f64fd,0x2cad0052,0x798933b3,0x395f64fe}},	//   dach, _used_, rgew, rbus_,
   {{0xb05b022a,0x660d3115,0x798964ff,0x316b0035}},	//   _träf, _ajak, sgew, _lecz_,
   {{0x7afc0496,0x61ed6500,0x46f507b0,0x63a751cf}},	//   _žrtv, khal, ючит, dejn,
   {{0x656f0094,0x7a350009,0x67e40260,0xdb030097}},	//   gach, _všts, _fòjo, jené,
   {{0x61ed6501,0x3e4801d6,0x320905f5,0x660d53db}},	//   dhal, _işte_, dnay_, _djak,
   {{0x31606502,0x66e56503,0xe7390369,0x656f009e}},	//   wbiz_, _мола, _кел_, aach,
   {{0x656f6504,0xc7440125,0x752d01d7,0x682f0249}},	//   bach, _عضوي, _ezaz, rødd,
   {{0x61ed6505,0x320900a7,0x660d00da,0xdb036506}},	//   ghal, gnay_, _gjak, gené,
   {{0x201a03c9,0xdb011eae,0x316001a3,0x63a76507}},	// [6440] topi_, _calú, rbiz_, bejn,
   {{0xb4e602b4,0x62870033,0x63a70355,0x75240027}},	//   पनी_, bujo, cejn, _iyiz,
   {{0x61ed09c3,0x61466508,0x7e670221,0x201a1851}},	//   bhal, _мена, _cwjp, ropi_,
   {{0x44446509,0x201a4063,0xdb080314,0xb05b01ff}},	//   _hi_, sopi_, _nadá, _bräd,
   {{0x4444650a,0xf1bf01a5,0xa6de0023,0x61e4650b}},	//   _ki_, _cháu_, _ngưn, mkil,
   {{0x4444650c,0x2ca924c5,0x61e4650d,0x75240010}},	//   _ji_, çada_, lkil, _myiz,
   {{0xb05b0ed4,0x656f25d1,0xa3b200ab,0xb17b0044}},	//   _präg, yach, _ऐसन_, _blåh,
   {{0x4444650e,0xdb082b82,0x999f033e,0x7a250037}},	//   _li_, _cadá, rmuş_, nóth,
   {{0x764a650f,0x63a70031,0xb05b01ff,0x7a3500ac}},	//   _sufy, yejn, _gräd, _pštr,
   {{0x44446510,0xc7b80202,0x109b0122,0x656f6511}},	//   _ni_, kođe_, סביב, wach,
   {{0xb05b16ad,0x656f6512,0xf1bf0019,0x61e46513}},	//   _träg, tach, _khát_, kkil,
   {{0x2fd809e3,0x69a13dc1,0x75240010,0x61ed267f}},	//   _lorg_, _कॉपी, _byiz, xhal,
   {{0xf772006c,0x61e453a2,0xdb030187,0x752401d5}},	//   _ہاں_, dkil, vené, _cyiz,
   {{0x44446514,0x656f09e3,0x62876515,0xdb08053d}},	//   _ci_, sach, tujo, _zadá,
   {{0x44446516,0x61ed6517,0x63a70038,0x656f6518}},	//   _di_, thal, rejn, pach,
   {{0x44446519,0x244f08a1,0x53342d35,0x61e4300c}},	//   _ei_, _tüm_, фест, gkil,
   {{0x4444651a,0x61ed2b87,0x32090e8c,0x752d3776}},	// [6450] _fi_, rhal, rnay_, _uzaz,
   {{0x4444651b,0x61ed651c,0x320900a2,0x628702d7}},	//   _gi_, shal, snay_, pujo,
   {{0x61ed651d,0x656d0ce8,0x644d184f,0x44210282}},	//   phal, _keah, _huai, _ikh_,
   {{0x4444651e,0x6445651f,0xdb010037,0xf1bf6520}},	//   _zi_, _hihi, _talú, _chát_,
   {{0x44446521,0x69ce051e,0xe7bc05f8,0x6ab302e4}},	//   _yi_, थानी, ्ञाप, ंट्र,
   {{0x4444048c,0x656d59f6,0x7a250093,0x2fd86522}},	//   _xi_, _leah, móti, _gorg_,
   {{0x64456523,0x4cd300c8,0x644d066a,0x661d6524}},	//   _mihi, _দেখু, _luai, kosk,
   {{0xb05b022a,0x2fd80a75,0x64456525,0x644d00f7}},	//   _träd, _zorg_, _lihi, _ouai,
   {{0x644d41e3,0x7a25021d,0xdb0800b5,0x0e4400af}},	//   _nuai, nóti, _vadá, _цэрм,
   {{0x76440103,0xe8f6010b,0x61e401a3,0x6d4900a8}},	//   _siiy, ялы_, zkil, şmağ,
   {{0x44446526,0x98ab037a,0xdb1a6527,0x271600b8}},	//   _ri_, ımız_, _botõ, věné_,
   {{0x644d0094,0xc7b80129,0x20016528,0x44210088}},	//   _buai, vođe_, hihi_, _akh_,
   {{0x4444142f,0x644d006e,0xb4e60907,0x64456529}},	//   _pi_, _cuai, पने_, _bihi,
   {{0x644d02a8,0x69d90122,0x4444652a,0x61fd0168}},	//   _duai, _howe, _qi_, _amsl,
   {{0x444404ca,0x64452883,0x61e401d6,0x7c210159}},	//   _vi_, _dihi, tkil, _mklr,
   {{0x44440c1f,0x644d003b,0xc243292e,0x2fd8652b}},	//   _wi_, _fuai, енск, _sorg_,
   {{0x4444652c,0x61e4652d,0x7a251d2b,0x25a0652e}},	// [6460] _ti_, rkil, góti, _ibil_,
   {{0x61e4652f,0x44446530,0xaabd00b8,0x644503be}},	//   skil, _ui_, ्माक, _gihi,
   {{0xf1bf6531,0x61e408e2,0x00000000,0x00000000}},	//   _phát_, pkil, --, --,
   {{0x69d9004e,0x2cbf6532,0x64456533,0x5edb0033}},	//   _nowe, _brud_, _zihi, _যেহে,
   {{0x644504fb,0x20011096,0x7a250473,0x91bb00a5}},	//   _yihi, bihi_, cóti, _המכי,
   {{0xf1bf0079,0xaa666245,0x6d4903d0,0xf093016b}},	//   _fhás_, птик, _egea, _אנש_,
   {{0x6fc91e79,0x69d928ff,0xa3cd02cb,0x78a26534}},	//   रारं, _bowe, ळात_, _spov,
   {{0xe0df0107,0x00000000,0x00000000,0x00000000}},	//   _ogòl_, --, --, --,
   {{0x69d921a3,0xf8ad13cf,0x661d019d,0x00000000}},	//   _dowe, لکو_, vosk, --,
   {{0x656d6535,0x644d09bb,0x25a000ab,0xc6150026}},	//   _seah, _ruai, _abil_, णक्य_,
   {{0x473431a8,0x644d02a8,0x661d3f76,0x2ab5009e}},	//   ьнос, _suai, tosk, rùbá_,
   {{0x64456536,0x7bda000e,0x973c0009,0x442100f4}},	//   _sihi, _hotu, lećk, _skh_,
   {{0x644d0370,0xd7e61112,0x64456537,0x44216538}},	//   _quai, _ніко, _pihi, _pkh_,
   {{0x493b02da,0x69d90a75,0x7bda00ec,0x661d5696}},	//   _הגדו, _zowe, _jotu, sosk,
   {{0x7bda0cca,0x661d2f62,0x69d94ac8,0xe45f0282}},	//   _motu, posk, _yowe, spö_,
   {{0x644d0a24,0xd01100b5,0x82340172,0x7a250015}},	//   _tuai, ھلا_, فرقا, tóti,
   {{0x4433345d,0xd01105f5,0x644501a0,0x7bda00be}},	// [6470] _thx_, پلا_, _tihi, _ootu,
   {{0x44270082,0x7bda6539,0x7a250473,0x09c90099}},	//   _ón_, _notu, róti, _ाच्य,
   {{0x20010723,0xdb0a191b,0x0ef926c6,0xb05b0ef0}},	//   rihi_, ndfä, ्पेस_, _bräc,
   {{0x7bc8653a,0x2ca90279,0x2001653b,0x2cbf653c}},	//   _andu, çado_, sihi_, _prud_,
   {{0x7bda653d,0xee3802ce,0x69d9653e,0x2001023a}},	//   _botu, їні_, _rowe, pihi_,
   {{0x69d9653f,0xfaa540e2,0x7bda1bec,0xfbc70e6f}},	//   _sowe, дако, _cotu, लाइम,
   {{0x34aa6540,0x69d96541,0x7528004e,0x7bda00f4}},	//   _छन्द, _powe, ędzi, _dotu,
   {{0x63b701ef,0x08c50431,0x2cbf6542,0x6d4908c8}},	//   _laxn, дбин, _trud_, _ugea,
   {{0xf8a900bf,0x7bda01f7,0xdb032c8b,0xdb1a0282}},	//   تگاه_, _fotu, mení, _antä,
   {{0xdb032d87,0xd70900c3,0xdb1a0168,0x7bda6543}},	//   lení, жное_, _potô, _gotu,
   {{0x69d96544,0xb4e6021a,0xff5600a5,0x00000000}},	//   _towe, पन्_, ובתך_, --,
   {{0xf3e902da,0x2d8f01ca,0xfb1a02b5,0x28ae0266}},	//   _דף_, ngge_, _וועמ, _जैवि,
   {{0x6d446545,0xdb1a0421,0xddce00fe,0x00000000}},	//   žiav, _entä, _dubň, --,
   {{0x33d538ac,0xf771004f,0x67d4036e,0xe1ff02d7}},	//   ніст, _شات_, _почу, _amó_,
   {{0x63b70168,0x00000000,0x00000000,0x00000000}},	//   _daxn, --, --, --,
   {{0xdb030187,0xbbda0380,0x25a00116,0x00000000}},	//   jení, _बक्क, _ubil_, --,
   {{0xdb03024e,0xdb1a0523,0x63b76546,0x00000000}},	// [6480] dení, _intå, _faxn, --,
   {{0xed5902c4,0xdfa6004f,0x7a250093,0xdee60c06}},	//   _afž_, بحري, mótu, мози,
   {{0x7bda6547,0xb05b02b1,0x00000000,0x00000000}},	//   _rotu, _präc, --, --,
   {{0x7bda527b,0x00000000,0x00000000,0x00000000}},	//   _sotu, --, --, --,
   {{0x3ead0470,0xa3b2006a,0xa3e20299,0x7bda6548}},	//   _ćete_, _ऐसा_, _दवा_, _potu,
   {{0x2d8f0382,0x2ac60274,0x00000000,0x00000000}},	//   agge_, дљив, --, --,
   {{0x160e0a5e,0x7bda6549,0xc6e80083,0x2d960f08}},	//   ाचार_, _votu, _পশ্চ, _орас,
   {{0x2d95654a,0x80b50461,0xdb030355,0x00000000}},	//   _прус, _उनमे, cení, --,
   {{0x7bda654b,0x50db0070,0x973c02c4,0x25b9027a}},	//   _totu, ַקטא, meći, vdsl_,
   {{0x7bc8654c,0x61db035d,0xa5c701ef,0x9f4a00ac}},	//   _undu, _यक्ष, _opóñ, _blbé_,
   {{0xd8480028,0xcb0a096a,0xeb9700d4,0xa5bb0079}},	//   _mọi_, _بيان_, _цих_, llói,
   {{0x7c2a2b73,0x6d4400d8,0x19b900af,0xf1bf00cc}},	//   llfr, žiau, _нучь_, _nháp_,
   {{0xdb01024e,0x998600fe,0x00000000,0x00000000}},	//   _malý, _choť_, --, --,
   {{0xdb0300b8,0x7a13002d,0xd7c80037,0x00000000}},	//   zení, măta, _روعه_, --,
   {{0x2d8f2895,0x7c2a0118,0x92580f8f,0x00000000}},	//   ygge_, ilfr, даст_, --,
   {{0x973c0254,0xb6080097,0x442a0211,0xf1bf055c}},	//   jeći, _vyší, alb_, _cháp_,
   {{0xc34b01c8,0x60f915eb,0xdb03654d,0x973c0a78}},	// [6490] _мяне_, чная_, vení, deći,
   {{0xceeb0bdf,0x5fc90066,0x00000000,0x00000000}},	//   يران_, राइल, --, --,
   {{0xdb03654e,0xb17b10dd,0x00000000,0x00000000}},	//   tení, _blåt, --, --,
   {{0x7bde0093,0x00000000,0x00000000,0x00000000}},	//   öpun, --, --, --,
   {{0x7ae3001e,0x415a0d85,0xdb0300a0,0xa5bb0079}},	//   wynt, _מדרג, rení, glói,
   {{0xdb030314,0x9f5a01f7,0x00000000,0x00000000}},	//   sení, cipà_, --, --,
   {{0xd8480028,0x3ce902f6,0xdb030097,0xc4cb00b8}},	//   _gọi_, šav_, pení, ामुख,
   {{0xc7b80b16,0xfe4304e8,0x8d770088,0xa5bb654f}},	//   vođa_, _شکای, _زارا, blói,
   {{0x7a2500fb,0xa5bb004f,0x6d5b0054,0x75e60067}},	//   dótt, clói, _ifua, _wózk,
   {{0xb8d71140,0x5fd20931,0xb7bf0033,0x00000000}},	//   _चन_, सायल, েস্ট, --,
   {{0x66e5004b,0xd62a6550,0x00000000,0x00000000}},	//   хона, зоне_, --, --,
   {{0x98a000d8,0x2bc74f52,0x6abd02b4,0xdb030176}},	//   _šią_, लाका, ्मीर, menà,
   {{0x8cc2004e,0xe8ee0948,0x6d5b08c7,0x00000000}},	//   लियो, _сл_, _mfua, --,
   {{0x973c011c,0xb6020355,0xe787010b,0xdd0c0067}},	//   zeći, _žáda, _цудо, _różo,
   {{0xf1bf00e8,0x5fc901c0,0x12ce0033,0x00000000}},	//   _pháp_, राईल, রন্দ, --,
   {{0x3ebe008a,0xdb016551,0xd84800cc,0x00000000}},	//   _átti_, _haló, _rọi_, --,
   {{0x66066552,0x0457004f,0xbf081bb5,0x92c20033}},	// [64a0] mikk, _كلية_, वप्न_, ্নে_,
   {{0x66066553,0xb17b2a5e,0x61ef02d7,0x6d5b023c}},	//   likk, _blås, _elcl, _afua,
   {{0x69cb61fe,0x28b60380,0x0d86014d,0xf1bf0019}},	//   _onge, _अनभि, елен, _tháp_,
   {{0x66066554,0x63ae6555,0x7c2a001e,0x6fc90026}},	//   nikk, lebn, wlfr, राउं,
   {{0x628e4be0,0x2fca012f,0x973c011c,0xfa150033}},	//   lubo, _tnbg_, reći, াতাল_,
   {{0x69cb6556,0x031f0bda,0x973c0129,0x66066557}},	//   _ange, _मुँह_, seći, hikk,
   {{0x628e1292,0xed590009,0x66066558,0x9f5a02d7}},	//   nubo, _anžu_, kikk, cipá_,
   {{0x7e9b0122,0x629c01a2,0xdb010118,0xf2d3076b}},	//   _מסלו, itro, _mblè, רעה_,
   {{0x6c860071,0x8c956559,0xdb010300,0x629c01f4}},	//   _سلام, _архі, _baló, htro,
   {{0x6e22655a,0xdb01171c,0xed35002d,0xeb9700af}},	//   loob, _caló, _рэсэ, _пиу_,
   {{0x66061e54,0x031f0299,0x63ae01c0,0x8c1b016b}},	//   fikk, _मुंह_, debn, _צובי,
   {{0x6606655b,0x629c0284,0x628e0207,0x6e22001c}},	//   gikk, dtro, dubo, noob,
   {{0x7a2500fb,0x37e61c6b,0x629c01a2,0xdb030bca}},	//   rótt, _подг, etro, mená,
   {{0x63ae02c9,0xb05b655c,0x629c1f88,0x6e220553}},	//   gebn, _brän, ftro, hoob,
   {{0xdbc7007c,0x66060273,0x31c7010b,0x69cb0cfc}},	//   _töös, bikk, нсав, _ynge,
   {{0xb05b00a6,0xdb01021e,0x6aa80183,0x00000000}},	//   _drän, _kalò, _mpdf, --,
   {{0x6e22030d,0xc61d0963,0xb17b1e74,0x00000000}},	// [64b0] doob, नवीय_, _blår, --,
   {{0xa0c40037,0x6fb83c16,0xb05b1788,0x7a2501ef}},	//   ديكو, нгур_, _frän, nótr,
   {{0x4423655d,0x63a903fd,0x629c1121,0xb05b013c}},	//   moj_, đend, ctro, _grän,
   {{0x6e22001c,0x127a016b,0xaf340037,0x9f5a021d}},	//   goob, _קארע, اركت, ripá_,
   {{0x973c042a,0xdb034e39,0x672a008a,0x44230124}},	//   meću, dená, _lyfj, ooj_,
   {{0x4423655e,0xed150332,0xeab10037,0xe0df00e2}},	//   noj_, _یہاں_, لعب_, _ngòi_,
   {{0x9f340044,0x3da701c8,0xdea400d1,0x6e22001c}},	//   _бері, _праб, _میلی, boob,
   {{0x4423655f,0x63ae0035,0x6d5b002f,0xaac40088}},	//   hoj_, zebn, _ufua, اتون,
   {{0x80c4065a,0x44231254,0x6d4401ba,0xdb010176}},	//   रिये, koj_, žiar, _calò,
   {{0x44230537,0x3ddf022e,0x6606152b,0x629c6560}},	//   joj_, _houw_, wikk, ytro,
   {{0x44236561,0x66066562,0xdb010332,0x63ae05d3}},	//   doj_, tikk, _való, vebn,
   {{0x69cb6563,0x20d11b8f,0x3ddf0a75,0x7a130043}},	//   _unge, समाध, _jouw_, măto,
   {{0x66061fe9,0x63ae00b8,0x7a13002d,0xf41f31ea}},	//   rikk, tebn, lăto, rrän_,
   {{0x44232f6e,0x629c64a3,0x66066564,0x628e5ddf}},	//   goj_, ttro, sikk, tubo,
   {{0x23271a56,0xe29719c3,0x63ae01ba,0x629c002a}},	//   вори_, кар_, rebn, utro,
   {{0x629c12af,0x63ae02dd,0x212b01c0,0x60c902c4}},	//   rtro, sebn, _bych_, _šema,
   {{0x44232d5b,0x66046565,0xa3ba18dd,0x6e2200ac}},	// [64c0] boj_, _imik, _قادر_, voob,
   {{0xb05b06d7,0x44230b67,0x629c6566,0x10a3081e}},	//   _trän, coj_, ptro, рифн,
   {{0x224b06d7,0x6e22007c,0x443a00d7,0x3ddf0120}},	//   _fick_, toob, _ihp_, _bouw_,
   {{0x224b022a,0x98b100b8,0x91e60dfc,0x443a009e}},	//   _gick_, íběh_, _роме, _hhp_,
   {{0x2240007c,0x6fc9004e,0x6e226567,0xdb0a0b3e}},	//   mmik_, राखं, roob, ldfø,
   {{0x8aa60210,0x3a266568,0xdce001c0,0x6e22073a}},	//   врид, _skop_, _země, soob,
   {{0xeaaf11c0,0x443a6569,0x7a1300af,0x63a300b5}},	//   قعي_, _mhp_, găto, _önne,
   {{0xada6195a,0x44230031,0xdd9208cf,0xd8480023}},	//   _шабл, zoj_, _خور_, _lọt_,
   {{0xdb1a00da,0xdca60370,0x22400159,0x1c46656a}},	//   _katë, _јази, imik_, _анам,
   {{0x66040332,0x4423656b,0x394f024b,0x2240656c}},	//   _amik, xoj_, _eggs_, hmik_,
   {{0x4423011c,0x7a130043,0x7a2501ef,0xdb1a0055}},	//   voj_, căto, rótr, _matë,
   {{0x6f0300c9,0x3ebe0093,0x672a0298,0x3a260207}},	//   únci, _áttu_, _vyfj, _ukop_,
   {{0xf8b6084b,0x3eaa00d7,0xd84800e2,0xf7b7026b}},	//   _अनिय, _lpbt_, _bọt_, ردیش_,
   {{0x5694656d,0x443a027d,0xdb1a01f4,0x9f4a0176}},	//   _бакт, _chp_, _natë, _albí_,
   {{0x4423656e,0xaad20632,0xf8370122,0x224b3585}},	//   roj_, थमिक, _שנות_, _pick_,
   {{0xed591bfc,0x442300da,0x661601d2,0x521401c8}},	//   _kaže_, soj_, _gjyk, адст,
   {{0x44230a53,0x973c011c,0x3ddf0223,0x33590043}},	// [64d0] poj_, reću, _rouw_, _папэ_,
   {{0x224b3c9d,0x973c042a,0xdb080b3e,0xd84800e2}},	//   _wick_, seću, _fadø, _gọt_,
   {{0xdb030955,0xed591635,0xdb1a01f4,0x212b00e9}},	//   menç, _laže_, _datë, _wych_,
   {{0x212b324f,0xed5802ce,0x764d00d7,0x7c3a656f}},	//   _tych_, вої_, _jiay, _ahtr,
   {{0xdca51283,0x61ed02fc,0xb05b1193,0xab07008d}},	//   уали, mkal, _kräm, _íbúð_,
   {{0x7a1300af,0x320908dd,0x3ddf0223,0x764d2884}},	//   tăto, liay_, _wouw_, _liay,
   {{0xaed41ad4,0x7c230e82,0x3ddf0223,0x752d030d}},	//   _корш, ronr, _touw_, _lyaz,
   {{0x61ed6570,0xdb1a6571,0x7c236572,0x5f74006c}},	//   nkal, _matè, sonr, _ماہر,
   {{0x6e3b4f4f,0x7a1300af,0x61ed6573,0xdb1a0260}},	//   _ihub, săto, ikal, _latè,
   {{0xe8f62cc7,0xa7b50431,0x61ed6574,0x69de00a2}},	//   уль_, усиј, hkal, êper,
   {{0x764d1d86,0xb9950037,0xdb030132,0x00000000}},	//   _biay, _ملاب, denç, --,
   {{0x394f0051,0x61ed6575,0x752d3a34,0xdb0803d0}},	//   _uggs_, jkal, _byaz, _radø,
   {{0x61ed6576,0x1abd0026,0x764d027c,0x69db0df4}},	//   dkal, ्मकथ, _diay, mjue,
   {{0xec350070,0xdb1a0359,0xdc35016b,0xdb036577}},	//   טאָר_, _batè, טאָט_, genç,
   {{0xd8480023,0x61f66578,0x752d018e,0x6e29073a}},	//   _vọt_, thyl, _eyaz, _okeb,
   {{0x61ed149b,0x66046579,0x764d657a,0x75e600d5}},	//   gkal, _umik, _giay, _pózu,
   {{0x68e90f1a,0xb05b022a,0xdb1a0031,0x69db02d7}},	// [64e0] nyed, _främ, _patë, ijue,
   {{0x6e3b0232,0xdb0303e6,0x61ed657b,0xa3cb0380}},	//   _ahub, cenç, akal, _रोप_,
   {{0xa2e63e10,0x7d1b01dd,0x6e3b0069,0xbd8a0037}},	//   _сонд, _axus, _bhub, فنان_,
   {{0x7c3a00da,0x6456050f,0xed5a657c,0x2013012f}},	//   _shtr, _kuyi, ход_, anxi_,
   {{0x6e3b09c3,0x63be00b5,0xa07500c3,0x41d10355}},	//   _dhub, _kapn, _высш, हारस,
   {{0x64560186,0xdb1a00b5,0x6e29657d,0x00000000}},	//   _muyi, _haté, _ekeb, --,
   {{0x60c4657e,0xdb1a0088,0x75e600b5,0x66f300a8}},	//   lvim, _katé, _józs, bəkə,
   {{0x248001cc,0xbc7600f8,0x6e3b08c7,0x5a3403e6}},	//   _ovim_, _مهرب, _ghub, јнит,
   {{0xdb1a657f,0x26c76580,0x68e900b5,0x2b5e6581}},	//   _maté, _arno_, gyed, _tftc_,
   {{0x26c701c0,0xed590129,0xdb1a00f7,0x61ed01a3}},	//   _brno_, _važe_, _laté, zkal,
   {{0x26c70c0a,0x70d1045c,0xdb036582,0x752d00d7}},	//   _crno_, _सप्ल, venç, _syaz,
   {{0x64566583,0xdb0a03e6,0x60c46584,0xa5bb0132}},	//   _buyi, nefí, kvim, coól,
   {{0xdb030370,0x67d42d4d,0x61ed3656,0xb05b033b}},	//   tenç, _волу, vkal, _präm,
   {{0xe45410b0,0xdb1a6585,0x8937010b,0x60c900f4}},	//   скры, _patè, _спіс_, _šemo,
   {{0xdb036586,0x61ed6587,0xd6cf5b1d,0x3f870093}},	//   renç, tkal, _ут_, ónum_,
   {{0xdb1a1010,0x673803fd,0xdb0303e6,0x777a6588}},	//   _caté, _izvj, senç, latx,
   {{0x26c70506,0x9f4a0176,0x6e3b6589,0xdb0a01ef}},	// [64f0] _zrno_, _albà_, _rhub, defí,
   {{0x61ed658a,0x6e3b658b,0xf3ff0183,0x6aba658c}},	//   skal, _shub, mpão_, _ostf,
   {{0x5d55658d,0x1dc60084,0x60c400d8,0xf3ff0132}},	//   акет, _रोहत, avim, lpão_,
   {{0x63be024e,0x777a01a3,0x00000000,0x00000000}},	//   _zapn, hatx, --, --,
   {{0x6aba0012,0xeb99275d,0x66f30095,0x33f40282}},	//   _astf, вил_, rəkə, _häxa_,
   {{0x8c450328,0x68fb00a8,0x7e7705f5,0xa3cb0f06}},	//   шеле, vzud, _مارئ, _रोम_,
   {{0x6e3b00f1,0x69c00120,0x25a90097,0x09f554d3}},	//   _thub, fdme, _obal_, ичия,
   {{0x09e528cc,0x7d1b01ed,0x6e3b0371,0x6e29658e}},	//   роин, _txus, _uhub, _ukeb,
   {{0xf7712604,0x69a1658f,0x6aba0139,0x777a0176}},	//   ياد_, क्षी, _estf, fatx,
   {{0xdb036590,0x69db0453,0x999e010b,0x69c06591}},	//   tenä, sjue, _butų_, adme,
   {{0x248001cc,0x68e96592,0x60c400ee,0xb05b0523}},	//   _svim_, syed, zvim, _bräk,
   {{0x63be025f,0x78b9006f,0x75e600b5,0xe4c60210}},	//   _sapn, _tswv, _rózs, айми,
   {{0xf8a9007c,0xdb03328f,0xdb1a00a2,0xb05b017b}},	//   _कहिय, senä, _raté, _dräk,
   {{0xdb1a1ec0,0x69a109a8,0x25a936de,0x00000000}},	//   _saté, क्री, _ebal_, --,
   {{0xdb0101c0,0x63be6593,0x232a0896,0xa2e3052a}},	//   _oblí, _vapn, тови_, оорд,
   {{0xd84801a5,0x60c40a78,0xe2970166,0x71660037}},	//   _họp_, tvim, јат_, شارك,
   {{0x387f2990,0x395f046a,0xdfd20ad9,0x69b801d1}},	// [6500] nsur_, icus_, يير_, ्यती,
   {{0x63be012f,0x38600037,0x60c46594,0x3e48566d}},	//   _uapn, _éire_, rvim, _işti_,
   {{0xdfcf017e,0x60c46595,0x9f4a0791,0x00000000}},	//   ظيم_, svim, _blbá_, --,
   {{0x6da606cd,0x387f6596,0x127b016b,0x00000000}},	//   рида, ksur_, _באטע, --,
   {{0xa3cb04cc,0x7e6900ac,0xf1bf0023,0x1c4632b3}},	//   _रोड_, _čepe, _nháy_, андм,
   {{0x22b80107,0xbd050345,0x9e6603fc,0x00000000}},	//   _kōk_, _stéé, _نارن, --,
   {{0x81b900c8,0xd00700af,0x80c43b23,0x00000000}},	//   চার_, _тере_, रिवे, --,
   {{0x98741c80,0x3e480160,0x00000000,0x00000000}},	//   блиц, _oşti_, --, --,
   {{0x25a9009e,0xf1bf01a5,0x69c001e0,0x387f00e7}},	//   _rbal_, _cháy_, rdme, gsur_,
   {{0x57f4066d,0xd84800e2,0xdb0100ac,0xdcfb007a}},	//   спот, _cọp_, _zblí, _sbuħ,
   {{0xcf5700a5,0xdb010132,0x777a01a3,0xb05b1e2e}},	//   יבית_, _balõ, ratx, _präk,
   {{0x98a60afd,0xa88a081b,0x777a01b7,0x00000000}},	//   _виде, _айда_, satx, --,
   {{0x69fb0070,0x628e1167,0x777a0065,0x00000000}},	//   _בלאק, erbo, patx, --,
   {{0x77920df3,0x25bf0506,0x74250033,0x44310282}},	//   _بیدا, žul_, পষ্ট_, ulz_,
   {{0xf8b6252b,0xa5c4004e,0xed590009,0x3e48002d}},	//   _अनुप, _spół, _laža_, _eşti_,
   {{0x33f401ff,0x11552dc3,0xd4b93e10,0xa5bb01ef}},	//   _växa_, скаю, _блиц_, clóp,
   {{0x657d6597,0xc05800d8,0x81b90033,0x628e0d35}},	// [6510] mash, аіх_, চাল_, arbo,
   {{0x657d6598,0x3f6700af,0x1e1f0c67,0x908a006c}},	//   lash, ртаб, यक्ष_, املے_,
   {{0x656f024e,0x63b502c6,0x00000000,0x00000000}},	//   obch, mezn, --, --,
   {{0x59a6009a,0x657d6599,0x66ea0095,0x387f659a}},	//   _कॉलर, nash, məkd, ysur_,
   {{0xfd100c26,0x71d600a5,0x00000000,0x00000000}},	//   وجه_, _הורד_, --, --,
   {{0x657d659b,0xed5900ec,0x00000000,0x00000000}},	//   hash, _daža_, --, --,
   {{0x657d3370,0xd90f0332,0x38660279,0x00000000}},	//   kash, ڈیا_, _ator_, --,
   {{0x657d07ce,0xdb1a659c,0x9f430031,0xdb010097}},	//   jash, _antó, _lojë_, _ublí,
   {{0x657d659d,0x63b5006c,0xd7d200a1,0x395f3f36}},	//   dash, kezn, तांच, rcus_,
   {{0x31790332,0x63b554c4,0x387f659e,0xdb0801ef}},	//   _lesz_, jezn, rsur_, _cadó,
   {{0x657d070b,0x387f659f,0x2902008e,0x7bc165a0}},	//   fash, ssur_, úkar_, _ialu,
   {{0xf3e902da,0x7bc165a1,0xdb1a043f,0x657d65a2}},	//   _אף_, _halu, _entó, gash,
   {{0x7bc165a3,0x5a0a0070,0xb343013b,0x00000000}},	//   _kalu, _גלײַ, əçis, --,
   {{0x7bc14519,0xe708006c,0xe29a1a8e,0x1de42b6d}},	//   _jalu, اتین_, лаг_, _कक्ष_,
   {{0x657d65a4,0x7bc165a5,0x2ba902cb,0xe695004f}},	//   bash, _malu, च्या, _العد,
   {{0x7bc11d11,0x628e013c,0xc7b800f4,0x00000000}},	//   _lalu, rrbo, vođi_, --,
   {{0x614311c5,0x63b5008b,0x7a13002d,0x31790051}},	// [6520] зета, bezn, găti, _desz_,
   {{0x7bc165a6,0x2f5665a7,0x9f430031,0x00000000}},	//   _nalu, стас, _gojë_, --,
   {{0x442a65a8,0x66ea0095,0x683d000d,0x81e40033}},	//   mob_, cəkd, cède, ভোগ_,
   {{0x7e6300b5,0xdb0a65a9,0x00000000,0x00000000}},	//   ínpa, ánít, --, --,
   {{0x7bc165aa,0x628101c0,0x442a006d,0xe7b7021a}},	//   _balu, álov, oob_, _असंप,
   {{0x7bc165ab,0x657d0010,0x68f60067,0x92df0033}},	//   _calu, zash, _żydo, _দেয়_,
   {{0x386604ca,0x657d65ac,0x7bc14b79,0xdb1a65ad}},	//   _stor_, yash, _dalu, _antò,
   {{0xada3107a,0x442a01a9,0x63b507b3,0x6da303fa}},	//   _насл, hob_, zezn, _ниса,
   {{0x7bc165ae,0x657d65af,0xcb6a65b0,0xa3bd364c}},	//   _falu, vash, _базе_, ीएम_,
   {{0x442a65b1,0x7bc165b2,0x657d000e,0x3f9a010d}},	//   job_, _galu, wash, ngpu_,
   {{0x657d65b3,0x63b51851,0x6e45008d,0x442a65b4}},	//   tash, vezn, _útbú, dob_,
   {{0x7bc165b5,0xbb3b02b5,0x61e600ea,0x7c2a0453}},	//   _zalu, _געבי, _nokl, lofr,
   {{0x657d65b6,0xd90e064e,0xdb1a2b01,0x442a65b7}},	//   rash, _سید_, _matí, fob_,
   {{0x657d65b8,0xdb1a65b9,0x63a90a78,0xb05b022a}},	//   sash, _latí, đeno, _kräv,
   {{0x63b565ba,0xa77b02b5,0x657d65bb,0x69c208eb}},	//   rezn, _גרופ, pash, _kaoe,
   {{0x245d00e8,0x657d046a,0x61e604f6,0x63b53c56}},	//   _tìm_, qash, _cokl, sezn,
   {{0x660f0076,0x61e62018,0x645d0069,0x62950355}},	// [6530] mick, _dokl, qqsi, suzo,
   {{0x660f0e7d,0x60090095,0xd5a500a1,0xa3b01fe0}},	//   lick, _kömə, ग्रज, _टॉप_,
   {{0x41c41451,0xf1c44fa7,0xdb1a01ef,0x7bc100af}},	//   _लोकस, _लोकन, _batí, _ralu,
   {{0x7bc165bc,0x660f114d,0xa69b0070,0x200a018e}},	//   _salu, nick, רשאפ, _embi_,
   {{0x7bc165bd,0xdb1801b4,0x00000000,0x00000000}},	//   _palu, ndvæ, --, --,
   {{0xdfdb0021,0x660f3adb,0x7bc1007a,0x547c0070}},	//   _съм_, hick, _qalu, נטוו,
   {{0x7bc165be,0x7bc301ae,0x660f65bf,0x6e94081b}},	//   _valu, rdnu, kick, _ниру,
   {{0x7bc165c0,0x660f00ee,0x2aa10035,0x6b880103}},	//   _walu, jick, rób_, _eddg,
   {{0x442a0221,0x7bc165c1,0x2aa1004e,0x660f024e}},	//   yob_, _talu, sób_, dick,
   {{0xdb1a65c2,0x7bc1006d,0x2cbf65c3,0x0685191f}},	//   _zatí, _ualu, _isud_, огон,
   {{0xe7390b46,0x660f0076,0x442a00fe,0xae000567}},	//   рен_, fick, vob_, लोकन_,
   {{0x660f0076,0x58d5029f,0x00000000,0x00000000}},	//   gick, _моет, --, --,
   {{0x442a65c4,0xb05b033b,0x62850533,0x628100a2}},	//   tob_, _kräu, _avho, âlon,
   {{0x61e63842,0x2b4000b8,0xdb010097,0xdce900a0}},	//   _sokl, řice_, _zblá, _oceľ,
   {{0x660f65c5,0xfbd20122,0x27e701da,0x386d05d6}},	//   bick, ותם_, _ionn_, lper_,
   {{0x799b637e,0x2688004f,0x660f00ac,0x2cbf0bca}},	//   nguw, _اخوي_, cick, _osud_,
   {{0x27e70c1f,0x600a55ca,0x3fe62ee2,0xe0da290a}},	// [6540] _konn_, анам_, ожав, шва_,
   {{0xdb1a002a,0x386d614c,0x27e7553b,0x00000000}},	//   _satí, iper_, _jonn_, --,
   {{0x91e632c9,0x27e70359,0xdb1a65c6,0x386d0055}},	//   _доне, _monn_, _patí, hper_,
   {{0x5eac0083,0xdb1a021d,0x27e70260,0xec6a00af}},	//   ছিলে, _latã, _lonn_, аркк_,
   {{0xa01b00fb,0x386d65c7,0x50462d59,0x2034006c}},	//   _kvöl, jper_, _мемб, _فہرس,
   {{0x660f65c8,0x200a3239,0xa3b00026,0xaa661b0a}},	//   zick, _umbi_, _टॉम_, отик,
   {{0x05ca09f9,0xed5900ee,0xaab70037,0xdb1a021d}},	//   ियाब, _gažo_, قدير_, _satâ,
   {{0xab5c0029,0x660f0187,0x48aa65c9,0x799b0008}},	//   _daļa, xick, атом_, gguw,
   {{0x27e765ca,0xb7bc0080,0x660f65cb,0x59a620ab}},	//   _bonn_, loģi, vick, क्षर,
   {{0x274a2632,0xc6a623c0,0x660f65cc,0x27f8008a}},	//   ично_, орми, wick, órn_,
   {{0x660f114d,0x27e765cd,0x8cc20963,0xab5c0228}},	//   tick, _donn_, लिको, _gaļa,
   {{0x3dc6252d,0xc7b800f4,0x00000000,0x00000000}},	//   ndow_, vođu_, --, --,
   {{0x660f114d,0x38cb006c,0x27e765ce,0xf8ad00bf}},	//   rick, _پانی_, _fonn_, _یکی_,
   {{0x660f024e,0x3dc401e8,0x798065cf,0x27e70260}},	//   sick, _lamw_, lamw, _gonn_,
   {{0x3d11488d,0x660f024e,0x69a100b4,0x03c8010b}},	//   _देने_, pick, क्की, цыяй_,
   {{0x2ca60008,0x798065d0,0xb05b01ff,0x00000000}},	//   ktod_, namw, _orät, --,
   {{0xf8bc006a,0xdcfb03fd,0x27e70c1f,0x59bd012f}},	// [6550] ्टिय, _iduć, _yonn_, ्यतर,
   {{0x798025bf,0x2cbf022e,0x628100b8,0xb4c70026}},	//   hamw, _rsud_, álos, ईटी_,
   {{0xa91d0b67,0x35d00461,0x798065d1,0xdb180454}},	//   maže, _तोड़, kamw, ndvä,
   {{0x62810a78,0xa91d0254,0x386d33d4,0x25b90355}},	//   šlos, laže, yper_, nesl_,
   {{0xa0c505f5,0x660d4df5,0x28b60066,0x22490553}},	//   _عيسو, _mmak, _अनगि, mmak_,
   {{0x224965d2,0xa91d00b8,0x26ce0042,0x00000000}},	//   lmak_, naže, _orfo_, --,
   {{0x27e70260,0x660d65d3,0xdb1a0443,0xf41432e3}},	//   _ronn_, _omak, _catà, ופס_,
   {{0xe9d90610,0xa2cc009a,0x3f8165d4,0x224965d5}},	//   ски_, हित्, lahu_, nmak_,
   {{0x63a90537,0xa91d0169,0x386d65d6,0xb05b033b}},	//   đenj, kaže, uper_, _träu,
   {{0x660d1810,0xa3cb1ca8,0x386d17a8,0x3f8165d7}},	//   _amak, _रोल_, rper_, nahu_,
   {{0x386d65d8,0xdb0a15e5,0xf529011d,0x660d0159}},	//   sper_, gefä, _עץ_, _bmak,
   {{0x2d9d30c6,0x3f8165d9,0x386d293a,0x27e702d0}},	//   ngwe_, hahu_, pper_, _wonn_,
   {{0x27e765da,0x660d0069,0xdb1a0079,0x67d50009}},	//   _tonn_, _dmak, _iatá, _ноду,
   {{0xdb1a0332,0xa91d00cb,0x660d492b,0x5f010083}},	//   _hatá, ražd, _emak, _এখনও_,
   {{0x7d020036,0x660d0069,0x3f8100f4,0x3f8e008d}},	//   zzos, _fmak, dahu_, ófum_,
   {{0x80660823,0xdddc0124,0x91e31180,0x224901ed}},	//   зваж, _ovrš, носе, gmak_,
   {{0xdb1a65db,0x76440371,0x00000000,0x00000000}},	// [6560] _matá, _ihiy, --, --,
   {{0xd9b80461,0x3f810009,0x798008a0,0x974200f4}},	//   _आस्ट, gahu_, zamw, šćem,
   {{0x44440537,0x59bd131c,0x2ec6004f,0x3d110006}},	//   _ih_, ्यार, ثقاف, _देबे_,
   {{0xdb1a6453,0x4444345d,0x65660223,0xdb1801ff}},	//   _natá, _hh_, nckh, ndvå,
   {{0x444465dc,0xdb0a65dd,0x79800027,0xdb1a0176}},	//   _kh_, ndfö, vamw, _satà,
   {{0x61f601ff,0x0fda0037,0x444465de,0x7d0265df}},	//   lkyl, _ابحث_, _jh_, rzos,
   {{0x444465e0,0x80c40d00,0xb05b00a6,0x7528004e}},	//   _mh_, रिके, _fräs, ędzy,
   {{0xdb1a2140,0xdca665e1,0xb05b3f3b,0x76560095}},	//   _catá, _наби, _gräs, _niyy,
   {{0x6b5646c4,0xfc6400bf,0x798065e2,0xa96703e6}},	//   _فضائ, _آخری, ramw, чиња_,
   {{0x6d400ae0,0x1dda009a,0x660d65e3,0xdb03024e}},	//   _izma, णावत, _smak, lený,
   {{0x65955fc0,0xdb1a040f,0xa91d00cd,0x22490225}},	//   ману, _fatá, važe, ymak_,
   {{0x444465e4,0xaadb0122,0x76440107,0xaac20099}},	//   _ah_, _לחבר, _chiy, _वैयक,
   {{0x444465e5,0x7656028b,0x3f810118,0xa91d0355}},	//   _bh_, _diyy, yahu_, taže,
   {{0x444465e6,0x248d15d7,0x69a23010,0x660d0176}},	//   _ch_, šemo_, _गाडी, _wmak,
   {{0x4444004a,0x883b0052,0xa91d6192,0x3f810366}},	//   _dh_, _התגו, raže, vahu_,
   {{0x44440269,0x660d65e7,0xdb03024e,0xa91d00b8}},	//   _eh_, _umak, jený, saže,
   {{0x444465e8,0xdb03024e,0x224965e9,0x3f8165ea}},	// [6570] _fh_, dený, rmak_, tahu_,
   {{0x2904103a,0x24890176,0x661d0009,0x61e40df0}},	//   izma_, _ivam_, lnsk, ajil,
   {{0xb05b3230,0xdddc65eb,0x224901d6,0xe7ae0ed1}},	//   _präs, _svrš, pmak_, ज्यप,
   {{0x661d59a0,0x3f810076,0x4421028b,0x64570042}},	//   nnsk, sahu_, _hjh_, _hixi,
   {{0x444465ec,0x661d65ed,0xdca50336,0x00000000}},	//   _yh_, insk, фали, --,
   {{0x444465ee,0x645f030d,0xdb1a0300,0x26120009}},	//   _xh_, _muqi, _satá, jšon_,
   {{0x628765ef,0xdb03024e,0x60cd65f0,0x600001ff}},	//   nsjo, bený, lvam, _dömd,
   {{0x661d117c,0xdb0365f1,0xa3d4052f,0x00000000}},	//   jnsk, cený, _सोन_, --,
   {{0x3a2d0903,0xdddc04c3,0x9f5a00de,0xdb0300b5}},	//   roep_, _uvrš, cipó_, lenü,
   {{0x645758bd,0x628702ce,0x661d17b3,0x600065f2}},	//   _nixi, ksjo, ensk, _gömd,
   {{0x6b8365f3,0x444465f4,0x4ac10f17,0x3d114069}},	//   mang, _rh_, _शनिव, _देते_,
   {{0x6b8365f5,0x661d1bd3,0x645765f6,0x6445002a}},	//   lang, gnsk, _aixi, _ahhi,
   {{0x645765f7,0x69d965f8,0x444400a5,0x65660051}},	//   _bixi, _inwe, _ph_, rckh,
   {{0x661d016f,0xdb03024e,0x69c906a2,0x60000510}},	//   ansk, zený, ldee, _köme,
   {{0x69c9021d,0x9f430097,0x6445009e,0x78a965f9}},	//   odee, _bojí_, _dhhi, ltev,
   {{0x6b8365fa,0x645f00da,0x6d5b2884,0x2444013c}},	//   hang, _fuqi, _ngua, döme_,
   {{0x6b83251e,0x44440052,0x78a965fb,0xdb03024e}},	// [6580] kang, _th_, ntev, vený,
   {{0x6d5b50a1,0x6b8365fc,0x61f60c8b,0x61fd0223}},	//   _agua, jang, skyl, _elsl,
   {{0x6b834037,0x63bc65fd,0x78a965fe,0xdb03354e}},	//   dang, mern, htev, genü,
   {{0x63bc65ff,0xdd8f036b,0x3f870093,0x629c6600}},	//   lern, لوم_, ónur_, muro,
   {{0x69c9001c,0x6b835b26,0xdb091840,0xdbc600ab}},	//   ddee, fang, čnýc, _mööb,
   {{0x63bc1b41,0x0a6a372f,0x69d96601,0xdb183675}},	//   nern, ории_, _anwe, levé,
   {{0x661d6602,0xa3df00a1,0x629c6603,0x6d400035}},	//   ynsk, णात_, nuro, _wzma,
   {{0x63a901cc,0x69d50d91,0x9f5a027a,0x78a96604}},	//   đeni, भागी, cipò_, ftev,
   {{0x6b836605,0x6d406606,0xdb1a03e6,0x63bc0c60}},	//   bang, _uzma, _antô, kern,
   {{0x63bc11cb,0x69c9013a,0x629c6607,0x6b836608}},	//   jern, adee, kuro, cang,
   {{0x7bda6609,0xa5bb0391,0x64570042,0x7bc80395}},	//   _intu, olóx, _rixi, _iadu,
   {{0x629c001e,0x645700a2,0x661d00ac,0xb4950274}},	//   duro, _sixi, unsk, нимљ,
   {{0x7bc8660a,0xe9f700d4,0x629c1b39,0xd5a50026}},	//   _kadu, _інші_, euro, ग्गज,
   {{0x63bc279f,0x7bc802c2,0x7bca660b,0xf8bc111e}},	//   gern, _jadu, ndfu, ्टीप,
   {{0x629c660c,0x645701dd,0x545411b9,0x7a3e01f4}},	//   guro, _vixi, тврт, nëto,
   {{0x60cd02f6,0x6b830273,0x248901ef,0xf1bf006c}},	//   tvam, zang, _tvam_, _akár_,
   {{0x63bc660d,0x6287048c,0x6234453e,0x909901d3}},	// [6590] bern, ssjo, тету, яват_,
   {{0x60cd660e,0x6d5b660f,0x7bc86610,0x629c6611}},	//   rvam, _sgua, _nadu, buro,
   {{0x201301c2,0x629c6612,0x44316613,0x69c9081b}},	//   rixi_, curo, moz_, ydee,
   {{0x6b836614,0x7bda6615,0x44316616,0xed5917d1}},	//   wang, _antu, loz_, _kaži_,
   {{0x6b836617,0x7bc86618,0xcb693471,0x00000000}},	//   tang, _badu, пале_, --,
   {{0x7bc81c11,0x6cd2006c,0x44316619,0x28d2661a}},	//   _cadu, اقوا, noz_, तिनि,
   {{0x6b8304fb,0xeab100f5,0xfb8401c8,0xed590a61}},	//   rang, اعت_, тычн, _laži_,
   {{0x7bda661b,0x44310332,0x78a9661c,0x6d5b02fb}},	//   _entu, hoz_, ttev, _ugua,
   {{0x6b83661d,0x69c90903,0x0ff30380,0xf8c80028}},	//   pang, rdee, _आकाश_, _cứ_,
   {{0x7bc8661e,0x44310831,0x78a9661f,0x69c90d35}},	//   _gadu, joz_, rtev, sdee,
   {{0x681101c0,0x26d16620,0xc95900ad,0xe5a6019e}},	//   vědě, ízo_, _فلاش_, нини,
   {{0x6b816621,0x7bc85305,0x63bc6622,0x63a50211}},	//   _helg, _zadu, wern, _achn,
   {{0x6b81018d,0x7bc801d5,0x66ea013b,0x44316623}},	//   _kelg, _yadu, ləkl, foz_,
   {{0x629c6624,0xe1ff6625,0x6b810029,0x443101d7}},	//   turo, _aló_, _jelg, goz_,
   {{0xe7362701,0x63bc6626,0xed5900ea,0x00000000}},	//   _пеш_, rern, _daži_, --,
   {{0x63bc0830,0x629c6627,0xe1ff0079,0xdb0a000d}},	//   sern, ruro, _cló_, uffé,
   {{0x63bc6628,0xf8c801a5,0xa3cb00b1,0x629c6629}},	// [65a0] pern, _xứ_, _रोक_, suro,
   {{0x629c662a,0x59d10006,0xdb010473,0x44310300}},	//   puro, _दोसर, _eclé, coz_,
   {{0x225954b2,0x539b0122,0xdbd9008d,0x00000000}},	//   _fisk_, _ציטו, _ræðs, --,
   {{0x7bc800bf,0x9cca0733,0x60db02f6,0x9f4a01f7}},	//   _sadu, зыка_, _šume, _jobé_,
   {{0x6b81662b,0x261200a0,0xdce000ea,0x3ebf00f4}},	//   _belg, jšom_, _iemī, _ćute_,
   {{0x22590187,0x6b8133e9,0x6a670225,0xab380043}},	//   _zisk_, _celg, _sıfa, мплу_,
   {{0x59d10299,0x6b81662c,0xa91d03c9,0xf8c80019}},	//   _दोहर, _delg, važa, _sứ_,
   {{0x7bc8662d,0x3d11007c,0x4431662e,0x22590176}},	//   _wadu, _देवे_, zoz_, _xisk_,
   {{0x6b81662f,0x0c3a0037,0x44316630,0x48a700af}},	//   _felg, _فكرة_, yoz_, нтэм_,
   {{0x7bda4150,0x7a3e01f4,0x7bc808c7,0x6b816631}},	//   _untu, pëto, _uadu, _gelg,
   {{0x44316632,0xa3cb0bc1,0x290b25ec,0x66ea0095}},	//   voz_, _रोग_, úcar_, cəkl,
   {{0x63a502bf,0xf8c80019,0xa91d5210,0x8afb00a5}},	//   _schn, _tứ_, saža, _מהבי,
   {{0xa91d6633,0x443101d7,0x22590122,0xe61f0132}},	//   paža, toz_, _risk_, rnô_,
   {{0xdb016634,0xe1ff008d,0x00000000,0x00000000}},	//   _sclé, _sló_, --, --,
   {{0xed591269,0x60c66635,0xa91d05e2,0xa5bb2fba}},	//   _važi_, _askm, nažn, rnób,
   {{0x644e6636,0x28b70066,0x44315819,0x752203b0}},	//   ambi, _अहमि, soz_, _žoze,
   {{0x213901f4,0x0094002d,0x656d6637,0x44316638}},	// [65b0] _qysh_, литэ, _ifah, poz_,
   {{0xa91d00cd,0x00000000,0x00000000,0x00000000}},	//   kažn, --, --, --,
   {{0x22593723,0xa91d6639,0xfbdf0019,0x3eb80118}},	//   _tisk_, jažn, _đê_, _cprt_,
   {{0x6b81663a,0xdd95010b,0x2eee013c,0xc693016b}},	//   _selg, тады, äffa_, ראף_,
   {{0x3d11018d,0x6b81663b,0x61ef009e,0xf8bc0f17}},	//   _देशे_, _pelg, _iocl, ्टोप,
   {{0x26121ac4,0x527400f8,0xd11600a5,0xeb99663c}},	//   všom_, _جایز, _יקרה_, фик_,
   {{0xe9d1004f,0x63a3008a,0x6b8102ce,0x61ef023a}},	//   لغة_, _önnu, _velg, _kocl,
   {{0x6b81663d,0x2b5e009f,0x8d77663e,0x9f34093e}},	//   _welg, _egtc_, _سارا, _сесі,
   {{0x6b81663f,0x3f836338,0x6c5501d3,0x00000000}},	//   _telg, _keju_, _акау, --,
   {{0x3f83012f,0x399a0225,0x61ef009e,0x656d023c}},	//   _jeju_, tüsü_, _locl, _afah,
   {{0xfdf50939,0xd5dd00b4,0x3f830207,0xb17b0282}},	//   _आवास_, यांज, _meju_, _knåd,
   {{0x61ef6640,0x261202b2,0x2bd90099,0x27ee099e}},	//   _nocl, pšom_, ढाका, _eofn_,
   {{0x762300af,0x00000000,0x00000000,0x00000000}},	//   рмяз, --, --, --,
   {{0xd3720125,0xe7871129,0xccf200a5,0x99840067}},	//   شهر_, _чудо, סכם_, kimś_,
   {{0x69cb0703,0xa823006c,0x61ef009e,0x9f4a00ac}},	//   _kage, _لکھن, _bocl, _blbý_,
   {{0x61ef6641,0x00000000,0x00000000,0x00000000}},	//   _cocl, --, --, --,
   {{0xed590a78,0x59a60275,0x61ef6642,0x3d11007c}},	// [65c0] _kažu_, क्टर, _docl, _देले_,
   {{0x69cb1e8b,0x09cd00c8,0x61ef0608,0x9f8a0282}},	//   _lage, িউটা, _eocl, _lööf_,
   {{0x0d860f28,0xa3df0429,0x61ef004f,0x38ab3a92}},	//   влен, णार_, _focl, hør_,
   {{0xa91d148a,0xed59012e,0xbf220534,0x35aa0067}},	//   važn, _lažu_, _मशीन_, _काफ़,
   {{0xdca31f08,0x6da318d0,0x00000000,0x00000000}},	//   иаци, рича, --, --,
   {{0x69cb008c,0x60c46643,0x00000000,0x00000000}},	//   _aage, mwim, --, --,
   {{0xdee36644,0x69cb4368,0x394026e3,0x60c40024}},	//   _кори, _bage, _šis_, lwim,
   {{0x38ab0c61,0xa91d6645,0xddc90035,0x7c280207}},	//   før_, gažo, _mieś, _šmrč,
   {{0x69cb1abb,0x7e696646,0x38ab054e,0x81cc0083}},	//   _dage, _čepi, gør_, লাপ_,
   {{0xdb184b1d,0x6e220d14,0xa91d6647,0xdb1a07c0}},	//   leví, lnob, pažn, _matú,
   {{0x25df22f2,0x69cb0c60,0x60c401ae,0x656d6538}},	//   गाली_, _fage, hwim, _pfah,
   {{0xa3cb6017,0x60c42f10,0x69cb3916,0x6e220282}},	//   _रोज_, kwim, _gage, nnob,
   {{0x2d846648,0x69c06649,0xa3df0026,0x39400079}},	//   _meme_, meme, णाल_, _áis_,
   {{0x69c0664a,0x69cb664b,0x2d84664c,0x61ef664d}},	//   leme, _zage, _leme_, _socl,
   {{0xe8e00028,0x69cb01d0,0xdb180279,0x7af800b5}},	//   _đội_, _yage, levâ, nyvt,
   {{0xd9e50953,0xe610026e,0x656d002f,0x69c040bb}},	//   कायत_, _وشي_, _ufah, neme,
   {{0x51842739,0x69c0664e,0xa91d00cd,0xa184005f}},	// [65d0] руса, ieme, jažl, рысл,
   {{0xcbbd0083,0x69c0664f,0x753800a5,0x00000000}},	//   _ইচ্ছ, heme, _באחד_, --,
   {{0x69c06650,0x25a91330,0x2d840055,0x81b80831}},	//   keme, _kcal_, _beme_, চয়_,
   {{0x69c06651,0x78a06652,0x6e224135,0x25a901ed}},	//   jeme, kumv, gnob, _jcal_,
   {{0x69c06653,0x69cb6654,0xa91d024e,0x66ea00a8}},	//   deme, _rage, važo, fəkk,
   {{0x69cb6655,0x30da02b5,0x38ab1f8b,0x60da0070}},	//   _sage, _אַלע, vør_, _אַלג,
   {{0x69cb1ce3,0x69c06656,0x394601ef,0x41aa0355}},	//   _page, feme, _azos_, ङ्कस,
   {{0x69c06657,0x683d0443,0xb05b013c,0x38ab082b}},	//   geme, mèdi, _osäk, tør_,
   {{0xa91d6658,0x26c70009,0xdd0300ea,0x683d01f7}},	//   ražo, _ssno_, ārēj, lèdi,
   {{0xfbc000c4,0x2d846659,0x95fe0026,0x69cb0f93}},	//   _एसएम, _zeme_, ॉफ्ट_, _wage,
   {{0x69cb665a,0x69c0665b,0x3dcd0118,0x4423665c}},	//   _tage, beme, _kaew_, dnj_,
   {{0x69c0665d,0x8afa1804,0x78a0665e,0x7c2d0098}},	//   ceme, _אלעז, bumv, éarf,
   {{0x81cc0b52,0xa3df00e7,0x200302a7,0x00000000}},	//   লাম_, णां_, _olji_, --,
   {{0x3a3f665f,0xa91d01ba,0xb8920037,0x59bd012f}},	//   llup_, nažm, _الوع, ्यकर,
   {{0x3ea1007c,0x26c700d7,0x75ff01f4,0x23275086}},	//   juht_, _usno_, _gëzo, гори_,
   {{0x60db3c4a,0x25a90139,0xa3d400be,0x00000000}},	//   _šuma, _gcal_, _सोर_, --,
   {{0x66040657,0xc0e347c5,0xb1466660,0x6e2200d5}},	// [65e0] _ilik, ботк, унал, vnob,
   {{0x69c06661,0x7f865b76,0x2d846662,0xdee61b5d}},	//   zeme, الان, _seme_, лози,
   {{0x66046663,0x69c02c47,0x645e0159,0x2cad0069}},	//   _klik, yeme, _iipi, _aqed_,
   {{0x831b02b5,0x69c012c3,0x78a008bd,0x0caa233a}},	//   _טויז, xeme, yumv, етки_,
   {{0x645e000e,0x22406664,0x69c00e15,0x628e0990}},	//   _kipi, mlik_, veme, lsbo,
   {{0x22406665,0x66040159,0x3e86004f,0x443a6666}},	//   llik_, _llik, _مشرف, _jkp_,
   {{0x66046667,0x2d846668,0x69c01691,0x645e0b65}},	//   _olik, _teme_, teme, _mipi,
   {{0x22406669,0x201a666a,0x200f00ea,0x777a006d}},	//   nlik_, lipi_, īgie_, wbtx,
   {{0x69c0666b,0xdd8f0754,0x22400173,0x2df700a5}},	//   reme, _رول_, ilik_, _עצמך_,
   {{0x69c0666c,0x645e666d,0x6604666e,0xa81402c4}},	//   seme, _nipi, _alik, рдош,
   {{0x10370052,0x2240666f,0x69c06670,0xf1bf01ba}},	//   רטים_, klik_, peme, ššie_,
   {{0x0f570122,0x443a6671,0x628e071b,0x201a1bba}},	//   טיים_, _akp_, dsbo, hipi_,
   {{0x22406672,0x645e4296,0x629c6673,0x628e32c5}},	//   dlik_, _bipi, erro, esbo,
   {{0x66046674,0x22406675,0x645e6676,0x600001ff}},	//   _elik, elik_, _cipi, _sömn,
   {{0x645e0452,0x22406677,0x28d20355,0x66046678}},	//   _dipi, flik_, तिवि, _flik,
   {{0xdb0a6679,0x2240667a,0xbb3b0070,0x44f517f9}},	//   lefó, glik_, געלי, _впис,
   {{0x3015667b,0xa6e1008d,0x443a1371,0x657d667c}},	// [65f0] адар, óðve, _fkp_, mbsh,
   {{0x645e02b3,0x443a667d,0xeae407b5,0x660412b8}},	//   _gipi, _gkp_, _कपूत_, _zlik,
   {{0x2240667e,0x764d20fb,0xdb0a01ae,0x656f07e5}},	//   blik_, _khay, gefü, occh,
   {{0x248d667f,0x645e034d,0x629a0009,0x764d0107}},	//   šemu_, _zipi, štoc, _jhay,
   {{0xfce519b6,0x764d10d6,0x765f013b,0xb60600ac}},	//   роло, _mhay, _miqy, _unáš,
   {{0xb09a0052,0x61ed240f,0x201a12c3,0x3209011e}},	//   _בישר, ljal, cipi_, lhay_,
   {{0x5fce0803,0x6d9c01ba,0x764d0159,0x66ea013b}},	//   _होटल, _sťaž, _ohay, bəki,
   {{0xe9d964cc,0x3209011e,0xa5bb002a,0x5c7510b4}},	//   тки_, nhay_, lióf, _влат,
   {{0xa8055dbe,0xdb0300f7,0x3866027a,0x6e3b1596}},	//   изил, igné, _cuor_, _ikub,
   {{0x660432dc,0x764d007b,0x22400463,0x61ed073c}},	//   _slik, _ahay, zlik_, hjal,
   {{0xb4de1371,0x66046680,0x22406681,0x764d00e7}},	//   णम्_, _plik, ylik_, _bhay,
   {{0x645e0099,0x764d6682,0x7bc36683,0x3866027a}},	//   _sipi, _chay, lenu, _fuor_,
   {{0x6e3b000e,0x61ed6684,0x764d0118,0x04465568}},	//   _mkub, djal, _dhay, иемн,
   {{0x7bc3007c,0x656f0382,0x628e17ad,0x2ba90e61}},	//   nenu, acch, tsbo, च्चा,
   {{0x6e3b39a7,0x645e000e,0x7e67006d,0xdb0a2613}},	//   _okub, _vipi, _nujp, lefò,
   {{0x66043ec8,0x61ed0093,0x628e427a,0x22401b4a}},	//   _ulik, gjal, rsbo, ulik_,
   {{0x22406677,0x6564070b,0x9f866685,0xa0a60f6d}},	// [6600] rlik_, _igih, игад, разд,
   {{0x22406686,0x6e3b6376,0x6aa301ae,0x15e400a1}},	//   slik_, _akub, kunf, गावर_,
   {{0x2ba90569,0x201a6687,0x6d4900d7,0xfe720d47}},	//   च्छा, ripi_, _azea, زدا_,
   {{0x44386688,0x320902e9,0x61ed6689,0x7a3e01f4}},	//   lor_, chay_, cjal, pëti,
   {{0xfbe2000c,0x0cd4668a,0x6e291f55,0x44380088}},	//   पालम, солю, _djeb, oor_,
   {{0x7bc3668b,0x4438668c,0x6e3b001c,0x2c6b10db}},	//   genu, nor_, _ekub, _død_,
   {{0x6b8a4f47,0x4438081d,0x6d4901a3,0x20180107}},	//   rafg, ior_, _ezea, _imri_,
   {{0x4438668d,0xada30f94,0x6da30200,0x6000008a}},	//   hor_, _масл, _миса, _mömm,
   {{0x4438668e,0xed5703ad,0xdddc0129,0x7e6008dd}},	//   kor_, _вот_, _kvrž, _iimp,
   {{0x7e600f20,0x61ed668f,0x44382ac2,0x764d6690}},	//   _himp, zjal, jor_, _shay,
   {{0x4fd902b5,0x764d012f,0x7c384034,0x7e606691}},	//   אַרד, _phay, movr, _kimp,
   {{0x7e60035f,0x7c3802a7,0x656f0036,0xa5bb1459}},	//   _jimp, lovr, ucch, cnól,
   {{0x44380044,0xd9431286,0x7e6004f6,0x85470c8a}},	//   for_, _деци, _mimp, рэне,
   {{0x44386692,0x7c386693,0x3cee004e,0x60db011c}},	//   gor_, novr, _आपने_, _šumo,
   {{0x32096694,0x3f87008a,0xd838108a,0xe694004f}},	//   thay_, ðnum_, moč_, _البد,
   {{0x2018000e,0x7df5073f,0x60000282,0x764d0027}},	//   _amri_, _आवेग_, _dömm, _uhay,
   {{0xc95302b5,0x7c380169,0x6fb9027a,0x6d406695}},	// [6610] ַמע_, kovr, лгар_, _nyma,
   {{0x6e29025c,0x61ed19e4,0x6e3b6696,0x6b8833d4}},	//   _sjeb, sjal, _skub, _nedg,
   {{0xe8e00028,0x7c381fe5,0x6d406697,0x7bc32c99}},	//   _đời_, dovr, _ayma, venu,
   {{0x20186698,0x68fb012f,0x7e603413,0x6d40008c}},	//   _emri_, yyud, _cimp, _byma,
   {{0x3d110953,0xbc1901c8,0x7e606699,0x6d40001e}},	//   _देखे_, лікі_, _dimp, _cyma,
   {{0x00f602b8,0x661d669a,0x7c3801a0,0xd83808b7}},	//   _המשך_, hisk, govr, joč_,
   {{0x7bc3669b,0xa91d669c,0x7d0600ab,0x6d400c53}},	//   renu, maži, _üksn, _eyma,
   {{0x6e3b3069,0x290d03cb,0x661d669d,0xa91d04c3}},	//   _ukub, tzea_, jisk, laži,
   {{0x7bc31096,0x443835fa,0x6d4000e9,0xdb1800a0}},	//   penu, yor_, _gyma, revá,
   {{0x4438669e,0x30da02b5,0xb8cf0af6,0x290d0279}},	//   xor_, אַטע, _ओम_, rzea_,
   {{0x661d669f,0x98b80228,0x7e6066a0,0xab5c013a}},	//   fisk, ārā_, _yimp, _daļs,
   {{0x661d04ca,0xdb010037,0x2cbf022e,0x443866a1}},	//   gisk, _gclá, _kpud_, wor_,
   {{0x5a0c0070,0xa91d0627,0x12b90033,0x00000000}},	//   _בלאַ, kaži, ুমোদ, --,
   {{0xdd990260,0xec35016b,0xd9e5193c,0x00000000}},	//   _blňk_, מאָר_, कावत_, --,
   {{0x443866a2,0x81cc0083,0x00000000,0x00000000}},	//   ror_, লাস_, --, --,
   {{0x63bb10d1,0x661d66a3,0x7cde0395,0x6564007b}},	//   đuna, cisk, _hărţ, _ugih,
   {{0x443866a4,0x7e6066a5,0x03a6079d,0x32001505}},	// [6620] por_, _rimp, _липо, rkiy_,
   {{0x7e6902c6,0xa91d66a6,0x44380510,0x00000000}},	//   _čepr, gaži, qor_, --,
   {{0x7e604367,0x2cbf66a7,0xddcb00cb,0x8d1a00d1}},	//   _pimp, _apud_, _šišm, گزار_,
   {{0x6da6622d,0x81cc0033,0x249f00cd,0xa5bb1186}},	//   сида, লাহ_, šume_, ciód,
   {{0x7c380a78,0xc17300a5,0x8c4612a0,0xe1ff00ee}},	//   tovr, _מחר_, беде, _diód_,
   {{0x2018000e,0xdee60e60,0x7e6066a8,0x661d66a9}},	//   _umri_, _логи, _wimp, zisk,
   {{0x7e6066aa,0x6d40004e,0x6b880044,0x00000000}},	//   _timp, _wyma, _vedg, --,
   {{0x18741172,0x98742626,0x3f8a0054,0x6e390069}},	//   огия, олиц, _hebu_, cowb,
   {{0xf8ad132d,0xd8380c21,0xd7fa32dd,0x661d3981}},	//   نکو_, toč_, гун_, visk,
   {{0x661d004e,0x7cde002d,0x3f8a022f,0xdb1a00ac}},	//   wisk, _cărţ, _jebu_, _zatý,
   {{0x661d66ab,0x290266ac,0x4427036a,0xc5e40066}},	//   tisk, ška_, _ın_, गांठ_,
   {{0x6f0900b8,0xa91d063c,0xd838008b,0x3f8a03da}},	//   _řeck, zaži, soč_, _lebu_,
   {{0x661d33aa,0x2ca6129d,0x05aa01c0,0x3f980116}},	//   risk, nuod_, _कारब, _odru_,
   {{0x661d0a09,0x3f8a0877,0x25ad003c,0x195700a5}},	//   sisk, _nebu_, żel_, _הבדל_,
   {{0xdb1a02c9,0xa91d00d8,0x00000000,0x00000000}},	//   _natü, važi, --, --,
   {{0xdb1a00b5,0x7a3e0031,0x25090088,0x68e4009e}},	//   _ható, pëtu, _نرخی_, _àids,
   {{0xa5bb0d2e,0x3f8a012e,0xdb180196,0x60990919}},	// [6630] riód, _bebu_, levä, شناس_,
   {{0x3f670c65,0x2007008d,0x3f8a66ad,0x00000000}},	//   стаб, óni_, _cebu_, --,
   {{0x3f8a66ae,0xa91d00c5,0x2cbf0345,0xdb1800c3}},	//   _debu_, raži, _spud_, nevä,
   {{0x7cd922f1,0xdd9401c8,0x8d870086,0xa91d2a28}},	//   имер_, зацы, сужд, saži,
   {{0xa91d00d8,0x69a20722,0xda7801ba,0x75ff0031}},	//   paži, _गाजी, _atď_, _vëzh,
   {{0x3f8a028b,0xdb1800c3,0x00000000,0x00000000}},	//   _gebu_, kevä, --, --,
   {{0x81cc00c8,0x93fc02b5,0xfbd0017e,0xb05b0282}},	//   লার_, רלוי, عته_, _dsät,
   {{0x60dd02c4,0x05d90437,0x3f98023a,0x00000000}},	//   _krsm, _बोलब, _zdru_, --,
   {{0x2d8f66af,0x26dc18af,0x75ff0031,0x7cde002d}},	//   mage_, _arvo_, _gëzi, _părţ,
   {{0xdb1a1423,0x2d8f66b0,0x2ca0004f,0x115c02b5}},	//   _cató, lage_, áide_, נדזע,
   {{0x65c63c3e,0x00000000,0x00000000,0x00000000}},	//   обна, --, --, --,
   {{0x26dc0254,0x2d8f20ac,0x998400b5,0x361600d4}},	//   _drvo_, nage_, _فلمو, ієнт,
   {{0x893705bc,0x195900d8,0x67d50142,0xa3ce00b4}},	//   _اعضا, _тады_, _моду, _रसद_,
   {{0xa3d40387,0x00000000,0x00000000,0x00000000}},	//   _सोख_, --, --, --,
   {{0xe36302ce,0x0443365b,0x3f8a0260,0x7c240079}},	//   дкри, ферн, _rebu_, éiri,
   {{0x2167258d,0x2d8f66b1,0x91e307fa,0xdb1a0359}},	//   жити_, jage_, мосе, _katò,
   {{0x2d8f66b2,0x81cc0033,0x00000000,0x00000000}},	// [6640] dage_, লাল_, --, --,
   {{0x798b3c83,0xdfa60037,0x66ea00a8,0x00000000}},	//   _legw, تحري, cəks, --,
   {{0x2d8f0248,0x3f8a02c4,0xee3a17d0,0xa91d1ada}},	//   fage_, _vebu_, анж_, mažu,
   {{0x3f8a05d3,0xee3a66b3,0x2d8f66b4,0xe0df0359}},	//   _webu_, шне_, gage_, _dyòb_,
   {{0x61e666b5,0x3f8a0ce8,0x3f6a2d93,0x00000000}},	//   _inkl, _tebu_, _виго_, --,
   {{0xe7ae01c0,0xa91d005f,0x7d06018d,0x00000000}},	//   ज्ञप, nažu, _üksm, --,
   {{0x3d1a006a,0xe8e00028,0xdb1a0831,0x2d8f66b6}},	//   _मेरे_, _đối_, _rató, bage_,
   {{0x2d8f66b7,0x0d860ffd,0x00000000,0x00000000}},	//   cage_, _флан, --, --,
   {{0xdb1a66b8,0x225e0187,0x1d0700c3,0xc7c61e9c}},	//   _pató, ítky_, _дети_, осни,
   {{0x26dc66b9,0xd7fa039e,0xb8f200ab,0xdb1866ba}},	//   _prvo_, руи_, _हई_, tevä,
   {{0xdb1a2587,0x61e61c9b,0xec1301cb,0x45d510b4}},	//   _obté, _onkl, _تولد, понс,
   {{0xa5bb66bb,0x1b130033,0xdb1866bc,0x91da0067}},	//   dióc, _ঢুকে_, revä, _पोलै,
   {{0xdb1866bd,0x00000000,0x00000000,0x00000000}},	//   sevä, --, --, --,
   {{0x61e6318b,0x67d40009,0xa91d02c4,0x998d004e}},	//   _ankl, _хоку, gažu, kieś_,
   {{0x2d8f02e1,0xf4850416,0x72d441f8,0xa5bb0098}},	//   yage_, _کابی, морф, hnói,
   {{0xceeb00d1,0x2d8f259e,0x63be0065,0xba9b0070}},	//   یران_, xage_, _ebpn, יסלי,
   {{0x3d1a05e7,0x2d8f1691,0x2c70009e,0x00000000}},	// [6650] _मेले_, vage_, _nàd_, --,
   {{0x61e666be,0x35b10084,0x6b9a008c,0x00000000}},	//   _enkl, _झाड़, _ndtg, --,
   {{0x64471851,0x9f51027a,0x2489008c,0x00000000}},	//   mlji, _alzò_, _hwam_, --,
   {{0x24890a75,0x7c2a0051,0x00000000,0x00000000}},	//   _kwam_, enfr, --, --,
   {{0x2d8f66bf,0x7c2a008a,0xdb030079,0xa2d300b4}},	//   rage_, fnfr, rgní, डिक्,
   {{0x798b66c0,0x64475e51,0x2d8f66c1,0x60cd43e9}},	//   _segw, nlji, sage_, mwam,
   {{0x27e90019,0x61e60523,0x629566c2,0x2c5d0260}},	//   _đan_, _ynkl, nszo, _jňdi_,
   {{0xdb1a0176,0x600002b1,0x629502a2,0xc7b800f4}},	//   _patò, _römi, iszo, viđa_,
   {{0x6447219c,0x24890107,0x00000000,0x00000000}},	//   klji, _nwam_, --, --,
   {{0x798b5bb3,0x2a6c0009,0x629507cf,0x00000000}},	//   _wegw, _fudb_, kszo, --,
   {{0xb8f266c3,0xe7394697,0x64470496,0x24891096}},	//   _है_, сен_, dlji, _awam_,
   {{0x60cd66c4,0x629566c5,0x00000000,0x00000000}},	//   kwam, dszo, --, --,
   {{0xa87900c2,0x5fac00a1,0x998d0035,0x00000000}},	//   _פאַר, _चालल, zieś_, --,
   {{0x387f0b0e,0x987a0319,0x6447008b,0x78a900de}},	//   mpur_, _האסט, glji, muev,
   {{0x91e605f2,0x387f0093,0x824a0037,0x629500b5}},	//   пове, lpur_, مشرف_, gszo,
   {{0x249f0029,0x24890107,0xdb1200b5,0xe7f500b8}},	//   šuma_, _fwam_, égér, ेसका_,
   {{0x78a9548d,0x644710ec,0xdb0a0279,0x7e7b26f9}},	// [6660] nuev, blji, lefô, _čupa,
   {{0xa3d40bc1,0x81cc00c8,0x13a809b9,0x20cd0009}},	//   _सोच_, লাই_, _بندی_, _dži_,
   {{0x24890051,0x0eb9010b,0x00000000,0x00000000}},	//   _zwam_, жучы_, --, --,
   {{0xe7e20992,0x7d0600ab,0x60cd0186,0x61e602b1}},	//   _कोना_, _üksk, bwam, _unkl,
   {{0xdd8f16e6,0x94000026,0x16a80066,0x75ff0031}},	//   اوه_, _उवाच_, _कम्ब, _gëzu,
   {{0xa5bb0079,0xddc90067,0x00000000,0x00000000}},	//   rnói, _cheł, --, --,
   {{0xb05b081b,0x7c2a0d3e,0x3961013b,0x671a0354}},	//   _isäp, rnfr, ərsə_, _फेंक_,
   {{0x644703ab,0x7e9b00a5,0x00000000,0x00000000}},	//   zlji, _לסלו, --, --,
   {{0xdca6034b,0xe8e00023,0xdca324c8,0x3ebf00cd}},	//   _хази, _đồi_, _пати, _ćuti_,
   {{0x779204e8,0x6e2266c6,0xa5bb01ef,0xeb9700af}},	//   ریبا, liob, nnóv, _ниу_,
   {{0x64471851,0xbb4a22c4,0x7bca0054,0x660f01f4}},	//   vlji, _الان_, mefu, thck,
   {{0x6a1605bc,0x6e2266c7,0x00000000,0x00000000}},	//   _عبار, niob, --, --,
   {{0x64471851,0x7e6e01e8,0x7d022d15,0x6aaa1f2c}},	//   tlji, _lubp, nyos, luff,
   {{0x629500b5,0x7bca66c8,0x7bd85aa0,0x7e7c146c}},	//   tszo, nefu, ndvu, _otrp,
   {{0x64471851,0x9f5801f4,0xd7bb00a5,0xb3540166}},	//   rlji, _dorë_, _הצור, екрш,
   {{0x6447008b,0xe1f3006c,0x60cd66c9,0x62955423}},	//   slji, رسز_, twam, rszo,
   {{0x64470496,0xe1340409,0x660d66ca,0x6295006c}},	// [6670] plji, енты, _ilak, sszo,
   {{0x60cd01d0,0x660d0093,0x00000000,0x00000000}},	//   rwam, _hlak, --, --,
   {{0x660d66cb,0x442366cc,0xd341006c,0x7bca66cd}},	//   _klak, mij_, _شہری, defu,
   {{0xe0df0028,0x442366ce,0xb8120083,0xf1bf0183}},	//   _trò_, lij_, িচিত_, _ubá_,
   {{0x660d66cf,0x20cd33ee,0x23700055,0x394666d0}},	//   _mlak, _uži_, _çojë_, _nyos_,
   {{0xce6b0a87,0x442366d1,0x7bca66d2,0x224966d3}},	//   _град_, nij_, gefu, llak_,
   {{0x660d0a78,0x3946121e,0x7d02011e,0x80db0efa}},	//   _olak, _ayos_, ayos, निवे,
   {{0x4423006f,0x224951c0,0x2ca00009,0x2a660160}},	//   hij_, nlak_, šida_, _ciob_,
   {{0xa91d01ba,0x7bca66d4,0x200e010b,0x442366d5}},	//   važs, befu, škių_, kij_,
   {{0x660d66d6,0x99dd0187,0x3946067f,0x44230223}},	//   _alak, plňo, _dyos_, jij_,
   {{0x660d66d7,0x442366d8,0x224966d9,0x7c23017b}},	//   _blak, dij_, klak_, minr,
   {{0x387f66da,0x629a005f,0x7c2316c9,0x00000000}},	//   ppur_, štok, linr, --,
   {{0x660d28d2,0x2101010b,0x442366db,0x78a900f6}},	//   _dlak, nčią_, fij_, quev,
   {{0x660d5c06,0xb05b022a,0x442366dc,0x6e2201ed}},	//   _elak, _spän, gij_, ziob,
   {{0x7bc166dd,0x660d66de,0x00000000,0x00000000}},	//   _mblu, _flak, --, --,
   {{0x3cee02cb,0xa5bb01ba,0x3a2d66df,0x224966e0}},	//   _आपले_, lión, nnep_, glak_,
   {{0x7e7c0877,0x442366e1,0x7bc166e2,0x3946006d}},	// [6680] _strp, bij_, _oblu, _xyos_,
   {{0xa5bb0391,0x442302c6,0x7d020054,0x7c2d0037}},	//   nión, cij_, vyos, éarl,
   {{0x44444cca,0x216a0573,0x7bca0093,0x22491328}},	//   _ik_, _мини_, vefu, blak_,
   {{0xe9d9004e,0x7bc166e3,0x00000000,0x00000000}},	//   jdź_, _ablu, --, --,
   {{0x09bc00c8,0x444466e4,0x6e2249fb,0xdd990107}},	//   _অফলা, _kk_, riob, _alňs_,
   {{0x6aaa08c3,0x444466e5,0x7d0222fb,0x7e6e006d}},	//   tuff, _jk_, ryos, _tubp,
   {{0xa06766e6,0x7e7c0a69,0x645c00f1,0xa5bb219d}},	//   _цара_, _utrp, imri, dión,
   {{0x444466e7,0x442366e8,0x6aaa66e9,0xa2a609b4}},	//   _lk_, zij_, ruff, _छिन्,
   {{0x6aaa66ea,0xeb9a0370,0x2d8666eb,0x7bca66ec}},	//   suff, _миа_, mboe_, pefu,
   {{0x4444070b,0xa5bb016f,0x76441944,0x31570070}},	//   _nk_, gión, _akiy, ויפן_,
   {{0xe8e00028,0x7c3d0093,0x2fd866ed,0x44231f45}},	//   _đổi_, _ísra, _marg_, vij_,
   {{0x444466ee,0x2fd866ef,0x09061999,0x44230051}},	//   _ak_, _larg_, _опен, wij_,
   {{0x442366f0,0x224901bf,0x9f58000d,0x69c23842}},	//   tij_, vlak_, _doré_, _iboe,
   {{0xa5bb3612,0x3fd90083,0x68e2006c,0xe1ff0300}},	//   ción, _দক্ষ, _irod, _ción_,
   {{0x444466f1,0x442366f2,0x660d07cb,0xdb1a00b8}},	//   _dk_, rij_, _tlak, _obtí,
   {{0x444466f3,0x68e266f4,0x442366f5,0x35f80037}},	//   _ek_, _krod, sij_, _يريد_,
   {{0x444466f6,0x44230a66,0x224966f7,0x290466f8}},	// [6690] _fk_, pij_, rlak_, nyma_,
   {{0x68e260cc,0x22496276,0x00000000,0x00000000}},	//   _mrod, slak_, --, --,
   {{0x2904524e,0x7c2d0037,0x2bd9143a,0xa19515df}},	//   hyma_, éarm, _योगा, _панч,
   {{0x68e266f9,0x1cb90082,0xa01b0e80,0x44443c79}},	//   _orod, كاتب_, _stöd, _zk_,
   {{0xdb09033a,0x2fd801d5,0x4444278e,0x30790070}},	//   čníc, _farg_, _yk_, _מאָנ,
   {{0xa5bb043f,0x320900fe,0xe9d9004e,0x2fd866fa}},	//   xión, lkay_, wdź_, _garg_,
   {{0x644501a2,0xbb42150d,0xaa4501f2,0x4421228c}},	//   _mkhi, лешк, некл, _mmh_,
   {{0xe7d73914,0x656d061e,0x61fd0228,0xf8af0416}},	//   _भोजप, _ngah, _josl, لکت_,
   {{0xa5bb002a,0x68e200f1,0x44210341,0x60000282}},	//   tión, _crod, _omh_, _göms,
   {{0x644501e8,0x61fd0e54,0x656d0010,0x68e20035}},	//   _nkhi, _losl, _agah, _drod,
   {{0xf6260dde,0x3f9106a2,0x9991006c,0x68e209b3}},	//   едно, _mezu_, őző_, _erod,
   {{0x444466fb,0xa5bb1a71,0x64450224,0x61fd0029}},	//   _sk_, sión, _akhi, _nosl,
   {{0xe1ff01ef,0x68e266fc,0x7e690051,0xa5bb002a}},	//   _pión_, _grod, _miep, pión,
   {{0x7e693bc2,0x69d966fd,0x93460009,0x4444007a}},	//   _liep, _hawe, енге, _qk_,
   {{0x69d92ada,0xa5bb08c0,0xed45006c,0x425666fe}},	//   _kawe, gnós, _چھ_, етат,
   {{0x7e69004e,0xed45026b,0x69db66ff,0x78bb00d8}},	//   _niep, _نھ_, ndue, otuv,
   {{0x61fd2190,0x78bb6700,0x3eb86701,0x22406702}},	// [66a0] _dosl, ntuv, _sqrt_, roik_,
   {{0x44440122,0x69d9001e,0x24800dc3,0x3209010d}},	//   _uk_, _lawe, _itim_, akay_,
   {{0x93b70122,0x78bb073c,0x2fd86703,0x3f9101a3}},	//   _אליו_, htuv, _varg_, _dezu_,
   {{0x69d96704,0x7e690035,0x78bb010b,0xf1bf01ba}},	//   _nawe, _ciep, ktuv, íšte_,
   {{0x7e690136,0x101600d8,0x2d860a8a,0x2fd86705}},	//   _diep, _зьвя, rboe_, _targ_,
   {{0x2ca66706,0x62810300,0x2ca00009,0xf537016b}},	//   rrod_, ílog, šido_, ענסי_,
   {{0xada62f19,0x5fc60026,0x68e26707,0x69d96708}},	//   _павл, _रॉयल, _srod, _bawe,
   {{0x2ca66709,0x600000a8,0xd9bc0026,0x69d9670a}},	//   prod_, _gömr, ्जेट, _cawe,
   {{0x2480006f,0x69d9670b,0x3f91010a,0x62530132}},	//   _ntim_, _dawe, _yezu_, nçoa,
   {{0x4c9b0122,0x25a009df,0x62530279,0x2b16002d}},	//   _משמע, _adil_, içoa, _пьер,
   {{0x69db0310,0x3209596c,0xfaa30009,0x69bd00a1}},	//   bdue, ykay_, _бахо, व्ही,
   {{0x7bda0657,0x68e2408c,0xa5bb0473,0x69d9670c}},	//   _hatu, _trod, ciól, _gawe,
   {{0x7bda45a9,0x68e2004e,0x61fd670d,0x765d0a8c}},	//   _katu, _urod, _rosl, rmsy,
   {{0x7bda0f1a,0x78ad0187,0x69d9670e,0x69c00345}},	//   _jatu, ňový, _zawe, lfme,
   {{0x69d9670f,0x3f911a8a,0xe7ed2516,0x00000000}},	//   _yawe, _rezu_, जारा_, --,
   {{0x7bda6710,0x80ca0083,0x656d04fb,0x00000000}},	//   _latu, রিন্, _ugah, --,
   {{0x59c2052f,0x32091008,0x7e696711,0x1fa71858}},	// [66b0] व्यर, rkay_, _riep, ерег,
   {{0xb4bf1a75,0x320902e9,0x60db08b3,0xa01b033b}},	//   ीबी_, skay_, _šums, _stöb,
   {{0x4fc400d8,0x7e696712,0x3f910a78,0xbe8800af}},	//   ыста, _piep, _vezu_, есче_,
   {{0x7bda393e,0x78bb010b,0x09c50033,0xe7e200b4}},	//   _aatu, ytuv, _শোনা, _कोसा_,
   {{0x7bda58c6,0x629a0187,0x44310118,0xddc0002d}},	//   _batu, átov, onz_, _simţ,
   {{0x7bda09df,0x99dd01c0,0x69d900bf,0x69c00051}},	//   _catu, plňk, _sawe, efme,
   {{0x629a0690,0xf771064e,0x69d96713,0x40340f08}},	//   štov, یاد_, _pawe, _серс,
   {{0x09e52aa5,0x9f5807e5,0x78bb00c3,0xbca5026e}},	//   тоин, _morì_, ttuv, _لمري,
   {{0x69db0291,0x290b016f,0x7bda6714,0x78bb0f99}},	//   rdue, áca_, _fatu, utuv,
   {{0x7bda0efc,0x69d96715,0x78bb1638,0xd70900c3}},	//   _gatu, _wawe, rtuv, дное_,
   {{0x24806716,0x78bb6717,0x290b0121,0x69d91019}},	//   _stim_, stuv, šca_, _tawe,
   {{0x7bda6718,0xc3250831,0xc60a0831,0xddc0005f}},	//   _zatu, _মুভি_, শোনা_, _kimš,
   {{0x7bda3004,0x59da0567,0x79892cee,0x7d0600ab}},	//   _yatu, _मोटर, mbew, _ükst,
   {{0x33d50823,0x2bc42095,0x79892b87,0xbf210099}},	//   ліст, ल्पा, lbew, _मधून_,
   {{0x41b612a2,0xd4670202,0x78a96719,0x00000000}},	//   ксат, тире_, lrev, --,
   {{0x2011027a,0x260201ef,0x798909b0,0x44310110}},	//   _alzi_, _vóos_, nbew, anz_,
   {{0xf9920779,0x4127519d,0x78a90185,0x00000000}},	// [66c0] ירן_, вото_, nrev, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a90a75,0xaad00066,0x644e3436,0xa01b02b1}},	//   hrev, _थैंक, mlbi, _stöc,
   {{0x78a9671a,0xf53f5c1b,0x798901e4,0x62530176}},	//   krev, mgår_, jbew, lçon,
   {{0x7bda671b,0x798902a2,0xb5fb2d95,0x00000000}},	//   _patu, dbew, lmác, --,
   {{0x6253671c,0x78a94d91,0x09bc112b,0x2ac60274}},	//   nçon, drev, ्ज्य, вљив,
   {{0x3cee006a,0x63a10035,0x7bda052a,0x629c03c1}},	//   _आपके_, ólni, _vatu, nsro,
   {{0x7bda0657,0xc33300c2,0x58d81d80,0x629c01ae}},	//   _watu, יוו_, едия_, isro,
   {{0xd83a00c7,0xe7860043,0x78a9671d,0x9f585459}},	//   дэн_, куно, grev, _morí_,
   {{0xad1b0122,0xa5bb00b5,0x7bda021d,0x3f8500be}},	//   _חומר, ciój, _uatu, _õlut_,
   {{0x65951e93,0x629c0009,0x7e7b0207,0x00000000}},	//   лану, jsro, _čupk, --,
   {{0xf53f01b4,0xe7e20864,0x644e0067,0xa926021d}},	//   dgår_, _कोरा_, elbi, _идел,
   {{0x78a90370,0x00000000,0x00000000,0x00000000}},	//   crev, --, --, --,
   {{0xa3a40202,0xecc40033,0x3cf500a1,0xa5bb021d}},	//   ијск, _এছাড, ्हते_, anóp,
   {{0x2bc4671e,0x442d01cc,0x07a3052c,0xfbc40577}},	//   ल्या, đe_, _тајн, ल्यम,
   {{0x22841d67,0x00000000,0x00000000,0x00000000}},	//   рург, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [66d0] --, --, --, --,
   {{0x4427671f,0x2bc40324,0xa3d503e6,0x629c0298}},	//   _ön_, ल्मा, _сооч, bsro,
   {{0x78a96720,0xaca30023,0x626706c9,0xddc002a7}},	//   zrev, _trừn, _لاحق, _simš,
   {{0x78a901e9,0x00000000,0x00000000,0x00000000}},	//   yrev, --, --, --,
   {{0x61ef6721,0xfd1001b2,0x23c00edf,0xada4010b}},	//   _incl, يجه_, श्वद, раіл,
   {{0xf09f0176,0x61ef07c0,0x1c4402a4,0xe7e20d12}},	//   _ivà_, _hncl, анім, _कोला_,
   {{0xe4580070,0x63b500ea,0x79896722,0xdb14008d}},	//   דיגט_, igzn, tbew, ðaðu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79895fea,0x60120a8a,0x00000000,0x00000000}},	//   rbew, _hæma, --, --,
   {{0x78a96723,0x7d0403ad,0x79896724,0xa3e20067}},	//   rrev, äise, sbew, _नों_,
   {{0x61ef6725,0x78a9029e,0x63b8013c,0x7989000b}},	//   _oncl, srev, _övni, pbew,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8ee4a7c,0x18a50336,0x98a50265,0xb05b00c3}},	//   _ул_, _салм, _силе, _epäi,
   {{0x61ef0453,0xe61202fd,0x629c245b,0xe7876726}},	//   _ancl, _گشت_, tsro, _рудо,
   {{0x625352af,0xdceb003c,0xe9ff0023,0x60db0355}},	//   rçon, bagħ, _ngẫm_, _šump,
   {{0xb5fb6727,0x00000000,0x00000000,0x00000000}},	//   rmác, --, --, --,
   {{0x6253000d,0x7646010b,0x463b0070,0x629c6728}},	// [66e0] pçon, moky, _רעפע, ssro,
   {{0x28a600ab,0x61ef05f0,0x76466729,0x00000000}},	//   _खिसि, _encl, loky, --,
   {{0x442a672a,0x03d70070,0xdd990097,0x9f5801f7}},	//   mib_, _גוים_, _soňa_, _torí_,
   {{0x442a0669,0xf2d30317,0x3ea7672b,0x764600ac}},	//   lib_, _פער_, ánta_, noky,
   {{0x40950500,0x7bc301ae,0xb6a300cc,0x00000000}},	//   _врст, ffnu, _suấ, --,
   {{0x442a672c,0xd0120037,0x00000000,0x00000000}},	//   nib_, _الس_, --, --,
   {{0x47dc0033,0x3202429e,0x00000000,0x00000000}},	//   বামী, _koky_, --, --,
   {{0x442a672d,0xaa5403fa,0x3f9a672e,0x249f0228}},	//   hib_, јвиш, lapu_, šumi_,
   {{0xb05b081b,0x442a672f,0x4814279d,0x7e7b0eac}},	//   _späi, kib_, имис, _čupi,
   {{0x442a4507,0x7e626730,0x2bae0d41,0x00000000}},	//   jib_, lmop, _घाटा, --,
   {{0x442a6731,0x6fc602cb,0x7c2a6732,0x5fc60577}},	//   dib_, र्यं, mifr, र्यल,
   {{0x7ae8009e,0xa2d8018d,0x2456008d,0x00000000}},	//   _irdt, मबन्, væma_, --,
   {{0x2ed121a8,0x442a012f,0x3f9a6733,0x7bc80051}},	//   _सन्त, fib_, kapu_, _kbdu,
   {{0x2492099e,0x00000000,0x00000000,0x00000000}},	//   _dwym_, --, --, --,
   {{0x179702b8,0x320200ac,0xd25b6734,0x00000000}},	//   _גדול_, _boky_, еца_, --,
   {{0x2bc42135,0x7e620207,0x00000000,0x00000000}},	//   ल्ता, jmop, --, --,
   {{0x442a6735,0x3fab0202,0x36340d47,0xaca30019}},	// [66f0] bib_, ењем_, _دروس, _trứn,
   {{0x442a00a8,0x2c7902d0,0x7c2a00d7,0x351c00a5}},	//   cib_, _rèd_, jifr, _רוזנ,
   {{0x7c2a0282,0x09ac0033,0x629a33a5,0x2c790359}},	//   difr, ক্যা, štor, _sèd_,
   {{0x7bc86736,0x64476737,0x628503d0,0x5fc60ed1}},	//   _abdu, loji, _itho, र्बल,
   {{0x563802b5,0x7ae3006d,0x9f580183,0x7ae80079}},	//   נאדע_, wvnt, _porã_, _ardt,
   {{0x644726e3,0xab290847,0xc31c0083,0xe47c00a5}},	//   noji, кола_, _দুটি_, ערוכ,
   {{0x3d952626,0x20030160,0x60120a8a,0x7f58081b}},	//   _вибр, _ioji_, _kæmn, _барс_,
   {{0x442a6738,0x6447000e,0x6d5700a8,0x20036739}},	//   zib_, hoji, əxan, _hoji_,
   {{0x2003673a,0x442a673b,0x64470a09,0xd5ed0023}},	//   _koji_, yib_, koji, _giả,
   {{0x442a673c,0x6285673d,0x3ae3027d,0x6447034d}},	//   xib_, _otho, _tıp_, joji,
   {{0xe7392a8a,0x99f501c8,0x64473cf1,0x628501e8}},	//   тен_, _вялі, doji, _ntho,
   {{0x20030ec0,0x25e62afe,0x6d5d01dd,0x22a100c7}},	//   _loji_, _जोशी_, _úsas, dėk_,
   {{0x3202290b,0x62851720,0x7646067f,0x2003012f}},	//   _roky_, _atho, roky, _ooji_,
   {{0x6447673e,0x3ddf673f,0x7e621626,0xa6c90279}},	//   goji, _lauw_, zmop, _алка_,
   {{0x442a6740,0xe297002d,0x5276002d,0x6e2b0008}},	//   rib_, иар_, ругу, kigb,
   {{0x442a6741,0xcb1202b5,0xd1860812,0x799b6742}},	//   sib_, קלן_, рлай, nauw,
   {{0x6285001e,0x64476743,0x60260183,0x3f9a6744}},	// [6700] _etho, boji, адаа, tapu_,
   {{0x8fa61150,0x442a013b,0x60d6001e,0x66040328}},	//   раже, qib_, rwym, _hoik,
   {{0x799b067f,0x320228ce,0x23fb0d85,0xf1bf0300}},	//   kauw, _toky_, _ספטמ, _imán_,
   {{0x3f9a05eb,0x9f580176,0x00000000,0x00000000}},	//   sapu_, _vorà_, --, --,
   {{0x2ca0004f,0x3ddf0051,0x66046745,0x443a005f}},	//   éid_, _dauw_, _moik, _kjp_,
   {{0x8aa607e5,0x1eaa1c64,0xfaa615df,0x225201ed}},	//   арид, _لاري_, ашин, llyk_,
   {{0xbea309b5,0x7c2a6746,0x443a0176,0x60120a8a}},	//   _марк, rifr, _mjp_, _hæmo,
   {{0x25e60026,0xce340416,0x4aa70026,0x3ddf01e4}},	//   _जोली_, _اورک, _गिरव, _gauw_,
   {{0x64470054,0x9a670037,0xf1bf0138,0xc9140033}},	//   yoji, جميل_, _omán_, াপ্ত_,
   {{0xf8066747,0x9cd700a5,0x6604009e,0x3f980345}},	//   рчин, _דומה_, _aoik, _jeru_,
   {{0x644718cc,0x3f985a0c,0x12b10083,0xd6d73bd2}},	//   voji, _meru_, _চন্দ, атя_,
   {{0x47dc00c8,0xf1bf002a,0xa01b0225,0x3f980207}},	//   বাধী, _amán_, _atöl, _leru_,
   {{0x64476748,0x0ca402e4,0x660401ed,0xe786027a}},	//   toji, _ऑटोम, _doik, _куйо,
   {{0x443a6749,0x78a20069,0x3f980207,0x00000000}},	//   _cjp_, _ivov, _neru_, --,
   {{0x443a012f,0x99dd0187,0xe1f35cfa,0x66163356}},	//   _djp_, plňt, يسر_, _flyk,
   {{0x52142afc,0x660401d7,0x6447278c,0x443a013a}},	//   одст, _goik, soji, _ejp_,
   {{0x6447674a,0x3f9829e7,0xcf9b0370,0x7c28674b}},	// [6710] poji, _beru_, вје_, _omdr,
   {{0x96da10b7,0x3ea70831,0x3f9800ea,0xd3a71654}},	//   _बनाउ, ánto_, _ceru_, _трип,
   {{0x22520b88,0x9f58002a,0x62850044,0x3f980207}},	//   blyk_, _porá_, _utho, _deru_,
   {{0x7d0b013c,0x78a201ef,0x09ac0083,0x249f00ea}},	//   tygs, _ovov, ক্তা, šumu_,
   {{0x224901d7,0xfce53efc,0xddce0395,0x764d034d}},	//   moak_, соло, _subţ, _mkay,
   {{0xda78024e,0x224901d7,0x799b08c7,0xeb96097b}},	//   _buď_, loak_, wauw, биш_,
   {{0x60cf00e0,0x9f580d9b,0x3e770024,0x78a202ee}},	//   _hpcm, _torá_, _oħti_, _avov,
   {{0xe9d92cdd,0x224906a2,0xa2d80066,0x3f98674c}},	//   уки_, noak_, मबत्, _zeru_,
   {{0x2bc400a1,0x6e29002f,0x9d15674d,0x4ad720af}},	//   ल्हा, _imeb, _удач, _भैरव,
   {{0x764d674e,0x96100035,0x6e3b0009,0xc610022e}},	//   _akay, ास्ट_, _hjub, ास्य_,
   {{0x224903cb,0xb5fb674f,0x66040086,0x6e3b0009}},	//   koak_, rmán, _poik, _kjub,
   {{0x645e01d2,0xf4091899,0x2d9d6750,0xa01b1aee}},	//   _shpi, _אפ_, nawe_, _stöl,
   {{0xe8ee0aeb,0x7c28001e,0xb5fb008a,0x224901a3}},	//   _эл_, _ymdr, mmál, doak_,
   {{0x6e3b2eaf,0x2d9d0010,0x63836734,0xb5fb0093}},	//   _ljub, hawe_, згра, lmál,
   {{0x2d9d0035,0x224901b7,0x00000000,0x00000000}},	//   kawe_, foak_, --, --,
   {{0x3f980118,0x224906a2,0x66160b41,0x6e3b001c}},	//   _seru_, goak_, _ulyk, _njub,
   {{0x3f980033,0x51561eea,0x287a0070,0x487a0070}},	// [6720] _peru_, ству, ָנעמ, ָטעס,
   {{0x3a2d0019,0x6e296751,0x09d400b4,0x79990345}},	//   hiep_, _ameb, _दस्य, _leww,
   {{0x3f986752,0xe9ff0019,0x224906a2,0x6d5b0453}},	//   _veru_, _ngắm_, boak_, _azua,
   {{0x79996753,0xb05b6754,0x2d9d00bf,0x44381661}},	//   _neww, _spät, gawe_, lnr_,
   {{0xdd990038,0xd47a0070,0x3f98002a,0xa5bb2127}},	//   _deň_, נאַל, _teru_, miót,
   {{0x69cb02bf,0x60c46755,0x61e46756,0x44382293}},	//   _abge, mtim, ldil, nnr_,
   {{0x26190066,0xb05b0421,0x602f004b,0x61e41e7b}},	//   _पतली_, _epäs, _dėmė, odil,
   {{0x61e46757,0x8f3700a5,0xb5fb008d,0x60c400f4}},	//   ndil, _האלו_, gmál, otim,
   {{0xd90e03c5,0x26dc0345,0x9f580225,0x00000000}},	//   عیت_, _ssvo_, _borç_, --,
   {{0x47341b09,0x765f01f4,0x224906a2,0x60c46758}},	//   жнос, _shqy, zoak_, itim,
   {{0x661d01d2,0x60c46759,0x28d80066,0x00000000}},	//   ërko, htim, _बैरि, --,
   {{0x60c4675a,0x0f570122,0x224901d7,0x78a202c4}},	//   ktim, מיים_, xoak_, _tvov,
   {{0x60c400da,0x61e4675b,0x3ceb0066,0x3a5600b5}},	//   jtim, ddil, चिये_, _پیکج_,
   {{0x4adc5f12,0x61e4675c,0x395901ae,0x44381058}},	//   _मनाव, edil, üsse_, gnr_,
   {{0x60c400d8,0x6b9a675d,0x224901d7,0x9f4101f4}},	//   etim, _metg, toak_, rdhë_,
   {{0x53341eea,0x60c401f4,0x20180600,0x61e40c47}},	//   чест, ftim, _alri_, gdil,
   {{0x60c4675e,0x22490291,0x6253675f,0x3e7e00f6}},	// [6730] gtim, roak_, nçoi, _aït_,
   {{0x24890034,0x6b9a010b,0x224906a2,0x249f0029}},	//   _itam_, _netg, soak_, šums_,
   {{0x61e4007a,0xa5bb1fca,0xa3e2210a,0x3f81001e}},	//   bdil, biót, _नोट_, rchu_,
   {{0x998d15ce,0x3f8101a6,0x64556760,0x20180345}},	//   kneš_, schu_, llzi, _elri_,
   {{0x6b9a005f,0x2d9d6761,0x60c46762,0x0dc81f39}},	//   _betg, rawe_, ctim, сухи_,
   {{0x2bc4000c,0xa5bb1d8a,0x998d08c2,0x3ea10031}},	//   ल्ला, gnóz, dneš_, psht_,
   {{0xb4d6051d,0xf9910037,0x6d402b1c,0xda653cc0}},	//   _सन्_, وبة_, _exma, овки,
   {{0x291f06a2,0x6e296763,0x24890107,0x6b9a0fdb}},	//   tzua_, _umeb, _otam_, _eetg,
   {{0xb5fb6764,0x998d18b0,0x2489006d,0x6b9a0392}},	//   rmál, gneš_, _ntam_, _fetg,
   {{0xd82500d4,0xb5fb6765,0x61e41e85,0xa7fc027d}},	//   ідни, smál, zdil, smın,
   {{0x09c300c8,0x61e46766,0x248922ca,0x60c405f5}},	//   ্যবা, ydil, _atam_, ztim,
   {{0x3ced6767,0x60c46768,0xe0df0359,0xe56a002d}},	//   _krev_, ytim, _osò_, иинд_,
   {{0x955617bd,0x44386769,0x60c4676a,0x25a900e9}},	//   تخدا, tnr_, xtim, _ddal_,
   {{0xf1bf0831,0x69c9676b,0x60c4082d,0x44380371}},	//   _acá_, lfee, vtim, unr_,
   {{0xe29a38e7,0x4438008c,0x25a9009f,0xe7e2073f}},	//   раб_, rnr_, _fdal_, _कोटा_,
   {{0x60c442c2,0x661d5838,0x69c90051,0x61e400fe}},	//   ttim, chsk, nfee, udil,
   {{0x61e4676c,0x4376021d,0x68e900b5,0xe9ff0023}},	// [6740] rdil, _мунт, nved, _ngậm_,
   {{0xe29a0500,0x60c41901,0x2f560923,0xb05b1193}},	//   _као_, rtim, отес, _spär,
   {{0xdc2a01cb,0x998d20dc,0x3e770024,0xdfcf0088}},	//   یسته_, zneš_, _oħtu_, ئيم_,
   {{0x60c4676d,0x6b9a676e,0xdd8f0c26,0x3ced1b2f}},	//   ptim, _setg, نوم_, _brev_,
   {{0xce34006c,0x6b9a0176,0x973c0254,0x69c9676f}},	//   _ہوسک, _petg, maće, dfee,
   {{0x70d902b5,0x973c011c,0x7a3e00ea,0x2aaa0274}},	//   _פֿרו, laće, dīta, атио_,
   {{0x69c96770,0xd9100594,0x68e95aa0,0x00000000}},	//   ffee, کیش_, eved, --,
   {{0x6b9a11cc,0xddc9002d,0x998d0124,0xa8a610e3}},	//   _wetg, _vieţ, tneš_, орок,
   {{0xdcf80332,0xd7fa6771,0xb4c9007c,0x3ced6772}},	//   _دہشت_, аун_, _ईहे_, _grev_,
   {{0x7e7c2a28,0xe1ff0037,0x6253000d,0x998d0a66}},	//   _kurp, _thóg_, rçoi, rneš_,
   {{0xdb180006,0x09ac00c8,0x8f7b0100,0x24896773}},	//   tevõ, ক্ষা, יניק, _stam_,
   {{0xe81c020d,0x973c02c4,0x7bd81cf9,0x6fca143a}},	//   _फतवा_, jaće, levu, स्तू,
   {{0x7e7c01a3,0xa9260037,0x628e0051,0x271500e2}},	//   _lurp, _بعضه, epbo, án_,
   {{0x3ceb018d,0x7e7c6774,0x7bd800ab,0xddc900a0}},	//   चिते_, _ourp, nevu, _mieš,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a906a2,0x09ac0083,0x973c011c,0xd6280274}},	//   _udal_, ক্রা, gaće, _моје_,
   {{0x64402b9f,0x7e7c01d7,0xa01b01ff,0x628e0298}},	// [6750] émic, _aurp, _utök, apbo,
   {{0x20070093,0xcf8b0183,0x7bd800b8,0x74280037}},	//   ðni_, рсад_, jevu, _وكيف_,
   {{0x4431036a,0x7bd86775,0x68e90a3c,0x973c022f}},	//   miz_, devu, zved, baće,
   {{0x3cfd01e8,0xdb03033b,0x3ced024b,0x7c2600c7}},	//   txwv_, rgnü, _prev_, _įkra,
   {{0xe0df0036,0xb4c900ab,0xddc90228,0xe1ff055c}},	//   _usò_, _ईहो_, _cieš, _chóe_,
   {{0x44316776,0x7bd86777,0x68e96778,0xeb9612a2}},	//   niz_, gevu, vved, пиш_,
   {{0x4ea40a7c,0x60d900d0,0x7e7c01a3,0xb5fb00b5}},	//   _орта, şamı, _gurp, rmáj,
   {{0x28a6009a,0xdce8004e,0x443106a2,0x13e40083}},	//   _खिखि, _śląs, hiz_, মায়,
   {{0x69c96779,0x4431677a,0x7bd80036,0x25e60726}},	//   rfee, kiz_, bevu, _जोगी_,
   {{0x87255de9,0x68e9677b,0x7bd802fb,0x69c911cc}},	//   змож, rved, cevu, sfee,
   {{0x6c6a00f5,0x4431677c,0x68e9677d,0xe9450416}},	//   _اللہ_, diz_, sved, _کرای,
   {{0x19b800af,0x3ebe01e0,0x00000000,0x00000000}},	//   _душь_, _åtte_, --, --,
   {{0x973c0254,0x4431677e,0x26c500d5,0x9f430c6f}},	//   vaće, fiz_, stlo_, _bajë_,
   {{0x4431677f,0x00000000,0x00000000,0x00000000}},	//   giz_, --, --, --,
   {{0x366a0274,0xa5bb01ef,0xe3630dec,0x973c00f4}},	//   _лако_, riór, екри, taće,
   {{0x05764e87,0x00000000,0x00000000,0x00000000}},	//   _عابد, --, --, --,
   {{0xb1430dba,0x973c0a78,0x21670d15,0x55bb00a5}},	// [6760] ентл, raće, зити_, _המפו,
   {{0xddc9016f,0x7e7c0122,0x44316780,0x973c00f4}},	//   _rieš, _purp, ciz_, saće,
   {{0x973c00cd,0x7ae10107,0x00000000,0x00000000}},	//   paće, _nslt, --, --,
   {{0xddc96781,0x644e6782,0xfcaa0118,0x7bc107a7}},	//   _pieš, lobi, ماتو_, _aclu,
   {{0x20170332,0x9f430359,0x05c1007e,0x00000000}},	//   áció_, _lajè_, ष्टब, --,
   {{0x7e7c6783,0xddc901c8,0x61e601d6,0x00000000}},	//   _turp, _vieš, _hakl, --,
   {{0x6012008e,0x7bd82d3d,0x644e01a3,0x62530055}},	//   _næmi, revu, iobi, rçov,
   {{0xddc90080,0x200a6784,0x44316785,0x2d80016f}},	//   _tieš, _hobi_, ziz_, žieb_,
   {{0x44316786,0x644e6787,0x61e66788,0x0c263e10}},	//   yiz_, kobi, _makl, _еман,
   {{0xe1ff01a5,0x7bc10037,0x644e011c,0x3cfa0461}},	//   _khóc_, _gclu, jobi, ्हीं_,
   {{0x644e2ce5,0x61e66789,0x4431678a,0x6fc105e7}},	//   dobi, _oakl, viz_, र्टू,
   {{0xcb130779,0x8afb0122,0x2d86678b,0xf76f07f6}},	//   _אלע_, _להבי, ncoe_, داً_,
   {{0x4431021e,0xa9c500d1,0x2ca6067f,0xd5640fb4}},	//   tiz_, _آزمو, nsod_, етрп,
   {{0xb3470279,0x644e0090,0x61e6678c,0x601203d0}},	//   _naçõ, gobi, _aakl, _fæmi,
   {{0x61e6678d,0x4431678e,0x268a0037,0xe1ff0023}},	//   _bakl, riz_, _اختي_, _nhóc_,
   {{0x4431678f,0x61e62502,0x69c20345,0x754800b5}},	//   siz_, _cakl, _jcoe, észé,
   {{0x61e601cc,0x44310453,0x764f6790,0xd5ed00e2}},	// [6770] _dakl, piz_, mocy, _giá,
   {{0x764f4827,0xdb1a002a,0x200a00f8,0x3f6700af}},	//   locy, _actí, _cobi_, птеб,
   {{0x3ea70332,0x61e66791,0x200a6792,0xe1ff00e2}},	//   ént_, _fakl, _dobi_, _chóc_,
   {{0x5d350332,0x9f4a0183,0x68e2016e,0x764f6793}},	//   وفائ, _robô_, _osod, nocy,
   {{0x200a6794,0x00000000,0x00000000,0x00000000}},	//   _fobi_, --, --, --,
   {{0x61e60a0b,0x200a6795,0x69c2021d,0x764f1691}},	//   _zakl, _gobi_, _acoe, hocy,
   {{0x6281024e,0x61e601d6,0xcb66029f,0xe45f00c3}},	//   íloh, _yakl, маше_, ytön_,
   {{0x644e0138,0x08890036,0x00000000,0x00000000}},	//   zobi, обий_, --, --,
   {{0x68e2006c,0x8cd50035,0x320b0035,0x644e4583}},	//   _csod, _मैचो, _mocy_, yobi,
   {{0xf8ae0118,0xb9052218,0xe63000a8,0x290300f4}},	//   شکه_, _पन_, _bəşə, ćja_,
   {{0x644e0bec,0xfb15004f,0x68e259a6,0x9f430453}},	//   vobi, _تواج, _esod, _bajé_,
   {{0xcb120052,0x320b0035,0xc9150200,0x00000000}},	//   _שלא_, _nocy_, _одећ, --,
   {{0x3a2f4704,0x00000000,0x00000000,0x00000000}},	//   _imgp_, --, --, --,
   {{0xb4ce3717,0x61e66796,0xe45f00c3,0x69db6797}},	//   _रही_, _sakl, stön_, leue,
   {{0x61e66798,0x09e00083,0x200a6799,0x3a2f012f}},	//   _pakl, ভারা, _robi_, _kmgp_,
   {{0x27e7064b,0x2d9f02bf,0x644e679a,0x200a679b}},	//   _hann_, _neue_, sobi, _sobi_,
   {{0x27e70446,0x037a02fd,0x644e679c,0x6283000d}},	// [6780] _kann_, _وحدت_, pobi, _énon,
   {{0x25a0679d,0x27e70260,0x2ca6008b,0x69db1bc9}},	//   _heil_, _jann_, vsod_, heue,
   {{0x27e70938,0xe7cf00e7,0x3a2f01ef,0x25a0679e}},	//   _mann_, त्यप, _omgp_, _keil_,
   {{0x3eba1be4,0x27e7006b,0x2480028b,0xa3c8112b}},	//   rupt_, _lann_, _kuim_, ोजक_,
   {{0x3cfa006a,0xa06a679f,0x25a0007c,0x6da33851}},	//   ्हें_, _мама_, _meil_, тича,
   {{0xb5fb004f,0xfa8a0949,0x2d9f03bc,0xa01b01ff}},	//   rmái, осий_, _eeue_, _stöv,
   {{0x25a000f7,0xa6e1008a,0x69db033b,0x248011ae}},	//   _oeil_, óðle, feue, _luim_,
   {{0xe1ff0028,0x31620221,0xb4ce0084,0xc7ce0019}},	//   _khóa_, _kzkz_, _रहू_, _cống_,
   {{0x27e702e9,0xada367a0,0x973c0124,0x00000000}},	//   _bann_, _шатл, daća, --,
   {{0x39580080,0x7c65026e,0x00000000,0x00000000}},	//   ārs_, _كالل, --, --,
   {{0x27e70446,0x764f1298,0xec13026e,0x25a067a1}},	//   _dann_, tocy, _جولد, _beil_,
   {{0xa01b013c,0x25a0009e,0x27e70341,0x6e2201ed}},	//   _utöv, _ceil_, _eann_, nhob,
   {{0x764f67a2,0x27e709bd,0xadc30019,0xd90f006c}},	//   rocy, _fann_, _hoản, _نیٹ_,
   {{0xe63001c2,0x27e71d23,0x24800b0d,0xe72f00d1}},	//   _təşə, _gann_, _duim_, اصی_,
   {{0x450700c8,0x6adc0d00,0x2a660221,0x25a002ce}},	//   _লেখক_, _मनोर, _khob_, _feil_,
   {{0x69c052e4,0x25a067a3,0x00000000,0x00000000}},	//   ngme, _geil_, --, --,
   {{0x48bc0083,0x27e76634,0x2a6600e9,0x248001f7}},	// [6790] _অনুর, _yann_, _mhob_, _guim_,
   {{0x660d67a4,0x25a01167,0x6d5d009e,0x00000000}},	//   _hoak, _zeil_, _ùsai, --,
   {{0xb27567a5,0x53350012,0x00000000,0x00000000}},	//   _плош, _чент, --, --,
   {{0x3eaa00d5,0xf2d2016b,0xdb03021d,0x00000000}},	//   _dvbt_, _געט_, banê, --,
   {{0x2ca90082,0x69c000a5,0x660d0282,0x656b01a6}},	//   éad_, dgme, _moak, _ùghd,
   {{0xc7ce00e8,0x6b6517b7,0x200500be,0x69c00298}},	//   _sống_, нкла, _õli_, egme,
   {{0xe7e5009a,0x27e767a6,0xdb0301f4,0x69db01ae}},	//   _कसबा_, _rann_, manë, teue,
   {{0x2a6601e8,0x27e767a7,0x3ebe013c,0x6e2267a8}},	//   _chob_, _sann_, _åtta_, chob,
   {{0xb4ce3717,0x29192d87,0x973c0c21,0x27e767a9}},	//   _रहे_, ása_, vaća, _pann_,
   {{0x248067aa,0xddc9016f,0x25a01b4a,0x00000000}},	//   _ruim_, _dieť, _seil_, --,
   {{0x98ab0723,0x27e767ab,0x2480009d,0xc7ce0019}},	//   ğlık_, _vann_, _suim_, _tống_,
   {{0x27e701ae,0xc7ce01a5,0x98ab027d,0x2a6601da}},	//   _wann_, _uống_, şlık_, _ghob_,
   {{0x27e702e9,0x248061b1,0x973c0254,0xdb0301f4}},	//   _tann_, _quim_, raća, kanë,
   {{0x25a002c9,0x33d500d4,0x7d040086,0x22420183}},	//   _weil_, кіст, äisi, _sjkk_,
   {{0x25a067ac,0x78a90955,0x660d00d7,0x2cbd02a2}},	//   _teil_, lsev, _foak, huwd_,
   {{0x91e367ad,0x24804fc9,0x00000000,0x00000000}},	//   лосе, _tuim_, --, --,
   {{0x52750036,0x888c0070,0x78a967ae,0xdb0101b4}},	// [67a0] туру, ַראַ, nsev, _udlæ,
   {{0x656404fb,0x78a967af,0x2cbd0223,0xdb030055}},	//   _izih, isev, duwd_, ganë,
   {{0x444467b0,0xdb1a67b1,0x2cbd02a2,0x7c230098}},	//   _ij_, _octá, euwd_, dhnr,
   {{0xe7cf0099,0xa01b013c,0x645c2ea7,0x78a967b2}},	//   त्तप, _stöt, llri, ksev,
   {{0xb4ce0299,0x22401cb0,0x98b80029,0x78a92038}},	//   _रहो_, mnik_, ārī_, jsev,
   {{0x224067b3,0x6e22070b,0x973c0124,0xb4ce00ab}},	//   lnik_, shob, daćn, _रहै_,
   {{0x50431ea1,0x6e2267b4,0x63a30006,0x78ab0176}},	//   _серб, phob, _õnne, _avgv,
   {{0x224067b5,0xfce638d0,0x58d4279d,0x2a66006d}},	//   nnik_, _побо, воит, _qhob_,
   {{0x69c067b6,0xdd8f05bc,0xd7f0004f,0x1c461fd8}},	//   rgme, _طول_, لكة_, _знам,
   {{0xc619012f,0x7644030d,0x224067b7,0x3867009e}},	//   दस्य_, _ajiy, hnik_, _chnr_,
   {{0x659567b8,0x2cb000d8,0xdb0600c3,0x65640371}},	//   кану, žodį_, ämäl, _azih,
   {{0x4444124b,0x394667b9,0x00000000,0x00000000}},	//   _aj_, _txos_, --, --,
   {{0x444467ba,0xba29004f,0x00000000,0x00000000}},	//   _bj_, _تسلم_, --, --,
   {{0xe45f0093,0x224009b7,0x44443c8f,0x3e67018d}},	//   mtök_, enik_, _cj_, mõte_,
   {{0x81c50083,0x2456008a,0x43840fa2,0x6564073a}},	//   _এসব_, væmt_, الفق, _ezih,
   {{0x444467bb,0xb5fb1fca,0xa75b00a5,0x00000000}},	//   _ej_, gmát, _מדור, --,
   {{0x661d0055,0x00000000,0x00000000,0x00000000}},	// [67b0] ërku, --, --, --,
   {{0x765d67bc,0x444467bd,0x4ea767be,0xd9dd0035}},	//   llsy, _gj_, ерда, _मस्ट,
   {{0x224067bf,0xdd91004f,0x63a7023a,0xdb0301f4}},	//   bnik_, لوا_, majn, ranë,
   {{0x63a70478,0x443300d5,0x224067c0,0xed35002d}},	//   lajn, _hmx_, cnik_, кэлэ,
   {{0xfce521be,0x61fd67c1,0x6e20009e,0x61ed67c2}},	//   толо, _insl, _dlmb, mdal,
   {{0xa13602b5,0x61ed67c3,0x21290ac8,0x60cd67c4}},	//   _יארק_, ldal, mzah_, mtam,
   {{0x60cd67c5,0x44330211,0x973c0207,0x00000000}},	//   ltam, _mmx_, daćo, --,
   {{0x3209289c,0x78a90d4c,0x60cd1388,0xdb0367c6}},	//   njay_, tsev, otam, nané,
   {{0x5c75015a,0x9f4301c0,0x60cd409c,0x44334ddc}},	//   _алат, _mají_, ntam, _omx_,
   {{0x22401cb0,0x60cd67c7,0x2cad022e,0x2129028b}},	//   znik_, itam, _ived_, izah_,
   {{0x44440370,0x63a767c8,0x78a967c9,0xb5fb01c0}},	//   _rj_, dajn, ssev, klád,
   {{0x61ed67ca,0x9a840043,0x22400be2,0x44330d20}},	//   jdal, _суфл, xnik_, _amx_,
   {{0x224002dd,0x61ed67cb,0xdb030187,0x442100ee}},	//   vnik_, ddal, dané, _blh_,
   {{0x2240006a,0x63a704c3,0x61fd1281,0x7bc367cc}},	//   wnik_, gajn, _ansl, ngnu,
   {{0x224018b0,0x03a34866,0x44330098,0x44210168}},	//   tnik_, рисо, _dmx_, _dlh_,
   {{0xc24300b6,0x61ed67cd,0xb5fb2587,0x44440088}},	//   анск, gdal, umát, _wj_,
   {{0xb5fb1c98,0x44440b79,0x224067ce,0x6d5b01a9}},	// [67c0] rmát, _tj_, rnik_, _nyua,
   {{0x224002b2,0xa01b4357,0x63a70912,0xb5fb3207}},	//   snik_, _stör, cajn, smát,
   {{0x61ed3636,0x22400a18,0xdb0320d9,0x6d490160}},	//   bdal, pnik_, bané, _axea,
   {{0x443867cf,0x7c2167d0,0x7e7b002d,0xdb01021d}},	//   lir_, _allr, _ciup, _telê,
   {{0x60cd4df4,0x44380082,0xdb010176,0x7e690118}},	//   ctam, oir_, _helè, _dhep,
   {{0x443867d1,0x3e6700ab,0xdb010118,0x1d070274}},	//   nir_, võte_, _kelè, тељи_,
   {{0xaa5856e6,0x7a3e0029,0xfaa30409,0xbea30c98}},	//   нику_, līti, ашын, _васк,
   {{0x443849e4,0xdbdf0093,0x261403e6,0x7e7b043d}},	//   hir_, síðu, _mãos_, _giup,
   {{0xfce30d36,0x443867d2,0x48c20083,0x6934132d}},	//   _кото, kir_, ্ট্র, دکار,
   {{0xd7f7342d,0x4438625d,0x61ed0693,0xb5fb006c}},	//   вую_, jir_, zdal, ymás,
   {{0x443867d3,0x61ed67d4,0xda6f67d5,0xe45f008d}},	//   dir_, ydal, _вя_, stök_,
   {{0x7c3867d6,0xc9830369,0x7e690031,0x44380079}},	//   livr, _куши, _xhep, eir_,
   {{0x67d467d7,0x2bc9017a,0x443867d8,0x6d5b01a9}},	//   _болу, _रामा, fir_, _xyua,
   {{0x9f470076,0x443867d9,0x61ed0069,0x7c3867da}},	//   žné_, gir_, wdal, nivr,
   {{0x63a767db,0x682401f7,0x6a650079,0xdb0300f6}},	//   rajn, _còde, lófa, tané,
   {{0x60cd67dc,0x443867dd,0x63a702c4,0xd8383f01}},	//   ttam, air_, sajn, lič_,
   {{0x443863b0,0xe7cf0e6f,0xdb0300ac,0x442109ba}},	// [67d0] bir_, त्वप, rané, _tlh_,
   {{0x60cd67de,0x44381166,0xd8382d5b,0x661d1e65}},	//   rtam, cir_, nič_, lksk,
   {{0x60cd67df,0x645567e0,0xd37100bf,0x6d5b00d7}},	//   stam, mozi, _دهد_, _syua,
   {{0x6455619f,0x60cd0043,0x661d67e1,0xa7fc67e2}},	//   lozi, ptam, nksk, llıd,
   {{0x91ba0122,0xd83808b7,0x7a3e00ea,0xf1bf00ac}},	//   _אמרי, kič_, cīti, _vlád_,
   {{0xcb6967e3,0xd838008b,0x5f940573,0x62850054}},	//   нале_, jič_, _вирт, _kuho,
   {{0xd8382d5b,0x628567e4,0x7e7b1e77,0x7bc307c4}},	//   dič_, _juho, _tiup, rgnu,
   {{0x443867e5,0x628567e6,0x3eda02b5,0x9df82028}},	//   zir_, _muho, _אַמא, _инст_,
   {{0x443867e7,0xe1ff0028,0x6012054e,0xa7fc01d6}},	//   yir_, _nhóm_, _kæmp, klıd,
   {{0x443867e8,0x63a5016f,0x48052286,0xd83808b7}},	//   xir_, _nehn, упов, gič_,
   {{0x35a615ae,0xe5a667e9,0x645567ea,0x7a3e00ea}},	//   ланг, лини, dozi, zīti,
   {{0x443809ac,0x20110118,0xdb0167eb,0xe8f51902}},	//   wir_, _lozi_, _relè, _مستخ,
   {{0x443867ec,0xdb0102d0,0xd8383f01,0x799b41a6}},	//   tir_, _selè, bič_, mbuw,
   {{0x628567ed,0x645567ee,0xd91a02b5,0x201100cb}},	//   _buho, gozi, _רוסל, _nozi_,
   {{0x443867ef,0xdb0167f0,0xb5fb67f1,0xaac606fe}},	//   rir_, _belé, rmár, रूपक,
   {{0xe7cf02cb,0x62851851,0xdb0167f2,0x7a3e0029}},	//   त्रप, _duho, _celé, tīti,
   {{0x443867f3,0x645567f4,0x412767f5,0xdb011f55}},	// [67e0] pir_, bozi, гото_, _welè,
   {{0xdb0112c3,0x22590009,0xa7fc0381,0x443820e2}},	//   _telè, _eksk_, rlıg, qir_,
   {{0xdb0100b5,0x628501d5,0x201167f6,0x2d8000ea}},	//   _felé, _guho, _dozi_, žiem_,
   {{0x175602b5,0xe1ff004f,0x52d702b5,0xdb0167f7}},	//   אסער_, _gnó_, _גוטע_, _gelé,
   {{0x7c382038,0x7a3e00ea,0x9f58021d,0xa5bb003e}},	//   tivr, nūte, _poró_, skóg,
   {{0xdddc1575,0x78bb013a,0x3f9a0647,0x2011034d}},	//   _utrž, druv, _سپرد_, _gozi_,
   {{0xfbcf103b,0xd83867f8,0x81e70083,0xa5bb1df9}},	//   ستو_, vič_, পার_, rióz,
   {{0x611a0029,0x64550054,0x7d040328,0x799b010d}},	//   _tālā, zozi, äiss, gbuw,
   {{0x02e12cb0,0xd8383f01,0x6455002f,0x4aa42e64}},	//   _पन्न, tič_, yozi, _गौरव,
   {{0x6a6567f9,0x648b013a,0x00000000,0x00000000}},	//   rófa, _bļin, --, --,
   {{0x63a567fa,0xd83830ec,0x8c1b0d85,0x9f4a0118}},	//   _rehn, rič_, _רובי, _babé_,
   {{0x98a600c9,0x63a567fb,0xd104035d,0xd8380252}},	//   _биде, _sehn, रमाण_, sič_,
   {{0x661d0343,0x628501a0,0x645567fc,0xd8383f01}},	//   rksk, _suho, tozi, pič_,
   {{0xdb012f07,0x62850207,0xa7fc01fb,0x00000000}},	//   _selé, _puho, rmıs, --,
   {{0x443f0a78,0xa7fc0448,0x2bd60099,0x63a50421}},	//   đu_, rlıd, ढ्या, _vehn,
   {{0x973c02c4,0x645567fd,0x855700b5,0x224d0207}},	//   haćk, sozi, _میجر_, čeko_,
   {{0x645567fe,0x20113e4a,0x81e70033,0x2fca67ff}},	// [67f0] pozi, _pozi_, পাল_, _bcbg_,
   {{0x62856800,0x27ee008a,0xa7fc00a8,0x78a20cdf}},	//   _tuho, _jafn_, qlıd, _mwov,
   {{0xdb013318,0x20114693,0x00000000,0x00000000}},	//   _telé, _vozi_, --, --,
   {{0x6cf0020d,0x79826801,0x5fc700a1,0x51842b5b}},	//   चिंग_, _ngow, _लावल, _гура,
   {{0xfaf80ae0,0x20110298,0x9e9501cb,0x00000000}},	//   _arī_, _tozi_, _چارچ, --,
   {{0x27ee008a,0x3dc9003c,0xfaf8013a,0x00000000}},	//   _nafn_, żaw_, _brī_, --,
   {{0x1b4901d3,0x44fd0033,0x00000000,0x00000000}},	//   ъзки_, ুনিক_, --, --,
   {{0x61ef028b,0x1c0300b4,0x78bb05ee,0x00000000}},	//   _jacl, लाहल_, truv, --,
   {{0x61ef01a6,0x2d9d1548,0xdb035723,0x3cec0066}},	//   _macl, mbwe_, maní, _आईये_,
   {{0x1bab006c,0x66db0086,0xdb036802,0x9f4a0176}},	//   _سائٹ_, _näkö, laní, _sabé_,
   {{0xbb84004f,0x9f5e01a5,0x4e190722,0x270f0099}},	//   _المي, _ôtô_, _दवाई_, ाहेर_,
   {{0x61ef0284,0x78bb007a,0x60dd0051,0xdddc6803}},	//   _nacl, pruv, _opsm, _kurš,
   {{0xe0c00083,0x1dd70026,0x5a0a0070,0xd5e40023}},	//   _উন্ন, ण्यत, _בלײַ, _chí,
   {{0xe7876804,0xdddc02a7,0x00000000,0x00000000}},	//   _судо, _murš, --, --,
   {{0x6a65002a,0x60dd2b26,0x00000000,0x00000000}},	//   nófo, _apsm, --, --,
   {{0xc4860923,0x61ef009e,0x6824009e,0x00000000}},	//   _клик, _cacl, _iòda, --,

   {{0xdb036805,0xddc90029,0x2d8001ba,0x69d926df}},	// [6800] daní, _biež, žiek_, _mbwe,
   {{0xcef603fa,0xb5fb0187,0x9f580093,0x00000000}},	//   ичењ, plác, _borð_, --,
   {{0x0d8618b6,0xe7f80026,0x61ef0014,0x69d90273}},	//   ален, ्ञता_, _facl, _obwe,
   {{0x61ef01da,0xdb030042,0x53d20ac4,0x23d20808}},	//   _gacl, ganí, द्रश, द्रद,
   {{0x9d240083,0x61e46806,0x00000000,0x00000000}},	//   বপ্ন_, meil, --, --,
   {{0x69d901ae,0x61e46807,0x79821727,0x61ef00d5}},	//   _abwe, leil, _sgow, _zacl,
   {{0x7f430a55,0xdb032d36,0x7aed0035,0xed5000b5}},	//   _держ, baní, łatn, _کھا_,
   {{0x78a20c1f,0x61e40086,0xd90d00f8,0x68f9016e}},	//   _pwov, neil, کیه_, _brwd,
   {{0x973c01cc,0x2d84010d,0x60c40553,0x995000ee}},	//   maći, _igme_, nuim, _búši_,
   {{0x61e46808,0x973c0124,0x7d28045e,0x69d901a8}},	//   heil, laći, ırsı, _ebwe,
   {{0x09e6320c,0x442a004f,0x7bda006d,0x61e40086}},	//   _воен, dhb_, _ibtu, keil,
   {{0x7e626809,0x78a20027,0x79820103,0x68f900e5}},	//   nlop, _twov, _ugow, _frwd,
   {{0xb8940514,0x61e4680a,0x60c40009,0xa5bb0132}},	//   _التع, deil, juim, nhói,
   {{0xb4d70726,0x320255d7,0x00000000,0x00000000}},	//   _सही_, _anky_, --, --,
   {{0xf1a71761,0xdb1a0caa,0x61e4001e,0x7cda0029}},	//   иран, _actú, feil, lārā,
   {{0xe1ff0023,0x61e4680b,0xf1bf003e,0xd5e400e2}},	//   _khói_, geil, _bláa_, _thí,
   {{0x60c42d8d,0x7bda680c,0xdb03016f,0x7e6201bf}},	// [6810] guim, _obtu, vaní, dlop,
   {{0x9f4701c0,0x7afa0103,0x3a260310,0x74150088}},	//   žní_, _ortt, _llop_, _چوکا,
   {{0xa18715eb,0x24890189,0x64470254,0x61ef5ff8}},	//   _выгл, _huam_, mnji, _tacl,
   {{0x248901e8,0x7e62680d,0x7cda013a,0x60c4680e}},	//   _kuam_, glop, kārā, buim,
   {{0xdb03680f,0x9ce721df,0x7afa6810,0x25a93d32}},	//   raní, рцел, _artt, _meal_,
   {{0x1ee7006c,0x2489006f,0x25a921a4,0xdb0333d5}},	//   _پوری_, _muam_, _leal_, saní,
   {{0x248901a9,0x601301c0,0x998400d8,0x7e620345}},	//   _luam_, _výmě, jimų_, blop,
   {{0x09f90037,0x9984010b,0x39e91e9f,0x64470a66}},	//   افظة_, dimų_, удио_, hnji,
   {{0x644704c3,0x2489006d,0xa5bb0079,0xe1ff00e2}},	//   knji, _nuam_, chói, _chói_,
   {{0x998d016f,0x08d400d8,0x644700cd,0x61e46811}},	//   dieť_, іцыя, jnji, zeil,
   {{0x64475e51,0x6297006f,0x3a266812,0x25a90079}},	//   dnji, _ntxo, _flop_, _beal_,
   {{0x69d90010,0x25a90037,0x08f90609,0x24890211}},	//   _ubwe, _ceal_, _مرتب_, _buam_,
   {{0x61e46813,0x24890189,0x25a900a5,0x7a7a0070}},	//   veil, _cuam_, _deal_, _ערנס,
   {{0x61e402c9,0x248901f4,0x69c912ba,0x68e909a2}},	//   weil, _duam_, lgee, mwed,
   {{0x61e46814,0x68e90297,0x23276815,0x25a901ef}},	//   teil, lwed, бори_, _feal_,
   {{0x69c96816,0x2489006d,0x25a909c3,0x60c40086}},	//   ngee, _fuam_, _geal_, tuim,
   {{0x61e46817,0x7e620c1f,0x66046818,0x26c56819}},	// [6820] reil, vlop, _inik, lulo_,
   {{0x61e4681a,0x60c4681b,0xb4e40084,0x26c5681c}},	//   seil, ruim, नबी_, oulo_,
   {{0xd00f07f8,0x26c5681d,0x68e901ae,0x6616010d}},	//   علم_, nulo_, hwed, _koyk,
   {{0xa5bb004f,0x63ae681e,0x443a681f,0x24890189}},	//   thói, labn, _hmp_, _yuam_,
   {{0x27e5186a,0x7e626820,0x629c1e4e,0x2489006d}},	//   keln_, rlop, lpro, _xuam_,
   {{0x69c9030d,0x26c5149b,0x68e9001e,0x7e626821}},	//   egee, kulo_, dwed, slop,
   {{0x7e621f2c,0x973c022f,0x27e519ee,0xaab70037}},	//   plop, paći, deln_, مدير_,
   {{0x4c865e04,0xae0c2c29,0x26c51d99,0x69c96822}},	//   _глав, _सचिन_, dulo_, ggee,
   {{0xdca36823,0x25a91f74,0xf98f004f,0x270e0095}},	//   _нати, _real_, ربي_, məni_,
   {{0x27e53230,0x660455c6,0x2489006f,0x629c6824}},	//   geln_, _anik, _ruam_, kpro,
   {{0x81040567,0x24895e99,0x26c56825,0x629c6826}},	//   रमुख_, _suam_, gulo_, jpro,
   {{0x2489006f,0x9984010b,0xe1ff0023,0x6e222591}},	//   _puam_, rimų_, _thói_, nkob,
   {{0x64471269,0x27e50ed4,0x66040009,0x629c2fe5}},	//   tnji, beln_, _dnik, epro,
   {{0x26c56827,0x629c1b4a,0x2489006f,0x9984010b}},	//   bulo_, fpro, _vuam_, pimų_,
   {{0x752f0755,0x26c56828,0x629c0cca,0x64470ce9}},	//   szcz, culo_, gpro, rnji,
   {{0x24890189,0x644746d1,0x9f510132,0x6e220009}},	//   _tuam_, snji, _fazê_, jkob,
   {{0x30155562,0x63ae0ec0,0x764d000e,0x7c3a6829}},	// [6830] одар, babn, _ijay, _omtr,
   {{0x656d682a,0x6440000d,0x66040035,0x68240176}},	//   _izah, émit, _znik, _mòdo,
   {{0xdb01682b,0x69c90345,0x4f6b4717,0x00000000}},	//   _pelí, ygee, ушам_, --,
   {{0x7c28682c,0x68e9001e,0x9f4a011e,0x443a023a}},	//   _aldr, ywed, _babâ_, _zmp_,
   {{0x067c0070,0x224900b5,0x1d091d30,0x26c52cc2}},	//   אנאל, mnak_, рели_, zulo_,
   {{0x2249006c,0x8d7403fb,0x27e51193,0x6fd80b54}},	//   lnak_, سانا, xeln_, न्दू,
   {{0x69c901e4,0x27e51193,0x224901b7,0x00000000}},	//   tgee, veln_, onak_, --,
   {{0x3ced01a9,0x7c28682d,0x22490332,0x68e901ae}},	//   _tsev_, _eldr, nnak_, twed,
   {{0x69c9682e,0x27e50ed4,0x26c5682f,0x22496830}},	//   rgee, teln_, wulo_, inak_,
   {{0x6e291577,0xd7c91301,0x5fcc06d9,0x629c6831}},	//   _hleb, جوده_, ालयल, ypro,
   {{0x6e296832,0x22490332,0x68e96833,0x656d6834}},	//   _kleb, knak_, swed, _azah,
   {{0x443a6835,0x63ae6836,0x27e56837,0xb5fb6838}},	//   _smp_, wabn, seln_, slán,
   {{0x2249213b,0x629c64c1,0x9f5101f4,0xf1bf024e}},	//   dnak_, wpro, _bazë_, _plán_,
   {{0x26c56839,0x4add035d,0xaadd0fbf,0x224906a2}},	//   pulo_, _महाव, _महाक, enak_,
   {{0x366a282d,0x63ae39ea,0x6e3b0273,0xdb0a2919}},	//   _како_, rabn, _omub, tafé,
   {{0x6604683a,0x9fa3008a,0x3a3f0034,0x2249006c}},	//   _unik, _síðu_, niup_, gnak_,
   {{0x7bdc008a,0x291f002f,0x6440683b,0xdddb030d}},	// [6840] _örug, nyua_, émis, _ekuŋ,
   {{0x629c0484,0x6e29124b,0x22490f20,0x443a000d}},	//   ppro, _aleb, anak_, _ump_,
   {{0x9f510260,0x270e013b,0x2c0300ab,0x00000000}},	//   _jazè_, təni_, लाईं_, --,
   {{0xcbc60083,0x645c08f2,0x6e29683c,0xdd9014ac}},	//   _এসেছ, lori, _cleb, روت_,
   {{0x6e22683d,0x9f4701ba,0x9f5102d0,0x3a2d00f8}},	//   rkob, ľná_, _lazè_, dhep_,
   {{0x9f470076,0x6e22683e,0x62830248,0x6e2901d7}},	//   žná_, skob, _énor, _eleb,
   {{0xa3dc0ed1,0xdb03683f,0x1b1d0033,0x60d60104}},	//   ण्य_, taná, _ভেবে_, ltym,
   {{0x201803cb,0x645c6840,0xa2cb0325,0xdb010176}},	//   _hori_, hori, तंत्, _delà,
   {{0x20186841,0x212002c2,0xdb032c8b,0x60d66842}},	//   _kori_, nyih_, raná, ntym,
   {{0x2249006c,0x60d6010b,0x47341d91,0xccf90067}},	//   znak_, itym, знос, _myśl_,
   {{0x645c6843,0x20186844,0x224926ad,0x656404fb}},	//   dori, _mori_, ynak_, _ayih,
   {{0x28c20026,0x656401d5,0x090600af,0x00000000}},	//   _शिपि, _byih, _мпен, --,
   {{0x61f600e9,0xdb010183,0xf1040ed1,0x656404fb}},	//   ddyl, _telã, रमोद_, _cyih,
   {{0x20186845,0x9faf04d4,0x7e600107,0xd61b00b5}},	//   _nori_, _işçi_, _lkmp, اتھا_,
   {{0x2249006c,0xb5fb00b5,0x04fd0033,0x00000000}},	//   tnak_, llám, ুনের_, --,
   {{0x2249422c,0x786f035b,0xa2ac049c,0x06386846}},	//   unak_, røve, _जबर्, _وسيع_,
   {{0x645c6847,0x22494c54,0x765d6848,0x20186849}},	// [6850] bori, rnak_, mosy, _bori_,
   {{0x22493a54,0x2018684a,0x9f4a0176,0x765d684b}},	//   snak_, _cori_, _babà_, losy,
   {{0x2018684c,0x161f0378,0xdb0300a8,0x224900b5}},	//   _dori_, _पवार_, manç, pnak_,
   {{0xfe7000f8,0xdb03684d,0x765d684e,0xa3dc5bba}},	//   ندن_, lanç, nosy, ण्ठ_,
   {{0xeb99498a,0x2018027a,0xd9c20033,0xdca51eb9}},	//   бил_, _fori_, ্জাম, чали,
   {{0xdb03684f,0x9f43016f,0x201815d7,0x6824021e}},	//   nanç, _majú_, _gori_, _bòdm,
   {{0x68e21bea,0x3a3f0034,0xfb85006c,0x765d6850}},	//   _apod, tiup_, _ہدای, kosy,
   {{0x645c6851,0x6e3b0232,0x290d06a2,0xdb0100ee}},	//   zori, _umub, txea_, _celá,
   {{0x645c6852,0xa3dc111b,0x6a65002a,0x648b007a}},	//   yori, ण्ड_, nófi, _jżid,
   {{0x645c0065,0x68e202d7,0x201801ed,0xdb030176}},	//   xori, _dpod, _xori_, janç,
   {{0xdb030370,0xf1cb0380,0x765d5ba3,0x41cb6853}},	//   danç, िलान, fosy, िलास,
   {{0x765d6854,0x60d600c3,0x3cff0124,0x9f4a0183}},	//   gosy, ytym, _kruv_, _jabá_,
   {{0x2bd20e6f,0x3cfe0299,0x280601c0,0xdb0800f7}},	//   _सामा, लिये_, ávní_, _redé,
   {{0x5fc702cb,0xa7fc0463,0xdb030279,0x78fa00a5}},	//   _लागल, nlıl, ganç, _לפנו,
   {{0x20180009,0x765d31dc,0x32190159,0x645c0b73}},	//   _rori_, bosy, _bosy_, rori,
   {{0x2bd20387,0x60d60086,0x20186855,0x239700b8}},	//   _साभा, ttym, _sori_, tějí_,
   {{0x20186856,0x16db0387,0xd25900d8,0x224000be}},	// [6860] _pori_, _बहुब, ццё_, riik_,
   {{0xdb0303e6,0x645c00a8,0x20180510,0x60d66857}},	//   canç, qori, _qori_, rtym,
   {{0x60d62691,0xdfcf00bc,0x20186858,0xbd8a08cf}},	//   stym, ايم_, _vori_, منان_,
   {{0xdd8f0bdf,0x2018010d,0x00000000,0x00000000}},	//   هوم_, _wori_, --, --,
   {{0x628608dd,0xdb0101ba,0x127b016b,0x00000000}},	//   _iiko, _relá, _לאטע, --,
   {{0x62866859,0x28c203de,0xdb03685a,0xa3ac00ab}},	//   _hiko, _शिबि, kanä, खरि_,
   {{0x68e21cb0,0x62862eb8,0xdb010138,0xada65b87}},	//   _spod, _kiko, _pelá, _навл,
   {{0x8cc40d55,0xa9c302ce,0x62860054,0x60c4081b}},	//   _रिपो, нськ, _jiko, orim,
   {{0x6286685b,0xdb011111,0xa3ac3c8d,0x3cff0282}},	//   _miko, _velá, खरा_, _gruv_,
   {{0x6286685c,0x60c40082,0x76b8002d,0x2cb701c0}},	//   _liko, irim, олор_, ředí_,
   {{0xfaa30572,0xe1ff004f,0x628600c3,0x79a60009}},	//   _захо, _mhór_, _oiko, _ерле,
   {{0x60c4685d,0xdb010249,0xae020ec5,0x00000000}},	//   krim, _belæ, _रोमन_, --,
   {{0x67d40210,0xdb0361b1,0x321952a2,0x765d685e}},	//   _жолу, tanç, _rosy_, rosy,
   {{0x60c4685f,0x62860086,0x765d6860,0x00000000}},	//   drim, _aiko, sosy, --,
   {{0xdb036861,0x62866862,0x60c40006,0x3cfe0026}},	//   ranç, _biko, erim, लिडे_,
   {{0x7d000608,0x80e10033,0xdb03000d,0x32640867}},	//   _orms, নিস্, sanç, етув,
   {{0x60c41d68,0x6286072e,0xa6ae0083,0xdff504bf}},	// [6870] grim, _diko, _কমিট, мпањ,
   {{0x44ef6863,0x6a650824,0xd7f80043,0x9f4a01ef}},	//   _iż_, rófi, ndă_, _sabá_,
   {{0x6a653207,0x60c407e5,0xa85700a5,0x2dd51eb9}},	//   sófi, arim, לימה_, джер,
   {{0x60c46864,0x62866865,0x6a650042,0xb5fb00ac}},	//   brim, _giko, pófi, dlák,
   {{0x60c46866,0xdb1a01ef,0xa7fc0448,0xed590207}},	//   crim, _octó, tlıl, _odže_,
   {{0x6f010279,0x628601d0,0x224d0506,0x3cde0067}},	//   _álco, _ziko, čeku_, _गहरे_,
   {{0xa7fc0448,0x628604fb,0x2a95013a,0x00000000}},	//   rlıl, _yiko, _bāba_, --,
   {{0x09e00083,0x68fb007c,0x2bc900b4,0x00000000}},	//   _মোবা, tvud, _राका, --,
   {{0xa7fc0381,0x69db0110,0x00000000,0x00000000}},	//   lmıy, rfue, --, --,
   {{0xb8d5103f,0xa5bb00fb,0x8afc004e,0x63a200f4}},	//   _जब_, skól, _częs, _đono,
   {{0xe0200243,0x44ef004e,0x68fb6867,0x2bd232ea}},	//   _मकसद_, _aż_, svud, _साता,
   {{0x1b1612eb,0x5fdd09b4,0xd7f8002d,0x60c46868}},	//   _থেকে_, न्तल, adă_, yrim,
   {{0x62866869,0xb8f20083,0x798b0024,0xdb01027b}},	//   _riko, _হৈ_, _iggw, _belç,
   {{0x6286686a,0x60c401d6,0xe7290012,0x3cfe018d}},	//   _siko, vrim, _молд_, लिते_,
   {{0x2bdf2e64,0xfbdf00e7,0x44ef007a,0xe2974054}},	//   प्या, प्यम, _eż_, дас_,
   {{0x26c51bd8,0x7aed0067,0x00000000,0x00000000}},	//   mrlo_, łatw, --, --,
   {{0x21673cee,0x6286686b,0x6143686c,0x60c4686d}},	// [6880] дити_, _viko, вета, urim,
   {{0x60c4686e,0x2bd205f7,0x68240211,0x2bc901d1}},	//   rrim, _साधा, _còdh, _रागा,
   {{0x6286686f,0x60c400d7,0x1b1d0033,0x798b030d}},	//   _tiko, srim, _ভেসে_, _oggw,
   {{0x7afc1d2b,0x629e36c4,0xd5ed0023,0xf98718dd}},	//   _árti, _itpo, _khá, _لب_,
   {{0x2bc9009a,0xdb0a043f,0xa7fc037a,0x05b60084}},	//   _राखा, rafí, rmız, _अजनब,
   {{0xdb0a0b4c,0xe50f00b4,0x5fdd021a,0xdd99021e}},	//   safí, ामति_, न्दल, _efň_,
   {{0xb5fb0391,0x644e0a8d,0x15ee004e,0xe8110354}},	//   noác, inbi, ज़ार_, ़ाना_,
   {{0xf2d301f3,0x80e10033,0xb5fb002a,0x00000000}},	//   דעה_, নির্, zoáb, --,
   {{0x26c56870,0x8d636871,0x81e00831,0x00000000}},	//   erlo_, _авте, _দফা_, --,
   {{0xdb0100a6,0x629e0a78,0xdca341f8,0xb5fb5f70}},	//   _belä, _otpo, _рафи, mlái,
   {{0xb5fb0037,0xd7f800af,0x78740176,0x88bd0067}},	//   llái, rdă_, jàve, tyśc,
   {{0xa5f90086,0x7a2e0211,0xdb016872,0xa9263924}},	//   чему_, _dùtc, _selç, _одел,
   {{0x26c56873,0xdb0865c6,0x09d70033,0x63be01f7}},	//   arlo_, _medí, _দোকা, _bdpn,
   {{0xe9470a86,0x3e6e00a0,0x69d500b5,0x7d0400c3}},	//   _ترمی, kýto_, őzet, äisy,
   {{0xb5fb0037,0xe2f80185,0xe7f300a1,0xdb01033b}},	//   hlái, мері_, _असता_, _gelä,
   {{0x644e14e3,0xa7fc027d,0x909901d3,0x200a0051}},	//   anbi, klık, зват_, _anbi_,
   {{0x26cc6874,0x682d0037,0x22846875,0x00000000}},	// [6890] ludo_, _húda, тург, --,
   {{0xa3d60e1d,0xe3c60083,0x44270019,0xe8110035}},	//   _हाय_, শ্বব, _ôn_, ़ाया_,
   {{0x26cc6876,0xd2510609,0xfd1000d1,0x63b52898}},	//   nudo_, _مند_, یجه_, mazn,
   {{0x63b52f6e,0xdb08002a,0x682d002a,0x5d552b4a}},	//   lazn, _cedí, _múda, нкет,
   {{0xeb996877,0xdb086878,0x61ed6879,0x343800d1}},	//   пил_, _dedí, meal, _رسید_,
   {{0xeb99111d,0x27ec0009,0x60cd002f,0xf09f0069}},	//   чик_, jedn_, muam, _ità_,
   {{0x999f01ba,0x60cd00c3,0x9f5100ac,0x2a8700cc}},	//   hnuť_, luam, _kazí_, _bđbp_,
   {{0x61ed687a,0x00000000,0x00000000,0x00000000}},	//   neal, --, --, --,
   {{0x63b51efc,0xa3c10302,0xb5fb0079,0xd8251172}},	//   kazn, ुला_, clái, едпи,
   {{0x61ed687b,0x63b51cb0,0x699f0d00,0xe7390274}},	//   heal, jazn, _ग्री, зео_,
   {{0x366a1169,0x60cd687c,0x61ed0352,0xdb0128a6}},	//   зано_, huam, keal, _belå,
   {{0x60cd0054,0xd5ed0023,0x00000000,0x00000000}},	//   kuam, _phá, --, --,
   {{0x61ed687d,0x63b5080a,0xdb01017b,0x68240359}},	//   deal, fazn, _delå, _nòdw,
   {{0xf1bf01ef,0x26cc687e,0xb6a50139,0x60cd00b9}},	//   _adá_, budo_, _atâţ, duam,
   {{0x26cc0a20,0x91e63804,0x80c2018d,0xa2e3081b}},	//   cudo_, нове, _लिहे, лорд,
   {{0x2bdf06bc,0x2d8d00d7,0x60cd006d,0x61ed687f}},	//   प्ता, _ngee_, fuam, geal,
   {{0x63b56880,0x60cd6881,0x2bd2020c,0x00000000}},	// [68a0] bazn, guam, सलमा, --,
   {{0x25dc0d1f,0x3c2b082b,0x76461c85,0x682401f7}},	//   ग्री_, _søvn_, liky, _pòdi,
   {{0xfbc90fd0,0x2bc96882,0xf09f64a3,0xdb084009}},	//   _राजम, _राजा, _età_, _pedí,
   {{0xe29b00a5,0x61ed6883,0xa7fc0225,0x2bd201d1}},	//   _משטר, ceal, tlık, _साहा,
   {{0x8c46014d,0xc3c90a86,0x60cd01ef,0x1dd100b4}},	//   неде, _عظیم_, cuam, _हारत,
   {{0xf1bf0187,0xa7fc027d,0x26cc022e,0x88bd0033}},	//   _zdá_, rlık, yudo_, _অহংক,
   {{0xb5fb0098,0x00000000,0x00000000,0x00000000}},	//   slái, --, --, --,
   {{0x998d0035,0x00000000,0x00000000,0x00000000}},	//   cież_, --, --, --,
   {{0x29023e34,0xd7fa2028,0x68240107,0xfce3027a}},	//   íka_, пун_, _mòdv, _йото,
   {{0x26cc0bb0,0x81c90083,0xdb060043,0x7e626884}},	//   tudo_, ল্প_, ămân, loop,
   {{0x28c20632,0x63b52e11,0xdb08021d,0xa2e0007e}},	//   _शिवि, vazn, _dedã, _býčí_,
   {{0x26c2011c,0x27ec0009,0xf1bf0168,0x0ae90037}},	//   čko_, sedn_, _hláv_, _تركي_,
   {{0x645a024e,0x63b51534,0x61ed6885,0x9f516886}},	//   čtin, tazn, veal, _razí_,
   {{0xaad40f8a,0x7e620d35,0x61ed00d7,0x682d0079}},	//   _धमाक, hoop, weal, _túda,
   {{0x63b51075,0xf09f07e5,0x7e626887,0x892400b5}},	//   razn, _stà_, koop, _سڑکو,
   {{0xfd260028,0xa3d60b4a,0x60cd6888,0xddcf00f4}},	//   _đình_, _हाथ_, tuam, _žeže,
   {{0x61ed6889,0x660d688a,0x865c0122,0x7e62241d}},	// [68b0] real, _inak, _מדהי, doop,
   {{0x61ed688b,0xc0581958,0x60cd688c,0x9f580055}},	//   seal, ніх_, ruam, _garë_,
   {{0x6447003c,0xa3d61f29,0x53351129,0x61ed01bb}},	//   miji, _हात_, _рент, peal,
   {{0x6447688d,0x09e00033,0x7a3e00e1,0x00000000}},	//   liji, _মোসা, būti, --,
   {{0x60cd027a,0x660d688e,0x0638016b,0x00000000}},	//   quam, _mnak, ענדט_, --,
   {{0x64472251,0x68240176,0xb5fb0132,0x628a01ef}},	//   niji, _kòdu, cláv, _éfor,
   {{0x660d326f,0x2bd202e4,0xdb0a01ef,0xfbd2057c}},	//   _onak, _सारा, tafá, _सारम,
   {{0x28c200b4,0x660d01a8,0x68240443,0x3ebe03d0}},	//   _शिशि, _nnak, _mòdu, _ætta_,
   {{0x09e00083,0x64470af0,0xc5b00033,0x0ec900a1}},	//   _মোহা, kiji, _কালপ, ांकड,
   {{0x660d52f0,0x64472f59,0x7a4700e0,0x7c2a05aa}},	//   _anak, jiji, _bètè, ckfr,
   {{0xaac729fe,0x81c90033,0x76464e27,0x682401f7}},	//   _ستان, ল্য_, tiky, _nòdu,
   {{0xddc21977,0x9f580260,0x8be60033,0xeab000bc}},	//   ološ, _darè_, _গোপন_, _طعم_,
   {{0x9f5801d2,0xdb0100ee,0x00000000,0x00000000}},	//   _parë_, _nelú, --, --,
   {{0xa5a20026,0x660d688f,0x64476890,0x64a3010b}},	//   _क्रौ, _enak, giji, рара,
   {{0xc7d602b8,0x7e620103,0xfbd200a5,0x78bb003e}},	//   _יוסי_, yoop, יתם_, lsuv,
   {{0xdb0801ba,0xddc26891,0x00000000,0x00000000}},	//   _jedá, kloš, --, --,
   {{0x7bc10537,0x64476892,0x76440010,0xd1863efc}},	// [68c0] _odlu, biji, _imiy, тлай,
   {{0x25e30992,0x9f5800de,0xddc2012e,0x64476893}},	//   ट्ठी_, _haré_, dloš, ciji,
   {{0x44446894,0x7e626895,0x9f580168,0x00000000}},	//   _im_, toop, _karé_, --,
   {{0xdb08024e,0x471a02b5,0x78bb03a6,0xb5fb6896}},	//   _nedá, וועג, ksuv, sláv,
   {{0x7e622efa,0x9f4300de,0x9f58494e,0xdb080176}},	//   roop, _bajó_, _maré_, _sedà,
   {{0x682d01ba,0x9f5801cb,0x81ba0033,0x8fa31402}},	//   _súdn, _laré_, _আউট_, _варе,
   {{0x44446897,0x7c2a008d,0xdddc007a,0x99d6063d}},	//   _mm_, rkfr, _kurż, نتظا,
   {{0xda0906bc,0x64476898,0xc9860073,0x7bc10523}},	//   वागत_, ziji, купи, _edlu,
   {{0x8e5501e0,0xb5fb01ef,0x6e20023c,0x272207c0}},	//   _стрі, ilát, _iomb, _očná_,
   {{0x6e2000c8,0x660d6899,0x7644689a,0x88bd004e}},	//   _homb, _snak, _amiy, myśl,
   {{0x61e6024e,0x64472f17,0xa3d60006,0x7d02689b}},	//   _obkl, viji, हलन_, lvos,
   {{0x4444689c,0x2911004f,0x6e20689d,0x644700bf}},	//   _am_, ónaí_, _jomb, wiji,
   {{0x6447689e,0x6e20689f,0xdd110716,0xe1f30493}},	//   tiji, _momb, _müşa, یسر_,
   {{0x764468a0,0x9f43021e,0x61e602b1,0xa5bb0067}},	//   _emiy, _majò_, _abkl, yków,
   {{0x644768a1,0x444468a2,0x6e200173,0x9f580310}},	//   riji, _dm_, _oomb, _faré_,
   {{0x444468a3,0x6e2068a4,0x27fc08c8,0x644768a5}},	//   _em_, _nomb, _havn_, siji,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [68d0] --, --, --, --,
   {{0x2ca631dc,0x53470f88,0xb034081b,0x26de027a}},	//   dpod_, _ахма, ануш, otto_,
   {{0x42550416,0xdd910037,0x26de3706,0xe458016b}},	//   _مندر, موا_, ntto_, _ביזט_,
   {{0x13b80083,0x4421393e,0x74aa0461,0xddc200cd}},	//   _জায়, _hoh_, जीकृ, tloš,
   {{0x444468a6,0x44213d9c,0x6e2068a7,0xb5fb006c}},	//   _ym_, _koh_, _domb, llás,
   {{0x61fd44fd,0x442168a8,0x27fc1123,0x224968a9}},	//   _hasl, _joh_, _navn_, liak_,
   {{0xe81602cb,0x6e200107,0xaa450002,0x3cef0299}},	//   ताना_, _fomb, лекл, _इनके_,
   {{0xe8f91099,0xa3e30299,0x61fd68aa,0x6e2068ab}},	//   ели_, फ्त_, _jasl, _gomb,
   {{0xb5fb68ac,0x656d68ad,0x443368ae,0x21296338}},	//   hlás, _nyah, _olx_, nyah_,
   {{0x442168af,0x61fd68b0,0x212900d7,0x9f5800e0}},	//   _noh_, _lasl, iyah_, _saré_,
   {{0x444468b1,0x06860036,0x656d005d,0x22490291}},	//   _rm_, лгон, _ayah, kiak_,
   {{0x61fd04c3,0x64a668b2,0x2bdf05f7,0xfbdf00a1}},	//   _nasl, лама, प्रा, प्रम,
   {{0x37e55fb8,0x444468b3,0x442168b4,0x7a3568b5}},	//   _болг, _pm_, _boh_, _cáte,
   {{0x656d0159,0xb744006c,0x444468b6,0xdb01177c}},	//   _dyah, ائیو, _qm_, _belø,
   {{0x44215179,0x61fd68b7,0x6445009e,0x08760070}},	//   _doh_, _basl, _dmhi, _געסט_,
   {{0x22490291,0x444468b8,0x443368b9,0x9f4a0176}},	//   giak_, _wm_, _elx_, _tabú_,
   {{0x6e2065fc,0xb5fb00b5,0x68eb0124,0x444406c6}},	// [68e0] _romb, rlát, _jpgd, _tm_,
   {{0x444468ba,0x442168bb,0xb5fb68bc,0x61fd68bd}},	//   _um_, _goh_, slát, _easl,
   {{0x0dca68be,0xb5fb0a20,0x6e2068bf,0xa5650493}},	//   елей_, clás, _pomb, _مدین,
   {{0xe1f21015,0xed5a03ad,0x7e7b68c0,0xb5fb64ce}},	//   _اسد_, ное_, _chup, llár,
   {{0x442168c1,0x61e468c2,0x2ca6043d,0xe816000c}},	//   _yoh_, mfil, upod_, तामा_,
   {{0x7d0268c3,0x78a20009,0x2bdf0026,0x7c2149ea}},	//   rvos, _rtov, प्ला, _colr,
   {{0x78a24877,0xd6ae00c8,0x2ca631e1,0xaa660814}},	//   _stov, _কম্প, spod_, лтик,
   {{0x29062651,0x48aa219f,0xdb180055,0x6e20023c}},	//   _proa_, нтом_, lavë, _uomb,
   {{0x38342186,0x27fc028b,0x7c2101f7,0xf1bf008d}},	//   инир, _pavn_, _folr, _klár_,
   {{0x22490291,0xe45f68c4,0xdb030097,0x61e409a2}},	//   ziak_, tröm_, laný, hfil,
   {{0x9b930514,0xab93004f,0x656d128f,0x44211034}},	//   _المت, _المغ, _syah, _roh_,
   {{0x212968c5,0x7a3500b8,0x1a9b0070,0x442168c6}},	//   yyah_, _páte, _נידע, _soh_,
   {{0x44210487,0x61fd3c54,0x78a268c7,0x61e468c8}},	//   _poh_, _rasl, _utov, dfil,
   {{0xb4e5006a,0x61fd176d,0x61e41c1c,0xdb0300ac}},	//   _नही_, _sasl, efil, haný,
   {{0x0cd1210a,0x61fd01c8,0x5334465e,0x62985072}},	//   _सम्म, _pasl, берт, _évol,
   {{0x53345de9,0x61e468c9,0x442168ca,0xb5fb006c}},	//   щест, gfil, _woh_, rlás,
   {{0x7bda68cb,0x224903cb,0x44211658,0xdb030187}},	// [68f0] _octu, riak_, _toh_, daný,
   {{0x7e691f4a,0x661d1851,0xf1bf004f,0x224968cc}},	//   _skep, ljsk, _clár_, siak_,
   {{0x21290ac8,0x61fd68cd,0xaca30019,0x2cbf022f}},	//   syah_, _tasl, _trịn, _svud_,
   {{0x7bda2370,0x661d02dd,0x61fd004f,0xddc20035}},	//   _actu, njsk, _uasl, mnoś,
   {{0xddc2006a,0x7c2168ce,0xb21b0b3e,0x7afa0312}},	//   lnoś, _polr, _diæt, _astt,
   {{0x628f00d7,0x645568cf,0x00000000,0x00000000}},	//   _hico, nnzi, --, --,
   {{0xf991004f,0x60cd0079,0x4af90144,0xddc20035}},	//   يبة_, lram, тэля_, nnoś,
   {{0x6d5b0189,0xba251566,0x60cd0382,0x7c210345}},	//   _txua, рдик, oram, _wolr,
   {{0x26cc0083,0xa3d619b7,0xe1ff0392,0x60cd026e}},	//   erdo_, _हाल_, _maó_, nram,
   {{0x200100d1,0x3a2d053e,0x7d0968d0,0xaae70c74}},	//   ndhi_, skep_, _ires, _مسؤو,
   {{0x60cd68d1,0x2bab02cb,0x200168d2,0x7d090093}},	//   hram, _घ्या, idhi_, _hres,
   {{0xddc2004e,0x645507e5,0x96662a9a,0x4a9a011d}},	//   dnoś, enzi, ркме, _סינג,
   {{0x60cd0055,0x9983010b,0x9576454f,0x4438016e}},	//   jram, ėjų_, рынч, thr_,
   {{0x62971505,0xdb030097,0x26cc0506,0x17070fa2}},	//   _buxo, zaný, brdo_, _مفتی_,
   {{0xe5a602ee,0x2a7d0221,0x2001027c,0x78a968d3}},	//   _кийи, _khwb_, ddhi_, lpev,
   {{0x60cd68d4,0x201168d5,0x98a200d8,0x64550054}},	//   fram, _anzi_, šką_, anzi,
   {{0xdb030076,0x628f68d6,0x9f47016f,0x3e7c0187}},	// [6900] vaný, _dico, ľný_, níte_,
   {{0x9f47024e,0xf09f0019,0x628f583b,0x00000000}},	//   žný_, _tràn_, _eico, --,
   {{0x91e668d7,0x628f68d8,0x60cd68d9,0xd7dd0035}},	//   _коне, _fico, aram, _मानच,
   {{0xa3d60953,0x60cd68da,0x0e660763,0x20110054}},	//   _हाँ_, bram, шкен, _enzi_,
   {{0x7d0968db,0x628468dc,0x3e7c0097,0xdb080282}},	//   _cres, mmio, jíte_, _medå,
   {{0x3e7c024e,0x7d0968dd,0x628f023a,0x628468de}},	//   díte_, _dres, _zico, lmio,
   {{0x7d0968df,0x9f5800d5,0x661d0067,0xb5fb00ac}},	//   _eres, _karí_, yjsk, kláp,
   {{0x7d0968e0,0x628f68e1,0x2bd205f7,0x5ca600af}},	//   _fres, _xico, _साका, _виаб,
   {{0x7d0968e2,0xa3d6238a,0xdca33b8b,0x9f580392}},	//   _gres, हला_, _мати, _marí_,
   {{0x63bc68e3,0x7bda00ee,0x69a622c7,0x290000c7}},	//   jarn, _uctu, _ट्री, _šias_,
   {{0x63bc68e4,0xeb971f7e,0xcfcc0033,0xdc3b00a5}},	//   darn, _тих_, র্থন, _שעבר,
   {{0xf64703d0,0x60cd0463,0xc98651be,0xd6d70012}},	//   рхон, yram, _кули, шть_,
   {{0x628f0133,0x6284004e,0xddc2004e,0x63bc518e}},	//   _rico, dmio, wnoś, farn,
   {{0x63bc68e5,0xddc2004e,0xcfcc0083,0xdd9900ee}},	//   garn, tnoś, র্তন, _maňa_,
   {{0xe1ff0176,0xdb030176,0x765600fd,0x00000000}},	//   _paó_, lanò, ógyá, --,
   {{0x80c20299,0xddc20035,0xdce902c4,0x229c031d}},	//   _लिखे, rnoś, _uzeć, _dík_,
   {{0x63b701c2,0x51870b6b,0x60cd0443,0xddc20035}},	// [6910] _texn, рува, uram, snoś,
   {{0x60cd1c98,0x7d0901f4,0x25e31db9,0x7a3568e6}},	//   rram, _rres, ट्री_, _máta,
   {{0x5fdd009a,0xf09f0019,0x7d09011c,0xa7fc00a8}},	//   न्गल, _trào_, _sres, nlıq,
   {{0x60cd2286,0xdb010187,0x7a3c006c,0x9f580176}},	//   pram, _celý, _hétf, _garí_,
   {{0xaca30028,0x60cd01c2,0x787d00f7,0x3c39000d}},	//   _trọn, qram, lève, _lève_,
   {{0x7d0968e7,0x3e7c0314,0x8c6710b4,0x1c4402a4}},	//   _vres, víte_, штед, онім,
   {{0xad9d0035,0xdef80012,0xa3dc0683,0x7d0968e8}},	//   _paźd, _кыт_, ण्ट_, _wres,
   {{0x61e9007c,0x7a3568e9,0x3e7c0187,0xa7fc00a8}},	//   _öeld, _báta, títe_, dlıq,
   {{0x63bc0034,0x7d0968ea,0x7a2e01a6,0x7a350138}},	//   yarn, _ures, _mùth, _cáta,
   {{0xfc33211f,0x7a354969,0x7a2e01da,0x68451482}},	//   _بحر_, _dáta, _lùth, ённа,
   {{0x63bc2a9f,0x3e7c0076,0x78a939ea,0xa3d6007c}},	//   varn, síte_, spev, हलस_,
   {{0x80ad0083,0x63bc06d4,0xb995004f,0x78a968eb}},	//   _চিন্, warn, _الإب, ppev,
   {{0x682d4db2,0x9985004f,0x53dc198f,0x09e00033}},	//   _lúdi, _الشو, _बादश, _মোকা,
   {{0x53a306d8,0x03a368ec,0x3c3900f6,0x00000000}},	//   зарб, зиро, _fève_, --,
   {{0x63bc68ed,0xf48600b5,0x7a2e0284,0x7a3500ac}},	//   rarn, لاڑی, _bùth, _záta,
   {{0x984f00a8,0x00000000,0x00000000,0x00000000}},	//   _işıq_, --, --, --,
   {{0xdb180370,0x4fea11d0,0x7a2e0014,0x682d021d}},	// [6920] ravé, лман_, _dùth, _aúdi,
   {{0xdb01006c,0x9588004e,0x3ae100b5,0x628400b9}},	//   _belü, _ciąż, kóp_, smio,
   {{0xd9f90429,0x232a09cc,0x644e68ee,0x93fb02b5}},	//   ्यात_, _сони_, mibi, _גליי,
   {{0x0d860f23,0x6d031db9,0x023400b5,0x00000000}},	//   блен, लिंग_, _بہرح, --,
   {{0xa7fc013b,0x00000000,0x00000000,0x00000000}},	//   zlıq, --, --, --,
   {{0x6fd502ce,0xdb01006c,0xa0a32701,0x7a3568ef}},	//   _місц, _felü, _хард, _ráta,
   {{0x0aea0af8,0x7bd82193,0xa3d60b47,0xb05b0282}},	//   ارتي_, rgvu, _हाई_, _kvän,
   {{0x644e68f0,0x3ea768f1,0x61f610b1,0x64800421}},	//   hibi, ínte_, neyl, löid,
   {{0x644e68f2,0x320200d5,0x261c05f8,0xad2601cb}},	//   kibi, _maky_, यानी_, _ارزو,
   {{0x644e000e,0x74230033,0x32020097,0xdb010067}},	//   jibi, _নষ্ট_, _laky_, _celó,
   {{0xb05b01ff,0x7bc8009f,0xdca300af,0x00000000}},	//   _ovän, _iddu, _маӂи, --,
   {{0xa7fc00a8,0x98c40225,0x00000000,0x00000000}},	//   rlıq, ştık_, --, --,
   {{0xdb0101ef,0x9f580392,0xda650c74,0x00000000}},	//   _feló, _larà_, _بالي, --,
   {{0x3a260903,0xdb010176,0x648000c3,0x00000000}},	//   _hoop_, _geló, jöid, --,
   {{0x3a260903,0x2be00f9f,0xcfde0083,0x25e10324}},	//   _koop_, _नाना, ড়ান, _कापी_,
   {{0x3a264ee8,0x7a3568f3,0xe81600b4,0x926b2a2d}},	//   _joop_, _látn, तावा_, урга_,
   {{0x644e68f4,0x320701c0,0x3a260051,0x32020168}},	// [6930] bibi, ěny_, _moop_, _daky_,
   {{0x644e09ab,0x764f68f5,0x9f580176,0xdb08002a}},	//   cibi, licy, _barà_, _dedú,
   {{0xe7ea00a1,0x3ea70c7c,0xa1953aee,0x00000000}},	//   ज्या_, ënt_, _манч, --,
   {{0x25e10953,0x7bc822a4,0xed5100d1,0x9f5807e5}},	//   _काफी_, _addu, وپا_, _darà_,
   {{0x25e1020d,0x9c7d0107,0x00000000,0x00000000}},	//   _कानी_, _opōt, --, --,
   {{0x9f582f88,0x9f4a0176,0x00000000,0x00000000}},	//   _farà_, _cabó_, --, --,
   {{0xdb0103e6,0x9e350421,0xa6fa0831,0x00000000}},	//   _reló, _девч, ইমুম_, --,
   {{0x200368f6,0xed150332,0x644e68f7,0x7bc8018e}},	//   _haji_, _وہاں_, zibi, _eddu,
   {{0x8c190987,0x200368f8,0x3a26053e,0xddc90069}},	//   _پيار_, _kaji_, _doop_, _mheż,
   {{0x2003000e,0x9f580831,0x752f004e,0xdb010260}},	//   _jaji_, _hará_, dycz, _delò,
   {{0x20030657,0x644e07e5,0x86990370,0xdb012127}},	//   _maji_, vibi, јтот_, _veló,
   {{0x29180079,0x3a260523,0x366a0274,0x764f0371}},	//   ófaí_, _goop_, рамо_, gicy,
   {{0x2be01119,0xfbe001c0,0xf77302fd,0xa907026b}},	//   _नामा, _नामम, _کاش_, _دبان,
   {{0x69db38bc,0xb05b013c,0xdb080042,0x3a260051}},	//   lgue, _svän, _redú, _zoop_,
   {{0x644e68f9,0xe8160325,0x320268fa,0x764f0371}},	//   ribi, तारा_, _paky_, bicy,
   {{0x644e68fb,0x69db68fc,0xd2990044,0x41aa0036}},	//   sibi, ngue, стрі_, рван_,
   {{0x9f5801d3,0x7a3553b1,0x200300d7,0x32020097}},	// [6940] _sarà_, _láto, _baji_, _vaky_,
   {{0xdb0801ba,0x9f585c1d,0xdb1a021d,0x6604666e}},	//   _vedú, _parà_, _detê, _haik,
   {{0x66040d36,0x200703e6,0x320201c0,0x64800086}},	//   _kaik, ônia_, _taky_, röid,
   {{0x0caa0665,0x66045688,0x9f4a68fd,0xf1e137e8}},	//   атки_, _jaik, _babò_, _फायन,
   {{0x66043884,0xb05b022a,0x9f580152,0x6eaa006c}},	//   _maik, _kväl, _dará_, انچہ_,
   {{0x660468fe,0x200320fb,0x8aa60a7c,0x7a3c57ff}},	//   _laik, _gaji_, орид, _méte,
   {{0x752f006a,0x3f980a78,0x443a035f,0x9f5868ff}},	//   zycz, _igru_, _mlp_, _fará_,
   {{0x66045306,0x1cba1d6c,0x80ad0083,0xcfcc0033}},	//   _naik, _نائب_, _চিত্, র্শন,
   {{0xdb08008c,0xb05b0282,0x00000000,0x00000000}},	//   _ledø, _oväl, --, --,
   {{0xdb1a00da,0x60c46900,0x7b16004f,0x6616010b}},	//   _jetë, isim, _وظائ, _anyk,
   {{0x09e66901,0x907b1899,0x6fdd00a1,0x764f0027}},	//   _можн, שטיי, _पासू, ticy,
   {{0x60c46902,0x752f006a,0xdb1a00da,0x09b40083}},	//   ksim, tycz, _letë, _টাকা,
   {{0x3ce66903,0x08fa0609,0x660400d8,0x7c286904}},	//   ntov_, _خراب_, _daik, _kodr,
   {{0x69c06905,0x7a3c02e1,0x752f004e,0xdb08390d}},	//   lame, _déte, rycz, _bedø,
   {{0x43946906,0x443a0526,0x2003433c,0x752f0035}},	//   дарс, _dlp_, _raji_, sycz,
   {{0xdb1800fb,0x3ce62ce5,0x443a012f,0x6fdd00a1}},	//   javí, ktov_, _elp_, _पाहू,
   {{0x7c3a01d3,0xdb180033,0xcf9b0202,0x443a022e}},	// [6950] _oltr, daví, аје_, _flp_,
   {{0x69c06907,0x7c280029,0x38a00014,0xdb031e2e}},	//   hame, _nodr, _mòr_, manö,
   {{0xe7e20f39,0x09e000c8,0x69c01901,0x60c46908}},	//   _खाना_, _মোছা, kame, asim,
   {{0x7c3a6909,0x69c0690a,0x6e22006c,0x7c28009e}},	//   _altr, jame, gjob, _aodr,
   {{0x7c28690b,0x2003002f,0x1d091052,0x43d40e3a}},	//   _bodr, _taji_, сели_, _عزیز,
   {{0xf1bf0391,0x5fe202e4,0xb09a00a5,0x7c2801fd}},	//   _xoán_, _पायल, _לישר, _codr,
   {{0x7c28690c,0xdb1a0260,0xdb18040f,0x00000000}},	//   _dodr, _jetè, baví, --,
   {{0x69c06226,0x6e220312,0x3cff006d,0x69db1214}},	//   game, cjob, _tsuv_, ugue,
   {{0x69db2c35,0xe8e001a5,0x6604145d,0xed5901f2}},	//   rgue, _đợi_, _raik, _beže_,
   {{0x660400bf,0x764d2107,0x68fb0034,0x69db690d}},	//   _saik, _amay, rwud, sgue,
   {{0x6604690e,0x69c0690f,0xdb2300d1,0x6e296910}},	//   _paik, bame, _توضی, _koeb,
   {{0x261c0302,0x7a3c00b5,0x7c280120,0xb5fb0132}},	//   याधी_, _péte, _zodr, zoáv,
   {{0x66044cc4,0xe8ee0ffd,0x69cb011e,0x764d0176}},	//   _vaik, _ял_, _idge, _dmay,
   {{0x764d0107,0xf7451400,0xdb1a0359,0x7a3c00b5}},	//   _emay, _нело, _betè, _véte,
   {{0x660415eb,0xd9e20243,0x6e3b6911,0xa3dd07b5}},	//   _taik, क्कत_, _olub, _डार_,
   {{0x60c46912,0x6e29012f,0xdb1a02d0,0x7a3c00b5}},	//   tsim, _noeb, _detè, _téte,
   {{0x60c401c8,0xf1bf0028,0x443a023c,0xb1460dee}},	// [6960] usim, _toán_, _tlp_, чнал,
   {{0x88bd00c8,0xaf9a2246,0xa3d60324,0xdb1a01f4}},	//   _আমাক, стах_, _हाट_, _qetë,
   {{0x60c46913,0xdb1a01d2,0x7c2821a4,0x69c06914}},	//   ssim, _vetë, _rodr, yame,
   {{0x6e3b6915,0xfe72147f,0x0d8614a9,0x7c286916}},	//   _club, ردا_, плен, _sodr,
   {{0x2be01fb4,0x60c4003c,0xdb180187,0x6e2233c2}},	//   _नादा, qsim, raví, rjob,
   {{0x629e08c7,0x26c500d8,0x3ce60bcc,0x68e40086}},	//   _kupo, kslo_, rtov_, _äidi,
   {{0xd9f902cb,0x80a2045c,0x3ce66917,0x69c06918}},	//   ्यंत_, _कंडे, stov_, tame,
   {{0x6e3b00d7,0x3ce64644,0xaf5b00a5,0xed59030a}},	//   _glub, ptov_, _הכלכ, _seže_,
   {{0xa3dd0299,0x629e6919,0x98a4010b,0xdb1a2fba}},	//   _डाल_, _lupo, kymą_, _meté,
   {{0x4734691a,0x645c01f2,0x69cb0f00,0x00000000}},	//   днос, jnri, _edge, --,
   {{0x69c0691b,0x290f0069,0xe7dd0461,0xed596471}},	//   pame, _erga_, _मारप, _veže_,
   {{0x0f570122,0x6b7b02b5,0x69c00510,0x3ebe0093}},	//   ליים_, _פראנ, qame, _ættu_,
   {{0xed590528,0x290f022f,0xdb1a0118,0xab630067}},	//   _teže_, _grga_, _setè, ężen,
   {{0xdb1a02d0,0x629e030d,0xab5c00ec,0x00000000}},	//   _petè, _bupo, _ceļg, --,
   {{0x274200d1,0x63be008c,0xdb1a00fd,0x764d0103}},	//   _déné_, _depn, _beté, _tmay,
   {{0x764d1d38,0x2018691c,0xeb3b0070,0x645c0298}},	//   _umay, _anri_, זעלש, anri,
   {{0x236d004e,0xdb1a2314,0x629a0138,0x629e0069}},	// [6970] łej_, _deté, ítor, _eupo,
   {{0x6e29691d,0x6387691e,0x274200f6,0x2f8b0200}},	//   _soeb, géné, _géné_, бљен_,
   {{0xfe7103fc,0x02a4093c,0x6e3b0211,0x00000000}},	//   نگر_, _прям, _plub, --,
   {{0x224028f4,0xdd910dc0,0x648b009f,0x765d691f}},	//   chik_, نوا_, _eżit, nnsy,
   {{0xfce510d4,0xdb01006c,0x682d00a0,0x69cf01ef}},	//   фоло, _jelö, _múdr, ócem,
   {{0x320905f5,0x61ed6920,0x00000000,0x00000000}},	//   lday_, lfal, --, --,
   {{0xdcfb0759,0x6e2909a6,0x25a900e9,0x00000000}},	//   _izuč, _toeb, _ofal_, --,
   {{0x61ed6921,0x6e3b004e,0x3209293c,0x291f01a3}},	//   nfal, _ulub, nday_, txua_,
   {{0xa3dd00a1,0x3dcd0107,0x261c3e9e,0xb5fb00fd}},	//   डला_, _idew_, यासी_, bláz,
   {{0xb5fb00de,0x3a3f03d0,0x32096922,0x68240107}},	//   zoát, shup_, hday_, _kòdy,
   {{0x63be37c4,0xfe70006c,0x27420118,0xe3e30033}},	//   _repn, _شدہ_, _réné_, য়াব,
   {{0x7bc36923,0xddc203c9,0x26c500d8,0xa5bb0093}},	//   lanu, zlož, rslo_, sjón,
   {{0x7a350237,0x29030029,0xdb1a01ef,0x61ed49fa}},	//   _látk, ājas_, _reté, dfal,
   {{0x61ed6924,0x765d022e,0x629e0cc2,0xe29a6925}},	//   efal, ansy, _pupo, жав_,
   {{0x03a30d46,0x81e60083,0x224000d1,0xe7e219b7}},	//   тисо, _যোগ_, thik_, _खाता_,
   {{0x7bc3564a,0xdb0800d5,0x61ed5549,0x7a3c13cf}},	//   hanu, _nedý, gfal, _kéta,
   {{0x68e96926,0x3ead0129,0xf7780484,0xdb0101ae}},	// [6980] nted, _četa_, mgħa_, _gelö,
   {{0x7a3c0248,0x7bc36927,0x261c00a1,0x61e900be}},	//   _méta, janu, यावी_, _öeln,
   {{0x441b00c2,0x141b02b5,0x7bc36928,0x63870248}},	//   _וויס, _וויב, danu, réné,
   {{0x68e90723,0xddc216ae,0x16140067,0x00000000}},	//   kted, slož, _तोमर_, --,
   {{0x25e30e1d,0x7bc36929,0xdca3692a,0x8c4602fb}},	//   ट्टी_, fanu, вачи, меде,
   {{0x7bc3692b,0x2ca91e60,0x3dcd021e,0x787d0176}},	//   ganu, íada_, _edew_, dèvo,
   {{0x5f031c2e,0x160e0bc1,0xddc6692c,0x26ca0484}},	//   _изра, ियार_, _обви, ġbok_,
   {{0x2be000a1,0x68e9692d,0x99860097,0x7a3c2507}},	//   _नावा, fted, _vlož_, _béta,
   {{0x7bc30232,0x7a355f70,0x68e901b4,0xa3c032da}},	//   banu, _máth, gted, ुणा_,
   {{0x25e10429,0x7a3c02e1,0x7a355f8a,0x7bc30139}},	//   _काही_, _déta, _láth, canu,
   {{0x3209524e,0x61ed692e,0x60d60090,0x99860097}},	//   yday_, yfal, hrym, _ulož_,
   {{0xa4d52659,0x290d0009,0x68e9692f,0x00000000}},	//   номі, bvea_, bted, --,
   {{0x68e950f0,0x765d0c61,0xd826021d,0x00000000}},	//   cted, rnsy, _одди, --,
   {{0xed59003d,0x260f00ab,0x00000000,0x00000000}},	//   _ježa_, _तोरी_, --, --,
   {{0x61ed6930,0x25a9003c,0x261c00a1,0xed5900ea}},	//   tfal, _tfal_, याशी_, _meža_,
   {{0x7bc30160,0xc7ad00b5,0xe81601c0,0x25a9021d}},	//   zanu, _پڑی_, ताका_, _ufal_,
   {{0x30151ce8,0x261c0953,0xf09f01a5,0x32096931}},	// [6990] ндар, यारी_, _quà_, rday_,
   {{0x32096931,0x47d00083,0xdb08033b,0x44380ca5}},	//   sday_, ত্রী, _bedü, ckr_,
   {{0x64556423,0x47c30083,0x7bc36932,0x2cad0909}},	//   mizi, _শামী, vanu, _sted_,
   {{0x200702dd,0x7bc36933,0x648b035f,0x8c3d0139}},	//   žni_, wanu, _gżir, _muşe,
   {{0x7bc36934,0x4fc7178e,0xb5fb002a,0x60d600f6}},	//   tanu, _осва, onáb, crym,
   {{0xdb850043,0x09c700a1,0x62980132,0x7a3c000d}},	//   нгли, ळण्य, _évor, _réta,
   {{0x7bc36935,0xeb960227,0xed590009,0xdab900d8}},	//   ranu, ниш_, _deža_, чылі_,
   {{0x68e9177c,0x64550043,0x49931a95,0x7a3c4135}},	//   tted, hizi, نیار, _péta,
   {{0x64550ce7,0xdb18314b,0xe8f61ac5,0x2d5800c3}},	//   kizi, ravá, елы_, _жить_,
   {{0x68e96936,0x9bf4257f,0x7c380051,0x64556937}},	//   rted, _изуч, ckvr, jizi,
   {{0x64556938,0x68e96939,0x25e1030f,0x7a35008a}},	//   dizi, sted, _काशी_, _láti,
   {{0xdd12027d,0x7a3c00f6,0x68e90a21,0x00000000}},	//   nüşt, _téta, pted, --,
   {{0x7bc14367,0x645503dd,0x25e104bc,0x7a3568ef}},	//   _kelu, fizi, _कारी_, _ráth,
   {{0x6286071f,0x64552ed0,0x7bc1693a,0xd8d60070}},	//   _shko, gizi, _jelu, _נוצט_,
   {{0x7bc10f1a,0xdb01021d,0x221600c7,0x6aa10523}},	//   _melu, _telõ, нфар, _julf,
   {{0x7bc1693b,0x628d0008,0x60d6693c,0x7a35003e}},	//   _lelu, gmao, trym, _báti,
   {{0xe0da693d,0x645562c8,0x6143693e,0xe8140325}},	// [69a0] ява_, bizi, гета, _थोडा_,
   {{0x6455693f,0x7bc16940,0x7a3501ef,0x9f5a00d5}},	//   cizi, _nelu, _dáti, lepé_,
   {{0x671f1119,0xe7e20066,0x7a350079,0x249a0069}},	//   यमिक_, _खासा_, _táth, _iipm_,
   {{0x7a35478a,0x4d6600d8,0x5fe20099,0xf9870079}},	//   _fáti, нкев, _पावल, _مب_,
   {{0x7bc14322,0x629800f7,0x00000000,0x00000000}},	//   _belu, _évoq, --, --,
   {{0xdee62f2c,0x9f580098,0x6aa1026e,0x00000000}},	//   _поги, _marú_, _bulf, --,
   {{0x7bc16941,0x25e11a75,0x61ef0037,0x3e751281}},	//   _delu, _काली_, _éilí, tått_,
   {{0x3f7b0070,0x645535a7,0x6aa10176,0xf09f0284}},	//   _זאלס, zizi, _dulf, _gràs_,
   {{0x0d860202,0x200a6942,0x7bc16943,0x64551939}},	//   _члан, _kabi_, _felu, yizi,
   {{0x7bc10d26,0xdca3021d,0x2ef80009,0x200a6944}},	//   _gelu, _сафи, _kprf_, _jabi_,
   {{0x6aa103d0,0x8ad606ee,0x200a251e,0x00000000}},	//   _gulf, _ستائ, _mabi_, --,
   {{0x200a6945,0x7bc163ec,0x6455007b,0xbb3b00a5}},	//   _labi_, _zelu, wizi, _מעבי,
   {{0x64556946,0xda6f006c,0x249a046a,0xdb1a0300}},	//   tizi, _اُن_, _bipm_, _metí,
   {{0x200a19d4,0xd4986947,0xdb1a6948,0x249a0183}},	//   _nabi_, ерс_, _letí, _cipm_,
   {{0x64556949,0x7a350473,0x648b0069,0x13683175}},	//   rizi, _sáti, _dżip, ешти_,
   {{0x7a3c1423,0x6455694a,0xa3dd0299,0x26de024e}},	//   _méto, sizi, _डाक_, muto_,
   {{0x26de694b,0x628d694c,0x9f4a0069,0x6ed300ab}},	// [69b0] luto_, rmao, _abbà_, _डिहु,
   {{0xd2510357,0x78a21583,0xb88101c0,0x61e601a2}},	//   _چند_, _muov, _říze, _eckl,
   {{0x26de694d,0x7bc1694e,0xad2705f5,0x78a200c3}},	//   nuto_, _relu, کراو, _luov,
   {{0x7bc11201,0x290606a2,0x7a350279,0xf7730070}},	//   _selu, _osoa_, _táti, אקע_,
   {{0x78a20021,0x7bc1694f,0x51846950,0xdb1a0042}},	//   _nuov, _pelu, _бура, _detí,
   {{0x200a00a7,0x2ef5496c,0x8d7400d2,0x41e10084}},	//   _gabi_, _изгр, داما, _फाँस,
   {{0x48bd0083,0x26de6951,0xdb1800ab,0x69c20b0d}},	//   _আমের, juto_, javä, _beoe,
   {{0x26de6952,0x7a3c00f7,0x200a00ee,0x6aa16953}},	//   duto_, _déto, _zabi_, _vulf,
   {{0x7bc14507,0x8c3d0160,0x6aa16954,0x981500fd}},	//   _telu, _cuşc, _wulf, نبدا,
   {{0xe7392afc,0x5d5407f2,0x3ea301f4,0x200a5565}},	//   део_, _скут, _kujt_, _xabi_,
   {{0x366a27fa,0x41e10035,0x26de0027,0xe7e200b4}},	//   дано_, _फांस, guto_, _खारा_,
   {{0x69c26955,0xe7dd02b4,0xbbd143fd,0x64a61bcb}},	//   _geoe, _माकप, _सयुक, кама,
   {{0x26de005b,0xda1e0035,0x78a203d0,0xa3dd01d1}},	//   auto_, भारत_, _guov, डलं_,
   {{0x26de6956,0x987902b5,0xa87902b5,0x0ed1052b}},	//   buto_, _קאַט, _קאַר, _हिंड,
   {{0x200a6957,0x26de6958,0xfbb4018d,0x00000000}},	//   _rabi_, cuto_, ुरतम, --,
   {{0x200a0269,0xb5fb6959,0x69c2002a,0x00000000}},	//   _sabi_, rnác, _xeoe, --,
   {{0xdb1a0a20,0x2fc30024,0x21a30002,0x00000000}},	// [69c0] _retí, _bejg_, риум, --,
   {{0x161a009a,0x2d9f009e,0x33f600af,0x00000000}},	//   धाकर_, _ague_, _рчис, --,
   {{0x03d70070,0xdb1a695a,0x200a08b7,0xf1aa0387}},	//   _בוים_, _petí, _vabi_, _कलपन,
   {{0xee3a1728,0xed5a0086,0x7a3c695b,0xadb70079}},	//   ьне_, мое_, _réto, نهما_,
   {{0x200a34da,0x290001ef,0x5ce30421,0xe7e200be}},	//   _tabi_, _áiax_, ающа, _खाला_,
   {{0x61e408a1,0x5c730eb9,0x7d02695c,0x8fa603e6}},	//   lgil, аліт, rwos, _јаве,
   {{0xaa663f6c,0x7a350146,0xf1bf00e2,0x15f400be}},	//   ктик, _látu, _soái_, ेजार_,
   {{0x61e4695d,0x26de02fb,0xab5c00ea,0x8c3d0395}},	//   ngil, vuto_, _ceļa, _puşc,
   {{0x2d840254,0x6c0603fa,0xdca61e9c,0x7e6207e7}},	//   _uzme_, _изаз, _рази, mnop,
   {{0x25a00118,0x7a3c52d5,0x00000000,0x00000000}},	//   _agil_, _této, --, --,
   {{0xc0150070,0xdb010b3e,0x161400ab,0x00000000}},	//   אַרק_, _aflæ, _तोहर_, --,
   {{0xd00b00c8,0xf1e14092,0x25a00382,0x7a35003e}},	//   রায়_, _फाइन, _cgil_, _bátu,
   {{0x58d4695e,0x320b0284,0x26de695f,0x0fe20099}},	//   _солт, _racy_, suto_, _पांढ,
   {{0x7a354b1d,0x26de6960,0x7e6251f2,0x8c3d027d}},	//   _dátu, puto_, hnop, _kuşa,
   {{0xe81f0299,0x7e626955,0x82a4052c,0xf8ad00b5}},	//   बारा_, knop, иште, _وکی_,
   {{0x1fcb2160,0x61e46961,0x4545006c,0x53344bf9}},	//   ाण्ड, ggil, _منعق, шест,
   {{0x68e003be,0xe1340409,0xfbb40bad,0xed5902a7}},	// [69d0] numd, анты, ुराम, _režo_,
   {{0x162102cb,0x7a3510b2,0x660d6962,0x53b700dc}},	//   यावर_, _hátt, _haak, _अभिश,
   {{0x53356963,0x660d6964,0x320b0067,0x00000000}},	//   _сент, _kaak, _tacy_, --,
   {{0x7a35008e,0x660d4a86,0x2ca4022e,0x61e46965}},	//   _játt, _jaak, _bumd_, cgil,
   {{0x660d6966,0x7a350093,0x28c400dc,0xf09f0211}},	//   _maak, _mátt, लीमि, _gràp_,
   {{0x660d6967,0x69c6008d,0x7a352c89,0x2a666968}},	//   _laak, ðken, _látt, _ajob_,
   {{0x629d6969,0xadbd02a4,0x2001018d,0xed5908b7}},	//   _kiso, _навi, mehi_, _težo_,
   {{0x7a35008a,0x20012f18,0x60cd0390,0x660d399f}},	//   _nátt, lehi_, osam, _naak,
   {{0x629d696a,0x3d94696b,0xdddb0097,0x2a66021e}},	//   _miso, _витр, _chuť, _djob_,
   {{0x629d696c,0x7d09696d,0x7b080086,0x200100d1}},	//   _liso, _ises, ästä, nehi_,
   {{0x660d01a8,0xe7393e47,0x629d0282,0x7a350312}},	//   _baak, хен_, _oiso, _bátt,
   {{0x20cf0029,0x629d696e,0x244600a2,0x00000000}},	//   kļi_, _niso, _môme_, --,
   {{0x61e406d3,0x7d0901ed,0x2a7f006d,0x660d0103}},	//   vgil, _jses, mlub_, _daak,
   {{0x64a3467d,0x60cd696f,0x66e53f6b,0x6d4b01ed}},	//   сара, dsam, _бока, izga,
   {{0x629d09e8,0x61e40523,0x7d090b3e,0x3e7c00fd}},	//   _biso, tgil, _lses, síti_,
   {{0x41b50d54,0x7d090103,0x96951ac5,0x6eaa021a}},	//   исут, _oses, _крыш, _जंबु,
   {{0x629d6970,0x76440657,0xdb1a0473,0x61e46971}},	// [69e0] _diso, _iliy, _metá, rgil,
   {{0x660d6972,0xdb1a0187,0x629d001e,0x840600d4}},	//   _zaak, _letá, _eiso, _спож,
   {{0x44446973,0x7d096974,0x2a7f6975,0x76446976}},	//   _il_, _ases, klub_, _kliy,
   {{0x5d6a03ad,0x60cd6977,0x44442cfc,0xb05b01ba}},	//   нием_, bsam, _hl_, _svät,
   {{0x44446978,0x7a3500b5,0x7e626979,0x764408c7}},	//   _kl_, _láts, rnop, _mliy,
   {{0x4444697a,0x629d3a34,0x7e6202ee,0x6a7e0055}},	//   _jl_, _ziso, snop, mëfi,
   {{0xb5fb01c0,0xa0670dfc,0x4444697b,0x7644073a}},	//   dnán, _сара_, _ml_, _oliy,
   {{0x4444697c,0xdd08016f,0x5a345d99,0x2be0035d}},	//   _ll_, môže, рнит, _नाका,
   {{0x4444697d,0x8cdb1bb5,0x660d697e,0xb05b013c}},	//   _ol_, _नियो, _raak, _tvät,
   {{0x444425cb,0x764419c6,0x68e00092,0x660d697f}},	//   _nl_, _aliy, rumd, _saak,
   {{0x764402e9,0x2a7f01e8,0x7bca0027,0x38a900ee}},	//   _bliy, blub_, mafu, _eúr_,
   {{0x261c22a7,0xdb08013c,0xd6d700c3,0x7bca6980}},	//   यागी_, _bedö, ыть_, lafu,
   {{0x44446981,0x629d6982,0x3c390c1f,0xb4c102cb}},	//   _bl_, _riso, _sèvi_, ुळे_,
   {{0x44446983,0x7bca4267,0x629d6984,0x660d6985}},	//   _cl_, nafu, _siso, _waak,
   {{0x629d1408,0xe2f80210,0x660d6986,0x43955a55}},	//   _piso, лері_, _taak, равс,
   {{0x44446987,0xf1270d36,0x60cd6988,0x20010118}},	//   _el_, льзо, tsam, wehi_,
   {{0x629d00c7,0x44442251,0xd49b294a,0x905501c8}},	// [69f0] _viso, _fl_, _про_, авац,
   {{0x60cd6989,0x629d0027,0x7bca08c7,0x7a3506fe}},	//   rsam, _wiso, jafu, _játr,
   {{0x629d698a,0x2001698b,0x64570024,0x4421698c}},	//   _tiso, rehi_, _imxi, _inh_,
   {{0x2001272d,0x60cd698d,0x4444698e,0xb5fb00b8}},	//   sehi_, psam, _zl_, znán,
   {{0x1d090e0a,0x656d0069,0xb05b017b,0x00000000}},	//   тели_, _jxah, _dvär, --,
   {{0xab5c0080,0xe29f0093,0x7bca3a1b,0xd6c60037}},	//   _ceļo, _hið_, gafu, _وق_,
   {{0xb5fb01c0,0x4421023c,0x00000000,0x00000000}},	//   vnán, _mnh_, --, --,
   {{0x4df90070,0xe8f912fa,0x4433698f,0x442100a2}},	//   _שפּא, вли_, _lox_, _lnh_,
   {{0x7a3c0248,0x7bca1939,0xe29f0093,0x7d096990}},	//   _méth, bafu, _mið_, _uses,
   {{0xe29f0093,0x2a7f49f2,0xb8fd0f8a,0xdb010a8a}},	//   _lið_, slub_, _तट_, _aflå,
   {{0xb5fb6991,0xf62615c0,0x69cf05c9,0x22491292}},	//   rnán, адно, óces, khak_,
   {{0x442100e8,0x7ae36992,0x64450054,0x38a96993}},	//   _anh_, munt, _alhi, _túr_,
   {{0x44446994,0x64a66995,0x44336996,0x7ae33ec3}},	//   _pl_, рага, _box_, lunt,
   {{0x7e69029d,0x9984004f,0x44446997,0x44216998}},	//   _ljep, _الهو, _ql_, _cnh_,
   {{0xb77900c2,0x425605c0,0xc5fb0083,0x366a0798}},	//   _באַש, атат, ইয়া_, _иако_,
   {{0xc2431f6a,0x764428f7,0x2249022e,0x7a3c0118}},	//   онск, _uliy, ghak_, _céth,
   {{0x44446999,0x7bca699a,0x4433699b,0x394d1ca7}},	// [6a00] _tl_, yafu, _fox_, nzes_,
   {{0x4444699c,0x7ae3699d,0xf1bf0019,0x28dd10aa}},	//   _ul_, kunt, _soát_, _मिनि,
   {{0xeaf40429,0x645c699e,0x7ae3699f,0xaf06151c}},	//   _आहेत_, miri, junt, рпел,
   {{0x645c1df3,0x22490260,0x7bca69a0,0x7e69022f}},	//   liri, chak_, wafu, _cjep,
   {{0x7bca3f1f,0xcfaa05bc,0x44330095,0x61f60093}},	//   tafu, _لازم_, _yox_, mfyl,
   {{0x645c033d,0x394d00ea,0x7e7b0c6f,0xb5fb0079}},	//   niri, dzes_, _ekup, enál,
   {{0x7ae369a1,0xcb0701b2,0x7bca69a2,0xaa5869a3}},	//   gunt, ليون_, rafu, лику_,
   {{0x645c1526,0xfb190332,0xb5fb1d8a,0x3a3f0a4e}},	//   hiri, اروں_, gnál, gkup_,
   {{0x645c69a4,0x3ead02c4,0x8c3d0225,0x00000000}},	//   kiri, _četi_, _kuşl, --,
   {{0x7ae369a5,0x3a3f31dc,0x7a3c0248,0x645c016a}},	//   bunt, akup_, _méti, jiri,
   {{0xcb670192,0xdb0100e0,0x00000000,0x00000000}},	//   _кафе_, _nglè, --, --,
   {{0x8c3c08a1,0x645c2cd9,0xe7ea049c,0x442100f1}},	//   _diğe, eiri, ज्जा_, _snh_,
   {{0x645c69a6,0x7bc83635,0x64450221,0x44210359}},	//   firi, _kedu, _plhi, _pnh_,
   {{0x645c69a7,0x7bc80069,0x5fe214ab,0xd7ef0037}},	//   giri, _jedu, _पागल, _يكن_,
   {{0x224900bf,0xeaf400a1,0x61f6016e,0x569569a8}},	//   thak_, _आहोत_, ffyl, _лакт,
   {{0x645c004f,0x7bc869a9,0x644500d7,0x25e10084}},	//   airi, _ledu, _wlhi, _काटी_,
   {{0xe29f2ea0,0x645c4114,0x765d69aa,0x22493829}},	// [6a10] _við_, biri, misy, rhak_,
   {{0x7e7b04c3,0x2fc700e8,0x765d69ab,0x442101ef}},	//   _skup, úng_, lisy, _unh_,
   {{0x261c0429,0x753d00b5,0x2be0167e,0x925900af}},	//   याची_, lysz, _नाजा, _бант_,
   {{0x765d0c1f,0x7a3c0320,0xf1ab00f8,0x7ae31c52}},	//   nisy, _féti, _جاده_, vunt,
   {{0xe450006c,0x9f5811fa,0x753d00b5,0x7ae3073a}},	//   _رضی_, _baró_, nysz, wunt,
   {{0x7ae369ac,0x7bc869ad,0xfaa505d8,0x013600a5}},	//   tunt, _cedu, бако, _הרשת_,
   {{0x25e80429,0x547a0070,0x7e6969ae,0x765d02d0}},	//   _झाली_, נְננ, _tjep, kisy,
   {{0x7e7b01cc,0x645c69af,0xed5915d7,0x394d01ae}},	//   _ukup, ziri, _leži_, tzes_,
   {{0x20114273,0x7ae3692c,0x26de0033,0x645c69b0}},	//   _kazi_, sunt, erto_, yiri,
   {{0x7ae369b1,0x7bc869b2,0x7e790223,0x7d1b194a}},	//   punt, _gedu, lowp, _irus,
   {{0x394d0332,0x44260019,0x765d02d0,0x201169b3}},	//   szes_, _đo_, fisy, _mazi_,
   {{0x7d1b1769,0x645c65e2,0x201169b4,0x9a8702c8}},	//   _krus, wiri, _lazi_, _тузл,
   {{0x645c6303,0xa8a769b5,0xba740082,0xed591977}},	//   tiri, _трек, _بالت, _beži_,
   {{0x628f0024,0x26180864,0x7a3c000d,0x7d1b0118}},	//   _ahco, _बोरी_, _réti, _mrus,
   {{0xf773272b,0x765d1d51,0x7a3c69b6,0xdb0101ef}},	//   _باش_, bisy, _séti, _aflú,
   {{0x645c69b7,0x7a3c1f3c,0x28c40354,0x7d1b0523}},	//   siri, _péti, लीवि, _orus,
   {{0x201169b8,0x660669b9,0x224000d7,0x61f63d98}},	// [6a20] _bazi_, mekk, rkik_, rfyl,
   {{0x660669ba,0x2240053e,0x645c0bf4,0xa3be252c}},	//   lekk, skik_, qiri, आरओ_,
   {{0x7d1b69bb,0xb5fb0237,0x2d800029,0x25ad03c9}},	//   _arus, znám, ļiem_, žele_,
   {{0x7bc869bc,0x2259012f,0x8c3d69bd,0x7a3c69be}},	//   _sedu, _gmsk_, _duşm, _hétv,
   {{0x201131e1,0x7bc809df,0x27170023,0xf1b3011d}},	//   _fazi_, _pedu, _lăn_, _מסר_,
   {{0x7d1b69bf,0x765d1d49,0x6284293a,0x201169c0}},	//   _drus, zisy, llio, _gazi_,
   {{0x753d004e,0x7bc869c1,0x245800a8,0xdee30a80}},	//   zysz, _vedu, _cümə_, _нори,
   {{0x261803e2,0x9f580382,0x7f3b0070,0x7bc869c2}},	//   _बोली_, _farò_, _געלו, _wedu,
   {{0x765d1d11,0x7d1b4766,0x7bc869c3,0x99d311cf}},	//   visy, _grus, _tedu, ستيا,
   {{0x6b8169c4,0x37c80033,0x27170023,0x765d0159}},	//   _fylg, _শাহর, _băn_, wisy,
   {{0x765d0c1f,0x27170028,0x907b0100,0xbb86004f}},	//   tisy, _căn_, רטיי, _الاي,
   {{0xdb1a00c3,0x00000000,0x00000000,0x00000000}},	//   _vetä, --, --, --,
   {{0xb9960082,0x765d69c5,0x67d40185,0x4a7b016b}},	//   _الشب, risy, _долу, _גראב,
   {{0x765d383a,0x26de008b,0x3eb80207,0x00000000}},	//   sisy, prto_, _otrt_, --,
   {{0x765d69c6,0xed591b76,0x660669c7,0x6aa2023c}},	//   pisy, _veži_, bekk, _kiof,
   {{0x62840133,0x79820103,0x20110027,0x00000000}},	//   glio, _kyow, _sazi_, --,
   {{0x518769c8,0x20110a18,0xed590bc6,0xc0350370}},	// [6a30] сува, _pazi_, _teži_, онај,
   {{0x6aa20211,0x6284057a,0x7d1b0031,0x00000000}},	//   _liof, alio, _rrus, --,
   {{0x9f580382,0xdcfb0187,0x7d1b022f,0x5e8700d8}},	//   _sarò_, _vyuč, _srus, будз,
   {{0x2011000e,0xf127037c,0x62840098,0x00000000}},	//   _wazi_, _льго, clio, --,
   {{0x3ead042a,0x798200e0,0x00000000,0x00000000}},	//   _četu_, _nyow, --, --,
   {{0x09b300e7,0x26c200cb,0x7a3c0118,0x00000000}},	//   ीर्य, ćkoj_, _métu, --,
   {{0x447c0070,0x1a29046e,0x00000000,0x00000000}},	//   אנגע, ижки_, --, --,
   {{0x8c0900c8,0x7d1b293a,0x6aa269c9,0x271700e2}},	//   লাইন_, _trus, _ciof, _răn_,
   {{0x7d1b69ca,0xaca30019,0xdb180187,0x27170019}},	//   _urus, _trốn, mavý, _săn_,
   {{0x7982010d,0xdb1800d5,0x00000000,0x00000000}},	//   _dyow, lavý, --, --,
   {{0x61fd37fe,0x6aa269cb,0x628469cc,0xd62a0e9f}},	//   _obsl, _fiof, ylio, аоне_,
   {{0x271700e8,0x28f90086,0x78bb0196,0xdb1800ac}},	//   _văn_, _ведь_, ppuv, navý,
   {{0xa5bb00fb,0xe8ee0036,0x66065fdf,0x64400279}},	//   tjór, _юл_, rekk, êmio,
   {{0xf7456877,0x2d8d000e,0xf988026e,0x80b00026}},	//   _мело, _mzee_, _انهي_, _अंबे,
   {{0x69cb0ac8,0x2bfb0026,0x4911000c,0x03a36229}},	//   _kege, ल्यू_, तिको_, диро,
   {{0xcb120d85,0x69cb69cd,0x628469ce,0x2fca0069}},	//   ולל_, _jege, ulio, _sebg_,
   {{0x69cb69cf,0x628469d0,0x3eaa013a,0xdb1800ac}},	// [6a40] _mege, rlio, _subt_, davý,
   {{0x61ef69d1,0x69cb35f9,0x6fd500d8,0x57cc0070}},	//   _eccl, _lege, зіцц, ָמאַ,
   {{0x71a60009,0x1eda004f,0x628469d2,0x78a369d3}},	//   _манз, شباب_, plio, _minv,
   {{0x69cb69d4,0x5bb4111a,0x2bb4035d,0x0d8669d5}},	//   _nege, ुर्व, ुर्थ, олен,
   {{0xc27b0122,0xac0a0c06,0xf65300a5,0x00000000}},	//   _כרטי, инда_, וצא_, --,
   {{0x8cdb05f8,0xdfd200d1,0x7a3c0093,0x69d90d4a}},	//   _निरो, _زير_, _létt, _adwe,
   {{0x69cb479f,0x291802d4,0x2d8d0103,0x9f58008d}},	//   _bege, āram_, _ezee_, _garð_,
   {{0x26d853b1,0x78ab69d6,0x69cb00f6,0x4df401c0}},	//   árom_, _bugv, _cege, _एउटै_,
   {{0xed5a051b,0x69cb69d7,0x69d9001e,0x78a30103}},	//   _тоа_, _dege, _ddwe, _binv,
   {{0x291d0107,0xb5fb01ef,0x60c90a21,0x37aa034b}},	//   _drwa_, xiáb, _çeme, штин_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69cb69d8,0x8b6515f4,0xe9d201df,0x7a3c0093}},	//   _gege, _عالم, _آغا_, _pétu,
   {{0xb5fb004f,0x7e9b02b8,0xb86502fd,0x78a369d9}},	//   nnái, יסטו, _کانو, _finv,
   {{0x69cb69da,0x61ef69db,0xaaa90066,0x3ea40044}},	//   _zege, _sccl, _चूँक, _limt_,
   {{0xd25b49ad,0x3a2669dc,0x69cb01d5,0xb5fb69dd}},	//   аца_, _knop_, _yege, riáb,
   {{0xa2dc05b7,0xdb182fba,0x78a302a2,0x6d55013b}},	//   _फिर्, lavó, _zinv, _əzab,
   {{0xc69402b5,0x25a9007c,0x3fab03fa,0x7bda020e}},	// [6a50] _קאפ_, _igal_, ањем_, _odtu,
   {{0x28dd0722,0x7a3c00b5,0x644e69de,0x00000000}},	//   _मिसि, _kéts, chbi, --,
   {{0x64800086,0xb5fb69df,0xaaa90067,0x94740079}},	//   röit, ciác, _चूंक, _تديا,
   {{0x9f58008a,0x2d990097,0x3d95002d,0x00000000}},	//   _varð_, _úsek_, пиер, --,
   {{0x69cb245b,0x518411eb,0x61ed00ea,0xdb1a0279}},	//   _rege, _жура, mgal, _getú,
   {{0x61ed69e0,0x78ab5693,0xfaa569e1,0x661a0228}},	//   lgal, _rugv, пако, ētki,
   {{0x81ce0b52,0xfe730041,0x69cb69e2,0x78a30382}},	//   _রাত_, _قدر_, _pege, _rinv,
   {{0xefc80019,0xf771006c,0x78a369e3,0xed5900cd}},	//   _đỉnh_, ہاج_, _sinv, _sežu_,
   {{0x7a3c00fb,0x69cb3b14,0x2d8d08c7,0x00000000}},	//   _rétt, _vege, _uzee_, --,
   {{0xa2dc27bd,0x25b60bdd,0x69cb69e4,0x1bf2004e}},	//   _फिल्, ूर्ण, _wege, _घायल_,
   {{0x69cb69e5,0xed5933ee,0xb5fb01ef,0x00000000}},	//   _tege, _vežu_, xiác, --,
   {{0x63b5004e,0xaca30019,0xd0140083,0x291d0035}},	//   eczn, _trồn, সায়_, _trwa_,
   {{0x61ed69e6,0x78a3035f,0x80b022d4,0x04b60945}},	//   dgal, _tinv, _अंधे, ясня,
   {{0x25a969e7,0x7ae30051,0x00000000,0x00000000}},	//   _egal_, ornt, --, --,
   {{0x68e90090,0xdb1a0132,0x25ad69e8,0x7e6b010d}},	//   lued, _setú, žela_, kngp,
   {{0xcb120779,0x1fd406fe,0x61ed69e9,0x57560122}},	//   עלן_, दण्ड, ggal, _מבצע_,
   {{0x80a62f7a,0x9abc007a,0x00000000,0x00000000}},	// [6a60] سمان, _irċe, --, --,
   {{0x61ed01a8,0x3ea4002d,0xe0d7093e,0x66160225}},	//   agal, _simt_, яву_, _hayk,
   {{0x645e69ea,0x443a0602,0xe45700c2,0x7a3c69eb}},	//   _impi, _iop_, _זייט_, _métr,
   {{0x7a3c006c,0x2d840453,0xdb1a01ef,0x290d0cdf}},	//   _létr, _pyme_, _tetú, kwea_,
   {{0x2ca50a2f,0x443a69ec,0x661669ed,0x7cd701e0}},	//   _bild_, _kop_, _mayk, змір_,
   {{0xb5fb004f,0xed4f006c,0xe81b007c,0x7a3c00e0}},	//   rnái, چھے_, _भोला_, _nétr,
   {{0xaab80df3,0x2ca50a8a,0x7f4a0037,0x00000000}},	//   زگار_, _dild_, _الأق_, --,
   {{0x443a0023,0x98b84be9,0x66160107,0x2d84034d}},	//   _lop_, олит_, _nayk, _tyme_,
   {{0x63b5006a,0xfce369ee,0x68e9001e,0x443a69ef}},	//   yczn, _пото, gued, _oop_,
   {{0x61ed69f0,0x443a69f1,0x7e6269f2,0xbc631b0a}},	//   zgal, _nop_, liop, _звук,
   {{0x7a3c0248,0xa2b10b7a,0x661669f3,0x9f585459}},	//   _détr, _आंध्, _bayk, _obrí_,
   {{0x645e1fc7,0x61ed0282,0x1dcc084b,0x60d669f4}},	//   _ampi, xgal, ारित, ksym,
   {{0x7aea039b,0x6d4269f5,0xab5c0228,0x00000000}},	//   luft, nyoa, _ceļv, --,
   {{0xb8660071,0x9f580453,0x61ed099e,0xdb1a0b41}},	//   _عاشو, _abrí_, wgal, _betø,
   {{0xb5fb0076,0x1dcc06bc,0x7c3a69f6,0x61ed2686}},	//   dnáv, ारात, _motr, tgal,
   {{0x623469f7,0x7c3a5a38,0x61ed69f8,0x645e69f9}},	//   несу, _lotr, ugal, _empi,
   {{0x61ed69fa,0x764d3e0b,0x7c2869fb,0x443a0298}},	// [6a70] rgal, _ilay, _ondr, _fop_,
   {{0x7c3a69fc,0x301469fd,0xc879002d,0x2cad0a8a}},	//   _notr, ндур, tuşi_, _rued_,
   {{0x61ed00b5,0x00000000,0x00000000,0x00000000}},	//   pgal, --, --, --,
   {{0x7c2804ca,0x7c3a0284,0xf2d202b5,0x2ca569fe}},	//   _andr, _aotr, _בעט_, _sild_,
   {{0x2ab125ec,0x5187021d,0x7c3a69ff,0xd5fc0070}},	//   _sáb_, _хуна, _botr, מפאר,
   {{0x7c3a0139,0x443a01f7,0x009500af,0xa0a4010b}},	//   _cotr, _xop_, _цигэ, _паўд,
   {{0xfbd00082,0x764d06d3,0x09be0083,0x7a3c6a00}},	//   اته_, _olay, _ইয়া, _rétr,
   {{0x7c286a01,0x7e621a03,0x2ca506ae,0xca0602fb}},	//   _endr, ciop, _wild_, днъж_,
   {{0x7a3c6a02,0x2cad007c,0x23bf00e7,0x6e296a03}},	//   _pétr, _uued_, ्राद, _ineb,
   {{0xefc800e8,0x6e3b6a04,0x764d6a05,0x7c3a0088}},	//   _định_, _houb, _alay, _gotr,
   {{0x6e3b6a06,0x764d6a07,0x6e295056,0xddc20d77}},	//   _koub, _blay, _kneb, lnoš,
   {{0xb5fb024e,0x443a6a08,0x6e3b03bc,0x2b4f01d6}},	//   znáv, _sop_, _joub, ımcı_,
   {{0x6e3b043d,0x443a6a09,0x7c28005f,0x49b82149}},	//   _moub, _pop_, _yndr, _راند_,
   {{0x7d0400a8,0x764d6a0a,0x93c30139,0x00000000}},	//   çisi, _elay, _ţărm, --,
   {{0x64a301c8,0xb5fb314b,0x638302fb,0x6e2901e0}},	//   тара, vnáv, вгра, _oneb,
   {{0xd0480669,0x764d0088,0x2a6d6a0b,0xe1fa010b}},	//   ələr, _glay, nneb_, ўга_,
   {{0xa0a6005f,0x10a61172,0xddc200cd,0x321c0355}},	// [6a80] даад, диан, jnoš, ěvy_,
   {{0x645e6a0c,0xddc20254,0x6d420054,0x6e2900b8}},	//   _umpi, dnoš, vyoa, _aneb,
   {{0x6e3b6a0d,0xdfcf01b2,0x60d65cde,0x7e626a0e}},	//   _boub, شين_, ssym, tiop,
   {{0x93ee0bc1,0x7c3a1a64,0x6e3b021d,0x8c3d0160}},	//   _जाँच_, _sotr, _coub, _muşu,
   {{0x7c3a0bc9,0x6e3b6a0f,0xc879045e,0x6da32701}},	//   _potr, _doub, luşu_, вица,
   {{0x6e290d51,0x7e626a10,0x7c830421,0x2a6d018d}},	//   _eneb, siop, куще, eneb_,
   {{0x7c3a105d,0xb5fb05f6,0x6e3b0260,0xce4a010b}},	//   _votr, dián, _foub, _дзве_,
   {{0x20186a11,0x39146a12,0xddc200cd,0x26000569}},	//   _hari_, емир, bnoš, ष्मी_,
   {{0x20186a13,0x93ee004e,0x5fb20026,0x7e600069}},	//   _kari_, _जांच_, _जलाल, _immp,
   {{0x7c2803cc,0x4734496c,0x20182243,0x6c0303fa}},	//   _undr, енос, _jari_, _изуз,
   {{0x20186a14,0x764d6a15,0x6e3b12d9,0xd5ed0023}},	//   _mari_, _play, _youb, _nhạ,
   {{0x20186a16,0x81e40083,0x8c3d156b,0x387e02d7}},	//   _lari_, প্ত_, _duşu, sotr_,
   {{0x06ac0033,0x00000000,0x00000000,0x00000000}},	//   _কৌশি, --, --, --,
   {{0xb5fb002a,0x20186a17,0x36d400d4,0x00000000}},	//   cián, _nari_, _зокр, --,
   {{0xddc211c6,0x2c00012f,0xd6cf6a18,0x02a7094f}},	//   znoš, ल्यं_, _шт_, драм,
   {{0x764d000e,0x20180dc3,0x3ce610a5,0xd5b801e0}},	//   _ulay, _aari_, krov_, _ось_,
   {{0x20186a19,0x6e3b6a1a,0x394456ee,0x00000000}},	// [6a90] _bari_, _roub, nyms_, --,
   {{0xdfd10082,0x6e3b01c0,0xddc20528,0x20186a1b}},	//   ايا_, _soub, vnoš, _cari_,
   {{0x20186a1c,0x6e3b0fce,0x8c3d3afb,0x2a6d016e}},	//   _dari_, _poub, _muşt, yneb_,
   {{0xb05b15e5,0xddc2011c,0xb5fb6a1d,0x201801ed}},	//   _städ, tnoš, mnás, _eari_,
   {{0x20186a1e,0xe3a503c5,0x3ce66a1f,0xfce50268}},	//   _fari_, _تشکی, grov_, холо,
   {{0x20186a20,0x6e3b0359,0x6b882200,0xddc21c1a}},	//   _gari_, _woub, _bydg, rnoš,
   {{0x29066a21,0x8cdb02e4,0x6e3b139b,0xddc26a22}},	//   _apoa_, _निको, _toub, snoš,
   {{0xe9d90dde,0x5f945fed,0x20180010,0x7f946a23}},	//   чки_, _рист, _zari_, _расх,
   {{0x2018070b,0x5c750ca6,0x8c3d564b,0x3219088d}},	//   _yari_, _злат, _buşt, _masy_,
   {{0xc05202b5,0xb5fb0187,0x2a6d00ab,0x7aee0098}},	//   ָזט_, znát, sneb_, óité,
   {{0xb5fb1d85,0x96660fc5,0x22b81405,0x00000000}},	//   rián, екне, _očka_, --,
   {{0xf6522e36,0xfb1a00a5,0xb21b08c8,0x00000000}},	//   ائد_, _מועמ, _skæn, --,
   {{0xe1ff008a,0x00000000,0x00000000,0x00000000}},	//   _ljós_, --, --, --,
   {{0x6f150035,0x291f08c7,0x8c3d6a24,0x22b800fe}},	//   _oszc, mvua_, _guşt, _ačka_,
   {{0x20186a25,0x32190d14,0x23270036,0xe29a208b}},	//   _rari_, _basy_, нори_, зав_,
   {{0xdb1a0097,0x2cbf00cd,0x32190168,0x3ddf00e0}},	//   _netý, _otud_, _casy_, _nduw_,
   {{0x20186a26,0x66040232,0x68fb6a27,0x26d801ba}},	// [6aa0] _pari_, _ibik, ntud, árov_,
   {{0xb4fb0122,0x32190122,0x2018035f,0x752401d7}},	//   _צפיי, _easy_, _qari_, _iriz,
   {{0x20186a28,0x75240009,0x68fb00ab,0xf1bf0355}},	//   _vari_, _hriz, htud, _znám_,
   {{0x3ce65861,0x20180232,0xee3a6a29,0x673c03d0}},	//   trov_, _wari_, яне_, ørji,
   {{0x20186a2a,0xb5fb6a2b,0x6286003c,0x66046a2c}},	//   _tari_, onár, _ikko, _mbik,
   {{0x60c46a2d,0x2bfb0026,0x3ce019be,0x672302a7}},	//   mpim, ल्लू_, šivo_, _ornj,
   {{0x68fb12ee,0xfaa6052a,0x2cbf0107,0xff0700af}},	//   etud, ншин, _etud_, _перк_,
   {{0xdff03e72,0xbea31180,0x75246a2e,0x3ce66a2f}},	//   _चाँद_, _баск, _oriz, prov_,
   {{0xc8660cb5,0x68fb6a30,0x3f8a00e9,0x8c3d0395}},	//   етни, gtud, _hybu_, _puşt,
   {{0x66046a31,0x1bba004f,0x2a6a00b5,0x224901a3}},	//   _abik, _رائع_, őbb_, zkak_,
   {{0x6723011c,0xd6d7002d,0x2bc60d41,0xb5fb00ac}},	//   _crnj, нтя_, _र्या, biál,
   {{0xb5fb2eef,0x21200a78,0xd0190033,0x67230207}},	//   ciál, kvih_, ঠায়_, _drnj,
   {{0x75240043,0x67230069,0xdb0808c8,0xdff0198f}},	//   _criz, _ernj, _afdø, _चांद_,
   {{0x628600f5,0xddc90c0a,0x660409d6,0x349500d8}},	//   _akko, _mješ, _ebik, тагр,
   {{0xddc90280,0x75246a32,0x00000000,0x00000000}},	//   _lješ, _eriz, --, --,
   {{0x75246a33,0xdb1a01f4,0x998d0169,0xcfcd0033}},	//   _friz, _aftë, lješ_, _লাইন,
   {{0x660f0076,0x60f9342d,0x067c02b8,0x22496a34}},	// [6ab0] meck, ьная_, _מנהל, rkak_,
   {{0x660f6a35,0x62861084,0x661d150b,0x998d00cb}},	//   leck, _ekko, ldsk, nješ_,
   {{0xc88501ae,0xdb1a01ba,0x661d6a36,0xdddb1813}},	//   äßig_, _metó, odsk, _akuš,
   {{0x660f6a37,0xddc9012e,0xdb1a002a,0x22b80124}},	//   neck, _bješ, _letó, _učka_,
   {{0xed580a55,0x661d6a38,0x644801ff,0xdd94010b}},	//   ної_, idsk, ödig, гацы,
   {{0xe52220af,0x660f6a39,0x628d4d5f,0x9c8700ac}},	//   मिति_, heck, llao, dičá,
   {{0x7f9402ee,0x6f150067,0xdb18018d,0xe81b021a}},	//   _барх, _uszc, kavõ, _भोगा_,
   {{0x660f1e85,0x68fb6a3a,0x6e9500af,0x25ad03c9}},	//   jeck, ttud, _рибу, želj_,
   {{0x660f6a3b,0xb5fb0076,0xdb1a00a0,0x6723023a}},	//   deck, riál, _betó, _srnj,
   {{0x67230129,0x68fb2dd3,0x661d0b88,0xdb1a002a}},	//   _prnj, rtud, edsk, _cetó,
   {{0xdddb01c0,0xd90f00b5,0xf8c60051,0xf09200a5}},	//   _zkuš, شیں_, _ééns_, שני_,
   {{0x6723271b,0x75246a3c,0xcb1200a5,0x6b8402b1}},	//   _vrnj, _priz, _כלב_, ßige,
   {{0x69c96a3d,0x95992705,0x26dc00fe,0x00000000}},	//   mbee, етру_, _evvo_, --,
   {{0xd7fb021d,0x69c96a3e,0xe73100b2,0x67231b8d}},	//   _худ_, lbee, _نصب_, _trnj,
   {{0xe73900d4,0x67150722,0x660f05aa,0x69c9073a}},	//   _цей_, _तनिक_, beck, obee,
   {{0x26c51423,0x69c9213d,0x21200528,0x68e96a3f}},	//   mplo_, nbee, tvih_, ored,
   {{0x68e96a40,0x21670b07,0x69c90345,0x75246a41}},	// [6ac0] nred, вити_, ibee, _uriz,
   {{0xddc92ba7,0x68e90132,0x071519b7,0xdb1a02d0}},	//   _rješ, ired, _तनाव_, _metò,
   {{0x68e90297,0x7d0903e6,0x26c502d0,0x45240033}},	//   hred, _apes, nplo_, _পথিক_,
   {{0xddc90c0a,0x60c42103,0x69c90051,0x62860421}},	//   _pješ, ppim, jbee, _ukko,
   {{0x9cb3004f,0x68e96a42,0x69c9033b,0x00000000}},	//   لمنت, jred, dbee, --,
   {{0xddc9029d,0x68e914d3,0x660f0097,0xddc20187}},	//   _vješ, dred, zeck, dnoť,
   {{0xdb1a2cad,0xa404018d,0x7d090260,0x661d03bc}},	//   _retó, श्यप_, _epes, ydsk,
   {{0xddc9025c,0xf2d300a5,0x69c91472,0x8cdb0d1f}},	//   _tješ, בעה_, gbee, _निचो,
   {{0x6da34ae6,0x660f06d7,0xdb1a01ef,0x22b800ac}},	//   _вита, veck, _petó, _očko_,
   {{0xad256202,0x69c9018e,0x660f0b38,0x63bc00cd}},	//   _حرفو, abee, weck, jcrn,
   {{0x660f6a43,0x7bd86a44,0x45d51d32,0x6aab0260}},	//   teck, mavu, лонс, _figf,
   {{0x68e90532,0x3ce903ab,0xb0e20e3b,0x7bd86a45}},	//   bred, šave_, _पिंग, lavu,
   {{0x660f6a46,0x661d02ce,0x3dd70033,0x68e96a47}},	//   reck, rdsk, _হামল, cred,
   {{0x7bd86a48,0x660f6a49,0x26d800b5,0xdb18018d}},	//   navu, seck, áros_, savõ,
   {{0xe5c76a4a,0x07f70ef5,0x660f39c0,0x3d190035}},	//   _испо, _شروع_, peck, _मैने_,
   {{0x35f56a4b,0x2cac03d0,0x7bd86a4c,0x3547010b}},	//   _спир, _lidd_, havu, _ахов,
   {{0x51876a4d,0x7bd86a4e,0xd49b6a4f,0x628d0207}},	// [6ad0] тува, kavu, _оро_, rlao,
   {{0x7bd800a0,0x88c40033,0x00000000,0x00000000}},	//   javu, _এটাক, --, --,
   {{0x7d096a50,0xd25101b2,0x68e91851,0x1fa72d35}},	//   _spes, _هند_, zred, траг,
   {{0x6d1e1e79,0x7bca006d,0x68e96a51,0x2cac0090}},	//   पिंग_, ebfu, yred, _aidd_,
   {{0xf1bf02d7,0x00000000,0x00000000,0x00000000}},	//   _ifá_, --, --, --,
   {{0x68e96a52,0x7bd86a53,0xeb990e60,0x6d592a3a}},	//   vred, gavu, нил_, rzwa,
   {{0x9f3400d4,0x8c420945,0x69c90b0d,0x68e9016e}},	//   _кері, сеще, tbee, wred,
   {{0x68e96a54,0x00000000,0x00000000,0x00000000}},	//   tred, --, --, --,
   {{0x69c90903,0x68e902f6,0x8cbb00d1,0x7bd84296}},	//   rbee, ured, _آدرس_, bavu,
   {{0x2cac03d0,0x3ead03d0,0x672100f4,0xf8ae0118}},	//   _gidd_, _hiet_, tvlj, سکه_,
   {{0x68e96a55,0x628408c7,0x3ead00cc,0x00000000}},	//   sred, yoio, _kiet_, --,
   {{0x68e91b89,0x3ead007a,0x67210124,0xcf9200a5}},	//   pred, _jiet_, rvlj, מטי_,
   {{0x3ead509c,0xb60800fe,0x00000000,0x00000000}},	//   _miet_, _arší, --, --,
   {{0xfbe500c8,0x3ead6a56,0x972507f6,0x2bc600e7}},	//   প্রত, _liet_, _مفتو, रुपा,
   {{0x91e603ad,0xc8a802fb,0x00000000,0x00000000}},	//   лове, _ръце_, --, --,
   {{0x3ead4cca,0x42556a57,0x7bd86a58,0x2d8d034d}},	//   _niet_, атут, zavu, _oyee_,
   {{0x62846a59,0x7bd86a5a,0x00000000,0x00000000}},	// [6ae0] roio, yavu, --, --,
   {{0x3ead0176,0xfdcc0931,0x00000000,0x00000000}},	//   _aiet_, ार्फ, --, --,
   {{0x93fb0100,0x3ead0023,0x1fb5002d,0x7bd81023}},	//   _אליי, _biet_, рсур, vavu,
   {{0x2216172a,0x201c00cb,0x7bd86a5b,0x3ead0228}},	//   _сфор, žvi_, wavu, _ciet_,
   {{0x3ead6a5c,0xa07600c3,0x8c4621e2,0x2cac0118}},	//   _diet_, _бывш, леде, _pidd_,
   {{0x61f6001e,0x644e6a5d,0xddcb0207,0x84ed073f}},	//   lgyl, nkbi, čišk, _जमघट_,
   {{0x7bd86a5e,0x3ead0051,0x81d70033,0xa5bb01ef}},	//   ravu, _fiet_, _সাত_, ndóc,
   {{0x3ead6a5f,0x25ad6a60,0x62580079,0x61f66a61}},	//   _giet_, želi_, _díog, ngyl,
   {{0xd7fa081b,0xa2bb112b,0x286a0426,0xc7b00079}},	//   нун_, _शून्, ерно_, يّة_,
   {{0x0d75342d,0x3ead0a75,0x22422e04,0x00000000}},	//   _тыся, _ziet_, _lokk_, --,
   {{0xfd5000e2,0x8037016b,0xb05b0523,0x00000000}},	//   _nghẽ, אניע_, _otän, --,
   {{0x22426a62,0x00000000,0x00000000,0x00000000}},	//   _nokk_, --, --, --,
   {{0x58d40210,0x2a661bec,0x80b00387,0xf9925a37}},	//   _толт, _imob_, _अंगे, _ابا_,
   {{0x2a66006d,0x81ce0083,0xef0500ab,0x00000000}},	//   _hmob_, _রাগ_, _रहलऽ_, --,
   {{0x56950133,0x04642374,0x05150033,0x00000000}},	//   _какт, стям, ামের_, --,
   {{0x1fdd4ae7,0xea0100e2,0x00000000,0x00000000}},	//   मण्ड, _đẫy_, --, --,
   {{0x3ead01bf,0x3f980207,0x224203d0,0x00000000}},	// [6af0] _riet_, _azru_, _dokk_, --,
   {{0x3ead3536,0x2bc6178c,0x26de29ab,0x00000000}},	//   _siet_, रुमा, osto_, --,
   {{0x53356a63,0x3ead6a64,0x62580037,0x26de03d0}},	//   _тент, _piet_, _bíod, nsto_,
   {{0x51871c56,0x9f5c00b8,0x26de6a65,0x62580079}},	//   _буга, ývá_, isto_, _ríog,
   {{0x3ead01a5,0xb8140084,0x9ce7027f,0x00000000}},	//   _viet_, तजाम_, уцел, --,
   {{0x26de6a66,0xcb696a67,0x13d90033,0x3ead213d}},	//   ksto_, кале_, _তাড়, _wiet_,
   {{0x3ead6a68,0x5b35002d,0x00000000,0x00000000}},	//   _tiet_, рэлу, --, --,
   {{0x80da000c,0x2f1801e0,0xdb2400b5,0xaa450043}},	//   _पौडे, _щось_, ásáh, реил,
   {{0x26de6a69,0x7e6b010d,0x00000000,0x00000000}},	//   esto_, migp, --, --,
   {{0x7d1b6a6a,0x78650268,0x6fe000b8,0x00000000}},	//   _isus, ркоз, mácí, --,
   {{0x6d4b6a6b,0xfb150609,0xb06401ae,0xa3d9007c}},	//   lyga, _خواج, lmäß, ारन_,
   {{0x7e6b010d,0x00000000,0x00000000,0x00000000}},	//   nigp, --, --, --,
   {{0xb06402b1,0x69db0110,0x00000000,0x00000000}},	//   nmäß, maue, --, --,
   {{0xb05b3bed,0x7e6b0dc3,0xa8790070,0x69db6a6c}},	//   _stän, higp, _שאַר, laue,
   {{0x7e6b043d,0x03a66a6d,0xa1c500a0,0xb06402b1}},	//   kigp, риво, _dážď_, hmäß,
   {{0xbbd1000c,0x69db01ae,0x877a0070,0x3ce000cd}},	//   हरुक, naue, _באצי, šivi_,
   {{0xe3b2017e,0x61f66a6e,0x1fb600af,0x7d1b030d}},	// [6b00] _ورد_, rgyl, асер, _nsus,
   {{0x69db02c9,0x629d0065,0x7bc10024,0x00000000}},	//   haue, _ehso, _nflu, --,
   {{0x44440133,0x7d1b6a6f,0xe0020084,0xb05b02ee}},	//   _io_, _asus, र्षद_, _itäl,
   {{0x7bc1039f,0x72db00a5,0xcee700c3,0x00000000}},	//   _aflu, _בקטג, рдце_, --,
   {{0x44446a70,0xbbd1000c,0x69db033b,0x55bb00a5}},	//   _ko_, हरूक, daue, דמנו,
   {{0x26de4d2b,0xf115016b,0x00000000,0x00000000}},	//   ysto_, _פֿרי_, --, --,
   {{0x44446a71,0xe3e902b5,0xdb1a006c,0xfbcf0083}},	//   _mo_, אַפֿ, _letö, _রাখত,
   {{0x44446a72,0x3ce901cc,0x6d4b6a73,0x5a340e05}},	//   _lo_, šava_, byga, снит,
   {{0x44446a74,0xb4e5018d,0x200a3540,0x3eb86a75}},	//   _oo_, _पटे_, _kbbi_, _hurt_,
   {{0x444415b7,0xb8fe6a76,0x6e2045f8,0x3eb8345d}},	//   _no_, _तब_, _hamb, _kurt_,
   {{0x6e206a77,0xdb2404a3,0x69db6a78,0x2fd8002d}},	//   _kamb, _دوای, baue, _merg_,
   {{0x44446a79,0x6e2026a5,0xf76f0642,0x69db01f7}},	//   _ao_, _jamb, باً_, caue,
   {{0x44446a7a,0x7d026a7b,0x6e206a7c,0x38bb099e}},	//   _bo_, ntos, _mamb, _gêr_,
   {{0x44440122,0xea0101a5,0xf487262e,0x25be00b8}},	//   _co_, _đẩy_, румн, ětla_,
   {{0x44440052,0x883b0122,0x628002c4,0x7d024b52}},	//   _do_, _בתגו, čmon, htos,
   {{0x44446a7d,0x6e2053be,0x09aa0083,0x7d026a7e}},	//   _eo_, _namb, _গ্যা, ktos,
   {{0x44446a7f,0x6e22073a,0x2fd85092,0x6f0e0345}},	// [6b10] _fo_, ddob, _berg_, _apbc,
   {{0x444402aa,0xd7f80043,0x60c20079,0x6e220207}},	//   _go_, ngă_, íoma, edob,
   {{0x4ea7004b,0x6e206a80,0x3eb86a81,0x44210009}},	//   арда, _bamb, _curt_, _iah_,
   {{0x44446a82,0x6e20582c,0x6e226a83,0x44330023}},	//   _zo_, _camb, gdob, _hnx_,
   {{0x44446a84,0x44216a85,0x64450303,0x7bc10bf7}},	//   _yo_, _kah_, _kohi, _pflu,
   {{0x4444638c,0x4421007c,0x3eb86a86,0x69c20345}},	//   _xo_, _jah_, _furt_, _afoe,
   {{0x44216a87,0x64453151,0x69db1b04,0x7d02110e}},	//   _mah_, _mohi, taue, atos,
   {{0x6e20072e,0xe8f913f9,0x442161f5,0x737800a5}},	//   _gamb, гли_, _lah_, יגוד_,
   {{0x7e690054,0x69db3fa4,0x7d1b62c2,0x97d900d4}},	//   _imep, raue, _usus, льну_,
   {{0x442105ca,0x68e20121,0x69db6a88,0x64456a89}},	//   _nah_, _dvod, saue, _nohi,
   {{0x44446a8a,0x9b950082,0xab95004f,0x6e201548}},	//   _ro_, _الات, _الاغ, _yamb,
   {{0x44446a8b,0xb05b06d7,0x6e206a8c,0x065600d8}},	//   _so_, _stäl, _xamb, стоў,
   {{0x44216a8d,0x69d9053e,0x386700e7,0x81cd0083}},	//   _bah_, _iewe, _tmnr_, রণা_,
   {{0x6e2200cd,0x2a6d00a0,0x442100d1,0x64a6005f}},	//   zdob, lieb_, _cah_, сага,
   {{0x44446a8e,0x7d020332,0x44216a8f,0x69d958b6}},	//   _vo_, ztos, _dah_, _kewe,
   {{0x44446a90,0x69d96a91,0x7e7b00d1,0x2fd80107}},	//   _wo_, _jewe, _njup, _serg_,
   {{0x44446a92,0x6e2007ee,0x394d6a93,0xe2976a94}},	// [6b20] _to_, _ramb, nyes_, сат_,
   {{0x69d90626,0xd12f0c9e,0xa3d92afe,0x7e690054}},	//   _lewe, عمل_, ारण_, _amep,
   {{0x6e206a95,0x290f01a2,0xb5fb6a96,0x645c6a97}},	//   _pamb, _lpga_, riáv, mhri,
   {{0x291d0c1f,0x7d0264a3,0x6e2201a2,0x442101ed}},	//   _oswa_, ttos, udob, _zah_,
   {{0x6e226a98,0x442105ca,0x395f006d,0x7e7b01bc}},	//   rdob, _yah_, jzus_, _djup,
   {{0x705616a4,0x7d026a99,0x6e203d10,0x6f130391}},	//   _انسا, rtos, _wamb, ñecí,
   {{0x69d914e8,0xa6f20083,0x68e26192,0xa3d93138}},	//   _bewe, _জন্ম_, _svod, ारत_,
   {{0x7d02620c,0x69d96a9a,0xa3e800b4,0x6e20023c}},	//   ptos, _cewe, मृत_, _uamb,
   {{0xed5007a8,0x69d96a9b,0x3ebf0877,0x645c0a4e}},	//   _تھا_, _dewe, _čuti_, khri,
   {{0x3ea6043d,0x22b80009,0xd7f8002d,0xe00b6a9c}},	//   lmot_, _ečki_, ugă_, स्पद_,
   {{0xb5fb1d85,0x3aeb0416,0xd7f800af,0x645c6a9d}},	//   mnáz, _مبنی_, rgă_, dhri,
   {{0x69d91892,0x442109df,0x291a04e8,0x7bda0031}},	//   _gewe, _sah_, _مقصد_, _hetu,
   {{0x7bda6a9e,0xa967692c,0xb05b022a,0x68e20496}},	//   _ketu, _лица_, _stäm, _uvod,
   {{0xe9470332,0x645c6a9f,0x7bda01f4,0x9abc009f}},	//   _درمی, ghri, _jetu, _arċi,
   {{0x7bda6aa0,0x212b00fe,0xddc201a0,0xb86506ca}},	//   _metu, _srch_, dnož, _بانو,
   {{0x442100d1,0x2bcf0d1f,0x7bda4d7a,0x64456aa1}},	//   _wah_, _स्ना, _letu, _wohi,
   {{0x44216aa2,0x644500ab,0x94870043,0x645c0874}},	// [6b30] _tah_, _tohi, _гынд, bhri,
   {{0x645c6aa3,0x7bda6aa4,0x34b50461,0x4421564b}},	//   chri, _netu, ंदीद, _uah_,
   {{0x6aba012f,0x752d15d8,0x00000000,0x00000000}},	//   _nutf, _hraz, --, --,
   {{0x752d0c1f,0x7bda018d,0x00000000,0x00000000}},	//   _kraz, _aetu, --, --,
   {{0x7bda6aa5,0x660d6aa6,0x69d90035,0x8c454be9}},	//   _betu, _mbak, _rewe, желе,
   {{0x69d96aa7,0x752d07fc,0xa3d900ab,0x7bda6aa8}},	//   _sewe, _mraz, ारि_, _cetu,
   {{0xda590036,0x7c213913,0x765d00d7,0x9f5f00c3}},	//   ириш_, _valr, khsy, ärän_,
   {{0x752d027a,0x7c2104f4,0x7e696aa9,0x08c501ee}},	//   _oraz, _walr, _umep, обин,
   {{0x60cd6aaa,0x2a6d6aab,0x7c211961,0x6f05024b}},	//   npam, rieb_, _talr, lthc,
   {{0x660d6aac,0x7bda6aad,0x60cd61cb,0x69d96aae}},	//   _abak, _getu, ipam, _wewe,
   {{0x2bcf2160,0x752d6aaf,0xa5bb0391,0x69d94180}},	//   _स्या, _araz, rdón, _tewe,
   {{0xd02200c8,0xf5066ab0,0x68ee0644,0x21296ab1}},	//   নায়_, озмо, ündü, kvah_,
   {{0x645c6ab2,0x2bc6143a,0x37e5220a,0x60cd0e46}},	//   thri, रुवा, _долг, jpam,
   {{0x2bcf0518,0x660d6ab3,0xa8a7002d,0x00000000}},	//   _स्मा, _ebak, _урек, --,
   {{0x752d6ab4,0x645c0093,0xd33561ad,0x00000000}},	//   _eraz, rhri, пэты, --,
   {{0x645c6ab5,0x316001d7,0xf1bf00ee,0x00000000}},	//   shri, tziz_, _snár_, --,
   {{0x752d6ab6,0x645c0037,0x60cd03be,0x3d1901c0}},	// [6b40] _graz, phri, gpam, _मैले_,
   {{0x22594777,0xb5fb002a,0xa49b01f7,0x00000000}},	//   _elsk_, siát, ntòl, --,
   {{0xef1a6ab7,0x7bda6ab8,0xe29a0c98,0x752d01ba}},	//   рме_, _retu, _ван_, _zraz,
   {{0x7bda325b,0xb5fb6ab9,0x1ea90c26,0x00000000}},	//   _setu, liár, ماني_, --,
   {{0x7bda1b0f,0x3ea66aba,0x6f051c8b,0x00000000}},	//   _petu, rmot_, athc, --,
   {{0xc61707df,0x98a601c0,0x8c4303fa,0x3cd9010b}},	//   _तस्य_, _proč_, деље, сьцю_,
   {{0x7bda6abb,0x2bc60099,0x62960159,0x00000000}},	//   _vetu, रुषा, olyo, --,
   {{0x7bda6abc,0x7a38002d,0x98a60116,0x00000000}},	//   _wetu, спир_, _vroč_, --,
   {{0x7bda2ada,0x998d027d,0x49741eb9,0x00000000}},	//   _tetu, rdeş_, ялис, --,
   {{0x29046abd,0xa7fc027d,0x1bba00b5,0xc8660037}},	//   rtma_, lnız, _ضائع_, تطبي,
   {{0xa3d90174,0x752d6abe,0xb5fb0752,0x56952324}},	//   ारस_, _sraz, diár, зант,
   {{0x752d0a0b,0xe66701e0,0x1db10354,0x00000000}},	//   _praz, ітно, ुँचत, --,
   {{0x64b508b0,0x998f005f,0x769d00f8,0x00000000}},	//   ंदेश, _dogų_, géya, --,
   {{0xc1d30d00,0xb5fb6a96,0x752d6abf,0x00000000}},	//   तर्ग, giár, _vraz, --,
   {{0x9f470092,0x926b0132,0x6aa208c7,0x22b8023a}},	//   ünü_, араа_, _khof, _očku_,
   {{0xa75b0122,0x95cb06c2,0x02a4049f,0x660d2f10}},	//   _כדור, _тука_, друм, _ubak,
   {{0x50f50086,0xb5fb2587,0x04100083,0xa5bb6ac0}},	// [6b50] язат, siás, ায়ী_, ndóm,
   {{0xb5fb0294,0xea0100e2,0x071e193c,0x00000000}},	//   ciár, _đậy_, _बनाव_, --,
   {{0xdefb004b,0xb5fb0037,0x00000000,0x00000000}},	//   рыз_, mháb, --, --,
   {{0x60cd6ac1,0x6f056ac2,0xa5bb008d,0x00000000}},	//   ppam, rthc, kdóm, --,
   {{0x260000a1,0xddc20035,0x28da3100,0x823a025a}},	//   ष्टी_, lkoś, _मौलि, _הערצ,
   {{0x64550120,0x2bc601c0,0x6aa2023c,0x00000000}},	//   nkzi, रुला, _ahof, --,
   {{0x62580079,0x7bc301e9,0x00000000,0x00000000}},	//   _míon, rcnu, --, --,
   {{0x6aa26ac3,0x6258004f,0x00000000,0x00000000}},	//   _chof, _líon, --, --,
   {{0x2bcf0162,0xa5bb05ee,0x38ca00d1,0x6e9401e0}},	//   _स्था, gdóm, یایی_, _циту,
   {{0xc1b808b0,0xb5fb002a,0x00000000,0x00000000}},	//   _अल्ग, xiár, --, --,
   {{0xb5fb03e6,0xdb1a008c,0x00000000,0x00000000}},	//   viár, _aftæ, --, --,
   {{0x2bcf02e4,0xfbcf3c8d,0x62580037,0xda670987}},	//   _स्ता, _स्तम, _aíon, _بائي,
   {{0x6258004f,0x6aa9082b,0x81c10033,0xdddb008b}},	//   _bíon, mmef, ঁরা_, _okuž,
   {{0xddc9029d,0xb5fb00fd,0x00000000,0x00000000}},	//   _njež, gháb, --, --,
   {{0x42560ea7,0xd46700af,0xa49b0176,0x00000000}},	//   птат, чире_, ctòm, --,
   {{0xb21b6ac4,0xa3b800ab,0x00000000,0x00000000}},	//   _skær, _छलक_, --, --,
   {{0xddc9124d,0x4fea6ac5,0x62580079,0x00000000}},	// [6b60] _bjež, йман_, _fíon, --,
   {{0xb4d80429,0xd1790044,0xb5fb01ef,0x64550110}},	//   ाठी_, істі_, cháb, ckzi,
   {{0x0dca01e0,0x389a016b,0x00000000,0x00000000}},	//   були_, ציענ, --, --,
   {{0x9e650833,0x00000000,0x00000000,0x00000000}},	//   وانن, --, --, --,
   {{0xe3b203c5,0xacf81645,0x00000000,0x00000000}},	//   _ترک_, інку_, --, --,
   {{0x6aa201f4,0xdfd20af8,0x00000000,0x00000000}},	//   _shof, _سير_, --, --,
   {{0x6aa20282,0x00000000,0x00000000,0x00000000}},	//   _phof, --, --, --,
   {{0xce3400e0,0x201a6ac6,0x9f580183,0x22b80207}},	//   _تورک, lepi_, _ecrã_, _učku_,
   {{0xd90e07e4,0x61eb0a54,0x851b0084,0x15e30035}},	//   ایت_, ógli, _पैंट_, _ख़बर_,
   {{0x201a6ac7,0xa5bb0093,0xe7866ac8,0x8db503d0}},	//   nepi_, rdóm, зумо, _істі,
   {{0x25a06ac9,0x09db0033,0x212700e2,0x00000000}},	//   _azil_, _ধারা, ̉nh_, --,
   {{0x201a442d,0x00000000,0x00000000,0x00000000}},	//   hepi_, --, --, --,
   {{0x09aa00c8,0xb5fb0079,0xda650a42,0x00000000}},	//   _গ্রা, tháb, _تالي, --,
   {{0x201a0c21,0xa49b0176,0x00000000,0x00000000}},	//   jepi_, ptòm, --, --,
   {{0x92953d51,0x201a3850,0xf1b8021a,0x00000000}},	//   давц, depi_, _अलखन, --,
   {{0xdddb0c21,0x4394081b,0x3ce610a5,0x00000000}},	//   _skuž, хасс, ksov_, --,
   {{0x644100be,0x212f0079,0x2122055c,0x00000000}},	// [6b70] ölis, ígh_, _cskh_, --,
   {{0x2fc701a5,0x3a260118,0x201a00e0,0x00000000}},	//   ùng_, _laop_, gepi_, --,
   {{0xddc90c21,0xb5fb0314,0x7f1901b2,0xf09f01da}},	//   _vjež, chác, تياز_, _spàs_,
   {{0x13e20033,0x00000000,0x00000000,0x00000000}},	//   _বায়, --, --, --,
   {{0xf1ab00bf,0x5184081b,0xece801e0,0x26050387}},	//   _داده_, _зура, зділ_, _वानी_,
   {{0x5fe1004e,0x224b028b,0x201a6aca,0x00000000}},	//   _फ़िल, _hock_, cepi_, --,
   {{0x9aa500b5,0x224b6acb,0x6e670382,0x00000000}},	//   ومتو, _kock_, _етаж, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c8700af,0x00000000,0x00000000,0x00000000}},	//   _еуже, --, --, --,
   {{0x6fb100a1,0x6fdd05e7,0x224b5f54,0x00000000}},	//   _जणां, यरिं, _lock_, --,
   {{0xcb550841,0x888200af,0x00000000,0x00000000}},	//   _تناظ, тлэж, --, --,
   {{0x3915026e,0x2cbf007c,0xf3e900a5,0x81d30033}},	//   _يواز, _kuud_, _כף_, হৃত_,
   {{0xa3d901d1,0x6258004f,0xb5fb0952,0x00000000}},	//   ारं_, _díol, riáp, --,
   {{0x2cbf007c,0x68fb6acc,0xe8d600a5,0x03a61499}},	//   _muud_, muud, _חוסר_, диго,
   {{0x232711d0,0x224b0110,0x25bf0207,0x2cbf6acd}},	//   мори_, _bock_, žula_, _luud_,
   {{0x09b10083,0xcb1200a5,0x224b6ace,0x2bcf021a}},	//   _ট্যা, כלל_, _cock_, _स्सा,
   {{0x201a6acf,0xf1aa2149,0x66046ad0,0x224b49f7}},	// [6b80] tepi_, زاره_, _icik, _dock_,
   {{0xa3d94b07,0x4fea0210,0xf1b1183b,0x39420086}},	//   ारः_, імен_, اءِ_, äksi_,
   {{0x224b6ad1,0x201a6ad2,0x68fb02ee,0x62580098}},	//   _fock_, repi_, huud, _híom,
   {{0x90c6172a,0x649201b4,0x201a6ad3,0xc7b80009}},	//   _обме, pæis, sepi_, međe_,
   {{0x61e46ad4,0x60c90095,0x92d60083,0x68fb276c}},	//   mail, _çemp, _সময়_, juud,
   {{0x13e200c8,0x68fb0103,0x61e46ad5,0x443a0009}},	//   _বাড়, duud, lail, _jnp_,
   {{0x60c40031,0x09e20033,0x62580079,0xaec3010b}},	//   lqim, _যাবা, _líom, _абсл,
   {{0x61e46ad6,0x8fa301c8,0x66040009,0x00000000}},	//   nail, _расе, _ncik, --,
   {{0x2bcf0e6f,0x60c20082,0x672301d2,0xfbcf1371}},	//   _स्वा, íomh, _asnj, _स्वम,
   {{0x61e46ad7,0x0c262659,0x62580079,0x443a6ad8}},	//   hail, _імен, _síol, _nnp_,
   {{0x7c3a6ad9,0x61e46ada,0x60c401f4,0xc7b8012e}},	//   _intr, kail, hqim, jeđe_,
   {{0x7c282fa1,0x443a2aed,0x7e623238,0x7c2a6adb}},	//   _hadr, _anp_, nhop, ldfr,
   {{0x224b6adc,0x6846066d,0x443a6add,0xa5bb6ade}},	//   _rock_, _онда, _bnp_, ndói,
   {{0x7c284382,0x443a0160,0x7c2a6adf,0x62580079}},	//   _jadr, _cnp_, ndfr, _díom,
   {{0xc61400c8,0x61e46ae0,0x7c28012c,0x439407fa}},	//   িয়া_, fail, _madr, варс,
   {{0x61e46ae1,0x3ce900cb,0x442a009e,0x00000000}},	//   gail, šavi_, adb_, --,
   {{0x661d6ae2,0x7c3a6ae3,0x7e626ae4,0xa29400d4}},	// [6b90] mesk, _ontr, dhop, таті,
   {{0xcf9b0202,0xd9bb0bc1,0x443a31ad,0x2cbf4128}},	//   оје_, _उल्ट, _gnp_, _ruud_,
   {{0x833500c2,0x03d60052,0x61e402a8,0x00000000}},	//   _װאָס_, _אותם_, bail, --,
   {{0x7c3a6ae5,0x28df6ae6,0x61e40a32,0x7c28007c}},	//   _antr, पीडि, cail, _aadr,
   {{0x7c286ae7,0x644e08b7,0x91f600a5,0x646800be}},	//   _badr, žniš, _אמרו_, _äriü,
   {{0x7c286ae8,0x68fb00c3,0x661d02ee,0x61ef0168}},	//   _cadr, vuud, hesk, _hdcl,
   {{0x661d0d4c,0x60cf17d9,0xa5bb0079,0x7c284dd0}},	//   kesk, _htcm, adói, _dadr,
   {{0x7c3a0fe4,0x7e626ae9,0x661d012e,0xdd950733}},	//   _entr, chop, jesk, _забы,
   {{0x39592919,0x6e3b08dd,0x59c10324,0x2001027a}},	//   áss_, _inub, शखबर, oghi_,
   {{0x62580082,0x61e40291,0x20016aea,0x6e3b006d}},	//   _ríom, zail, nghi_, _hnub,
   {{0xe7390ca6,0x68fb41b7,0xd6ce0a86,0x6e2900ab}},	//   чен_, suud, یقی_, _kaeb,
   {{0x7c280121,0x661d5cf2,0x443a6aeb,0x26050127}},	//   _zadr, gesk, _snp_, _वाणी_,
   {{0x61e46aec,0x442a009e,0xdddb073a,0x668400b5}},	//   vail, tdb_, _aluŋ, ٹیکل,
   {{0x7c280f84,0x68e96aed,0x00000000,0x00000000}},	//   _xadr, msed, --, --,
   {{0xa6960d44,0x661d6aee,0x61e46aef,0x68e9013c}},	//   _приј, besk, tail, lsed,
   {{0x69c96af0,0x6447009b,0x35a6005f,0x2001027a}},	//   ncee, ajji, _пайг, eghi_,
   {{0x61e46af1,0x5f46006c,0x68e96af2,0x60dd001e}},	// [6ba0] rail, کنال, nsed, _cwsm,
   {{0x61e406a2,0x2bcf02e4,0x2a7f006d,0x645e43cc}},	//   sail, _स्ला, hnub_, _ulpi,
   {{0x91e6010e,0x69cb6af3,0x61e46af4,0x6e29030d}},	//   _поне, _ofge, pail, _baeb,
   {{0x7c2801cc,0x61460431,0x69c9006d,0x68e96af5}},	//   _sadr, _зема, jcee, ksed,
   {{0x7e62013c,0xd4690416,0x6e3b009f,0x60dd00e9}},	//   rhop, _رحیم_, _dnub, _gwsm,
   {{0x68e93f4c,0x69cb201e,0x8c430e0a,0x7c286af6}},	//   dsed, _afge, лече, _qadr,
   {{0x7c2a6af7,0x8fa36af8,0x4f953c0c,0x68eb0176}},	//   rdfr, _баре, _арту, _avgd,
   {{0x5a3407c1,0x0dc90037,0x89386af9,0x6e3b008c}},	//   тнит, _يبقى_, дпис_, _gnub,
   {{0x81e500c8,0xb05b0328,0x7c28023a,0x27ee01b7}},	//   _নাম_, _itär, _tadr, _pdfn_,
   {{0x47344f88,0xf8ad0118,0x6e296afa,0xbc6a02de}},	//   внос, يکو_, _zaeb, _عمان_,
   {{0x661d6afb,0x45d51b09,0x68e900fe,0xa5f96afc}},	//   tesk, конс, ased, мену_,
   {{0xea0101a5,0xc9861783,0x63be02a7,0x68e90051}},	//   _đầy_, _пули, _agpn, bsed,
   {{0x661d6afd,0x94ab00d8,0x764d02d7,0x00000000}},	//   resk, зтва_, _voay, --,
   {{0xb5fb6afe,0x661d6aff,0x00000000,0x00000000}},	//   chán, sesk, --, --,
   {{0x93884311,0x02a716b6,0x00000000,0x00000000}},	//   еста_, ерам, --, --,
   {{0x5695081b,0x998607c0,0x00000000,0x00000000}},	//   _шайт, _množ_, --, --,
   {{0x2cff02b4,0xddc90395,0x00000000,0x00000000}},	// [6bb0] _ईमेल_, _aleş, --, --,
   {{0x6e3b1884,0x6e290088,0x768801fb,0x00000000}},	//   _snub, _saeb, rıye, --,
   {{0x200102fb,0xf4120122,0xddc90160,0x00000000}},	//   rghi_, _דפי_, _cleş, --,
   {{0xa3d90ca1,0x68e9016e,0x00000000,0x00000000}},	//   ारक_, ysed, --, --,
   {{0xddc96b00,0xdddb0160,0x00000000,0x00000000}},	//   _eleş, _ajuţ, --, --,
   {{0x22496b01,0xeb991052,0x6e2908c7,0x00000000}},	//   ljak_, мил_, _waeb, --,
   {{0xa3e20066,0x2bac0253,0x6b9a00e5,0x00000000}},	//   दरत_, टेला, _cytg, --,
   {{0x5f9434a2,0xcd42006c,0x68e91f13,0xc3340d85}},	//   _сист, _چھوٹ, tsed, רוק_,
   {{0x69c96b02,0x3d080096,0x33310118,0x00000000}},	//   rcee, _समये_, hvzx_, --,
   {{0x68e90f1a,0x2454017b,0x00000000,0x00000000}},	//   rsed, _jämt_, --, --,
   {{0xf77103c7,0x68e96b03,0x0a1506ee,0x00000000}},	//   شاد_, ssed, _لواح, --,
   {{0x68e96b04,0xf1bf0098,0x3ce90207,0x00000000}},	//   psed, _ngá_, šavu_, --,
   {{0xceb20779,0xb5fb0079,0x22496b05,0xa3b40b35}},	//   ייט_, mhál, djak_, जेन_,
   {{0x5ed200c8,0x64a600c7,0xf771132d,0xf1bf0098}},	//   _হিসে, тага, _پات_, _agá_,
   {{0x160a00a1,0x290d6b06,0xe29a01e0,0x91e61180}},	//   _वापर_, ltea_, дав_, кове,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2976b07,0x80c800c8,0x290d6b08,0xe1ff0176}},	// [6bc0] тат_, _লিঙ্, ntea_, _amós_,
   {{0xb21b0022,0xa2a20b54,0xb05b306a,0xc7b80506}},	//   _hjæl, _कीर्, _stär, leđa_,
   {{0xe81302cb,0x52aa03fa,0x645c17ad,0x4ab308b0}},	//   त्या_, _овом_, mkri, ुदाव,
   {{0x75362854,0x81e50033,0x00000000,0x00000000}},	//   _kryz, _নাথ_, --, --,
   {{0xb5fb0079,0x425500af,0x3a2d0027,0x00000000}},	//   dhál, _стэт, ddep_, --,
   {{0xe81300c4,0x201e0bd2,0x645c1cb3,0x7af80009}},	//   त्मा_, _úti_, nkri, trvt,
   {{0xbae300d8,0x7c6500e0,0xcb071301,0x00000000}},	//   ацый, دانل, نيون_, --,
   {{0xc7b8012e,0x645c01f4,0x7e6001da,0x00000000}},	//   jeđa_, hkri, _ulmp, --,
   {{0xfe9100bf,0xd7fa01f2,0x0c261461,0xe7f300dc}},	//   _اینج, мун_, _иман, _आयशा_,
   {{0xea0101a5,0x22496b09,0x26050084,0x645c03bc}},	//   _đấy_, zjak_, _वाही_, jkri,
   {{0xb5fb004f,0xa3c604bc,0x3ffb00a5,0xb21b0b3e}},	//   bhál, एशन_, ופיע, _bjæl,
   {{0xdddb0009,0xcf9300a5,0x7b790070,0xb5fb5cbd}},	//   _kjuš, יטת_, _אָנצ, chál,
   {{0x2249082d,0xd0480095,0x290d0473,0xda65004f}},	//   vjak_, şlər, ctea_, _حالي,
   {{0x49170317,0x645c4894,0x7536005f,0x2bc6021a}},	//   _סקול_, gkri, _dryz, रुचा,
   {{0xa2af00a1,0xdddb011c,0x9484010b,0x22495344}},	//   ंगल्, _ljuš, рыяд, tjak_,
   {{0x75360035,0x32640867,0x316901a3,0xb21b03d0}},	//   _fryz, атув, tzaz_, _gjæl,
   {{0x30150036,0x057401cb,0x22496b0a,0xdddb044d}},	// [6bd0] лдар, _پايد, rjak_, _njuš,
   {{0xc05801c8,0x224902f6,0x20076b0b,0x645c3f36}},	//   кіх_, sjak_, üni_, ckri,
   {{0x290d06a2,0x9df903e6,0x2ef517d0,0x9ed90384}},	//   ztea_, енет_, узер, хмет_,
   {{0x765d02e9,0xe0df02e9,0x4ea41f14,0x20070067}},	//   nksy, _twò_, арча, żni_,
   {{0xa5bb0300,0x768800c1,0x66ec0775,0x00000000}},	//   cdót, nıya, _झिझक_, --,
   {{0xc1b80402,0x9f410176,0x00000000,0x00000000}},	//   _шлях_, lahí_, --, --,
   {{0xeb9627eb,0xb5fb6b0c,0xa2b900e7,0xd5e306fe}},	//   лиш_, thál, ्दप्, पराज,
   {{0x0b160037,0x645c6b0d,0x290d0065,0xf2d40070}},	//   اقية_, zkri, ttea_, בעק_,
   {{0xb5fb29f4,0x00000000,0x00000000,0x00000000}},	//   rhál, --, --, --,
   {{0x290d6b0e,0xb21b054e,0xb8db0035,0xe8f6021f}},	//   rtea_, _sjæl, _आओ_, ыль_,
   {{0x290d5bf2,0x6d595527,0xfc300e6b,0x7bc10008}},	//   stea_, lywa, _بحق_, _iglu,
   {{0x290d002d,0x98ad008b,0x78640176,0x2bcf05f8}},	//   ptea_, mveč_, _ròve, सुरा,
   {{0x6d596b0f,0x09b10083,0x645c5f83,0xb5fb0187}},	//   nywa, _ট্রা, tkri, chám,
   {{0x69db6b10,0x98790070,0x68fb023c,0x7d1b0371}},	//   lbue, _ראַט, mrud, _mpus,
   {{0x645c6b11,0xe7391bdc,0xe89800b5,0x63860227}},	//   rkri, _чей_, _جموں_, угва,
   {{0x645c0e45,0x7d1b0791,0xe2976b12,0x98a6022f}},	//   skri, _opus, гас_, _proć_,
   {{0x68fb6b13,0x645c010b,0x7bc16b14,0xe47600af}},	// [6be0] nrud, pkri, _oglu, _бунэ,
   {{0x7bc116e6,0x68fb6b15,0xa5bb0093,0x6d590067}},	//   _nglu, irud, rdót, dywa,
   {{0xddc966b9,0xa5bb008a,0x7d1b0b9b,0x98ad008b}},	//   _smeš, sdót, _apus, jveč_,
   {{0xb8130d34,0xdee3410e,0x1ea90c74,0x60d6081b}},	//   त्तम_, соци, ناني_, ppym,
   {{0xf8c80028,0x68fb0b3e,0x6296034d,0x9f43021e}},	//   _mức_, jrud, moyo, _lejè_,
   {{0x61e66b16,0xac186b17,0x62840e18,0xa49b01f7}},	//   _hekl, току_, lnio, ltòr,
   {{0x26051db6,0x1fb50086,0x60c66b18,0xa49b0176}},	//   _वाली_, _встр, _hukm, bròf,
   {{0x62846b19,0x6d590035,0x7bc143ed,0x68fb00e9}},	//   nnio, bywa, _eglu, frud,
   {{0x61e60ae0,0xddc93957,0x8e756747,0x6da31a7d}},	//   _mekl, _umeš, _турч, _гита,
   {{0xad1b02b8,0x60c606b3,0x7d0200d8,0xb8ec022e}},	//   _אומר, _mukm, muos, _शं_,
   {{0xb8cb1b6a,0xf8c801a5,0x60c614cc,0x7d026b1a}},	//   _की_, _bức_, _lukm, luos,
   {{0x69dd008a,0x68fb01e0,0x56950036,0x6aab01ed}},	//   ðset, brud, рамт, _ghgf,
   {{0x6284004e,0x550701c8,0x4a7b02b5,0x7d02010b}},	//   dnio, ычна, _אראב, nuos,
   {{0x62840035,0xd7ef0274,0x67d46b1b,0x200a6b1c}},	//   enio, _ћу_, _току, _ncbi_,
   {{0x61e66b1d,0x6d59004e,0x00000000,0x00000000}},	//   _bekl, zywa, --, --,
   {{0x62966b1e,0x7d024194,0x61e60118,0x69c20069}},	//   goyo, kuos, _cekl, _jgoe,
   {{0xc1b914d0,0x20180103,0x7d0200c7,0xe6100079}},	// [6bf0] тлах_, _bbri_, juos, _رشي_,
   {{0x2c090907,0x61e60051,0x09d10d4e,0x7d0263ae}},	//   _साधू_, _eekl, _सभ्य, duos,
   {{0x7d1b08c2,0x6d592112,0x44236b1f,0x62965db0}},	//   _spus, wywa, mej_, boyo,
   {{0x44236b20,0x61e602c0,0xcf9803fa,0x6d59004e}},	//   lej_, _gekl, ују_, tywa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44236b21,0x6d596b22,0x69c20118,0xb5fb00b5}},	//   nej_, rywa, _agoe, nkáb,
   {{0x6d590035,0x68e26b23,0x6e226b24,0x00000000}},	//   sywa, _awod, beob, --,
   {{0x44236b25,0x68fb6b26,0x7f840082,0x68e2021e}},	//   hej_, trud, _الفن, _bwod,
   {{0x44236b27,0x69db01e9,0xe40a00a8,0x0d6702fb}},	//   kej_, rbue, _çiçə, _съвм,
   {{0x7ae71129,0x4423307f,0xf8c80028,0x69c20291}},	//   _бюдж, jej_, _sức_, _egoe,
   {{0x4423000c,0x6284001e,0x366a0545,0x25a96b28}},	//   dej_, ynio, вано_, _azal_,
   {{0x44310029,0x00000000,0x00000000,0x00000000}},	//   edz_, --, --, --,
   {{0x9f4300de,0x44236b29,0x7c230223,0x00000000}},	//   _dejé_, fej_, oenr, --,
   {{0x61e66b2a,0x3ebf00d7,0x60c600f8,0x7c23033b}},	//   _sekl, _liut_, _rukm, nenr,
   {{0x46a62590,0xf8c80028,0x60c665fc,0xf66a16e6}},	//   _какв, _tức_, _sukm, _لحظه_,
   {{0x768801d6,0xb3470279,0xf8c80019,0xb2260370}},	//   mıyo, _seçõ, _hứa_, јмал,

   {{0x768801d6,0x62966b2b,0x6f1c024e,0x44236b2c}},	// [6c00] lıyo, royo, _sprc, bej_,
   {{0xa49b0955,0x44236b2d,0x27e702e9,0x26c72881}},	//   stòr, cej_, _jenn_, _kuno_,
   {{0x27e76b2e,0x6e226b2f,0x93fb1899,0x212b0479}},	//   _menn_, teob, _בליי, _esch_,
   {{0xed5a6b30,0x27e76b31,0x7d026b32,0x3ead6b33}},	//   кое_, _lenn_, tuos, _chet_,
   {{0x26c701a8,0xa5bb0183,0x1bd402fb,0x6e22023a}},	//   _luno_, ndóp, боля, reob,
   {{0x6e220c99,0x7d026b34,0x7c236b35,0x768801d6}},	//   seob, ruos, genr, kıyo,
   {{0xb5fb2905,0x26c76b36,0x7d02037c,0x00000000}},	//   nkác, _nuno_, suos, --,
   {{0x4423263f,0x68e20c1f,0xe8130e62,0xeb970274}},	//   zej_, _pwod, त्सा_, јић_,
   {{0x27e705f5,0x7c235cc3,0x48aa15dd,0x62580079}},	//   _benn_, benr, ктом_, _híos,
   {{0xb5fb004f,0x26c701a8,0xe8060099,0xb21b008c}},	//   mhái, _buno_, _शाळा_, _pjæk,
   {{0xf1c6009a,0x27e702bf,0x44236b37,0x2bcf0066}},	//   लखान, _denn_, vej_, _स्टा,
   {{0x4423006a,0x6f0312c3,0x62580037,0x4b7b100a}},	//   wej_, ànci, _míos, _באבו,
   {{0x44236b38,0x249806d1,0x2a66011e,0xa9c501cb}},	//   tej_, form_, _ilob_, _ازمو,
   {{0x29046b39,0x2a660189,0x27e76b3a,0x25a9031d}},	//   muma_, _hlob_, _genn_, _vzal_,
   {{0x29046b3b,0x44232ce5,0x44316b3c,0x4df8000c}},	//   luma_, rej_, rdz_, ुलाई_,
   {{0x44236b3d,0xd7bb0122,0x7c230051,0x27e70107}},	//   sej_, _בצור, zenr, _zenn_,
   {{0xe8132874,0x44236b3e,0x3ebf6b3f,0x660d6b40}},	// [6c10] त्वा_, pej_, _riut_, _icak,
   {{0xb5fb6b41,0x752d6b42,0x44230031,0x3ead6b43}},	//   dhái, _isaz, qej_, _shet_,
   {{0x29046b44,0x7c230223,0x9295004b,0x2c000785}},	//   huma_, venr, _ганц, _राजू_,
   {{0x29046b45,0xf2d20122,0x62580037,0xa3d355f5}},	//   kuma_, _מעט_, _díos, हुर_,
   {{0x61ed1361,0x29046b46,0x51846b47,0x7c234d5a}},	//   maal, juma_, _дура, tenr,
   {{0x61ed6b48,0x29046b49,0xa3be0bc1,0x3ce40b88}},	//   laal, duma_, ुँच_, _dwmv_,
   {{0x27e70044,0x7c236b4a,0x660d6b4b,0xf8c800e2}},	//   _renn_, renr, _ocak, _rứa_,
   {{0xb5fb0514,0x3209383a,0x61ed6b4c,0x7c236b4d}},	//   bhái, ngay_, naal, senr,
   {{0x29046b4e,0x27e74d80,0xb5fb0082,0xe93902fd}},	//   guma_, _penn_, chái, اسبت_,
   {{0x26c76b4f,0x61ed6b50,0xb8ff0006,0x2c0e00b4}},	//   _puno_, haal, _तऽ_, _सायं_,
   {{0x2bdd0e9b,0x61ed6b51,0x24986b52,0xdd06027d}},	//   _न्या, kaal, vorm_, _köşe,
   {{0x27e70446,0x21290ec0,0x6b7a02b5,0xb5fb0187}},	//   _wenn_, kwah_, _גרענ, vkác,
   {{0x61ed6b53,0x1e3a02b5,0x29046b54,0xa5bb002a}},	//   daal, אגרא, cuma_, udóp,
   {{0xa3d300fa,0x768801d6,0x4d7a0070,0xb5fb0187}},	//   हुल_, pıyo, אָלא, tkác,
   {{0x61ed001c,0x935913fe,0xe79a00b8,0xa5bb002a}},	//   faal, арту_, _těší, leól,
   {{0xe81300dc,0x61ed6b55,0x575600a5,0x32090159}},	//   त्रा_, gaal, _לבצע_, ggay_,
   {{0x614330ca,0xb5fb0097,0x41aa3cc0,0x20ca00f3}},	// [6c20] пета, skác, уван_, ابري_,
   {{0x62580037,0xb5fb00d5,0x00000000,0x00000000}},	//   _píos, pkác, --, --,
   {{0x44446b56,0x29043aa0,0x61ed01a8,0xa3b406bc}},	//   _in_, zuma_, baal, जेश_,
   {{0x29040198,0x44446b57,0xb5fb0037,0x62580079}},	//   yuma_, _hn_, thái, _víos,
   {{0x4444029d,0x62580037,0xfff802fd,0xdd060225}},	//   _kn_, _fíor, _نکات_, _döşe,
   {{0x29046b58,0xa3d8000c,0x00000000,0x00000000}},	//   vuma_, ाडि_, --, --,
   {{0x44446b59,0x907b00c2,0x3a240024,0x2a6601e8}},	//   _mn_, _עטלי, temp_, _plob_,
   {{0x29046b5a,0xb5fb6b5b,0x44440147,0x00000000}},	//   tuma_, phái, _ln_, --,
   {{0x444435d9,0xa3d81e79,0x7688008f,0x7e6200ea}},	//   _on_, ाडा_, rıyl, mkop,
   {{0x44446b5c,0x76443ee2,0x7688008f,0x7e626b5d}},	//   _nn_, _aniy, sıyl, lkop,
   {{0x61ed6b5e,0x29046b5f,0xa09b0319,0xab960037}},	//   yaal, suma_, רייט, _الضغ,
   {{0x44446b60,0x656f0110,0x00000000,0x00000000}},	//   _an_, tzch, --, --,
   {{0xa2b90096,0x61ed6b61,0x2c6b0044,0x4444441c}},	//   ्दस्, vaal, _fødd_, _bn_,
   {{0x81e500c8,0x5ed900c8,0x61ed6b62,0x656f004e}},	//   _নাই_, _ডিসে, waal, rzch,
   {{0x61ed6b63,0x44446b64,0xa3d80299,0xa87b00a5}},	//   taal, _dn_, ाड़_, _תאור,
   {{0xe5c76b65,0x23d900b4,0x62580079,0x1dba01d1}},	//   _уско, _ब्रद, _síor, ेशात,
   {{0x61ed1246,0x7e620c7c,0x90551e9c,0x32096b66}},	// [6c30] raal, dkop, овац, rgay_,
   {{0x61ed6b67,0x32090159,0x91d90084,0x2129046a}},	//   saal, sgay_, _फ्रै, rwah_,
   {{0x61ed6b68,0xb4b537e8,0x2c6b01e0,0x00000000}},	//   paal, जगी_, _jøde_, --,
   {{0xa3ae0299,0xf8c80c67,0x2c6b01b4,0x7e626b69}},	//   _औरत_, रदाय, _møde_, gkop,
   {{0x44446b6a,0x62580037,0xb21b008c,0xccfb0274}},	//   _yn_, _tíor, _bjæv, уће_,
   {{0x6ab30967,0xb5fb0187,0x44330298,0x351c0122}},	//   ुद्र, cháv, _jax_, טודנ,
   {{0x64570602,0xb21b08c8,0x7eaa00d5,0x00000000}},	//   _moxi, _djæv, sýpa, --,
   {{0x9f4301c0,0x7e626b6b,0x64570042,0x3ce000af}},	//   _její_, ckop, _loxi, ţiva_,
   {{0x6258021d,0x00000000,0x00000000,0x00000000}},	//   _míop, --, --, --,
   {{0x64572ea2,0xd83802d0,0x2c6b08c8,0x5d5400af}},	//   _noxi, blčm_, _bøde_, _экут,
   {{0xf62614f8,0x7e696b6c,0x81c10033,0xdb1f0086}},	//   одно, _klep, ুরি_, äväs,
   {{0xa3bf06bc,0x44446b6d,0x9f4a03e6,0x3cf008a9}},	//   ेशन_, _sn_, _bebê_, ुंचे_,
   {{0x44330095,0x1c1e0035,0x7e690118,0x628800a2}},	//   _bax_, _मॉडल_, _mlep, édom,
   {{0x66e50de3,0xe7390011,0x81c10033,0x444400cc}},	//   _дока, _век_, ুরা_, _qn_,
   {{0x444400e8,0xa3b4006a,0x44336b6e,0x42561578}},	//   _vn_, जें_, _dax_, отат,
   {{0x64450159,0xb5fb6764,0x4444538d,0x00000000}},	//   _enhi, lkán, _wn_, --,
   {{0x394d5988,0x4fea0368,0x44446b6f,0x6445021d}},	// [6c40] nxes_, иман_, _tn_, _fnhi,
   {{0xc48600af,0xa3eb2e64,0xa3d307b5,0x394d0443}},	//   _флок, मरण_, हुआ_, ixes_,
   {{0x0eba005f,0xb5fb00ac,0x00000000,0x00000000}},	//   ауды_, rháv, --, --,
   {{0x61461156,0x44330395,0x7e690160,0xf3f10023}},	//   _дема, _zax_, _clep, ực_,
   {{0x7e626b70,0xa2b906d9,0xbc4a03fa,0xff0a0033}},	//   rkop, ्दर्, ичке_, রবেশ_,
   {{0x7e626b71,0x653b0070,0xdee61129,0x395f0159}},	//   skop, יענד, _моги, dyus_,
   {{0xd8380009,0x7e626b72,0x0a6a02ee,0xbb430279}},	//   noče_, pkop, ирии_, дејк,
   {{0x2c6b10db,0x7e6901cb,0xdb0100a2,0x1fa701e0}},	//   _røde_, _glep, _mylè, _єкти_,
   {{0xf98f006c,0x2c6b01cf,0xbe131b20,0xc7b800f4}},	//   ہبی_, _søde_, _توقع, međi_,
   {{0x7c660088,0x7e69024e,0x3ea66b73,0x7d021ea7}},	//   _بارل, _zlep, llot_, mros,
   {{0x7d020fa8,0x7bc8043d,0x394d01dd,0xd838008b}},	//   lros, _igdu, axes_, joče_,
   {{0x44336b74,0xd83818b0,0x8f9b00a5,0x645a6b75}},	//   _sax_, doče_, שיטי, ötin,
   {{0xa25b021d,0x00000000,0x00000000,0x00000000}},	//   _biôn, --, --, --,
   {{0x684300af,0x7d020015,0x44336b76,0x00000000}},	//   _онча, iros, _qax_, --,
   {{0xd83802c6,0x44330282,0x236500b5,0x3ea60159}},	//   goče_, _vax_, álj_, klot_,
   {{0x26de6b77,0x44330147,0x44f53494,0x478912ea}},	//   mpto_, _wax_, _епис, _усім_,
   {{0x443300a5,0x3ea66b78,0x1ad60033,0x00000000}},	// [6c50] _tax_, dlot_, সওয়া, --,
   {{0x7e692662,0x443300d5,0x442700fd,0xa25b00e2}},	//   _slep, _uax_, _ún_, _giôn,
   {{0xd250006c,0x7e696b79,0xa2c40099,0x00000000}},	//   رنے_, _plep, _ांच्, --,
   {{0x2a6d006d,0xb5fb0314,0x3ea66b7a,0x38ab1217}},	//   xheb_, chát, glot_, jørn_,
   {{0x7d026b7b,0x61e20831,0xb3bd0083,0x7e6900d5}},	//   gros, ñole, _অভিজ, _vlep,
   {{0xc6270033,0x00000000,0x00000000,0x00000000}},	//   যাটা_, --, --, --,
   {{0x3ea66b7c,0x7d02325f,0x00000000,0x00000000}},	//   blot_, aros, --, --,
   {{0x6d5c01c2,0x394d0443,0x7e7b6b7d,0x98af011c}},	//   _əraz, txes_, _umup, đače_,
   {{0x13a80d00,0xe80609b1,0xa3eb19b7,0x22590159}},	//   _गर्भ, _शाखा_, मरा_, _mosk_,
   {{0x394d6b7e,0x9f4a2dc4,0x395f596c,0xd7090421}},	//   rxes_, _bebè_, ryus_, бное_,
   {{0x38ab08c8,0x786d0093,0xf7456b7f,0xb5fb00fd}},	//   børn_, _núve, чено, rkán,
   {{0xe81c056a,0xb5fb0355,0xeaae01e0,0x00000000}},	//   ब्बा_, skán, _їй_, --,
   {{0xd9451199,0xe79a0355,0x09e20831,0x00000000}},	//   _хели, _měří, _যাচা, --,
   {{0xa7fc027d,0x52b400b4,0x00000000,0x00000000}},	//   lkın, ंग्स, --, --,
   {{0x22590009,0x69d200a1,0x07a2002d,0xb5fb0079}},	//   _bosk_, णुकी, _пашн, thát,
   {{0xa7fc00a8,0xb5fb00b5,0xf5ea00af,0xcfe80033}},	//   nkın, nkál, _умил_, _পাইন,
   {{0x64890009,0xb5fb0146,0xdfd20037,0xf0ba00b5}},	// [6c60] džif, rhát, فيذ_, مائش_,
   {{0x071f22a7,0xd3e402fd,0x2bdd2e8c,0xb5fb0093}},	//   _बहाव_, _تقدی, नुमा, shát,
   {{0xa7fc0723,0xd00f14ac,0xef1a03fa,0x3ea66b80}},	//   kkın, الم_, сме_, tlot_,
   {{0x442a1d78,0x932500b5,0x3ea60159,0x8ca40067}},	//   leb_, _کرین, ulot_, _चीजो,
   {{0x61e46b81,0x3ea62d91,0xdca60bfe,0xd1ba27ad}},	//   mbil, rlot_, пади, _دادا_,
   {{0x61e46b82,0x442a6b83,0x44386b84,0x3ea66b85}},	//   lbil, neb_, ndr_, slot_,
   {{0x3ea66b86,0xb21b0044,0xdee61a1c,0x00000000}},	//   plot_, _gjæs, _хоби, --,
   {{0x442a6b87,0x7d026b88,0xdb0f0093,0x75240124}},	//   heb_, pros, _ódýr, _opiz,
   {{0x61e407e5,0x442a3ee5,0xb21b10db,0x99d3026e}},	//   ibil, keb_, _kjær, رتيا,
   {{0x6d406b89,0x442a6b8a,0x987300c3,0xc61a0033}},	//   _irma, jeb_, ельц, _তোলা_,
   {{0x1faa00b1,0x9f4a2303,0x442a001e,0x7bdb0122}},	//   _करोड, _bebé_, deb_, _הקבו,
   {{0x7c2a6b8b,0xfb87006c,0x6d400881,0x7c382069}},	//   lefr, _عدلی, _krma, ldvr,
   {{0x61e4038d,0x442a016e,0x2fca0118,0x2c6b03d0}},	//   dbil, feb_, _ogbg_, _høda_,
   {{0x27e900e8,0x442a2889,0xf8c80ea3,0x6d400510}},	//   _đang_, geb_, रदीप, _mrma,
   {{0xc5ec0033,0xdb0800ee,0x855700f8,0x926b0279}},	//   _কারা_, _ozdí, زیگر_, браа_,
   {{0x6d400f1c,0xfbdf0028,0x61e46b8c,0x63a5031d}},	//   _orma, _đêm_, gbil, _vyhn,
   {{0xd49b3121,0x7c2a6b8d,0x442a28ae,0xb21b0a8a}},	// [6c70] _грн_, kefr, beb_, _bjær,
   {{0xb5fb10ba,0x81e50033,0x00000000,0x00000000}},	//   chár, _নাও_, --, --,
   {{0x61e40484,0x06e00083,0x7c2a13dc,0x6d400d19}},	//   bbil, _ভিডি, defr, _arma,
   {{0x8d7400b5,0x7c3812ba,0x24830051,0x00000000}},	//   کاما, edvr, lijm_, --,
   {{0xc7b80537,0x442101b4,0x9f430453,0x2f153ee4}},	//   među_, _kbh_, _dejá_, såg_,
   {{0x7c2a6b8e,0x998d2018,0x6d400207,0xc7b800cd}},	//   gefr, jdeš_, _drma, leđu_,
   {{0xff041397,0x44216b8f,0x2c0e0099,0x00000000}},	//   _пятн, _mbh_, _सारं_, --,
   {{0x61ef6b90,0xae140066,0x44216b91,0xac7700bf}},	//   _jecl, _डायन_, _lbh_, _کارش,
   {{0xa7fc00d0,0x61ef027d,0x95f30033,0x6288000d}},	//   rkın, _mecl, ঝলাম_, édoi,
   {{0xa3bf0953,0x60c702d0,0x61e40eac,0x6aa200d5}},	//   ेशा_, _jijm, zbil, _ekof,
   {{0x752f004e,0x61e408c8,0x61fd03c9,0xa2cd0084}},	//   ewcz, ybil, _odsl, _दूल्,
   {{0x442a3304,0xf1bf0380,0x61ef6b92,0x60c702a2}},	//   web_, ्शान, _necl, _lijm,
   {{0x442a6b93,0x629f01f4,0xe57700d8,0x00000000}},	//   teb_, doqo, дзя_, --,
   {{0x6aa9039b,0x60c701e4,0x61fd2ae3,0x27ee00e9}},	//   llef, _nijm, _adsl, _gefn_,
   {{0x61e46b94,0x7d0b008d,0x26ce027a,0x442101a3}},	//   tbil, hugs, _gufo_, _dbh_,
   {{0x442a6b95,0x7d0b011e,0x44210a8a,0x60cf0124}},	//   seb_, kugs, _ebh_, _bucm,
   {{0x61e46b96,0x8ffa028c,0x61ef6b97,0xd838008b}},	// [6c80] rbil, قرار_, _decl, loča_,
   {{0x61e46b98,0x00000000,0x00000000,0x00000000}},	//   sbil, --, --, --,
   {{0x69cb6b99,0x68eb006d,0x69d901e4,0xee3a3cee}},	//   _ogge, _lwgd, _ofwe, жне_,
   {{0x0d8607f5,0xdee338c7,0x7c2a001e,0x69cb00d1}},	//   млен, тоци, wefr, _ngge,
   {{0x7c2a6b9a,0x78a3030d,0xb21b0a8a,0x00000000}},	//   tefr, _oknv, _tjær, --,
   {{0x69cb6b9b,0x69d902e6,0x6aa20298,0x62840205}},	//   _agge, _afwe, _skof, liio,
   {{0x7c2a6b9c,0x1f590012,0x7d0b010b,0xa5bb0183}},	//   refr, _ешть_, augs, reói,
   {{0xfe43021d,0x6aa911cb,0x7d0b6b9d,0xf3f40033}},	//   _инсо, glef, bugs, _জাফর_,
   {{0x6d406b9e,0x20cd02a7,0x00000000,0x00000000}},	//   _urma, _vžig_, --, --,
   {{0x69cb6b9f,0x6c86103b,0x6aa90036,0x0c231888}},	//   _egge, _غلام, alef, _имун,
   {{0xd83802c6,0x78a84e8b,0x25b2151a,0x00000000}},	//   goča_, rldv, _azyl_, --,
   {{0x2bcc0026,0x78640176,0x00000000,0x00000000}},	//   ाशवा, _mòvi, --, --,
   {{0x9f410079,0x661d008d,0x4421021d,0x00000000}},	//   rbhé_, rfsk, _pbh_, --,
   {{0x26ce0036,0x32c7099e,0x00000000,0x00000000}},	//   _tufo_, _cŵyn_, --, --,
   {{0x3d080243,0x7d0b6ba0,0x786401f7,0xb86521a0}},	//   _समझे_, zugs, _nòvi, _ثانو,
   {{0x6aa0013c,0xb5fb0187,0x96fb00a5,0xe5c70923}},	//   nomf, cháp, _ולהת, _оспо,
   {{0x61e20b4c,0x442100f1,0x4a5b024b,0xf2c400af}},	// [6c90] ñola, _tbh_, קדמו, тсрн,
   {{0xa7fc01d6,0x44216ba1,0x6d4f01da,0x31c40200}},	//   kkım, _ubh_, _àcai, ђств,
   {{0x91c007b5,0x26c90103,0x6aa06ba2,0x60c70055}},	//   लेबै, _kiao_, komf, _vijm,
   {{0x7bda00fb,0x5fdf0c67,0x3d956ba3,0x78640107}},	//   _aftu, _प्रल, ниер, _dòvi,
   {{0x26c96ba4,0x60dd6ba5,0x6aa90055,0xece801e0}},	//   _miao_, _utsm, vlef, дділ_,
   {{0x7d0b6ba6,0xa3d30324,0xc6230033,0x00000000}},	//   rugs, हुच_, _বোমা_, --,
   {{0xa7fc027d,0xfaa56ba7,0xf8c80023,0x248138b4}},	//   rkıl, нако, _gứi_, _mmhm_,
   {{0xd83800a0,0xa49b01f7,0x7bda008e,0x00000000}},	//   voča_, dròm, _eftu, --,
   {{0x26d80391,0x6abb0dd6,0x00000000,0x00000000}},	//   íron_, rmuf, --, --,
   {{0x44ed5ffc,0x6aa96ba8,0x691300cd,0x00000000}},	//   dž_, slef, jžeš, --,
   {{0x25a9012f,0x44ed1675,0x786d0168,0xe1ff021d}},	//   _ayal_, ež_, _cúva, _elói_,
   {{0x26c96ba9,0x69cb6baa,0xd838008b,0x49752682}},	//   _ciao_, _ugge, roča_, _плес,
   {{0x64890009,0x6c7600e2,0x00000000,0x00000000}},	//   džib, _hànộ, --, --,
   {{0xe1ff00b5,0x6c79016b,0x3a2d293c,0x00000000}},	//   _adó_, לאָפ, leep_, --,
   {{0xe0df0359,0xa49b0176,0x25a92cb7,0x6ed402b4}},	//   _atò_, cròm, _eyal_, _बंधु,
   {{0x26c900e8,0xe0da6bab,0x160a045c,0x09c30083}},	//   _giao_, зва_, _वाटर_, _এ্যা,
   {{0xd5b20b82,0x4127519d,0xdb08148a,0xd00a002d}},	// [6ca0] _حفظ_, ното_, _mzdá, зезе_,
   {{0x80a600b2,0xfe0d0d4e,0xf0a700af,0x00000000}},	//   رمان, _हाउस_, екул_, --,
   {{0xb4be16d3,0x3a2d271e,0xdb010168,0x6aa008c7}},	//   ेदी_, keep_, _bylí, yomf,
   {{0x35a50299,0x443a6bac,0x2bdd1f29,0x645e0b48}},	//   _गुड़, _hap_, नुसा, _hopi,
   {{0x443a6bad,0x3a2d2ea2,0xb7bc00ea,0x78a16bae}},	//   _kap_, deep_, reģi, kolv,
   {{0x443a6baf,0x61f6027d,0x645e6bb0,0x3d200067}},	//   _jap_, layl, _jopi, _यहीं_,
   {{0x443a0122,0x645e01a2,0xa3b40099,0x00000000}},	//   _map_, _mopi, जेच_, --,
   {{0x443a6bb1,0x645e6bb2,0x61f66bb3,0xada612b1}},	//   _lap_, _lopi, nayl, _забл,
   {{0x6aa06bb4,0x99980355,0x786d00a0,0x1d07210e}},	//   romf, ěrů_, _súva, _пети_,
   {{0x443a5964,0x645e0029,0x497318f0,0x78a13246}},	//   _nap_, _nopi, ульс, golv,
   {{0x25a9046a,0x61f66bb5,0x25ac013b,0x6aa0023c}},	//   _syal_, kayl, ədli_, pomf,
   {{0x443a6bb6,0x5f080354,0x76880225,0x00000000}},	//   _aap_, _हिन्_, dıys, --,
   {{0x7c3a6bb7,0xb1120083,0x2bdd00b8,0x00000000}},	//   _katr, হবুব_, नुवा, --,
   {{0x443a6bb8,0x69dc004e,0x7c3a0260,0x645e0aed}},	//   _cap_, śred, _jatr, _copi,
   {{0x645e08b6,0x443a1bab,0x083b0100,0x43941b5d}},	//   _dopi, _dap_, _מעגל, гарс,
   {{0x7c3a6bb9,0x32c700e9,0x00000000,0x00000000}},	//   _latr, _gŵyl_, --, --,
   {{0x764d0657,0x443a6bba,0x6d466bbb,0x9f4a02d7}},	// [6cb0] _inay, _fap_, _škan, _debí_,
   {{0x2497006c,0x3014002d,0x645e3b82,0x443a6bbc}},	//   _سمجھ_, лдур, _gopi, _gap_,
   {{0x61f66bbd,0xe81811b5,0xdea100b5,0x00000000}},	//   bayl, _दाना_, لیسی, --,
   {{0xa2d60fd1,0x78a16bbe,0x61f60381,0x645e01ed}},	//   _मंत्, zolv, cayl, _zopi,
   {{0x443a6bbf,0x7c3a6bc0,0x764d002f,0xc1f600a5}},	//   _yap_, _batr, _mnay, _במרץ_,
   {{0x7c3a6bc1,0xc4d40070,0xa5bb01ef,0x00000000}},	//   _catr, אגס_, leós, --,
   {{0x78a16bc2,0x764d027d,0x7c3a00e9,0xeb9603c6}},	//   volv, _onay, _datr, киш_,
   {{0xcff60083,0x0b880037,0x7c3a14a0,0x764d001c}},	//   _চায়_, عضوي_, _eatr, _nnay,
   {{0xdd9440c5,0x7c3a6bc3,0x3a2d4e42,0xdb0800b8}},	//   _баты, _fatr, reep_, _vzdá,
   {{0x290302dd,0x764d6bc4,0x20130fa0,0x7c3a6bc5}},	//   čja_, _anay, ngxi_, _gatr,
   {{0x6e3b6bc6,0x443a6bc7,0x25c70095,0x7886000d}},	//   _kaub, _rap_, ətlə_, _sévè,
   {{0x7c3a1c90,0x645e03ad,0xf772132d,0x443a409c}},	//   _zatr, _sopi, شاپ_, _sap_,
   {{0x645e6bc8,0x443a0c1f,0x7c3a50f0,0x6e3b6bc9}},	//   _popi, _pap_, _yatr, _maub,
   {{0x232a00d4,0x68fb6bca,0x6e3b0b74,0x764d6bcb}},	//   моги_, msud, _laub, _enay,
   {{0x638301c8,0xf8c80028,0x888305f5,0x61f601d6}},	//   агра, _cứu_, _لیکن, tayl,
   {{0x443a6bcc,0x69db6bcd,0x6e3b2326,0x2007008d}},	//   _wap_, ncue, _naub, ónin_,
   {{0x443a6bce,0x645e6bcf,0x68fb6bd0,0x61f60448}},	// [6cc0] _tap_, _topi, nsud, rayl,
   {{0x443a01d1,0x61f66bd1,0x648900cd,0x3fe34b5e}},	//   _uap_, sayl, ržic, ижув,
   {{0x7c3a6049,0xdfcf017e,0x7d1b0069,0x6e3b6bd2}},	//   _ratr, زين_, _aqus, _baub,
   {{0x7c3a6bd3,0x6e3b3303,0x8d86027a,0xfce607be}},	//   _satr, _caub, кулд, водо,
   {{0xdd8f0082,0xa2d60026,0x786d0443,0x2b45099e}},	//   يوم_, _मूत्, _núvo, _arlc_,
   {{0x68fb12ac,0xfbcf0098,0x7c3a007a,0x6e3b00f6}},	//   dsud, يتى_, _qatr, _eaub,
   {{0x7c3a619f,0x09ca05f8,0x26131a75,0x6e3b1db3}},	//   _vatr, ाख्य, _थाली_, _faub,
   {{0x2bc144d2,0x6e3b6bd4,0x7e6b0051,0x5a340227}},	//   षेधा, _gaub, ckgp, унит,
   {{0x7c3a4a8b,0x7e60004f,0x68fb6bd5,0xccc6081b}},	//   _tatr, _iomp, gsud, _абай,
   {{0x7e600221,0x3ce66bd6,0x47341c46,0x6e3b6bd7}},	//   _homp, mpov_, гнос, _zaub,
   {{0x81cb00c8,0x00000000,0x00000000,0x00000000}},	//   রুপ_, --, --, --,
   {{0x648901c8,0x09e618b6,0x9f5102d0,0x6b7b0317}},	//   džia, _родн, _dezè_, _קראנ,
   {{0x39400082,0x7e605d16,0x7eb8002a,0xf8c800e2}},	//   _éis_, _momp, cípe, _bứt_,
   {{0xdddb0723,0x67d30948,0x7e606bd8,0x80d60084}},	//   _oluş, _кошу, _lomp, _बढ़े,
   {{0x81e400c8,0x248d0a78,0x47c00083,0xf8c80019}},	//   _নয়_, đem_, _শ্রী, _dứt_,
   {{0x764d6aa9,0x20182c7b,0x7e606bd9,0xbb3b32e3}},	//   _unay, _acri_, _nomp, ועלי,
   {{0x2ba90c57,0xc05b2327,0x81cb0083,0x3ce6006d}},	// [6cd0] _चुना, між_, রুন_, jpov_,
   {{0x3f67052a,0x6e3b6bda,0x2018021d,0x00000000}},	//   ктеб, _saub, _ccri_, --,
   {{0x44316bdb,0x2fc7022a,0x6e3b6bdc,0x68fb0187}},	//   mez_, äng_, _paub, zsud,
   {{0x44316bdd,0x38b9000d,0x39460ddf,0xacf96bde}},	//   lez_, mère_, _oros_, енду_,
   {{0x93c9006c,0x394601e8,0x38b900f7,0x6e3b04da}},	//   _تاکہ_, _nros_, lère_, _vaub,
   {{0x44316bdf,0xa3b70b7a,0x261a0299,0x67380c21}},	//   nez_, _जरा_, _भाभी_, _osvj,
   {{0x4fc410a9,0x3ec701c8,0x3946001e,0x6d420043}},	//   _вста, _асаб, _aros_, avoa,
   {{0x44316be0,0x39466be1,0x7e606be2,0x68fb6be3}},	//   hez_, _bros_, _gomp, tsud,
   {{0x39466be4,0x44316be5,0x38b900f7,0x9f510260}},	//   _cros_, kez_, hère_, _sezè_,
   {{0x394602c7,0x46e9449f,0x44316be6,0x3a260392}},	//   _dros_, ндон_, jez_, _ebop_,
   {{0x44312853,0x6ec700ab,0x9854081b,0xb7c30831}},	//   dez_, ़गपु, ртыш, োর্ট,
   {{0x394600d7,0x38b900f7,0xf8c800cc,0xa50a027a}},	//   _fros_, dère_, _sứt_, нема_,
   {{0x39466be7,0x69da02b5,0x6faa0084,0x00000000}},	//   _gros_, _אַוו, _जुनू, --,
   {{0x44316be8,0x38b900f7,0x26d10f84,0x9f434410}},	//   gez_, fère_, ízos_, _dejú_,
   {{0xe8180006,0x38b900f7,0x2327021d,0xb3a40324}},	//   _दाता_, gère_, лори_, _खुशख,
   {{0x6d466be9,0x2003027c,0x64896bea,0x20181720}},	//   _škam, _adji_, ržia, _scri_,
   {{0xe29700af,0xd02607e5,0x291f6beb,0x44316bec}},	// [6ce0] уат_, лмай, ntua_, bez_,
   {{0x64c5026b,0x44316bed,0x64892463,0x291f1c9a}},	//   _پيپل, cez_, lžin, itua_,
   {{0x441b0779,0x141b0100,0xa5bb6bee,0x7f860ae7}},	//   _אויס, _אויב, nfón, دلان,
   {{0x291f06a2,0xc60b0083,0x236501ff,0xb5fb0355}},	//   ktua_, ষ্ঠা_, älje_, skáv,
   {{0x5bcc170c,0xaff800b5,0x291f0031,0x127b0070}},	//   ाश्व, _لہذا_, jtua_, _טאטע,
   {{0x6d426bef,0x398a0006,0x22406bf0,0xdca301e0}},	//   rvoa, _हs_, ldik_, бачи,
   {{0x68e20af9,0x291d003c,0x46cf00ab,0xfaa603c6}},	//   _stod, _aqwa_, _संगह, лшин,
   {{0x44310755,0x39466bf1,0x22406bf2,0x66042d9d}},	//   zez_, _pros_, ndik_, _ndik,
   {{0xe8186017,0xa9c302ce,0x443102e1,0x648904d9}},	//   _दादा_, йськ, yez_, džin,
   {{0xb8dc035d,0x660420fb,0x3ea60a43,0x44316bf3}},	//   _आठ_, _adik, loot_, xez_,
   {{0x44311010,0xa3d86bf4,0x291f6bf5,0x62863942}},	//   vez_, िशन_, atua_, _omko,
   {{0x1efb02b5,0x39466bf6,0x3ea603c4,0x60ce0107}},	//   עלכע, _tros_, noot_, _libm,
   {{0x44316bf7,0x291f1979,0x39466bf8,0x6604009f}},	//   tez_, ctua_, _uros_, _ddik,
   {{0x66040c1f,0x3ea66bf9,0x4431521e,0x38b91f3c}},	//   _edik, hoot_, uez_, tère_,
   {{0x44316bfa,0xfe140299,0x3ea601e7,0x200702d7}},	//   rez_, _डांस_, koot_, ónim_,
   {{0x44316bfb,0x62860051,0x92b70037,0x38b900a2}},	//   sez_, _cmko, احسا, rère_,
   {{0x20cd0c99,0x7c286bfc,0x38b9000d,0x7d040079}},	// [6cf0] _džin_, _obdr, sère_, áisl,
   {{0x38b90248,0x752d0036,0x9d5500fd,0x22406bfd}},	//   père_, _ipaz, ینات, adik_,
   {{0x291f01d7,0x636802fb,0x63a902b1,0x8f3500af}},	//   ztua_, _бряг_, ßend, реец,
   {{0x63a9027d,0x3cfd006d,0xddc90c8c,0x3ea60051}},	//   ğend, tswv_, _aleš, goot_,
   {{0x63a90a21,0xa3bf3b23,0xddc90c8c,0xddc20124}},	//   şend, ेशक_, _bleš, tkoš,
   {{0x6b6500d4,0x8c450714,0xa3d800a1,0xac0612a2}},	//   икла, реке, िशय_, анша_,
   {{0x61ed6bfe,0x5c043b4d,0xb5fb00fd,0x00000000}},	//   obal, сяча, nkás, --,
   {{0x291f6bff,0x752d02c6,0xddc20eac,0x81cb0033}},	//   ttua_, _opaz, skoš, রুণ_,
   {{0xe8f6325e,0x6e296c00,0x291f00c3,0x9ac50103}},	//   алы_, _ibeb, utua_, _naŋŋ,
   {{0xb5fb000c,0x291f3ab0,0x648900d8,0x6d496c01}},	//   cház, rtua_, džio, _irea,
   {{0x61ed6c02,0x291f49b4,0x2ca76c03,0xd90f00b5}},	//   kbal, stua_, mond_, زیں_,
   {{0xf1c5046c,0x2ca70987,0xa6de01a5,0x61ed6c04}},	//   वधान, lond_, _trưn, jbal,
   {{0x61ed6c05,0x81cb0083,0xe9ce6c06,0x6e2900f8}},	//   dbal, রুত_, _фк_, _mbeb,
   {{0x18666c07,0xf7450368,0x6d46022f,0x61ed08c4}},	//   _ваши_, _веко, _škak, ebal,
   {{0x68e94a11,0xe3630226,0x22400be2,0x6e290282}},	//   lped, окри, tdik_, _obeb,
   {{0x61ed2700,0x2ca70b0d,0x6d050026,0x660408c7}},	//   gbal, hond_, _रिंग_, _udik,
   {{0x2ca70006,0x22400457,0x1fe70033,0xb5fb00b5}},	// [6d00] kond_, rdik_, _পয়স, yház,
   {{0x6e296c08,0xf00b01a5,0xe0df0019,0x68e9010b}},	//   _abeb, _đảng_, _tròn_, iped,
   {{0x2120068b,0x61ed018e,0x6d490ca5,0x3ea60b0d}},	//   stih_, bbal, _area, toot_,
   {{0x6d496c09,0x68e9046a,0xa11600d1,0x212003c9}},	//   _brea, kped, _پوست, ptih_,
   {{0x6d496c0a,0x2ca76c0b,0x62966c0c,0xddc90e5e}},	//   _crea, fond_, mnyo, _pleš,
   {{0x6d496c0d,0x2ca7139b,0x6e290a21,0xb5fb6802}},	//   _drea, gond_, _ebeb, nkár,
   {{0xe45702b5,0x290d1fbf,0x64890009,0xb5fb00b5}},	//   ייסט_, erea_, džil, rház,
   {{0x6d490f46,0x7f3b0d85,0x62960273,0xd838008b}},	//   _frea, _בעלו, nnyo, moči_,
   {{0x6d495d5f,0xfce332ff,0xd5a50907,0xd838008b}},	//   _grea, _мото, _गुंज, loči_,
   {{0x61ed024e,0x2ca70122,0xc7c62f19,0xc8660f8c}},	//   zbal, cond_, исни, ртии,
   {{0xa2d600c0,0x752d6c0e,0x290d002d,0x1bba006c}},	//   _मूल्, _spaz, area_, _شائع_,
   {{0xe8180fd1,0x290d01d7,0x6296019f,0x0a67052c}},	//   _दावा_, brea_, jnyo, _врши_,
   {{0x290d026e,0x00000000,0x00000000,0x00000000}},	//   crea_, --, --, --,
   {{0xd8380169,0xa7860105,0xd4980390,0x00000000}},	//   koči_, _پشتو, арс_, --,
   {{0xe28700c9,0x20cd02c4,0x83f80421,0xd838008b}},	//   аѓан, _džil_, ресс_, joči_,
   {{0x78a86c0f,0x27770122,0x2ca70120,0xd8380121}},	//   lodv, _כגון_, zond_, doči_,
   {{0xc1b9081b,0xf8ba0f8a,0x2ca76c10,0x98ba0803}},	// [6d10] улах_, _उठाय, yond_, _उठाए,
   {{0x6296009b,0x7eb80300,0xae140826,0x9f6b002d}},	//   anyo, vípa, _डाउन_, крез_,
   {{0x6d490094,0x2ca70120,0x62966c11,0x00000000}},	//   _srea, vond_, bnyo, --,
   {{0x6d496c12,0xb6d90070,0x4255083a,0x00000000}},	//   _prea, אַסט, _انحر, --,
   {{0x2ca76c13,0x9d4507fa,0x2c790107,0x00000000}},	//   tond_, селд, _lède_, --,
   {{0x6d490043,0x628d0036,0xeb993e5d,0x290d027a}},	//   _vrea, liao, лил_, vrea_,
   {{0xa3d8051e,0x2ca702e6,0x00000000,0x00000000}},	//   िशत_, rond_, --, --,
   {{0x290d6c14,0x6d49172d,0x2ca7053e,0x648902c4}},	//   trea_, _trea, sond_, džim,
   {{0x6d496c15,0x2ca76c16,0xa2ba074f,0x6d9900d8}},	//   _urea, pond_, ्षत्, _сваё_,
   {{0x290d3658,0xa5bb008d,0xa85500ed,0x5ba7002d}},	//   rrea_, rfól, стиј, _крез,
   {{0xa5bb008a,0xb8fe0006,0xf8ae00e0,0x07a52dc3}},	//   sfól, _दू_, رکه_, санн,
   {{0x68e96c17,0x60c501f7,0xb4d00355,0x15e3073f}},	//   pped, hmhm, षद्_, कुलर_,
   {{0x41a700b4,0x67216c18,0xe94500d1,0x628d02ee}},	//   _कुलस, stlj, _درای, diao,
   {{0x81bd0033,0x00000000,0x00000000,0x00000000}},	//   ইখা_, --, --, --,
   {{0x786d6c19,0xa3b40067,0x66de02d4,0x00000000}},	//   _núvi, ड़ें_, _tīka, --,
   {{0x20cd02c4,0xb5fb00b8,0x56930166,0x00000000}},	//   _džim_, skár, _најт, --,
   {{0x629600fd,0x00000000,0x00000000,0x00000000}},	// [6d20] rnyo, --, --, --,
   {{0x26d219c6,0x6aa90136,0x2f561470,0x3ead01f7}},	//   _hiyo_, hoef, йтес, _aket_,
   {{0xa2ba021a,0x26d22884,0x00000000,0x00000000}},	//   ्षद्, _kiyo_, --, --,
   {{0x786d0370,0x9f5800da,0x290201c8,0x3ebf6c1a}},	//   _dúvi, _herë_, škai_, _chut_,
   {{0x3ebf0014,0x64890eac,0x26d2021e,0xa3ba00fd}},	//   _dhut_, džij, _miyo_, _جاکر_,
   {{0x653b0070,0xdca3002d,0x6a754aea,0x26d200f8}},	//   טענד, пачи, _ráfa, _liyo_,
   {{0x26c0024b,0x26d20118,0x22421b39,0x6aa90345}},	//   _ohio_, _oiyo_, _kakk_, foef,
   {{0x6e960082,0x25ad004e,0x26d26c1b,0x261a056a}},	//   _الرا, żeli_, _niyo_, _भाषी_,
   {{0x81aa00c8,0xd7fa150d,0x6c1a004f,0x9f5a0132}},	//   গের_, лун_, _متاح_, dapé_,
   {{0x7c650082,0x290a3788,0x7d02022e,0x96ea2a82}},	//   _والل, čba_, msos, льма_,
   {{0x26d26a0a,0x26c0009e,0x7d026c1c,0xcb0901e0}},	//   _biyo_, _bhio_, lsos, _вхід_,
   {{0x64893b1a,0x8f9b00a5,0xe0df009e,0xc5e30067}},	//   ržim, ריטי, _sròm_, कुंठ_,
   {{0x92d50b52,0x261a0066,0x98a634fe,0x7d0201a2}},	//   _হবে_, _भारी_, _лиде, nsos,
   {{0x2a6601e8,0xa7fc027d,0xf48402fb,0x64890355}},	//   _hoob_, rkıs, пусн, mžik,
   {{0x2a660189,0x7d02011e,0x26d20027,0x9a2900e2}},	//   _koob_, hsos, _fiyo_, _hươu_,
   {{0x9f5a6c1d,0x7d023674,0x2a66018d,0x00000000}},	//   capé_, ksos, _joob_, --,
   {{0x786d016f,0x2a660221,0xe0df009e,0x3ead2be0}},	// [6d30] _súvi, _moob_, _tròm_, _rket_,
   {{0x2a666c1e,0x442700e2,0x3ead01b4,0x461500e0}},	//   _loob_, _ùn_, _sket_, _اوکر,
   {{0x656f00e5,0x273a00ea,0x26d2024c,0x3ebf00e2}},	//   lych, _jūn_, _yiyo_, _phut_,
   {{0x66e10029,0x81cb0033,0xd83800f4,0x00000000}},	//   _jēka, রুষ_, moču_, --,
   {{0xed596c1f,0x61ff0095,0x656f6c20,0x7d020cca}},	//   рол_, maql, nych, gsos,
   {{0x61ff013b,0xc05b00d4,0x2c6b0c71,0xcb690012}},	//   laql, _сім_, _nødt_, иале_,
   {{0x6aa919c1,0x61b90067,0xa7fc0225,0x261a060a}},	//   toef, _आरुष, ykır, _भाली_,
   {{0xe9d90ae6,0x2a660189,0x2bdd018d,0x61ff00a8}},	//   шки_, _coob_, नुजा, naql,
   {{0x2ba923e3,0x6aa91472,0x2b4c0211,0x81cb0033}},	//   _चुरा, roef, _erdc_, রুর_,
   {{0x26d2000e,0x656f6c21,0x7c972604,0x26c040f4}},	//   _siyo_, dych, _اشرا, _shio_,
   {{0x2a660221,0xc1a6057c,0x2ca00079,0x2c6b0b41}},	//   _foob_, _खड्ग, éide_, _dødt_,
   {{0x2a6600fe,0x00000000,0x00000000,0x00000000}},	//   _goob_, --, --, --,
   {{0xa2ba057c,0x9f5a1214,0x2c6b1217,0x15ba00c7}},	//   ्षस्, rapé_, _født_, рыны_,
   {{0x7d04004f,0xb5fb008d,0x7bf9016b,0x00000000}},	//   áisi, skáp, יפֿצ, --,
   {{0x26c0012f,0x81b10083,0x324602fb,0xd252186e}},	//   _thio_, টেম_, оевг, ونس_,
   {{0x2a6601e8,0x66de00ea,0xd6d20037,0x63a902b1}},	//   _xoob_, _mīkl, _تقع_, ßena,
   {{0x25df1163,0x80664bd3,0x8cd90354,0x15e3073f}},	// [6d40] _गलती_, оваж, _फूलो, _क्टर_,
   {{0x76440858,0x1fb601e0,0x6ecc033e,0x68e4183d}},	//   _haiy, осер, _işbi, _éide,
   {{0x44446c22,0x81cb0083,0xe821004e,0x9f416c23}},	//   _ia_, রুল_, _माना_, nchè_,
   {{0x44446c24,0x61ff0095,0x87ac0070,0x442a01b7}},	//   _ha_, caql, נשאַ, lfb_,
   {{0x44446c25,0x2a660189,0x8cf301c8,0x76444aec}},	//   _ka_, _roob_, дзіц, _maiy,
   {{0x44446c26,0x1ab40e6f,0x2a6601e8,0x7644028b}},	//   _ja_, ुष्ठ, _soob_, _laiy,
   {{0x44446c27,0x44386c28,0x2a660189,0x7d026c29}},	//   _ma_, ier_, _poob_, ssos,
   {{0x44446c2a,0x44386c2b,0x61e46c2c,0x2a66006f}},	//   _la_, her_, ncil, _qoob_,
   {{0x44446c2d,0xe51c045c,0xddc90097,0x9f5801f7}},	//   _oa_, भूमि_, _pleť, _serè_,
   {{0x6d400669,0x44386c2e,0x7e620a78,0x2c6b008c}},	//   _isma, jer_, ljop, _døds_,
   {{0x7644046a,0x2a666c2f,0x2c7001a6,0x673a01e4}},	//   _baiy, _toob_, _ràdh_, uwtj,
   {{0x368b2b05,0x7c386c30,0x656f0035,0x44381e7e}},	//   рсон_, levr, tych, eer_,
   {{0x44446c31,0x44381f06,0x764400e7,0x1dca0567}},	//   _ba_, fer_, _daiy, िधित,
   {{0x44446c32,0x44380249,0x6a7c0248,0xe82112e7}},	//   _ca_, ger_, _défe, _माया_,
   {{0x6faa0084,0x29040051,0x9f4107e5,0xd8380009}},	//   _जुलू, lsma_, cchè_, meč_,
   {{0x44446c33,0x6d406c34,0xd838008b,0x27e90506}},	//   _ea_, _osma, leč_, _đani_,
   {{0x44446c35,0x61ff01c2,0xe821193c,0x2904415b}},	// [6d50] _fa_, raql, _मामा_, nsma_,
   {{0x7c380bc6,0xdb0101ba,0x661d4793,0x61e4002a}},	//   jevr, _vylú, lgsk, acil,
   {{0x44216c36,0x4ea74419,0x6d406c37,0x1eea0609}},	//   _ich_, орда, _asma, مولی_,
   {{0x51870200,0x9f416c38,0x644510a2,0x29046c39}},	//   _дуга, nché_, _hahi, ksma_,
   {{0x444415ab,0x644532e1,0x61fd00ea,0x7c385d6e}},	//   _ya_, _kahi, _iesl, fevr,
   {{0x44446c3a,0xd8380470,0x61fd086d,0x64450f9f}},	//   _xa_, ječ_, _hesl, _jahi,
   {{0x64456c3b,0x20011b18,0x6d406c3c,0x6d463f01}},	//   _mahi, mahi_, _esma, _škat,
   {{0x44386c3d,0x644506b3,0x20010fc2,0x60d50723}},	//   zer_, _lahi, lahi_, _hizm,
   {{0x44216c3e,0x44386c3f,0x61fd01d6,0xdb08033a}},	//   _och_, yer_, _mesl, _vydá,
   {{0x64456c40,0x44386c41,0x26dc0a93,0x9f586c42}},	//   _nahi, xer_, _buvo_, _seré_,
   {{0x44383d03,0x44446c43,0x7e7b6c44,0x66e801c0}},	//   ver_, _ra_, _klup, _někd,
   {{0x44446c45,0x442141f0,0x44386c46,0x9f410133}},	//   _sa_, _ach_, wer_, rchè_,
   {{0x44446c47,0x64456c48,0x20016c49,0x290200b5}},	//   _pa_, _bahi, kahi_, ákat_,
   {{0x44386c4a,0x64456c4b,0xb4b60ec5,0x20013dea}},	//   uer_, _cahi, जते_, jahi_,
   {{0x44446c4c,0x44380075,0x61fd6c4d,0x6445134c}},	//   _va_, rer_, _besl, _dahi,
   {{0x44440a15,0x44213d48,0x60d50029,0x9f4107e5}},	//   _wa_, _ech_, _aizm, cché_,
   {{0x44446c4e,0x61fd1417,0x64456c4f,0x60d56c50}},	// [6d60] _ta_, _desl, _fahi, _bizm,
   {{0x44441020,0x61e46c51,0x60d56c52,0x8fa601d3}},	//   _ua_, scil, _cizm, пазе,
   {{0x7e7b0051,0x5ed61c64,0x60dd009e,0x7e690b88}},	//   _blup, ستاز, _eusm, _boep,
   {{0x61fd6c53,0x64456c54,0x0dca00c3,0x394f33c5}},	//   _gesl, _zahi, блей_, _orgs_,
   {{0xa25b098b,0x644508bd,0x41b9043b,0x7c386c55}},	//   _khôn, _yahi, _आरएस, tevr,
   {{0x91bb0122,0xdd8f0413,0x69d900e9,0x644500a8}},	//   _למכי, دوه_, _agwe, _xahi,
   {{0x5e961168,0x8fa34073,0x7c386c56,0xd83802c6}},	//   _فلسط, _заре, revr, več_,
   {{0x7e7b6c57,0xb95400d4,0xf8ad0647,0x26dc0036}},	//   _glup, двищ, یکو_, _ruvo_,
   {{0x26dc02c4,0xac860043,0xc6230033,0x2d8201ff}},	//   _suvo_, _егал, _বোঝা_, _åke_,
   {{0x6c862087,0x29046c58,0xb806006c,0xf80601e0}},	//   _علام, rsma_, سکتے_, ччин,
   {{0x64456c59,0x7bda0008,0xd838040b,0x394f0051}},	//   _rahi, _igtu, reč_, _ergs_,
   {{0x64456c5a,0xd6d72830,0xf1be04aa,0xb5fb006c}},	//   _sahi, ять_, ्धान, aján,
   {{0x9f416c5b,0x64456c5c,0x661d6c5d,0x20016c5e}},	//   rché_, _pahi, rgsk, yahi_,
   {{0x753d006a,0x26dc6c5f,0x290200d8,0x61fd01d6}},	//   rwsz, _tuvo_, škas_, _sesl,
   {{0x64456c60,0x24910092,0xe82123e3,0x442101ef}},	//   _vahi, rizm_, _माता_, _vch_,
   {{0x20015b7d,0x644504f7,0x60f910b0,0x648900ac}},	//   wahi_, _wahi, жная_, jživ,
   {{0x20016c61,0x6445359a,0xd2500332,0x64890c99}},	// [6d70] tahi_, _tahi, ھنے_, dživ,
   {{0x44210409,0x7e696c62,0x7e7b6c63,0x645701ef}},	//   _uch_, _soep, _slup, _unxi,
   {{0x61fd6c64,0x7e7b0248,0x7e6942f9,0xb21b008c}},	//   _tesl, _plup, _poep, _nlæg,
   {{0xa159061c,0xddd0010b,0x60dd6c65,0x7bda0345}},	//   _даму_, _šešt, _tusm, _agtu,
   {{0x8c452aac,0x6d460612,0x69d9012f,0x60d50051}},	//   деле, _škar, _rgwe, _tizm,
   {{0xa3b100b4,0x22496c66,0x69d9016e,0x7e6901bf}},	//   टअप_, ldak_, _sgwe, _woep,
   {{0x7e690244,0x660d6c67,0x2a7f6c68,0x9f3400d4}},	//   _toep, _odak, thub_, _пері,
   {{0x224910cd,0x660d6c69,0x7e7b00f8,0xcf920070}},	//   ndak_, _ndak, _ulup, _סטן_,
   {{0x21292bab,0x7d04004f,0x2a7f00d7,0xe8210066}},	//   ntah_, áist, rhub_, _मादा_,
   {{0x660d522f,0x7d040484,0x7d0960f9,0xa8896c6a}},	//   _adak, ġist, _ives, ійна_,
   {{0xa25b0248,0xb21b4c6e,0x395f006f,0x2249010d}},	//   _rhôn, _klæd, sxus_, kdak_,
   {{0x7bc101a0,0x21290069,0x7d0900ec,0x660d0118}},	//   _izlu, ktah_, _kves, _cdak,
   {{0xddc01269,0xd9452399,0xa25b0023,0x29020a66}},	//   _komš, _цели, _phôn, škar_,
   {{0x2a7d006f,0x02c63100,0x660d073a,0x00000000}},	//   _hlwb_, लग्न, _edak, --,
   {{0x21296c6b,0x394d6c6c,0x224912ba,0x91e61d6b}},	//   etah_, lves_, fdak_, добе,
   {{0x7d096c6d,0x648900d8,0x21293af3,0xc7b200a5}},	//   _oves, džiu, ftah_, _שבה_,
   {{0xa25b098b,0x3ced0189,0xe2972b32,0x4127029f}},	// [6d80] _thôn, _ntev_, фат_, мото_,
   {{0xa2be1140,0xb5fb008d,0x394d013a,0x224600a0}},	//   _वीर्, hjál, ives_, žok_,
   {{0x7d096c6e,0xa3b50066,0x72c6359e,0x7eb80042}},	//   _aves, _छुप_, _обоз, lípi,
   {{0x2007003e,0xdddb0355,0x3d090066,0x11d60079}},	//   ónir_, _kouř, _सिखे_, _يتحد,
   {{0x6489011c,0x98bd0260,0x24780260,0x6a7c00a2}},	//   rživ, _aswč_, _kٍm_, _néfa,
   {{0x394d006c,0x7d0947f5,0x00000000,0x00000000}},	//   dves_, _dves, --, --,
   {{0x6489024e,0x2ac60274,0xddc0005f,0x394d40bb}},	//   mžit, мљив, _domš, eves_,
   {{0xb21b054e,0x261a0722,0x2a7d001e,0xf27b0070}},	//   _glæd, _भागी_, _clwb_, ַריש,
   {{0xdb0800c3,0x00000000,0x00000000,0x00000000}},	//   _sydä, --, --, --,
   {{0x6a7c0248,0x2ba902e4,0x22490009,0xda20018d}},	//   _défa, _चुका, zdak_, _यावत_,
   {{0x7d094034,0x00000000,0x00000000,0x00000000}},	//   _zves, --, --, --,
   {{0x787f0248,0xb4d706fe,0xdddb0355,0x63a902b1}},	//   _rêve, िद्_, _bouř, ßenm,
   {{0xd05d013b,0x41ae0067,0x63a90225,0xdd990791}},	//   _etsə, _झुलस, ğenm, _keňa_,
   {{0xe1ff0079,0x69c2023a,0x00000000,0x00000000}},	//   _seó_, _izoe, --, --,
   {{0xa4d402ce,0x46a70086,0x56950043,0xf8370122}},	//   торі, _ошиб, _пакт, _חנות_,
   {{0xe0df0133,0x660d6c6f,0xd6c30df3,0x6d0e0099}},	//   _può_, _udak, _جمعی, _सिंग_,
   {{0x7eb80370,0x22496c70,0xf1940352,0x41b900b4}},	// [6d90] cípi, rdak_, вить, _आरओस,
   {{0x22491a89,0xb21b0b3e,0x69c2023c,0x66de02d4}},	//   sdak_, _slæd, _mzoe, _cūkg,
   {{0x21296c71,0x7d090a78,0x7a1500a8,0xddc0210c}},	//   stah_, _sves, nətç, _romš,
   {{0xc33200c2,0x6aa200da,0x00000000,0x00000000}},	//   _גוט_, _njof, --, --,
   {{0xd1cb00af,0x00000000,0x00000000,0x00000000}},	//   _фунд_, --, --, --,
   {{0x6aa20139,0xf1bf06fe,0x00000000,0x00000000}},	//   _ajof, _dbát_, --, --,
   {{0x1ee700d1,0x6a7c00e0,0x81d40831,0x00000000}},	//   _آوری_, _séfa, সুদ_, --,
   {{0xe8f91d91,0x00000000,0x00000000,0x00000000}},	//   пли_, --, --, --,
   {{0x9f410082,0x81b100c8,0x7d096c72,0x394d00f7}},	//   ichí_, টের_, _uves, uves_,
   {{0x394d3cdb,0xb5fb00b5,0xe8f60104,0x6a750183}},	//   rves_, ckáz, эль_, _máfi,
   {{0x47d20033,0xe7ee0066,0x7bc1005f,0x69c20051}},	//   _দ্বী, छड़ा_, _uzlu, _ezoe,
   {{0xda671328,0x7eb84e1c,0x443300d5,0x00000000}},	//   _تائي, típi, _abx_, --,
   {{0x7ae16c73,0xa25b00f7,0x00000000,0x00000000}},	//   _hult, _chôm, --, --,
   {{0x7eb83c2b,0x648900f4,0x00000000,0x00000000}},	//   rípi, džis, --, --,
   {{0x42560cd0,0x53a30044,0xf77300e0,0x7ae16c74}},	//   нтат, гарб, _جاش_, _jult,
   {{0x7ae16c75,0xb21b3ce9,0x22151c89,0x00000000}},	//   _mult, _smær, кфур, --,
   {{0x66066c76,0x563702b5,0xa69b00a5,0x443300f6}},	// [6da0] makk, _טאקע_, _משקפ, _fbx_,
   {{0x66066c77,0x64891efc,0x3e4c0023,0xddc200cd}},	//   lakk, užit, _ớt_, tkož,
   {{0xee3a6c78,0x44e60019,0x648915b5,0x15f452cf}},	//   зне_, _hô_, ržit, _आभार_,
   {{0x66066c79,0x44e60019,0xe1f202ed,0xdd990168}},	//   nakk, _kô_, _حسد_, _seňa_,
   {{0x628402a8,0x629601d6,0xdb0101d6,0x44e60132}},	//   mhio, miyo, _eylü, _jô_,
   {{0x62966c7a,0x44e601a5,0x7ae16c7b,0x9f5a0036}},	//   liyo, _mô_, _bult, papà_,
   {{0xc60b00c8,0x66066c7c,0x44e601a5,0xa0a36c7d}},	//   ষ্টা_, kakk, _lô_, _сард,
   {{0x629601d6,0x9f5a0132,0xe0df0176,0x7ae10566}},	//   niyo, capá_, _gròs_, _dult,
   {{0xada30183,0x6da30145,0x660608eb,0x44e60023}},	//   _батл, _бита, dakk, _nô_,
   {{0xd7f74fa1,0x6296383a,0x32025f47,0x63a902b1}},	//   ную_, hiyo, _leky_, ßenk,
   {{0x66066c7e,0x62964093,0x7ae10029,0xe8210fd1}},	//   fakk, kiyo, _gult, _मारा_,
   {{0x6e226c7f,0x660620fb,0x7a150095,0x44e600e2}},	//   ngob, gakk, rətç, _bô_,
   {{0x44e60028,0x629601d6,0x69c20054,0x64890009}},	//   _cô_, diyo, _uzoe, džir,
   {{0x44e600cc,0xb4ab018d,0x6a75605e,0x00000000}},	//   _dô_, गके_, _ráfi, --,
   {{0xd7f8002d,0x628411d9,0xa8470079,0x3ce70067}},	//   mbă_, fhio, _سليم_, _छूने_,
   {{0x62846c80,0xd7bb011d,0x44e60260,0x67bb00a5}},	//   ghio, _מצור, _fô_, _ממוק,
   {{0x68e21db7,0x51871bca,0x44330282,0x32020097}},	// [6db0] _juod, хува, _tbx_, _deky_,
   {{0x68e20086,0x9f580176,0x28c60035,0x00000000}},	//   _muod, _berà_, _रीमि, --,
   {{0x62966c81,0x26c96c82,0x62846c83,0x44e600e2}},	//   biyo, _khao_, bhio, _zô_,
   {{0x62846c84,0xedd50312,0x394668fb,0x7ae16c85}},	//   chio, نياد, _osos_, _rult,
   {{0x44e60019,0x68e2010b,0xe82113ab,0x7ae1222b}},	//   _xô_, _nuod, _माला_, _sult,
   {{0xd11602b8,0xed560009,0x224b012c,0x44230c6f}},	//   _בקשה_, тош_, _hack_, ngj_,
   {{0x66066c86,0x0ebb02fd,0x9f4a01f7,0xddc90c8c}},	//   yakk, _فارغ_, _debó_, _ulež,
   {{0x6a7c00f7,0x394602d7,0x68e20090,0x7ae153fb}},	//   _défo, _bsos_, _buod, _vult,
   {{0x66066c87,0x20030ac8,0x6abb19b4,0xdfe507b5}},	//   vakk, _keji_, rluf, _औलाद_,
   {{0x6284005f,0x68e26c88,0xeafb02fd,0xb4ab000c}},	//   zhio, _duod, _فرصت_, गको_,
   {{0x07a538ac,0xf4270b52,0x39460033,0x660637d4}},	//   танн, য়ার_, _esos_, takk,
   {{0x44e653c5,0xd7f800af,0x224b268b,0xa8020448}},	//   _pô_, abă_, _nack_, çırm,
   {{0xb6a36c89,0x6296027d,0x7d1900e9,0x6845010b}},	//   риял, viyo, nrws, _анла,
   {{0x44e60028,0x7eb81d2b,0x291f0054,0x03a600af}},	//   _vô_, lípt, muua_, виго,
   {{0x62846c8a,0x224b6c8b,0x62960723,0xe517004e}},	//   thio, _back_, tiyo, _तिथि_,
   {{0x44e60028,0xcfb70083,0x224b055c,0x00000000}},	//   _tô_, জধান, _cack_, --,
   {{0x62966c8c,0x9f5812c3,0xe0da2356,0x069400b5}},	// [6dc0] riyo, _serà_, два_, _لاکھ,
   {{0x66046c8d,0x629626b1,0x62846c8e,0x03960aeb}},	//   _heik, siyo, shio, _армя,
   {{0x66046c8f,0x403300d4,0xdd9900ee,0x224b017b}},	//   _keik, реєс, _beňo_, _fack_,
   {{0x644e1b5b,0x6a7c00f7,0x66040065,0x91e600af}},	//   ldbi, _réfo, _jeik, _шоме,
   {{0x6e220359,0x66046c90,0x3cfd000c,0x6a7c00a2}},	//   rgob, _meik, रीले_, _défl,
   {{0x66040c8b,0x6aca0b35,0xdb1a006c,0x3a26002d}},	//   _leik, ाग्र, _aztá, _scop_,
   {{0xa0370bed,0x3860022f,0x68e20421,0xfbd50033}},	//   _שאלה_, _đir_, _suod, _স্বত,
   {{0xeaaf0082,0x60dc03a6,0x2498033b,0x66046c91}},	//   يعي_, _hirm, hirm_, _neik,
   {{0x60dc6c92,0xfce66c93,0x1c46002d,0x58d81d13}},	//   _kirm, _розо, _инам, ндия_,
   {{0x68e203ad,0x26c914cc,0x60dc0069,0x00000000}},	//   _vuod, _shao_, _jirm, --,
   {{0x25be01c2,0xdc9b0122,0xba26107b,0x26c90023}},	//   ətli_, _קיבל, _адек, _phao_,
   {{0x645e142f,0x6f030370,0x39460221,0xeb97011d}},	//   _anpi, ânci, _tsos_, _בדבר_,
   {{0x39460876,0xceb302b8,0x333a0069,0x79890067}},	//   _usos_, שיר_, _appx_, czew,
   {{0x224b034e,0xf7540037,0xc9770277,0x00000000}},	//   _sack_, _منتج, _בגדי_, --,
   {{0x26c90028,0x442301f4,0x35c70035,0x224b0eaf}},	//   _thao_, rgj_, रेज़, _pack_,
   {{0x442d01c0,0x645e6c94,0x7c2d00cd,0x66044fc9}},	//   ře_, _enpi, đari, _geik,
   {{0x60dc6c95,0x6a7c0248,0x212b00a2,0x00000000}},	// [6dd0] _birm, _réfl, _qqch_, --,
   {{0x9f580aca,0x764d010d,0x660402a2,0x9f4a021e}},	//   _será_, _haay, _zeik, _rebò_,
   {{0x764d0b04,0x224b022a,0x60dc6c96,0xde190037}},	//   _kaay, _tack_, _dirm, فقات_,
   {{0x60dc01da,0xfe700833,0xed59031d,0x12790070}},	//   _eirm, يدن_, _lyže_, _נאָע,
   {{0x764d6c97,0xed580a55,0x9f581ea3,0x721a011d}},	//   _maay, кої_, _verá_, _אורח,
   {{0x66e8000c,0x60dc008f,0x61ed01f7,0x32090008}},	//   _něko, _girm, lcal, laay_,
   {{0x9f581335,0x61ed0036,0xd4380070,0xeb350105}},	//   _terá_, ocal, דרוק_, ارتخ,
   {{0x66e801c0,0x764d6c98,0x00000000,0x00000000}},	//   _pěkn, _naay, --, --,
   {{0x66046c99,0x4c25006c,0x3a3f012f,0xac270395}},	//   _reik, _مظاہ, reup_, _афек,
   {{0x6604073c,0x6d496c9a,0x79890035,0x0dc84be9}},	//   _seik, _isea, rzew, _руси_,
   {{0x32090051,0x764d01a8,0xd70900d8,0x79890035}},	//   kaay_, _baay, энне_, szew,
   {{0x764d073a,0x8afa024b,0x3ce40027,0x00000000}},	//   _caay, _נהני, _yumv_, --,
   {{0x660455b4,0x764d0103,0x224000d8,0x32090103}},	//   _veik, _daay, veik_, daay_,
   {{0xd8790037,0x66de00ec,0x00000000,0x00000000}},	//   _سمعت_, _cīks, --, --,
   {{0x3878022a,0x660455d6,0x888300bf,0x00000000}},	//   örre_, _teik, _میکن, --,
   {{0x6d496c9b,0x60dc6c9c,0x61466c9d,0x764d018e}},	//   _osea, _sirm, леба, _gaay,
   {{0x60dc68fe,0x22401e7e,0xd2a70fa7,0x6d491720}},	// [6de0] _pirm, reik_, укте_, _nsea,
   {{0x61ed027a,0x764d018e,0x00000000,0x00000000}},	//   acal, _zaay, --, --,
   {{0x6d496c9e,0x320913d6,0x629a52d5,0x2896016b}},	//   _asea, baay_, étos, נדען_,
   {{0x61ed6c9f,0xdfcf00ad,0x0dca190a,0xfce62ef5}},	//   ccal, سين_, нули_, годо,
   {{0x67216ca0,0x63a902b1,0x63be6ca1,0xa49b0176}},	//   hulj, ßenv, _hypn, rsòv,
   {{0x67216ca2,0xdb0800ee,0xafe36ca3,0x00000000}},	//   kulj, _ozdô, _горл, --,
   {{0x67210506,0xed590168,0x41be007e,0x00000000}},	//   julj, _ryže_, ्धकस, --,
   {{0x67214db1,0x3914315d,0xc9140200,0x00000000}},	//   dulj, амир, адић, --,
   {{0x980600d8,0x00000000,0x00000000,0x00000000}},	//   лянд, --, --, --,
   {{0x47344234,0x764d6ca4,0x61ed02d7,0x00000000}},	//   анос, _saay, zcal, --,
   {{0x67216ca5,0x32090159,0x764d6ca6,0xf65f0d50}},	//   gulj, yaay_, _paay, nlæg_,
   {{0x61ed00de,0x45d54ae8,0x7bc825e2,0x66de02d4}},	//   xcal, ионс, _izdu, _cūka,
   {{0xd90e0609,0xb21b08c8,0x25f400be,0x94ab224a}},	//   _عید_, _blæn, ंड़ी_, етва_,
   {{0x764d018e,0x67d40ecb,0x2c7902e9,0x6721247c}},	//   _waay, _колу, _pèdi_, bulj,
   {{0xd25b6ca7,0x764d073a,0xddc90139,0x00000000}},	//   нца_, _taay, _oneş, --,
   {{0xf65f0022,0x48fb01c0,0x09d80033,0x00000000}},	//   dlæg_, लीको_, _ধ্যা, --,
   {{0x940a0095,0xb21b0a8a,0x00000000,0x00000000}},	// [6df0] hibə_, _flæn, --, --,
   {{0xf00b01a5,0x6d4901ef,0x629a00a2,0x00000000}},	//   _đẳng_, _rsea, étor, --,
   {{0x2fc7022a,0x61ed0176,0x00000000,0x00000000}},	//   ång_, pcal, --, --,
   {{0x5d550ced,0x00000000,0x00000000,0x00000000}},	//   икет, --, --, --,
   {{0x67211793,0x00000000,0x00000000,0x00000000}},	//   zulj, --, --, --,
   {{0xeb9905a1,0x1ee703fc,0x6d49023a,0x7bc80067}},	//   кил_, _موسی_, _vsea, _bzdu,
   {{0x290f2978,0x7c840274,0x961d0033,0x3d17021a}},	//   _svga_, ључе, ধ্যম_, _निवे_,
   {{0x6d490082,0x6721030a,0x6e2900d5,0x00000000}},	//   _tsea, vulj, _uceb, --,
   {{0x6d490086,0x290f00cc,0x7cd9021d,0x7bc801ed}},	//   _usea, _qvga_, _амар_, _ezdu,
   {{0x5d840082,0xdd7400b5,0x00000000,0x00000000}},	//   _الكل, _دھمک, --, --,
   {{0xf7710df3,0x5ba70086,0x290d6ca8,0x966618e0}},	//   زاد_, _сраз, ssea_, акне,
   {{0xc4c900a5,0x67216ca9,0x66df1eef,0x290d00af}},	//   _חג_, rulj, _pūka, psea_,
   {{0x672100f4,0xd5d00f8a,0x9f580392,0x05d00099}},	//   sulj, सेंज, _terç_, सेंब,
   {{0x67216caa,0xdb1a00d5,0x6a7500ee,0xd5470274}},	//   pulj, _syté, _gáfr, јпре_,
   {{0xe29a6cab,0x00000000,0x00000000,0x00000000}},	//   вав_, --, --, --,
   {{0x63be024e,0x59d2021a,0xa80200c1,0x00000000}},	//   _vypn, देवर, _çıra, --,
   {{0x9c7c0009,0x00000000,0x00000000,0x00000000}},	// [6e00] _hiče, --, --, --,
   {{0x2f566cac,0x7e606cad,0x2a7f00be,0x9c7c00f4}},	//   итес, _snmp, hkub_, _kiče,
   {{0xd9f702e4,0xb4b20387,0x66160355,0x8fa60079}},	//   ीरात_, टकी_, _kdyk, جماه,
   {{0xb17b013c,0x2a6d0484,0xd8381e85,0x443a00ee}},	//   _igån, jjeb_, miče_, _hbp_,
   {{0x6da60183,0xe3b200f8,0xd838117c,0x9c7c08b7}},	//   шида, _درک_, liče_, _liče,
   {{0xed591e85,0x00000000,0x00000000,0x00000000}},	//   _drž_, --, --, --,
   {{0x8fa368d3,0x9c7c6cae,0xd83800ac,0x2d806caf}},	//   _даре, _niče, niče_, šie_,
   {{0x7bc805cd,0x2a7f006d,0x443a4605,0x940a00a8}},	//   _vzdu, gkub_, _lbp_, ribə_,
   {{0xc8666cb0,0x5c160d93,0xd90d0416,0xd7fa493b}},	//   атни, _نظار, فین_, кун_,
   {{0x9da500d1,0x6a7c000d,0x9c7c00cd,0x443a0067}},	//   _اصفه, _méfi, _biče, _nbp_,
   {{0x7d0d03ab,0x7bc86302,0xd83802c4,0x6d4f0d9b}},	//   šast, _uzdu, jiče_, _ácar,
   {{0x3ea66cb1,0xd83800b8,0x2b4c022e,0xdddb00d5}},	//   nnot_, diče_, _isdc_, _hluš,
   {{0x443a6cb2,0x7ae802fc,0x00000000,0x00000000}},	//   _bbp_, _hudt, --, --,
   {{0xb8cb00c8,0x68ed004f,0x443a598f,0x656b0211}},	//   _কী_, _éada, _cbp_, _àghm,
   {{0x443a104e,0x3ea66cb3,0x26c20097,0x00000000}},	//   _dbp_, knot_, blko_, --,
   {{0xf00b0019,0x32646cb4,0x88bd0067,0xb5fb00fd}},	//   _đằng_, отув, puśc, gját,
   {{0x1bf80084,0x30156cb5,0x3ea6020e,0xdddb023a}},	// [6e10] ुराल_, йдар, dnot_, _oluš,
   {{0x6a7c02e1,0xd838024e,0x62866cb6,0x3cea0324}},	//   _défi, biče_, _elko, _चढ़े_,
   {{0x2b4c012f,0x60ce01da,0xed5900cd,0x657d6cb7}},	//   _nsdc_, _dhbm, _srž_, lysh,
   {{0xa283064e,0x63bb06d3,0x4ea400d8,0x7c3a6cb8}},	//   _بیرو, ğund, орча, _abtr,
   {{0x067c0070,0xdb0800ac,0xefb100b5,0x63bb10b1}},	//   כנאל, _vydý, _کیاگ, şund,
   {{0x3085004f,0x2085126b,0x7ae803d0,0x8af9013b}},	//   _السف, _السّ, _budt, htəş,
   {{0xa3d700c0,0x2a7f00ab,0x7ae800f1,0x920800ea}},	//   िधि_, tkub_, _cudt, stāž,
   {{0x769600c7,0x0a4900af,0x00000000,0x00000000}},	//   ršyk, узий_, --, --,
   {{0xceb20319,0x6e3b6cb9,0xe9d90421,0x00000000}},	//   _זין_, _ibub, ыки_, --,
   {{0xac740082,0x7c2d0a78,0x657d01f4,0xa3d72218}},	//   _والش, đars, dysh, िधा_,
   {{0xe7390274,0x25f437e8,0x00000000,0x00000000}},	//   ћем_, ंडली_, --, --,
   {{0x443a6ab1,0x99860c99,0xd8381e85,0x9c7c00cd}},	//   _sbp_, šiše_, viče_, _viče,
   {{0x64e20096,0x6e3b1e41,0x95990678,0x69cd0099}},	//   पदेश, _mbub, атру_, देखी,
   {{0xa9561899,0xd8380a78,0x974202c4,0x9c7c03c9}},	//   _לינק_, tiče_, _šćen, _tiče,
   {{0x6e3b0273,0x637900af,0xa3b50066,0x68fb029e}},	//   _obub, астр_, _छुआ_, lpud,
   {{0x27316cba,0xe2972682,0xd83819be,0x443a0051}},	//   mán_, бас_, riče_, _wbp_,
   {{0x27316cbb,0x6d5b0189,0x21670b3b,0xd8380097}},	// [6e20] lán_, _nrua, бити_, siče_,
   {{0x6e3b6cbc,0x76466cbd,0xd336002d,0x291f0065}},	//   _abub, leky, _лэмы, irua_,
   {{0xef1a6cbe,0x54770122,0xe29a167d,0x3ea60282}},	//   уме_, _הגיע_, _бан_, tnot_,
   {{0xdddb00cb,0x628603ad,0xe82100a1,0x6d5b6cbf}},	//   _sluš, _ulko, _माझा_, _brua,
   {{0x27310082,0x6d5b0094,0x7ae8053b,0x325700a5}},	//   hán_, _crua, _sudt, _הסכם_,
   {{0x7646011e,0x27312d87,0xf8a70037,0x3ea66cc0}},	//   heky, kán_, _رة_, snot_,
   {{0xe821065a,0x7f860082,0x273110b2,0x66df010b}},	//   _माजा_, _الأن, ján_, _būkl,
   {{0x27316cc1,0x7bc1001e,0x6d5b0523,0xc33300a5}},	//   dán_, _dylu, _frua, פוח_,
   {{0x0d86005f,0x6d5b6cc2,0x2b4c00e7,0xed571b96}},	//   _улан, _grua, _wsdc_, _лот_,
   {{0x7ae8006c,0x200a4363,0x97140d28,0x752601d7}},	//   _tudt, _jebi_, омоц, dukz,
   {{0x27310405,0xb8ef020c,0xb21b0093,0x69cb01ed}},	//   gán_, _वी_, _slæm, _ezge,
   {{0x212007e7,0x9f5807c0,0x657d0421,0x76466cc3}},	//   krih_, _berú_, tysh, geky,
   {{0x20180009,0xb5fb0093,0x6d406cc4,0x00000000}},	//   _odri_, fjár, _jpma, --,
   {{0x657d071f,0x200a40b3,0xc9170122,0x2731006c}},	//   rysh, _nebi_, _פחות_, bán_,
   {{0x2731600c,0xd5ed00e2,0x00000000,0x00000000}},	//   cán_, _toà, --, --,
   {{0x46a41a31,0x6d402c59,0x78ba011c,0x249a01f7}},	//   _најв, _opma, lotv, _empm_,
   {{0x909907c1,0x660f6cc5,0x7ae26cc6,0xf8ad00b5}},	// [6e30] ават_, mack, _miot, _سکی_,
   {{0x660f6cc7,0x7ae26cc8,0xb21b3da1,0x6d5b0055}},	//   lack, _liot, _klæk, _rrua,
   {{0x200a0a31,0x64476cc9,0x6d405ca4,0x75280035}},	//   _debi_, meji, _apma, ądze,
   {{0x21206cca,0x660f6ccb,0xddc0008b,0x46c9178c}},	//   brih_, nack, _domž, रतिह,
   {{0x628d004f,0x27316ccc,0x69c20118,0x9f412b01}},	//   mhao, zán_, _nyoe, nchú_,
   {{0x64556ccd,0xf00b0019,0x64476cce,0x44ef1d1b}},	//   ndzi, _đặng_, neji, _mü_,
   {{0xdea400b5,0x78ba00cd,0x320b00ac,0x6d400103}},	//   _کینی, dotv, _kecy_, _epma,
   {{0xf8b3112b,0x6d5b6ccf,0x273160f3,0x539c02b5}},	//   ुत्प, _trua, ván_, טיוו,
   {{0x3ebf0d1c,0x7ae206a2,0x6f07006d,0x4438001e}},	//   _ikut_, _diot, _hwjc, yfr_,
   {{0x27316cd0,0x6455004e,0x48792294,0x291f6cd1}},	//   tán_, jdzi, рсия_, rrua_,
   {{0xe7390610,0x644725d3,0x00000000,0x00000000}},	//   шен_, deji, --, --,
   {{0x27313c0f,0x9f586cd2,0x7ae26cd3,0x68fb6cd4}},	//   rán_, _perú_, _giot, ppud,
   {{0x44ef0095,0x27316cd5,0x6447080f,0x3ead6cd6}},	//   _cü_, sán_, feji, _mjet_,
   {{0x27310841,0x7ae201d7,0x752601d7,0x76466cd7}},	//   pán_, _ziot, rukz, seky,
   {{0x68e3013a,0x44ef5384,0x200a01f7,0x68eb008e}},	//   _iind, _eü_, _rebi_, _hugd,
   {{0x68e36cd8,0xe1fa2031,0x200a66b9,0x6aa91f9d}},	//   _hind, рга_, _sebi_, nnef,
   {{0x68e30191,0x2018022e,0x81e20033,0xefea0037}},	// [6e40] _kind, _pdri_, নুন_, لعضو_,
   {{0x68eb009e,0x68e36cd9,0x28cf4092,0x394f0279}},	//   _mugd, _jind, _सीमि, _msgs_,
   {{0x68e358fb,0xd8382406,0x68eb0298,0xe3b20919}},	//   _mind, niča_, _lugd, _زرد_,
   {{0x68e36cda,0x628d52f1,0x6a7c0118,0x00000000}},	//   _lind, chao, _yéfu, --,
   {{0x200a17ee,0x395d6cdb,0x7ae241c7,0x2d5801e0}},	//   _tebi_, _nrws_, _riot, силь_,
   {{0x68e36cdc,0x2018022f,0x6284323d,0x660f1bfa}},	//   _nind, _udri_, lkio, zack,
   {{0x7ae2004e,0x80b9143a,0x78ba00cd,0xaff500b5}},	//   _piot, ्तरे, votv, _رہنا_,
   {{0x68e36cdd,0xd8380e42,0x6455297a,0xdcfa042c}},	//   _aind, diča_, zdzi, _نفرت_,
   {{0xfe4302ce,0xf2d302b8,0x660f6cde,0x68e36cdf}},	//   _інфо, ועה_, vack, _bind,
   {{0x26c00107,0xc19b0070,0x6a7c175d,0x395d00e9}},	//   _akio_, ישפי, _réfu, _drws_,
   {{0x68e31744,0x67210c0a,0x7ae26ce0,0x9f58027a}},	//   _dind, grlj, _tiot, _perù_,
   {{0x68e36ce1,0x6455004e,0x395d04fb,0x44ef340c}},	//   _eind, wdzi, _frws_, _pü_,
   {{0xd6d80a55,0x68e36ce2,0xa3dd0096,0x660f6ce3}},	//   ють_, _find, तेन_, rack,
   {{0xd8386ce4,0x6aa06ce5,0x64556ce6,0x672100f4}},	//   biča_, limf, udzi, brlj,
   {{0x64556ce7,0x64476ce8,0x629f046a,0x628d6ce9}},	//   rdzi, reji, tiqo, thao,
   {{0x68e36cea,0x44ef2f90,0x64473bdc,0x00000000}},	//   _zind, _tü_, seji, --,
   {{0x67286ceb,0x68e301d5,0x629f2dfb,0x628d00e9}},	// [6e50] ludj, _yind, riqo, rhao,
   {{0x660d00ab,0x628d6cec,0x6ef30484,0x3ebf0345}},	//   _heak, shao, _aħba, _skut_,
   {{0x660d0ac8,0x67286ced,0x6aa060e3,0x00000000}},	//   _keak, nudj, kimf, --,
   {{0x9c7c6cee,0x00000000,0x00000000,0x00000000}},	//   _riča, --, --, --,
   {{0x3ead00da,0x63ad0080,0xed596cef,0x248c00d8}},	//   _vjet_, šinā, сол_, šimų_,
   {{0xe3df0b52,0x317a0052,0x22490291,0x6d5d008a}},	//   _ব্যব, _הרשמ, leak_, _ásam,
   {{0x68eb1b82,0x2129012f,0x6aa959f4,0x6abb0fce}},	//   _sugd, luah_, tnef, touf,
   {{0xd8386cf0,0x224901d7,0x6721012e,0xa3dd0099}},	//   viča_, neak_, vrlj, तेय_,
   {{0x6aa96cf1,0xe8f6004b,0x629d00ee,0x00000000}},	//   rnef, плы_, _mmso, --,
   {{0x628406a2,0x6721003a,0x68e301f4,0x6aa90093}},	//   zkio, trlj, _qind, snef,
   {{0x660d026a,0x7d09012f,0x629d071b,0x224901a3}},	//   _beak, _hwes, _omso, keak_,
   {{0x7d096cf2,0x649000ab,0x941100a8,0x224901d7}},	//   _kwes, _käig, mizə_, jeak_,
   {{0x224903cb,0x660d6cf3,0x394f41c7,0x2129012f}},	//   deak_, _deak, _usgs_, juah_,
   {{0x9c7c2c3f,0x629d0088,0x7d0901d0,0x68e3008c}},	//   _ličn, _amso, _mwes, _uind,
   {{0x87040c74,0x93590208,0x7d09073a,0x941100a8}},	//   _قبيل, орту_, _lwes, nizə_,
   {{0xc7b202b8,0x224901d7,0x7d09001c,0xe2970259}},	//   _רבה_, geak_, _owes, пас_,
   {{0x66e801c0,0x216711a7,0x3ced0453,0x62840065}},	// [6e60] _děku, пити_, _nuev_, rkio,
   {{0x8236006c,0x76566cf4,0x90c30086,0x3dd10033}},	//   _کردا, _hayy, ебуе, িশাল,
   {{0x224901d7,0x7d0900a5,0x6aa00371,0x547b024b}},	//   beak_, _awes, yimf, _הטיו,
   {{0x2129203f,0xddcf1abc,0x3ced01ef,0x491c0324}},	//   buah_, _šeše, _buev_, _मिलो_,
   {{0x7d09001e,0x78a1008a,0x9c7c0506,0x00000000}},	//   _cwes, kilv, _dičn, --,
   {{0x653b02b5,0x941100a8,0x394d0b88,0x3ce500ec}},	//   מענד, fizə_, dwes_, _cilv_,
   {{0x3af10019,0x5f2710be,0x7d091805,0xdd8f00b5}},	//   _cáp_, _норм_, _ewes, نڈے_,
   {{0x3212011e,0x3a2d01cb,0x00000000,0x00000000}},	//   nayy_, ggep_, --, --,
   {{0x7d09001e,0x649000be,0x00000000,0x00000000}},	//   _gwes, _käid, --, --,
   {{0x660d6cf5,0xb0be06bc,0x50be5bba,0x224901d7}},	//   _seak, ्तिग, ्तिष, zeak_,
   {{0x660d0006,0x66e801c0,0x99e60945,0x6a7c000d}},	//   _peak, _někt, _ежед, _défr,
   {{0x224901d7,0x2a66010d,0x00000000,0x00000000}},	//   xeak_, _unob_, --, --,
   {{0x78a16cf6,0x67280124,0x20be0253,0x00000000}},	//   bilv, sudj, ्ताध, --,
   {{0xb9db0122,0x64901c55,0x22490069,0x629d023a}},	//   _החדש, _näid, weak_, _smso,
   {{0x083b02da,0x22490291,0x883b0122,0x7528004e}},	//   _העול, teak_, _לתגו, ądza,
   {{0xe8df01a5,0x2129022e,0x6d1c00b4,0x00000000}},	//   ược_, tuah_, _निंग_, --,
   {{0x224906a2,0x769600c7,0x9c7c07c0,0x00000000}},	// [6e70] reak_, ršyt, _ničo, --,
   {{0x21290a4e,0x224901a3,0x7d09007b,0x9c7c02a7}},	//   ruah_, seak_, _rwes, _sičn,
   {{0x212902c2,0x3f870bca,0x44330160,0xa5bb002a}},	//   suah_, ánu_, _icx_, rgóu,
   {{0x3f8f004e,0x3af10023,0x7d096cf7,0x9c7c00d5}},	//   ągu_, _ráp_, _pwes, _bičo,
   {{0x3f870254,0x3af10023,0xb21b008c,0x9c7c00cd}},	//   šnu_, _sáp_, _blæv, _vičn,
   {{0xd7e60082,0x64570298,0x00000000,0x00000000}},	//   _لك_, _jaxi, --, --,
   {{0x6a7c00f7,0x9c7c0009,0x999f0009,0xaac40088}},	//   _réfr, _tičn, deuš_, کتون,
   {{0xe8f94234,0x94110095,0x7d09041b,0x645700f6}},	//   оли_, rizə_, _twes, _laxi,
   {{0x44330526,0x6ba60095,0x7656028b,0x81b10033}},	//   _ocx_, _əsgə, _rayy, য়ের_,
   {{0x76565fe5,0x7e7b0355,0x9f5a0453,0xe6c50207}},	//   _sayy, _houp, capó_, _ćešć,
   {{0x7e7b6cf8,0x321200d7,0x7e690542,0x00000000}},	//   _koup, yayy_, _knep, --,
   {{0x76564530,0xe5a61bca,0xd0160083,0x7e7b6cf9}},	//   _qayy, дими, ালয়_, _joup,
   {{0x6b835581,0x6457013b,0x7e7b0107,0x78a1624b}},	//   lyng, _baxi, _moup, pilv,
   {{0x2bda0302,0xd9420573,0x645703e6,0x98f40037}},	//   येवा, _реши, _caxi, _أثنا,
   {{0xa3d8006a,0x645701c2,0x765600c1,0x443303d0}},	//   ़ें_, _daxi, _tayy, _dcx_,
   {{0x7e7b6cfa,0x00000000,0x00000000,0x00000000}},	//   _noup, --, --, --,
   {{0x00e601c8,0x64573e0d,0x8afc0067,0x00000000}},	// [6e80] джан, _faxi, _kręc, --,
   {{0xf4250b52,0xeb0d0084,0x44f402ee,0x00000000}},	//   ম্বর_, _सबूत_, _iä_, --,
   {{0x649000ab,0x7e7b6cfb,0x44f46cfc,0xdd8f03fc}},	//   _väid, _boup, _hä_, یوم_,
   {{0x7e7b0e15,0xdfcf0079,0x9c7c0207,0x00000000}},	//   _coup, جيم_, _pičo, --,
   {{0x649000ab,0x7e7b6cfd,0x66fa0024,0x41030382}},	//   _täid, _doup, _iċke, _изяв,
   {{0x44f40086,0x7e690009,0x6b83001e,0x6fd60325}},	//   _mä_, _enep, fyng, _भरपू,
   {{0x6b830297,0x649000ab,0x905700a5,0x44f44e8f}},	//   gyng, _käib, _קבלו_, _lä_,
   {{0xf1bf004f,0x5a3401d3,0x7e7b00a2,0x00000000}},	//   _gcás_, хнит, _goup, --,
   {{0x44f41ab7,0xcfb00033,0x00000000,0x00000000}},	//   _nä_, _করিন, --, --,
   {{0x7d022962,0x9c7c011c,0x6c3200b5,0x7e7b01ef}},	//   mpos, _kičm, _شہبا, _zoup,
   {{0x7d026cfe,0x3ce70084,0x7e7b2939,0x443300f6}},	//   lpos, _छूटे_, _youp, _rcx_,
   {{0x64576cff,0xc5f90084,0x44f40523,0x49920220}},	//   _saxi, ंडेय_, _bä_, _لیبر,
   {{0x7d026d00,0x44334523,0xb4e90ca1,0x00000000}},	//   npos, _pcx_, यदे_, --,
   {{0x44f4038e,0xd7ef00ed,0x00000000,0x00000000}},	//   _dä_, _ју_, --, --,
   {{0x53340009,0x64570042,0x9c7c0009,0xf8b000b5}},	//   керт, _vaxi, _ričl, _لکھ_,
   {{0x27384a07,0x64570337,0x320f00b5,0x7d026d01}},	//   mén_, _waxi, úgy_, kpos,
   {{0x7d026d02,0x7e7b1335,0x27386d03,0x44f40282}},	// [6e90] jpos, _roup, lén_, _gä_,
   {{0x6fa00953,0x7e7b6d04,0xd011234a,0xd7f80043}},	//   _गेहू, _soup, الا_, ncă_,
   {{0x7e7b6d05,0x7d020051,0x2fc701b4,0x9f50008d}},	//   _poup, epos, æng_, ðaði_,
   {{0xdde20b67,0x394601f7,0x273801ef,0x05d30066}},	//   _šušt, _opos_, ién_, _सराब,
   {{0x7d026d06,0x849800d1,0x628f0036,0x6eb3012f}},	//   gpos, _رئیس_, _ilco, ेकबु,
   {{0x64900006,0x44316d07,0x2738042c,0x6b836d08}},	//   _täie, ngz_, kén_, tyng,
   {{0x4fc41db7,0x7e7b02e9,0x2738006c,0x39460183}},	//   _аста, _toup, jén_, _apos_,
   {{0x27380580,0x201101b7,0x00000000,0x00000000}},	//   dén_, _hezi_, --, --,
   {{0x2259024b,0x00000000,0x00000000,0x00000000}},	//   _mask_, --, --, --,
   {{0x20110c1f,0x81b10083,0xf0920070,0x273801ef}},	//   _jezi_, _ওরা_, ָנט_, fén_,
   {{0x20116d09,0x3946053e,0x2738006c,0x387c0036}},	//   _mezi_, _epos_, gén_, _dovr_,
   {{0x28cf0299,0x20110124,0xa9090037,0x63bb037a}},	//   _सीरि, _lezi_, _فيصل_, ğunl,
   {{0x3eaf0037,0x63bb00a8,0xd9450fb4,0xd914010b}},	//   ingt_, şunl, _чели, _адчы,
   {{0x27380d2e,0x20110009,0x9f4102d7,0x44f46d0a}},	//   bén_, _nezi_, nchó_, _vä_,
   {{0x21390c6f,0x22596753,0x44f40553,0x2738365a}},	//   _aqsh_, _bask_, _wä_, cén_,
   {{0x44f46d0b,0x2259008c,0x9c7c02c4,0x228e00d5}},	//   _tä_, _cask_, _ričm, _býka_,
   {{0x9556004f,0x26c26d0c,0xe29703c6,0x76440010}},	// [6ea0] _أخبا, moko_, хат_, _ibiy,
   {{0x26c26d0d,0x6acb021a,0x628f6d0e,0x228e00d5}},	//   loko_, ातुर, _elco, _dýka_,
   {{0x44441020,0x03a66bde,0x7d1b6d0f,0x7d0200cc}},	//   _ib_, _чино, _avus, wpos,
   {{0x81e200c8,0x644e6d10,0x7d020a78,0x645c6d11}},	//   নুষ_, lebi, tpos, ldri,
   {{0xdca64b34,0x27381d8a,0x444406c6,0x9f580392}},	//   нади, zén_, _kb_, _peró_,
   {{0xa80201c2,0x26c26d12,0x98a40029,0x644e6d13}},	//   _çıxa, hoko_, kumā_, nebi,
   {{0x98a40080,0x26c26d14,0x4444538d,0x7d02187d}},	//   jumā_, koko_, _mb_, spos,
   {{0x65646d15,0xdc3c0169,0xdee30aec,0x27386d16}},	//   _orih, _išči, _боси, vén_,
   {{0x44446d17,0x644e6d18,0x26c201d7,0xd90d042c}},	//   _ob_, kebi, doko_, قین_,
   {{0x27386d19,0x44446d1a,0x76446d1b,0x644e6d1c}},	//   tén_, _nb_, _abiy, jebi,
   {{0x56956d1d,0x644e6d1e,0xd7f8002d,0x645c6d1f}},	//   вант, debi, rcă_, ddri,
   {{0x44446d20,0x645c6d21,0x27386d22,0x9bb70122}},	//   _ab_, edri, rén_, _אהבה_,
   {{0x9c7c0478,0x39460159,0x65640160,0x22596d23}},	//   _ničk, _upos_, _crih, _rask_,
   {{0xf1db009a,0x644e6d24,0x645c0801,0x7644018e}},	//   _मृगन, gebi, gdri, _ebiy,
   {{0x26c23aa0,0xb8650416,0xd3242374,0x326700d8}},	//   boko_, _جانو, льти, нтав,
   {{0x201102d0,0x645c0036,0x6564408c,0x26c201ed}},	//   _sezi_, adri, _frih, coko_,
   {{0x2ba70387,0x2b52004e,0x644e0225,0x3ea66d25}},	// [6eb0] _केना, łych_, bebi, diot_,
   {{0x44446d26,0x644e1432,0xd91b0319,0x764f233c}},	//   _gb_, cebi, פובל, lecy,
   {{0x20116d27,0x442100f1,0x64450211,0xceeb0416}},	//   _vezi_, _idh_, _ibhi, سران_,
   {{0x9f586d28,0x765d01b4,0x531a02b5,0x44446d29}},	//   _però_, ndsy, _קורצ, _zb_,
   {{0x32096d2a,0x760c02b5,0x442100a0,0xa3f500b4}},	//   mbay_, פּאַ, _kdh_, _आलाप_,
   {{0x7d1c0029,0x26c2048d,0x212900f8,0x32090381}},	//   _ārst, zoko_, mrah_, lbay_,
   {{0x26c26d2b,0xdfd4004b,0x9f410453,0x3e3300b5}},	//   yoko_, _боры, rchó_, _مہار,
   {{0x32096d2c,0x644e6d2d,0x98a400ea,0x645c0207}},	//   nbay_, zebi, vumā_, zdri,
   {{0x644e01d6,0x6f1c0cc1,0x26c26d2e,0xb6040355}},	//   yebi, _zvrc, voko_, ndář,
   {{0x21290034,0x644e06a2,0x44210254,0x26c20010}},	//   irah_, xebi, _ndh_, woko_,
   {{0x320900a7,0x26c25819,0x6c7a02b5,0x6564012f}},	//   kbay_, toko_, _קרעד, _srih,
   {{0x65644644,0x44210874,0x98a40029,0x2ca76d2f}},	//   _prih, _adh_, rumā_, lind_,
   {{0x26c26d30,0x44446d31,0x21294367,0x644e6d32}},	//   roko_, _pb_, jrah_, tebi,
   {{0x44446d33,0x61fd6d34,0x2ca7002d,0x44211214}},	//   _qb_, _afsl, nind_, _cdh_,
   {{0x645c6d35,0x26c2536f,0x7aeb011e,0xe3b82f80}},	//   rdri, poko_, _kigt, çı_,
   {{0x44440189,0x2ca76d36,0x644e6d37,0x7afc0332}},	//   _wb_, hind_, sebi, _érte,
   {{0x2ca73155,0x22400a21,0x645c6d38,0x3ea60421}},	// [6ec0] kind_, rfik_, pdri, viot_,
   {{0x44446d39,0x42c40083,0x7aeb6d3a,0x31606d3b}},	//   _ub_, ্দেশ, _ligt, rviz_,
   {{0xee3a30ba,0xe29a0374,0x21295cdd,0x6d4901ef}},	//   дне_, _жан_, arah_, _apea,
   {{0x26c301cc,0x787e01c0,0x9c7c01f2,0x21290118}},	//   čkog_, _závě, _tičk, brah_,
   {{0xa2bf00b8,0x201c0183,0x6458008d,0x2ba70387}},	//   वकर्, óvis_, _óvis, _केबा,
   {{0x9f58008a,0x03160066,0x9c7c201d,0x3ea66d3c}},	//   _ferð_, _तबाह_, _kiči, siot_,
   {{0x7aeb010d,0x6d4901d7,0x9f58008a,0x68ea00d7}},	//   _bigt, _epea, _gerð_, _rifd,
   {{0x69cb0626,0x9c7c0b5e,0xab836d3d,0x67280207}},	//   _byge, _miči, рушк, vrdj,
   {{0x7aeb6d3e,0x2ca71995,0x9c7c01a0,0x7c210107}},	//   _digt, bind_, _liči, _fdlr,
   {{0x2bbb0084,0x2ca76d3f,0x00000000,0x00000000}},	//   _ऊँचा, cind_, --, --,
   {{0x32092326,0xd83801a0,0x69cb0051,0x6445009e}},	//   ybay_, niči_, _eyge, _rbhi,
   {{0x4733006c,0x44216d40,0x6445010d,0x752f0035}},	//   گریز, _sdh_, _sbhi, tucz,
   {{0xa2d30026,0xa2b806bc,0x38570df3,0x67280124}},	//   _भीष्, ्कन्, رشید_, srdj,
   {{0x3af86d41,0x98a303e6,0x9c7c00c7,0x752f2555}},	//   _kép_, _киче, _biči, rucz,
   {{0xa3dd004e,0x44212a86,0x64450453,0x753d608b}},	//   तें_, _vdh_, _vbhi, stsz,
   {{0xd8380a3c,0x21296d42,0x3af800e2,0x9c7c00cd}},	//   diči_, trah_, _mép_, _diči,
   {{0x26c90009,0x320933cd,0x3af86d43,0x44216d44}},	// [6ed0] _ikao_, rbay_, _lép_, _tdh_,
   {{0x32090211,0x941801c2,0x66df4cd6,0xdddb082d}},	//   sbay_, kirə_, _tūks, _pluž,
   {{0x2ca76d45,0xdb1e0248,0x6d490122,0x649000ab}},	//   vind_, _évèn, _spea, _käin,
   {{0x2ca76d46,0x9f58008a,0xa3dd022e,0xb21b0093}},	//   wind_, _verð_, तेः_, _glæp,
   {{0x7aeb6d47,0x9c7c0009,0x2ca700af,0x1d342d93}},	//   _rigt, _ziči, tind_, инця,
   {{0x6acb0d53,0x7aeb6d48,0x649000ab,0x69cb01b4}},	//   ात्र, _sigt, _läin, _ryge,
   {{0x447c00c2,0x2ca76d49,0x69cb054e,0xdd030644}},	//   ונגע, rind_, _syge, ırım,
   {{0x3af80019,0x2ca76d4a,0x649003a6,0x60c56d4b}},	//   _dép_, sind_, _näin, lohm,
   {{0x7aeb054e,0x2ca76d4c,0x6d490421,0x08c5027a}},	//   _vigt, pind_, _upea, лбин,
   {{0xd7090086,0x0ba702ee,0x69cb0097,0x6ef30069}},	//   нное_, _ишем, _vyge, _aħbi,
   {{0x7aeb0008,0x16aa1199,0x3af800b5,0x2eed6d4d}},	//   _tigt, евни_, _gép_, _kief_,
   {{0xb80306bc,0x69cb58be,0x9c7c00f4,0xd05c013b}},	//   _श्रम_, _tyge, _riči, _dirə,
   {{0x5e560070,0xa3e600b4,0x69aa00b4,0x07e800b5}},	//   נישע_, बेन_, _जेपी, ٹریٹ_,
   {{0x6aa9320a,0x2eed6d4e,0x92b00033,0x9c7c07e7}},	//   lief, _lief_, _ওঠে_, _piči,
   {{0xd05c013b,0x00000000,0x00000000,0x00000000}},	//   _girə, --, --, --,
   {{0xb29503fa,0x628d03be,0xd838023a,0x6aa90f0a}},	//   ајућ, gkao, viči_, nief,
   {{0xe0da5049,0x79890657,0x412717e3,0x7d040029}},	// [6ee0] ева_, nyew, лото_, ģisk,
   {{0x071700b4,0x6616045e,0x6296007b,0x9c7c0881}},	//   _दबाव_, _heyk, shyo, _tiči,
   {{0xe45700c2,0x645e0008,0xdddb0069,0x2eed0345}},	//   _גייט_, _iapi, _eluż, _bief_,
   {{0x645e6d4f,0xdb1e02e1,0x42561c2e,0x443a6d50}},	//   _hapi, _évén, _стот, _hcp_,
   {{0x63b60080,0xd8380187,0x2eed2069,0x98a400c7}},	//   šanā, siči_, _dief_, lumą_,
   {{0x6adc210a,0x10a66058,0x645e6d51,0xdc140033}},	//   मग्र, _сигн, _japi, _সাহস_,
   {{0x645e6d52,0x201a010d,0x2ba70c67,0x2eed00f6}},	//   _mapi, mapi_, _केदा, _fief_,
   {{0x201a2700,0xdd160105,0x9c7c02a7,0x6aa9095a}},	//   lapi_, _مورخ, _ničv, gief,
   {{0xd83a00af,0xcc36149c,0x443a026e,0xb4db01f7}},	//   нэн_, _مراع, _ocp_, ntàc,
   {{0x645e6d53,0x31570052,0x201a0580,0x8d930037}},	//   _napi, ניין_, napi_, _الكش,
   {{0xc6000033,0xb86600d1,0x9c7c0207,0x66160225}},	//   ্ণনা_, ناگو, _bičv, _beyk,
   {{0x645e6d54,0x201a00e0,0x00000000,0x00000000}},	//   _aapi, hapi_, --, --,
   {{0x201a0224,0x443a67f7,0xe1ff0035,0x386e01f7}},	//   kapi_, _bcp_, _znów_, _tnfr_,
   {{0x645e46d2,0x66d63c0e,0x00000000,0x00000000}},	//   _capi, ráka, --, --,
   {{0x645e2487,0x201a005d,0xf53f5c1b,0x43941199}},	//   _dapi, dapi_, stå_, барс,
   {{0x68ed004f,0x92582356,0x66160345,0xddc9007a}},	//   _éadr, ласт_, _geyk, _poeż,
   {{0x7c3a56bc,0x1da40067,0x2eed02b1,0x201a021d}},	// [6ef0] _octr, _खेलत, _rief_, fapi_,
   {{0x645e6d55,0x00000000,0x00000000,0x00000000}},	//   _gapi, --, --, --,
   {{0x23fa0122,0x14b807f6,0x60c56d56,0x20d400c3}},	//   _בהתא, _حديث_, rohm, päin_,
   {{0x7c3a0300,0xd838264f,0x3ef800af,0x00000000}},	//   _actr, miču_, унцэ_, --,
   {{0xa3a93e72,0x645e43d6,0x201a00ee,0x2b4c2df0}},	//   _खेत_, _yapi, bapi_, _apdc_,
   {{0x99dd01c0,0x201a09e7,0x64900196,0x00000000}},	//   zeňs, capi_, _näil, --,
   {{0x6aa96d57,0x3f87007c,0x2eed033b,0x75280035}},	//   tief, änud_, _tief_, ądzi,
   {{0xca850036,0xa92532ff,0x00000000,0x00000000}},	//   ргий, адил, --, --,
   {{0x661600fb,0x6aa96d58,0x6e3b0027,0x8e840037}},	//   _reyk, rief, _icub, _القه,
   {{0xa3b51282,0x28cf0066,0x6d5b0027,0x9c7c0b1a}},	//   जपा_, _सीखि, _isua, _biču,
   {{0xe7390202,0x81ce0033,0x2b4c0069,0xf7453175}},	//   њем_, ষেপ_, _gpdc_, шено,
   {{0x645e6d59,0x6b7a00c2,0xd5e612da,0xd83803c9}},	//   _sapi, _ברענ, ижни, diču_,
   {{0x2d9d070b,0x80ba04cc,0x15ba005f,0xc8b4042c}},	//   nzwe_, ्वमे, тыны_, _گلوک,
   {{0x37e5051a,0x2aba00ea,0x00000000,0x00000000}},	//   _колг, mība_, --, --,
   {{0x638329af,0xc7a244a0,0x2aba0029,0x2b4c028b}},	//   огра, _мишк, lība_, _xpdc_,
   {{0x02060fe7,0x645e000e,0x98a400d8,0x60280029}},	//   рзан, _wapi, rumą_, zīmē,
   {{0x201a38b2,0xe1f70823,0x2aba0029,0x66d61df9}},	// [6f00] tapi_, ргу_, nība_, láko,
   {{0x649000ab,0x6e3b002a,0xa49400f8,0x60264ee3}},	//   _käim, _acub, _ایست, рджа,
   {{0xb4c40bc1,0x41d50299,0x32460c7e,0x66d600a0}},	//   ौती_, _दरअस, _кенг, náko,
   {{0x201a6d5a,0xdfcf004f,0xcd06692a,0xfe72026e}},	//   sapi_, ذين_, ачки, غدا_,
   {{0xa2c300b4,0x201a00b9,0x00000000,0x00000000}},	//   लवर्, papi_, --, --,
   {{0x2aba00ea,0xc7b8011c,0xd0076d5b,0x9b261fff}},	//   dība_, lađe_, _вере_, афил,
   {{0x20186d5c,0x92d80083,0x66dd006c,0x69d96251}},	//   _ieri_, াদী_, léke, _azwe,
   {{0xe8df00e8,0x64901246,0x20186d5d,0xc7b8011c}},	//   ước_, _säil, _heri_, nađe_,
   {{0x5ecc0033,0x69d900fe,0xed570f8f,0x7c3a0185}},	//   িষদে, _czwe, _кот_, _tctr,
   {{0x20c60324,0x7e606d5e,0x2b4c023c,0x47341d30}},	//   वविध, _hamp, _tpdc_, бнос,
   {{0xb8fd0755,0x501b0052,0x4ff70070,0xcf930070}},	//   _थी_, כויו, יזיע_, ַטש_,
   {{0x7e604667,0x4438001e,0x7bda4d98,0x212000bf}},	//   _jamp, egr_, _iztu, ksih_,
   {{0x7e602bab,0x2aba0029,0x6d426d5f,0xaae50957}},	//   _mamp, cība_, ntoa, _اسلو,
   {{0x442d02c9,0x20186d60,0xd8380254,0x7e606d61}},	//   ße_, _neri_, tiču_, _lamp,
   {{0x93883ef3,0xd7ef294d,0x61ec0095,0xa87b0070}},	//   аста_, _фу_, ənlə, _באגר,
   {{0x7e6061f5,0x442d6d62,0x20186d63,0x6d4201b7}},	//   _namp, şe_, _aeri_, ktoa,
   {{0x20186d64,0x661d0e45,0x7e626d65,0x51f8021f}},	// [6f10] _beri_, mask, ddop, рную_,
   {{0xdb1a0248,0x6d426d66,0x29060054,0x7e600159}},	//   _exté, dtoa, _mtoa_, _aamp,
   {{0x201801d2,0x46bb6d67,0x64556d68,0xa857011d}},	//   _deri_, _उदाह, mezi, שיבה_,
   {{0x64556d69,0x44fd0019,0x2ef811cc,0x201831ff}},	//   lezi, _kì_, _durf_, _eeri_,
   {{0x7e606d6a,0x63bb06d3,0xc27a0070,0x7bda0065}},	//   _damp, ğunu, _ערשי, _aztu,
   {{0x64556d6b,0x20186d6c,0xaf3703c5,0x44fd0023}},	//   nezi, _geri_, _پرست, _mì_,
   {{0x1fe500c8,0x7e600090,0x20015ab9,0x44fd0822}},	//   _প্রস, _famp, mchi_, _lì_,
   {{0x6d5b01a9,0x7e6016ab,0x661d6d6d,0x291f6d6e}},	//   _tsua, _gamp, jask, tsua_,
   {{0x6d5b325c,0x20180463,0x1c0b0f9c,0xdea40919}},	//   _usua, _yeri_, _स्थल_, _بینی,
   {{0x20016d6f,0x7e6050bd,0x291f00d7,0x32190097}},	//   nchi_, _zamp, rsua_, _lesy_,
   {{0x7e6035a7,0x661d6d70,0x66dd00b5,0x46ea0fc5}},	//   _yamp, fask, zéke, лдон_,
   {{0xa50a2788,0x661d4f65,0x7e605bb0,0x44fd0019}},	//   лема_, gask, _xamp, _bì_,
   {{0x7529042a,0x64550382,0xddcb0035,0xc7b80009}},	//   šezn, fezi, legł, vađe_,
   {{0x2a7f02f6,0x66dd006c,0x64556d71,0x44fd6d72}},	//   ljub_, véke, gezi, _dì_,
   {{0x66e66d73,0x661d6d74,0x44386191,0x64a30ee6}},	//   _лока, bask, rgr_, чара,
   {{0x66dd0332,0x27230092,0x20186d75,0x661d00d7}},	//   téke, mın_, _seri_, cask,
   {{0x7e6000e0,0x44fd00e8,0x2ef86d76,0x27230092}},	// [6f20] _ramp, _gì_, _surf_, lın_,
   {{0x2120124f,0x645502fb,0x7e604a68,0x7e100567}},	//   rsih_, cezi, _samp, ार्ग_,
   {{0x27236d77,0x2a7f046a,0x7e60470b,0x00000000}},	//   nın_, kjub_, _pamp, --,
   {{0xc3330052,0xb4db0310,0x7e6203d0,0x75240121}},	//   _צור_, ntàn, udop, _kviz,
   {{0xf767040d,0x7bda004e,0x763b02b5,0x20186d78}},	//   _کا_, _sztu, רענג, _teri_,
   {{0x200101d3,0x40960082,0x272306d3,0x2ef81c9e}},	//   cchi_, _السر, kın_, _turf_,
   {{0x62863828,0xa3e00953,0x6d426d79,0x660400fe}},	//   _koko, _तरफ_, stoa, _ofik,
   {{0x2723036a,0x628601d7,0x6d425e3a,0x68f90103}},	//   dın_, _joko, ptoa, _buwd,
   {{0x62866d7a,0xdee30086,0x64556d7b,0x67230523}},	//   _moko, _хоти, yezi, _avnj,
   {{0x62866d7c,0x661d2bab,0x415b02b5,0x09070033}},	//   _loko, wask, נדיג, _শিশু_,
   {{0x64556d7d,0x44fd02fb,0x661d53ec,0x7bda0029}},	//   vezi, _sì_, task, _uztu,
   {{0x62860044,0x64556d7e,0x1ddc046c,0xdddb007e}},	//   _noko, wezi, _बरात, _houš,
   {{0x64556d7f,0xa3e60026,0xf1bf0300,0x66dd00b5}},	//   tezi, बेस_, _adán_, tékb,
   {{0x44fd00e8,0x661d6d80,0x7afa6d81,0x2723045e}},	//   _vì_, sask, _kutt, bın_,
   {{0x64556d82,0x62866d83,0x7afa6d84,0xf8bf00f7}},	//   rezi, _boko, _jutt, éée_,
   {{0x62866d85,0x7afa342a,0x64556d86,0x44fd00e2}},	//   _coko, _mutt, sezi, _tì_,
   {{0x62860865,0x64556d87,0x7afa6d88,0xe1f00037}},	// [6f30] _doko, pezi, _lutt, فسك_,
   {{0x656d22a1,0x26cb6d89,0x64900421,0x64550055}},	//   _irah, loco_, _näih, qezi,
   {{0x7afa39df,0x200101d3,0x62866d8a,0x75242190}},	//   _nutt, rchi_, _foko, _zviz,
   {{0x20016d8b,0x656d00da,0x7c286d8c,0x26cb6d8d}},	//   schi_, _krah, _addr, noco_,
   {{0x27230092,0x823a00c2,0x764d6d8e,0xa2b80d34}},	//   zın_, _דערצ, _mbay, ्कर्,
   {{0x27230d6f,0xa3bd02cb,0x7afa6d8f,0x0f1b042c}},	//   yın_, _अशा_, _butt, _مغرب_,
   {{0xeb996d90,0xddc9024e,0x27230095,0x543c02b5}},	//   рий_, _dneš, xın_, טעגא,
   {{0x7afa6d91,0x6490007c,0x656d011c,0x68f90159}},	//   _dutt, _päik, _orah, _puwd,
   {{0xe8f6342d,0xc9850037,0xdddb023a,0x6e296d92}},	//   олы_, تشغي, _fouš, _ideb,
   {{0x3eaf6d93,0x7d040ae0,0x27230d6f,0x764d203d}},	//   ligt_, ģist, tın_, _abay,
   {{0xa3a90939,0x75246d94,0x656d6d95,0x7afa03d0}},	//   _खेल_, _sviz, _arah, _gutt,
   {{0x27230eab,0x656d0f5d,0x395d006d,0x7d090009}},	//   rın_, _brah, _tsws_, _ktes,
   {{0x62860038,0x272306d0,0xdce00043,0xb4db0443}},	//   _roko, sın_, _urmă, rtàn,
   {{0x62866d96,0x656d6d97,0xd7fb6d98,0x272301d6}},	//   _soko, _drah, _суд_, pın_,
   {{0x62866d99,0x6e290803,0xaca30019,0xe73900af}},	//   _poko, _odeb, _huỳn, _тей_,
   {{0x7d096d9a,0xb5fb6d9b,0x28dd2b22,0x6e296d9c}},	//   _otes, ndál, _नीति, _ndeb,
   {{0x3eaf6d9d,0x61432f40,0xe29701fd,0xe8001e82}},	// [6f40] digt_, мета, цат_, लुका_,
   {{0x2ed205f8,0x62866d9e,0xc7b800cd,0x6fcb00ab}},	//   तत्त, _woko, lađa_, _तुहू,
   {{0x62866d9f,0x6e290176,0xfcaa05f5,0x00000000}},	//   _toko, _bdeb, یاتو_, --,
   {{0x82360357,0x62866da0,0x7afa6da1,0xddc90009}},	//   _بردا, _uoko, _rutt, _sneš,
   {{0x7d091702,0xdce9035f,0xdddb0355,0x649000c3}},	//   _ctes, _greċ, _pouš, _päih,
   {{0x6e2901d6,0x7afa34b2,0xbb2a0043,0xc7b800cd}},	//   _edeb, _putt, ацие_, hađa_,
   {{0x46ca1cce,0x7d090562,0xddc902a7,0x7c2803d0}},	//   रवाह, _etes, _vneš, _vddr,
   {{0x7d0901f4,0xee370208,0x2c0a0033,0x80ba0b35}},	//   _ftes, _мнс_, রণেই_, ्ववे,
   {{0x26cb50a8,0x7bc10168,0x9c7c0359,0x2c0b07df}},	//   voco_, _exlu, _chčc, _स्वं_,
   {{0x7afa0021,0xb4c409a3,0xa49b02e9,0x656d01f4}},	//   _tutt, एको_, npòt, _rrah,
   {{0x7afa0086,0x656d00e0,0xe75801e0,0x00000000}},	//   _uutt, _srah, щині_, --,
   {{0x656d6da2,0xc7b803fd,0x56940ebb,0x59e2018d}},	//   _prah, gađa_, дают, _परपर,
   {{0xfaf80029,0x7ae26da3,0x19b60037,0x00000000}},	//   _trīs_, _ihot, _بحاج, --,
   {{0xfbd1006c,0x656d0097,0x14cb00c3,0xb4db0176}},	//   _آتے_, _vrah, рыми_, ctàl,
   {{0x13686da4,0x7ae20703,0x2249027d,0xc7b8011c}},	//   ошти_, _khot, tfak_, bađa_,
   {{0x656d6da5,0x764d6da6,0xdce9003c,0x00000000}},	//   _trah, _ubay, _preċ, --,
   {{0x7ae209c3,0x656d0af0,0xef2f00e2,0x7ce401f7}},	// [6f50] _mhot, _urah, _đựoc_, mòrf,
   {{0x7ae26da7,0x807822aa,0xb5fb00b5,0xe4d901cb}},	//   _lhot, обус_, zdál, _دوخت_,
   {{0x7d096da8,0x3eaf6da9,0xa7fc01fb,0xb4b7021a}},	//   _stes, tigt_, ydın, चची_,
   {{0xe0df02d0,0x92580421,0x7f45024b,0x82f80647}},	//   _apòt_, _дают_, rthq, _گریز_,
   {{0x41e700ef,0x3eaf5552,0x427a0d85,0x3af1023a}},	//   _фіна, rigt_, _הארג, _dšpl_,
   {{0x3eaf02a5,0x4c8400d8,0x7ae201d7,0xdb1a01ef}},	//   sigt_, млів, _ahot, _extí,
   {{0x7ae26daa,0x00000000,0x00000000,0x00000000}},	//   _bhot, --, --, --,
   {{0x7ae26dab,0x6e296dac,0xed1600fd,0x2ea700fd}},	//   _chot, _udeb, _کہوں_, _بھئی_,
   {{0xf2d402b5,0xaca30019,0x7d091d2f,0x7ae26dad}},	//   ועק_, _quỳn, _utes, _dhot,
   {{0x48790086,0xdce96dae,0x290d5688,0x7ae2081b}},	//   ссия_, _kreč, rpea_, _ehot,
   {{0x7ae2026e,0x6490007c,0x69dd07b5,0xa8220594}},	//   _fhot, _käiv, _परवी, رکون,
   {{0x7ae26daf,0x98ad02c6,0xa7fc05f9,0x869a0370}},	//   _ghot, mreč_, ldıl, стот_,
   {{0xc7b80129,0x9f5801e0,0x18691783,0x00000000}},	//   rađa_, _ifrå_, _гали_, --,
   {{0x3ebf00cb,0x7ae20187,0x66dd0220,0xa7fc10b1}},	//   _ljut_, _zhot, réka, ndıl,
   {{0xa3e60084,0xccf20122,0xe29603e6,0xb4db01f7}},	//   बें_, תכם_, праќ, ctàm,
   {{0x7afe6db0,0x7ae96db1,0xd5ad006c,0x6abb6db2}},	//   ípti, nmet, اہی_, nnuf,
   {{0x27e20035,0x26d20027,0x7ae96db3,0x00000000}},	// [6f60] ękne_, _ikyo_, imet, --,
   {{0x3ead6db4,0xd12f096a,0x7ae96db5,0x3ebf45a7}},	//   _amet_, امل_, hmet, _ajut_,
   {{0x7ae96db6,0xd4c50c26,0x3ebf0024,0xe3b210ad}},	//   kmet, _تغيي, _bjut_, _سرد_,
   {{0xde031283,0xdfcf0c26,0x7ae96db7,0xdce900f4}},	//   епци, ديم_, jmet, _dreč,
   {{0x7ae96db8,0x2cac028b,0x00000000,0x00000000}},	//   dmet, _pmdd_, --, --,
   {{0x7ae96db9,0xdca36dba,0x3ead6dbb,0x2bb80026}},	//   emet, начи, _emet_, इपला,
   {{0x7ae26dbc,0xe81f0067,0x7ae96722,0x00000000}},	//   _phot, _मज़ा_, fmet, --,
   {{0x9c7c009e,0x00000000,0x00000000,0x00000000}},	//   _dhča, --, --, --,
   {{0x81ce00c8,0x2242028b,0x3ea76dbd,0xada312a2}},	//   ষের_, _mckk_, ënte_, _затл,
   {{0x26c301cc,0x27f80c61,0x2db702b5,0x7ae96dbe}},	//   čkom_, ørn_, _זלמן_, amet,
   {{0x7ae201d2,0x7ae96dbf,0x16356dc0,0x6296022e}},	//   _thot, bmet, меня, kkyo,
   {{0x7ae96dc1,0xba17004f,0xeb970d85,0xfaa3010b}},	//   cmet, _فيما_, _מדבר_, _пахо,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d20273,0x3ae101ba,0x81e20033,0x6fbe0099}},	//   _ekyo_, rópe_, দশা_, ्थां,
   {{0x4ab0065a,0x67d300ef,0x2a6600be,0x6e22023c}},	//   _जगाव, _пошу, _kaob_, kaob,
   {{0xd7bb0122,0x628401f4,0x354700af,0x66060036}},	//   _לצור, gjio, _ехов, cckk,
   {{0x51876dc2,0xdce9108a,0xdceb6dc3,0x66dd00b5}},	// [6f70] чува, _sreč, _žičk, léko,
   {{0x7ae96dc4,0xdce96dc5,0x3ead1f2c,0x66df010b}},	//   zmet, _preč, _smet_, _rūky,
   {{0x44236dc6,0x64900d36,0x7ae96dc7,0x661f0031}},	//   maj_, _päiv, ymet, _keqk,
   {{0xdce96dc8,0x02a70ddc,0xa3bc0099,0x00000000}},	//   _vreč, _хром, ेअर_, --,
   {{0x3946006d,0x629d027a,0xdd94010b,0x00000000}},	//   _nqos_, _ilso, нацы, --,
   {{0x44236dc6,0xdce900d8,0x66dd00b8,0x2c6d00b5}},	//   naj_, _treč, kéko, ködő_,
   {{0x26c301cc,0x66dd006c,0x3ebf0dc9,0xa7fc05f9}},	//   čkoj_, jéko, _tjut_, rdıl,
   {{0x44230d4b,0xb3aa0083,0x68e301f4,0xa3e00066}},	//   haj_, _খুঁজ, _shnd, _तरस_,
   {{0x44236dc9,0x6efa01c0,0x6abb3e48,0x6490007c}},	//   kaj_, _vůbe, rnuf, _käit,
   {{0xb0bf1604,0x20bf012f,0x290b0029,0x7d1b0027}},	//   ्विग, ्विध, īca_, _iwus,
   {{0xb90466c3,0x44236dca,0x229c00fb,0x3f47018d}},	//   _भी_, daj_, _líka_, nõu_,
   {{0x7c236dcb,0x7a360225,0x00000000,0x00000000}},	//   lanr, rütü, --, --,
   {{0xa3e01033,0x20bf0d00,0x95830086,0x44236dcc}},	//   _तरह_, ्वाध, вляе, faj_,
   {{0x64902efa,0x629d0120,0x6e220926,0xd84e0023}},	//   _näit, _also, zaob, _họng_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a3f6dcd,0x7c2302c2,0xaadd01c0,0x26c0002f}},	//   ngup_, hanr, मतिक, _ujio_,
   {{0x44236dce,0x0563002d,0x76446dcf,0x00000000}},	// [6f80] baj_, _авын, _iciy, --,
   {{0x44230af1,0x65645a0c,0x92be0083,0x917a0023}},	//   caj_, _isih, ইতে_, _cấp_,
   {{0x645c6dd0,0xb4da0035,0xdfcf0037,0xd47b00a5}},	//   meri, ़ती_, ليك_, _ואיל,
   {{0x645c6dd1,0x7bdc0211,0x00000000,0x00000000}},	//   leri, _ùrui, --, --,
   {{0xdca60c98,0xfee9004f,0x6e2209c3,0xcce600ce}},	//   мади, أعلى_, raob, وستي,
   {{0x7c2301a2,0x2a660009,0x28dd00b4,0x649000be}},	//   ganr, _saob_, _नीलि, _täiu,
   {{0xdfd20372,0x645c6dd2,0xd84e055c,0x00000000}},	//   _شير_, ieri, _bọng_, --,
   {{0x44232ce5,0x44446dd3,0xa7fc06d3,0x2ec91d25}},	//   zaj_, _lc_, rdım, िकृत,
   {{0xa8020723,0x44236dd4,0x3160011e,0xdd8f0e3a}},	//   _çıka, yaj_, nwiz_, _پول_,
   {{0x6e206dd5,0x66dd0332,0x7c236dd6,0xdb1a00d5}},	//   _hemb, téko, canr, _extá,
   {{0x44236dd7,0x6e200d1c,0x2c1425d8,0x2a666dd8}},	//   vaj_, _kemb, _न्यू_, _taob_,
   {{0x44441973,0x6e2054d2,0x7d00000e,0x44236dd9}},	//   _ac_, _jemb, _kums, waj_,
   {{0x44236dda,0x649000c3,0x645c5f7b,0xa7fc027d}},	//   taj_, _näis, feri, ndık,
   {{0x6e203021,0x7d006ddb,0x3a2412ef,0x673a0031}},	//   _lemb, _mums, lamp_, putj,
   {{0x44236ddc,0x7d006ddd,0x6564145d,0x00000000}},	//   raj_, _lums, _esih, --,
   {{0x44236dde,0x59e2018d,0x6e2000d1,0x6490081b}},	//   saj_, _परार, _nemb, _säit,
   {{0x7c230987,0x44236ddf,0x7d000b3e,0x765d6de0}},	// [6f90] yanr, paj_, _nums, mesy,
   {{0xfe7000d1,0x44440cdb,0x44230055,0x6f1c0090}},	//   یدن_, _gc_, qaj_, _bwrc,
   {{0x64456de1,0x3a246de2,0x9f040125,0x64900f67}},	//   _ichi, kamp_, نولو, _väit,
   {{0x6e20128f,0x765d001e,0x7d005056,0x2ec90099}},	//   _cemb, nesy, _bums, िकेत,
   {{0x6490007c,0x61ad0033,0xb5fb0037,0x44210088}},	//   _täit, _কুরআ, meád, _keh_,
   {{0xf41d0083,0x442100e0,0x6490127d,0x6e200051}},	//   _তাঁর_, _jeh_, _häir, _eemb,
   {{0x44216de3,0xa6d60033,0x6445002f,0x66c8027d}},	//   _meh_, _সংঘট, _mchi, lıke,
   {{0x44216de4,0x32096de5,0x6e201034,0xc3340122}},	//   _leh_, ncay_, _gemb, דוק_,
   {{0x64450043,0xd84e01a5,0x645c6de6,0x765d6de7}},	//   _ochi, _vọng_, yeri, desy,
   {{0x644519c6,0x645c6de8,0x4421331f,0xe7390274}},	//   _nchi, xeri, _neh_, пео_,
   {{0x44446de9,0x765d4d42,0x645c6dea,0x7e693081}},	//   _rc_, fesy, veri, _kaep,
   {{0x64456deb,0xeb960779,0x645c6dec,0x3a246ded}},	//   _achi, _אדער_, weri, camp_,
   {{0x44216dee,0x2d4927c2,0x753d006c,0x27e20035}},	//   _beh_, núe_, gusz, ękna_,
   {{0xb4da0299,0x4444643c,0x64906def,0x64450036}},	//   ़ते_, _qc_, _räis, _cchi,
   {{0x44443e26,0x645c23f4,0xfddc02e4,0x44216df0}},	//   _vc_, reri, _बर्फ, _deh_,
   {{0x645c6df1,0x64450012,0x44446df2,0x212900d7}},	//   seri, _echi, _wc_, fsah_,
   {{0x6e206df3,0x65642d69,0x00000000,0x00000000}},	// [6fa0] _remb, _usih, --, --,
   {{0x6e206df4,0x7d006df5,0x7e7b6df6,0x69d96df7}},	//   _semb, _rums, _anup, _mywe,
   {{0x6e20203f,0x7d006df8,0x6490081b,0x7e69021d}},	//   _pemb, _sums, _wäis, _baep,
   {{0x1ea90c74,0x6490007c,0x2129028b,0x291d0159}},	//   واني_, _täis, bsah_, _owwa_,
   {{0x44216df9,0x3a243a29,0x69d96dfa,0x6e206dfb}},	//   _yeh_, vamp_, _nywe, _vemb,
   {{0x765d004e,0x7c2101f7,0xb5fb6dfc,0xfb660274}},	//   zesy, _celr, rdái, ењим,
   {{0x6e2006d4,0x6d4b0d35,0x00000000,0x00000000}},	//   _temb, atga, --, --,
   {{0x2d4901dd,0x7d006dfd,0x69d90298,0xfcaa0220}},	//   búe_, _tums, _bywe, _کارو_,
   {{0x3a246dfe,0x2d4901ef,0xbea304d9,0x7c21526f}},	//   ramp_, cúe_, _сатк, _felr,
   {{0x69d90297,0x3ae16dff,0xb5fb6e00,0x7c210223}},	//   _dywe, rópa_, ndáv, _gelr,
   {{0x44216d56,0x59e20b4d,0x21290187,0x765d03d0}},	//   _reh_, _परवर, zsah_, tesy,
   {{0x64456e01,0x6f031ec0,0x44216e02,0xb4db01f7}},	//   _schi, ínci, _seh_, ntàv,
   {{0x765d6e03,0x6acc021a,0xba170079,0x66dd00fd}},	//   resy, ावीर, _أيها_, lékk,
   {{0xb4bd00ab,0x753d004e,0xb86600fd,0x765d6e04}},	//   ेके_, rusz, _ساتو, sesy,
   {{0x765d6976,0x00000000,0x00000000,0x00000000}},	//   pesy, --, --, --,
   {{0x44216e05,0x753d2130,0x5575083e,0x52bd00b4}},	//   _weh_, pusz, _агит, ्केस,
   {{0x44216e06,0x25b70332,0x60f915eb,0x660d07e3}},	// [6fb0] _teh_, _سندھ_, дная_, _ifak,
   {{0x7e6900b9,0x644557b4,0x2aba00ea,0x2ec9170c}},	//   _saep, _uchi, mību_, िक्त,
   {{0x2aba00ea,0x9c7c0107,0x7e690c6f,0x00000000}},	//   lību_, _chčm, _paep, --,
   {{0x2d490391,0x6d4b6e07,0xa2c201c0,0xb5fb01ef}},	//   túe_, ttga, रचण्, meáb,
   {{0x41e4005f,0x2aba0029,0xb5fb01ef,0x8d6500c3}},	//   _біра, nību_, leáb, твле,
   {{0x01360122,0x6d4b050b,0x7bda0a8a,0x2d490042}},	//   _ברשת_, rtga, _bytu, rúe_,
   {{0x7bda6e08,0x6d4b6e09,0x2d49043f,0x4c920202}},	//   _cytu, stga, súe_, ријс,
   {{0x6d4b0bf7,0x6f090333,0x628f0107,0xb5fb006c}},	//   ptga, _čech, _joco, ldáu,
   {{0xfc330416,0x628f5702,0xa9220409,0xdce90139}},	//   _محض_, _moco, адыл, _creă,
   {{0x5ba76e0a,0xb4bd09a3,0x660d0a21,0x2aba00ea}},	//   _през, ेको_, _afak, dību_,
   {{0x7bda00e9,0x752d06c4,0xddc200ea,0x7af9016e}},	//   _gytu, _avaz, mdoš, _tiwt,
   {{0x628f6e0b,0x96966444,0xe1ff0023,0xc4c900a5}},	//   _noco, трош, _ngó_, _וג_,
   {{0xd945135d,0x05636e0c,0xb5fb0097,0xae2207b5}},	//   _рели, авян, zdáv, मरतन_,
   {{0x2a6d001e,0xd1320ef2,0x28f8002d,0xf77000d1}},	//   ldeb_, یمز_, _зечь_, _گاه_,
   {{0x394d6e0d,0x752d6e0e,0x00000000,0x00000000}},	//   ltes_, _evaz, --, --,
   {{0x628f6e0f,0x2a6d001e,0xf65f02e9,0x394d59c0}},	//   _coco, ndeb_, ceæ_, otes_,
   {{0x394d03d0,0x41270cac,0x2aba0029,0x752d0409}},	// [6fc0] ntes_, кото_, cību_, _gvaz,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x649b168d,0x394d6e10,0x3f9c031d,0x26c341c8}},	//   _חסיד, htes_, ávu_, čkov_,
   {{0x394d058d,0x65760031,0x7bda1640,0x38a000f1}},	//   ktes_, _kryh, _rytu, _mòra_,
   {{0x7bda004e,0x394d6e11,0xb4db01f7,0x00000000}},	//   _sytu, jtes_, rtàv, --,
   {{0x61e66e12,0xdd9300d8,0xb5fb0037,0xdbdc008d}},	//   _izkl, рашы, leác, _báði,
   {{0x2d800012,0x2aba00ea,0x69dd02b1,0x00000000}},	//   ţie_, zību_, üsen, --,
   {{0x394d6e13,0xdee6395b,0xdce20124,0x628f0310}},	//   ftes_, _роби, kvoć, _xoco,
   {{0x394d6e14,0x3ea60159,0xd83a1023,0x00000000}},	//   gtes_, mhot_, мэн_, --,
   {{0x7bda004e,0xa78600bf,0x660d0009,0xc7b8011c}},	//   _tytu, نشجو, _sfak, lađi_,
   {{0x69c4010b,0x752d00b8,0x394d6e15,0x56951d30}},	//   _žied, _svaz, ates_, гант,
   {{0xc7b803fd,0x394d6e16,0x2aba0029,0xb21b0b3e}},	//   nađi_, btes_, tību_, _knæe,
   {{0x394d0955,0x98c6220a,0xd94316b8,0x855800b5}},	//   ctes_, _искл, _вечи, نیٹر_,
   {{0x09e30f94,0x2aba0029,0x65760090,0x00000000}},	//   _точн, rību_, _dryh, --,
   {{0x628f6e17,0x2aba0029,0x6576011e,0x3ea6022e}},	//   _poco, sību_, _eryh, khot_,
   {{0x660d6e18,0x00000000,0x00000000,0x00000000}},	//   _ufak, --, --, --,
   {{0x752d00d5,0x6576008c,0xb5fb0042,0x3ea601cb}},	// [6fd0] _uvaz, _gryh, seáb, dhot_,
   {{0x26c3024e,0x6aa200e9,0x70bf00b4,0x628f00e0}},	//   čkou_, _llof, ्वेल, _woco,
   {{0x628f0519,0x25b7006c,0x6aa21366,0x66c81008}},	//   _toco, _سنگھ_, _olof, lıka,
   {{0xdbdc0093,0x394d6e19,0x44336e1a,0x00000000}},	//   _ráði, ytes_, _hdx_, --,
   {{0x51846e1b,0x394d6e1c,0x2a6d01e8,0xfe700773}},	//   _кура, xtes_, vdeb_, تدل_,
   {{0x9f050bdf,0xb5fb006c,0xed590207,0x00000000}},	//   _موسو, ldás, _vpž_, --,
   {{0xddc26e1d,0x6aa2021e,0xe0d2016b,0x00000000}},	//   rdoš, _blof, _הײם_, --,
   {{0x394d6e1e,0x3ea632ef,0x6aa2099e,0xb5fb00b5}},	//   ttes_, chot_, _clof, ndás,
   {{0x6e941a33,0x394d6e1f,0x2a6d001e,0xe8f90336}},	//   _титу, utes_, rdeb_, нли_,
   {{0xddc96e20,0x6aa26e21,0x00000000,0x00000000}},	//   _knež, _elof, --, --,
   {{0x394d6e22,0x5b150cac,0x6fb8046c,0x6aa200f6}},	//   stes_, _смет, ्पयू, _flof,
   {{0x394d6e23,0x44330079,0x6aa26e24,0x5ba400af}},	//   ptes_, _adx_, _glof, _труз,
   {{0x673a0fdb,0xdddb007e,0x00000000,0x00000000}},	//   artj, _louž, --, --,
   {{0xf7450384,0x65760173,0x3f73012e,0x00000000}},	//   _беко, _vryh, _oću_, --,
   {{0x42560896,0x03a31e56,0x61e60035,0x0fbe0033}},	//   лтат, биро, _szkl, _অর্ধ,
   {{0xb3d20a90,0xc61e0083,0x86466e25,0xb7da016b}},	//   _दुःख, _থাকা_, _сниж, _אקצי,
   {{0x6d5b006f,0x91ee02b4,0xddc9007e,0x60ea1b96}},	// [6fe0] _npua, चेंज_, _anež, емам_,
   {{0xb4660086,0xa91b05e7,0x61e60116,0x00000000}},	//   _скол, पीएफ_, _vzkl, --,
   {{0xb4c00429,0xee3a6e26,0xe29a027a,0xef1a01d3}},	//   ंची_, ене_, _зан_, хме_,
   {{0x442a6e27,0xb4db12c3,0xcd2a00c3,0x764630e8}},	//   lab_, gràf, ежде_, ngky,
   {{0x61e61715,0xf65300a5,0x3ea63491,0xbea30200}},	//   _uzkl, מצא_, rhot_, љачк,
   {{0x442a6e28,0x4095192f,0x6acc018d,0x6aa2016e}},	//   nab_, _крст, ाव्र, _slof,
   {{0x8fa66e29,0xb5fb6e2a,0x6aa21472,0x66c80a21}},	//   _саве, ndár, _plof, zıka,
   {{0x442a3ca0,0xbea310cc,0xb4db0443,0xd91a1bca}},	//   hab_, _ласк, ntàr, ньо_,
   {{0x6e935f8a,0x442a6e2b,0x5e93004f,0x38a001da}},	//   _القا, kab_, _القط, _dòrn_,
   {{0x442a6e2c,0x38a0009e,0x787400fd,0x00000000}},	//   jab_, _eòrn_, küvő, --,
   {{0xda6f6e2d,0x442a6e2e,0x443301a2,0xd7f7021f}},	//   _ля_, dab_, _rdx_, лую_,
   {{0x7c2a6e2f,0x59af0006,0x7e626e30,0x00000000}},	//   lafr, _जेकर, neop, --,
   {{0x442a6e31,0xe815021a,0x95c80aec,0x9c7c023a}},	//   fab_, _द्वा_, гура_, _ahči,
   {{0x442a6e32,0xb4df0efa,0x44250037,0x7c2a6e33}},	//   gab_, तते_, úl_, nafr,
   {{0x3cfe00d7,0x7e626e34,0x38a00211,0x389b016b}},	//   _mitv_, keop, _hòro_, _איגנ,
   {{0x78ba0888,0xadf60299,0x2906002f,0x52150deb}},	//   litv, ेशान_, _kuoa_, рдат,
   {{0x442a1581,0x661d01ef,0xddc93d86,0x44332a18}},	// [6ff0] bab_, mbsk, _snež, _tdx_,
   {{0xdddb114d,0x442a2e60,0x78ba008b,0x9c7c009e}},	//   _použ, cab_, nitv, _fhči,
   {{0x7ced1d83,0x00d80647,0x00000000,0x00000000}},	//   lúrg, ابقت_, --, --,
   {{0xdce90a78,0x644715f2,0x7e622cdc,0xb4db0310}},	//   _kreć, lgji, geop, ctàr,
   {{0x80bf0b52,0x070b20d8,0xc7b80009,0xa0240033}},	//   ্তব্, _संभव_, mađu_, _পারব_,
   {{0x64476159,0x78ba008b,0xa3bc060a,0xddc90024}},	//   ngji, jitv, _अधम_, _ineż,
   {{0xd4980122,0x78ba02c6,0xdb210644,0x25dc07b5}},	//   רכות_, ditv, _ötür, _गुनी_,
   {{0xdd95004b,0x6d4208dd,0xc7b8011c,0x00000000}},	//   _кабы, buoa, nađu_, --,
   {{0x442a6e35,0x6d5b0c86,0xddc90069,0x00000000}},	//   yab_, _upua, _jneż, --,
   {{0xc6250083,0x6b7c0160,0xb4cf00b8,0x661d02b1}},	//   _ভাষা_, _băgă, षको_, ebsk,
   {{0x442a6e36,0x29020093,0x26c9021d,0x37e5081b}},	//   vab_, íkar_, _bjao_, ронг,
   {{0xfd4c00e8,0x442a0452,0x6e2b0dc3,0x6440010b}},	//   _nhiề, wab_, nagb, ėmim,
   {{0x442a397a,0x5e560070,0x693303fc,0x64470055}},	//   tab_, סישע_, _اکبر, fgji,
   {{0xb4c00429,0x49b82087,0x6b7c0395,0x3dcd0024}},	//   ंचे_, _حامد_, _făgă, _mxew_,
   {{0x6e2b0008,0x66e63296,0x22590168,0x6b7c0160}},	//   kagb, _кока, _bbsk_, _găgă,
   {{0x442a6e37,0xfd4c01a5,0xf1aa0118,0x9f580079}},	//   sab_, _chiề, پاره_, _ngrá_,

   {{0x442a142f,0x66040010,0x61466e38,0x22590023}},	// [7000] pab_, _igik, реза, _dbsk_,
   {{0x442a6e39,0xf0a76a63,0x7e62053e,0x130a0421}},	//   qab_, акул_, weop, _иной_,
   {{0x09e20c67,0xa7fc0d6f,0x1f6602c4,0x643b0397}},	//   _पर्य, ldır, ркем, _בעינ,
   {{0x2eed27bf,0x75246e3a,0x61460171,0x175602b5}},	//   _chef_, _kwiz, _кема, יסער_,
   {{0xa7fc0dac,0x7e626e3b,0x78ba0987,0x7c2a6e3c}},	//   ndır, reop, yitv, tafr,
   {{0x752408bd,0xa0a60409,0x1db7018d,0xb4db0176}},	//   _mwiz, _тагд, _अधरत, rràg,
   {{0xf7670796,0xfaa614d0,0x78ba02c6,0x6e2b0159}},	//   _با_, ишин, vitv, bagb,
   {{0xf1bf004f,0x66046e3d,0xb5fb6e3e,0xa3e90354}},	//   _meán_, _ngik, deán, _बरस_,
   {{0x4c862447,0x78ba6e3f,0x75240359,0x4efb024b}},	//   _клав, titv, _nwiz, _יהלו,
   {{0x66041642,0x26c90207,0x00000000,0x00000000}},	//   _agik, _sjao_, --, --,
   {{0xdce901cc,0x78ba108a,0x6f006e40,0xb09b0070}},	//   _sreć, ritv, _kimc, דייר,
   {{0x7ced377e,0x75240010,0x78ba49c3,0x7c282336}},	//   túrg, _bwiz, sitv, _hedr,
   {{0x661d6e41,0x2a64008b,0x09e32123,0x95cb059d}},	//   rbsk, memb_, _доцн, туна_,
   {{0x7c2802dd,0x66c801d6,0xdce90c0a,0x39440029}},	//   _jedr, lıkl, _vreć, mums_,
   {{0x644701d2,0x7c286e42,0xfd4c0019,0x53340573}},	//   rgji, _medr, _phiề, жест,
   {{0xdce901cc,0x26c90054,0xf1bf01ef,0x66c8027d}},	//   _treć, _ujao_, _deán_, nıkl,
   {{0x7c2800e9,0x394400ea,0xe4e701e0,0xc7b800cd}},	// [7010] _oedr, nums_, _вінн, rađu_,
   {{0x7c2847e8,0x656d6e43,0x2eed0031,0x3d0a01d1}},	//   _nedr, _isah, _shef_, ादने_,
   {{0x7fb900f3,0xfd4c0023,0x6e2b6e44,0xddcb00b5}},	//   دهار_, _thiề, tagb, vegő,
   {{0x39440080,0x63ad0029,0xf1d82450,0xdb030187}},	//   kums_, ģinā, _भुवन, jzná,
   {{0x7c284128,0x39440ae0,0xee381958,0x66c8027d}},	//   _bedr, jums_, рні_, dıkl,
   {{0x8d740088,0x394400ea,0x229c0093,0x6e2b1511}},	//   غانا, dums_, _ríki_, sagb,
   {{0x26d96e45,0x6aa95be2,0xe45802b5,0x6e2b300c}},	//   koso_, thef, ייגט_, pagb,
   {{0x26d96e46,0x22496e47,0x6f000392,0x38a900ee}},	//   joso_, ngak_, _gimc, _múre_,
   {{0x26d93207,0x39440029,0x7c283596,0x656d0024}},	//   doso_, gums_, _fedr, _nsah,
   {{0x7c286e48,0x6aa96e49,0x228e00d5,0x752404fb}},	//   _gedr, shef, _dýky_, _rwiz,
   {{0x6e2901e8,0x656d4ed3,0x7d096e4a,0x26d907e5}},	//   _keeb, _asah, _hues, foso_,
   {{0x7d012b6f,0xa7fc0095,0x26d909ca,0xba74004f}},	//   _hils, tdır, goso_, _وانت,
   {{0x6e296e4b,0x2d9d3058,0xb5fb01dd,0xf1bf0037}},	//   _meeb, nywe_, seán, _seán_,
   {{0x7d090083,0xb5fb6e4c,0xa50710e3,0x6e29018d}},	//   _mues, rdáp, сера_, _leeb,
   {{0x7d013a42,0xb5fb0037,0x03a32b60,0x23d207b5}},	//   _mils, leál, пиро, _दुखद,
   {{0x7d090248,0xa2061f14,0x26d91c11,0x22490703}},	//   _oues, спад, coso_, ggak_,
   {{0x7d0900c8,0x644108c0,0xb5fb0037,0x752410a2}},	// [7020] _nues, ólic, neál, _uwiz,
   {{0x7d01026a,0x66c81008,0x22490065,0x00000000}},	//   _nils, zıkl, agak_, --,
   {{0x6e296e4d,0xa3bc0efa,0x00000000,0x00000000}},	//   _beeb, _अधि_, --, --,
   {{0xdfcf38b7,0x6e296e4e,0x5286004f,0x7d016e4f}},	//   رين_, _ceeb, _الحك, _ails,
   {{0x7c281ec5,0x7d0909ab,0x7d016e50,0xc2130d85}},	//   _pedr, _cues, _bils, _מהר_,
   {{0xd47a0070,0x26d90300,0x394400ea,0xd5ed00e2}},	//   ראַל, zoso_, vums_, _hoạ,
   {{0x7d0100ea,0x6f0001a6,0x26d96e51,0x6ab902d7}},	//   _dils, _timc, yoso_, _bmwf,
   {{0x39440080,0x7d090831,0x8f9b00a5,0x39140c98}},	//   tums_, _fues, _גילי, омир,
   {{0x7d016e52,0x0eb90f99,0x26d90384,0xd00f00b5}},	//   _fils, _туры_, voso_, _آلہ_,
   {{0xdb0300f5,0x6e290c21,0x39446e53,0x7d016e54}},	//   szná, _zeeb, rums_, _gils,
   {{0x26d93aa7,0x39446e55,0x7ced0183,0xa7fc013b}},	//   toso_, sums_, búrb, tdıq,
   {{0x6e2901e8,0xcf9300a5,0xb5fb104b,0x368b6e56}},	//   _xeeb, לטת_, beál, усон_,
   {{0xe9ff0019,0xb5fb0079,0xd6d80043,0xceb3025a}},	//   _trạm_, ceál, стэ_, פיש_,
   {{0x26d96e57,0x7ced0176,0x00000000,0x00000000}},	//   soso_, múrc, --, --,
   {{0x26d96e58,0x443f0d6f,0x5695021d,0xd7ef6e59}},	//   poso_, ğu_, _макт, _ху_,
   {{0x764d02d7,0x656d6e5a,0x443f6e5b,0x00000000}},	//   _ucay, _tsah, şu_, --,
   {{0x656d06b3,0x224901a3,0x2bdf057c,0x00000000}},	// [7030] _usah, rgak_, _पुना, --,
   {{0x7d090176,0x6e296e5c,0x51f8037c,0xf70900e2}},	//   _rues, _seeb, сную_, _mần_,
   {{0xf70900e8,0x7d096e5d,0xde19006c,0x6e296096}},	//   _lần_, _sues, لقات_, _peeb,
   {{0x7d090083,0x7d016e5e,0x51876e5f,0x00000000}},	//   _pues, _sils, _луга, --,
   {{0x7d096e60,0x7d010080,0x6e290006,0xfc052f77}},	//   _ques, _pils, _veeb, опло,
   {{0xcc8900bf,0x7d090033,0xa6cf0083,0x6e29018e}},	//   شنبه_, _vues, রতিট, _weeb,
   {{0x6e29006f,0x7d090bf7,0x00000000,0x00000000}},	//   _teeb, _wues, --, --,
   {{0xdce9042a,0x7d096931,0xb5fb0079,0x271700e2}},	//   _iseč, _tues, teál, _hăng_,
   {{0xf70900e8,0x7d010b41,0x7d0900ab,0x00000000}},	//   _cần_, _tils, _uues, --,
   {{0xd90c00d1,0xf70901a5,0xb5fb0405,0xa3e90099}},	//   دیو_, _dần_, reál, _बरं_,
   {{0xe9a80416,0x27170023,0xb5fb0037,0x5ba70804}},	//   لدین_, _măng_, seál, _ураз,
   {{0x27170019,0xda670987,0x1959010b,0x38a90312}},	//   _lăng_, _دائي, _вады_, _búrc_,
   {{0xf7090028,0x26190066,0xf8bf000d,0x66c80381}},	//   _gần_, पड़ी_, éés_, lıkk,
   {{0x271700e8,0xdce90009,0x229c0093,0xc7a532ff}},	//   _năng_, _oseč, _líkt_, _милк,
   {{0x6fd92135,0x232a01e0,0x2b470176,0x00000000}},	//   _बुलं, роби_, nunc_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x271701a5,0x15380580,0x00000000,0x00000000}},	// [7040] _băng_, _ازبک_, --, --,
   {{0x27170019,0x2056010b,0x00000000,0x00000000}},	//   _căng_, ўтар, --, --,
   {{0xb4d61ae9,0xb21b0a8a,0x00000000,0x00000000}},	//   िकी_, _knæl, --, --,
   {{0x443a00ac,0x7ce412c3,0xa75a0070,0xb4db0176}},	//   _hdp_, mòri, ידער, pràc,
   {{0x62866e61,0x7ce40392,0x00000000,0x00000000}},	//   _inko, lòri, --, --,
   {{0x443a0009,0xccb700d4,0x271700e2,0x316200ee}},	//   _jdp_, огії_, _găng_, _ipkz_,
   {{0xbea600af,0x9e660647,0x9c7c0107,0xf70900cc}},	//   _давк, _وارن, _shčs, _sần_,
   {{0x5a34029f,0x00000000,0x00000000,0x00000000}},	//   чнит, --, --, --,
   {{0x80bf0083,0x443a0035,0xc8661858,0xcc8a01cb}},	//   ্তর্, _odp_, отни, _پناه_,
   {{0xa3bb0006,0x27170019,0xf7090023,0x6e226e62}},	//   _आइल_, _xăng_, _vần_, lbob,
   {{0x6d420147,0x00000000,0x00000000,0x00000000}},	//   lroa, --, --, --,
   {{0x443a6e63,0xf7090019,0x7ce40176,0x00000000}},	//   _adp_, _tần_, dòri, --,
   {{0x443a6e64,0x6d42023c,0x66090207,0x2ee60298}},	//   _bdp_, nroa, žeko, ilof_,
   {{0x62866e65,0xdc080029,0x7ce40392,0x00000000}},	//   _anko, rēķi, fòri, --,
   {{0x27176e66,0x443a0110,0x7ce401f7,0x00000000}},	//   _răng_, _ddp_, gòri, --,
   {{0x6d426e67,0xc1050079,0x00000000,0x00000000}},	//   kroa, كوري, --, --,
   {{0xb80e017a,0x200710ec,0x7c3a19f6,0x443a0110}},	// [7050] _सलाम_, žnim_, _odtr, _fdp_,
   {{0x6d426e68,0x8fe72626,0x62866391,0x7ce40392}},	//   droa, оцед, _enko, bòri,
   {{0x44316e69,0xdce20b16,0xe9ff0019,0xfbfe0033}},	//   maz_, jvođ, _trầm_, ুরুষ_,
   {{0x44316e6a,0x59ca0b35,0xdce2011c,0x6e226b9d}},	//   laz_, ापार, dvođ, gbob,
   {{0x27170028,0x443a028b,0x6d420139,0x067c025a}},	//   _tăng_, _ydp_, groa, ינאל,
   {{0x9f3515d6,0x44316e6b,0x7c3a0211,0x251c1804}},	//   _негі, naz_, _cdtr, סווא,
   {{0x7ced0d2e,0xdce902c4,0x6e2200e5,0xeb990f9e}},	//   gúra, _useč, bbob, сий_,
   {{0x44316e6c,0x26cb139c,0xdcfb035f,0x66c80225}},	//   haz_, ébol_, _kruċ, rıkk,
   {{0x44310bca,0x8d770357,0x6e3b0069,0x6d426e6d}},	//   kaz_, _بازا, _idub, croa,
   {{0x78a90202,0x7d1b01a2,0x29036e6e,0x50db0099}},	//   ског_, _itus, öja_, भविष,
   {{0xd90f0332,0xbb480082,0x44316e6f,0x66e66e70}},	//   ریں_, _ولكن_, daz_, зона,
   {{0x443a6e71,0x64410093,0x998000a0,0x70b800b4}},	//   _sdp_, ólin, _žiť_, _इग्ल,
   {{0x44316e72,0x443a02a7,0x777a006d,0x66dd00b5}},	//   faz_, _pdp_, avtx, rékp,
   {{0xb4d6007c,0x44316e73,0x7ce412c3,0xf7090019}},	//   िके_, gaz_, tòri, _hầm_,
   {{0x07a50671,0x63836355,0xb4bc193c,0x00000000}},	//   _хайн, нгра, _आगी_, --,
   {{0x7d1b073a,0xa5bb01ef,0x6e3b6e74,0x44310088}},	//   _otus, mbón, _ndub, aaz_,
   {{0x26c26e75,0xb14601c8,0xe2971d6b,0x44316e76}},	// [7060] miko_, янал, чат_, baz_,
   {{0xb063016f,0xf7090019,0x6564011e,0x6e3b6e4c}},	//   jväč, _lầm_, _ipih, _adub,
   {{0x7d1b6e77,0x9e660e60,0xee86081b,0x6e3b262d}},	//   _atus, звед, зыло, _bdub,
   {{0x645c6e78,0x26c26e79,0x6d426e7a,0x69c4010b}},	//   lfri, niko_, troa, _žiem,
   {{0xfce64599,0x6da34ae8,0x2ee66e7b,0x6e226e7c}},	//   подо, ница, rlof_, rbob,
   {{0x6d420291,0x26c26e7d,0x6e3b01d7,0x645c05aa}},	//   rroa, hiko_, _edub, nfri,
   {{0x26c23d63,0x7d1b03ad,0x61e60b3e,0xf70900e2}},	//   kiko_, _etus, _hykl, _bầm_,
   {{0x60de6e7e,0xf70901a5,0x44316e7f,0x6d4200a5}},	//   lopm, _cầm_, zaz_, proa,
   {{0x26c206a2,0xd90d0148,0x4431008f,0x25fe0653}},	//   diko_, لین_, yaz_, रेमी_,
   {{0xb4d66e80,0x7c3a01b4,0xb19b0070,0xe29f0093}},	//   िको_, _udtr, צייכ, _miða_,
   {{0x26c26e81,0x645c22c0,0xf98f0df3,0x61e6008d}},	//   fiko_, dfri, نبی_, _lykl,
   {{0xb5fb004f,0x26c206a2,0x76ab0652,0xf7090023}},	//   leái, giko_, стов_, _gầm_,
   {{0x645c6e82,0x44316e83,0x201802e9,0x3ea61d38}},	//   ffri, taz_, _ofri_, ikot_,
   {{0x645c006c,0xb5fb004f,0x6f1c0124,0x24180421}},	//   gfri, neái, _otrc, зоры_,
   {{0x44316e84,0x2007068b,0x26c25e09,0x02a7010b}},	//   raz_, žnik_, biko_, прам,
   {{0x645c029d,0x66e41a31,0x929401c8,0x6fbd02e4}},	//   afri, _поја, насц, ्पसं,
   {{0x44311423,0x25a2017f,0x00000000,0x00000000}},	// [7070] paz_, cykl_, --, --,
   {{0xb21b08c8,0x00000000,0x00000000,0x00000000}},	//   _knæk, --, --, --,
   {{0xb5fb0037,0x7ae200f4,0x741604a3,0x7d1b081b}},	//   deái, _okot, _توپا, _stus,
   {{0x3ea66e85,0x7ae2007b,0x6f0e00ee,0x00000000}},	//   gkot_, _nkot, _dubc, --,
   {{0xcbfe0033,0xf70900e2,0x20180090,0x00000000}},	//   ুরোধ_, _rầm_, _ffri_, --,
   {{0x26c26e86,0x7ae26e87,0xf70900e2,0x6738035f}},	//   ziko_, _akot, _sầm_, _ovvj,
   {{0xfc300037,0x61e66e88,0x765d0176,0x00000000}},	//   احه_, _zykl, kfsy, --,
   {{0x26c26e89,0x6e3b011c,0x00000000,0x00000000}},	//   xiko_, _udub, --, --,
   {{0x645c6e8a,0x3ebf6e8b,0x7d1b4507,0x67380069}},	//   yfri, _imut_, _utus, _avvj,
   {{0xb4bc1ee0,0xb5fb0082,0xa3ad0084,0x6d4b050f}},	//   _आगे_, ceái, कना_, muga,
   {{0x26c26e8c,0x6d4b383a,0xf70901a5,0x3ead0116}},	//   tiko_, luga, _tầm_, _klet_,
   {{0xb4d600b4,0xa5bb6e8d,0x3ebf009f,0x291f4466}},	//   िक्_, rbón, _jmut_, ppua_,
   {{0x6d596e8e,0x26c26e8f,0x20070888,0x7afb6e90}},	//   ntwa, riko_, žnih_, mmut,
   {{0x7ae96e91,0xdcfb0009,0xb4e80380,0x7afb6e92}},	//   llet, _oruč, बते_, lmut,
   {{0x6d4b00fb,0x26c26e93,0x290f008a,0x7ae96e94}},	//   huga, piko_, _huga_, olet,
   {{0x645c17ad,0x6d4b6e95,0x29076e96,0x6d596e97}},	//   sfri, kuga, _hina_, ktwa,
   {{0x290f203f,0x29076e98,0x6d4b6e99,0xd24f006c}},	// [7080] _juga_, _kina_, juga, شنل_,
   {{0x25fe0821,0x29070657,0x6d4b03be,0x290f6e9a}},	//   रेणी_, _jina_, duga, _muga_,
   {{0x29076e9b,0xe29a0274,0x212b001e,0x6d59030d}},	//   _mina_, _дан_, _ewch_, etwa,
   {{0x6d596e9c,0x29076e9d,0x6d4b6e9e,0x29020187}},	//   ftwa, _lina_, fuga, íkaz_,
   {{0xb5fb004f,0x6d4b2884,0x7ae96e9f,0x29070b9b}},	//   teái, guga, dlet, _oina_,
   {{0x7ae26ea0,0x7ae96ea1,0x3ebf00f8,0x3ead219d}},	//   _skot, elet, _emut_, _elet_,
   {{0x7ae96ea2,0x290f6ea3,0xb5fb004f,0x3ead00da}},	//   flet, _auga_, reái, _flet_,
   {{0x2907291d,0xb5fb004f,0x6d4b6ea4,0x3ead0139}},	//   _aina_, seái, buga, _glet_,
   {{0x29076ea5,0x286a2368,0x81e00083,0xb5fb6ea6}},	//   _bina_, орно_, ধের_, peái,
   {{0x29070452,0x7ae930af,0x5fd5000c,0x9f58009e}},	//   _cina_, alet, _दशमल, _sgrù_,
   {{0x29076ea7,0x291d02c9,0xa7fc027d,0xfa90027b}},	//   _dina_, _etwa_, ldız, çüsü_,
   {{0x29076ea8,0x7ae25a6d,0x7d080b3e,0x256f0069}},	//   _eina_, _ukot, _hids, _pżl_,
   {{0x29076ea9,0x290f6eaa,0xe4e700d4,0x8afb00a5}},	//   _fina_, _guga_, дівн, _והאי,
   {{0x67d405f4,0xa2c104aa,0x7ae000fd,0xf76f00e0}},	//   _полу, रोन्, lomt, _چاي_,
   {{0x6d4b33bd,0x7d0849f7,0xdce0013a,0x00000000}},	//   zuga, _mids, _armī, --,
   {{0x7d0800b8,0x29076eab,0x6d4b6eac,0x6d5926d8}},	//   _lids, _zina_, yuga, ytwa,
   {{0x64480d2e,0x660d6ead,0x50f56eae,0xdcfb00cd}},	// [7090] ódic, _igak, езат, _sruč,
   {{0x3ead054e,0x6d4b041b,0x7ae96eaf,0x3ebf6eb0}},	//   _slet_, vuga, zlet, _smut_,
   {{0x7ae96eb1,0x7ae007c0,0x3ead0a8a,0x00000000}},	//   ylet, komt, _plet_, --,
   {{0x752d6eb2,0x6d59035f,0x644303e6,0x7d083db4}},	//   _kwaz, ttwa, _ônib, _aids,
   {{0x212b001e,0x7ae901d6,0x660d0430,0xdce90254}},	//   _uwch_, vlet, _mgak, _sređ,
   {{0xdce91269,0x6d596eb3,0x6d4b62c8,0x629d01cb}},	//   _pređ, rtwa, ruga, _hoso,
   {{0x629d071f,0x6d4b00a7,0x7ae96eb4,0x290f4884}},	//   _koso, suga, tlet, _suga_,
   {{0x29076eb5,0x660d00d1,0x79826eb6,0xdce90b16}},	//   _sina_, _ngak, _brow, _vređ,
   {{0x2bdf00dc,0x7ae96dd0,0x629d6eb7,0x7afb45f8}},	//   _पुरा, rlet, _moso, rmut,
   {{0x660d01d0,0x7ae9523f,0x629d088a,0x26c0012e}},	//   _agak, slet, _loso, _smio_,
   {{0xdce901cc,0x752d2cee,0x07a50823,0x79820103}},	//   _uređ, _awaz, ханн, _erow,
   {{0x629d6eb8,0x672103fd,0x290f6eb9,0x79826eba}},	//   _noso, rplj, _tuga_, _frow,
   {{0xd756006c,0x79820122,0x290f0159,0x27e7233c}},	//   ولیت_, _grow, _uuga_, _wynn_,
   {{0x6f096ebb,0x752d24dc,0x394d0031,0x660d0065}},	//   _liec, _dwaz, mues_, _egak,
   {{0x7c3e0370,0x629d0703,0xd8760405,0x68e16ebc}},	//   ópri, _boso, _سميت_, mold,
   {{0xe2970202,0x6f093d3f,0x629d6ebd,0x752d0260}},	//   нас_, _niec, _coso, _fwaz,
   {{0x61431fd8,0x21670b3b,0x394d6ebe,0xe5a600af}},	// [70a0] лета, нити_, nues_, _чипи,
   {{0x9c7c05d3,0x68e16ebf,0x2a6d006f,0x23db13a0}},	//   _akčn, nold, heeb_, _मुकद,
   {{0x54570052,0x7053099f,0x752d02d0,0x6f091232}},	//   _אביב_, انما, _zwaz, _biec,
   {{0x68e11953,0x7d080022,0x629d6ec0,0x6f096ec1}},	//   hold, _sids, _goso, _ciec,
   {{0x6f095aee,0x2a6d00d7,0x394d0031,0x68e16ec2}},	//   _diec, deeb_, jues_, kold,
   {{0x653b02b5,0x394d1b00,0x00000000,0x00000000}},	//   לענד, dues_, --, --,
   {{0x6f090012,0x629d6ec3,0x2bc30ac4,0x7d085e59}},	//   _fiec, _yoso, _वेदा, _vids,
   {{0x7982006a,0x6f0900d7,0xdfcf600c,0x6ee300be}},	//   _prow, _giec, _ايف_, sõbr,
   {{0x68e16ec4,0xf9920125,0x7d086ec5,0x394d3820}},	//   fold, ابع_, _tids, gues_,
   {{0x68e1006c,0x2d8400de,0x752d04fb,0x00000000}},	//   gold, _irme_, _rwaz, --,
   {{0x67d42b5b,0x752d6ec6,0x65760118,0xa2c100b4}},	//   тону, _swaz, _asyh, रोड्,
   {{0x79826ec7,0x2a6d01e8,0x38a000f1,0x29110079}},	//   _trow, ceeb_, _còrr_, únaí_,
   {{0x38cb13cf,0x68e16ec8,0x394d00a2,0x1874010b}},	//   _کانی_, bold, cues_, _агля,
   {{0x629d6ec9,0x752d02d0,0x5fd900ab,0x00000000}},	//   _soso, _vwaz, _बुझल, --,
   {{0x629d6eca,0x60c500be,0x00000000,0x00000000}},	//   _poso, vihm, --, --,
   {{0x629d007a,0x752d6ecb,0x2d846ecc,0x0cdc6ecd}},	//   _qoso, _twaz, _orme_, मकुम,
   {{0x629d0831,0x752d6074,0x673a6ece,0x6f096ecf}},	// [70b0] _voso, _uwaz, lstj, _riec,
   {{0x6f09004e,0xfbb01f57,0x629d29c5,0x00000000}},	//   _siec, जनाम, _woso, --,
   {{0x6f096ed0,0xdfd10037,0x629d018e,0x394d0031}},	//   _piec, جيا_, _toso, zues_,
   {{0x6ee70037,0x2a6d006d,0x52a70037,0x443306c6}},	//   رسال, xeeb_, _أصدق, _hex_,
   {{0x6f093c05,0x2a6d00be,0x394d0031,0x5e5400fd}},	//   _viec, veeb_, xues_, ائمر,
   {{0x6f09004e,0x394d00f7,0xe10400d8,0xada2010b}},	//   _wiec, vues_, _бясп, рашл,
   {{0x68e16ed1,0x673a01e4,0xdb036ed2,0xdea100d1}},	//   vold, jstj, lyné, _پیشی,
   {{0x44336ed3,0x394d6ed4,0x68e124dc,0x673a2bf2}},	//   _lex_, tues_, wold, dstj,
   {{0x6aa900fb,0xe9d90ebb,0xe8f900c3,0x673a02a2}},	//   rkef, ьки_, мли_, estj,
   {{0xa2c106bc,0x7e7b02c9,0x394d6ed5,0x2a6d006d}},	//   रोत्, _haup, rues_, seeb_,
   {{0x7e7b6ed6,0x394d6ed7,0x68e16ed8,0x8c3c0448}},	//   _kaup, sues_, rold, _doğd,
   {{0x68e16ed9,0x44330223,0x7cf600af,0x394d6eda}},	//   sold, _aex_, râre, pues_,
   {{0x394d6edb,0x68e16edc,0x7e7b02cb,0x67240254}},	//   ques_, pold, _maup, _čije,
   {{0x7e7b6edd,0x443301f7,0x98a20274,0x6ef8002a}},	//   _laup, _cex_, _више, míbe,
   {{0x44331be4,0xe29f008d,0x6ef801c0,0x42564f19}},	//   _dex_, _boð_, líbe, ктат,
   {{0xc24332b3,0x1b1300c8,0x7e7b026f,0x95860e60}},	//   инск, _সবাই_, _naup, _алие,
   {{0x942616e2,0x6d5b006f,0x6ef801ef,0x26d902d7}},	// [70c0] _импе, _nqua, níbe, éroe_,
   {{0xf5370070,0xb5fb01ef,0x443300f6,0x00000000}},	//   _שניי_, reát, _gex_, --,
   {{0x63a7006a,0xb4c022f2,0xe0d500d4,0x442a00d7}},	//   cyjn, ूची_, ують, mbb_,
   {{0xa2c1021a,0xb5fb002a,0xb21b3d3e,0x00000000}},	//   रोद्, meár, _snæv, --,
   {{0x7e7b000d,0x44386ede,0xdce000ea,0xbea30bfe}},	//   _daup, oar_, _apmā, јачк,
   {{0x55bb00a5,0x6ef801ef,0x13c60033,0x237f0067}},	//   ומנו, díbe, _শুয়, łuje_,
   {{0x09ca012f,0xf70a0019,0x44386edf,0x6d5b0122}},	//   ाप्य, _hầu_, iar_, _equa,
   {{0x44386ee0,0x3a740e0a,0x21220159,0xbea30b25}},	//   har_, улир, _ktkh_, _каск,
   {{0xbea32351,0xdc5403c5,0x63a70035,0x3f5c0093}},	//   _татк, _مراک, zyjn, líu_,
   {{0x44386ee1,0xf70a0023,0x673a2c7a,0x7e7b008b}},	//   jar_, _mầu_, tstj, _zaup,
   {{0xd7f73a6a,0xf70a0019,0x69d9009f,0xfd4e00e2}},	//   кую_, _lầu_, _exwe, _ngoặ,
   {{0x673a00fb,0x7c380370,0x443800e9,0x645a02d0}},	//   rstj, lavr, ear_, òtin,
   {{0x44386ee2,0x673a008a,0x25fe0066,0x36d40210}},	//   far_, sstj, रेली_, рояр,
   {{0x64d229ad,0x7d1d0443,0x673a4af9,0x3d150067}},	//   _सदृश, _ésse, pstj, _फंसे_,
   {{0x25ad16dc,0xd83800ac,0xd6db0370,0x349403d0}},	//   šel_, mač_, _оти_, шарр,
   {{0xf70a01a5,0xd8381e85,0x63a70035,0x3f5c5eb6}},	//   _bầu_, lač_, ryjn, díu_,
   {{0x7e7b049d,0xf70a00e8,0x63a70035,0x60f94194}},	// [70d0] _raup, _cầu_, syjn, еная_,
   {{0x2edb0b40,0xf70a01a5,0x7e7b6ee3,0x51f81397}},	//   यक्त, _dầu_, _saup, тную_,
   {{0xf4120052,0x7e7b6ee4,0x200703ad,0x7c386ee5}},	//   _לפי_, _paup, äni_, davr,
   {{0xd8386ee6,0x4ea701d3,0xa29512ea,0xa5bb002a}},	//   hač_, ърза, _самі, rcóf,
   {{0x628f6ee7,0xd83803c9,0x8c45021d,0x6d5b6701}},	//   _inco, kač_, геле, _qqua,
   {{0xd8380496,0x3f5c0f02,0x387c01ed,0x645500fd}},	//   jač_, bíu_, _navr_, ngzi,
   {{0x7e7b3ecb,0x3f5c002a,0x9f3401e0,0x7ced0d99}},	//   _taup, cíu_, _весі, núri,
   {{0xdce92c3f,0x6ef80042,0xead10831,0x00000000}},	//   _oseć, tíbe, াত্ম, --,
   {{0x44386ee8,0x101708a9,0xd8380207,0x38ca00e0}},	//   yar_, _तलाश_, fač_, کايی_,
   {{0x44386ee9,0x6ef82e7d,0xd83804c3,0x6f150069}},	//   xar_, ríbe, gač_, _kuzc,
   {{0x6ef80391,0xa6ca075c,0x38a90132,0x7ced1e60}},	//   síbe, елна_, _júri_, júri,
   {{0xaca30023,0xba390070,0xcb1200a5,0x00000000}},	//   _ruộn, _װײַט, _הלא_, --,
   {{0xd9456eea,0xf9900413,0x2a7f01e8,0xd8380124}},	//   _сели, _وبه_, mdub_, bač_,
   {{0x628f0133,0x2a7d01e8,0x44386eeb,0x6e3901e8}},	//   _anco, _hawb_, uar_, hawb,
   {{0x395f6eec,0x2a7d006d,0x6d4b033b,0xf70a0023}},	//   ltus_, _kawb_, hrga, _sầu_,
   {{0x670c0755,0x2a7f007c,0x7c3803c9,0x387c0009}},	//   _सूचक_, ndub_, zavr, _zavr_,
   {{0x44386eed,0x395f3ef9,0x2a7d006d,0x76446eee}},	// [70e0] par_, ntus_, _mawb_, _idiy,
   {{0x628f2020,0x2a7d01e8,0x44386eef,0x395f0086}},	//   _enco, _lawb_, qar_, itus_,
   {{0x44446ef0,0x03a6107a,0x6d4b6ef1,0x395f00ab}},	//   _id_, _сино, erga, htus_,
   {{0xd838029d,0x2a7d0189,0x395f6ef2,0xf70a00e2}},	//   zač_, _nawb_, ktus_, _tầu_,
   {{0xdca6095d,0x395d006d,0x7c386ef3,0x395f01e8}},	//   лади, _nqws_, tavr, jtus_,
   {{0xa3e8007c,0xfce301e0,0xbd8702e7,0x752408c7}},	//   _बडा_, бочо, انون_, _mtiz,
   {{0x2a7d001e,0x6e39011e,0x44446ef4,0x395f00be}},	//   _bawb_, bawb, _md_, etus_,
   {{0x76440657,0xdee6248c,0x7c380c21,0x395f03bc}},	//   _ndiy, _соби, savr, ftus_,
   {{0x44440496,0x2a7d01a9,0x395f6ef5,0x5eca0033}},	//   _od_, _dawb_, gtus_, িকদে,
   {{0x2bdf0e1d,0x2ee612b0,0x444400a5,0x7c650118}},	//   _पुका, loof_, _nd_, _نامل,
   {{0x2a660021,0xd8380a78,0x2a7d006f,0x75240a33}},	//   _бълг, rač_, _fawb_, _atiz,
   {{0x44446ef6,0xd838535d,0xa3e80006,0xdce900cb}},	//   _ad_, sač_, _बड़_, _pseć,
   {{0xd838063b,0x764400e5,0x00000000,0x00000000}},	//   pač_, _ddiy, --, --,
   {{0x6aa2201e,0x44440122,0x764401d6,0x7ced6ef7}},	//   _hoof, _cd_, _ediy, túri,
   {{0xb86500bf,0x6aa201b7,0x290e0069,0x32676e5f}},	//   _خانو, _koof, _iifa_, лтав,
   {{0x44440021,0xb6c90332,0x6e240391,0x2a7d006d}},	//   _ed_, _جاتے_, ñibl, _xawb_,
   {{0x408701e0,0xf1941eb9,0x290e0b23,0x2ee60afc}},	// [70f0] лужб, бить, _kifa_, doof_,
   {{0x26cb6ef8,0x3d180992,0x7ced0443,0x656d0f3a}},	//   lico_, _पढ़े_, púri, _ipah,
   {{0x6d401884,0x3f8740ea,0x64456ef9,0xe29f008d}},	//   _avma, ínu_, _idhi, _liði_,
   {{0x6d4b1d7d,0x395f010b,0x290e0093,0x628f6efa}},	//   trga, ytus_, _lifa_, _unco,
   {{0x395f6efb,0x2a7d006d,0x44446efc,0xeb990012}},	//   xtus_, _rawb_, _yd_, ӂий_,
   {{0x21291034,0x6f026efd,0x26cb027a,0x251c0070}},	//   mpah_, amoc, hico_, עווא,
   {{0xeb991493,0x2a7d001e,0x644508c7,0x26cb0116}},	//   тий_, _pawb_, _mdhi, kico_,
   {{0xf53f6efe,0x290e2971,0x395f6eff,0x26cb6f00}},	//   kså_, _aifa_, ttus_, jico_,
   {{0x81e700c8,0x2024008a,0x395f6f01,0x6aa2676b}},	//   যের_, _árið_, utus_, _doof,
   {{0x395f6f02,0x08c50369,0x229c01c0,0xe765384b}},	//   rtus_, рбон, _díky_, авоп,
   {{0x395f6f03,0x2a7d0221,0x316001d7,0x7524011c}},	//   stus_, _tawb_, ztiz_, _stiz,
   {{0x26cb16d5,0x64456f04,0x6aa26f05,0x66e66f06}},	//   gico_, _adhi, _goof, рома,
   {{0x44446f07,0x6ef80176,0x7d0e048f,0xe9a80754}},	//   _pd_, níba, _ünsü, _مدون_,
   {{0x7ae4067b,0x4421011e,0x44446f08,0x394d01f4}},	//   čite, _cfh_, _qd_, mres_,
   {{0x44446f09,0x26cb6f0a,0x394d05ca,0xdc0800ea}},	//   _vd_, bico_, lres_, mēģi,
   {{0x394d0bc8,0x7644012f,0x42260409,0x644500e0}},	//   ores_, _udiy, рдав, _edhi,
   {{0x78a36f0b,0x61ef6f0c,0x3d150437,0xdc020035}},	// [7100] _konv, _cycl, _फूले_, _लण्ड_,
   {{0x394d1010,0x44446f0d,0x3d0f004e,0xdb1800b5}},	//   ires_, _ud_, ादों_, szvé,
   {{0xee3a2497,0x394d01ae,0x9d120033,0x78a36f0e}},	//   вне_, hres_, _হবেন_, _monv,
   {{0x33db02b8,0x394d6f0f,0x316007e7,0xeda600c3}},	//   _יחיד, kres_, ptiz_, ишло,
   {{0x6aa26f10,0x2ee66f11,0x00000000,0x00000000}},	//   _roof, roof_, --, --,
   {{0x394d6f12,0x78a36f13,0x1d1900d8,0x8c3c00d0}},	//   dres_, _nonv, уюць_, _boğa,
   {{0x394d6f14,0x9f5c03ad,0x1e9600af,0x7f43002d}},	//   eres_, ävä_, _крар, _мерж,
   {{0x26cb6f15,0x394d6f16,0x8c3c0723,0x290e000e}},	//   xico_, fres_, _doğa, _sifa_,
   {{0x26cb6f17,0x999702fb,0xdce0004b,0x00000000}},	//   vico_, икът_, _apmą, --,
   {{0x78a36f18,0x61eb02b1,0x9c7c023a,0x3ce7021d}},	//   _conv, ügli, _okči, conv_,
   {{0x3ea404ce,0x656d6f19,0x78a36f1a,0x00000000}},	//   _komt_, _spah, _donv, --,
   {{0x394d0310,0xf53f177c,0xbad500d8,0x4421021d}},	//   bres_, tså_, _лічы, _sfh_,
   {{0x26cb0f1f,0x394d6f1b,0x290e022e,0x78a3021e}},	//   rico_, cres_, _tifa_, _fonv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cb478a,0xdce90484,0xf2c70819,0xb4db0392}},	//   pico_, _speċ, асан, dràt,
   {{0x68e86f1c,0x96351400,0x78a30223,0x00000000}},	//   lodd, _униц, _zonv, --,
   {{0x26c901cc,0x6fd90299,0x656d1c71,0x16030026}},	// [7110] _imao_, _मशहू, _upah, रेशर_,
   {{0x92d700c8,0x68e8001e,0x64450054,0x64550200}},	//   িতে_, nodd, _udhi, _увођ,
   {{0x61ef6f1d,0xd0180ffd,0x00000000,0x00000000}},	//   _wycl, рфу_, --, --,
   {{0x22950dc0,0x394d6f1e,0x68e800e9,0x00000000}},	//   _الحس, yres_, hodd, --,
   {{0x3ea40024,0x3f8a00d5,0x8c3c0448,0x27e20067}},	//   _domt_, _erbu_, _soğa, ękny_,
   {{0x394d27f3,0x6ef86f1f,0xb4db0443,0xeac900e2}},	//   vres_, ríba, cràt, hẹt_,
   {{0x3f8a0129,0x7ced0037,0x3f8500f7,0x998400c7}},	//   _grbu_, dúrt, _élu_, kamų_,
   {{0x394d6f20,0x8d7700f8,0x9984010b,0x2b49011c}},	//   tres_, _پارا, jamų_, čac_,
   {{0x394d6f21,0xdc0800ea,0x78a30116,0x00000000}},	//   ures_, tēģi, _ponv, --,
   {{0x4879186f,0x26c90008,0x2481033b,0xdcf90957}},	//   усия_, _amao_, _nahm_, _صفات_,
   {{0xb69b0ebc,0xd70a0421,0x37e50183,0x78a30107}},	//   rmân, лное_, сонг, _vonv,
   {{0x394d6a8d,0x2ca500a5,0x7b1500b8,0x660000a0}},	//   pres_, _hold_, _všud, ýmko,
   {{0x81ac00c8,0x16030026,0x2ca50249,0x7ae96f22}},	//   _কেন_, रेलर_, _kold_, moet,
   {{0x78ba5745,0xdce94220,0x7ae96f23,0xf8ab0067}},	//   chtv, _opeč, loet, _छविय,
   {{0x2481011e,0x2ca56f24,0x00000000,0x00000000}},	//   _dahm_, _mold_, --, --,
   {{0x7ae96f25,0x7bce022f,0xdb1200b5,0xb4db0176}},	//   noet, _žbuk, ógép, fràs,
   {{0xe1fa2632,0x3f8a00f4,0x870600fd,0x7ae90065}},	// [7120] уга_, _srbu_, _پڑھے_, ioet,
   {{0x2ca5010d,0x3ae101ba,0xa49401cb,0x3ce10067}},	//   _nold_, rópy_, _بیست, खकों_,
   {{0x443a0260,0x7ae906a2,0x7ced0079,0xd5e90105}},	//   _iep_, koet, húrs, _معین_,
   {{0xe29a6f26,0x443a32c7,0xee3a2947,0x7ae901ed}},	//   _сам_, _hep_, унд_, joet,
   {{0x2ca56f27,0x443a6f28,0x7ae90737,0x00000000}},	//   _bold_, _kep_, doet, --,
   {{0x443a4b4a,0x62846f29,0x2ca500a5,0x00000000}},	//   _jep_, ldio, _cold_, --,
   {{0x6724011c,0x7ae900e9,0x798b12ba,0x3ea41b2f}},	//   _čijo, foet, _argw, _tomt_,
   {{0xd00f004f,0x443a02c6,0x7ae901d7,0x00000000}},	//   _ألف_, _lep_, goet, --,
   {{0xd83a005f,0x98b80043,0xe29b0070,0x9c5a0919}},	//   лэн_, илит_, רשפר, _مجاز_,
   {{0x2ca540d4,0xad1b00a5,0xb17b0070,0x26c96f2a}},	//   _gold_, _עובר, נטיר, _smao_,
   {{0x15e10299,0x68e80297,0x7ae96f2b,0xbb8601cb}},	//   _गुजर_, rodd, boet, _دلاي,
   {{0xfaa30a2b,0x6e220099,0xeb970122,0x68e83596}},	//   _нахо, ncob, _לדבר_, sodd,
   {{0x628402c7,0x6d426f2c,0x7c3a6f2d,0x443a6f2e}},	//   ddio, nsoa, _ketr, _bep_,
   {{0x443a6f2f,0xdcfb03fd,0x7c3a1942,0x661600b5}},	//   _cep_, _vruć, _jetr, _egyk,
   {{0x87262087,0x443a6f30,0x572610ad,0x5334002d}},	//   _اعتم, _dep_, _ارتق, зест,
   {{0x443a01ed,0xbb3b0070,0x02a400af,0x00000000}},	//   _eep_, טעלי, прум, --,
   {{0xa159256a,0xe3b000b5,0x51871a5a,0xdce91f45}},	// [7130] разу_, ورہ_, щува, _speč,
   {{0x7ae901a3,0x628400be,0x443a6f31,0x00000000}},	//   zoet, adio, _gep_, --,
   {{0x83670037,0x2f21004b,0x2ca50a8a,0x00000000}},	//   _ادخل, _bėga_, _rold_, --,
   {{0x2ca500a5,0x443a40a8,0x2bc344d2,0xa159010b}},	//   _sold_, _zep_, _वेगा, _каму_,
   {{0x7c3a6724,0xee381958,0xdca529e5,0x5d6702fb}},	//   _betr, сні_, жали, стез,
   {{0x61fd3e38,0x443a00cc,0x00000000,0x00000000}},	//   _izsl, _xep_, --, --,
   {{0x7ae96f32,0x2ca50249,0x01db0831,0x00000000}},	//   toet, _vold_, _দরিদ, --,
   {{0xa92501f6,0x2ca56f33,0x6e220036,0x4ea702ee}},	//   одил, _wold_, ccob, _урга,
   {{0x7ae92c74,0x2ca56f34,0x7c3a27c5,0x6d92008d}},	//   roet, _told_, _fetr, rðað,
   {{0x7c3a3d7d,0x7ae41b8d,0x25ed0299,0x6e3b6f35}},	//   _getr, čita, _घड़ी_, _heub,
   {{0xe73903fa,0x7f572b28,0x443a6f36,0x7ae9245b}},	//   јем_, nuxq, _rep_, poet,
   {{0x443a6f37,0x7d1b6f38,0x2d8d0260,0xc8780225}},	//   _sep_, _kuus, _kree_, doğu_,
   {{0x443a6f39,0x6e3b6f3a,0xaca30019,0x7d1b03a6}},	//   _pep_, _meub, _huốn, _juus,
   {{0x7d1b1eca,0x6e3b6f3b,0x69dc027d,0x38bb03bc}},	//   _muus, _leub, ğret, _bêre_,
   {{0x25fe0953,0x7d1b6f3c,0xdce000c7,0x923a00af}},	//   रेजी_, _luus, _esmė, ичау_,
   {{0x6e3b4fec,0x3a3f011e,0x62846f3d,0xaca300e2}},	//   _neub, naup_, udio, _muốn,
   {{0x7d1b0173,0x7d01017b,0xa5bb0042,0x291f055c}},	// [7140] _nuus, _ohls, lcón, nqua_,
   {{0x6284334c,0x66cf0107,0x00000000,0x00000000}},	//   sdio, _tòkè, --, --,
   {{0x2d8d02fb,0x7c3a630a,0xe7ef1ca8,0xf42a00c3}},	//   _aree_, _retr, _घुमा_, _elää_,
   {{0x6d420065,0x7d1b559a,0x7d010523,0x260704aa}},	//   tsoa, _buus, _ahls, सेवी_,
   {{0x3ce6009a,0x2d8d6f3e,0x6e226f3f,0x6e2d0300}},	//   टवले_, _cree_, rcob, ñaba,
   {{0x6d426f40,0x645c6f41,0x9b261150,0x6e226f42}},	//   rsoa, ngri, офил, scob,
   {{0x6d4200c9,0x20182209,0x7c3a6f43,0xa2c1258f}},	//   ssoa, _igri_, _vetr, रोक्,
   {{0x22400a7e,0xf41300a5,0x7d1b018f,0x6e3b0027}},	//   naik_, ופו_, _fuus, _geub,
   {{0x7d1b0051,0x69c000f4,0x2d8d055c,0x00000000}},	//   _guus, uzme, _gree_, --,
   {{0x6f1c6f44,0x6e3b01ed,0x22400345,0x00000000}},	//   _kurc, _zeub, haik_, --,
   {{0x645c6f45,0x00000000,0x00000000,0x00000000}},	//   dgri, --, --, --,
   {{0x6f1c6f46,0x7d1b002f,0xa96a6f47,0x986900ee}},	//   _murc, _yuus, _вида_, _gúľ_,
   {{0x291f12a2,0x672d01a0,0x2ab80118,0x25640225}},	//   cqua_, _čaje, _géba_, göl_,
   {{0x645c34c2,0x6f1c6f48,0x38bb0345,0x00000000}},	//   ggri, _ourc, _pêre_, --,
   {{0x93886f49,0xaca301a5,0x6f1c43f3,0x02a72c4c}},	//   оста_, _xuốn, _nurc, орам,
   {{0x20186f4a,0x3f870093,0x7e6002a7,0xb4db0176}},	//   _agri_, ænum_, _ncmp, rràq,
   {{0x6e3b0284,0xa2c11ab2,0x00000000,0x00000000}},	// [7150] _reub, रोग्, --, --,
   {{0x6f1c6f4b,0x7d1b5473,0xddc9002d,0x6ef801ef}},	//   _burc, _ruus, _aceş, síbl,
   {{0x2fc70028,0x6f1c1315,0x22406f4c,0x7d1b03a6}},	//   àng_, _curc, baik_, _suus,
   {{0x6f1c0446,0xef1800d8,0x39460f84,0x2d8d0f43}},	//   _durc, імі_, _ovos_, _pree_,
   {{0x7b150069,0x38c4004b,0x00000000,0x00000000}},	//   _nġur, _kūrė_, --, --,
   {{0x6f1c6f4d,0xdd8e6f4e,0x2d8d0051,0xc1721804}},	//   _furc, اوو_, _vree_, _רחם_,
   {{0x7ae402c6,0x25640576,0x3946021d,0x7d1b0051}},	//   čitn, zöl_, _avos_, _wuus,
   {{0x2d8d00a5,0x7d1b253c,0x09cc0033,0xdddb0139}},	//   _tree_, _tuus, _লড়া, _cauţ,
   {{0x3a3f022e,0x291f0024,0x00000000,0x00000000}},	//   raup_, uqua_, --, --,
   {{0x6d596f4f,0x645c0282,0x22406f50,0x2704021a}},	//   muwa, xgri, zaik_, रग्र_,
   {{0xc5e96f51,0xf77103c7,0x6d596f52,0x291f6f53}},	//   _עד_, راد_, luwa, squa_,
   {{0x195900d8,0xe1ff01f7,0xda781482,0x9f520fce}},	//   _гады_, _ozó_, _мяч_, édée_,
   {{0x6d596f54,0xeab007f6,0x645c6f55,0xa5bb6f56}},	//   nuwa, _جعل_, tgri, scón,
   {{0xa50a06c2,0xd11c04bc,0x2eb81e82,0x765d0b88}},	//   сега_, _भूषण_, _आत्त, agsy,
   {{0x291d2251,0x6d595676,0x232a01e0,0xe29a6f57}},	//   _huwa_, huwa, соби_, бав_,
   {{0x291d225e,0xdbd741b7,0x645c001e,0x6d596f58}},	//   _kuwa_, määr, sgri, kuwa,
   {{0x6f1c6f59,0xa5bb0473,0x20180feb,0x2f210409}},	// [7160] _surc, ncól, _pgri_, _bėgo_,
   {{0x6d596f5a,0x6f1c0122,0xe45a00d8,0x291d2973}},	//   duwa, _purc, _ужо_, _muwa_,
   {{0x2721008a,0xb4e8238a,0xaca30023,0xdbd70303}},	//   _jón_, यकी_, _luồn, näär,
   {{0x27216f5b,0x6d593998,0x127a0037,0x3a240036}},	//   _món_, fuwa, _احدث_, xcmp_,
   {{0x6d596f5c,0x27210079,0xa2d9111b,0x568d016b}},	//   guwa, _lón_, नचर्, יטאַ,
   {{0x6f1c6f5d,0x62860010,0xdbd76f5e,0x00000000}},	//   _turc, _hako, käär, --,
   {{0x62866f5f,0x27210023,0xafe30036,0x291d034d}},	//   _kako, _nón_, _зорл, _auwa_,
   {{0x62866f60,0x6d596f61,0x3afa01f4,0x5fdb00a5}},	//   _jako, buwa, rëpo_, _החלק,
   {{0x62866f62,0xaca30023,0x5886004b,0x291d0118}},	//   _mako, _cuồn, пына, _cuwa_,
   {{0x62866f63,0xfca96f64,0x27210023,0x291d034d}},	//   _lako, _والو_, _bón_, _duwa_,
   {{0x2919003e,0xf09300a5,0x628600ee,0x3d1500be}},	//   ísar_, גנת_, _oako, _फूटे_,
   {{0x62860254,0x45d55fb8,0xa3cd2450,0xa9a60279}},	//   _nako, домс, _शेष_, _ниед,
   {{0xf1bf1111,0x272101ef,0x291d5091,0x6f0300a2}},	//   _afán_, _eón_, _guwa_, ïnci,
   {{0x27210037,0x6286081b,0xa9c504cd,0x00000000}},	//   _fón_, _aako, _غزنو, --,
   {{0x62862591,0xb4bd004e,0xe1ff006c,0x439402f3}},	//   _bako, _आती_, _szó_, нарс,
   {{0x6d595efb,0xdddb2acc,0x78aa4283,0xcfc40033}},	//   yuwa, _lauš, _hofv, ্থান,
   {{0xa3cd0299,0x764d00d7,0x7c28008e,0x62860b73}},	// [7170] _शेर_, _iday, _ofdr, _dako,
   {{0x2eb5012f,0x752d6f65,0xdddb67da,0x55bc00a5}},	//   ंस्त, _itaz, _nauš, _למחו,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d59640c,0x7c286f66,0x62863782,0x6ee70037}},	//   tuwa, _afdr, _gako, أسئل,
   {{0xdddb6f67,0x7e790051,0x00000000,0x00000000}},	//   _bauš, rewp, --, --,
   {{0x628667b3,0xeb993bd5,0x6d596f68,0x752d0054}},	//   _zako, жик_, ruwa, _mtaz,
   {{0x628619c7,0x764d1008,0x6d596f69,0x291d1775}},	//   _yako, _oday, suwa, _suwa_,
   {{0xa2c10026,0x764d6f6a,0x6d59010d,0x752d0187}},	//   रोच्, _nday, puwa, _otaz,
   {{0x2721162d,0x752d01d5,0xcda90037,0x31696f6b}},	//   _són_, _ntaz, _بهذه_, ntaz_,
   {{0xd90f0332,0x764d027d,0x272101ef,0x6d490395}},	//   ھیں_, _aday, _pón_, _ivea,
   {{0x66e61999,0x752d6d14,0x79820103,0x635e0160}},	//   дона, _ataz, _esow, _mănî,
   {{0x291d6f6c,0x64410093,0x9ac50103,0x2721055c}},	//   _tuwa_, ðlin, _beŋŋ, _vón_,
   {{0xe8ee1a24,0x62866f6d,0x2b40044d,0x764d0273}},	//   _ал_, _rako, ćice_, _dday,
   {{0x62864389,0xe7396f6e,0xb4e80026,0xdce200a0}},	//   _sako, _дек_, यके_, ytoč,
   {{0x62866f6f,0x752d0c1f,0x316901a3,0x00000000}},	//   _pako, _etaz, etaz_, --,
   {{0xe2971334,0x6e2d0300,0xdb2400b5,0x7cf600af}},	//   мас_, ñabl, éséh, râri,
   {{0x62866f70,0x61433d53,0x3f8300ab,0x6724011c}},	// [7180] _vako, кета, _asju_, _čiji,
   {{0x62863d10,0x645a01dd,0x6e2968fd,0x3f91011c}},	//   _wako, ótid, _afeb, _brzu_,
   {{0x62861342,0x9e666f71,0x730613f8,0x6d49002d}},	//   _tako, двед, _опоз, _avea,
   {{0x917a00e2,0x00000000,0x00000000,0x00000000}},	//   _cập_, --, --, --,
   {{0xdce26f72,0xdddb00ac,0x81ac0831,0x00000000}},	//   stoč, _pauš, _কের_, --,
   {{0x3e4e01a5,0x1603364c,0xa2ca09b1,0xbb2a002d}},	//   ột_, रेटर_, सोर्, оцие_,
   {{0xff2300af,0x6aab08c8,0xeb9749a8,0x00000000}},	//   _амсо, _bogf, диј_, --,
   {{0x3e8601c8,0x27e00009,0xc4bb1d25,0x78aa00ee}},	//   _būtų_, _ćin_, _उत्ख, _sofv,
   {{0x6aab001e,0xb5fb2cad,0xbc6603fa,0xdddb0009}},	//   _dogf, nfát, _овак, _tauš,
   {{0xd90d1c0c,0x47344073,0xb4e800a9,0xb4bd0f09}},	//   مین_, ннос, यको_, _आते_,
   {{0x90570122,0x205702b5,0xf98f00d1,0xc05700a5}},	//   וסיף_, וייל_, هبی_, וביץ_,
   {{0x569408a6,0x6ef80183,0x00000000,0x00000000}},	//   вают, fíbi, --, --,
   {{0x2d84000c,0x6ef8004f,0x00000000,0x00000000}},	//   _jsme_, ríbh, --, --,
   {{0x2cac0069,0x249a055c,0x00000000,0x00000000}},	//   _jodd_, _cnpm_, --, --,
   {{0x36d5022c,0x2cac001e,0x38cb0647,0x249a021d}},	//   _покр, _modd_, _بانی_, _dnpm_,
   {{0x764d0feb,0xae0e0af9,0x2d8400cd,0xb5fb1e15}},	//   _uday, िधान_, _osme_, rgáb,
   {{0x349518a4,0x752d6f73,0xf70a0023,0x00000000}},	// [7190] _запр, _utaz, _nầy_, --,
   {{0x442701d6,0x31696f74,0x7ae26f75,0x7d1d0176}},	//   _ün_, rtaz_, _ljot, _éssi,
   {{0xdfd16f76,0x316901d7,0x6d490364,0x7ae202d7}},	//   ديا_, staz_, _svea, _ojot,
   {{0x867c0070,0xf70a0023,0xf1d0112b,0x7ae20088}},	//   ַרוו, _bầy_, _सेवन, _njot,
   {{0xf70a00e2,0x2cac016e,0x7e9e0160,0x00000000}},	//   _cầy_, _bodd_, _săpâ, --,
   {{0x2cac012f,0xf70a00e2,0x7ae20328,0x00000000}},	//   _codd_, _dầy_, _ajot, --,
   {{0x2cac233c,0x2d846f77,0x917a00e2,0xa3c1018d}},	//   _dodd_, _esme_, _tập_, ्छि_,
   {{0xff07010b,0x00000000,0x00000000,0x00000000}},	//   _цягн, --, --, --,
   {{0x5c753e89,0x2cac001e,0xe9d90d13,0xf70a0023}},	//   _плат, _fodd_, яки_, _gầy_,
   {{0xa3c12cb0,0x48cd0033,0x3ebf0093,0x77c96f78}},	//   ्छा_, রক্র, _hlut_, злог_,
   {{0x65765f8c,0xe80a00ab,0x3ebf1769,0x00000000}},	//   _spyh, हेला_, _klut_, --,
   {{0xddc00107,0xef190069,0x0bb6016b,0xb4e80099}},	//   _bemň, _jiż_, _אלעם_, यक्_,
   {{0x3ead6f79,0xef19007a,0x00000000,0x00000000}},	//   _moet_, _miż_, --, --,
   {{0x7afb6e90,0x26c201e9,0xef19009f,0xb9040033}},	//   llut, shko_, _liż_, _ভী_,
   {{0xd5b80029,0x38b20139,0xa85600a5,0x00000000}},	//   ņā_, _pârv_, _טיסה_, --,
   {{0xef19004e,0x7afb01a2,0x056601e0,0x00000000}},	//   _niż_, nlut, _звин, --,
   {{0x20566f06,0x3afa0070,0x26c0023c,0x7afb6f7a}},	// [71a0] етер, פּלע, _ilio_, ilut,
   {{0xdcfb1269,0x66046f7b,0x7afb008a,0x764602b3}},	//   _oruđ, _izik, hlut, laky,
   {{0x7afb6f7c,0x26c00009,0x4438016e,0xc43b00a5}},	//   klut, _klio_, mbr_, _מתיי,
   {{0x3ead01f7,0x9f5801f4,0x7ae42d5b,0xd00f0037}},	//   _coet_, _hyrë_, čitk, حلم_,
   {{0x3ead0a75,0x2cbe012f,0xef190024,0x26c06f7d}},	//   _doet_, _pltd_, _diż_, _mlio_,
   {{0x22420484,0x672d18b0,0x6604002f,0xaca300e2}},	//   _hekk_, _čajn, _mzik, _muỗn,
   {{0x26c06f7e,0x7afb0093,0x3dc66f7f,0xef19035f}},	//   _olio_, flut, szow_, _fiż_,
   {{0x2907035f,0x2242048c,0x7afb6f80,0x68e30009}},	//   _ahna_, _jekk_, glut, _ajnd,
   {{0x63b5004e,0xed574fa2,0xc8665674,0x66041939}},	//   zyzn, _пот_, нтни, _nzik,
   {{0x26c06f81,0x29186f82,0xd6fb0d00,0x44380009}},	//   _alio_, öra_, ृष्ठ_, jbr_,
   {{0x6604010f,0x26c0009e,0x7e62002f,0x64410093}},	//   _azik, _blio_, ogop, ðlim,
   {{0x7d1a6f83,0x7e6207ee,0x22420107,0x7afb6f84}},	//   _hits, ngop, _nekk_, clut,
   {{0x7d1a600f,0x2b4c0051,0x8e2002a4,0x00000000}},	//   _kits, _hvdc_, вiк_, --,
   {{0x26c0027a,0x66040efa,0x7d1d0176,0xf993016b}},	//   _elio_, _dzik, _èsse, _תרס_,
   {{0xf76f01ca,0x6604018e,0x27f30187,0x387e6f85}},	//   _هاي_, _ezik, čané_, metr_,
   {{0x7d1a6f86,0x2122008c,0x26c0009e,0xa5bb0079}},	//   _lits, _bukh_, _glio_, hcói,
   {{0x645a2140,0x3ead12ba,0x44380176,0x22426f87}},	// [71b0] ótic, _roet_, bbr_, _dekk_,
   {{0x90280a93,0x7d1a6f88,0x3ead03bc,0x442a0345}},	//   ецца_, _nits, _soet_, ccb_,
   {{0x64470228,0x3ead09b3,0x22420044,0x3ebf6f89}},	//   maji, _poet_, _fekk_, _plut_,
   {{0x2242008a,0x64476f8a,0x9f580055,0x00000000}},	//   _gekk_, laji, _zyrë_, --,
   {{0x7d1a6dcf,0x09b50083,0x3ead03c4,0x628d02a2}},	//   _bits, _জেনা, _voet_, mdao,
   {{0xd04501c2,0x64476f8b,0x7e620051,0x96030033}},	//   yihə, naji, agop, _এলাম_,
   {{0x7d1a0345,0x672d0187,0x3ead01bf,0x00000000}},	//   _dits, _čajo, _toet_, --,
   {{0x1dd20380,0x7afb18af,0x628d6f8c,0xdce90207}},	//   _देवत, ulut, ndao, _opeć,
   {{0x64476f8d,0x2b400254,0x8d744e87,0x6f090260}},	//   kaji, ćica_, _مالا, _ihec,
   {{0x7afb0b87,0x7d1a2c56,0x6447023c,0x8c3c0644}},	//   slut, _gits, jaji, _boğu,
   {{0x81d700c8,0x6f1b6f8e,0x629d0103,0x6d4b0830}},	//   িথি_, _kiuc, _onso, lsga,
   {{0x8c3c06d0,0x6d593440,0x7d1a2fe9,0x00000000}},	//   _doğu, orwa, _zits, --,
   {{0x95996f8f,0x6d4b6f90,0x41d007ba,0x76466075}},	//   нтру_, nsga, _सेंस, raky,
   {{0x76466f91,0x64476f92,0x629d6f93,0x6d4b2343}},	//   saky, gaji, _anso, isga,
   {{0x04430573,0x76466f94,0x64a36f95,0x395f02ee}},	//   ресн, paky, шара, luus_,
   {{0x3afa01f4,0x628d02b3,0x26c0002f,0x44383a62}},	//   tëpi_, gdao, _ulio_, sbr_,
   {{0x64476f96,0x61462947,0x395f6f97,0x69c96f98}},	// [71c0] baji, теза, nuus_, nzee,
   {{0x81ac00c8,0x629d0273,0x7ae40a78,0x67236f99}},	//   _কেউ_, _enso, čiti, _kunj,
   {{0x7d1a0093,0x75240120,0x44446f9a,0x66d601a0}},	//   _rits, _huiz, _ie_, nško,
   {{0x444400f8,0x6f096f9b,0x6aa9012e,0x75246f9c}},	//   _he_, _chec, jjef, _kuiz,
   {{0x44446f9d,0x7d1a6f9e,0x6f09009e,0x67230691}},	//   _ke_, _pits, _dhec, _lunj,
   {{0x44440496,0x75246f9f,0x8cf300d8,0xfd0f026e}},	//   _je_, _muiz, азіц, يجو_,
   {{0x44443be6,0x6d596fa0,0x7d1a0044,0x75246fa1}},	//   _me_, arwa, _vits, _luiz,
   {{0x44442c27,0x237a00d7,0x7d1a6fa2,0x661b6fa3}},	//   _le_, _mppj_, _wits, žuki,
   {{0xf2d302da,0x44446fa4,0x66d600d8,0x7d1a4e80}},	//   יעה_, _oe_, eško, _tits,
   {{0x44446fa5,0x7d1a1c47,0xed570423,0x1bed0006}},	//   _ne_, _uits, _шоу_, _चुकल_,
   {{0x64476fa6,0xb8fa6fa7,0x6aa90453,0x6723219c}},	//   vaji, _ठग_, bjef, _cunj,
   {{0x44446fa8,0x67236fa9,0x69c9006d,0x752402a2}},	//   _ae_, _dunj, bzee, _buiz,
   {{0x444401f3,0x64476faa,0x9a672149,0x395f02a2}},	//   _be_, taji, _شمول_, cuus_,
   {{0x44446fab,0x75240120,0xa4e400d8,0x00000000}},	//   _ce_, _duiz, аўск, --,
   {{0x64476fac,0x67236fad,0x56951402,0x83f80395}},	//   raji, _gunj, _байт, верс_,
   {{0x44440ccf,0x64476fae,0x291c01ef,0x28da0380}},	//   _ee_, saji, _hiva_, यचकि,
   {{0x44446faf,0x26d96fb0,0x628d02a8,0xe2f80185}},	// [71d0] _fe_, miso_, rdao, теті_,
   {{0x44446fb1,0x26d96fb2,0x6f1b0211,0x00000000}},	//   _ge_, liso_, _siuc, --,
   {{0xce3313cf,0xa5c70093,0x752400e2,0x15f40105}},	//   لواک, _fróð, _zuiz, _مسیح,
   {{0x4444331b,0xf77300c2,0x291c6029,0x26d96fb3}},	//   _ze_, יקע_, _liva_, niso_,
   {{0x44446fb4,0x64455422,0x22490626,0xee381958}},	//   _ye_, _kehi, maak_, тні_,
   {{0x444400e8,0x6d4b6fb5,0x656f00f1,0x395f0086}},	//   _xe_, rsga, itch, vuus_,
   {{0x6f096fb6,0x26d96fb7,0xdce00029,0x44210260}},	//   _thec, kiso_, _apmē, _mgh_,
   {{0x64456fb8,0xc2070461,0x61fd0187,0xc334011d}},	//   _lehi, _शराब_, _kysl, בוק_,
   {{0x26d94b9f,0x987e0095,0x99dd0187,0x44211d22}},	//   diso_, _açıq_, raňo, _ogh_,
   {{0x61fd6fb9,0x69c90223,0x395f1130,0xe0df02d0}},	//   _mysl, rzee, ruus_, _dwòg_,
   {{0x44446fba,0xca7529d6,0x395f03ad,0x75246fbb}},	//   _re_, _булы, suus_, _suiz,
   {{0xcfc500c8,0x44216fbc,0xb5fb6fbd,0x291c01ef}},	//   _এখান, _agh_, rgán, _eiva_,
   {{0x44441a24,0x644533aa,0x75240018,0x442102a3}},	//   _pe_, _behi, _quiz, _bgh_,
   {{0x444408e3,0x672365fc,0x64456fbe,0x291c6fbf}},	//   _qe_, _tunj, _cehi, _giva_,
   {{0x44446fc0,0xb5fb0332,0x394d6fc1,0x26d90345}},	//   _ve_, lgál, lses_, biso_,
   {{0x444401f3,0x26d9449f,0x394d6fc2,0x212900d7}},	//   _we_, ciso_, oses_, fqah_,
   {{0x44446fc3,0x6445007a,0x394d6fc4,0x44210160}},	// [71e0] _te_, _fehi, nses_, _fgh_,
   {{0x644503cb,0x7e6909ab,0xe1f74684,0x291c01f7}},	//   _gehi, _acep, угу_, _xiva_,
   {{0x37d50033,0x22496fc5,0xa3c1021a,0xb4c20a90}},	//   _সুতর, baak_, ्छः_, ्फी_,
   {{0xf2a60395,0x394d6fc6,0x7126006c,0x64450225}},	//   _симп, kses_, _مرسل, _zehi,
   {{0x463b0070,0x3160081c,0xee370043,0x61fd23bd}},	//   גענע, quiz_, унч_, _gysl,
   {{0x38a900ac,0x0b8a10bb,0xdc2a1c2d,0x7e6902ee}},	//   _túry_, есии_, رسته_, _ecep,
   {{0x09dc0387,0x394d6fc7,0xd0070b00,0x291c6fc8}},	//   मप्य, eses_, _бере_, _riva_,
   {{0xd12f006c,0x291c6fc9,0x8c3c00d0,0xe0df0359}},	//   _ذمہ_, _siva_, _coğr, _ewòd_,
   {{0x8c3c0d6f,0x26d901d3,0xe0df0107,0xc27b00a5}},	//   _doğr, viso_, _fwòd_, גרפי,
   {{0x224939fc,0x00000000,0x00000000,0x00000000}},	//   zaak_, --, --, --,
   {{0xb8dc0299,0x64450d0d,0x26d96fca,0x29020029}},	//   _इक_, _rehi, tiso_, ēka_,
   {{0x64453635,0x2f970070,0x656f02b1,0x645a008d}},	//   _sehi, אכטן_, ttch, ótin,
   {{0x44210159,0x26d96fcb,0x64451785,0x25bf006c}},	//   _pgh_, riso_, _pehi, ául_,
   {{0x61fd093a,0x00000000,0x00000000,0x00000000}},	//   _rysl, --, --, --,
   {{0xd6d10a72,0x26d95a5a,0x77924e4a,0x64454d29}},	//   _وقت_, piso_, _ایجا, _vehi,
   {{0xa6ab0a72,0x66c66fcc,0x59d90026,0x1dc409b8}},	//   _سابق_, _póke, _बेडर, वनात,
   {{0xd1310427,0x22496fcd,0xa1581018,0x644500ab}},	// [71f0] زما_, raak_, лату_, _tehi,
   {{0x04670d8d,0x7e696fce,0x442114d8,0x61fd024e}},	//   _стим, _scep, _ugh_, _vysl,
   {{0x80073f9f,0x00000000,0x00000000,0x00000000}},	//   учае, --, --, --,
   {{0x66f7051e,0x394d093a,0xd13000b5,0x67050ca1}},	//   ीतिक_, yses_, تمے_, रतिक_,
   {{0xa2ba16d3,0x6da51dd6,0x628f6fcf,0xada50421}},	//   _एकत्, рила, _iaco, ралл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628f0118,0x2bd8022e,0xeab10079,0xfaa50328}},	//   _kaco, _भेदा, قعة_, иако,
   {{0x394d6fd0,0x628f05d6,0x00000000,0x00000000}},	//   tses_, _jaco, --, --,
   {{0x394d6fd1,0x08c55fed,0xf1b20070,0xdd940104}},	//   uses_, ибин, ַסט_, _латы,
   {{0x394d5a87,0x3a2d0811,0x3f9800e9,0x00000000}},	//   rses_, scep_, _yrru_, --,
   {{0x394d04b0,0xeaae006c,0x00000000,0x00000000}},	//   sses_, سٹی_, --, --,
   {{0x89d60357,0xe1ff0453,0xd49100e2,0x6b9c008d}},	//   اویر_, _oyó_, ồn_, _árga,
   {{0xcb120052,0xd945136c,0xf506355e,0xa2c406fe}},	//   _ולא_, _тели, измо, रसस्,
   {{0xb4c200a1,0x00000000,0x00000000,0x00000000}},	//   ्फे_, --, --, --,
   {{0x232a1126,0x98f446c4,0xb60800fe,0x628f6fd2}},	//   тоби_, _اثنا, _buší, _baco,
   {{0xd1320037,0x00000000,0x00000000,0x00000000}},	//   قمر_, --, --, --,
   {{0x628f14fa,0x225d0035,0xb608007e,0x6906008d}},	// [7200] _daco, ówka_, _duší, iðen,
   {{0xe3ba38ac,0x628f01a6,0xbebd010b,0xa5bb0d9b}},	//   _або_, _eaco, _liūd, rcót,
   {{0x628f6fd3,0xb4c20b47,0x7e260265,0xb4db0176}},	//   _faco, ंसी_, адеж, rsàt,
   {{0x539b0122,0x277602b5,0x628f00cc,0x00000000}},	//   _סיכו, יגען_, _gaco, --,
   {{0xdd94005f,0x7aed011c,0x628408c7,0xc8780225}},	//   салы, čatl, meio, liğe_,
   {{0x61434717,0x628f3b5e,0x00000000,0x00000000}},	//   _фера, _zaco, --, --,
   {{0x69dd016f,0x798b00e5,0xa5bb6fd4,0x00000000}},	//   úsen, _asgw, ncór, --,
   {{0x628f20d9,0x8f3700a5,0xdee60d46,0x62840183}},	//   _xaco, _כאלו_, _тоби, neio,
   {{0x63bc1366,0x8d2a01e0,0x59d900b4,0xdb1800fd}},	//   hyrn, _розв_, _बेदर, nyvé,
   {{0x6f026fd5,0x8c660416,0x20070035,0xc17300a5}},	//   lloc, _خطرن, żnie_, קחת_,
   {{0x56950009,0x627e0035,0xe81100b4,0x00000000}},	//   бант, _złoż, डेला_, --,
   {{0x7bdb00a5,0x98ab00ea,0xfaa34187,0x00000000}},	//   _בקבו, īcā_, _махо, --,
   {{0x628f6fd6,0x99341d05,0xb60800d5,0x62846fd7}},	//   _raco, _افتت, _ruší, deio,
   {{0x6f025c35,0xb60800d5,0x00000000,0x00000000}},	//   hloc, _suší, --, --,
   {{0x628f6fd8,0xd9e80083,0x6aa26fd9,0x6f026fda}},	//   _paco, _পরিম, _knof, kloc,
   {{0x6f02002d,0xa3191e31,0x798b016e,0xf1bf00e2}},	//   jloc, ужбу_, _ysgw, _ngác_,
   {{0x51871012,0xc1051ee1,0x20051f6f,0x00000000}},	// [7210] шува, موري, _šli_, --,
   {{0x92d700c8,0xd9e80083,0xa7fc027d,0x6f0203d0}},	//   াকে_, _পরাম, ygıl, eloc,
   {{0x33950082,0x628f6fdb,0xb6080097,0x6f0205aa}},	//   _الجز, _taco, _tuší, floc,
   {{0x6284021d,0x00000000,0x00000000,0x00000000}},	//   ceio, --, --, --,
   {{0x6b9a1f3f,0x127a0070,0x00000000,0x00000000}},	//   _artg, _גארע, --, --,
   {{0x6aa2486c,0x4431137e,0x8c420f8c,0x00000000}},	//   _anof, ncz_, пеше, --,
   {{0xde6701d3,0x627e0067,0x00000000,0x00000000}},	//   _възп, _włoż, --, --,
   {{0x6f026fdc,0x28d90edf,0xa7fc027d,0x3a9800c3}},	//   cloc, योनि, rgıl, атью_,
   {{0xe8f9399d,0x7b2302c4,0xa2ba07df,0x627e0067}},	//   лли_, _ađut, _एकस्, _ułoż,
   {{0x2d8d027a,0x6aa2023a,0x00000000,0x00000000}},	//   _isee_, _enof, --, --,
   {{0x30fa164f,0x2cf500a1,0x66d60009,0x6aa20069}},	//   ्ततः_, ेतील_, lški, _fnof,
   {{0x66c6008a,0x5b1511b9,0x44330110,0x00000000}},	//   _bóka, _умет, _afx_, --,
   {{0x3a3f4808,0x66080035,0x59c40037,0x66d66fdd}},	//   mbup_, ędko, _ويمك, nški,
   {{0xb4c20084,0x66d600d8,0x2d8d034d,0x00000000}},	//   ंसे_, iški, _msee_, --,
   {{0xdce2044d,0xdddb0a66,0x78a31a9e,0x7e7b6fde}},	//   stoć, _nauž, _innv, _obup,
   {{0x443330bc,0x86463db0,0x60c70207,0x44310067}},	//   _efx_, _униж, _aljm, acz_,
   {{0x95560071,0x31230036,0x463b0070,0x2d8d0159}},	// [7220] _اخبا, здуг, _געפע, _nsee_,
   {{0x65660dc3,0xb4db0443,0xb46603fa,0xb69b0183}},	//   mukh, ssàr, _укол, nlân,
   {{0x644e6fdf,0x61ef1116,0xee3a4ae8,0x201c02ee}},	//   mabi, _excl, гне_, ävi_,
   {{0x644e6fe0,0x61e9552b,0xf4130122,0x91e61bcb}},	//   labi, _žele, _מפת_, _гоме,
   {{0x1dd20953,0x22406fe1,0x9c7c023a,0x63a3009e}},	//   _देखत, mbik_, _ujčk, _ànnr,
   {{0x644e6fe2,0x8fa652bc,0x6f026fe3,0x395f6fe4}},	//   nabi, _лаге, sloc, drus_,
   {{0x6f020523,0xdb09024e,0x09b50033,0x00000000}},	//   ploc, žnýc, _জেলা, --,
   {{0x6566034d,0x644e062c,0xeb970274,0x290e030d}},	//   kukh, habi, сић_, _shfa_,
   {{0x644e6fe5,0xa3df0066,0x46cc00b4,0xd91a02fb}},	//   kabi, _देन_, ासनह, льо_,
   {{0xd90d0a86,0xa2d8021a,0xb4c20edf,0xe7860d6e}},	//   نین_, नोत्, ंसो_, бумо,
   {{0x644e3fb8,0xda7a02fb,0x00000000,0x00000000}},	//   dabi, _бял_, --, --,
   {{0x60de6fe6,0x316000d7,0xb5fb0037,0x6aa20b73}},	//   hipm, kriz_, lgái, _unof,
   {{0x395f6fe7,0xb5fb0098,0x00000000,0x00000000}},	//   crus_, ogái, --, --,
   {{0x316002d7,0xb5fb6fe8,0xe4e703d0,0x00000000}},	//   driz_, ngái, сімн, --,
   {{0xf8db00a5,0x320200fe,0x187700a5,0x24194194}},	//   _תחומ, _ayky_, _העור_, ровы_,
   {{0x7b15022f,0x65661775,0x386e000d,0x644e01ed}},	//   _ušut, bukh, _hcfr_, aabi,
   {{0x644e6fe9,0xcfd60033,0x320200d5,0xa2da01c0}},	// [7230] babi, _তুলন, _cyky_, _नगर्,
   {{0x644e6fea,0x660d6feb,0x764f0035,0x1154010b}},	//   cabi, _izak, lacy, якую,
   {{0x7bde0138,0x224000b5,0xb5fb00d5,0x2bd83d9e}},	//   úpul, bbik_, jfáz, _भेला,
   {{0x764f6fec,0x63ba0168,0x395f010b,0xd7fb0070}},	//   nacy, ätne, yrus_, נהאל,
   {{0x31600382,0x9cf500d4,0x00000000,0x00000000}},	//   criz_, озді, --, --,
   {{0x66d6010b,0x60c702c4,0x212b009e,0x9401013b}},	//   rški, _uljm, _iuch_, _sahə_,
   {{0x764f004e,0x3ec400b5,0xa3df00ab,0x212b0bf7}},	//   kacy, ártó_, _देम_, _huch_,
   {{0x644e6fed,0x7b150009,0xb5fb0037,0xdcfb00ea}},	//   zabi, _ašur, agái, _kruī,
   {{0x644e6fee,0x395f6fef,0x224b6ff0,0x7e640079}},	//   yabi, urus_, _meck_, óipe,
   {{0x212b0052,0xb80d0243,0xf771028c,0x395f67b2}},	//   _much_, _हरदम_, واج_, rrus_,
   {{0xb69b0279,0x16aa0a87,0x644e6ff1,0x212b0719}},	//   rlân, авни_, vabi, _luch_,
   {{0x764f6ff2,0x644e595c,0x09e80033,0x224b024b}},	//   gacy, wabi, _পররা, _neck_,
   {{0x644e6ff3,0x7ae96ff4,0x26c20196,0xa3df007c}},	//   tabi, mnet, rkko_, _देब_,
   {{0x7afb6ff5,0x7ae9402a,0x6566681e,0x42c60033}},	//   lout, lnet, rukh, _এদেশ,
   {{0x212b0446,0x36e9006c,0x660d2efd,0x224b6ff6}},	//   _auch_, _گروپ_, _ezak, _beck_,
   {{0x7ae90c89,0x31601423,0x212b01ae,0x644e6ff7}},	//   nnet, triz_, _buch_, sabi,
   {{0xe0da001f,0x644e6ff8,0x59c96ff9,0x7ae96ffa}},	// [7240] ава_, pabi, िनिर, inet,
   {{0x31600291,0x7ae96ffb,0x7afb6ffc,0xd5e00035}},	//   rriz_, hnet, hout, _पेयज,
   {{0x212b02c9,0x29050086,0x7ae9030a,0x7afb4235}},	//   _euch_, illa_, knet, kout,
   {{0xe29a2dc5,0x28d96ffd,0x7afb6ffe,0x31606fff}},	//   _там_, योति, jout, priz_,
   {{0x7ae97000,0x7afb7001,0x0caa7002,0xddc80035}},	//   dnet, dout, итки_, _żołn,
   {{0xd0e804e8,0x764f5f2a,0x7ae901d7,0x659b016b}},	//   _اکرم_, zacy, enet, יינק,
   {{0xf76701ca,0x7afb32ef,0xb5fb0079,0x7ae9033b}},	//   _تا_, fout, rgái, fnet,
   {{0x29057003,0x7afb7004,0x62966251,0x66c60093}},	//   ella_, gout, ndyo, _sókn,
   {{0x66047005,0x764f0120,0x68fa002d,0x672a01e9}},	//   _nyik, vacy, totd, _sufj,
   {{0x1d0a0133,0xb17b02b5,0x26c9011c,0x764f7006}},	//   _тези_, סטיר, _slao_, wacy,
   {{0x660d0332,0xa09b02b5,0x8ca70035,0x660404fb}},	//   _szak, בייט, चारो, _ayik,
   {{0x99e80083,0xd6db2846,0x29050086,0x66c600ee}},	//   _পরীক, рто_, alla_, _dóko,
   {{0x764f7007,0x2bde1ef5,0x672409df,0x6604007b}},	//   racy, _केतू_, _diij, _cyik,
   {{0x7ae07008,0xd5b801c8,0x212b0f86,0x67240103}},	//   limt, іся_, _ruch_, _eiij,
   {{0x57f32f7b,0x212b7009,0x533417d0,0x98a30200}},	//   _општ, _such_, дест, _ције,
   {{0x25a6008b,0xb88200b8,0x2ab100fe,0x660d01b7}},	//   _šole_, řídi, _báby_, _tzak,
   {{0x69c0700a,0x660d4093,0xd52d00e2,0x00000000}},	// [7250] nyme, _uzak, _dựn, --,
   {{0xcf9b0500,0x7ae003be,0x7ae900b8,0x7aed02b2}},	//   ије_, himt, znet, čati,
   {{0x752d0031,0x7ae008c7,0x224b700b,0x69c0099e}},	//   _huaz, kimt, _teck_, hyme,
   {{0xe8a706bc,0xc7b302b8,0x7982004e,0x23fa00a5}},	//   _कच्च, ובע_, _opow, _להתא,
   {{0xa3df0b39,0x2905700c,0x752d0132,0xaaa905b7}},	//   _देत_, ylla_, _juaz, कासक,
   {{0x91ba0122,0x7afb700d,0xd7ca0253,0xccfb0200}},	//   _המשי, wout, ानाच, шће_,
   {{0x447c00c2,0x7afb700e,0x79820051,0x7f580adb}},	//   ינגע, tout, _apow, _марс_,
   {{0xe7fe0084,0xfbd000bf,0x4aa90384,0x7ae01732}},	//   _उड़ा_, خته_, скин_, gimt,
   {{0x29050443,0x2d990453,0x69c0580c,0x31690065}},	//   tlla_, _ése_, gyme, nuaz_,
   {{0x7afb700f,0x7ae97010,0x88c91c76,0x29051402}},	//   sout, snet, слов_, ulla_,
   {{0xb8e30461,0x07a52327,0x7ae920ee,0x764d00e0}},	//   _एक_, чанн, pnet, _beay,
   {{0x752d0103,0x6a9401e0,0x31690065,0x00000000}},	//   _buaz, _оріє, kuaz_, --,
   {{0x6b50004f,0x00000000,0x00000000,0x00000000}},	//   _tógá, --, --, --,
   {{0x69d400be,0x80ba0067,0x2a6d00be,0xddc90168}},	//   _बेटी, _इवें, lgeb_, _obež,
   {{0x68e17011,0x7cf600af,0x03a30421,0x99dd0097}},	//   mild, târz, ниро, raňu,
   {{0x6e2900f8,0x61e97012,0xc32300ed,0x1dbd143a}},	//   _ngeb, _žela, емск, ्नात,
   {{0x752d30af,0xdb0a00b5,0xa2cd05a6,0x31690065}},	// [7260] _guaz, ínés, _सतर्, guaz_,
   {{0xb4663816,0x6e29030d,0x68e17013,0x7ae0023c}},	//   _экол, _ageb, nild, zimt,
   {{0x69c0302f,0x752d0065,0x00000000,0x00000000}},	//   zyme, _zuaz, --, --,
   {{0x68e1386f,0x2d9f7014,0x25a002a7,0x00000000}},	//   hild, _brue_, _kril_, --,
   {{0x68e17015,0x1d0a24c8,0xe29b00a5,0x2d9f428c}},	//   kild, беди_, _השכר, _crue_,
   {{0x2d9f0a8a,0x6e290a8a,0x00000000,0x00000000}},	//   _drue_, _egeb, --, --,
   {{0x6fb616a4,0x79820035,0x7ae07016,0x68e17017}},	//   _عمرا, _spow, timt, dild,
   {{0x7d010009,0x2d9f0a8c,0x78b87018,0x66c60093}},	//   _ekls, _frue_, _sovv, _bókm,
   {{0x7ae0573c,0x68e17019,0x2d9f701a,0xeaaf0079}},	//   rimt, fild, _grue_, اعى_,
   {{0x02c909b8,0x7ae0701b,0x764d012f,0x68e1701c}},	//   _रत्न, simt, _seay, gild,
   {{0x25a000d7,0xa09b0070,0x752d0c6f,0x69c00090}},	//   _aril_, זייט, _suaz, syme,
   {{0x25a011cc,0xe0df0107,0x69c002d7,0xa3c2021a}},	//   _bril_, _awòl_, pyme, ्नन_,
   {{0x68e1701d,0x18a6701e,0xaaa900a9,0x2b40003a}},	//   bild, _надм, कारक, ćicu_,
   {{0x65600079,0xf53f0304,0x00000000,0x00000000}},	//   ámha, rpå_, --, --,
   {{0x187b0122,0xa87b00a5,0xd7ef019e,0x25a00176}},	//   _הטוב, _האור, _чу_, _eril_,
   {{0x316901a3,0x00000000,0x00000000,0x00000000}},	//   tuaz_, --, --, --,
   {{0x44f522f1,0x25a006e7,0xc2c4004f,0xa0c50088}},	// [7270] _опис, _gril_, ريكي, ويرو,
   {{0x66f200ea,0x316901a3,0x6e29009e,0xbebd005f}},	//   māka, ruaz_, _sgeb, _ciūn,
   {{0x2fc700e8,0x66f20029,0x6d494c19,0xdce900ee}},	//   áng_, lāka, _swea, _preľ,
   {{0xd0920095,0x2d9f0176,0x68e10471,0xe81400b4}},	//   _müəs, _prue_, zild, _डरना_,
   {{0x3d0902cb,0x66f20029,0x68e100a8,0xfe700041}},	//   ितले_, nāka, yild, ادم_,
   {{0x2fc700e8,0x2bde0ccf,0x2d84021d,0x68e100a8}},	//   ơng_, _केहू_, _dpme_, xild,
   {{0xfc460355,0xaaa904aa,0xddc902a7,0x00000000}},	//   _říci_, कालक, _ubež, --,
   {{0x68e1053e,0x2d9f0122,0x6e2908c8,0x998d0124}},	//   wild, _true_, _ugeb, rbež_,
   {{0xac27701f,0x68e168b7,0x2f180086,0xa3df007c}},	//   _ефек, tild, _хоть_, _देस_,
   {{0x2576008e,0x5c7404d9,0xa2a4018d,0x57e90421}},	//   væl_, _плут, _चोन्, ждом_,
   {{0x68e10092,0xc05200a5,0x00000000,0x00000000}},	//   rild, כזי_, --, --,
   {{0x25a002a7,0xddc9009f,0xc4c9024b,0xabfa024b}},	//   _pril_, _obeż, _דג_, _והער,
   {{0x68e17020,0x7bc33ae1,0x66f200ea,0x7afc00b5}},	//   pild, lynu, gāka, _írta,
   {{0xa3df0e04,0xe8f80081,0x25a000f4,0x00000000}},	//   _देह_, _елі_, _vril_, --,
   {{0x46f61159,0x02c9018d,0x00000000,0x00000000}},	//   _очит, रसंभ, --, --,
   {{0x66f20029,0x257608c8,0x00000000,0x00000000}},	//   bāka, pæl_, --, --,
   {{0xf1de06bb,0x236a0034,0x7bc37021,0x201101ef}},	// [7280] _नेशन, subj_, hynu, _azzi_,
   {{0xa3df1b8f,0xdcfb0a78,0x25bf02b1,0x00000000}},	//   _देव_, _osuđ, äule_, --,
   {{0x443a4dce,0x00000000,0x00000000,0x00000000}},	//   _ifp_, --, --, --,
   {{0x67000567,0x27330019,0x6e2d008b,0x443a0124}},	//   ैतिक_, _mãn_, žabn, _hfp_,
   {{0xb5fb2d87,0x20560340,0x1be30eff,0xdc390225}},	//   lgár, _отвр, _केबल_, _açıd,
   {{0x236503ab,0x409500ed,0x443800e5,0x00000000}},	//   šlje_, _прст, ncr_, --,
   {{0x9f88008a,0x602301c8,0xd9b80d91,0xaaa910aa}},	//   _góða_, _адра, ेन्ट, कांक,
   {{0x4438216b,0x13e10033,0x00000000,0x00000000}},	//   hcr_, _মুড়, --, --,
   {{0xb866183b,0x645e1cb0,0xadba0037,0x225d0035}},	//   وادو, _odpi, _بهذا_, ówki_,
   {{0x443a00ee,0x66f200ea,0xb5fb00b5,0x2733055c}},	//   _nfp_, vāka, zgás, _bãn_,
   {{0xda6f164d,0x1bf2063f,0xeb9a0043,0x44380027}},	//   _ия_, _अखिल_, _фие_, dcr_,
   {{0x443a7022,0xf76f0118,0x59d904bc,0x66f200ea}},	//   _afp_, گای_, _बेकर, tāka,
   {{0x443a598f,0x6d4201d7,0xceb3011d,0xd6d800af}},	//   _bfp_, npoa, דיר_, фтэ_,
   {{0xf76f00f8,0x66f200ea,0xf4842d7a,0x2615073f}},	//   دای_, rāka, кусн, नेगी_,
   {{0xa3df0ec5,0x6566012f,0x00000000,0x00000000}},	//   _देश_, arkh, --, --,
   {{0x2bb619b7,0x443a027a,0x32647023,0x60ce0c6f}},	//   _अपना, _efp_, ктув, _albm,
   {{0xa3df0b4a,0xa2c4022e,0x02df030f,0xb5fb00b5}},	// [7290] _देर_, रसज्, _नगीन, rgás,
   {{0x2ec70bdd,0x395905ee,0x43957024,0x443a0f00}},	//   लस्त, ássi_, _заос, _gfp_,
   {{0x64557025,0x66c6008d,0x00000000,0x00000000}},	//   mazi, _bókh, --, --,
   {{0x7c3a173a,0xa25b00f7,0x3ea901b7,0xe0df021e}},	//   _aftr, _clôt, ñat_, _kwòk_,
   {{0xdd9400d8,0x2d58002d,0xceb900fe,0x00000000}},	//   кацы, дичь_, _jiři_, --,
   {{0x64557026,0xeb997027,0x8b9503fa,0xd0450987}},	//   nazi, зик_, ерич, _سپري,
   {{0x780d01c0,0x2011030d,0x00000000,0x00000000}},	//   _हरेक_, _uzzi_, --, --,
   {{0xa3c206bb,0x78aa0107,0xfcd900b5,0x645534e4}},	//   ्नत_, _anfv, _کارڈ_, hazi,
   {{0x64557028,0x68ef1111,0x7bce033b,0xe8ca01c0}},	//   kazi, écdo, _übun, िसूच,
   {{0xb4be0006,0xb8810187,0x64557029,0x6d59034d}},	//   _आवे_, _číse, jazi, mswa,
   {{0x6455702a,0x6d594646,0xdcfb011c,0x00000000}},	//   dazi, lswa, _usuđ, --,
   {{0x7ac4702b,0xeaae00d8,0xa5bb02d7,0x273300e2}},	//   _исче, _ёй_, lcóy, _vãn_,
   {{0x6d59702c,0x6455702d,0x6aab027a,0xe8ee3df1}},	//   nswa, fazi, _ingf, _бл_,
   {{0xbebd01c8,0x6d590051,0x81b50033,0x00000000}},	//   _siūl, iswa, জনা_, --,
   {{0x6383702e,0x443a0036,0xb4e00066,0x07a52521}},	//   лгра, _vfp_, _दगी_, _чайн,
   {{0x6d59241c,0x3d160461,0x7b05002a,0x6e3b030d}},	//   kswa, _पीने_, móus, _nfub,
   {{0x64a6702f,0x64557030,0xe04607be,0xe1ff0037}},	// [72a0] _запа, bazi, ензи, _scór_,
   {{0x64550133,0xa2c400b8,0x6d590afc,0xc05900d4}},	//   cazi, रसङ्, dswa, дії_,
   {{0x9e66095d,0x6d590051,0xb4cc0354,0x7b0501ef}},	//   евед, eswa, लसी_, nóus,
   {{0x481602b5,0x66c60093,0xddc000b8,0xee37280a}},	//   ײַבן_, _bóki, _zemř, енц_,
   {{0xdd940763,0x6da30896,0x6d597031,0xfce6261f}},	//   талы, лица, gswa, нодо,
   {{0x6e3b030d,0x00000000,0x00000000,0x00000000}},	//   _efub, --, --, --,
   {{0xa3c2045c,0x7ac60086,0x6d5912ba,0x6d4201ed}},	//   ्नि_, еспе, aswa, spoa,
   {{0x64550291,0x31920107,0x7d050160,0xc333024b}},	//   zazi, _kņz_, _pîrî, נוח_,
   {{0x4c8638d0,0x64557032,0x6d5908c7,0x66e400b5}},	//   _плав, yazi, cswa, tőkn,
   {{0xeb9a04bf,0xa3c219b7,0x6d400069,0x6455413e}},	//   _низ_, ्ना_, _itma, xazi,
   {{0x64557033,0xa3df004e,0x2cac7034,0x96f97035}},	//   vazi, _दें_, _indd_, дент_,
   {{0x64553eb0,0x3ce60026,0x56940d13,0x212a0079}},	//   wazi, _झगडे_, гают, _libh_,
   {{0x64557036,0x7ae2025c,0x00000000,0x00000000}},	//   tazi, _imot, --, --,
   {{0xdce2024e,0x7ae2024e,0x212a0090,0xab6402c9}},	//   kroč, _hmot, _nibh_, _grüß,
   {{0x64557037,0xa737004f,0x7ae200ac,0x7b05002a}},	//   razi, _كثير_, _kmot, cóus,
   {{0x64557038,0xdce2108a,0x290c7039,0x212a01da}},	//   sazi, droč, llda_, _aibh_,
   {{0x6455703a,0x69d6027d,0x7ae2018e,0x00000000}},	// [72b0] pazi, _üyed, _mmot, --,
   {{0x657d006d,0x656f07df,0xdce9007a,0x00000000}},	//   mtsh, much, _iseħ, --,
   {{0x6d40703b,0x7ae21321,0x28b104aa,0x657d64d3}},	//   _atma, _omot, जाति, ltsh,
   {{0x6d59703c,0xf4120122,0x7bd802c4,0x59b000c0}},	//   tswa, _כפי_, dzvu, जमार,
   {{0x657d6b9f,0x6d59703d,0x2249703e,0x212a01da}},	//   ntsh, uswa, mbak_, _fibh_,
   {{0x6d59703f,0x7ae22fba,0x224912ba,0x290c0009}},	//   rswa, _amot, lbak_, jlda_,
   {{0x09c902cb,0x6d597040,0x6d407041,0x6aab01dd}},	//   िन्य, sswa, _etma, _pngf,
   {{0x656f7042,0x290c7043,0xada601ba,0xeab10037}},	//   kuch, elda_, _slúž, شعب_,
   {{0x61e91851,0x657d656b,0x33330160,0x00000000}},	//   _želj, jtsh, _luxx_, --,
   {{0x656f0076,0x3ebf09a6,0x4d9800d8,0x657d03bc}},	//   duch, _hout_, _якую_, dtsh,
   {{0x3ebf02e9,0x3a757044,0x366a7045,0x00000000}},	//   _kout_, _алер, мано_, --,
   {{0x66e61b0a,0xdb0100f7,0x6aab63a4,0x656f228c}},	//   тома, _orlé, _ungf, fuch,
   {{0x3ebf0051,0x3ead5d43,0x63a5008c,0x7b0501ef}},	//   _mout_, _mnet_, _arhn, sóus,
   {{0x7d037046,0x7ae24962,0x31692a9e,0x224901ed}},	//   nons, _zmot, draz_, ebak_,
   {{0x3ead7047,0xe7b200d1,0x316901a3,0x212a19fd}},	//   _onet_, _نمود, eraz_, _ribh_,
   {{0x212a111c,0x656f5c90,0x657d7048,0x63a500d5}},	//   _sibh_, buch, btsh, _drhn,
   {{0x656f0083,0x26d2007b,0x28a600b4,0x65b4007e}},	// [72c0] cuch, _ilyo_, _कोडि, _džhá,
   {{0x23650528,0xe04306a6,0x3ebf1f3c,0x7d0300d4}},	//   šlja_, инуи, _aout_, jons,
   {{0x7d03543f,0x3ebf7049,0x6d40007a,0xa3df0930}},	//   dons, _bout_, _stma, _देऊ_,
   {{0xcfa90082,0x3169704a,0x3ebf00a2,0xe35700a5}},	//   عالم_, braz_, _cout_, _בשטח_,
   {{0x2907704b,0x3ebf02d0,0x6f02704c,0x290c704d}},	//   _okna_, _dout_, rooc, ylda_,
   {{0x7d033bc7,0x7ae2704e,0xdce21abc,0x50432d2b}},	//   gons, _smot, proč, _верб,
   {{0x3ebf704f,0x656f7050,0xa3e800be,0xc0e37051}},	//   _fout_, zuch, _मेम_, _торк,
   {{0x49740370,0xf8ca09b1,0x3ebf7052,0xb9987053}},	//   глис, िस्प, _gout_, евих_,
   {{0x0d7700bf,0xc87801d6,0xeef500d8,0x6d40014e}},	//   _لینک_, liği_, _сярэ, _utma,
   {{0x52bf0d00,0x1be3004e,0xa8a62bc4,0x02df00b4}},	//   _एक्स, _केवल_, трик, _नग्न,
   {{0x656f033b,0xc878027d,0xdb1800c3,0x628615ce}},	//   wuch, niği_, tyvä, _obko,
   {{0x656f7054,0x7ae21fb5,0x7c2700b5,0x657d2a5e}},	//   tuch, _umot, _újra, ttsh,
   {{0x656f02d7,0xb8960037,0x00000000,0x00000000}},	//   uuch, _للشع, --, --,
   {{0x656f7055,0x657d7056,0xa3df073f,0x645a4a22}},	//   ruch, rtsh, _देउ_, ótip,
   {{0x656f02bf,0x657d30bc,0x68e87057,0xdfe10035}},	//   such, stsh, midd, _गेंद_,
   {{0x63a55b2d,0x68e80273,0xc87801d6,0x7d030121}},	//   _vrhn, lidd, diği_, zons,
   {{0x3ebf0359,0x22497058,0x7d037059,0xdddb00d5}},	// [72d0] _rout_, rbak_, yons, _obuš,
   {{0x3169705a,0x660d705b,0x68e801a8,0x3ebf03bc}},	//   rraz_, _iyak, nidd, _sout_,
   {{0x7d034760,0x660d012f,0x3ebf0260,0x672d002f}},	//   vons, _hyak, _pout_, _kiaj,
   {{0x660d01a8,0x68e80510,0x26c0002a,0x7d03007b}},	//   _kyak, hidd, _xoio_, wons,
   {{0x7d0303d0,0x629d705c,0x68e801a8,0xd9e10067}},	//   tons, _iaso, kidd, गज़ात_,
   {{0x629d006c,0x9b4500ce,0x3ebf02e9,0x660d050f}},	//   _haso, هنتو, _wout_, _myak,
   {{0x3ebf705d,0x629d61d0,0x7d03705e,0x68e80103}},	//   _tout_, _kaso, rons, didd,
   {{0x629d705f,0x672d7060,0x8d744574,0x7d037061}},	//   _jaso, _niaj, _چالا, sons,
   {{0x7d037062,0xdd94057a,0x629d1ce2,0x660d4ac6}},	//   pons, _каты, _maso, _nyak,
   {{0x629d7063,0x68e801a8,0xe8f60421,0x26d90031}},	//   _laso, gidd, ллы_, ëron_,
   {{0x28d90653,0x660d01d6,0x9c7c0009,0x26c0002a}},	//   योगि, _ayak, _umča, _poio_,
   {{0x660d050f,0x28b10026,0x02d200be,0x4e1704aa}},	//   _byak, जाहि, _सतेन, _तराई_,
   {{0x7ae97064,0x672d402e,0xa97902b5,0x68e87065}},	//   miet, _diaj, _נאַכ, bidd,
   {{0x7ae97066,0x6abb39a2,0x660d6e35,0xa3c237e8}},	//   liet, ljuf, _dyak, ्नल_,
   {{0x629d7067,0x29057068,0x69c90103,0x660d01a8}},	//   _baso, mola_, lyee, _eyak,
   {{0x7ae97069,0xe2973be4,0x29050f51,0x6abb706a}},	//   niet, лас_, lola_, njuf,
   {{0x660d706b,0x69c9276d,0x69db1725,0x629d0107}},	// [72e0] _gyak, nyee, nzue, _daso,
   {{0x7ae9706c,0x2905706d,0x69c90103,0x6f09012f}},	//   hiet, nola_, iyee, _akec,
   {{0x7ae9706e,0x629d0c1f,0x2be300a1,0x6f1b0341}},	//   kiet, _faso, _केलं_, _bhuc,
   {{0x629d0c1f,0x2905706f,0xc878027d,0x7ae97070}},	//   _gaso, hola_, riği_, jiet,
   {{0x29057071,0x7ae97072,0x69c9006d,0x00000000}},	//   kola_, diet, jyee, --,
   {{0x629d5f2d,0x6284027a,0xe7d30026,0x2f1501ff}},	//   _zaso, lfio, दनाप, råga_,
   {{0x29057073,0x69c90103,0x629d01d0,0x7ae97074}},	//   dola_, eyee, _yaso, fiet,
   {{0x61e902dd,0xa3bc0ccf,0x7ae97075,0x5a3406c2}},	//   _želi, _आपन_, giet, шнит,
   {{0x290500d5,0x6da35ca3,0x2bb600e7,0x6284001e}},	//   fola_, _лита, _अपवा, ifio,
   {{0x672d034d,0x660d01d5,0x00000000,0x00000000}},	//   _siaj, _ryak, --, --,
   {{0x7ae97076,0xbec200da,0x68e80273,0x660d65fc}},	//   biet, _çësh, ridd, _syak,
   {{0x68e87077,0x7ae94d29,0x75360282,0x69c97078}},	//   sidd, ciet, _buyz, byee,
   {{0x672d7079,0x2905707a,0x7bca707b,0x00000000}},	//   _viaj, bola_, lyfu, --,
   {{0x29056ee9,0xa3c201d1,0x660d0054,0x629d707c}},	//   cola_, ्नं_, _vyak, _saso,
   {{0xa3df27bd,0x629d707d,0x672d006d,0xb2ab5451}},	//   _देख_, _paso, _tiaj, нтаж_,
   {{0x660d1a22,0x6e2d02c4,0x00000000,0x00000000}},	//   _tyak, žabi, --, --,
   {{0x629d002a,0xdcfb0a78,0x2018028b,0x660d4583}},	// [72f0] _vaso, _upuć, _azri_, _uyak,
   {{0x629d0a15,0x7ae901d7,0x25a908dd,0x3d0e0067}},	//   _waso, ziet, _iral_, ितों_,
   {{0x629d707e,0xa3c20b35,0x5f95707f,0x74150ef2}},	//   _taso, ्नः_, риет, _خودا,
   {{0x29057080,0x69c92884,0x25a900c1,0x28a60d43}},	//   zola_, yyee, _kral_, _कोसि,
   {{0x7ae97081,0xe80b0299,0x290501a8,0x4e78097f}},	//   viet, _सुना_, yola_, احمد_,
   {{0x7ae97082,0x69c901e8,0xdca538bb,0x98a7023a}},	//   wiet, vyee, раки, _pinč_,
   {{0x290501af,0x273a00da,0x7ae97083,0x6f1b7084}},	//   vola_, _nën_, tiet, _thuc,
   {{0x64577085,0x2bb60e6f,0x69db0291,0xfbb60387}},	//   _lexi, _अपरा, tzue, _अपरम,
   {{0xc8b510b0,0xe8f97086,0x8c3c045e,0xd90c03fc}},	//   асны, кли_, _bağd, کیو_,
   {{0x273a00da,0x69db7087,0x52d202b4,0xddc0027d}},	//   _bën_, rzue, _सत्स, _hemş,
   {{0x7ae97088,0x25a900a7,0x3f8146a6,0xf092011d}},	//   piet, _aral_, nthu_, חני_,
   {{0x29057089,0x3f8100e9,0x25a92018,0x28d9111a}},	//   sola_, ithu_, _bral_, योजि,
   {{0x290502b2,0x66f20029,0x25a90036,0x645706f2}},	//   pola_, nāki, _cral_, _bexi,
   {{0xccf202b5,0x20f40d00,0x64a6061c,0x934618e8}},	//   ַכן_, _आदेश_, шага, инге,
   {{0x7e7b708a,0x42561e26,0x6457708b,0x395f708c}},	//   _ocup, итат, _dexi, lsus_,
   {{0x7a2b0463,0xd7fa0122,0x3a3f012f,0x64570069}},	//   _götü, _בהצל, ncup_, _eexi,
   {{0xe2970265,0x2327708d,0x25a90453,0x00e6708e}},	// [7300] шат_, роти_, _gral_, ажан,
   {{0x6ad2012f,0xe0d72401,0xf1bf0391,0xe3e7006c}},	//   _तत्र, аву_, _agás_, اکین_,
   {{0x395f1008,0xdb010312,0x6e460220,0x00000000}},	//   hsus_, _arlí, لنام, --,
   {{0x395f708f,0xf2a60043,0xe0df0260,0x7e7b030d}},	//   ksus_, _тимп, _bwòs_, _ccup,
   {{0x81e40083,0x3a3f6b33,0xe2977090,0x463b0070}},	//   _পুর_, dcup_, _тая_, דענע,
   {{0x31600448,0x23ba07df,0xfb660274,0x7b660665}},	//   msiz_, _उपाद, ањим, атие,
   {{0x3160045e,0x395f7091,0x645c2741,0x00000000}},	//   lsiz_, esus_, iari, --,
   {{0x645c7092,0x09e70083,0x8f9b0100,0x22407093}},	//   hari, _পড়া, _בילי, ncik_,
   {{0x645c7094,0x316000d0,0xee0a14a1,0x66f200ea}},	//   kari, nsiz_, _реал_, cāki,
   {{0x28a60953,0x645c7095,0xdbdc0187,0x98b80183}},	//   _कोशि, jari, lším, улот_,
   {{0x64571a71,0x10370122,0x2240028b,0xb037016b}},	//   _rexi, יטים_, kcik_, יניג_,
   {{0x25a9142f,0x28a6131c,0x3160033e,0xdbdc00ac}},	//   _pral_, _कोरि, ksiz_, nším,
   {{0x645c7096,0xe5c40340,0xe29f008e,0x00000000}},	//   fari, осро, _rað_, --,
   {{0x645c7097,0x3160013b,0x00000000,0x00000000}},	//   gari, dsiz_, --, --,
   {{0xa3bc0429,0x64573762,0x2ba90084,0xd82f002d}},	//   _आपण_, _vexi, किया, _фэ_,
   {{0x39460035,0xdbdc0187,0x645c1e7b,0x66e403e6}},	//   _ktos_, jším, aari, _моја,
   {{0x645c4f32,0x765d033f,0x9487002d,0x00000000}},	// [7310] bari, masy, _кынд, --,
   {{0x765d7098,0x4499093c,0x66f200ea,0xbebd00c7}},	//   lasy, _свою_, vāki, _liūt,
   {{0x92957099,0x2d8d3bd6,0x2fc746e0,0x32070035}},	//   _ланц, _spee_, âng_, łny_,
   {{0x765d7098,0x3f81001e,0x61e9044d,0xbe88021d}},	//   nasy, rthu_, _želu, исче_,
   {{0x8c450dc8,0x395f00a8,0x6da5709a,0x3946006d}},	//   беле, xsus_, сила, _ntos_,
   {{0x7c87002d,0x765d081b,0x66f200ea,0x395f00ab}},	//   руде, hasy, rāki, vsus_,
   {{0x765d26a0,0x3946709b,0x2259709c,0x00000000}},	//   kasy, _atos_, _kesk_, --,
   {{0x213901d2,0x645c709d,0x395f007c,0xc3340122}},	//   _kush_, zari, tsus_, חוק_,
   {{0x645c709e,0x3a3f01a2,0xf991004f,0x765d709f}},	//   yari, rcup_, سبة_, dasy,
   {{0x645c70a0,0x71d80122,0x225970a1,0x21390c6f}},	//   xari, יוחד_, _lesk_, _mush_,
   {{0x395f70a2,0x645c40bb,0x69d60225,0x39461763}},	//   ssus_, vari, _üyen, _etos_,
   {{0x765d70a3,0xa3e870a4,0x3160438e,0x2b810035}},	//   gasy, _मेष_, ysiz_, móc_,
   {{0xa969014d,0x21390395,0x00000000,0x00000000}},	//   _сила_, _nush_, --, --,
   {{0x2ed410aa,0xdb08488c,0x044370a5,0x2a660160}},	//   _दत्त, _ardè, зерн, _zdob_,
   {{0x4adb007c,0x765d70a6,0x38675056,0xb4d8021a}},	//   _बताव, basy, _idnr_, _ाती_,
   {{0x316070a7,0x3d0900a1,0x22590392,0x2139024b}},	//   tsiz_, ाकडे_, _cesk_, _bush_,
   {{0xe80b00be,0x3946011e,0x645c70a8,0x8e2031ee}},	// [7320] _सुता_, _xtos_, pari, гiн_,
   {{0x645c20e2,0x316004d4,0x21394148,0xda0a00ab}},	//   qari, rsiz_, _dush_, _हँसत_,
   {{0x444401f3,0xbbb61bb5,0x316000c1,0xa85a016b}},	//   _if_, _अपेक, ssiz_, רדעכ,
   {{0xe8e001a5,0x6564023a,0x31601008,0xa77a016b}},	//   _thủy_, _kvih, psiz_, טרעפ,
   {{0x2cea0d36,0x31600be2,0xa3c20067,0x00000000}},	//   лько_, qsiz_, ्नक_, --,
   {{0x765d1d49,0x3ea001c0,0x62966251,0x614301ee}},	//   zasy, žit_, leyo, _хера,
   {{0x765d02e9,0xdbdc0097,0x394670a9,0x00000000}},	//   yasy, pším, _stos_, --,
   {{0x656f0297,0x386701ef,0x39460138,0xcff71804}},	//   yrch, _adnr_, _ptos_, _הצלה_,
   {{0x44446a92,0x765d3786,0x66f20029,0x38c800f8}},	//   _of_, vasy, nāku, لادی_,
   {{0xdd8f00bf,0x656f0237,0xf1b30122,0xe1ff0138}},	//   _سوم_, vrch, פסת_, _odón_,
   {{0xa3e80325,0x765d70aa,0x30fb012f,0x48a7037c}},	//   _मेल_, tasy, ्वतः_, стым_,
   {{0x444470ab,0xdb08002a,0x4b370d85,0x7d0a70ac}},	//   _af_, _ordé, _הראל_, lofs,
   {{0x765d70ad,0x629670ae,0x39460dc3,0x00000000}},	//   rasy, deyo, _utos_, --,
   {{0x444470af,0x98a30086,0x765d70b0,0x897b00a5}},	//   _cf_, _ниче, sasy, _ערוצ,
   {{0x444470b1,0x765d26a0,0xdb0800f6,0x22590069}},	//   _df_, pasy, _ardé, _pesk_,
   {{0x444470b2,0x656f00ac,0x2ba90026,0x7d0a033b}},	//   _ef_, prch, किता, hofs,
   {{0x444470b3,0x6aa20054,0x00000000,0x00000000}},	// [7330] _ff_, _maof, --, --,
   {{0x444470b4,0x92e90033,0x00000000,0x00000000}},	//   _gf_, মকে_, --, --,
   {{0x629670b5,0x623503e6,0xdb0800b5,0x64450069}},	//   beyo, _мену, _erdé, _ifhi,
   {{0x44443df8,0x6aa20079,0xe0df02d0,0xe8b50387}},	//   _zf_, _naof, _ewòp_, _अच्च,
   {{0xa69c016b,0x00000000,0x00000000,0x00000000}},	//   טשאפ, --, --, --,
   {{0x1b495150,0x4f5b017e,0x98a70139,0x00000000}},	//   азки_, _مجرد_, _mină_, --,
   {{0xfd1001b2,0xdb090187,0x98a70160,0x00000000}},	//   رجه_, žníc, _lină_, --,
   {{0xcf9202b8,0xa3bc0299,0x98a70160,0x00000000}},	//   _קטן_, _आपस_, _oină_, --,
   {{0x69d60723,0x00000000,0x00000000,0x00000000}},	//   _üyel, --, --, --,
   {{0x6d490284,0xe6c50254,0x6f0b0223,0xdd0e00c1}},	//   _itea, _češć, logc, mışl,
   {{0xa3e83ded,0x444466ea,0xb8d12c29,0x6d44002d}},	//   _में_, _rf_, _ऑफ_, ţiat,
   {{0x60c76fff,0xd62a178e,0x444470b6,0x00000000}},	//   _lojm, ионе_, _sf_, --,
   {{0xdd0e037a,0x629600cc,0x98a70139,0x89370ae7}},	//   nışl, veyo, _cină_, _اعصا,
   {{0x394d70b7,0x60c702c4,0x00000000,0x00000000}},	//   mpes_, _nojm, --, --,
   {{0x44441c9e,0x629670b8,0xd3720037,0x03a31c87}},	//   _vf_, teyo, ظهر_, миро,
   {{0x25b50831,0x8c3c06d3,0x7d0a0bc6,0x444470b9}},	//   ñaló_, _mağa, zofs, _wf_,
   {{0x64a601c8,0x444466c1,0xe0df02e9,0x62960260}},	// [7340] _дапа, _tf_, _pwòp_, reyo,
   {{0x0ef40953,0x78a370ba,0x444470bb,0x26c210ec}},	//   ेक्स_, _janv, _uf_, ljko_,
   {{0xee3a70bc,0x66f20080,0x60c70d66,0x6d4970bd}},	//   ане_, sāku, _dojm, _atea,
   {{0x78a370be,0x2fc7013c,0x26c2063b,0x25a00260}},	//   _lanv, änga_, njko_, _ksil_,
   {{0xdd0e1505,0xe0df02d0,0x226500b8,0x7e691d46}},	//   gışl, _twòp_, řský_, _ddep,
   {{0x6d49004f,0xafe670bf,0xdb6a3466,0x78a30107}},	//   _dtea, _догл, арил_, _nanv,
   {{0xdfd2317b,0x66f200ea,0x6d490312,0xb4db0392}},	//   _غير_, nāks, _etea, mpàt,
   {{0x78a3201e,0x7d0a0009,0x24980120,0xff0719b3}},	//   _aanv, sofs, herm_, _деск_,
   {{0x78a370c0,0xfe4500b5,0xdb2400b5,0x24980b88}},	//   _banv, _رکنی, _ہوئی, kerm_,
   {{0x2365108a,0x320f006c,0x3ea60228,0x39820093}},	//   šlji_, ügyi_, ldot_, rðs_,
   {{0x4a462b8e,0xd7fa0842,0x25a070c1,0x2a6601d3}},	//   _днев, руп_, _asil_, _дълг,
   {{0x3ea655a5,0xd6d90035,0x3ea40185,0x00000000}},	//   ndot_, ół_, _jamt_, --,
   {{0x2d86053e,0xdb010037,0xda1e00be,0x260701e0}},	//   ntoe_, _urlá, _परित_, ючог,
   {{0x3ea60086,0x98a700af,0x98ae0260,0x3ea4008c}},	//   hdot_, _vină_, _kifč_, _lamt_,
   {{0xd25b04b2,0x92c709c2,0x36d5081b,0x00000000}},	//   ица_, ощад, _нокр, --,
   {{0x290c70c2,0xdce2012e,0xdd0e045e,0x236d70c3}},	//   loda_, broć, yışl, čej_,
   {{0x60c715b5,0x78a30095,0xdd0e00a8,0x39490031}},	// [7350] _pojm, _yanv, xışl, _çast_,
   {{0xd250006c,0x3ea670c4,0x66f20228,0x00000000}},	//   ٹنے_, edot_, sākt, --,
   {{0x6d4970c5,0xa6c800b5,0xc49a00a5,0x00000000}},	//   _stea, _طویل_, _השתת, --,
   {{0x290c0252,0x59ca0e04,0x539a0bed,0x394d598f}},	//   hoda_, िहार, _פירו, ypes_,
   {{0x290c08a9,0xdd9b01e0,0x867c00a5,0x8c450036}},	//   koda_, рше_, שרדו, пеле,
   {{0xdd0e01c2,0x459c016b,0x3156016b,0x98a70409}},	//   rışl, יסדע, _מישן_, _kiną_,
   {{0x290c4583,0x78a318ee,0x60081482,0x00000000}},	//   doda_, _ranv, _днём_, --,
   {{0x78a30260,0x93fc00a5,0xb4d8170c,0x00000000}},	//   _sanv, ילוי, _ात्_, --,
   {{0x394d02e1,0x78a35aa7,0x3d16046c,0x7c873fcb}},	//   upes_, _panv, _पीके_, _муже,
   {{0x290c70c6,0xa922005f,0xdea300b5,0xae200066}},	//   goda_, ндыл, _ریڈی, _बरतन_,
   {{0x78a31f9d,0x9f4500c3,0x3cfa0070,0xaa9501e0}},	//   _vanv, _älä_, _פלענ, _нижч,
   {{0x394d70c7,0x2ca570c8,0x78a30345,0x68fa009e}},	//   ppes_, _hald_, _wanv, antd,
   {{0x7afb70c9,0xe0df0359,0x78a370ca,0x2ca51217}},	//   mnut, _atòm_, _tanv, _kald_,
   {{0x290c01f7,0x00000000,0x00000000,0x00000000}},	//   coda_, --, --, --,
   {{0x628f70cb,0x2ca570cc,0x2eed0160,0x00000000}},	//   _bbco, _mald_, _omef_, --,
   {{0x7afb70cd,0x363601cb,0x27f801ba,0xb1466b7f}},	//   nnut, _عربس, úrne_, знал,
   {{0x3ea401b4,0x867b00a5,0xdb01017b,0x249870ce}},	// [7360] _ramt_, _הרפו, _irlä, perm_,
   {{0x7afb70cf,0x3ea42129,0x3d050067,0xa0a3449f}},	//   hnut, _samt_, शकों_, науд,
   {{0x7afb0936,0x645e0029,0x443a70d0,0x3cfe0183}},	//   knut, _iepi, _igp_, _rjtv_,
   {{0x290c1f3d,0x645e027d,0x7afb70d1,0x527629fe}},	//   zoda_, _hepi, jnut, _عاجز,
   {{0x7afb0076,0x645e61f5,0x3ea670d2,0x1ea9004f}},	//   dnut, _kepi, rdot_, تالي_,
   {{0xeaf60d00,0x361b0070,0x2d8603c4,0x2ca500af}},	//   ुक्त_, זונד, rtoe_, _cald_,
   {{0x290c0888,0x2d8603bc,0x443a70d3,0xbc670037}},	//   voda_, stoe_, _mgp_, سمين_,
   {{0x645e70d4,0x7afb0a78,0xbea32214,0x00000000}},	//   _lepi, gnut, _паск, --,
   {{0x61e470d5,0x2ca5054e,0xfe20007c,0xf1c700ac}},	//   nzil, _fald_, _बरिस_, cháč_,
   {{0x81ae0b52,0x645e1d19,0xf98f0ad9,0x61e470d6}},	//   _কথা_, _nepi, ابي_, izil,
   {{0x290c6302,0x7c3a011e,0x7afb031d,0xd7f70421}},	//   roda_, _igtr, bnut, зуя_,
   {{0xd6db0dde,0x7e620054,0x290c70d7,0x501b00a5}},	//   сто_, naop, soda_, מויו,
   {{0x290c70d8,0x690f08c8,0x645e0987,0x00000000}},	//   poda_, røer, _bepi, --,
   {{0x293702b5,0x645e70d9,0x248d0254,0x61e470da}},	//   _זאגן_, _cepi, đemo_, dzil,
   {{0x645e70db,0x7e6270dc,0x026b010b,0x00000000}},	//   _depi, kaop, йшай_, --,
   {{0x381702da,0x443a3413,0xba3d0355,0x777a0065}},	//   _מקום_, _egp_, jdůl, mutx,
   {{0x3ced004e,0xa2ce035d,0x69c0011e,0xf194399d}},	// [7370] _अगले_, _सवर्, nxme, нить,
   {{0x645e70dd,0x7c3a0159,0x443a70de,0x00000000}},	//   _gepi, _ngtr, _ggp_, --,
   {{0x7afb70df,0x00000000,0x00000000,0x00000000}},	//   ynut, --, --, --,
   {{0xf4030083,0xadf51a55,0x4421005f,0x00000000}},	//   _এরপর_, мпеш, _izh_, --,
   {{0xdca56439,0x64d100a1,0x7afb00d5,0x69c60421}},	//   дали, _सकाळ, vnut, äkel,
   {{0x2365030a,0x777a01b7,0x00000000,0x00000000}},	//   šlju_, kutx, --, --,
   {{0x7afb148a,0x2ca570e0,0x786900b5,0x00000000}},	//   tnut, _vald_, _jövő, --,
   {{0xe9d970e1,0xfe6e00f8,0x612200f7,0x2ca570e2}},	//   жки_, _نگه_, rôle, _wald_,
   {{0x6e3b0008,0x67240051,0x2d580421,0x00000000}},	//   _igub, _rhij, _нить_, --,
   {{0x6f190297,0x672401f4,0x7afb00cd,0x00000000}},	//   llwc, _shij, snut, --,
   {{0x645e70e3,0x7afb024e,0x61e4009f,0x7d040079}},	//   _repi, pnut, zzil, éise,
   {{0x645e00d1,0x443a4e5f,0x00000000,0x00000000}},	//   _sepi, _sgp_, --, --,
   {{0x18692e76,0x645e70e4,0x00000000,0x00000000}},	//   _дали_, _pepi, --, --,
   {{0x6aa970e5,0x2a7f00ab,0x442100f6,0x777a01f7}},	//   ldef, lgub_, _bzh_, butx,
   {{0xa3e8009a,0x28a626d4,0x672424dc,0xdc45010b}},	//   _मेख_, _कोटि, _thij, jūči,
   {{0x6aa9038d,0x66044036,0x2a7f70e6,0x6e3b1da1}},	//   ndef, _txik, ngub_, _ngub,
   {{0x8c3c3410,0x00000000,0x00000000,0x00000000}},	// [7380] _bağl, --, --, --,
   {{0x6e3b030d,0x79890345,0x00000000,0x00000000}},	//   _agub, itew, --, --,
   {{0x8c3c04d4,0x130a1ac5,0x64410355,0x03260f08}},	//   _dağl, _мной_, žlic, _одон,
   {{0x61e400f6,0xf42a0086,0x25b270e7,0x79890223}},	//   pzil, _enää_, _kryl_, ktew,
   {{0xdd9003c5,0x6aa92ff6,0xfce61d32,0xad260ef2}},	//   اوت_, ddef, модо, ورتو,
   {{0x6e3b01a3,0x00000000,0x00000000,0x00000000}},	//   _egub, --, --, --,
   {{0xf7670ef5,0x7e620159,0xbb470c74,0x8f7501e0}},	//   _جا_, paop, ولون_, _путі,
   {{0xf96a0086,0x00000000,0x00000000,0x00000000}},	//   орой_, --, --, --,
   {{0x7989053e,0x8c3c033e,0x20180031,0x00000000}},	//   gtew, _yağl, _hyri_, --,
   {{0x6e3b70e8,0x41bb0070,0x6d40009e,0x7c3a01ed}},	//   _zgub, קציע, _iuma, _ugtr,
   {{0x7e6070e9,0xd83870ea,0xa8a300c7,0xe0df0107}},	//   _kemp, ječe_, трык, _stòk_,
   {{0x6d4070eb,0x7e6070ec,0xb8d500ab,0x6aa90392}},	//   _kuma, _jemp, _चो_, cdef,
   {{0x7e60120d,0x6d4070ed,0x94190095,0x8cc2021a}},	//   _memp, _juma, əyən_, लापो,
   {{0x6d402d06,0x777a0b3f,0x00000000,0x00000000}},	//   _muma, putx, --, --,
   {{0x3d160953,0x6d4070ee,0xa29501c8,0xd7ef6320}},	//   _पीछे_, _luma, наві, _ру_,
   {{0x8c3c2024,0x7e6070ef,0x6d406214,0x929400d8}},	//   _sağl, _nemp, _ouma, касц,
   {{0x6d4070f0,0x26d901c8,0x628d00e9,0x00000000}},	// [7390] _numa, ūros_, rfao, --,
   {{0x657d0010,0x60c50221,0x2138021e,0xf0fb1bc6}},	//   mush, ujhm, _cirh_, ्वेद_,
   {{0x657d63f3,0x3d02012f,0x7e6000e0,0x20180090}},	//   lush, वचने_, _bemp, _cyri_,
   {{0x6d4070f1,0x7e601287,0x63a5005f,0x00000000}},	//   _buma, _cemp, _ishn, --,
   {{0x6d40454e,0x506732ff,0x657d70f2,0xbdf801b2}},	//   _cuma, _отва, nush, ورها_,
   {{0x201805ee,0x6d4070f3,0x29031bd8,0x00000000}},	//   _fyri_, _duma, čjak_, --,
   {{0x657d1596,0xeb910609,0xd6e00035,0x6d407034}},	//   hush, اظت_, ółki_, _euma,
   {{0x224914e2,0x7e600464,0x657d70f4,0x9b920413}},	//   ncak_, _gemp, kush, اليت,
   {{0x6d400ee7,0x6aa9191b,0x7d040312,0xee84010b}},	//   _guma, rdef, éisc, _шыро,
   {{0x47c50086,0x657d70f5,0x8c3c00d0,0x6aa90408}},	//   ебов, dush, _yağm, sdef,
   {{0x798970f6,0x6d4014db,0x7e600103,0x00000000}},	//   stew, _zuma, _yemp, --,
   {{0x657d70f7,0x6d4070f8,0x7e604605,0x25b2017b}},	//   fush, _yuma, _xemp, _pryl_,
   {{0x6d400be2,0x657d70f9,0xd83802f6,0x58d51e48}},	//   _xuma, gush, veče_, _подт,
   {{0x09f600a5,0x98a20fc5,0x26d90031,0x00000000}},	//   _אמנם_, _бише, ëror_, --,
   {{0xd83803c9,0x141a0037,0x232a0ea0,0x7b2a007e}},	//   teče_, سيرة_, зови_, _křup,
   {{0x657d70fa,0x8c3c027d,0x97d80037,0x00000000}},	//   bush, _rağm, _تظهر_, --,
   {{0x7e6070fb,0xd8381577,0xd3351c8a,0x2018054f}},	// [73a0] _remp, reče_, тэры, _syri_,
   {{0x7e6070fc,0x6d401221,0xd83838cb,0x22470355}},	//   _semp, _ruma, seče_, ěnka_,
   {{0x7e60108b,0xd8381575,0x48fa016b,0x273a005f}},	//   _pemp, peče_, פּמא, _kūna_,
   {{0x040b00e8,0x6d4027f9,0x8c150083,0xdee30c06}},	//   _lượn, _puma, াধান_, лохи,
   {{0x13d50083,0x6d400be2,0x00000000,0x00000000}},	//   _হইয়, _quma, --, --,
   {{0x66df01f4,0x5ba61858,0xf1bf00e2,0x00000000}},	//   _mëka, ериз, _ngáy_, --,
   {{0x910302f3,0xdb080037,0xfca90118,0x6adb0035}},	//   _спре, _ardá, بانو_, बसूर,
   {{0x6d4070fd,0x657d01d5,0xa3c10099,0x00000000}},	//   _tuma, yush, ंमत_, --,
   {{0x6d4070fe,0xdee31052,0xb9970f99,0x999700af}},	//   _uuma, _соти, евых_, екыт_,
   {{0x60ce70ff,0x657d7100,0x4973010b,0x00000000}},	//   _jobm, vush, ыльс, --,
   {{0x60ce011e,0x273a010b,0x62867101,0x040b00cc}},	//   _mobm, _būna_, _ocko, _dượn,
   {{0x09e6052c,0x98a706fe,0x00000000,0x00000000}},	//   _поен, _kině_, --, --,
   {{0x1af702b5,0xe97310ee,0x99d314ac,0xceb300a5}},	//   _אמאל_, _مهند, _متوا, איר_,
   {{0x657d7102,0x2edd0096,0x80c40026,0x32190e7d}},	//   rush, _मत्त, राफे, _rysy_,
   {{0x25bf0043,0x657d0c3a,0x4394135b,0xad1b00a5}},	//   ţul_, sush, ларс, פולר,
   {{0x41e73665,0x657d7103,0x78aa017b,0x926b005f}},	//   ніза, push, _hafv, ярга_,
   {{0x22492a73,0x60ce0090,0x764d0027,0x00000000}},	// [73b0] rcak_, _bobm, _ifay, --,
   {{0xd56402fb,0x656d0371,0x00000000,0x00000000}},	//   _стъп, _ivah, --, --,
   {{0xc1040037,0x00000000,0x00000000,0x00000000}},	//   دولي, --, --, --,
   {{0xb1840334,0x1dac1604,0x64d122a7,0xd35600a5}},	//   šťas, चिंत, _सकुश, _שירי_,
   {{0xada51ac5,0x6da516ed,0x60ce023a,0x00000000}},	//   талл, тила, _fobm, --,
   {{0xeb99271c,0xd37801cc,0x3ea97104,0x656d007b}},	//   дик_, šće_, žat_, _mvah,
   {{0xa3c300ab,0xe81022a3,0x764d0118,0x00000000}},	//   ्हि_, _ठुला_, _ofay, --,
   {{0x9f340185,0x60ce0116,0x00000000,0x00000000}},	//   _бесі, _zobm, --, --,
   {{0xf40000af,0xf2d4016b,0x00000000,0x00000000}},	//   ăţii_, טעק_, --, --,
   {{0xa3c30325,0xe8f62ad9,0xadf40bfe,0x80c41140}},	//   ्हा_, клы_, _спуш, राये,
   {{0x66e65a00,0xe80b00be,0x040b0023,0x656d0027}},	//   вона, _सुखा_, _vượn, _avah,
   {{0x613400a8,0x00000000,0x00000000,0x00000000}},	//   rülə, --, --, --,
   {{0x040b0028,0x80c400b4,0x38ca00e0,0xe9ce1c87}},	//   _tượn, रामे, سایی_, _тк_,
   {{0xe9d838ac,0x6aab2c7a,0x64a60274,0x34d1012f}},	//   _які_, _hagf, њава, _सकृद,
   {{0xe3631052,0x764d0103,0x07a57105,0x63860382}},	//   икри, _ffay, _райн, ъгва,
   {{0x06f600bf,0x9f9d021d,0x00000000,0x00000000}},	//   _جستج, nçõe_, --, --,
   {{0x2619009a,0xa5263367,0x00000000,0x00000000}},	// [73c0] _युपी_, _имид, --, --,
   {{0x9ffa0172,0x62330274,0x6aab7106,0x00000000}},	//   وراء_, ређу, _lagf, --,
   {{0xdd1c01ba,0xb4790070,0xaa1e01c0,0x00000000}},	//   _nášh, _אָרי, _पर्छ_, --,
   {{0xde7600fd,0x00000000,0x00000000,0x00000000}},	//   ئداع, --, --, --,
   {{0xdcfb009f,0x00000000,0x00000000,0x00000000}},	//   _ssuġ, --, --, --,
   {{0x2b5e028b,0x6284027a,0x00000000,0x00000000}},	//   _pwtc_, lgio, --, --,
   {{0x6aab0b3e,0x3a20023a,0x00000000,0x00000000}},	//   _bagf, _šip_, --, --,
   {{0xd83813a6,0x2b5500d1,0xbdc600fd,0x1eaa0098}},	//   ječa_, ایند_, _لگتے_, _غازي_,
   {{0x6da30994,0x6aab7107,0x6f02009e,0xbd8a00bf}},	//   _кита, _dagf, mnoc, _زنان_,
   {{0x2ee6320a,0xd7fa03e6,0x6f027108,0x00000000}},	//   lhof_, дум_, lnoc, --,
   {{0x47350f94,0x88bc00b8,0x6aab3d9d,0x656d7109}},	//   лнос, dmět, _fagf, _svah,
   {{0x6f02710a,0x2ee617a8,0x2cac2b67,0x5b360b8d}},	//   nnoc, nhof_, _hadd_, _شعار,
   {{0xd90e006c,0xe8941853,0x6f020300,0x6aa008c7}},	//   _ویب_, _баль, inoc, memf,
   {{0x6f020400,0x7980159c,0x78aa008c,0x00000000}},	//   hnoc, mumw, _uafv, --,
   {{0x629f00a8,0x38cb05f5,0x24180aeb,0x389b0277}},	//   teqo, _تانی_, воры_, _חיונ,
   {{0x62840133,0xf8370122,0x69d6027d,0x291e710b}},	//   ggio, _בנות_, _üyes, llta_,
   {{0x6f0210b7,0xc1050037,0x5334081b,0x291e710c}},	// [73d0] dnoc, هوري, ретт, olta_,
   {{0x7ae258af,0x273b010b,0x62840036,0xdddb0139}},	//   _llot, _kūno_, agio, _aduş,
   {{0xa3d503e6,0x291e00c3,0x7ae20421,0x00000000}},	//   _сонч, ilta_, _olot, --,
   {{0x25a9046a,0x79801ae0,0x612b00ab,0x52270217}},	//   _ksal_, kumw, külg, _афга,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aab008c,0x6f025c1d,0x7ae202ee,0x5f4500b5}},	//   _sagf, anoc, _alot, _منسل,
   {{0xeb992147,0x7ae21a3e,0x7c8421be,0x00000000}},	//   хий_, _blot, руче, --,
   {{0x3f810118,0x6f02027a,0xdd1c01ba,0x7ae2710d}},	//   muhu_, cnoc, _vášh, _clot,
   {{0xa91d00b8,0x61fb0a18,0x3f81710e,0x8d770079}},	//   huže, _žulj, luhu_, _جازا,
   {{0x7ae2710f,0x2cac0282,0x3ead36cc,0xdce90116}},	//   _elot, _gadd_, _haet_, _kveč,
   {{0x25a90464,0xd8382d17,0x3ebf7110,0x6aab7111}},	//   _asal_, teča_, _knut_, _tagf,
   {{0x291e7112,0xa91d0a78,0xa68303fe,0xeab00037}},	//   alta_, duže, блюд, _وعن_,
   {{0x3f817113,0xd8380881,0x79800027,0x291e009e}},	//   huhu_, reča_, cumw, blta_,
   {{0x7ae27114,0x3ead0051,0x3b1f00a8,0x00000000}},	//   _zlot, _laet_, lluq_, --,
   {{0xe29a13a1,0xdb010132,0x7d037115,0x1e2001c0}},	//   нав_, _islâ, inns, _बर्ष_,
   {{0x42550dba,0x3f81034d,0xdb0100d5,0x2b4502a7}},	//   итут, duhu_, _oslí, _mulc_,
   {{0x62847116,0x612b0332,0x2d8d006d,0x7afe01ef}},	// [73e0] rgio, küld, _nqee_, épti,
   {{0x26d20453,0x3ebf027c,0xa91d08b7,0x78a17117}},	//   _hoyo_, _anut_, lužb, nelv,
   {{0x26d200bf,0x645c7118,0xd12f0037,0x2cac7119}},	//   _koyo_, mbri, أمل_, _radd_,
   {{0xa3c32fa9,0x645c711a,0x26d20118,0x798001d5}},	//   ्हर_, lbri, _joyo_, yumw,
   {{0x26d2000e,0x3ead0526,0x2ee6711b,0x80c40ec5}},	//   _moyo_, _daet_, rhof_, रादे,
   {{0x3f81711c,0x2ee63155,0x3320007a,0x7bd8010b}},	//   buhu_, shof_, llix_, tyvu,
   {{0x645c0037,0x78a11f2c,0x7ae2711d,0xafe603e6}},	//   ibri, delv, _plot, _совл,
   {{0x4974326d,0x798025bf,0x5fbb0122,0x2cac00d7}},	//   алис, tumw, _אצלנ, _wadd_,
   {{0xa91d0200,0xdce9068b,0x7ae23c4f,0x645c32c5}},	//   dužb, _zveč, _vlot, kbri,
   {{0x26c002d7,0x78a1711e,0x79803729,0xb69b021d}},	//   _anio_, gelv, rumw, gnân,
   {{0x645c3008,0x26d20951,0x6ecb0354,0x7ae200e5}},	//   dbri, _boyo_, _सचमु, _tlot,
   {{0x7c2825e5,0x7c2502c9,0x7ae254aa,0xc986291e}},	//   _izdr, ühre, _ulot, _буки,
   {{0x612b3c07,0x78a1711f,0x26d201cb,0x3f810009}},	//   lüle, belv, _doyo_, zuhu_,
   {{0x26c07120,0xa91d0254,0x645c0298,0x2242013a}},	//   _enio_, tuže, gbri, _agkk_,
   {{0x2419021f,0x612b0225,0x00000000,0x00000000}},	//   товы_, nüle, --, --,
   {{0xddc001c0,0xdb01021d,0x26d25efd,0x612b0225}},	//   _nemů, _islã, _goyo_, züld,
   {{0xdce91001,0x645c2e4b,0x50f54073,0x612b01ae}},	// [73f0] _sveč, bbri, азат, hüle,
   {{0x7c280881,0xd3780a78,0x3f810858,0x656f7121}},	//   _ozdr, šća_, tuhu_, msch,
   {{0x656f7122,0x92955951,0x3ead7123,0x351c00a5}},	//   lsch, _канц, _paet_, _אוזנ,
   {{0xde950202,0x3f817124,0x7d1a007c,0x656f027a}},	//   радњ, ruhu_, _akts, osch,
   {{0x656f7125,0x9e6400d4,0x0e6427ac,0x2b45023a}},	//   nsch, свід, скін, _sulc_,
   {{0x656f7126,0x88bc00b8,0x61ed7127,0x3f8107e7}},	//   isch, změr, mzal, puhu_,
   {{0x656f01ae,0xa2dc08a9,0x25fc0084,0x672d0009}},	//   hsch, _नवम्, _लेनी_, _ohaj,
   {{0x656f7128,0x645c05e2,0x00000000,0x00000000}},	//   ksch, zbri, --, --,
   {{0x9c8753c4,0x26d201cb,0x78a17129,0x7e6b010d}},	//   _مشاه, _royo_, telv, magp,
   {{0x656f712a,0x3946429e,0xf771004f,0x7e6b010d}},	//   dsch, _duos_, ياج_, lagp,
   {{0x672d712b,0xa91d0254,0x656f712c,0x6d59011e}},	//   _bhaj, tužb, esch, lpwa,
   {{0x6b830c76,0x645c712d,0x672d02e9,0x656f2778}},	//   mung, wbri, _chaj, fsch,
   {{0x6b83712e,0x7ae9370d,0x958300c3,0x656f712f}},	//   lung, mhet, оляе, gsch,
   {{0x7ae97130,0x7afb010b,0x61ed042f,0x69c9006d}},	//   lhet, liut, dzal, mxee,
   {{0x6b837131,0x660d315b,0x645c7132,0x26d2010d}},	//   nung, _exak, rbri, _toyo_,
   {{0x645c0a45,0x656f01ae,0x672d035f,0x7ae9370d}},	//   sbri, bsch, _ghaj, nhet,

   {{0x6b837133,0x656f0260,0xe5a60073,0x612b0222}},	// [7400] hung, csch, _типи, züle,
   {{0x6b837134,0x2056002d,0x7f4701f4,0x1fb600af}},	//   kung, ртар, _bujq, исер,
   {{0x6b830a93,0x44447135,0x7ae915ed,0x6e290107}},	//   jung, _ig_, khet, _azeb,
   {{0xed5a0ae6,0x44442cfc,0x65640010,0x249a0176}},	//   вод_, _hg_, _kwih, _hbpm_,
   {{0x6f090280,0x7ae97136,0x69c90221,0x61ed0035}},	//   _djec, dhet, jxee, czal,
   {{0x6b830875,0x6f090083,0x444464d3,0x656401d5}},	//   fung, _ejec, _jg_, _mwih,
   {{0x6b837137,0x44447138,0x39460107,0x2fc70ed4}},	//   gung, _mg_, _suos_, ängt_,
   {{0x80c4009a,0x612b7139,0x7ae90d0f,0x7644713a}},	//   रावे, rüle, ghet, _ngiy,
   {{0x4444713b,0xe1ff0f56,0x6b8300d7,0x612b713c}},	//   _og_, _león_, aung, süle,
   {{0x4444713d,0x6b83713e,0x8c431dd0,0x612b01d6}},	//   _ng_, bung, _дефе, püle,
   {{0x7d181075,0x61ed713f,0x6b830010,0x59a80084}},	//   movs, zzal, cung, _कनवर,
   {{0x44446e4f,0x656f7140,0x7ae97141,0xd6db0150}},	//   _ag_, tsch, chet, тто_,
   {{0xd95407e4,0x44447142,0xca9702b8,0x656f01ae}},	//   _انتخ, _bg_, _כדאי_, usch,
   {{0x656f7143,0x44440010,0xa4e400d8,0x656400d7}},	//   rsch, _cg_, оўск, _dwih,
   {{0x656f7144,0x44447145,0x672d0187,0xc348083e}},	//   ssch, _dg_, _thaj, ияте_,
   {{0x44440a55,0x083b0052,0xd2582217,0x61ed06a2}},	//   _eg_, _בעול, ицу_, tzal,
   {{0x6b8343d1,0x6f090124,0x6e200355,0xa91d00fe}},	// [7410] zung, _rjec, _nymb, luža,
   {{0x6f090c21,0x6b830a74,0x7ae9006c,0x7d180097}},	//   _sjec, yung, zhet, jovs,
   {{0x7d180a53,0x7e6b00a7,0x61ed278b,0x5f9510bb}},	//   dovs, tagp, szal, сиет,
   {{0x44447146,0x7ae901f4,0x6b830371,0xdb0100a0}},	//   _zg_, xhet, vung, _oslá,
   {{0x444420fb,0x6f097147,0x6b837148,0x7d1803c9}},	//   _yg_, _vjec, wung, fovs,
   {{0x6b837149,0x7d1808b7,0x69c9006d,0x2fc701ff}},	//   tung, govs, vxee, ängs_,
   {{0x7ae9714a,0x7e6b300c,0x6b83033b,0xeeab00c3}},	//   thet, pagp, uung, _итак_,
   {{0x6b83714b,0x9f050957,0x69c901d7,0x6f1b011c}},	//   rung, _اورو, txee, _ukuc,
   {{0x60d5714c,0x7afb714d,0x7d1800ee,0x7ae9714e}},	//   _kozm, riut, bovs, rhet,
   {{0x644500e8,0x6b83714f,0x7ae97150,0x1c1b0324}},	//   _nghi, pung, shet, _पुथल_,
   {{0x7ae97151,0x6d41067f,0x69c61535,0x7afb0211}},	//   phet, _iila, äker, piut,
   {{0x6d4101a3,0x44442cfc,0x64450139,0xe5a602fb}},	//   _hila, _sg_, _aghi, бими,
   {{0x6d417152,0x7e697153,0x39900310,0xb6a300af}},	//   _kila, _meep, càs_, чиял,
   {{0xdff9004e,0x6d417154,0x6d49046a,0x3a360122}},	//   ्पाद_, _jila, _muea, _פרסם_,
   {{0x6d417155,0xd3b50086,0x4444345d,0x6755096a}},	//   _mila, ость, _vg_, _اختر,
   {{0x44447156,0x6d417157,0x6b9c5ee7,0x764401d5}},	//   _wg_, _lila, _ärge, _ugiy,
   {{0x44447158,0xf1aa00d1,0xa3a80992,0x6d4101a3}},	// [7420] _tg_, دازه_, _खैर_, _oila,
   {{0x44447159,0x6d41537e,0x60d5715a,0x96040f8a}},	//   _ug_, _nila, _cozm, रपीट_,
   {{0x7d182f70,0x25fc0354,0xdb010b3e,0x823602fd}},	//   vovs, _लेती_, _islæ, _گردا,
   {{0x6d41715b,0x2bbd020c,0xddc00395,0xfdea02c4}},	//   _aila, ्मना, _nemţ, лдек_,
   {{0x6d41715c,0x7ce6008a,0x7d18063c,0x7e69715d}},	//   _bila, _aðra, tovs, _deep,
   {{0x6d41715e,0xdcb10023,0x6d49005f,0x5c97010b}},	//   _cila, _cả_, _duea, йкія_,
   {{0x6d412bab,0x7d182fbc,0xcec300b8,0x00000000}},	//   _dila, rovs, áří_, --,
   {{0xa3b91e18,0x7d18715f,0x6d415ab7,0x39900443}},	//   चित_, sovs, _eila, tàs_,
   {{0x6d417160,0x7d1818b0,0x7c961303,0x7d0d0079}},	//   _fila, povs, _грец, éasc,
   {{0x6d417161,0x39907162,0xd8f800d4,0x7e6902a2}},	//   _gila, ràs_, рної_, _zeep,
   {{0xf98f064e,0x613000a6,0x25a002b3,0xb90000b4}},	//   وبی_, mäld, _apil_, _धक_,
   {{0xa91d2c3f,0x6d417163,0xa25b0279,0xf1bf00b5}},	//   ruža, _zila, _anôn, _szám_,
   {{0x2fc70019,0xa2cc178c,0x13b30355,0xaac50266}},	//   ̣ng_, हान्, ुम्भ, वारक,
   {{0x44270028,0x6448012e,0x6d4100a8,0x612b7164}},	//   _ơn_, ždin, _xila, küla,
   {{0x60d50f86,0xd82f002d,0x569517f9,0xe1000033}},	//   _rozm, _хэ_, _дайт, ্তাহ_,
   {{0x925900c9,0x00000000,0x00000000,0x00000000}},	//   раат_, --, --, --,
   {{0x60f900d8,0x3ea67165,0xa3ce0cea,0x60d57166}},	// [7430] аная_, deot_, _शपथ_, _pozm,
   {{0x7e695be0,0x2bbd012f,0x00000000,0x00000000}},	//   _seep, ्ममा, --, --,
   {{0x44277167,0x6d41046f,0x2fc70023,0x61e800a8}},	//   _án_, _rila, ãng_, _ədli,
   {{0x6d417168,0x273b005f,0xdea10987,0x3f930065}},	//   _sila, _būni_, بیری, rtxu_,
   {{0x6f19004e,0xa91d011c,0x80b80033,0x7e6900be}},	//   rowc, dužn, _আকর্, _veep,
   {{0x6d417169,0xfbd000e0,0x7c210a8a,0x00000000}},	//   _qila, کته_, _pylr, --,
   {{0x6d41716a,0x7e69716b,0x09d60033,0x04dc025a}},	//   _vila, _teep, _তেলা, רקול,
   {{0x6d411120,0x788300b5,0x93fc100a,0x628f021d}},	//   _wila, kívü, טלוי, _jcco,
   {{0x6d41716c,0xed590254,0x6c750274,0x442400e2}},	//   _tila, _brže_, _млађ, ́m_,
   {{0xe8f932a6,0xb902010b,0xc79500af,0x00000000}},	//   рло_, дзьк, ормы, --,
   {{0xeaae00f5,0xa6ca16c0,0x25a0054e,0x628f02fb}},	//   رٹی_, ална_, _spil_, _occo,
   {{0x2ca7716d,0x6130716e,0xa91d3247,0xc4c9011d}},	//   lend_, mäle, drže, _בג_,
   {{0x94040095,0xddc0005f,0x00000000,0x00000000}},	//   əmə_, _kemš, --, --,
   {{0x628f716f,0x2ca75ff4,0xdb1a1db3,0x25a0023a}},	//   _acco, nend_, _artè, _vpil_,
   {{0x044305f2,0x443e00c3,0x7d040037,0x2ca73777}},	//   дерн, ät_, éisi, iend_,
   {{0x2ca77170,0x629d00ee,0x00000000,0x00000000}},	//   hend_, _cbso, --, --,
   {{0xdb011193,0x2ca7086f,0xb5fb7171,0x25a00118}},	// [7440] _islä, kend_, rbác, _upil_,
   {{0x6ab60f9c,0x628f0382,0x505a00d8,0x2ca70044}},	//   _अफ्र, _ecco, ршая_, jend_,
   {{0x232a02ce,0xe29a08ce,0x32460f27,0xb37600ff}},	//   _вони_, _кан_, _менг, _بدخش,
   {{0x6da61499,0x00000000,0x00000000,0x00000000}},	//   жида, --, --, --,
   {{0xc27b011d,0x2ca706c6,0x3c58002d,0x00000000}},	//   _דרכי, fend_, билэ_, --,
   {{0x2ca71f8c,0xcf5a00c3,0xda1d00ab,0x6ca30382}},	//   gend_, _врач_, _पड़त_, дръж,
   {{0x6130022a,0xd0077172,0xa91d0254,0x7d0d0037}},	//   räld, _дере_, tužn, éasa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc33302da,0xa91d3cd6,0x2ca77173,0x0c7a0754}},	//   ווה_, ružn, bend_, _نصاب_,
   {{0x9c7c00d5,0x20070035,0xd838068f,0x4c83021d}},	//   _mlčk, źnie_, leči_, _олув,
   {{0x2bbd0b35,0x3f570069,0xed590116,0x00000000}},	//   ्मणा, _għud_, _vrže_, --,
   {{0xa91d0292,0xd9461499,0xdb1a2e92,0x00000000}},	//   vrže, _деди, _orté, --,
   {{0xd6270037,0x6a9b00a5,0x00000000,0x00000000}},	//   تعدي, _כשאנ, --, --,
   {{0xe3b327ad,0x99fb024b,0x00000000,0x00000000}},	//   ورز_, _דפדפ, --, --,
   {{0x926b03e6,0xdb1a428c,0x00000000,0x00000000}},	//   ираа_, _arté, --, --,
   {{0xd8382802,0x25b003ad,0x2ca77174,0x3f810187}},	//   ječi_, ällä_, zend_, vrhu_,
   {{0xd8380b67,0x628f00cc,0x00000000,0x00000000}},	// [7450] deči_, _vcco, --, --,
   {{0xf43500af,0x160100b4,0xa91d0207,0xc79500b5}},	//   _непэ, _लेयर_, prže, _بھیا_,
   {{0x2ca77175,0xb4e70035,0xa0c40987,0xddc002a7}},	//   vend_, पसी_, ظيمو, _remš,
   {{0x2ca703c4,0x1dc604bc,0x7cef0b3e,0x15ff23e3}},	//   wend_, लमंत, _kørg, _उधार_,
   {{0x7cef2b6f,0xa3b90632,0x2ca74a89,0xd25600a5}},	//   _jørg, चिव_, tend_, _משרה_,
   {{0xf1bf0179,0x64550987,0x61300110,0x7d760037}},	//   _irá_, nczi, täle, أمور_,
   {{0x81ad00c8,0x2ca77176,0x8c4203e6,0xf1bf00a0}},	//   _কপি_, rend_, неше, _hrá_,
   {{0x2ca77177,0xdd9500d8,0x5ac96f57,0x20c90803}},	//   send_, _набы, слим_, रावध,
   {{0xceb2343f,0xe8f92a66,0xdd5807f5,0xa2cc2483}},	//   _אין_, йли_, _матч_, हात्,
   {{0xa3cb0311,0x2bbd04bc,0x6d5b3815,0xb4ea0099}},	//   लमा_, ्मदा, _itua, _मते_,
   {{0x66df01f4,0x779000b5,0x6f0b00cc,0x00000000}},	//   _lëku, نیوا, ongc, --,
   {{0x68ea1472,0x7cef01cf,0xa3c10066,0xdb010523}},	//   _elfd, _børg, ूमन_, _arlö,
   {{0x63be7178,0x7aeb00ea,0x69dd00be,0x00000000}},	//   _srpn, _ilgt, äsed, --,
   {{0xa87902b5,0x6aa97057,0x395f7179,0x2eb800b4}},	//   _האַר, leef, mpus_, _इफ्त,
   {{0x395f02ff,0x7e7b011c,0xb4cc0026,0xe73a1888}},	//   lpus_, _odup, _रची_, _лек_,
   {{0x93431999,0xdb0102b1,0x7cef008c,0x273b0409}},	//   енсе, _erlö, _hørd, _būnu_,
   {{0x6d5b0221,0x612b00b5,0xd1860036,0xa5f70200}},	// [7460] _ntua, rüln, ялай, _нећу_,
   {{0xf6170122,0x7e7b0298,0xfbbd1bc6,0x9c7c00ac}},	//   _מחפש_, _adup, ्माम, _vlčk,
   {{0x6d5b00c9,0xc2c6004f,0x09a8717a,0x7c25033b}},	//   _atua, _فيدي, _कन्य, ührl,
   {{0xf1bf064b,0x6146717b,0x7cef3a92,0xee3a45c8}},	//   _frá_, _нема, _lørd, бне_,
   {{0xf1bf0037,0xd838717c,0xb2bb024b,0xaabf04cc}},	//   _grá_, reči_, _המכר, _शोधक,
   {{0x6d5b0037,0x38600009,0x612b00c1,0x7cef0b3e}},	//   _dtua, _điro_, nüll, _nørd,
   {{0x8fa32839,0xab381a6d,0x00000000,0x00000000}},	//   _паре, опку_, --, --,
   {{0x6d5b01f4,0x9c7c00ee,0x612b02b1,0x6aa92c59}},	//   _ftua, _mlči, hüll, geef,
   {{0x2b4c022e,0x25fc0456,0x78a8008c,0xb60600f4}},	//   _wudc_, _लेली_, tedv, nošč,
   {{0x6f02717d,0xa91d0009,0x7aeb00c7,0xdc3c0168}},	//   lioc, lužj, _elgt, _háči,
   {{0x3f7800ea,0x25b265ff,0xfaa6004b,0x7cef10db}},	//   nču_, _asyl_, _нажо, _sørg,
   {{0x6f020c99,0xda7700af,0x7cef008c,0x00000000}},	//   nioc, _еяш_, _pørg, --,
   {{0x612b01ae,0x7cef0185,0x25580355,0xcfe00831}},	//   füll, _førd, vělý_, _যেমন,
   {{0x6f020036,0xd9430e9f,0x7cef008c,0x3a260027}},	//   hioc, _зечи, _gørd, _iyop_,
   {{0x290c0e6c,0x28b700a5,0x2ee60298,0x00000000}},	//   mnda_, _מפגש_, kkof_, --,
   {{0xf1bf0132,0x6f020009,0x628d02c4,0x7cef008c}},	//   _prá_, jioc, ugao, _iøre,
   {{0xe73005f5,0x7cef10db,0x867c00a5,0xf8e00066}},	// [7470] _حصو_, _høre, _הרחו, _पकाय,
   {{0x3cf8006a,0x291e717e,0x7cef054e,0x290c717f}},	//   ्चों_, nota_, _køre, nnda_,
   {{0x6d5b7180,0x814401df,0x00000000,0x00000000}},	//   _stua, رنمن, --, --,
   {{0xfbbd11b5,0x6f0202fb,0x291e7181,0xf1bf64cf}},	//   ्मसम, gioc, hota_, _trá_,
   {{0x290c00d7,0xed5900cd,0x291e45a0,0x26c908c7}},	//   knda_, _brža_, kota_, _mnao_,
   {{0x33297182,0x69d6027d,0x2716013a,0xd8380009}},	//   llax_, _üyey, māne_, leču_,
   {{0xeb997183,0x291e7184,0x3a26011e,0xed59023a}},	//   ций_, dota_, _ayop_, _drža_,
   {{0xa91d0936,0x290c7185,0x6f020747,0x6130013c}},	//   drža, enda_, cioc, mäla,
   {{0x6aa97186,0x386e099e,0x2bbd01d1,0x290c0093}},	//   reef, _befr_, ्महा, fnda_,
   {{0x26c908c7,0xd3780254,0x612b7187,0x7cef008c}},	//   _anao_, šći_, külm, _børe,
   {{0xb9050fd0,0x16aa2a7c,0x395f00af,0x7cef0044}},	//   _नव_, овни_, spus_, _vørd,
   {{0x98a20029,0xd838022f,0x395f7188,0x7cef0c71}},	//   ēkā_, ječu_, ppus_, _døre,
   {{0xb8e30b52,0x291e1164,0xdce90b16,0xba7406ca}},	//   _এক_, bota_, _cveć, _سانت,
   {{0x58d42294,0x6f0238a9,0x7cef0b41,0x6355010b}},	//   _почт, zioc, _føre, _sąna,
   {{0x15430043,0x7cef01b4,0x00000000,0x00000000}},	//   терм, _gøre, --, --,
   {{0x3947008a,0x99e30237,0x7d037189,0x9c7c00ac}},	//   _hins_, žňuj, hins, _vlči,
   {{0xb0c902e4,0x453600c3,0x394701f7,0x67243776}},	// [7480] रांग, _охот, _kins_, _ikij,
   {{0x7d03718a,0x26c903fd,0x3947718b,0xb606008b}},	//   jins, _znao_, _jins_, rošč,
   {{0x7d030496,0x6f0200cd,0x26c9011e,0x07020722}},	//   dins, tioc, _ynao_, _लगाव_,
   {{0x39473f05,0x2eed00f7,0x4ea300ed,0x291e1a73}},	//   _lins_, _clef_, врша, zota_,
   {{0x6f02718c,0x290c718d,0x395d006f,0x7d030044}},	//   rioc, ynda_, _ntws_, fins,
   {{0x6f021269,0x7d03718e,0xdb0a3a92,0xa3e507b5}},	//   sioc, gins, lvfø, बैक_,
   {{0x1eaa1c64,0x291e05ed,0x612b00ab,0xe2080035}},	//   _واري_, vota_, külj, _wróć_,
   {{0x8fa3002d,0x67242574,0x394700f6,0x7cef0249}},	//   _шасе, _nkij, _ains_, _røre,
   {{0x60dc718f,0x7d0400a2,0x7cef390d,0x291e7190}},	//   _korm, éiss, _søre, tota_,
   {{0x67240054,0xfbc60c46,0xa91d01ba,0x290c002f}},	//   _akij, _обзо, trža, unda_,
   {{0x60dc25e0,0xdce903fd,0x394712c3,0x6d48081b}},	//   _morm, _sveć, _dins_, _iida,
   {{0x3947064b,0x291e7191,0x6d487192,0xfbd30122}},	//   _eins_, sota_, _hida, _שתף_,
   {{0x3947162d,0x291e0169,0x6d48164e,0x60dc0a89}},	//   _fins_, pota_, _kida, _oorm,
   {{0x6d487193,0x6724018e,0x612b7194,0x39477195}},	//   _jida, _ekij, tülm, _gins_,
   {{0x6d480006,0xdceb048c,0x43940423,0x98a30274}},	//   _mida, stgħ, карс, _рије,
   {{0x53342b8e,0x612b7196,0x6d487197,0x69c23fe0}},	//   вест, rülm, _lida, _kroe,
   {{0x60dc7198,0xd8387199,0x7d03719a,0xdce90254}},	// [7490] _borm, reču_, yins, _uveć,
   {{0x6d481202,0x27320037,0x332902d7,0x78ba0a8c}},	//   _nida, mána_, slax_, ndtv,
   {{0xdb1a6cd2,0x7d03719b,0x332901ef,0x2d860051}},	//   _artí, vins, plax_, eroe_,
   {{0x7d03719c,0x6d484a06,0x80cd00a1,0x656d2f10}},	//   wins, _aida, साहे, _kwah,
   {{0x6d48719d,0xdca5365b,0xa2cc175f,0x2d86022e}},	//   _bida, еали, हार्, groe_,
   {{0x6d48130c,0x394f719e,0x7c280173,0x60dc2060}},	//   _cida, _rugs_, _bydr, _gorm,
   {{0x764d030d,0x75cb00a1,0x2b5e0176,0x7c2800e9}},	//   _ogay, ामुळ, _cttc_, _cydr,
   {{0x764d719f,0x69c21ead,0xe9d9172a,0x6d4871a0}},	//   _ngay, _broe, зки_, _eida,
   {{0x7d0371a1,0x6d4871a2,0x69c20297,0x80b60035}},	//   pins, _fida, _croe, _उसमे,
   {{0x6d4871a3,0xe8f61f1e,0x69c271a4,0x67240254}},	//   _gida, ель_, _droe, _skij,
   {{0x78b801d3,0x394771a5,0x6aa20176,0x69c20065}},	//   _davv, _vins_, _fbof, _eroe,
   {{0x394771a6,0x6d4871a7,0xbbbd0e61,0x656d0ed6}},	//   _wins_, _zida, ्मीक, _bwah,
   {{0x69c271a8,0x3947264a,0x7ae971a9,0x78b8017b}},	//   _groe, _tins_, mket, _favv,
   {{0x7ae971aa,0x399971ab,0xddc933a5,0x764d40f7}},	//   lket, mès_, _odež, _egay,
   {{0x399902d0,0x03a300c3,0x25fc007c,0xaad30931}},	//   lès_, лиро, _लइकी_, थापक,
   {{0x290505e2,0x7ae971ac,0x60dc71ad,0xa91d0254}},	//   lila_, nket, _sorm, duži,
   {{0xbbbd045c,0x399971ae,0x60dc18ad,0x656d0297}},	// [74a0] ्मुक, nès_, _porm, _gwah,
   {{0x290511e9,0x60dc009f,0xb2231bc0,0x26f005dc}},	//   nila_, _qorm, умул, _चतुर_,
   {{0x60dc71af,0x7ae971b0,0x6d4871b1,0x4ea60c06}},	//   _vorm, kket, _rida, ерла,
   {{0x6d480533,0x290571b2,0xfe7212de,0x2d8671b3}},	//   _sida, hila_, ادا_, troe_,
   {{0x60dc71b4,0x6d48227d,0xaad30aad,0xed5902a7}},	//   _torm, _pida, थानक, _držo_,
   {{0xd37801cc,0x290505e2,0x399971b5,0xa91d71b6}},	//   šću_, jila_, dès_, buži,
   {{0x290518b0,0x6d482a94,0x3dd80083,0x78b871b7}},	//   dila_, _vida, _দেখল, _ravv,
   {{0x69c271b8,0xd00f0180,0x78b83b65,0x7c28024e}},	//   _proe, _الف_, _savv, _vydr,
   {{0x6d4806ad,0x6e930037,0x7c280035,0xa92a004b}},	//   _tida, _حلقا, _wydr, зіне_,
   {{0x69c20903,0x273201c0,0x656d04fb,0x7ae971b9}},	//   _vroe, vána_, _rwah, aket,
   {{0x28d20299,0x273900e0,0xad1b0070,0x656d666e}},	//   ताबि, néng_, _צובר, _swah,
   {{0x69c271ba,0x7ae971bb,0x6abb012f,0xa2dc021a}},	//   _troe, cket, cduf, _नवग्,
   {{0x290571bc,0x399902e1,0x48e632fa,0xceb3134d}},	//   bila_, cès_, _подв, ניש_,
   {{0x290571bd,0xdddb0160,0x00000000,0x00000000}},	//   cila_, _leuş, --, --,
   {{0xd7ef02cc,0x9f47024e,0xe3b0006c,0x97a3010b}},	//   _су_, šné_, یرہ_, _брыл,
   {{0x656d01d5,0x21210159,0x764d0371,0x00000000}},	//   _twah, wohh_, _ugay, --,
   {{0x02e1074f,0x656d1596,0xa91d00cd,0x612b71be}},	// [74b0] _नवीन, _uwah, kržl, lüli,
   {{0x7ae90291,0xa91d0254,0x271602d4,0x25a90069}},	//   zket, tuži, māna_, _ipal_,
   {{0xa91d18b0,0x2d80016f,0x6e29012f,0x613000c3}},	//   držl, šiel_, _syeb, mäll,
   {{0x290502dd,0xa91d0528,0x6e2902d0,0xdef80328}},	//   zila_, ruži, _pyeb, ныч_,
   {{0xa3b9164c,0xb2760070,0x6ab9008c,0x00000000}},	//   चिक_, _בערג_, _rawf, --,
   {{0x399902e9,0x29052c36,0x2138002a,0xdca541f8}},	//   vès_, xila_, _ghrh_, таки,
   {{0x29050888,0x40340d46,0x7ae900c3,0x611402fb}},	//   vila_, _берс, tket, _сдру,
   {{0x63ba01b4,0x399971bf,0x290571c0,0x6d520079}},	//   ætni, tès_, wila_, údaí,
   {{0x7ae971c1,0x7cf401a6,0x61301cb5,0x6abb008c}},	//   rket, _bàrd, käll, rduf,
   {{0x3eaf309d,0x399971c2,0x7cf40176,0x613000c3}},	//   legt_, rès_, _càrd, jäll,
   {{0x290518b0,0x2d8f0a78,0x25a971c3,0x7ae9574c}},	//   rila_, luge_, _apal_, pket,
   {{0x2905039c,0xb8e80953,0x399902d0,0x7cf4009e}},	//   sila_, _लो_, pès_, _eàrd,
   {{0x613006ea,0x290571c4,0xd7f80012,0x4e7a0070}},	//   fäll, pila_, ază_, וארצ,
   {{0x7c2471c5,0x00000000,0x00000000,0x00000000}},	//   şire, --, --, --,
   {{0xb4b2004e,0x232a107a,0x25a94b9d,0xddc9007a}},	//   _ऐसी_, дови_, _epal_, _adeż,
   {{0x2ed000b8,0xb6a600af,0xa91d0207,0x00000000}},	//   _सचेत, _риил, gužv, --,
   {{0xdddb002d,0x3f570183,0x9c7c008b,0x2d8f103c}},	// [74c0] _reuş, _açu_, _hoče, juge_,
   {{0x9c7c71c6,0x2d8f71c7,0xf0630cc7,0x00000000}},	//   _koče, duge_, икуп, --,
   {{0xdb0101dd,0x9c7c02a7,0x00000000,0x00000000}},	//   _aplí, _joče, --, --,
   {{0x2d800080,0x2d8f71c8,0x2bc50569,0x273900e0}},	//   šiem_, fuge_, विना, réng_,
   {{0x2cbc0453,0x9c7c008b,0x2d960011,0xd65700a5}},	//   tdvd_, _loče, трес, דינת_,
   {{0x798971c9,0xed570202,0x645c71ca,0x00000000}},	//   drew, њој_, ncri, --,
   {{0x69dd71cb,0x09df0033,0xff260369,0xa2d900b4}},	//   äsen, _বেলা, _амво, फॉक्,
   {{0x64df0461,0x273200b8,0x501b00a5,0xdee30ddc}},	//   _नक्श, dáno_, _חולו, _коси,
   {{0x4973005f,0xc8666118,0xbda50ae7,0x645c26a2}},	//   алыс, ктни, _محلو, kcri,
   {{0x7cef0a8a,0x9c7c00fe,0x48aa00af,0x00000000}},	//   _hørn, _boče, фтим_, --,
   {{0x613071cc,0x00000000,0x00000000,0x00000000}},	//   väll, --, --, --,
   {{0x9c7c4989,0x4bfb0d85,0xcf9300a5,0xa91d71cd}},	//   _doče, _קלאס, סטר_, dužu,
   {{0x613006d7,0x59b631d7,0x596302fb,0x7cef008c}},	//   täll, _अनिर, _къща, _mørn,
   {{0x89d70a42,0x00000000,0x00000000,0x00000000}},	//   _جوهر_, --, --, --,
   {{0x2bc50722,0x8ca4046c,0x28b71b8f,0x00000000}},	//   विया, च्यो, _असति, --,
   {{0x59b60437,0x326446e1,0x61300086,0x3f57003c}},	//   _अनार, итув, säll, _dħul_,
   {{0x645c0107,0x2459002d,0x25a971ce,0x00000000}},	// [74d0] bcri, _папь_, _upal_, --,
   {{0x3eaf033b,0x2d8f01d5,0x25fc0387,0x00000000}},	//   wegt_, vuge_, _लेटी_, --,
   {{0x7cef0022,0x3eaf0a8a,0x00000000,0x00000000}},	//   _børn, tegt_, --, --,
   {{0xf2c700af,0x00000000,0x00000000,0x00000000}},	//   _рсон, --, --, --,
   {{0x2bc5143a,0x273200b8,0x3eaf02b1,0x00000000}},	//   विभा, záno_, regt_, --,
   {{0x2d8f71cf,0x3e7100cc,0x00000000,0x00000000}},	//   ruge_, ạt_, --, --,
   {{0xeab1004f,0x7cf40392,0xdfd40328,0xc87800d0}},	//   معة_, _bàrb, _коры, dağ_,
   {{0x273201c0,0x00000000,0x00000000,0x00000000}},	//   váno_, --, --, --,
   {{0x9c7c023a,0x00000000,0x00000000,0x00000000}},	//   _soče, --, --, --,
   {{0x9c7c3015,0xb4b21db6,0x798901bf,0x645c0160}},	//   _poče, _ऐसे_, rrew, xcri,
   {{0xd70a01c8,0x81d90083,0x66e65e89,0x00000000}},	//   енне_, ়নি_, гона, --,
   {{0x7c2502c9,0x7e79011e,0x7cf40310,0x2cf337e8}},	//   ühru, nawp, _vàre, _अतुल_,
   {{0x98a51578,0xc87801c2,0xe9ce0377,0x2bbd2218}},	//   _биле, bağ_, _ук_, ्मका,
   {{0x9c7c71d0,0x81d90033,0xa91d011c,0xdc4300b8}},	//   _toče, ়না_, tužu, _léči,
   {{0x9c7c0b16,0x29360070,0x833a5f11,0x04570037}},	//   _uoče, _גאסן_, ечат_, الفة_,
   {{0x645c71d1,0xa91d030a,0x271600ec,0x9c7c00fe}},	//   scri, ružu, māno_, _kočc,
   {{0x10a61283,0xf8b70099,0x00000000,0x00000000}},	// [74e0] лиан, _असाय, --, --,
   {{0x45fb00a5,0x65640027,0x67264ee8,0x00000000}},	//   _נהיג, _itih, lokj, --,
   {{0x749b0d85,0xb0c900dc,0x20551334,0x903612ea}},	//   _אייפ, राजग, ртур, ухач,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf76700f5,0xc27b0bed,0xf2d30070,0xfce62374}},	//   _گا_, _ארכי, _הער_, лодо,
   {{0x65640054,0x412a00d4,0x7cef0044,0x67260051}},	//   _mtih, _чого_, _døro, hokj,
   {{0xf7671168,0xeb4a399d,0x7cef0a8a,0x00000000}},	//   _دا_, нчик_, _tørn, --,
   {{0x7cef008c,0x629671d2,0xa3ac0266,0x3af1028f}},	//   _føro, ngyo, _गहन_, _pápa_,
   {{0x6130007c,0x656401d5,0xddc000fe,0x7ccb02d4}},	//   välj, _ntih, _hemž, _bērē,
   {{0x7f421505,0xdd8f0e0c,0xc19b00a5,0x7cef008c}},	//   lmoq, _روم_, עשיי, _jørl,
   {{0x98c31ac5,0x7cf40176,0x6564217c,0xd6d50f99}},	//   ссыл, _tàrb, _atih, ажны,
   {{0x28d20567,0x7bc82889,0x38600207,0x00000000}},	//   ताहि, _irdu, _điru_, --,
   {{0x92030026,0x7a7b016b,0xceb3076b,0x15a80382}},	//   _रेंज_, _טראס, זיר_, лъри_,
   {{0x6130013c,0x64430097,0xd83a002d,0x7cef008c}},	//   sälj, _únik, _пэй_, _nørl,
   {{0x7ae220a8,0xdce200ac,0xa41f021a,0x00000000}},	//   _koot, jpoč, _मुखप_, --,
   {{0x81ae0083,0x2bc5143a,0x28d22483,0x7bc871d3}},	//   কিন_, विता, तावि, _mrdu,
   {{0x9f47000c,0x7ae21246,0x612b71d4,0x53340800}},	// [74f0] ání_, _moot, kült, сетт,
   {{0x7bc871d5,0x7ae2007c,0x98a7011c,0x7cef0044}},	//   _ordu, _loot, čiću_, _røro,
   {{0x9f4701c0,0x644871d6,0x53351622,0x7cef71d7}},	//   šní_, ždir, _вент, _dørl,
   {{0xa1952101,0xdb010097,0x394e0282,0xf1ca00a0}},	//   _камч, _oplá, _lifs_, _stáť_,
   {{0x7bc806a2,0x7cef008c,0x127a02b5,0x7bc3006d}},	//   _ardu, _førl, _בארע, wvnu,
   {{0x81bc0083,0x2cbe0176,0x7bc8009e,0x55780070}},	//   _অথচ_, _catd_, _brdu, רעגן_,
   {{0x2bc5051d,0x7ae206d1,0x4c920274,0x00000000}},	//   विधा, _boot, цијс, --,
   {{0x7cf4009e,0x1ae50183,0xdb01026e,0x28b72e8c}},	//   _pàrc, роим, _bplá, _असहि,
   {{0x88d501c8,0x7ae201ed,0x00000000,0x00000000}},	//   аўні, _doot, --, --,
   {{0x3ebf2b00,0xa8552123,0xdb1a0282,0xfd13186e}},	//   _haut_, штиј, _artä, _اجر_,
   {{0x3ebf0080,0x7ae233e6,0x7bc8009e,0x3f931dab}},	//   _kaut_, _foot, _grdu, nuxu_,
   {{0xdb0101f7,0x7ae271d8,0x9c7c0207,0x394e099e}},	//   _eslò, _goot, _točc, _eifs_,
   {{0x3ebf0ec0,0xdce2024e,0xe8ee06cd,0xed59011c}},	//   _maut_, zpoč, _дл_, _brži_,
   {{0x3ebf71d9,0x9c7c023a,0xdb010098,0x81ae0831}},	//   _laut_, _koča, _tsló, কিম_,
   {{0xed590496,0x28d201c0,0x04461d29,0x68e371da}},	//   _drži_, तारि, ревн, _iond,
   {{0x1601006a,0xa91d1ed1,0xe3552b48,0x212a00d7}},	//   _लेकर_, drži, стрэ, _skbh_,
   {{0x68e371db,0x8be90083,0x26d227f9,0x7cf40014}},	// [7500] _kond, _কেমন_, _inyo_, _làra,
   {{0x26d2006d,0x27390187,0x68e316b6,0x00000000}},	//   _hnyo_, ména_, _jond, --,
   {{0x68e371dc,0x3ebf71dd,0x2d9f01f7,0x9c7c0520}},	//   _mond, _baut_, _aque_, _noča,
   {{0x26c001d7,0x3ebf002d,0xbea600d8,0x81ae0033}},	//   _jaio_, _caut_, радк, কিব_,
   {{0x823600bf,0x26c00bb0,0x7f420c6f,0x7ae201bb}},	//   _خردا, _maio_, rmoq, _root,
   {{0x68e306a2,0x6b814523,0xa0674cd3,0x9c7c336f}},	//   _nond, _bvlg, _вара_, _boča,
   {{0x3ebf1010,0xdb01024e,0x7d0a008a,0x26d22f10}},	//   _faut_, _splá, rifs, _onyo_,
   {{0x9c7c193b,0xbab82661,0x68e371de,0x26d209d6}},	//   _doča, угих_, _aond, _nnyo_,
   {{0x68e3142f,0xdcfb0a78,0x41c90355,0xbb470037}},	//   _bond, _zvuč, रियस, جلين_,
   {{0xb4d5018d,0x7ae271df,0x26d271e0,0x9c7c0009}},	//   _सचे_, _woot, _anyo_, _foča,
   {{0x68e371e1,0x7ae20006,0xd7fa71e2,0x7bc801a3}},	//   _dond, _toot, туп_, _urdu,
   {{0x6d4f0248,0x26c071e3,0xed5900cb,0x290756bd}},	//   _écar, _caio_, _srži_, _emna_,
   {{0x6f03162d,0xed590124,0x443a01b7,0x00000000}},	//   ènci, _prži_, _azp_, --,
   {{0x68e30332,0x2bbd0d53,0xd9434311,0x248d033b}},	//   _gond, ्मचा, _дечи, ßem_,
   {{0x26c001ef,0x09b60af9,0x38cb042c,0x6286013a}},	//   _faio_, _अनुय, _جانی_, _bdko,
   {{0x68e304ce,0x8c1b011d,0x4df807b5,0x248d027d}},	//   _zond, דולי, ्छाई_, şem_,
   {{0xdddb03fd,0x6d431037,0x672d08c6,0x6b5500c7}},	// [7510] _oduš, ymna, _ikaj, _išge,
   {{0x26c006a2,0x4aa6012f,0xa91d0252,0x3ebf71e4}},	//   _zaio_, क्तव, trži, _saut_,
   {{0x902801c8,0x3ebf71e5,0xb5fb01ef,0xf773016b}},	//   ацца_, _paut_, abát, ַקס_,
   {{0x02a771e6,0x2bbd02e4,0x8f6a00b5,0x31690d3c}},	//   _тром, ्मघा, النے_, ppaz_,
   {{0x51841c4d,0x3ebf0248,0x28b70066,0xa28200b5}},	//   _мура, _vaut_, _असलि, _ریلو,
   {{0x9c7c201b,0x290c5efd,0x6ed50026,0xa91d022f}},	//   _poča, jida_, णाहु, prži,
   {{0x290c1fca,0x68e371e7,0xdd91006c,0x3b0930fe}},	//   dida_, _rond, زوں_, леко_,
   {{0x68e371e8,0xce940036,0xfbd010ee,0x613028e5}},	//   _sond, _масъ, بته_, väli,
   {{0x61ed71e9,0x290c71ea,0x26c02314,0x6f09002f}},	//   nyal, fida_, _raio_, _imec,
   {{0x290c377e,0x672d5dbf,0xe8f63122,0x9c7c044d}},	//   gida_, _akaj, йлы_, _toča,
   {{0xfbd0004f,0x26c071eb,0x68e371ec,0x9c7c05e2}},	//   _يتم_, _paio_, _vond, _kočn,
   {{0x81ae0083,0x68e371ed,0x61ed0273,0x27390097}},	//   কিত_, _wond, kyal, téna_,
   {{0x9c7c02c6,0xe9ce002d,0xdb2600e0,0x2bc5074f}},	//   _močn, _эк_, _اونی, विवा,
   {{0x290c1ec0,0x69cb02c9,0xed591c8e,0x68fa7174}},	//   cida_, _irge, _muž_, chtd,
   {{0xf7461362,0x6f090139,0x00000000,0x00000000}},	//   _леко, _omec, --, --,
   {{0x9c7c71ee,0x6ab5052f,0x61e25d91,0x6e3b00ac}},	//   _nočn, _अघोर, äolo, _ozub,
   {{0x61ed00b5,0xd5b100e2,0x6e3b0027,0xed59148a}},	// [7520] gyal, ắc_, _nzub, _nuž_,
   {{0x205671ef,0xdb1a71f0,0x6f09002f,0xb5fb71f1}},	//   стар, _estè, _amec, rbát,
   {{0x7afb71f2,0x287a0070,0xe4570319,0xa3ba0d93}},	//   khut, רנעמ, _לייט_, _صادر_,
   {{0x290c0232,0x6e93004f,0xde960037,0x7cf414c4}},	//   zida_, كلما, إجاب, _càrn,
   {{0x290c0a21,0x7cf400f1,0x273200ac,0x61ed0027}},	//   yida_, _dàrn, gáni_, cyal,
   {{0xed591269,0x290c043f,0xa3cc22d4,0xdb1a07c0}},	//   _duž_, xida_, लिप_, _isté,
   {{0x290c71f3,0x9f470187,0x2d8f0345,0x2bc5012f}},	//   vida_, šná_, arge_, विषा,
   {{0x5f060409,0xbf161062,0x290c2642,0xbea371f4}},	//   _узба, _اورب, wida_, _наск,
   {{0x290c4f40,0xed5900f4,0x00000000,0x00000000}},	//   tida_, _bržu_, --, --,
   {{0x80db0066,0x41bb0070,0x672d15a8,0x3ce53ee4}},	//   नाये, נציע, _skaj, _golv_,
   {{0xda6f0a93,0x69cb71f5,0x290c71f6,0x7afb71f7}},	//   _ня_, _erge, rida_, bhut,
   {{0x290c71f8,0x7afb3adb,0xdc3b02b5,0x2bc504bc}},	//   sida_, chut, _געבר, विरा,
   {{0xeb140953,0xfa3603c7,0x80db0035,0x63be055c}},	//   तचीत_, _اراد, नामे, _aspn,
   {{0xa99b00a5,0x555871f9,0x9c7c0097,0x81de0033}},	//   _עבור, саря_, _močo, তনা_,
   {{0xdb1a00a2,0x7cef71d7,0x672d0207,0x00000000}},	//   _asté, _dørh, _tkaj, --,
   {{0x61ed71fa,0x672d0848,0xc9090033,0x65760090}},	//   tyal, _ukaj, রকৃত_, _fwyh,
   {{0x9c7c0e6a,0x7cef23f4,0x00000000,0x00000000}},	// [7530] _ročn, _førh, --, --,
   {{0x46a50d00,0x61ed71fb,0x6f0971fc,0x9c7c1635}},	//   ग्रह, ryal, _smec, _sočn,
   {{0x9c7c10e5,0x61ed71fd,0xdfd10037,0xa85700a5}},	//   _počn, syal, بيا_, ציאה_,
   {{0x61ed027d,0x7cef0c61,0x3e7d010b,0xed5900cd}},	//   pyal, _tørk, kštų_, _puž_,
   {{0x2cac71fe,0x7cef08c8,0x442100cc,0xfce50210}},	//   _bbdd_, _høri, _hxh_, жоло,
   {{0x27320187,0x2bc571ff,0x9c7c0168,0xaabd0067}},	//   ráni_, विला, _dočo, ्यभक,
   {{0x09d102cb,0x9c7c7200,0x7afb12a9,0x7cfd0392}},	//   तम्य, _točn, thut, _lèrg,
   {{0x7e627201,0x6f09002f,0xb4e6021a,0xf2df00e5}},	//   ccop, _umec, _भक्_, _giât_,
   {{0xe8f9103e,0x7afb0ac8,0x4433017b,0x3ce54541}},	//   или_, rhut, _lyx_, _tolv_,
   {{0xa3cc6540,0x7afb3069,0x7e7b19c1,0xa3ba007c}},	//   लिम_, shut, _heup, _आईल_,
   {{0xf09202da,0x60c5004f,0x7e7b02c2,0xf7461422}},	//   וני_, idhm, _keup, жено,
   {{0x6d5b7202,0x6f1900e9,0xd04d00a8,0x3dcd7203}},	//   _kuua, nnwc, ükəl, _krew_,
   {{0x2716013a,0x69cb7204,0x7c2d0448,0x7e7b023c}},	//   nāni_, _urge, şard, _meup,
   {{0x2a7f01ae,0x6d5b7205,0x18691470,0x63be0176}},	//   laub_, _muua, _таки_, _pspn,
   {{0x69c97206,0x3ead0159,0x6d417207,0x09df0033}},	//   lvee, _obet_, _mhla, _বেচা,
   {{0xf26a1583,0x613001ae,0x2716013a,0xb5fb4a22}},	//   риал_, hält, kāni_, rbár,
   {{0xb5fb7208,0x69c97209,0x3d1a08a9,0x61301c52}},	// [7540] lcán, nvee, _बदले_, kält,
   {{0xe0d75654,0x2a7f0221,0x7cef11cb,0x3ead010d}},	//   ову_, haub_, _føri, _abet_,
   {{0x09b60518,0x14d700c2,0xb5fb2fba,0xf1bf00ee}},	//   _अन्य, _וויל_, ncán, _esá_,
   {{0x3dcd2ea2,0x6d41027d,0x7cf40211,0x2d840176}},	//   _brew_, _ahla, _eàrl, _pvme_,
   {{0x6d41184f,0x0cd41065,0x61303308,0x6d2600d8}},	//   _bhla, золю, fält, оддз,
   {{0x6d41720a,0x3ead05f5,0x7e6207b9,0xc5f300a5}},	//   _chla, _ebet_, scop, ודד_,
   {{0x46dd012f,0x8fa300af,0x273200ac,0x00000000}},	//   यामह, _оаре, lánu_, --,
   {{0x7e7b2668,0x00000000,0x00000000,0x00000000}},	//   _geup, --, --, --,
   {{0xaaa609a8,0x4aa6022e,0x6d411a07,0xada60fc5}},	//   क्षक, क्षव, _fhla, _фазл,
   {{0x6d41006e,0xa3ba007c,0x97a608a6,0x2d801772}},	//   _ghla, _आईं_, ормл, šies_,
   {{0xfaa60854,0x7cfd0176,0xe0b700a5,0x00000000}},	//   _мажо, _sèrg, חליט_, --,
   {{0xb5e60033,0x7cfd3644,0x9c7c02a7,0x273200d5}},	//   _পেইচ, _pèrg, _močm, kánu_,
   {{0xe3b80644,0x6b5500c7,0x7cef0185,0x00000000}},	//   çın_, _išga, _søri, --,
   {{0x4aa60f17,0x273200d5,0x00000000,0x00000000}},	//   क्रव, dánu_, --, --,
   {{0x61300301,0xd7e62659,0x69dd02e2,0x430b0ecf}},	//   häls, _філо, äsev, ахам_,
   {{0x72d42611,0x9c7c02a7,0x92590183,0x00000000}},	//   мосф, _sočl, саат_, --,
   {{0x67ff006c,0x7cf401a6,0x27320187,0xbba706fe}},	// [7550] _tájé, _pàrl, gánu_, _कङ्क,
   {{0x4ad1009a,0x387c0009,0xd1310ae7,0x7f5c720b}},	//   _दोनव, _jevr_, رما_, _burq,
   {{0x7e7b0248,0x741516a4,0x44270019,0x53350112}},	//   _peup, _روحا, _ân_, _неот,
   {{0xf8b70240,0x2716013a,0x6d41006b,0x7cfd1f96}},	//   _अस्प, tāni_, _shla, _mère,
   {{0x3ead720c,0x6d41720d,0xbdf80037,0xf1bf0132}},	//   _vbet_, _phla, يرها_, _usá_,
   {{0x9f0503fc,0x14de720e,0x7cf40392,0x3ac70023}},	//   _کورو, मायण, _fàrm, _ốp_,
   {{0x0ec6009a,0x2a7f047b,0x7e7b012f,0x415403e6}},	//   _रोकड, taub_, _teup, _цврс,
   {{0xa3cc0d1f,0x613003ad,0x6d5b00be,0x81ae0033}},	//   लित_, sält, _tuua, কির_,
   {{0xc3340122,0xdd91126b,0xf991004f,0xfc460093}},	//   ווק_, _سوا_, ربة_, _þínu_,
   {{0x6d4100d5,0xe8f90994,0x3d94668a,0x2a7f006d}},	//   _uhla, сло_, _цифр, saub_,
   {{0xf0920779,0xccf20052,0x7cfd0118,0x69c9720f}},	//   ענט_, _רכב_, _cère, svee,
   {{0xa25b00f7,0x387c0069,0x9c7c02a7,0x7bc1343a}},	//   _saôn, _eevr_, _nočj, _islu,
   {{0xcb120052,0x9c830124,0xb5fb3b58,0x00000000}},	//   _אלא_, ščup, scán, --,
   {{0x7bc1011e,0x26c4007e,0x00000000,0x00000000}},	//   _kslu, žmo_, --, --,
   {{0xa50723c0,0xfdb80967,0x7cfd00a2,0x9f590118}},	//   чера_, _इन्फ, _gère, _èyèl_,
   {{0x877a0070,0xa3bd00b4,0x00000000,0x00000000}},	//   _פאפי, _इनर_, --, --,
   {{0xe71700a5,0x7f5c02d7,0x7cef0a8c,0xc693016b}},	// [7560] _מחקר_, _surq, _høru, _נאז_,
   {{0x7bc11321,0x9c7c0124,0xa3cc00b4,0x273200ac}},	//   _oslu, _počm, लिद_, ránu_,
   {{0x4abd115c,0xaabd1bb5,0x54770122,0x7f5c1505}},	//   ्याव, ्याक, _מגיע_, _qurq,
   {{0x2732043f,0x794d0035,0x6da625a0,0x81bb0033}},	//   máns_, _dźwi, зида, _অপর_,
   {{0x237f0a78,0x7bc10211,0x27327210,0x00000000}},	//   ćuje_, _aslu, láns_, --,
   {{0x7f5c7211,0x4c947212,0xd132004f,0xd7db0099}},	//   _turq, фикс, _أمس_, यमाच,
   {{0x6023224a,0x2d9903c1,0xa9f401c0,0x00000000}},	//   _здра, _åsen_, इन्छ_, --,
   {{0xfbcf0773,0xada60e02,0x37d10033,0x9c7c00b8}},	//   اتو_, _набл, াহার, _kočk,
   {{0x3f9a01c6,0x7bc10282,0x7cfd0118,0xd8ca00af}},	//   lupu_, _eslu, _sère, бынд_,
   {{0x7cef01e0,0x7cfd000d,0xfcaa00f8,0x9c7c00ee}},	//   _sørv, _père, _دارو_, _močk,
   {{0xe69500af,0x00000000,0x00000000,0x00000000}},	//   мины, --, --, --,
   {{0x27320391,0x7bdb00a5,0x00000000,0x00000000}},	//   dáns_, _לקבו, --, --,
   {{0x6d4a7213,0x9c7c023a,0x00000000,0x00000000}},	//   omfa, _nočk, --, --,
   {{0x3f9a7214,0x69c21d35,0x48e300f0,0x7cfd021e}},	//   kupu_, _isoe, _почв, _tère,
   {{0x7cef0a8a,0xd90e0d4f,0x7cfd0176,0x00000000}},	//   _tørv, _لیک_, _hèrc, --,
   {{0x78ba0332,0xf4080037,0x68ea0345,0x7cef0249}},	//   letv, سيقى_, _hofd, _hørt,
   {{0x442d004e,0x672f004e,0x7cef01b4,0x273200b5}},	// [7570] łe_, mocj, _kørt, ránt_,
   {{0x656d306e,0x9c7c0187,0x51f810b0,0x78ba7215}},	//   _itah, _dočk, чную_, netv,
   {{0xdb030237,0x3f877216,0x28ae0035,0x656d0024}},	//   stné, énu_, ज्यि, _htah,
   {{0x64430392,0x69c20065,0x00000000,0x00000000}},	//   _úniq, _osoe, --, --,
   {{0xddab0368,0x78ba0110,0x00000000,0x00000000}},	//   стел_, ketv, --, --,
   {{0x78ba0210,0x7cfd0392,0x98a50228,0x11da011d}},	//   jetv, _sèrb, kolā_, _וחשב,
   {{0xdb1a0a20,0x00000000,0x00000000,0x00000000}},	//   _estí, --, --, --,
   {{0x24830200,0x6b8802d7,0x2b5e0a17,0x752e00cd}},	//   hajm_, _dvdg, _dutc_, zobz,
   {{0x656d08bd,0xda6400f3,0x7cfd0176,0x60c74dce}},	//   _ntah, رايي, _cèrc, _kajm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc10496,0x60c77217,0x656d306e,0xb5fb0037}},	//   _uslu, _majm, _atah, scál,
   {{0xa3cc0378,0x60c701d2,0x672f7218,0x6b9c0c61}},	//   लिस_, _lajm, gocj, _årga,
   {{0x2bc51e82,0x443c010b,0x7cef03db,0x20e001d1}},	//   विका, _šv_, _ført, नामध,
   {{0x60c70928,0x9c7c2190,0x7aeb0282,0x7cef008c}},	//   _najm, _ročk, _hogt, _gørt,
   {{0x03a31574,0xa7fc027d,0x53a349b8,0x7cef08c8}},	//   киро, ncıl, карб, _hørs,
   {{0x273252d1,0x9c7c0bca,0x656d0024,0x7cef08c8}},	//   ráns_, _počk, _ftah, _kørs,
   {{0x90c6081b,0x27320042,0x7aeb0069,0x045a0037}},	// [7580] мбае, sáns_, _mogt, _وجدت_,
   {{0x3f9a5cbf,0x7aeb03d0,0x61eb01ff,0x98b00009}},	//   tupu_, _logt, ägla, čaću_,
   {{0xd12f0037,0x7aeb0345,0x00000000,0x00000000}},	//   جمل_, _oogt, --, --,
   {{0x9c7c129f,0xee3a7219,0x3f9a103d,0x7aeb03bc}},	//   _točk, оне_, rupu_, _nogt,
   {{0x6284721a,0x7cef0a8a,0x00000000,0x00000000}},	//   maio, _nørs, --, --,
   {{0x3f9a2988,0x6d4a0409,0x62842f5f,0x00000000}},	//   pupu_, umfa, laio, --,
   {{0x78ba721b,0x7aeb2be5,0x6d4a721c,0xa0a30036}},	//   vetv, _bogt, rmfa, _шард,
   {{0xdd920118,0x60c7721d,0x7cef035b,0x9c7c3b1a}},	//   _لور_, _zajm, _børs, _moči,
   {{0x7aeb0173,0x9c7c008b,0xa2a63d9e,0x7c2d0448}},	//   _dogt, _loči, _छान्, ğara,
   {{0x7c2d00d0,0x200400a8,0x7cef0a8a,0x9404013b}},	//   şara, _əmin_, _dørs, şmə_,
   {{0x656d721e,0x78ba01a0,0xa7150208,0x7aeb721f}},	//   _stah, retv, емні, _fogt,
   {{0x7cef1953,0x656d0009,0x6f027220,0x3cfe7221}},	//   _førs, _ptah, nhoc, _hltv_,
   {{0xdb1a00c9,0x779200d1,0xc9f60037,0x69c201ed}},	//   _estã, ریکا, _تساع, _usoe,
   {{0x9c7c7222,0x9f470079,0x00000000,0x00000000}},	//   _boči, ánú_, --, --,
   {{0x7aeb01e8,0x7cf40392,0x672f022f,0x291e0159}},	//   _yogt, _càri, pocj, mnta_,
   {{0x60c73470,0x9c7c0207,0x656d0103,0x00000000}},	//   _sajm, _doči, _ttah, --,
   {{0x291e7223,0xa2a501c0,0x656d7224,0x00000000}},	// [7590] onta_, ङ्ग्, _utah, --,
   {{0x46dd02d1,0x2724037a,0xa3cc0d1f,0x291e7225}},	//   यावह, mına_, लिश_, nnta_,
   {{0x291e7226,0x6f02004f,0x272404d4,0x60c77227}},	//   inta_, fhoc, lına_, _vajm,
   {{0x7cef01b4,0x2b460023,0x48150070,0x26cb00f6}},	//   _nørr, _nhoc_, ײַען_, ndco_,
   {{0x27240463,0x60c77228,0x6b45014c,0x7aeb05f5}},	//   nına_, _tajm, nóge, _rogt,
   {{0x7cef0044,0x8c451c20,0xdca20fc5,0xde4600fd}},	//   _rørs, неле, гаши, ریلو_,
   {{0xcfa400af,0xeb997229,0x2b460211,0x7cef0044}},	//   _ишти, чий_, _bhoc_, _sørs,
   {{0x6f02722a,0x2b46722b,0x845800a5,0x2ca90355}},	//   choc, _choc_, ובוס_, řad_,
   {{0x7aeb480b,0x2724027d,0xc5f40033,0x28db13f0}},	//   _vogt, jına_, _চেনা_, बालि,
   {{0xdb1a12c3,0x2eed1516,0x78a903fa,0x27240644}},	//   _està, _hoef_, чког_, dına_,
   {{0xe73a0de3,0x2d9d722c,0xd90c00e0,0x2eed722d}},	//   зен_, luwe_, تیو_, _koef_,
   {{0x291e62a0,0x9c7c0b67,0x27240644,0x3af800fd}},	//   anta_, _roči, fına_, _lépj_,
   {{0x9c7c33ed,0x27240471,0xdb030355,0x2d9d04fb}},	//   _soči, gına_, ntní, nuwe_,
   {{0xa3cc009a,0x9c7c1851,0xb0ce004e,0xdce902f6}},	//   लिल_, _poči, _होंग, _oteč,
   {{0xb602000c,0x628401ed,0x2eff1217,0x2d9d722e}},	//   _žádn, taio, _oluf_, huwe_,
   {{0x27240644,0x2d9d722f,0x91e6663c,0x273900b5}},	//   bına_, kuwe_, нобе, yéni_,
   {{0x79897230,0x28a60066,0x40961578,0xb1462c93}},	// [75a0] nsew, _खामि, ерет, енал,
   {{0xa0a3002d,0x9c7c232f,0x62847231,0x6abd142a}},	//   лауд, _toči, saio, ्युर,
   {{0x6f027232,0x62847233,0x9c7c0254,0x2eff0345}},	//   thoc, paio, _uoči, _bluf_,
   {{0x44440496,0xdb1a7234,0xa85600a5,0x3f4700be}},	//   _iz_, _ostá, גיעה_, jõud_,
   {{0x291e7235,0x9c7c0a23,0x2d9d0010,0xdb1a01f7}},	//   ynta_, _močv, guwe_, _ortò,
   {{0x6f027236,0x2eff035f,0x361b0070,0x7cfd0118}},	//   shoc, _eluf_, הונד, _pèra,
   {{0x50432590,0x44443f01,0x67240176,0x272400c1}},	//   _берб, _jz_, _ojij, zına_,
   {{0xe6ca06bb,0x6e961c51,0x44447237,0x6bd30413}},	//   ियोज, _سلطا, _mz_, اتور,
   {{0x256600e9,0x443a0055,0x76447238,0xd8ca00af}},	//   _nôl_, _lyp_, _nziy, пынд_,
   {{0xf2df00e8,0x291e7239,0x39585849,0x7cfd0176}},	//   _nhân_, unta_, örs_, _hèrn,
   {{0xdb1a12d1,0x1be40825,0x80ca0083,0x764433c8}},	//   _está, _कपिल_, রাপ্, _aziy,
   {{0xaaa72fa9,0x27240092,0xdbc7007c,0x6b452278}},	//   _गायक, tına_, _pöör, tóge,
   {{0x4444040d,0x443a0239,0x7c3a001e,0x7a49000d}},	//   _az_, _ayp_, _hytr, rêté,
   {{0x272406a8,0xf2df0028,0x6d5a723a,0x2bc5035d}},	//   rına_, _chân_, _jita, विचा,
   {{0x6d5a723b,0x4444723c,0x272406a8,0x7644723d}},	//   _mita, _cz_, sına_, _eziy,
   {{0x083b0122,0x4444723e,0x7c3a723f,0xdbc700ab}},	//   _מעול, _dz_, _mytr, _töör,
   {{0x44447240,0x80ca00c8,0xdce902dd,0x32551a55}},	// [75b0] _ez_, রান্, _steč, твар,
   {{0x6d5a7241,0x00000000,0x00000000,0x00000000}},	//   _nita, --, --, --,
   {{0x628f008c,0x0f3500e0,0x2eed0298,0x8af7013b}},	//   _tdco, نکرد, _poef_, _şəmk,
   {{0x6d5a573e,0x3ee401d3,0x2d9d7242,0x6d487243}},	//   _aita, лючв, tuwe_, _ahda,
   {{0x6d5a3782,0xa2a60c57,0xdca554e1,0xd24400af}},	//   _bita, _छात्, вали, _бэри,
   {{0x27390187,0x2d9d0abd,0x2eed0345,0x00000000}},	//   ménu_, ruwe_, _woef_, --,
   {{0x6d5a6072,0xdb0305d3,0xed05006c,0xdce90a69}},	//   _dita, stní, _یورپ, _uteč,
   {{0xe9d90f28,0x40340421,0x6d5a7244,0x8e840037}},	//   дки_, _сесс, _eita, _ملفه,
   {{0x6d5a7245,0x79890107,0x7d550036,0x2b4d0af3}},	//   _fita, usew, _авах, rmec_,
   {{0x6d5a7246,0x256600e9,0xd9450274,0x6d4801da}},	//   _gita, _rôl_, ђени, _ghda,
   {{0x79890069,0x7d01003e,0x7cf40176,0x9c7c023a}},	//   ssew, _ills, _pàrv, _počv,
   {{0x6d5a7247,0x6e3b7248,0x444464d3,0x443a03bc}},	//   _zita, _kyub, _rz_, _ryp_,
   {{0x44447249,0xf2df0028,0x7ae9724a,0xddc20690}},	//   _sz_, _phân_, mjet, zbož,
   {{0x7ae9724b,0x81e70083,0x6d5a724c,0xdddb011c}},	//   ljet, বনা_, _xita, _oduž,
   {{0x28a63914,0x63831c1b,0x29050014,0x44440069}},	//   _खाति, игра, mhla_, _qz_,
   {{0x4444429e,0x7ae9724d,0x61e43f88,0x7afb724e}},	//   _vz_, njet, txil, nkut,
   {{0xf2df0028,0x4444724f,0x7d010037,0x7cf401f7}},	// [75c0] _thân_, _wz_, _olls, _kàrt,
   {{0x443a7250,0x4444000e,0x42554e91,0x7ae97251}},	//   _typ_, _tz_, утст, hjet,
   {{0x444431c9,0x7afb7252,0xb0d7004e,0x65647253}},	//   _uz_, kkut, ठाजग, _huih,
   {{0x7d017254,0x7f493dcb,0x7ae90024,0x65643394}},	//   _alls, _cheq, jjet, _kuih,
   {{0x6d5a0521,0x7ae97255,0x29055f8c,0xbea30272}},	//   _pita, djet, khla_, рачк,
   {{0xe046174b,0xb5fb00b5,0x973d00cd,0x656400c3}},	//   _анги, tbáz, muće, _muih,
   {{0x9fc72ab4,0xb5fb0037,0x09bc03de,0xf76704cd}},	//   _игра_, rcái, ्ट्य, _خا_,
   {{0x6d5a7256,0xb5fb004f,0xab270370,0x7afb7257}},	//   _wita, scái, која_, gkut,
   {{0x6d5a0ba4,0x2bc2157d,0x7c3a0035,0xee377258}},	//   _tita, _वैरा, _wytr, _ант_,
   {{0x6d5a0043,0x9c7c53c3,0x7afb7259,0xa3b3073f}},	//   _uita, _poču, akut, _टहल_,
   {{0xa09b00c2,0x2739725a,0x7ae91f4f,0xf8ad103b}},	//   וייט, ként_, bjet, سکو_,
   {{0x7ae9725b,0x973d00cb,0x7d182981,0x7bc8004b}},	//   cjet, kuće, livs, _isdu,
   {{0x973d0254,0x65640118,0xceb30070,0x290514a0}},	//   juće, _cuih, סיש_, bhla_,
   {{0x29050334,0x973d011c,0x776301ef,0x6564009e}},	//   chla_, duće, _funx, _duih,
   {{0xd7ef725c,0x9388725d,0x55580012,0xb6070093}},	//   _ту_, кста_, таря_, _bráð,
   {{0x7d181577,0x2bd300e7,0xf76f1a95,0x6445023a}},	//   hivs, थिता, _باو_, _vzhi,
   {{0xdb1a022a,0x45d504bf,0x973d0254,0x6b4501ef}},	// [75d0] _istä, _сопс, guće, nóga,
   {{0xc7ad0332,0x7f490031,0x2739031d,0x7cf414c4}},	//   _بڑی_, _sheq, rénu_, _xàrt,
   {{0x6e3b012f,0x50640142,0x7535003c,0x2d8d0207}},	//   _syub, ртуа, mozz, _svee_,
   {{0x7535725e,0xf2df0023,0x395c0830,0x9c8200cd}},	//   lozz, _khâm_, _livs_, ščla,
   {{0x3da7001f,0x7ae9725f,0x41e401c8,0xa184037c}},	//   треб, vjet, _кіра, _высл,
   {{0x7afb0159,0x6b55010b,0x7ae91bc9,0x403513df}},	//   wkut, _išgi, wjet, _бегс,
   {{0x7ae97147,0xa3cc004e,0x4fc40086,0x7afb0763}},	//   tjet, लिए_, _кста, tkut,
   {{0xaada00b8,0x7cfd0118,0xdb1a0282,0x77630069}},	//   भागक, _tèro, _nstä, _runx,
   {{0x7ae97260,0x9c7c0237,0x7cf47261,0x7cfd0118}},	//   rjet, _počt, _càrs, _hèrm,
   {{0x7ae97262,0x6f1900e9,0x776347fb,0x57e941e2}},	//   sjet, liwc, _punx, едом_,
   {{0x7ae95f1c,0x7cfd0118,0x65640421,0xb8eb20af}},	//   pjet, _jèrm, _suih, _लस_,
   {{0x6f1900e9,0x7cf4009e,0x29050207,0x8f9a00a5}},	//   niwc, _fàrs, shla_, עירי,
   {{0x59b70581,0xf2df0023,0x80ca0033,0x7cf40176}},	//   _अहिर, _châm_, রাত্, _tàrt,
   {{0x7535027a,0x9506006c,0xc9920037,0x27390015}},	//   gozz, اہدے_, _الوظ, féns_,
   {{0x65640118,0x00000000,0x00000000,0x00000000}},	//   _wuih, --, --, --,
   {{0x316900a8,0xdd8500b5,0xf2a300af,0x2a6d021d}},	//   fqaz_, _وڈ_, йисп, nceb_,
   {{0x91e301b8,0x6f19001e,0x26c27263,0x75357264}},	// [75e0] боте, diwc, meko_, bozz,
   {{0x26c27265,0x27390294,0x7535027a,0x51560352}},	//   leko_, béns_, cozz, утбу,
   {{0x9f47024e,0xdb1a0086,0x28a6020d,0x6f1900e9}},	//   šný_, _ystä, _खासि, fiwc,
   {{0x26c20291,0x973d011c,0x00000000,0x00000000}},	//   neko_, puće, --, --,
   {{0xa3cc0066,0x7d18057f,0x00000000,0x00000000}},	//   लिक_, tivs, --, --,
   {{0x26c201a3,0x628628ef,0x6b81016e,0x00000000}},	//   heko_, _heko, _bwlg, --,
   {{0x7d180523,0x6286128f,0x26c27266,0x6fc8021a}},	//   rivs, _keko, keko_, _रनिं,
   {{0x26c27267,0x7cf412c3,0x6f19001e,0x62860260}},	//   jeko_, _càrr, ciwc, _jeko,
   {{0xbef70122,0x26c20291,0x60ce0221,0x5886005f}},	//   _עצמו_, deko_, _kabm, лына,
   {{0x57b4320c,0x62867268,0xd90d03c5,0xd8f800d4}},	//   абот, _leko, وین_, тної_,
   {{0xdb03024e,0xeb970a87,0x39420029,0x62867269}},	//   stná, _бих_, ēks_, _oeko,
   {{0x62860bc6,0x26c2070b,0x3ea6726a,0x7cf401da}},	//   _neko, geko_, ngot_, _gàrr,
   {{0xf2df0019,0xadf90066,0xdc340168,0x00000000}},	//   _giây_, ्नयन_, _múčk, --,
   {{0xdc34063c,0x26cd0207,0x00000000,0x00000000}},	//   _lúčk, žeo_, --, --,
   {{0x628606eb,0x7535726b,0x26c206a2,0x99470037}},	//   _beko, rozz, beko_, _حلول_,
   {{0x41e70eb9,0xf2df0019,0x42750382,0x80a70b47}},	//   ліза, _thâm_, ргас, _चाहे,
   {{0x161c1e79,0x92590279,0xb1150409,0x34951402}},	// [75f0] _पेपर_, таат_, амаш, _капр,
   {{0xdddb00ac,0x10074b2a,0xa3cc073f,0x7cfd0107}},	//   _neuš, ляем, लिख_, _pèrm,
   {{0x155a00a5,0x99760067,0x00000000,0x00000000}},	//   _שכתב, nęły_, --, --,
   {{0x62866e48,0x3ea603d0,0x64c500b4,0x79820103}},	//   _geko, ggot_, _लघुश, _owow,
   {{0x6f1900e9,0x78b80103,0x00000000,0x00000000}},	//   riwc, _obvv, --, --,
   {{0x26c203cb,0xe3b00416,0x6286726c,0xeb991da6}},	//   zeko_, _بری_, _zeko, вик_,
   {{0x26c22f7e,0x628601a8,0x7982030d,0x7cf4009e}},	//   yeko_, _yeko, _awow, _pàrr,
   {{0x26c201d7,0xdab900d8,0x241800a5,0x7982030d}},	//   xeko_, тыкі_, טחון_, _bwow,
   {{0x31af2c7c,0x6ca70071,0x090501e0,0x26c201ed}},	//   nüz_, _مصال, ипин, veko_,
   {{0xbc68004f,0x2903006c,0x6b45171c,0x26c22a92}},	//   _ممكن_, ója_, cógn, weko_,
   {{0x26c2726d,0x7b17002d,0x28a60035,0x7cf40310}},	//   teko_, lţum, _खारि, _tàrr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c2726e,0xd8f500bf,0x38ca00d1,0x6b45726f}},	//   reko_, _پزشک, رایی_, lógo,
   {{0x62861221,0x26c27270,0x88bc00b8,0x64a60166}},	//   _seko, seko_, lněn, јава,
   {{0x07a57271,0x26c201d7,0x69d9110e,0x60ce023a}},	//   _тайн, peko_, _hrwe, _rabm,
   {{0x05663471,0xaabd052b,0xe2970036,0x69d97272}},	//   _квин, ्यटक, иас_, _krwe,
   {{0x62867273,0x21a64cf3,0xf2670043,0xdc340168}},	// [7600] _veko, ризм, риул_, _rúčk,
   {{0xe0460cb5,0xb05a0037,0xdb0300be,0x6b55005f}},	//   анзи, نشاط_, ltnä, _išgu,
   {{0x62867274,0xc05900d4,0x3dc60069,0x9e667275}},	//   _teko, гії_, wwow_, авед,
   {{0x205512da,0xf98700bf,0x88bc00b8,0x00000000}},	//   стур, _وب_, jněn, --,
   {{0x60ce006d,0x3ea600a5,0x88bc00b8,0xee37658d}},	//   _tabm, rgot_, dněn, анц_,
   {{0x80ca0083,0x3ea60f3a,0x26070437,0x7cf40392}},	//   রাহ্, sgot_, हनती_, _pàrq,
   {{0xb5fb03e6,0x69d9001e,0x69cb5648,0xb86600b5}},	//   ncár, _arwe, _asge, یادو,
   {{0xbea324da,0x973d0009,0x539b076b,0x00000000}},	//   _маск, kuća, דיקו, --,
   {{0xdca60183,0x6c960079,0x2bb8021a,0x00000000}},	//   _вази, _نشاط, _आहवा, --,
   {{0xa3e60311,0x7f427276,0x273205fa,0xd90e0a86}},	//   पमा_, lloq, mány_, بیت_,
   {{0x69d902c9,0xda6f4ca7,0x30d902b5,0x60d902b5}},	//   _erwe, _мя_, אַרע, אַרג,
   {{0x88bc00b8,0x7bda0024,0x2bd30099,0x00000000}},	//   cněn, _irtu, थिरा, --,
   {{0xceb30122,0x973d0a78,0x7ae25672,0x26170d34}},	//   חיר_, guća, _inot, _पेशी_,
   {{0xd90e00d1,0xb0d50099,0x31af0448,0xd498355e}},	//   _آید_, _डोंग, vüz_, ирс_,
   {{0x2732006c,0x13680d6e,0xd7fa0431,0x2cac0051}},	//   hány_, ишти_, _јул_, _mcdd_,
   {{0xdb1a0d99,0xe7050609,0xa2da021a,0x00000000}},	//   _astú, _دستی, _पोद्, --,
   {{0x3358002d,0x20670274,0xb5fb002a,0x00000000}},	// [7610] ратэ_, ађев, acár, --,
   {{0x7bda4976,0x88bc0355,0x27327277,0x00000000}},	//   _ortu, zněn, dány_, --,
   {{0x83f96c89,0x31af0448,0x7ae2073a,0xa2670382}},	//   _сенс_, süz_, _onot, _въгл,
   {{0xa8570122,0xdb1a1e60,0x80ca0033,0x48dd00ab}},	//   ביבה_, _estú, রাষ্, _कोनो_,
   {{0x88bc00b8,0xd08700c3,0x273205fa,0x6b6a0067}},	//   vněn, _выби, gány_, _węgl,
   {{0x7ae20122,0xfbd1004f,0x7bda0183,0x00000000}},	//   _anot, كتب_, _brtu, --,
   {{0x7f42000d,0x88bc00b8,0x7f94005f,0x4ea70279}},	//   bloq, tněn, _марх, _врза,
   {{0xcac90086,0xdb0301f4,0xd5b90f8a,0x7cfd0310}},	//   угие_, munë, ेबाज, _mèri,
   {{0x88bc00b8,0x80ca0033,0x7bdc008d,0x3ead7278}},	//   rněn, রার্, _árun, _icet_,
   {{0x09053626,0x60c502c9,0x7ae27279,0x628d011e}},	//   спон, nehm, _enot, haao,
   {{0xdab901c8,0x88bc00b8,0x7ae203d0,0x00000000}},	//   _былі_, mněl, _fnot, --,
   {{0x6d43022a,0x7ae201a6,0x0a1800d1,0x00000000}},	//   llna, _gnot, افیک_, --,
   {{0xe8ee3e9c,0x69d90010,0x7cfd0310,0xdb0310c0}},	//   _ел_, _urwe, _aèri, rtnä,
   {{0xdce0013a,0x4aa700ab,0x7cfd01f7,0x07f9128b}},	//   _kumā, _गाँव, _bèri, _مربع_,
   {{0x68fc727a,0xe29a384b,0x973d022f,0x69c9727b}},	//   örde, лав_, suća, lwee,
   {{0x6aa9727c,0x27f8018d,0xadf904bc,0x7cfd01f7}},	//   ngef, ärne_, ्नान_, _dèri,
   {{0x9c8200d8,0x69c9727d,0xb5fb0300,0xa3cc0761}},	// [7620] ščia, nwee, scár, लिङ_,
   {{0x26d20657,0x343a03c7,0x2732727e,0x6aa901ae}},	//   _hayo_, _مسجد_, vány_, hgef,
   {{0x4aa70299,0x26d203a2,0x63be029b,0xdb1a01ba}},	//   _गांव, _kayo_, _uppn, _vstú,
   {{0x69c9727f,0x26d20103,0xbea651fe,0xe8090067}},	//   kwee, _jayo_, садк, हैया_,
   {{0x26d27280,0xdd8f0206,0x6da37281,0x644a0124}},	//   _mayo_, فون_, зича, šlić,
   {{0x26d218ad,0xd1320125,0x69c932c5,0x7ae2183a}},	//   _layo_, _رمز_, dwee, _snot,
   {{0x8fa30525,0x973d0a78,0xb60602c6,0x6aa97282}},	//   _наре, dućn, lišč, fgef,
   {{0x26d215c4,0x7bda28e8,0x68e37283,0x49743bd5}},	//   _nayo_, _vrtu, _annd, олис,
   {{0xdce20254,0x3eb300a8,0x2cac0381,0x00000000}},	//   spođ, əxt_, _tcdd_, --,
   {{0xa2da4e29,0x973d01cc,0xdd8f004f,0x26d26ca6}},	//   _पोस्, gućn, _أول_, _aayo_,
   {{0x06e405e7,0x26d27284,0x69c9001c,0x7d080b3e}},	//   गांव_, _bayo_, awee, _ilds,
   {{0x26d27285,0x6f027286,0x2d4920d9,0x29077287}},	//   _cayo_, nkoc, núen_, _elna_,
   {{0xe8940086,0x26d27288,0x7afd7289,0x7cfd12c3}},	//   _даль, _dayo_, öste, _sèri,
   {{0xb606108a,0xf76f00d1,0x7cfd0176,0x00000000}},	//   dišč, بای_, _pèri, --,
   {{0x291e728a,0x249f06d3,0xf1bf728b,0x6b55004b}},	//   mita_, ğum_, _spá_, _išgr,
   {{0x26d2728c,0x6ec400be,0x6b7102d4,0x249f00c1}},	//   _gayo_, _रसगु, _jāga, şum_,
   {{0x7d0801e0,0xbbb500b8,0x291e0086,0x6f0200a0}},	// [7630] _olds, _अङ्क, oita_, dkoc,
   {{0x764d728d,0x26d201d5,0xdb030031,0x22420185}},	//   _izay, _zayo_, tunë, _dykk_,
   {{0x26d20010,0x6f02033b,0x291e023c,0x00000000}},	//   _yayo_, fkoc, iita_, --,
   {{0x291e728e,0x2a66006d,0x141a00a5,0x7d1a728f}},	//   hita_, _ngob_, _כותב, _amts,
   {{0x291e7290,0x7cfd0107,0x00000000,0x00000000}},	//   kita_, _mèrv, --, --,
   {{0x21ba02b5,0x291e7291,0xdb037292,0x672d02c4}},	//   _דזשא, jita_, muné, _ljaj,
   {{0x81bb0083,0xdd91006c,0x2d4901dd,0x973d011c}},	//   _আছি_, سوں_, búen_, jućo,
   {{0x69c90052,0x7d08718d,0x764d0107,0x973d00cd}},	//   twee, _elds, _ozay, dućo,
   {{0x6aa928eb,0x26d21a84,0x61ed301c,0xae1600a1}},	//   rgef, _rayo_, nxal, _देऊन_,
   {{0x26d27293,0x69c9152b,0x6aa901ae,0x672d7294}},	//   _sayo_, rwee, sgef, _ajaj,
   {{0xb17b06d7,0x69c97295,0x26d20dc3,0x657d0051}},	//   _fråg, swee, _payo_, epsh,
   {{0xe73a0923,0x7cfd01f7,0xf2df0023,0xb17b008c}},	//   рем_, _cèrv, _khâu_, _gråg,
   {{0x291e7296,0x6f090067,0xa2da00a9,0x15ba00c7}},	//   bita_, _mlec, _पोष्, шыны_,
   {{0x291e7297,0x240a2f44,0x290c0284,0x26d201d5}},	//   cita_, анги_, chda_, _wayo_,
   {{0x26d20269,0x764d7298,0xc74601b2,0x6f1b073a}},	//   _tayo_, _ezay, _وضعي, _omuc,
   {{0xa22a029f,0xb606008b,0x98ac010b,0x00000000}},	//   ажба_, tišč, rodą_, --,
   {{0x256f037a,0x6f0201ba,0x88bc00b8,0xdce0002d}},	// [7640] _gül_, vkoc, dněj, _jumă,
   {{0xf53f04ca,0x6f090814,0xa2da00b4,0xb606008b}},	//   står_, _alec, _पोर्, rišč,
   {{0x2d490391,0x7bc1006f,0x753c7299,0x6f09729a}},	//   túen_, _nplu, morz, _blec,
   {{0x291e729b,0x444401d5,0x91e654d4,0x290c729c}},	//   zita_, _iy_, _доме, zhda_,
   {{0x44441e4f,0xf2df0028,0x6f02729d,0x291e33f4}},	//   _hy_, _châu_, rkoc, yita_,
   {{0x4444729e,0x6f093ec3,0x291e06a2,0x2d490391}},	//   _ky_, _elec, xita_, súen_,
   {{0x44441e4f,0x6f09729f,0x88bc0355,0x6f0200fd}},	//   _jy_, _flec, bněj, pkoc,
   {{0x444472a0,0xaec3487d,0x291e72a1,0x394512c3}},	//   _my_, _обсл, wita_, ells_,
   {{0x291e1014,0x753c004e,0x444472a2,0xb17b1bd3}},	//   tita_, korz, _ly_, _gråd,
   {{0x444472a3,0x672d0a78,0xeb9a0133,0x644100ab}},	//   _oy_, _sjaj, _виж_, ülik,
   {{0x44444409,0x291e3c5d,0x764d00d7,0xe1ff0019}},	//   _ny_, rita_, _szay, _ngón_,
   {{0x290c72a4,0xdce00139,0x764404fb,0x38690225}},	//   shda_, _fumă, _byiy, _şart_,
   {{0x444472a5,0x291e72a6,0x753c72a7,0xe81a0084}},	//   _ay_, pita_, forz, _फेरा_,
   {{0x444472a8,0x657d34eb,0x81c20033,0xe4e401e0}},	//   _by_, rpsh, ্মা_, місн,
   {{0x4444070b,0x987b0317,0x59d20ec5,0x7644073a}},	//   _cy_, _דרוק, तिकर, _eyiy,
   {{0x444472a9,0xf2df0023,0x63a7011c,0x68f81b99}},	//   _dy_, _nhât_, rujn, _hovd,
   {{0x444472aa,0x88bc01c0,0x764d72ab,0x753c5cc9}},	// [7650] _ey_, vněj, _uzay, borz,
   {{0xd49b1641,0x44440297,0x6f090a75,0x6f1b0a66}},	//   _три_, _fy_, _slec, _smuc,
   {{0x6f091a2f,0x44440273,0x656d72ac,0x88bc0355}},	//   _plec, _gy_, _huah, tněj,
   {{0x5187021d,0x656d002f,0xb69b000d,0x2d49002a}},	//   _муга, _kuah, chât, túeo_,
   {{0x7bc122b3,0x237f0254,0x39450282,0x88bc0355}},	//   _splu, ćuju_, ylls_, rněj,
   {{0x88bc00b8,0x00000000,0x00000000,0x00000000}},	//   sněj, --, --, --,
   {{0x6b452b10,0x69c272ad,0x4bd901c8,0x656d028b}},	//   lógi, _apoe, сьля_, _luah,
   {{0x6f1b0232,0xb17b34ae,0x3cdb04bc,0xb60600ac}},	//   _umuc, _tråd, _गोरे_, _hráš,
   {{0x673d0124,0x3b0d0031,0x60d51870,0x00000000}},	//   dosj, rheq_, _kazm, --,
   {{0x60d572ae,0x973d022f,0x635c0359,0xdb1a07c0}},	//   _jazm, sućl, _dčny, _istý,
   {{0x753c72af,0x6d410452,0x60d572b0,0x656d0553}},	//   vorz, _ikla, _mazm, _auah,
   {{0x444472b1,0x656d0464,0x753c004e,0x291c0987}},	//   _ry_, _buah, worz, _emva_,
   {{0x444472b2,0x753c004e,0xf96b002d,0x7cfd01f7}},	//   _sy_, torz, _трей_, _fèrt,
   {{0xb97a00a5,0x64450a8c,0x60d572b3,0x249172b4}},	//   _הנסי, _byhi, _nazm, gazm_,
   {{0x987a0070,0x7af9681e,0x638600d8,0x444401e9}},	//   _פאקט, _kowt, ягва, _qy_,
   {{0x444472b5,0xfe65006c,0x7e6900f8,0xe3630368}},	//   _vy_, _لگ_, _ngep, екси,
   {{0x444472b6,0x753c72b7,0x6b4572b8,0x5bb80803}},	// [7660] _wy_, porz, gógi, _आह्व,
   {{0x444472b9,0x205611d0,0x3ebf02b3,0xd24f0037}},	//   _ty_, птер, _abut_, انك_,
   {{0x444472ba,0x2126011c,0x60d50069,0x09b70033}},	//   _uy_, đoh_, _dazm, জিটা,
   {{0x6d4172bb,0xb17b1f8b,0xfbc30033,0x00000000}},	//   _akla, _dråb, ্মাত, --,
   {{0x628409ab,0x26c00054,0x44330176,0x00000000}},	//   mbio, _mbio_, _zxx_, --,
   {{0x60d572bc,0xdde911cf,0x290502c4,0x673d0124}},	//   _gazm, ترمه_, jkla_, zosj,
   {{0x69c2152b,0x7af972bd,0x26c002d7,0x6d583fd5}},	//   _spoe, _bowt, _obio_, rmva,
   {{0x6d4172be,0x79a6263d,0x1dd40387,0x628472bf}},	//   _ekla, прое, _धनपत, nbio,
   {{0x6da30b07,0x60d506d0,0x673d72c0,0x7afd2a7e}},	//   _пита, _yazm, vosj, östa,
   {{0x290a278b,0x29050159,0x80ca0033,0x656d023c}},	//   óba_, gkla_, রাক্, _ruah,
   {{0x7af90024,0x656d72c1,0x7cfd72c2,0x673d72c3}},	//   _fowt, _suah, _vèrt, tosj,
   {{0xe7ed0722,0xb9031f57,0x6d410355,0xb3470183}},	//   _छपरा_, _पो_, _zkla, _maçô,
   {{0xb0ac02cb,0xcb1302b8,0x673d02ce,0x656501ef}},	//   _चांग, _אלף_, rosj, _pihh,
   {{0x2ec972c4,0x38c8006c,0x2905013c,0x291c01d5}},	//   _रस्त, _ذاتی_, ckla_, _umva_,
   {{0x60d50888,0x58bb0122,0x88bb00a5,0x38cb0220}},	//   _razm, _המוצ, _המוז, _دانی_,
   {{0x656d2971,0x00000000,0x00000000,0x00000000}},	//   _tuah, --, --, --,
   {{0xb6060187,0x26cb00cc,0xd23402fb,0x00000000}},	// [7670] _práš, meco_, ентъ, --,
   {{0x26cb7285,0x26c000cd,0x80c70067,0x00000000}},	//   leco_, _zbio_, रजें, --,
   {{0x628407e5,0x200772c5,0x61e90009,0x60d50124}},	//   bbio, áni_, _šeld, _vazm,
   {{0x6d4172c6,0x26cb2ef4,0x2007003c,0x200f0067}},	//   _skla, neco_, ġni_, ągi_,
   {{0x200702dd,0x9f5c01c0,0x60d50225,0x290572c7}},	//   šni_, ává_, _tazm, ykla_,
   {{0x8c45082e,0xee3802ce,0x26cb0183,0x00000000}},	//   меле, чні_, heco_, --,
   {{0x6d41024e,0x26cb00e0,0x7af90035,0x628f10cd}},	//   _vkla, keco_, _powt, _keco,
   {{0x6441006a,0x7e690a8a,0x628f0107,0x2ef5004b}},	//   żliw, _ugep, _jeco, _ўзар,
   {{0xf1e00d91,0xc27c00a5,0x290500ac,0x00000000}},	//   नियन, זרחי, tkla_, --,
   {{0x48050a55,0x27392d87,0x6d4133ee,0xdb0333d5}},	//   дпов, mény_, _ukla, muní,
   {{0x628f1efe,0xb6a60183,0x26cb02d7,0x629d53eb}},	//   _oeco, минл, feco_, _odso,
   {{0x3ceb065a,0x628f72c8,0xeab00037,0x290503ee}},	//   चावे_, _neco, _معه_, skla_,
   {{0xe8f50037,0x00000000,0x00000000,0x00000000}},	//   _يستخ, --, --, --,
   {{0xd8250798,0x629d190f,0x00000000,0x00000000}},	//   _одли, _adso, --, --,
   {{0x628f0122,0x62840069,0xaac20035,0x98ac00b8}},	//   _beco, tbio, _वॉडक, hodě_,
   {{0x26c00254,0x26cb01ed,0x00000000,0x00000000}},	//   _ubio_, ceco_, --, --,
   {{0x628472c9,0x628f72ca,0xa09a0037,0x00000000}},	// [7680] rbio, _deco, قضاء_, --,
   {{0x8cbf0b4a,0x629d0279,0x62840282,0x9c7c0260}},	//   ल्मो, _edso, sbio, _enčj,
   {{0x628f72cb,0x6b45006c,0x25740523,0x00000000}},	//   _feco, lógu, _häl_, --,
   {{0x628f0a75,0x6da60210,0x00000000,0x00000000}},	//   _geco, дида, --, --,
   {{0x273900b5,0x00000000,0x00000000,0x00000000}},	//   gény_, --, --, --,
   {{0x628f0207,0x00000000,0x00000000,0x00000000}},	//   _zeco, --, --, --,
   {{0x69dd3a92,0x00000000,0x00000000,0x00000000}},	//   æsen, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cb0171,0xbebd00c7,0x25740282,0x00000000}},	//   veco_, _smūg, _näl_, --,
   {{0xcce60037,0x00000000,0x00000000,0x00000000}},	//   _تسري, --, --, --,
   {{0x7c65004f,0x26cb1214,0xdb0a01ff,0x973d0124}},	//   _كامل, teco_, ttfä, lući,
   {{0x6d4a72cc,0xa96a0390,0xdb1a72cd,0x798b099e}},	//   llfa, _дида_, _estò, _fwgw,
   {{0xdb0300a0,0x276802fd,0xb5fb0138,0x6b4500fd}},	//   ntný, _کشتی_, lcáz, gógu,
   {{0x628f0db7,0xdb0a1788,0x00000000,0x00000000}},	//   _seco, stfä, --, --,
   {{0x628f72ce,0x3eaf0e80,0x27390187,0x9c7c3f84}},	//   _peco, yggt_, zény_, _ančk,
   {{0x973d044d,0xe6670431,0x35b504a1,0x80c100b8}},	//   kući, _отпо, _збир, र्ने,
   {{0x443f004e,0x973d0254,0x61e90009,0x628f72cf}},	// [7690] łu_, jući, _šelb, _veco,
   {{0x973d011c,0xc5f200a5,0x7b17002d,0xb21b008c}},	//   dući, _עדי_, nţur, _beær,
   {{0x442706d7,0xb4cb00a1,0x35f80647,0x00000000}},	//   _än_, ळजी_, _فرید_, --,
   {{0x629d01b4,0xe0cf0033,0xbebd013a,0x27392d95}},	//   _udso, রাইভ, _ajūr, tény_,
   {{0x973d0a78,0x31790070,0x6da50210,0x80ca0033}},	//   gući, _מאָד, хила, রাজ্,
   {{0xabd504bf,0x7871006c,0xb17b0282,0x00000000}},	//   ециј, _művé, _gråa, --,
   {{0x8c420c9f,0x3a290160,0x00000000,0x00000000}},	//   леше, _ţap_, --, --,
   {{0x0dcb0b97,0x6d4a72d0,0x1ee700ff,0x00000000}},	//   _музи_, alfa, _توری_, --,
   {{0x1d3502fb,0xdb1a0a8a,0x00000000,0x00000000}},	//   _зная, _optæ, --, --,
   {{0xb4ce018d,0x3f6800c1,0x8ca9021a,0x00000000}},	//   _रसे_, _uğur_, _घाटो, --,
   {{0xb8d70f91,0x80c1022e,0x2d8d1872,0x80ca0033}},	//   _छा_, र्ये, _hwee_, রাচ্,
   {{0x2d8d022e,0xe5a61309,0x290e72d1,0x6448018d}},	//   _kwee_, ними, _elfa_, üdim,
   {{0x7e7b0054,0x7aeb0118,0x98a5002d,0x00000000}},	//   _mfup, _ingt, _зиле, --,
   {{0x257406d7,0x49b82149,0xa0000033,0x80c10f17}},	//   _väl_, _زاهد_, _এইসব_, र्मे,
   {{0xa3e772d2,0xd3720bdf,0xdddb0749,0x00000000}},	//   ндра_, اهر_, _neuž, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb1202b5,0x05770079,0x25ea021a,0x00000000}},	// [76a0] אלן_, _كمية_, _चपटी_, --,
   {{0x4f96002d,0x973d0207,0xdddb005f,0x00000000}},	//   ерду, vući, _beuž, --,
   {{0x66061f8b,0x24b70070,0xa4b700a5,0x2d8d0103}},	//   lykk, _אהין_, _אליה_, _awee_,
   {{0x67100e96,0x216a00aa,0x2d8d022e,0x00000000}},	//   ासिक_, _ними_, _bwee_, --,
   {{0x63ae0d14,0x00000000,0x00000000,0x00000000}},	//   lubn, --, --, --,
   {{0x6296121e,0x61460009,0x7aeb0159,0x3d1900b5}},	//   layo, _чега, _angt, وٹنگ_,
   {{0x1fb50798,0xdb034cbf,0x973d0124,0x00000000}},	//   _истр, stný, sući, --,
   {{0x6e930082,0x62960657,0xa06742ee,0xdd9202ed}},	//   _ملفا, nayo, _часа_, _مور_,
   {{0x88bc00b8,0x95ef0461,0x80d30831,0x00000000}},	//   knět, _चपेट_, সার্, --,
   {{0x62960a04,0x7b15171c,0xa3c000b4,0x92cc0831}},	//   hayo, _náuf, ंझा_, লায়_,
   {{0xf53f022a,0x62961982,0x60c1027d,0x88bc0355}},	//   från_, kayo, _ölme, dnět,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629603be,0x9c7c17d1,0x00000000,0x00000000}},	//   dayo, _anči, --, --,
   {{0x63a172d3,0x290e012f,0xdb030097,0x00000000}},	//   álno, _ulfa_, muná, --,
   {{0xa29501c8,0x63ae0ce9,0x6b4501ef,0xf72b00af}},	//   каві, gubn, mógr, _нций_,
   {{0x62962487,0xdb1801ba,0xa6db003e,0x635c0211}},	//   gayo, ftvé, boða, _sōnr,
   {{0xa0a700af,0x4ac20d00,0xaac206fe,0x30a710e3}},	// [76b0] ешел, व्यव, व्यक, ерев,
   {{0x6b450a20,0x337500c3,0x62960159,0xb17b01ff}},	//   nógr, _игор, aayo, _från,
   {{0xa3c5007c,0xe7e3007c,0x2d8d00d7,0x04670210}},	//   _एहि_, गिया_, _swee_, _ятим,
   {{0x62960453,0xfe7000bc,0x316a01ed,0x00000000}},	//   cayo, مده_, _eibz_, --,
   {{0x4ea40081,0x7bc80197,0xa69c016b,0x00000000}},	//   урха, _apdu, לשאפ, --,
   {{0xe1ff00e2,0x313515df,0x7b0e009e,0x973d00f4}},	//   _ngói_, _регр, _rùua, muću,
   {{0xb60600ee,0x80c10b35,0xdce1013a,0x00000000}},	//   _kráá, र्णे, _cilā, --,
   {{0x2d8d1c47,0x2bc202cb,0x7e7b002f,0x1ae5244d}},	//   _twee_, _शहरा, _ufup, тоим,
   {{0x0edd004e,0x7e6400cb,0x6b450098,0x00000000}},	//   _नोएड, žipr, fógr, --,
   {{0x3cfe012f,0x629672d4,0x74ad37e8,0x00000000}},	//   _gotv_, zayo, _जागृ, --,
   {{0xe73a36eb,0x6296018e,0x3cfa0070,0xab8403e6}},	//   ден_, yayo, _קלענ, _бучк,
   {{0xfbd202b8,0x80c1178c,0x660672d5,0xdb0300d5}},	//   _כתב_, र्ते, tykk, buná,
   {{0x50b30026,0x629672d6,0x75270051,0xaa880037}},	//   ुभाष, vayo, fijz, _أنهم_,
   {{0x2b401851,0x290b0029,0x2b4d72d7,0x63ae012f}},	//   čice_, īcas_, llec_, tubn,
   {{0x629672d8,0x672672d9,0xa8480079,0x00000000}},	//   tayo, pikj, _كلهم_, --,
   {{0x6d430ec0,0x2d800012,0x63ae0097,0x61e90009}},	//   hona, ţiei_, rubn, _šela,
   {{0x6d4372da,0x629672db,0x973d0254,0x491800dc}},	// [76c0] kona, rayo, guću, योको_,
   {{0x6d4372dc,0x629672dd,0x224b01a2,0xb17b01ff}},	//   jona, sayo, _dyck_, _trån,
   {{0xf9f90083,0x629602b3,0x3f9c00f7,0x224b01ef}},	//   েছিল_, payo, évu_, _eyck_,
   {{0xa85600a5,0xbe661902,0x8fa36ac5,0x00000000}},	//   דיעה_, نهاي, раце, --,
   {{0x6d4372de,0x9db710ee,0x3cfe0009,0x00000000}},	//   fona, ندوز_, _potv_, --,
   {{0x6d4372df,0x80c1111b,0xdfd20647,0x6b55010b}},	//   gona, र्दे, _پير_, _išgy,
   {{0x60dc72e0,0x61e60207,0xdea201cb,0x00000000}},	//   _iarm, _hrkl, _نیای, --,
   {{0x443a0036,0x61e600f4,0xe6dc04aa,0xfa230831}},	//   _mxp_, _krkl, ययोज, _পড়ল_,
   {{0x6d4372e1,0x6f000094,0x6b4508c0,0x799b0cca}},	//   bona, _iomc, tógr, gsuw,
   {{0x6d4372e2,0x67240009,0x998d0035,0x61e60124}},	//   cona, _amij, dzeń_, _mrkl,
   {{0x60dc72e3,0x2b4d1e85,0x6b4567f9,0x645a0093}},	//   _marm, blec_, rógr, ýtil,
   {{0x60dc72e4,0x75270a75,0x7c3a035f,0xb17b0282}},	//   _larm, wijz, _ixtr, _brål,
   {{0x6f03051b,0x6f00003a,0x67240069,0xcb6703e6}},	//   ênci, _momc, _dmij, _раце_,
   {{0x67245b34,0x06241d13,0x00000000,0x00000000}},	//   _emij, рфюм, --, --,
   {{0x61e6010b,0x752701e4,0x18a30d6e,0x00000000}},	//   _arkl, rijz, _тајм, --,
   {{0x6d4372e5,0x61e60612,0x41e754ea,0x45d5081b}},	//   zona, _brkl, кіза, _боис,
   {{0x6d4372e6,0x443a72e7,0x998d004e,0x61e60612}},	// [76d0] yona, _exp_, czeń_, _crkl,
   {{0x67240254,0x6d434d05,0x764d007b,0x2eff02d0}},	//   _zmij, xona, _iyay, _souf_,
   {{0x60dc72e8,0x6d4372e9,0x61e672ea,0x2eff72eb}},	//   _darm, vona, _erkl, _pouf_,
   {{0x6d4872ec,0xe7e306d9,0x224b01ff,0x776d0176}},	//   _akda, गिता_, _tyck_, _jiax,
   {{0xddc568be,0x6d4372ed,0x60dc72ee,0x6d5a009e}},	//   убли, tona, _farm, _bhta,
   {{0x3f4700be,0x621a076b,0x6d5a026e,0x00000000}},	//   tõus_, _טורק, _chta, --,
   {{0x5f9472ef,0x8b9400d8,0x3f67005f,0xdcfb00f4}},	//   _вист, арыч, _атаб, _utuč,
   {{0xe9d95b60,0x799b0159,0x6d4372f0,0x764d0159}},	//   еки_, tsuw, sona, _oyay,
   {{0x6d4372f1,0x764d72f2,0x60dc72f3,0x39470fef}},	//   pona, _nyay, _yarm, _pkns_,
   {{0x67240280,0x29110187,0x7c3a0024,0x60dc01b7}},	//   _smij, óza_, _fxtr, _xarm,
   {{0x764d72f4,0xd8250994,0xdb03021d,0x00000000}},	//   _ayay, удни, junç, --,
   {{0xa3e7007c,0x24981b4a,0x764d2506,0x681300a8}},	//   पिन_, warm_, _byay, nədə,
   {{0x64400095,0x7d0145c4,0x764d01d5,0xdce10160}},	//   əmiy, _kols, _cyay, _gilă,
   {{0x69d9035f,0x7afb72f5,0x588772f6,0x998d0035}},	//   _iswe, ljut, _рыда, rzeń_,
   {{0x394502d4,0xa6c90083,0x249872f7,0xdce901ba}},	//   mols_, ষয়ট, rarm_, _oveľ,
   {{0x7afb0f1a,0x67242676,0x61e672f8,0x80c11856}},	//   njut, _umij, _prkl, र्से,
   {{0x60dc72f9,0x2d490138,0xdb1a00ee,0x333201ef}},	// [76e0] _parm, núes_, _istô, rnyx_,
   {{0xb17b093a,0x23600207,0x7afb00be,0xdb0300d5}},	//   _gråm, smij_, hjut, drní,
   {{0x60dc3701,0x94bb0122,0xdee61150,0xbeaa00d1}},	//   _varm, _אמית, ложи, فهان_,
   {{0xee3a0a93,0x69cb201e,0x6d5a5f34,0x7f5b1d4e}},	//   нне_, _opge, _shta, _chuq,
   {{0x7d0125eb,0x7afb022f,0xddc90207,0x69d90371}},	//   _bols, djut, _efež, _nswe,
   {{0x7d0172fa,0x8cbf0026,0x39450176,0x271000b4}},	//   _cols, ल्लो, jols_, ासुर_,
   {{0x61e472fb,0x69d972fc,0x6e3b310f,0x798272fd}},	//   lvil, _aswe, _exub, _stow,
   {{0x7d010009,0xfbcf0312,0x25a00107,0x61e4018d}},	//   _eols, ستى_, _ovil_, ovil,
   {{0x80c137e8,0xe7e30083,0x39142447,0x69d90176}},	//   र्वे, মহোয, имир, _cswe,
   {{0x41bb02b5,0xd90e006c,0x7d010069,0x91bb0070}},	//   עציע, ثیت_, _gols, עמיי,
   {{0xb0c60026,0x61e472fe,0x290c013b,0xac970037}},	//   र्यग, hvil, rkda_, _إنما_,
   {{0x7bda72ff,0xd6db0eb9,0x61e47300,0x2d4902d7}},	//   _istu, хто_, kvil, búes_,
   {{0x776d043f,0xdce8021e,0xdb1a0098,0x798200f8}},	//   _viax, _lidč, _optú, _utow,
   {{0x61e47301,0x69c0010b,0xdb1a0132,0x272b0260}},	//   dvil, mtme, _estô, _bònè_,
   {{0xd7ef02c4,0x61e423dc,0x69c07302,0xd498004c}},	//   _уу_, evil, ltme, ыря_,
   {{0x2bac1bb5,0x69c003bc,0x2d8400cd,0x00000000}},	//   _घटना, otme, _otme_, --,
   {{0x69c07303,0xa5f90012,0xdb030132,0x764d0159}},	// [76f0] ntme, _репу_, sunç, _uyay,
   {{0x69c07304,0x7bda00ab,0x926805ac,0x31c40200}},	//   itme, _ostu, урса_, љств,
   {{0xdfd10286,0x7d0111cc,0x69c000be,0x61e47305}},	//   تيا_, _rols, htme, avil,
   {{0x7d017306,0x2d9d0232,0x00000000,0x00000000}},	//   _sols, tswe_, --, --,
   {{0x7d010803,0x6cf00026,0x26c9002f,0x681300a8}},	//   _pols, चांग_, _mbao_, rədə,
   {{0xfce501f0,0x69c00477,0x628d01a3,0xdce80107}},	//   роко, dtme, lbao, _fidč,
   {{0x7d0111cc,0x61140274,0x2d84027d,0x69c07307}},	//   _vols, _удру, _etme_, etme,
   {{0x7d014d01,0x69c06adb,0x2d4901ef,0x7afb00be}},	//   _wols, ftme, túes_, ujut,
   {{0x7afb0006,0xa2dd0243,0x39450443,0xdb1800b8}},	//   rjut, _पसन्, tols_, ctví,
   {{0x2b401851,0x7afb0303,0x26c91857,0xa9250036}},	//   čica_, sjut, _abao_, рдол,
   {{0x69c00122,0x61e4030a,0x7b15002a,0x39454790}},	//   atme, zvil, _cáuc, rols_,
   {{0x39457308,0xf7465da9,0x61e47309,0x69d90345}},	//   sols_, ремо, yvil, _tswe,
   {{0xe7372655,0x69d92a13,0x3945730a,0x69c00147}},	//   рея_, _uswe, pols_, ctme,
   {{0xf990730b,0x2bdc0907,0x2ed20a5e,0x2bda060a}},	//   _ربه_, _मनमा, _सस्त, भिचा,
   {{0xe29a1c76,0xdb0300be,0xb17b03d0,0x00000000}},	//   кав_, punä, _fråk, --,
   {{0x61e4730c,0x628d010d,0x798908c7,0x25a001e0}},	//   tvil, gbao, opew, _tvil_,
   {{0x3126081b,0x61e4000d,0xc69300a5,0x3fe20033}},	// [7700] адаг, uvil, _ואח_, _যথেষ,
   {{0x0ce00083,0xa0a6730d,0x9c7c730e,0x00000000}},	//   _বক্ত, ражд, _kače, --,
   {{0x9c7c00cd,0x00000000,0x00000000,0x00000000}},	//   _jače, --, --, --,
   {{0x539b0052,0x9c7c030a,0xdb18003e,0x00000000}},	//   _ביטו, _mače, ttví, --,
   {{0xd8383f01,0x1ea91902,0x9c7c0116,0x39890183}},	//   mače_, طاني_, _lače, _nºs_,
   {{0xd8380506,0x5ba61403,0xdb18008e,0x00000000}},	//   lače_, ариз, rtví, --,
   {{0x9c7c1851,0xed5703fa,0xdb1800d5,0x00000000}},	//   _nače, јој_, ství, --,
   {{0x2ba70953,0xa3e706bc,0x7bda05d3,0xd83800ac}},	//   _गिरा, पित_, _vstu, nače_,
   {{0xb99700d8,0x3f68045e,0xf2df055c,0x00000000}},	//   авых_, _oğuz_, _chây_, --,
   {{0x69c00122,0xd8380393,0xdde900d1,0x9c7c011c}},	//   rtme, hače_, _حرفه_, _bače,
   {{0x69c0730f,0x7bda7310,0xd838003d,0x8c465a1a}},	//   stme, _ustu, kače_, _теже,
   {{0xd8380528,0xb0c60035,0x69c0033b,0xf53f15ed}},	//   jače_, र्तग, ptme, pråk_,
   {{0xd83800ac,0x661d00b8,0xef110070,0x55077311}},	//   dače_, uzsk, פּט_, ачва,
   {{0x52af00b4,0xf80601e0,0x00000000,0x00000000}},	//   टल्स, _вчин, --, --,
   {{0xb17b3e7e,0x68fc00ab,0x97d70ae7,0x9c7c3f5d}},	//   _tråk, ördu, _نظير_, _gače,
   {{0xd83802c6,0x7cfd0107,0xe7e3018d,0x26c908c7}},	//   gače_, _dèry, गिरा_, _ubao_,
   {{0x9c7c108a,0xcad700a5,0xe80e01c0,0x00000000}},	// [7710] _zače, סומת_, ानका_, --,
   {{0x7778006d,0x2ba70826,0x00000000,0x00000000}},	//   _kuvx, _गिला, --, --,
   {{0xd49800d8,0x2007002d,0x4ac6018d,0x3949002a}},	//   _тры_, âni_, लभाव, _íase_,
   {{0xd8381a8a,0x623500af,0x00000000,0x00000000}},	//   cače_, _гему, --, --,
   {{0xe4ec00be,0x00000000,0x00000000,0x00000000}},	//   _छोडि_, --, --, --,
   {{0x8b950227,0x00000000,0x00000000,0x00000000}},	//   брич, --, --, --,
   {{0xab293c49,0x00000000,0x00000000,0x00000000}},	//   лока_, --, --, --,
   {{0x2bb8162b,0xd43800a5,0xe7ea1579,0x00000000}},	//   _इमरा, יטוי_, टिना_, --,
   {{0xdd914cbc,0xd5ed0023,0x9c7c011c,0x680a013b}},	//   _روا_, _ngà, _sače, hədd,
   {{0xd838029d,0x2903008a,0xa2c90325,0xe8f9020a}},	//   zače_, ðja_, _हॉस्, уло_,
   {{0x66e6005f,0x31710a8a,0x63b500d5,0xb8cf00b4}},	//   бона, _mizz_, juzn, _ओय_,
   {{0x273202c6,0x63b50124,0x317158da,0xfb8400f8}},	//   kšne_, duzn, _lizz_, _بگوی,
   {{0x99850514,0xd8380097,0xf7710118,0xda780133}},	//   _التو, vače_, _کات_, _тях_,
   {{0x63b52e37,0x9c7c082d,0xa879016b,0x00000000}},	//   fuzn, _tače, _גאַר, --,
   {{0xd8380076,0x7bc3245b,0x80ca021a,0x00000000}},	//   tače_, ntnu, स्फे, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd83848cf,0x171b00a5,0x7bc300be,0x21a63cef}},	// [7720] rače_, _תופע, htnu, сизм,
   {{0x6448007c,0xd83802f6,0x7bc31b04,0x63b500d5}},	//   üdis, sače_, ktnu, buzn,
   {{0xe7ea0992,0xd8387312,0x447700a5,0x31717313}},	//   टिया_, pače_, _לעיל_, _dizz_,
   {{0xdfcf004f,0xf48700d1,0xbda60037,0x00000000}},	//   عين_, _پایی, محتو, --,
   {{0x1d0a029f,0x00000000,0x00000000,0x00000000}},	//   леди_, --, --, --,
   {{0xa11603fb,0xdce1004b,0x00000000,0x00000000}},	//   _اوست, _kilę, --, --,
   {{0x28bd021a,0xdee667e9,0x00000000,0x00000000}},	//   ्भनि, _лови, --, --,
   {{0xa0370122,0xef9100d1,0x2b4008b7,0x00000000}},	//   _האלה_, _آیند, čico_, --,
   {{0xdca61461,0x00000000,0x00000000,0x00000000}},	//   _гази, --, --, --,
   {{0xdce90484,0x050a0831,0x00000000,0x00000000}},	//   _tweġ, রফুর_, --, --,
   {{0x80ca01d1,0x6d4a210b,0xd6d51667,0x7bc30051}},	//   स्ये, mofa, ожны, ctnu,
   {{0xab667314,0xa3e70066,0x6d4a1e5a,0xdb0a7315}},	//   _увел, पिस_, lofa, rtfó,
   {{0xceb300a5,0x80d800ab,0x00000000,0x00000000}},	//   היר_, ड़ाइ, --, --,
   {{0x80ca0026,0x973d00f4,0x63b50207,0x00000000}},	//   स्मे, vrću, tuzn, --,
   {{0x7ae2007c,0x93880086,0x24180f99,0x00000000}},	//   _kaot, йста_, боры_, --,
   {{0xe29f008d,0x7ae21b43,0x63b50a18,0xadfa1e82}},	//   _boða_, _jaot, ruzn, ्हान_,
   {{0x7ae2239a,0x9099290a,0x9f530098,0x00000000}},	// [7730] _maot, иват_, ídís_, --,
   {{0x29c2008a,0x672f004e,0x7bc30187,0x7ae22d96}},	//   iða_, licj, ytnu, _laot,
   {{0x660f022a,0x680a00a8,0x06dc0033,0x00000000}},	//   lyck, qədd, ধারি, --,
   {{0x31717316,0x672f0067,0x3f870228,0x00000000}},	//   _wizz_, nicj, īnu_, --,
   {{0xa6e30033,0x00000000,0x00000000,0x00000000}},	//   যাপট, --, --, --,
   {{0x212a02c9,0x9ce700b5,0x6d4a7317,0xb17b0282}},	//   _gmbh_, صوبے_, gofa, _bråv,
   {{0xff5315f4,0x7ae27318,0x61e9023a,0x00000000}},	//   _فخر_, _baot, _šelh, --,
   {{0xc9a90133,0x7bc30044,0xa6db008d,0x3eb91217}},	//   авие_, rtnu, boði, _øst_,
   {{0x7ae202b3,0x88d501c8,0x7bc37319,0xdd94323d}},	//   _daot, оўні, stnu, _наты,
   {{0x660f00b8,0x77c91c20,0x6d4a731a,0xb17b0044}},	//   dyck, алог_, cofa, _fråv,
   {{0x672f731b,0x7ae200f1,0x06e30033,0xb17b037d}},	//   ficj, _faot, যানি, _gråv,
   {{0x7ae204e6,0xfbd00647,0x00000000,0x00000000}},	//   _gaot, _ستم_, --, --,
   {{0x98a52d9c,0x18a567d7,0x629f013b,0x00000000}},	//   _диле, _далм, daqo, --,
   {{0x9c7c731c,0xdd7a02b5,0x98a50029,0xddc90035}},	//   _kača, יטשל, bilā_, _sześ,
   {{0x68e30fc2,0x9c7c0254,0x629f0031,0x212a021d}},	//   _iand, _jača, faqo, _rmbh_,
   {{0x290706a2,0x6abb731d,0x9c7c19be,0x6d4a0054}},	//   _hona_, nguf, _mača, zofa,
   {{0x68e3731e,0x2907731f,0xd8381038,0x6d4a000e}},	// [7740] _kand, _kona_, mača_, yofa,
   {{0x68e37320,0xd8380620,0x29077321,0xe29f0093}},	//   _jand, lača_, _jona_, _voða_,
   {{0x68e37322,0x9c7c00ac,0x60c302e9,0x6d4a5a0c}},	//   _mand, _nača, ònma, vofa,
   {{0x645e7323,0xa3c90930,0x29077324,0x29c2003e}},	//   _izpi, ोबर_, _lona_, yða_,
   {{0x6d4a7325,0x29077326,0x6edb021a,0xa3de00ab}},	//   tofa, _oona_, _नसरु, _दैत_,
   {{0x68e37327,0x29077328,0x7ae2066a,0xd7a901d1}},	//   _nand, _nona_, _saot, _किंच,
   {{0x26c00033,0xd8382676,0x7ae24a6d,0xa4fb016b}},	//   _ocio_, kača_, _paot, ילסט,
   {{0xd8380877,0x68e30903,0x9c7c0009,0x29070284}},	//   jača_, _aand, _dača, _aona_,
   {{0x68e37329,0x2907732a,0x80ca00a1,0x628400de}},	//   _band, _bona_, स्थे, icio,
   {{0x68e3732b,0x29c200fb,0x2918732c,0xdd8f00f8}},	//   _cand, rða_, óra_, _شوم_,
   {{0x2907732d,0x6284732e,0x7ae2007c,0xc07b02b5}},	//   _dona_, kcio, _taot, יטיש,
   {{0x80ca0808,0x660f732f,0xd83805e2,0xda6504cd}},	//   स्ते, tyck, gača_, _کامي,
   {{0x68e37330,0x9c7c0e6a,0xfa360a86,0x645e06a2}},	//   _fand, _zača, _براد, _azpi,
   {{0x32d50028,0x62867331,0x29077332,0x660f013c}},	//   _ấy_, _afko, _gona_, ryck,
   {{0x7d08054e,0x9c830187,0xd83800f4,0xdce80160}},	//   _mods, _účes, bača_, _zidă,
   {{0xd8380129,0x6aa008c7,0x39800260,0x7d084ddb}},	//   cača_, namf, _kòs_, _lods,
   {{0x672d1851,0x68e32c53,0x2907699a,0x60d73bfd}},	// [7750] _imaj, _yand, _yona_, texm,
   {{0x68e37333,0x62847334,0x26d97335,0x98ac010b}},	//   _xand, acio, leso_, rodė_,
   {{0x3cfe22d4,0x9743011c,0x80c11bdd,0x6aa06354}},	//   लाने_, šćuj, र्गे, kamf,
   {{0x62847336,0x7d1a177c,0x26d97337,0x9c7c1ada}},	//   ccio, _alts, neso_, _rača,
   {{0xfe7001ca,0x291e005d,0x23690207,0x7d0815e4}},	//   نده_, khta_, mmaj_, _bods,
   {{0xd8380254,0x9ccb0409,0x80c20066,0x8b953b6e}},	//   zača_, рыда_, _लाये, прич,
   {{0x290770cc,0xeb995f59,0xce9502fb,0x7ed7250f}},	//   _rona_, щий_, _навъ, _وزرا,
   {{0x629d5603,0x68e37338,0x29077339,0x273202c6}},	//   _jeso, _sand, _sona_, kšna_,
   {{0x629d733a,0xd8383ce5,0xb17b15ed,0x39800211}},	//   _meso, vača_, _gråt, _còs_,
   {{0x68e30be2,0x2ba50080,0x7d08674b,0x629d733b}},	//   _qand, pēc_, _gods, _leso,
   {{0xd8381ed1,0x6f1b733c,0x2907733d,0x26d9733e}},	//   tača_, _kluc, _vona_, feso_,
   {{0xe6461283,0x398002e9,0xe73a09f1,0x629d733f}},	//   земп, _fòs_, сем_, _neso,
   {{0xe9ce7340,0x68e37341,0x29077342,0xd8380a78}},	//   _як_, _tand, _tona_, rača_,
   {{0x291e3651,0x81c10083,0x629d0159,0x3cfe0243}},	//   chta_, ংবা_, _aeso, लाये_,
   {{0x629d7343,0xd8380506,0x26d9010d,0x78a1248a}},	//   _beso, pača_, beso_, malv,
   {{0x26d909ab,0x98a50043,0x629d7344,0x672d0a66}},	//   ceso_, bilă_, _ceso, _gmaj,
   {{0x28c20953,0xc2432101,0x00000000,0x00000000}},	// [7760] _शामि, ентк, --, --,
   {{0x672d0528,0x62847345,0x20b900d8,0x6f0900fe}},	//   _zmaj, scio, жыць_, _aoec,
   {{0x62841b73,0x629d01f7,0x6f1b0036,0x7d08008c}},	//   pcio, _feso, _bluc, _rods,
   {{0x44447346,0x629d0173,0x3f877347,0x6f1b0176}},	//   _ix_, _geso, ínua_, _cluc,
   {{0x6f020bf7,0x7d081140,0x5ea30754,0x78a17348}},	//   rjoc, _pods, رمول, kalv,
   {{0x602200b5,0x398001da,0x78a10176,0xac970037}},	//   _címé, _ròs_, jalv, كنها_,
   {{0x7d087200,0xe7b600c8,0x3dc67349,0x629d5efd}},	//   _vods, _জন্য, stow_, _yeso,
   {{0x4444734a,0x61200d6f,0xa03b02b5,0xdee361eb}},	//   _mx_, _bölg, _העלפ, _поси,
   {{0x291e0031,0x00000000,0x00000000,0x00000000}},	//   thta_, --, --, --,
   {{0x672d0078,0x78a14cd6,0x9c7c3e39,0x6aa03fee}},	//   _smaj, galv, _začn, samf,
   {{0x26d9734b,0xdc7500d8,0x394c3b48,0x80c10835}},	//   teso_, _жыць, rods_, र्टे,
   {{0x291e01d2,0x6d582b0e,0x5694051a,0x103700a5}},	//   shta_, llva, нают, לטים_,
   {{0x629d734c,0x78a14f7a,0xe66412b1,0x61200225}},	//   _reso, balv, етро, _gölg,
   {{0x26d9198e,0x629d734d,0x9c7c013a,0x2564008d}},	//   seso_, _seso, _mačo, jöld_,
   {{0x629d734e,0x26d93e05,0xccf800b8,0xd838008b}},	//   _peso, peso_, _mně_, mačo_,
   {{0x4444734f,0x083b0397,0x80ca0084,0xd7bb00a5}},	//   _dx_, _לעול, स्से, _הצהר,
   {{0x25ab03fb,0x9f47004f,0x629d008b,0x6f090051}},	// [7770] _ادبي_, íní_, _veso, _roec,
   {{0x6f1b46ac,0x236902c4,0x629d7350,0x6f0902d7}},	//   _sluc, smaj_, _weso, _soec,
   {{0x25a95c88,0x6f090fe2,0xa3e16540,0x00000000}},	//   _hval_, _poec, _धनि_, --,
   {{0x63b502a7,0x9c7c2381,0x25a90557,0x65777351}},	//   mrzn, _bačo, _kval_, _hixh,
   {{0x6f1b0120,0xfce57352,0xd8380009,0xd244002d}},	//   _vluc, доло, kačo_, _зэри,
   {{0x6577009f,0x00000000,0x00000000,0x00000000}},	//   _jixh, --, --, --,
   {{0x9c7c0bec,0x78a13115,0x61ed7353,0xccf806fe}},	//   _tačn, valv, lval, _dně_,
   {{0x7b15016f,0x2ec8012f,0x68f801ed,0x25a906c6}},	//   _záuj, रभृत, _anvd, _oval_,
   {{0xe29f2ea0,0x61ed2245,0x78a17354,0x6120006c}},	//   _með_, nval, talv, _föld,
   {{0xdb03004f,0x36e60066,0x612000fd,0x00000000}},	//   isné, _जोड़ी_, _völg, --,
   {{0x2ba70026,0xf7467355,0x78a11ca7,0x00000000}},	//   _गिटा, дено, ralv, --,
   {{0x27220019,0x291c0044,0x612000b5,0x09f90037}},	//   _móng_, _elva_, _zöld, _وفاة_,
   {{0x44447356,0x78a10086,0x7ae9021e,0xadf000dc}},	//   _sx_, palv, mdet, चियन_,
   {{0x61ed7357,0x7ae97358,0xf8ce0019,0x69c97359}},	//   dval, ldet, _hứng_, mtee,
   {{0x27220028,0x61ed110e,0x69c90856,0xdb0a2f79}},	//   _nóng_, eval, ltee, rtfö,
   {{0x7ae9735a,0x680a0095,0x7e7b00f8,0x69c9735b}},	//   ndet, qəda, _ngup, otee,
   {{0x69c9735c,0x26d2070b,0x61ed735d,0xb805006c}},	// [7780] ntee, _ibyo_, gval, _رکھے_,
   {{0x27220028,0x3ead01d6,0x2b404693,0xa6db0093}},	//   _bóng_, _adet_, čici_, boðs,
   {{0x69c903ad,0xf8cf022e,0x6add030f,0x28cf0f9f}},	//   htee, त्यय, _मसूर, त्यि,
   {{0x7ae971ee,0x63bc6d70,0x6d412e37,0xa25b0248}},	//   jdet, murn, _ajla, _icôn,
   {{0x7ae9735e,0x63bc2747,0x61ed0124,0x8d6a2123}},	//   ddet, lurn, cval, ојка_,
   {{0x09bc0083,0x0b8a141d,0x28cf021a,0x7ae9212d}},	//   _অনলা, осии_, त्मि, edet,
   {{0x63bc008d,0x6d4100ee,0x69c9735f,0x61200093}},	//   nurn, _djla, etee, _völd,
   {{0xf8ce01a5,0x7ae97360,0x9c7c0097,0x69c90147}},	//   _cứng_, gdet, _začl, ftee,
   {{0x63bc7361,0x69c90345,0x28c20066,0x00000000}},	//   hurn, gtee, _शादि, --,
   {{0x63bc7362,0x7ae97363,0x2bb007b5,0x26d21857}},	//   kurn, adet, ींदा, _abyo_,
   {{0x61ed05d9,0x9c8305d3,0x8c3c01d6,0x69c9001c}},	//   zval, _účas, _beğe, atee,
   {{0x63bc7364,0x00000000,0x00000000,0x00000000}},	//   durn, --, --, --,
   {{0x8c3c0723,0x69c90a75,0x61ed0282,0x6a160c9e}},	//   _değe, ctee, xval, _تبار,
   {{0x61ed7365,0x26d20273,0x291c012f,0x63bc1b5b}},	//   vval, _ebyo_, _ulva_, furn,
   {{0x63bc28c2,0xc60700c8,0x7bca5366,0x5bdc0b54}},	//   gurn, _লেখা_, ntfu, _मनोव,
   {{0xe2f80409,0xf8ce0019,0x62960345,0x00000000}},	//   месі_, _xứng_, gbyo, --,
   {{0x80c800c8,0x62342535,0x272201a5,0xd5677366}},	// [7790] রজন্, вету, _sóng_, _отоп,
   {{0x644501a9,0x7ae9006c,0x3f8708cb,0xb17b0523}},	//   _txhi, zdet, ínuo_, _dråp,
   {{0x61ed7367,0x75357368,0xf650006c,0x69c906a2}},	//   sval, mizz, _مئی_, ztee,
   {{0x75353b01,0xd25000f5,0x26dc02b5,0x69c900c3}},	//   lizz, انے_, ַקומ, ytee,
   {{0xa3e71119,0x1db10026,0x0cbc021a,0x69c90147}},	//   पिक_, ुंधत, ोभूम, xtee,
   {{0x753564a3,0x7bca1cdb,0x00000000,0x00000000}},	//   nizz, ftfu, --, --,
   {{0x4fc40d6e,0x9c7c02a7,0x00000000,0x00000000}},	//   _иста, _kačj, --, --,
   {{0x69c903ad,0x753507e5,0x7e7b007b,0x00000000}},	//   ttee, hizz, _ugup, --,
   {{0x7ae9172c,0x9c7c3b64,0x25ad03ab,0x888300b5}},	//   rdet, _mačj, šelj_, نیشن,
   {{0x61200987,0x7ae97369,0x69c90191,0x6c6a00b5}},	//   _töle, sdet, rtee, _کلمہ_,
   {{0x7535003c,0x69c9318c,0x8cc423e3,0x5ee20033}},	//   dizz, stee, _रातो, ফারে,
   {{0x69c92184,0x612000b5,0xb0cf021a,0x63bc736a}},	//   ptee, _kölc, स्तग, vurn,
   {{0x4a9a02b5,0x6b81736b,0x75350036,0xe6171346}},	//   _זינג, _hulg, fizz, едя_,
   {{0x63bc736c,0x6b8100be,0x80cf0033,0x59d80067}},	//   turn, _kulg, _হোস্, _बैटर,
   {{0x6b815bbe,0x680a0095,0xf8b2011d,0x27e00009}},	//   _julg, nədl, _עשה_, _ćing_,
   {{0x0cdc07df,0xf7d600a5,0x6b8126a4,0x63bc003e}},	//   _यस्म, _נופש_, _mulg, rurn,
   {{0x2bdc0d1f,0x6296736d,0x2aba027d,0x7535736e}},	// [77a0] _मन्थ, rbyo, lübü_, bizz,
   {{0x75350382,0x63bc736f,0x22590035,0xb97a016b}},	//   cizz, purn, _dysk_, פרעז,
   {{0x3cfe02e4,0xdefa081b,0x06e30033,0x1ae60831}},	//   लासे_, зыл_, যারি, কাতে_,
   {{0x28cf164f,0x73e300aa,0x26c27370,0x61fb7371}},	//   त्ति, _союз, ngko_, _šule,
   {{0xed5a03fa,0x127b0070,0xf2d3016b,0xc27b00a5}},	//   под_, _מאכע, _גער_, _מרכי,
   {{0x61e601cc,0x09d80033,0x7bca7372,0x763b016b}},	//   _iskl, তিমা, ttfu, הענג,
   {{0x99bc00c8,0x614369e1,0xdce1009e,0xbebd005f}},	//   _অনেক, _сера, _ghlč, _blūd,
   {{0x28c202e4,0x200d0463,0x6b810139,0xb17b0282}},	//   _शाहि, çmiş_, _dulg, _osål,
   {{0xf98f0609,0xa3e70354,0x00000000,0x00000000}},	//   یبی_, _मैन_, --, --,
   {{0x9c7c15ce,0x6b817373,0x6fc400a1,0x3ea60159}},	//   _mačk, _fulg, ांपू, laot_,
   {{0x7535003c,0x9c7c0009,0x313700a5,0x7b6400af}},	//   vizz, _lačk, תנים_, _иӂие,
   {{0x3cfe5f12,0x09d80083,0x8c1b00a5,0x290301ff}},	//   लावे_, তিবা, _מובי, öjar_,
   {{0x75352e4b,0xfba401c0,0xd6e30033,0x9c7c023a}},	//   tizz, _गौतम, যালয, _račj,
   {{0x2b40044d,0xd90e00b5,0xe4e401e0,0x00000000}},	//   čicu_, _چیک_, лісн, --,
   {{0x75357374,0x6b8101dd,0xf36728a1,0x395700a5}},	//   rizz, _xulg, етан, _רשום_,
   {{0x9c7c7375,0x75357376,0x7982023c,0x00000000}},	//   _bačk, sizz, _kuow, --,
   {{0x75357377,0x3ea602b3,0x680a00a8,0x1be2073f}},	// [77b0] pizz, daot_, zədl, _कैसल_,
   {{0x98be00b8,0x68ea009f,0x6aa247ee,0x9c7c005f}},	//   votě_, _jafd, _leof, _dačk,
   {{0x7b1c0248,0x61e67378,0x43950665,0xc4350919}},	//   _réun, _eskl, _шанс, _شکست,
   {{0xdb010076,0x22591b99,0x9c7c00ee,0x290e7379}},	//   _ovlá, _tysk_, _fačk, _lofa_,
   {{0x64630a78,0x6b8100ab,0x00000000,0x00000000}},	//   štić, _sulg, --, --,
   {{0x6b81737a,0x271e08b6,0x7c8700c3,0x68ea0024}},	//   _pulg, _पत्र_, худе, _nafd,
   {{0xfaf10037,0xbebd4886,0x3ea6448b,0xa3e7046c}},	//   لثة_, _plūd, baot_, _मैम_,
   {{0x6b8162e5,0xb4cd13ab,0xe29f0093,0x3f830176}},	//   _vulg, रभु_, _boði_, _iuju_,
   {{0xe9690346,0x28b9002d,0x00000000,0x00000000}},	//   маил_, мунэ_, --, --,
   {{0x798200e0,0x3f8300be,0x6b81018d,0x61200282}},	//   _duow, _kuju_, _tulg, _köla,
   {{0x978300bf,0x8c1929e3,0x28c2022e,0x2ca70191}},	//   دیبه, _تيار_, _शारि, mand_,
   {{0x3f83022f,0x5a352bed,0x00000000,0x00000000}},	//   _muju_, _инет, --, --,
   {{0x3f830009,0x290e0183,0x7aeb0b3e,0x00000000}},	//   _luju_, _fofa_, _iagt, --,
   {{0x2ca7737b,0x7aeb13f6,0x9c7c737c,0x69d9313e}},	//   nand_, _hagt, _račk, _ipwe,
   {{0x64a364a1,0xdb01033a,0x3f8300f8,0x6ed20fbf}},	//   раса, _zvlá, _nuju_, ण्डु,
   {{0x78a3177c,0x2b04045c,0x7aeb737d,0x6aa201ef}},	//   _henv, वायु_, _jagt, _xeof,
   {{0x7aeb737e,0x21a6737f,0x02e20084,0x78a37380}},	// [77c0] _magt, тизм, _पसीन, _kenv,
   {{0x2ca77381,0x7aeb7382,0x3123010b,0x3f830124}},	//   jand_, _lagt, адуг, _buju_,
   {{0xb4667383,0x2ca737ed,0x3f830124,0x00000000}},	//   _школ, dand_, _cuju_, --,
   {{0x9c7c1367,0x7aeb6854,0xee3a5fed,0x69d90b0d}},	//   _tačk, _nagt, мне_, _opwe,
   {{0x61e602f6,0x543609b9,0x3ea6010d,0x28c20e61}},	//   _uskl, _سرگر, raot_, _शालि,
   {{0x9c7c7384,0x61e4002f,0x61467385,0x78a30055}},	//   _kači, mwil, _рега, _nenv,
   {{0x8fa37386,0x7aeb7387,0x25a002d0,0x9c7c0254}},	//   _васе, _bagt, _lwil_, _jači,
   {{0xdd921b15,0x9c7c2a17,0x28cf0bad,0x9f4a0310}},	//   _نور_, _mači, त्सि, _urbà_,
   {{0x78a37388,0xd83802dd,0x99661400,0x7aeb38b9}},	//   _benv, mači_, ктол, _dagt,
   {{0xd1050e96,0x2ca7002d,0x310504aa,0x61e4033b}},	//   रायण_, cand_, रायः_, iwil,
   {{0x61e47389,0xdd3100a8,0x7aeb0a8c,0x78a3252d}},	//   hwil, ləşm, _fagt, _denv,
   {{0x9c7c0888,0xb8f90325,0x78a30a45,0xd83804c3}},	//   _nači, _डॉ_, _eenv, nači_,
   {{0x61e40120,0xfb1b00a5,0x58d4738a,0x7ae0738b}},	//   jwil, _קודמ, _болт, memt,
   {{0x78a30ab8,0x2d840054,0x69c001d5,0xd8380207}},	//   _genv, _mume_, mume, hači_,
   {{0x2d84738c,0x78a800fe,0xd83803c9,0x9c7c00f4}},	//   _lume_, madv, kači_, _bači,
   {{0xd83815d7,0x3ea401b4,0x2ca7738d,0x78a800b5}},	//   jači_, _nemt_, zand_, ladv,
   {{0x60f9325e,0x26c901a2,0x2d840043,0x9c7c738e}},	// [77d0] нная_, _icao_, _nume_, _dači,
   {{0x7bda0a78,0x31c404bf,0xdce801c0,0x78a80223}},	//   _optu, јств, _vidě, nadv,
   {{0x2ca7738f,0x69c07390,0x00000000,0x00000000}},	//   vand_, hume, --, --,
   {{0x3cfe0600,0x63ba01ba,0x2ca77391,0xd83801a0}},	//   _antv_, átne, wand_, gači_,
   {{0x7bda0029,0x2d840a54,0x7aeb03d0,0x69c07392}},	//   _aptu, _cume_, _ragt, jume,
   {{0x7aeb7393,0x8c4559d4,0x9c7c7394,0x2d847395}},	//   _sagt, леле, _zači, _dume_,
   {{0x31340086,0x7aeb7396,0x78a30248,0x2d84002a}},	//   _терр, _pagt, _renv, _eume_,
   {{0x2d843113,0x7b157397,0x69c0539a,0xb9280023}},	//   _fume_, _náut, fume, _thuở_,
   {{0x69c0707d,0x2ca77398,0x2d840620,0xa3c505e7}},	//   gume, pand_, _gume_, उंड_,
   {{0x7aeb000b,0x80e10083,0x3cfe022e,0x26c9021d}},	//   _wagt, নাক্, _gntv_, _acao_,
   {{0xd05c01c2,0xc1d02160,0x7aeb7399,0x628f739a}},	//   _barə, _सङ्ग, _tagt, _ofco,
   {{0xc9f50642,0x69c039b5,0x2d840019,0x2ca500a5}},	//   _مستع, bume, _yume_, _held_,
   {{0x6d43739b,0x9c7c02b2,0x69d908c7,0x2d8401b7}},	//   onna, _rači, _upwe, _xume_,
   {{0x9c7c1269,0x5e5602b5,0x272212c3,0xd838011c}},	//   _sači, רישע_, _dóna_, zači_,
   {{0x2ca50130,0x68e14b90,0x39892cd2,0x9c7c00d8}},	//   _meld_, meld, _hús_, _pači,
   {{0x28cf2afe,0xf8cf022e,0x3d1900bf,0x2732008b}},	//   त्रि, त्रय, _dèwi_, kšni_,
   {{0x626600c9,0xb1461517,0xd83800cd,0x672458a4}},	// [77e0] уваа, гнал, vači_, _ilij,
   {{0x80a606ca,0x61e4000b,0x2d84739c,0xdcfb011c}},	//   امان, rwil, _rume_, _otuđ,
   {{0x6724739d,0x9c7c01c8,0x69c0739e,0x2d84739f}},	//   _klij, _tači, zume, _sume_,
   {{0x68e173a0,0x6d4373a1,0x91863181,0x69c02468}},	//   held, enna, _مجسم, yume,
   {{0xdd8f0082,0x67240c21,0xd8380a78,0x68e173a2}},	//   كون_, _mlij, rači_, keld,
   {{0x69c00273,0x9c7c01f2,0xd83805e2,0x68e173a3}},	//   vume, _mačv, sači_, jeld,
   {{0xa0670370,0x7ae073a4,0x672473a5,0x68e173a6}},	//   _бара_, temt, _olij, deld,
   {{0x6d430e0f,0x69c073a7,0x2d84000e,0x5b1473a8}},	//   anna, tume, _tume_, рмит,
   {{0x2ca52179,0x7ae073a9,0xdb0a73aa,0x680a00a8}},	//   _feld_, remt, nsfé, mədi,
   {{0x2ca51892,0x672473ab,0x68e173ac,0x680a0095}},	//   _geld_, _alij, geld, lədi,
   {{0x672473ad,0x6ac60164,0x6d5a0484,0x31050066}},	//   _blij, _مقام, _ikta, रातः_,
   {{0x9c7c00cb,0x2360006d,0x680a00a8,0x657e5c6b}},	//   _bačv, jlij_, nədi, _aiph,
   {{0x67240207,0x395e0223,0x00000000,0x00000000}},	//   _dlij, plts_, --, --,
   {{0x672473ae,0x657e73af,0x7e7d016f,0xd9431bd2}},	//   _elij, _ciph, _úspe, _лечи,
   {{0x657e73b0,0x56951622,0x67240031,0xf77001cb}},	//   _diph, _кайт, _flij, تای_,
   {{0x290c0470,0x57fb0122,0x2bc6022e,0x672401e4}},	//   ljda_, _טלוו, रूया, _glij,
   {{0x6d5a73b1,0x6d4300e9,0x680a00a8,0x6d4800f4}},	// [77f0] _okta, ynna, dədi, _ojda,
   {{0x657e2a07,0x60c5006d,0xb2746660,0x67240a66}},	//   _giph, ughm, слуш, _zlij,
   {{0x72d573b2,0xa2d04532,0x2ca50298,0x9c7c00fe}},	//   _конф, _डॉक्, _reld_, _kaču,
   {{0x6d5a048c,0x539a0052,0x612073b3,0x7b1501ef}},	//   _akta, _שירו, _höll, _láur,
   {{0xdbde064b,0x612073b4,0xd83800f4,0x776d009e}},	//   _síða, _köll, maču_, _mhax,
   {{0x5bb5384b,0xd8380124,0x8b050035,0x6d4302ee}},	//   асиф, laču_, _mięś, unna,
   {{0x68e173b5,0x2ca5152b,0x612073b6,0x398901ef}},	//   veld, _veld_, _möll, _sús_,
   {{0x7c2b0f44,0xe9d90b3a,0x2ca50297,0x68e173b7}},	//   _đorđ, вки_, _weld_, weld,
   {{0x13de00c8,0xaa452dde,0x6aa9008e,0x32090510}},	//   ডিয়, репл, raef, nxay_,
   {{0xe8f60fa4,0x672473b8,0xdbde008d,0x7d790a86}},	//   аль_, _slij, _tíða, _شمار_,
   {{0x6c840082,0x68e173b9,0xd7060ca6,0x6724003a}},	//   _المم, reld, азни, _plij,
   {{0x7bc331e3,0x3989004f,0xe73a0376,0xd8380ce9}},	//   munu, _tús_, тем_, jaču_,
   {{0x7b742588,0x7bc36d6c,0xa9a50009,0x68e173ba}},	//   _اطلا, lunu, _тилд, peld,
   {{0x4a440131,0xdb0a033b,0x291e73bb,0xc8c804a3}},	//   _унів, zufü, ckta_, _موهن_,
   {{0xa956011d,0x03a60aec,0xede2608c,0x00000000}},	//   _דיסק_, рибо, _गन्ध_, --,
   {{0xf77200f5,0x95860e0a,0xc3230798,0x672473bc}},	//   _بات_, _клие, омск, _ulij,

   {{0x7bc373bd,0x657e6a8d,0x09b502b5,0x645e0035}},	// [7800] hunu, _tiph, יפּט_, _wypi,
   {{0x9c7c4693,0x201a01f4,0x645e293a,0x612073be}},	//   _začu, typi_, _typi, _göll,
   {{0x4ea60210,0x7bc373bf,0x680a0095,0xd83873c0}},	//   арла, junu, tədi, baču_,
   {{0xe8060fbf,0x7bc373c1,0xa6e20093,0x776d0031}},	//   षमता_, dunu, áðhe, _xhax,
   {{0xcd0602f3,0x680a00a8,0x4c940a5c,0x61200421}},	//   ички, rədi, билс, _yöll,
   {{0x21a31d6b,0x7e690506,0x7bc3174a,0xd5f70070}},	//   _фирм, _dzep, funu, יזנט_,
   {{0x7bc373c2,0x237f024e,0x50431682,0xdee65b1d}},	//   gunu, ňuje_, _дерб, _кови,
   {{0x3f9a00c3,0x00000000,0x00000000,0x00000000}},	//   mppu_, --, --, --,
   {{0x9c7c139d,0xacea03e6,0x00000000,0x00000000}},	//   _raču, _имаа_, --, --,
   {{0x776d1505,0x9c7c0a78,0xd83800cd,0x00000000}},	//   _shax, _saču, začu_, --,
   {{0x80d8022e,0x28b70026,0x291e73c3,0x4c3600d8}},	//   न्ये, _आयरि, rkta_, _тэат,
   {{0xdc3b00a5,0x3cfe00be,0x00000000,0x00000000}},	//   _בעבר, लाके_, --, --,
   {{0xb9940037,0x9f65006c,0xd838011c,0xe66709a5}},	//   _التب, ítés_, vaču_, ртно,
   {{0x80c2366c,0x61200095,0x7c2b0644,0x80d80ea3}},	//   _लागे, _bölm, _ömrü, न्मे,
   {{0x92a709ea,0x80aa0fd1,0x938813f9,0x612023b3}},	//   ијал, टरने, иста_, _völl,
   {{0x6d580076,0x6b8801a2,0x987b0319,0xa87b0d85}},	//   hova, _mudg, _ברוק, _באור,
   {{0x6d58531e,0x673d1163,0x26db006d,0xd838011c}},	// [7810] kova, misj, _ibqo_, raču_,
   {{0x6d58053d,0x2b49011c,0x32090be2,0x7bc300c1}},	//   jova, čaci_, rxay_, yunu,
   {{0x7e6973c4,0x7bc300a8,0x057411cf,0x00000000}},	//   _szep, xunu, _بايد, --,
   {{0x926b004b,0x0eb8005f,0xef19035f,0x673d73c5}},	//   _арга_, аушы_, _biża_, nisj,
   {{0x6d5873c6,0x7f490055,0x00000000,0x00000000}},	//   fova, _vjeq, --, --,
   {{0x7bc35837,0xfce5326d,0x06e30033,0x1dc800ab}},	//   tunu, соко, যাটি, _रमरत,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc35199,0x0ae9291e,0xd1050d53,0x673d01f4}},	//   runu, удий_, रावण_, jisj,
   {{0x6d580e6a,0x7bc373c7,0x3d940cb5,0x661d01b4}},	//   bova, sunu, _митр, jysk,
   {{0x6d581840,0x7bc373c8,0x661d73c9,0x00000000}},	//   cova, punu, dysk, --,
   {{0xbb85004f,0xa3e7020d,0x6b8800d7,0x753c00ea}},	//   _الصي, _मैल_, _gudg, virz,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb1202b8,0xe7371482,0x987800ea,0x612001ff}},	//   _מלא_, сея_, kšķi_, _dölj,
   {{0xa5c70093,0xf99200a5,0xf1ca00d5,0x00000000}},	//   _stóð, _צרו_, ndáž_, --,
   {{0x612006d7,0x232a692a,0xc79500f8,0x673d0044}},	//   _följ, гови_, _اشتب, bisj,
   {{0x6d582047,0xe7ec361f,0x661d198d,0xa6db05ee}},	//   zova, _जनता_, bysk, viðg,
   {{0xe1fa004b,0x95c903e6,0xe0da2701,0x6d5873ca}},	// [7820] ыга_, _куќа_, лва_, yova,
   {{0x6d5873cb,0xd00a0265,0x7e600b88,0x00000000}},	//   xova, лезе_, _rymp, --,
   {{0x6d5873cc,0xa2e60011,0x7e601691,0x63a900f4}},	//   vova, _лонд, _symp, ćenc,
   {{0x6b88021d,0xdcfa0260,0x00000000,0x00000000}},	//   _rudg, _vitč, --, --,
   {{0x9c7c02c6,0xee3a0043,0xaabd00b8,0xb17b008c}},	//   _načr, ынд_, ोलनक, _spåe,
   {{0x7e60028b,0x40ab0919,0x00000000,0x00000000}},	//   _vymp, _مخفی_, --, --,
   {{0x661d004e,0x988800b5,0x55770070,0x2bb70037}},	//   zysk, یحدہ_, זעסן_, ماية_,
   {{0x6d58656e,0x7e60081b,0x6286008c,0x00000000}},	//   sova, _tymp, _jgko, --,
   {{0x6d58308b,0x799b011e,0x5e4a2fa5,0x3f8a73cd}},	//   pova, gpuw, _спам_, _hubu_,
   {{0x3f8a06b3,0x8c460fa7,0x00000000,0x00000000}},	//   _kubu_, _лезе, --, --,
   {{0xa3e70755,0x415b0070,0x673d73ce,0x8ccd00b4}},	//   _मैं_, רדיג, tisj, _सातो,
   {{0x2bdd0d43,0x95cb0ea0,0x3f8a02b3,0x661d00c3}},	//   _महता, луга_, _mubu_, tysk,
   {{0x673d73cf,0xdb0a002a,0x00000000,0x00000000}},	//   risj, nsfí, --, --,
   {{0x92c50083,0x661d43e8,0x3f9800ea,0x66020124}},	//   _এসে_, rysk, _otru_, _šokc,
   {{0xa3e40066,0x9c7c0a66,0x661d0282,0x3f980160}},	//   पौल_, _začr, sysk, _ntru_,
   {{0x69c073d0,0x1fce0033,0x6b82002f,0x00000000}},	//   orme, রবাস, _jiog, --,
   {{0x6b820009,0x60870037,0x6fcb007c,0xb11500b6}},	// [7830] _miog, مشاك, _हमहू, омаш,
   {{0x69c004e6,0x3f8a73d1,0xdb186f5e,0x00000000}},	//   irme, _bubu_, luvä, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x01c90332,0x3f8a73d2,0x9df93e1f,0x26cb0337}},	//   _پوسٹ_, _dubu_, инет_, ngco_,
   {{0x3f98023a,0xf1ab0037,0x23a5021a,0x00000000}},	//   _etru_, _حاجه_, गीरद, --,
   {{0xa19473d3,0x61ef0176,0xe3b002fd,0x3f8a0176}},	//   _харч, _iscl, _تری_, _fubu_,
   {{0x251c00c2,0xeb990263,0x69c00298,0xcfa400af}},	//   רווא, ший_, erme, _ншти,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8273d4,0x27fc00d7,0x61fb0506,0x00000000}},	//   _diog, _arvn_, _šulj, --,
   {{0x3eaf03db,0x92c50033,0x78a90274,0x3f8a0371}},	//   lagt_, _এসো_, шког_, _yubu_,
   {{0x18690b46,0xfbdd0775,0xd70a01c8,0x00000000}},	//   рани_, _महिम, анне_, --,
   {{0x81e00083,0x6b8273d5,0x61ef104b,0x78b80207}},	//   থিত_, _giog, _oscl, _edvv,
   {{0xe9ce03d0,0xa3be0026,0x44310051,0x00000000}},	//   _юк_, ुंभ_, ezz_, --,
   {{0xfbdd05f7,0x2bc60967,0x6120033b,0xdb010185}},	//   _महाम, रूवा, _völk, _avlø,
   {{0xa87902b5,0x48ee02cb,0x69120009,0x61fd73d6}},	//   _דאַר, _असतो_, _džeđ, _arsl,
   {{0xe29a0370,0x798302c9,0x3f8a0b7f,0xa3bb0066}},	//   раа_, _hinw, _rubu_, _घिर_,
   {{0x6aab0332,0x79832379,0xea760070,0x44312c67}},	// [7840] _megf, _kinw, ַגער_, azz_,
   {{0x6aab006c,0x798b1815,0x3f8a41d8,0x00000000}},	//   _legf, _mugw, _pubu_, --,
   {{0x4fea0ec9,0x61ef07e5,0x798373d7,0xdd990107}},	//   рмен_, _escl, _minw, _atň_,
   {{0x9e660b00,0x57cc0070,0x00000000,0x00000000}},	//   овед, רמאַ, --, --,
   {{0x6b8200f1,0x2ee6024b,0x3f87003e,0xdcfa00ec}},	//   _riog, reof_, ínur_, _aitā,
   {{0x412a3634,0x3f8a73d8,0xd657011d,0x6b8273d9}},	//   _того_, _tubu_, חינת_, _siog,
   {{0xdcfa0029,0x6b820382,0xdfd20d4f,0xbb2a002d}},	//   _citā, _piog, _تيز_, ицие_,
   {{0x798b001c,0x81bd0033,0x00000000,0x00000000}},	//   _bugw, _আহত_, --, --,
   {{0xa3be1604,0xc8780225,0x6ab900e5,0x6aab0090}},	//   ुंड_, meği_, _ddwf, _degf,
   {{0xdce80029,0xdddb011c,0x00000000,0x00000000}},	//   _vidē, _uguš, --, --,
   {{0xf0930122,0x6b820341,0xab2a1578,0x3f8401a8}},	//   ונת_, _tiog, _кожа_, _kimu_,
   {{0x798301ae,0x66021710,0xc878027d,0x569410be}},	//   _einw, _šoka, neği_, мают,
   {{0xceb30122,0x6d4a58d3,0x2cac00b5,0x798300ac}},	//   ויר_, onfa, _kedd_, _finw,
   {{0x7983010d,0x3f84018e,0x6d4a73da,0x2cac009f}},	//   _ginw, _limu_, nnfa, _jedd_,
   {{0x68e873db,0x442573dc,0x389b00a5,0x6d4a73dd}},	//   medd, ál_, _דיונ, infa,
   {{0x68e873de,0x61fd61d3,0x249e0225,0x80d805f7}},	//   ledd, _prsl, ıtma_, न्से,
   {{0x94870043,0x8c3c08a1,0x2cac02c7,0xd0111328}},	// [7850] _мынд, _deği, _oedd_, کلا_,
   {{0x68e84499,0x25a902d7,0xecc900dc,0x2cac00e9}},	//   nedd, _iwal_, _राइफ, _nedd_,
   {{0x3eaf033b,0x3f84001c,0x00000000,0x00000000}},	//   tagt_, _bimu_, --, --,
   {{0x68e8001e,0x25a90051,0x5ede0831,0x00000000}},	//   hedd, _kwal_, _নোবে, --,
   {{0x7de70082,0xc33202b5,0x6da502d5,0x3eaf5cc3}},	//   تسام, _טוט_, чила, ragt_,
   {{0x3eaf7173,0x61ed0c2f,0xdd8e2fad,0x6b9a0103}},	//   sagt_, mwal, دوو_, _bttg,
   {{0x61ed018e,0x68e81904,0x2bc601c0,0x00000000}},	//   lwal, dedd, रूला, --,
   {{0x7e7d024e,0xc87801d6,0x3ce70183,0x3f84073a}},	//   _úspo, ceği_, senv_, _gimu_,
   {{0x61ed73df,0x7b1c00f7,0x68e800e9,0x6aab73e0}},	//   nwal, _réut, fedd, _vegf,
   {{0x68e801a8,0x3ead28e9,0x6ca700af,0x6aab02b1}},	//   gedd, _heet_, _фраж, _wegf,
   {{0x25a949c2,0xf8ae01cb,0x09e10083,0x3f8500f7}},	//   _awal_, اکه_, বিধা, _élus_,
   {{0x61ed73e1,0xe55600b5,0xd5b80029,0xf772096a}},	//   kwal, _اﷲ_, ņām_, عاد_,
   {{0x68e873e2,0x2d8573e3,0x7ae9007c,0x3ead73e4}},	//   bedd, _kile_, meet, _meet_,
   {{0x61ed73e5,0x7ae973e6,0x25a9035f,0x2d8573e7}},	//   dwal, leet, _dwal_, _jile_,
   {{0x69c973e8,0x290773e9,0x2d8573ea,0xd46a00af}},	//   luee, _inna_, _mile_, сиве_,
   {{0x2d8536e0,0x2b910023,0x3ead0088,0x9695002d}},	//   _lile_, _mác_, _neet_, _орьш,
   {{0x26d2070b,0x61ed73eb,0x7bc30314,0x3f840bc6}},	// [7860] _icyo_, gwal, hrnu, _rimu_,
   {{0x3f84000e,0x7ae973ec,0x2d850147,0x00000000}},	//   _simu_, heet, _nile_, --,
   {{0x7ae973ed,0x2cac73ee,0xdcfa0160,0xc8780225}},	//   keet, _redd_, _lită, teği_,
   {{0x2d8501d6,0x68e873ef,0x3ead02d7,0x2cac73f0}},	//   _aile_, zedd, _ceet_, _sedd_,
   {{0x2d8573f1,0x3ead01a2,0x7ae901d7,0x68e8018e}},	//   _bile_, _deet_, deet, yedd,
   {{0x2b910028,0x6296046a,0x2d853a83,0x6d4a0995}},	//   _bác_, lcyo, _cile_, unfa,
   {{0x2b91098b,0x1fb5195a,0x3f840657,0x6d4a73f2}},	//   _các_, _остр, _timu_, rnfa,
   {{0x2d851e6a,0x290773f3,0x68e873f4,0xb99802ce}},	//   _eile_, _anna_, wedd, ових_,
   {{0x2d8573f5,0x68e873f6,0xdcfa0160,0x2cac00fd}},	//   _file_, tedd, _cită, _tedd_,
   {{0x7f4200e7,0x2918008a,0xfe450df3,0x26d20027}},	//   lioq, ðra_, _تکمی, _acyo_,
   {{0x7d080022,0xbc6a03c7,0x61ed004e,0x7ae973f7}},	//   _inds, _امان_, zwal, beet,
   {{0x2d8573f8,0x68e873f9,0x25a902d0,0x290707e5}},	//   _zile_, sedd, _pwal_, _enna_,
   {{0x7d1a27f9,0x68e80103,0x58d40279,0x6e2204fb}},	//   _kots, pedd, _жолт, nyob,
   {{0x58d30370,0x2d850392,0xda7b024b,0x25a9021e}},	//   _зошт, _xile_, _הנדר, _vwal_,
   {{0x2b910028,0x63a90254,0x7d1a370d,0xf8db0122}},	//   _xác_, ćeno, _mots, _החומ,
   {{0x61ed73fa,0x7d1a73fb,0xe1ff0279,0x25a931d4}},	//   twal, _lots, _pró_, _twal_,
   {{0x8ccd0461,0x7d08362b,0x3ead20c8,0x25a901cb}},	// [7870] _सालो, _onds, _reet_, _uwal_,
   {{0x3ead008c,0x7bca6020,0x61ed73fc,0x395e0029}},	//   _seet_, kufu, rwal, nots_,
   {{0x61ed73fd,0x672d73fe,0x63a20009,0x9f0404cd}},	//   swal, _klaj, _čong, کونو,
   {{0x7d0873ff,0x2b9101a5,0x7bc3044d,0x2d85030a}},	//   _ands, _rác_, vrnu, _sile_,
   {{0x2a660d4b,0x7d1a7400,0x6e22006c,0x2d857401}},	//   _nyob_, _bots, gyob, _pile_,
   {{0x3ead019c,0x7bca7402,0x7ae97403,0x2b910023}},	//   _weet_, fufu, weet, _pác_,
   {{0xdd9100f5,0x2d850657,0x7ae97404,0x2a6600d7}},	//   روں_, _vile_, teet, _ayob_,
   {{0x394c0122,0x69c97405,0x7d087406,0x9f057407}},	//   ends_, tuee, _ends, _تورو,
   {{0x1dd10d91,0x7d1a3789,0xedd5211b,0x6f097408}},	//   _समित, _fots, _زياد, _inec,
   {{0x2b9100e8,0x2d851093,0x7d1a7409,0x660204ff}},	//   _tác_, _uile_, _gots, _šoko,
   {{0x612000fb,0x6f1b02e9,0x672d0691,0x7ae9740a}},	//   _tölv, _kouc, _blaj, peet,
   {{0x6d43740b,0x98ad0dac,0x236901e8,0xb0dd06fe}},	//   lina, ının_, jlaj_, न्तग,
   {{0x6f1b740c,0x6120006c,0x7d1a2379,0x2b5f00b8}},	//   _mouc, _költ, _yots, mouc_,
   {{0x68451346,0x6f1b740d,0x28d41db1,0x395e1db3}},	//   _онла, _louc, _दायि, cots_,
   {{0x3cf0004e,0x672d02c4,0x00000000,0x00000000}},	//   _इससे_, _flaj, --, --,
   {{0x6d43149b,0x672d0024,0x2b4d00a2,0xa6db008d}},	//   hina, _glaj, nnec_, liðn,
   {{0x2a66006d,0x27e00207,0x00000000,0x00000000}},	// [7880] _xyob_, _ćini_, --, --,
   {{0x69c602c6,0x672d0124,0x6e22002f,0x2564008d}},	//   škeg, _zlaj, vyob, tölu_,
   {{0x6f1b62e8,0x2369740e,0x7f4205c9,0x7d1a740f}},	//   _bouc, blaj_, tioq, _rots,
   {{0x7d1a007c,0x3f9c00ea,0x6d43010b,0x6f1b1691}},	//   _sots, īvu_, eina, _couc,
   {{0x7d1a7410,0xdd8f07f6,0x9f65006c,0x6f0900b8}},	//   _pots, لون_, ítás_, _dnec,
   {{0xb0dd1a75,0x7bca7411,0x6f090223,0xa2c607df}},	//   न्दग, tufu, _enec, िलक्,
   {{0xfbcf0ad9,0x6f1b7412,0x7d1a0009,0x395e0228}},	//   لتي_, _fouc, _vots, vots_,
   {{0x7bca7413,0x1b770037,0x61320a8a,0x320200ee}},	//   rufu, وصية_, _bælg, _krky_,
   {{0x6d437414,0x7bd87415,0x3ea67416,0x7d1a7417}},	//   bina, stvu, mbot_, _tots,
   {{0x3ea67418,0x6120008a,0x7d08035b,0x394c00a5}},	//   lbot_, _tölu, _unds, unds_,
   {{0xcb6a20b6,0x672d7419,0x395e00ea,0x6f1b60f5}},	//   _даже_, _plaj, rots_, _youc,
   {{0x61e6741a,0x8cda0569,0x3ea60053,0x613208c8}},	//   _opkl, प्रो, nbot_, _fælg,
   {{0x672d15d8,0x7ae2741b,0x3ea60159,0xaac50037}},	//   _vlaj, _ibot, ibot_, _أتمن,
   {{0xb3470370,0x249a008c,0x61200282,0x00000000}},	//   _opçõ, _cfpm_, _möls, --,
   {{0x61e600d8,0x3ea608dd,0xceb906fe,0x00000000}},	//   _apkl, kbot_, _hoře_, --,
   {{0x68f80022,0x6d43741c,0x3dc60159,0x672d002f}},	//   _havd, zina, krow_, _ulaj,
   {{0x291c741d,0xe4a7052a,0x7ae200bf,0x3495741e}},	// [7890] _kova_, _орно, _mbot, _папр,
   {{0x6d431a71,0xeb1b02cb,0x6f1b741f,0x291c02c4}},	//   xina, _फक्त_, _souc, _jova_,
   {{0x6d4318b0,0xa3d619b7,0x6f1b130f,0xa3e7004e}},	//   vina, _समय_, _pouc, _मैच_,
   {{0x6d430099,0x291c0da3,0x68f801f4,0x3ea648a5}},	//   wina, _lova_, _lavd, gbot_,
   {{0x6d437420,0xfce57421,0x25b909b3,0x6f090023}},	//   tina, еоло, nssl_, _vnec,
   {{0x0d8402ce,0x68f8008b,0x3ea618ad,0x691f03bc}},	//   влін, _navd, abot_, _lêer,
   {{0x6132054e,0x3ea67422,0x6f1b504d,0x506402ee}},	//   _sælg, bbot_, _touc, _атта,
   {{0x3dc67423,0x6f090027,0x160f021a,0x00000000}},	//   brow_, _unec, ामार_, --,
   {{0x6d437424,0x27340028,0x6120006c,0x291c7425}},	//   pina, _hãng_, _tölt, _bova_,
   {{0x63a90a78,0x6132054e,0x291c7426,0x7ae20118}},	//   ćenj, _vælg, _cova_, _ebot,
   {{0x6d417427,0x31580070,0x3f91314a,0xa2a00067}},	//   _imla, ויזן_, _juzu_, गुड्,
   {{0x06b00083,0xe7321062,0xdb0a0ef0,0x00000000}},	//   _কাহি, اصد_, gsfä, --,
   {{0xa6db008a,0x27340019,0x68f8023a,0x61320b3e}},	//   miðl, _lãng_, _favd, _hæle,
   {{0x7afb01d7,0x68f801ef,0x69db0055,0x613208c8}},	//   ldut, _gavd, mtue, _kæle,
   {{0x39450176,0x187502b5,0x69db7428,0x186600af}},	//   mils_, _אײַך_, ltue, _паши_,
   {{0x7afb7429,0x23b10e1d,0xfe6504cd,0x14170037}},	//   ndut, _जबरद, _نگ_, ريقة_,
   {{0x6462004e,0x6d41742a,0x7e696801,0x3ea602d0}},	// [78a0] _świę, _omla, _nyep, vbot_,
   {{0x20560603,0x39450392,0x25a002d0,0x7afb00c3}},	//   нтер, nils_, _itil_, hdut,
   {{0x9c7c0e6a,0x20560208,0xe29a742b,0x26180009}},	//   _obča, хтар, _нан_, _džoš_,
   {{0x6604742c,0x3f910291,0x200c0484,0x272201dd}},	//   _krik, _duzu_, _ġdid_, _ións_,
   {{0x3ea6742d,0x69db00da,0x0cd409c0,0xa2a0012f}},	//   rbot_, jtue, волю, गुण्,
   {{0x3dc600a5,0x660400d1,0xa2d8021a,0x7afb1945}},	//   rrow_, _mrik, मभक्, edut,
   {{0x3f91029d,0x26c04239,0x3ea6009e,0xd47a0070}},	//   _guzu_, _odio_, pbot_, האַל,
   {{0x26c00657,0x68f8573a,0x6d4101d6,0x291c742e}},	//   _ndio_, _savd, _emla, _sova_,
   {{0x3945742f,0x68f80055,0xe946052a,0x28d4018d}},	//   fils_, _pavd, ехно, _दादि,
   {{0x26c07430,0xadb70037,0x8e75027a,0x00000000}},	//   _adio_, _أهلا_, _русч, --,
   {{0x66047431,0x313700a5,0x25a07432,0xe75901e0}},	//   _arik, גנים_, _atil_, дині_,
   {{0xd6db00c3,0x7ae20207,0x00000000,0x00000000}},	//   что_, _ubot, --, --,
   {{0x69db7433,0x39457434,0xa3d302cb,0x6d410297}},	//   ctue, bils_, हून_, _ymla,
   {{0x66040c71,0x291c0382,0x39457435,0xd7f00037}},	//   _drik, _uova_, cils_, _نكت_,
   {{0x66047436,0xd82f1a24,0x06b00033,0x96a200b4}},	//   _erik, _сэ_, _কারি, _क्वॉ,
   {{0x66047437,0x2b090035,0x3f910124,0x52cb01c0}},	//   _frik, वाएँ_, _ruzu_, िलेस,
   {{0x3f9102c4,0x60f9021f,0x66047438,0x64590067}},	// [78b0] _suzu_, мная_, _grik, _świd,
   {{0x317800fe,0x00000000,0x00000000,0x00000000}},	//   _chrz_, --, --, --,
   {{0xf6500332,0xf8b30317,0x853c00a5,0x6604012e}},	//   _نئی_, רשע_, _מגזי, _zrik,
   {{0x27340023,0x7c3d013b,0xdcb100e2,0x2398023a}},	//   _vãng_, _əsrd, _sẻ_, _učja_,
   {{0x69db00a2,0x3cfd01c0,0x7ed4099f,0x61320a8a}},	//   xtue, लयले_, ازما, _sæle,
   {{0x51840009,0xfce57439,0x7af92b28,0x6132008c}},	//   _буса, токо, _sawt, _pæle,
   {{0x7afb0159,0x9c7c005f,0x41540200,0x00000000}},	//   tdut, _kačy, _сврс, --,
   {{0x69db743a,0x3ebf0118,0x00000000,0x00000000}},	//   ttue, _udut_, --, --,
   {{0x3945743b,0x2bcf0026,0x7afb743c,0x2add0e6f}},	//   tils_, संहा, rdut, क्षु_,
   {{0x6d41033b,0x7afb0036,0x69db743d,0xfe6e00f8}},	//   _umla, sdut, rtue, _بگم_,
   {{0xf092035e,0x3945743e,0x69db743f,0x660409df}},	//   יני_, rils_, stue, _srik,
   {{0x69db7440,0x628f0345,0x394500f6,0x00000000}},	//   ptue, _ngco, sils_, --,
   {{0x69350948,0x39457441,0xe8ee3945,0xbb3a02b5}},	//   _инду, pils_, _кл_, _קעני,
   {{0x629d09c7,0xe5a3002d,0x628f027a,0x6aa909e1}},	//   _afso, рири, _agco, lbef,
   {{0x28120118,0x6b8b7442,0x442c0037,0x00000000}},	//   _نووس, _kigg, ád_, --,
   {{0x6b8b007a,0x26c00506,0x6aa96246,0x98be00ec}},	//   _jigg, _udio_, nbef, mitā_,
   {{0x25a07443,0x877b0070,0x69c90051,0x6b8b030d}},	// [78c0] _util_, _קאפי, nree, _migg,
   {{0x6459006a,0x45b70070,0xb5b71804,0x10a6263c}},	//   _świe, _שפיל_, _שליח_, тижн,
   {{0x69c90a75,0x03a602ee,0x2d1e046c,0x00000000}},	//   hree, _шино, _बकौल_, --,
   {{0x69c93118,0x25ad002d,0x52760043,0x6da63cef}},	//   kree, ţele_, _аугу, вида,
   {{0xf2d314b0,0x527539e8,0xdce10107,0xe1ff0067}},	//   _דער_, _буру, _eklč, _wzór_,
   {{0xa3d60066,0x69c9002d,0xa0a30370,0x9e6500ce}},	//   _समा_, dree, _вард, دامن,
   {{0x61430ea0,0x69c959c1,0x656e1a07,0x6b8b7444}},	//   _тера, eree, ilbh, _bigg,
   {{0x7bc50453,0x28d40066,0x96a200b4,0x6b8b0282}},	//   áhua, _दाहि, _क्लॉ, _cigg,
   {{0x7de52499,0x63a90a78,0xecd401cb,0x69c93754}},	//   _مسلم, ćeni, _محاک, gree,
   {{0x39140eee,0xddc900f4,0xdb0a00d5,0xc27b0277}},	//   умор, _uzeš, nsfú, ורפי,
   {{0x6b8b01a2,0x69c9018f,0xb17b03d0,0x00000000}},	//   _figg, aree, _spåk, --,
   {{0xfaa607be,0x69c92b9a,0x6b8b7445,0x2d8c00a5}},	//   _радо, bree, _gigg, _hide_,
   {{0x2d8c01d7,0x00000000,0x00000000,0x00000000}},	//   _kide_, --, --, --,
   {{0xd9431126,0x6b8b7446,0x2d8c7447,0x00000000}},	//   _кечи, _zigg, _jide_, --,
   {{0x2d8c7448,0x9f5f0031,0xb8200033,0x6b8b09aa}},	//   _mide_, ërën_, _ফেরত_, _yigg,
   {{0x2d8c7449,0x656e0094,0x81e70033,0x0ed104aa}},	//   _lide_, albh, ভিস_, _हाइड,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [78d0] --, --, --, --,
   {{0x44f50969,0x2d8c023a,0x973d0207,0x00000000}},	//   _спос, _nide_, općo, --,
   {{0x51841ea1,0x628f07e5,0x69c900d7,0x00000000}},	//   рута, _tgco, zree, --,
   {{0x2d8c1010,0x6602744a,0xd9f237e8,0x00000000}},	//   _aide_, _šoki, _अनंत_, --,
   {{0x2d8c1605,0xdcb100e2,0x00000000,0x00000000}},	//   _bide_, _hỏi_, --, --,
   {{0x6b8b744b,0x69c911ad,0xdce10069,0xbebd4df2}},	//   _sigg, vree, _bilġ, _plūs,
   {{0x6b8b744c,0x69c90345,0x00000000,0x00000000}},	//   _pigg, wree, --, --,
   {{0x69c939df,0x2b980248,0x2d8c0185,0x290e0312}},	//   tree, _déc_, _eide_, _anfa_,
   {{0xc3340122,0x6b8b744d,0x6aa9744e,0x69c9744f}},	//   יוק_, _vigg, rbef, uree,
   {{0x69c97450,0x2d8c73e7,0x3f8d0023,0x201e01f7}},	//   rree, _gide_, _hieu_, _àtic_,
   {{0x6b8b7451,0x3f8d12ec,0x7ad500fc,0x28d401d1}},	//   _tigg, _kieu_, _مقاص, _दारि,
   {{0xeb3413cf,0x69c93d39,0xe5a667d7,0xf1bf00ac}},	//   _پرمخ, pree, лими, _ová_,
   {{0x3f8d7452,0x26de0035,0x77930160,0x4df9016b}},	//   _mieu_, ęto_, _măxi, עפֿא,
   {{0x3f8d02e1,0x98a21d91,0x00000000,0x00000000}},	//   _lieu_, _лише, --, --,
   {{0x64430207,0x00000000,0x00000000,0x00000000}},	//   _žnir, --, --, --,
   {{0x3f8d03bc,0x00000000,0x00000000,0x00000000}},	//   _nieu_, --, --, --,
   {{0x9f5e1010,0x00e60409,0x0206010b,0x00000000}},	// [78e0] _été_, лжан, ызан, --,
   {{0x98be002d,0xd5b800ea,0x00000000,0x00000000}},	//   mită_, ņās_, --, --,
   {{0x25b200e9,0x2d8c7453,0x3f8d00e2,0x232a3265}},	//   _hwyl_, _ride_, _bieu_, _зони_,
   {{0x2d8c0122,0x5fc922c7,0x25b20298,0xa25b021d}},	//   _side_, ांजल, _kwyl_, _idôn,
   {{0x3f8d7454,0x2d8c7455,0xfe4600af,0x98be00af}},	//   _dieu_, _pide_, ындо, nită_,
   {{0x61460dee,0x00000000,0x00000000,0x00000000}},	//   _сега, --, --, --,
   {{0x2d8c7456,0x0b8a7457,0x613203d0,0xc4d300a5}},	//   _vide_, нсии_, _gæla, צגה_,
   {{0x3cf0006a,0x2d8c00a5,0x70531062,0x1eaa4dc0}},	//   _इसके_, _wide_, _انفا, _ساري_,
   {{0x5f1102cb,0x442a0187,0xdca6191f,0xdddb0506}},	//   णार्_, hyb_, _бази, _zguž,
   {{0xa6db0093,0xc23700a5,0x2b980183,0x2d8c0116}},	//   miði, טרפו_, _téc_, _uide_,
   {{0x7c930082,0x5c5655e2,0xa6db0093,0x61f6016e}},	//   _المص, _стаф, liði, hwyl,
   {{0x6d4a1db4,0x9a6a0079,0x00000000,0x00000000}},	//   lifa, _كمال_, --, --,
   {{0x65952585,0x2918330b,0xdb0a0909,0x7c2a34d7}},	//   рагу, öras_, dsfø, lyfr,
   {{0x6d4a7458,0xb4c110b7,0x260a0084,0x65940144}},	//   nifa, ुले_, ामजी_, сару,
   {{0x78ba7459,0x3cec000c,0xa0240033,0xf1bf0355}},	//   matv, _आउने_, _যেসব_, _svá_,
   {{0xe2f80210,0x6d4a000e,0xa2a000be,0x78ba745a}},	//   лесі_, hifa, गुल्, latv,
   {{0x6d4a43dd,0x7c2a00e9,0xc2f70033,0x3f8d0051}},	// [78f0] kifa, hyfr, ঙালি_, _rieu_,
   {{0x78ba00c7,0x6d4a0054,0x3f8d0023,0x9f5100d5}},	//   natv, jifa, _sieu_, _drzý_,
   {{0x2007745b,0x7a480228,0xb17b0282,0x3f8d00f6}},	//   íni_, lītī, _opåv, _pieu_,
   {{0x672f004e,0x78ba745c,0x6d4a0051,0x63a503d5}},	//   nkcj, hatv, eifa, _ithn,
   {{0x386e001e,0x9f5c0355,0xdce1745d,0x00000000}},	//   _lyfr_, ívá_, _jilħ, --,
   {{0x6d4a0979,0xa3e9111b,0xdce10024,0xdce80409}},	//   gifa, _यहा_, _milħ, _didį,
   {{0x3f8d0023,0x78ba00e2,0x6132008c,0xa1580009}},	//   _tieu_, datv, _kæln, _сару_,
   {{0x6d4a0176,0x3cfe08c7,0x00000000,0x00000000}},	//   aifa, _eatv_, --, --,
   {{0x6d4a010a,0xdce1009f,0x00000000,0x00000000}},	//   bifa, _nilħ, --, --,
   {{0x394508a6,0x98be00af,0x78ba745e,0xbb4400c3}},	//   рног, vită_, gatv, äärä,
   {{0xe73a519d,0x2eff01ae,0x3cf200b4,0xb461013b}},	//   вен_, _kauf_, ंजरे_, çülə,
   {{0xdce10024,0xa2a7745f,0xc9f5097f,0x00000000}},	//   _bilħ, टुम्, _نستع, --,
   {{0x63a50037,0x78ba08c8,0x16b60026,0x00000000}},	//   _athn, batv, _अजीब, --,
   {{0x6459006a,0x18a503fa,0x6abb01ae,0x98be002d}},	//   _świa, _такм, lauf, rită_,
   {{0xd46a4745,0xf773006c,0x888300d1,0x98be00af}},	//   тиве_, _ڈاٹ_, _دیدن, sită_,
   {{0x97c400d1,0x6d4a3776,0x6abb033b,0x3f9c00b5}},	//   _اتوم, zifa, nauf, ívum_,
   {{0xe2977460,0x63a57461,0x4736064e,0xe0da0896}},	// [7900] рау_, _ethn, _مرکز, ква_,
   {{0x399b0370,0x28dd0fd0,0xf0a70043,0x6abb7462}},	//   _mês_, _माफि, икул_, hauf,
   {{0xa2e60fa7,0x6abb01ae,0x28dd3877,0x3d190d91}},	//   _конд, kauf, _मानि, पाने_,
   {{0xdee630ba,0x7c2e01ae,0x78ba00ee,0xa85600a5}},	//   роди, _übri, zatv, ביעה_,
   {{0x6d4a7463,0x3ea902d7,0x7bc17464,0x00000000}},	//   tifa, ñata_, _avlu, --,
   {{0x8bc60009,0xa6db008d,0x80dd0354,0x2b460211}},	//   асид, riði, _पाये, _smoc_,
   {{0x6d4a67ec,0x78ba7465,0x80ad0033,0x67240223}},	//   rifa, vatv, _চাচ্, _ooij,
   {{0x6d4a7466,0x5b14002d,0x98a5010b,0x78ad0124}},	//   sifa, смит, filį_, _đava,
   {{0x3f98000e,0xada3005f,0x78ba1c9f,0xb6060b67}},	//   _huru_, _матл, tatv, njšč,
   {{0x3f987467,0x6f007468,0x7aa60099,0x00000000}},	//   _kuru_, _hamc, _ट्रॅ, --,
   {{0x3f986e8b,0x6d487469,0x67240282,0xb8fe021a}},	//   _juru_, _imda, _boij, _णा_,
   {{0x9a861ad4,0x6f025603,0x09e62626,0x78ba1aa2}},	//   _кулл, ndoc, _водн, satv,
   {{0x78ba746a,0x29110037,0x09e300d8,0x3f9800e0}},	//   patv, ánaí_, _моцн, _luru_,
   {{0x200a0139,0x69c0746b,0x3d19046c,0x7a790070}},	//   _orbi_, msme, पाये_, _גרױס,
   {{0x69c0746c,0x53470036,0x397b0070,0x3f98746d}},	//   lsme, ахаа, _שטונ, _nuru_,
   {{0x394c746e,0x70af0067,0x00000000,0x00000000}},	//   lids_, टर्ल, --, --,
   {{0x6d48746f,0xf99302b5,0x6f027470,0x926b0274}},	// [7910] _omda, ַרף_, ddoc, трва_,
   {{0x2eff0248,0x394c0176,0x3f987471,0x60dc0069}},	//   _sauf_, nids_, _buru_, _ccrm,
   {{0x3f980160,0x63a90124,0x00000000,0x00000000}},	//   _curu_, ćens, --, --,
   {{0x671a0299,0x6f007472,0x69c00080,0x6d480297}},	//   धायक_, _camc, ksme, _amda,
   {{0xdef8325e,0xa3d352cf,0x6f007473,0x3f98429e}},	//   рых_, हूर_, _damc, _euru_,
   {{0xa3be004e,0x69c0590a,0xee380402,0x1fa70c46}},	//   ुंच_, dsme, шні_, _враг,
   {{0xadc301a5,0x6f025a56,0x6abb7474,0x6f000107}},	//   _trắn, bdoc, tauf, _famc,
   {{0x59c25860,0x6d480260,0x545832e3,0x00000000}},	//   _शिखर, _emda, יבוב_, --,
   {{0x6abb01ae,0xdce372f8,0x69c07475,0xe2a6008d}},	//   rauf, lonč, gsme, óðin_,
   {{0x9be702ce,0x394c7476,0x6abb033b,0xe8f60bfc}},	//   _відк, gids_, sauf, бль_,
   {{0xc6890bed,0x7d010159,0x2911037a,0xba4500b5}},	//   _נא_, _ials, ıza_, شنگٹ,
   {{0x7d017477,0xe73a10b0,0x81bd0033,0xaa950037}},	//   _hals, уем_, _ইমন_, _الإث,
   {{0xa3da02cb,0x2b4d0067,0x00000000,0x00000000}},	//   डून_, miec_, --, --,
   {{0xdce37478,0x394c3ec4,0x64a31a90,0x00000000}},	//   konč, cids_, зара, --,
   {{0x1dd10461,0x6f0209b3,0x00000000,0x00000000}},	//   _समझत, ydoc, --, --,
   {{0x2b4d307f,0x3f98433d,0x7d010103,0x00000000}},	//   niec_, _ruru_, _lals, --,
   {{0x6132054e,0x200a10ec,0x6f0000d5,0x3f98145d}},	// [7920] _fæll, _srbi_, _ramc, _suru_,
   {{0x3f987479,0xb69b747a,0x79990345,0x6132008c}},	//   _puru_, ndân, _muww, _gæll,
   {{0x6f000124,0x2af900be,0x61fd02b1,0x3f98013b}},	//   _pamc, ्याँ_, _essl, _quru_,
   {{0xee3a03fa,0x1e860012,0x7d01747b,0x69c0747c}},	//   лне_, блем, _aals, ysme,
   {{0x7d0133a9,0x81e70033,0x00000000,0x00000000}},	//   _bals, ভিউ_, --, --,
   {{0x3f9600c9,0x3f98747d,0xa06a30cc,0x69c0014e}},	//   _граѓ, _turu_, _бага_, vsme,
   {{0x7d01747e,0x394c747f,0x78b8081f,0xa1370070}},	//   _dals, vids_, _revv, _פאלק_,
   {{0xdee31964,0x69c07480,0x5a340be8,0xa2cb0067}},	//   _носи, tsme, жнит, तृप्,
   {{0x69c07481,0xa92a005f,0x394c362b,0x2bd40026}},	//   usme, гіне_, tids_, _धमका,
   {{0xa3d30006,0x69c07482,0xce370d85,0x61e47483}},	//   हूँ_, rsme, _האמת_, itil,
   {{0x9c7c338b,0xab96004f,0x394c198d,0x69c07484}},	//   _obči, _الصغ, rids_, ssme,
   {{0x61e47485,0x3f8602d0,0x973d022f,0x2b4d0035}},	//   ktil, nmou_, opći, ciec_,
   {{0x8b650082,0xe66703fe,0xe9182327,0x6d58081b}},	//   _بالم, стно, _волі_, onva,
   {{0xa6db003e,0x22400067,0x290200ea,0x00000000}},	//   viðu, dzik_, ēkas_, --,
   {{0xa3d30953,0x6b9a0443,0x0ed814ab,0x61e47486}},	//   हूं_, _jutg, _डांड, etil,
   {{0x61fd028b,0xe616008b,0x61320a8a,0x61e47487}},	//   _pssl, žišč, _dælm, ftil,
   {{0x388e0250,0x25ac0187,0x61e47488,0x613208c8}},	// [7930] lər_, čilý_, gtil, _tæll,
   {{0x660d03cb,0x25a97489,0x3d020035,0xa6db008d}},	//   _irak, _ital_, लयों_, riðu,
   {{0xd01127f6,0x61e4748a,0x273b01f4,0x3a3f0d24}},	//   بلا_, atil, _tënd_, zzup_,
   {{0x660d748b,0x61e4748c,0xa3ce0026,0xa6db0093}},	//   _krak, btil, _रित_, miðs,
   {{0x388e01c2,0x7d010df2,0x00000000,0x00000000}},	//   hər_, _pals, --, --,
   {{0xc3010b52,0x660d20f1,0x2b4d004e,0x78ad011c}},	//   _একটি_, _mrak, wiec_, _đavo,
   {{0x7d0155b4,0xeab1004f,0xcda900d1,0x98a5010b}},	//   _vals, وعة_, _چهره_, nklą_,
   {{0x388e01c2,0x49c94ea4,0x26c9012f,0x6d58053e}},	//   dər_, алин_, _ndao_, anva,
   {{0x7d01748d,0x7999012f,0x28d40f9c,0x7e7b0035}},	//   _tals, _quww, _दाखि, _uzup,
   {{0x388e01c2,0x47c5159f,0x57e9748e,0x26c9021d}},	//   fər_, обов, адом_, _adao_,
   {{0x660d748f,0x388e01c2,0x25a97490,0x2b4d004e}},	//   _arak, gər_, _atal_, piec_,
   {{0x61e47491,0x7bc37492,0x7c3d00a8,0x00000000}},	//   ytil, msnu, _əsrl, --,
   {{0xe57a3876,0xba2b017e,0x7ae97493,0x00000000}},	//   изм_, _حسام_, mfet, --,
   {{0x388e01c2,0x660d7494,0x7ae912d9,0x6b5e00ea}},	//   bər_, _drak, lfet, mīga,
   {{0x660d7495,0xe7b5004f,0x7bc34a11,0x6b5e0228}},	//   _erak, _بمعد, nsnu, līga,
   {{0xe2970834,0x7ae97496,0x61e41919,0x26cc00d8}},	//   жат_, nfet, ttil, ėdos_,
   {{0x6b5e00ea,0x6d58008e,0x660d7497,0x91e305a1}},	// [7940] nīga, ynva, _grak, моте,
   {{0x29057498,0xb17b013c,0x61e47499,0x7bc3749a}},	//   ndla_, _spår, rtil, ksnu,
   {{0x660d06cc,0xb4d6007c,0x224000b5,0x78ad022f}},	//   _zrak, हली_, szik_, _đavl,
   {{0x6b9a749b,0xd47b0bed,0x644801ba,0xdce0013b}},	//   _rutg, _כאיל, údiu, _rumı,
   {{0x3f862314,0x388e0095,0xee8300af,0xada30097}},	//   rmou_, zər_, мышо, _neúč,
   {{0x5ba61d91,0x613201cf,0xa1160372,0x388e00a8}},	//   ориз, _mælk, _بوست, yər_,
   {{0x7ae9749c,0x6d58749d,0xbea603d0,0x00000000}},	//   ffet, rnva, _мавк, --,
   {{0xdb010279,0x2905042f,0xdddb027d,0x388e00a8}},	//   _atlâ, edla_, _uyuş, vər_,
   {{0xb9970733,0x00000000,0x00000000,0x00000000}},	//   овых_, --, --, --,
   {{0x6b9a009e,0x388e00a8,0x4c160098,0x272200ee}},	//   _tutg, tər_, _وباس, _ióny_,
   {{0xeb9a00c9,0x2005008a,0x25a905ed,0x80d00083}},	//   _тие_, _álit_, _stal_, স্থ্,
   {{0x7bd8018c,0x388e00a8,0x00000000,0x00000000}},	//   muvu, rər_, --, --,
   {{0x95d80086,0xa5070352,0x7bd8749e,0x6b5e00ea}},	//   одят_, оявл, luvu, cīga,
   {{0x80d00033,0xfa7700a5,0x00000000,0x00000000}},	//   স্ত্, _ועדת_, --, --,
   {{0xb8660365,0x00000000,0x00000000,0x00000000}},	//   _باشو, --, --, --,
   {{0x26c90009,0xc2991c4d,0x00000000,0x00000000}},	//   _udao_, сках_, --, --,
   {{0xa2dc0f3d,0x660d749f,0x6b8274a0,0x00000000}},	// [7950] _फार्, _urak, _mhog, --,
   {{0x7bd874a1,0xc17800d4,0x320900ee,0x00000000}},	//   kuvu, оїх_, rvay_, --,
   {{0x5f95176f,0x28dd1e18,0x320974a2,0xb4fa024b}},	//   чиет, _मासि, svay_, _הפתי,
   {{0x443100f6,0x80dd00ab,0x00000000,0x00000000}},	//   myz_, _पावे, --, --,
   {{0xe1ff0453,0xdca52f19,0x00000000,0x00000000}},	//   _usó_, пали, --, --,
   {{0x6b82006c,0x61f9027b,0xeb991402,0x00000000}},	//   _ahog, ğalı, бик_, --,
   {{0x9c7c02c6,0x7bd874a3,0x6b8226c9,0x2d87023a}},	//   _obču, guvu, _bhog, rmne_,
   {{0x28dd0429,0x6b8274a4,0x6b5e0228,0xdcfa00ec}},	//   _माहि, _chog, tīga, _bitē,
   {{0x7ae9046f,0x7c380129,0xdcfa0029,0x1ddf021a}},	//   rfet, _čarš, _citē, _नमित,
   {{0xa2cb0567,0x7ae974a5,0xaaab0ebd,0x6b5e00ea}},	//   तृत्, sfet, _ट्रक, rīga,
   {{0x3ea074a6,0x6b820094,0x2c740037,0x98be00b8}},	//   žite_, _fhog, rúdú_, litě_,
   {{0x290302dd,0x2576008a,0x6b820024,0x00000000}},	//   žja_, mæli_, _ghog, --,
   {{0x613301d6,0x6b896ec2,0xdb18008d,0xa6e3008d}},	//   _kılı, mmeg, fsvæ, óðas,
   {{0x6b8974a7,0xb4d674a8,0x00000000,0x00000000}},	//   lmeg, हले_, --, --,
   {{0x29360070,0xf99000bc,0x00000000,0x00000000}},	//   _מאסן_, _شبه_, --, --,
   {{0xf1c707ba,0xe29a021d,0x6b892f21,0x00000000}},	//   _लिखन, саа_, nmeg, --,
   {{0x26c274a9,0xa8230332,0x00000000,0x00000000}},	// [7960] mako_, _رکھن, --, --,
   {{0x26c274aa,0x6b8902b1,0x00000000,0x00000000}},	//   lako_, hmeg, --, --,
   {{0x26c201a3,0x80dd01c0,0x397a016b,0x273b0055}},	//   oako_, _पारे, צטענ, _hëna_,
   {{0x26c274ab,0x6b8901e4,0xdce300b8,0x61320093}},	//   nako_, jmeg, plně, _mæli,
   {{0xddcb01d6,0x527500af,0x26c201a3,0xdce8003c}},	//   ğişi, _журу, iako_, _jidħ,
   {{0x26c201ed,0x656e01da,0xdb010392,0xdd9901e0}},	//   hako_, nobh, _atlà, іші_,
   {{0x26c274ac,0x06c700c8,0x00000000,0x00000000}},	//   kako_, ষ্টি, --, --,
   {{0x26c274ad,0xd90d00d1,0xd00f006c,0x27220097}},	//   jako_, یین_, _حلف_, _tóny_,
   {{0xa3d60953,0x26c274ae,0xadc301a5,0xee3a002d}},	//   _समझ_, dako_, _trạn, _уна_,
   {{0xd7fa0a87,0x69cf0a20,0x273400e2,0xbd460698}},	//   бум_, ácea, _hãnh_, _عناي,
   {{0xfbd20594,0x6b8267dd,0x28dd06bc,0x26c231ff}},	//   _ستا_, _thog, _मारि, fako_,
   {{0x6c7b02b5,0x26c274af,0x79a60009,0xcc5700a5}},	//   _פראד, gako_, _ерке, _צבאי_,
   {{0x613301d6,0x27340023,0x80dd23db,0x00000000}},	//   _yılı, _mãnh_, _पाले, --,
   {{0x273401a5,0x249a00d7,0x26c274b0,0x8afd0355}},	//   _lãnh_, _cgpm_, aako_, voři,
   {{0x0fd700c8,0x26c274b1,0xdb180093,0x18970037}},	//   _সন্ধ, bako_, rsvæ, _عضوة_,
   {{0x443170a9,0xb7db011d,0x26c21297,0x00000000}},	//   ryz_, _הקהי, cako_, --,
   {{0xd0470095,0x4431005f,0x69bf02b4,0x00000000}},	// [7970] əməs, syz_, लीपी, --,
   {{0x55bc011d,0xa25b07c0,0x00000000,0x00000000}},	//   _המזו, _odôv, --, --,
   {{0x67210fbf,0x2fc701cb,0x389b02b5,0x7ae202d7}},	//   यापक_, éng_, ציאנ, _ocot,
   {{0xdb18013c,0x00000000,0x00000000,0x00000000}},	//   nsvä, --, --, --,
   {{0x2fc70023,0x3d1901c0,0x68fa74b2,0x7bc874b3}},	//   ũng_, पाले_, ketd, _avdu,
   {{0x26c274b4,0x7ae225ac,0x6133013b,0x00000000}},	//   zako_, _acot, _qılı, --,
   {{0xbbe80082,0xdb010b4c,0x26c2018e,0x6b8974b5}},	//   كريم_, _atlá, yako_, tmeg,
   {{0xeaf900e7,0x26c201a3,0xeeb902fb,0x6b8974b6}},	//   ्येत_, xako_, _флаш_, umeg,
   {{0x6b8943fa,0x26c231ff,0x00000000,0x00000000}},	//   rmeg, vako_, --, --,
   {{0x26c274b7,0x77c91053,0x9f410037,0x3ebf02b1}},	//   wako_, олог_, ithí_, _heut_,
   {{0x26c203cb,0xfbd00e3a,0xef190069,0xb9050387}},	//   tako_, _متن_, _knż_, _फा_,
   {{0x201100cb,0x2d9f00be,0x7ae20098,0x00000000}},	//   _mrzi_, _kuue_, _gcot, --,
   {{0x26c274b8,0x656e0211,0x68fa0510,0x7afb023c}},	//   rako_, tobh, betd, meut,
   {{0x26c274b9,0x7afb54eb,0x64a603e6,0x00000000}},	//   sako_, leut, ќава, --,
   {{0x26c274ba,0x212a004a,0x656e00f1,0x64a3004b}},	//   pako_, _robh_, robh, таса,
   {{0x290774bb,0xae1d1e79,0x7afb74bc,0xc7d600a5}},	//   _hana_, पमान_, neut, _חוקי_,
   {{0x29075676,0x2d8500e7,0x20110139,0x273400e2}},	// [7980] _kana_, _ohle_, _arzi_, _rãnh_,
   {{0x66040006,0x29073c04,0x7afb0086,0x2011011c}},	//   _isik, _jana_, heut, _brzi_,
   {{0x2907431f,0xe29a15f1,0x251b00c2,0x351b1899}},	//   _mana_, _ман_, _וויא, _ווינ,
   {{0x290774bd,0x25a0005d,0x2011003d,0xdb0a01ff}},	//   _lana_, _kuil_, _drzi_, lsfö,
   {{0x26c000c9,0x7afb1fb3,0x25a002e1,0x3ebf74be}},	//   _meio_, deut, _juil_, _deut_,
   {{0x7ae24c34,0x66040054,0xdb0a01ff,0x26c074bf}},	//   _scot, _msik, nsfö, _leio_,
   {{0x69cf00b8,0x25a00260,0xdb01063c,0x00000000}},	//   ácen, _luil_, _stlá, --,
   {{0xbf160934,0x2907001c,0x386002c4,0x63ba00a0}},	//   _تورب, _aana_, _ćir_, átny,
   {{0x290774c0,0x7c3d00a8,0x394e0176,0xdb0a01ff}},	//   _bana_, _əsri, _pmfs_, ksfö,
   {{0x2d8501da,0x81b30033,0x00000000,0x00000000}},	//   _ghle_, _টিম_, --, --,
   {{0x290774c1,0x7d1a74c2,0xdb0a013c,0x29180644}},	//   _dana_, _ints, dsfö, ıra_,
   {{0x81c400c8,0xf09300a5,0x25a00284,0x68fa00f4}},	//   _এমন_, כנת_, _buil_, setd,
   {{0xceb30122,0x25a01c8b,0x290774c3,0xdb1801ff}},	//   כיר_, _cuil_, _fana_, rsvä,
   {{0x25a00284,0xf10d0f06,0x7d08021d,0x00000000}},	//   _duil_, _सफेद_, _jads, --,
   {{0x7d0801b4,0x6604073c,0x26c074c4,0x63bb02c4}},	//   _mads, _esik, _feio_, ćuno,
   {{0x25a004e6,0xe3b0126b,0x290774c5,0xf8ad0580}},	//   _fuil_, شرف_, _zana_, _پکی_,
   {{0x290774c6,0x7d1a0903,0x61150369,0x05bb01df}},	// [7990] _yana_, _onts, ндау, _بدعت_,
   {{0x7d080a3c,0xda080019,0x645a0d9b,0x290774c7}},	//   _nads, _mỏ_, útic, _xana_,
   {{0x3ebf1010,0x25a00051,0x395e74c8,0x7afb0177}},	//   _peut_, _zuil_, ints_, yeut,
   {{0xf1a73dc1,0x7d1a74c9,0x69cf1451,0x93440279}},	//   _कंपन, _ants, _दिली, _анџе,
   {{0x3ebf02e1,0x31a406d3,0x629d1296,0x3f9c008e}},	//   _veut_, _göz_, _igso, ívur_,
   {{0xe6dc0355,0xdd91006c,0x672d00d5,0x6132008c}},	//   _मञ्ज, ھوں_, _loaj, _bælu,
   {{0x7afb0086,0xfaa51538,0x3156016b,0x00000000}},	//   teut, найо, _טישן_, --,
   {{0x290774ca,0x7d1a02bf,0x395e74cb,0xda080028}},	//   _sana_, _ents, ents_, _bỏ_,
   {{0x290774cc,0xda080019,0x7afb45e8,0xc9551ac5}},	//   _pana_, _cỏ_, reut, етны,
   {{0x60c502c9,0x7d0800ea,0x25a00b0d,0x26c00183}},	//   nahm, _gads, _ruil_, _seio_,
   {{0x6d431093,0x6f1b1c7f,0x290774cd,0xc1720d85}},	//   mhna, _knuc, _vana_, רחי_,
   {{0x290774ce,0x395e34fc,0x69ba0066,0x672d0395}},	//   _wana_, ants_, _शौकी, _coaj,
   {{0x290774cf,0xf6521629,0x26c003e6,0xdb0a3f3b}},	//   _tana_, ائج_, _veio_, tsfö,
   {{0x60c5022e,0x25a00b0d,0x2907034d,0x00000000}},	//   jahm, _vuil_, _uana_, --,
   {{0x31a40092,0x60ce012f,0x69c61b97,0xe73a409d}},	//   _söz_, _rdbm, šket, _нек_,
   {{0x2327701e,0x66040178,0xdb0a01ff,0x41aa0145}},	//   носи_, _tsik, ssfö, зван_,
   {{0x64a6464d,0x660474d0,0x69c974d1,0xe36303b1}},	// [79a0] _папа, _usik, nsee, укти,
   {{0x7cf3033e,0x69c900c3,0x6f1b0088,0xddcb0225}},	//   nırı, isee, _anuc, _şişm,
   {{0x6d4309bb,0x7d0861d6,0x6f094c7c,0xa3d7018d}},	//   dhna, _rads, _baec, _सिय_,
   {{0x69c903ad,0x81cf0083,0x888c0070,0x7d0874d2}},	//   ksee, _শহর_, קראַ, _sads,
   {{0x6f090069,0x7cf30225,0x613208c8,0x23600067}},	//   _daec, kırı, _bælt, mnij_,
   {{0xdd8f0fab,0xafe60cb5,0x6d43066a,0xa2d8175f}},	//   مون_, _погл, ghna, यलक्,
   {{0x69cb0523,0x69c90086,0x7cf300c1,0xfbcf11c0}},	//   _avge, esee, dırı, متي_,
   {{0x6132008e,0xff2602fb,0x6f09021d,0x9f4a0421}},	//   _vælu, _ямбо, _gaec, ömän_,
   {{0xbc6a0647,0x6b99099e,0x69c90345,0x7d0803d0}},	//   _کمان_, _diwg, gsee, _tads,
   {{0x6d4374d3,0xda080019,0x395e74d4,0x26140ec5}},	//   chna, _vỏ_, unts_, दिनी_,
   {{0xdd8f0071,0x69cb0478,0x6bd618dd,0x2360004e}},	//   _اول_, _evge, _ستار, knij_,
   {{0xda080019,0x2a66006f,0x6fd300b4,0x00000000}},	//   _tỏ_, _txob_, _डिसू, --,
   {{0xe1ff0042,0x672d00cd,0x00000000,0x00000000}},	//   _axón_, _voaj, --, --,
   {{0x6846534f,0x00000000,0x00000000,0x00000000}},	//   _cédé, --, --, --,
   {{0x998200d8,0x684600e0,0x99830079,0x00000000}},	//   škų_, _dédé, _حلوو, --,
   {{0x236074d5,0x60c5012f,0x7c25033b,0x6b9c0042}},	//   gnij_, wahm, ähri, _érgu,
   {{0x68460248,0xe1ff01ef,0x291c0359,0x00000000}},	// [79b0] _fédé, _exón_, _knva_, --,
   {{0x290c74d6,0x6f1b0211,0x00000000,0x00000000}},	//   ndda_, _snuc, --, --,
   {{0xb4dd74d7,0x00000000,0x00000000,0x00000000}},	//   डली_, --, --, --,
   {{0x6fd60026,0xe52201c0,0x80dd4353,0x7cf30457}},	//   मंजू, माथि_, _पाके, zırı,
   {{0xdd9b0086,0x1d090ae6,0x228401d3,0x6d430037}},	//   чше_, дели_, _бург, thna,
   {{0x61ed74d8,0x063802b5,0x5ff502f3,0x6b99016e}},	//   mtal, ענגט_, _изгу, _siwg,
   {{0x61ed74d9,0xdfd80133,0x69c900d7,0x613208c8}},	//   ltal, _път_, wsee, _vælt,
   {{0x69c974da,0x5f9474db,0x6f1b00cd,0x291c0103}},	//   tsee, _бист, _unuc, _anva_,
   {{0x7cf30092,0x9c8201ba,0x6aa974dc,0x22490973}},	//   tırı, ľčan, rcef, nzak_,
   {{0x61ed74dd,0xe7a917f9,0x2ba9252c,0x224901b7}},	//   ital, мвол_, _चंपा, izak_,
   {{0x6d4174de,0x69c974df,0x61ed74e0,0xf7460ca6}},	//   _illa, ssee, htal, вено,
   {{0x61ed74e1,0xe5a60009,0x291c001c,0x48e50066}},	//   ktal, кими, _enva_, ज्जो_,
   {{0xcb360052,0x69c600b8,0x61ed74e2,0xdb010031}},	//   _שאני_, šker, jtal, _lulë,
   {{0xa3bf004e,0x98a21303,0x18a274e3,0x00000000}},	//   ुओं_, _кише, _кашм, --,
   {{0x03a60c06,0x61ed74e4,0x00000000,0x00000000}},	//   тибо, etal, --, --,
   {{0x61ed74e5,0xdb01013c,0x3b0d012f,0x22490223}},	//   ftal, _utlä, ndeq_, fzak_,
   {{0x61ed74e6,0x6d4174e7,0xa3ce0026,0x95860dee}},	// [79c0] gtal, _olla, _रिक_, _илие,
   {{0xe0d7178e,0x6d410176,0x236d00cd,0xb1435f4e}},	//   кву_, _nlla, čeja_, анул,
   {{0x409674e8,0x838a00d4,0x3dcd021e,0x14d90070}},	//   трат, _обов_, _avew_, _אַרמ,
   {{0x443874e9,0xc2940df3,0xa3d70d1f,0x66160f0f}},	//   myr_, _میزب, _सित_, _kryk,
   {{0x3ea029e7,0xdee374ea,0x290c74eb,0x26d2010d}},	//   žito_, рочи, ydda_, _mdyo_,
   {{0x6286278c,0x3ead0107,0x008674ec,0x6fb60037}},	//   _izko, _efet_, _алго, _لمسا,
   {{0xd47a0070,0x6d410118,0x70de00be,0x7e7b095f}},	//   ואַל, _dlla, मलील, _eyup,
   {{0x6d4174ed,0x3ead0069,0xceea010b,0x7bca0fa8}},	//   _ella, _gfet_, _ідзе_, rsfu,
   {{0xada62632,0x4438001e,0x7bca74ee,0x80c6021a}},	//   _разл, hyr_, ssfu, िरपे,
   {{0x5fc6046c,0x6d410055,0x00000000,0x00000000}},	//   _लबाल, _glla, --, --,
   {{0xec130118,0x61ed74ef,0x3137011d,0xdca309cc}},	//   _پوند, ztal, דריך_, _тахи,
   {{0x290a74f0,0x443874f1,0x61ed2555,0xbb4400c3}},	//   žba_, dyr_, ytal, äädä,
   {{0x59f800af,0x9f47000d,0x61ed74f2,0x26d201a8}},	//   _челя_, îné_, xtal, _ddyo_,
   {{0x6d5874f3,0x8e201a15,0xb4dd2095,0x61ed1281}},	//   niva, лiк_, डले_, vtal,
   {{0xd82f00af,0x628601a3,0x61ed0118,0x443874f4}},	//   _тэ_, _azko, wtal, gyr_,
   {{0x61ed74f5,0x6d5874f6,0x22490291,0x15e30026}},	//   ttal, hiva, tzak_, कंदर_,
   {{0x6d582c26,0x521500d8,0x66160031,0x61ed74f7}},	// [79d0] kiva, ыдат, _gryk, utal,
   {{0x61ed74f8,0x6d580a78,0x443874f9,0x00000000}},	//   rtal, jiva, byr_, --,
   {{0x667400bf,0x628601d7,0x4438021d,0xa28300b5}},	//   _مدیر, _ezko, cyr_, _چیزو,
   {{0x61ed74fa,0x6d4101f4,0x673d02ce,0x00000000}},	//   ptal, _slla, nksj, --,
   {{0x926b015a,0x22da011d,0xdd2c010b,0x6d410031}},	//   _црна_, _אחרא, _dėžu, _plla,
   {{0x6d5874fb,0x63a5005f,0x80dd00b4,0x00000000}},	//   giva, _kuhn, _पाटे, --,
   {{0x764b006c,0x6d4101f4,0xbbf50037,0x9f580260}},	//   _ügyf, _vlla, استث, _oprè_,
   {{0x7e690065,0x00000000,0x00000000,0x00000000}},	//   _txep, --, --, --,
   {{0x6d5874fc,0x9f3403d0,0x2bae0067,0x1eea0987}},	//   biva, _теті, _ręce_, _سولی_,
   {{0x6d4101a6,0x6d580a78,0x9f5802e9,0xdb010118}},	//   _ulla, civa, _aprè_, _mulé,
   {{0x25b274fd,0x6ec70380,0x63a501ef,0x00000000}},	//   _styl_, ारपु, _nuhn, --,
   {{0xe7e40299,0x6d46010b,0x2ab8002d,0x7c2502b1}},	//   _कमरा_, _įkai, _алць_, ähru,
   {{0xcb120052,0x443802c7,0x7f3a02b5,0x6abb002f}},	//   _ללא_, wyr_, גערו, mbuf,
   {{0x394401c8,0x443874fe,0xe5a30fa7,0x66160345}},	//   _кніг, tyr_, сири, _vryk,
   {{0x6286006a,0x443e74ff,0x044303b2,0x63a50118}},	//   _szko, át_, берн, _cuhn,
   {{0x6d5801cc,0xe7b201cb,0x66161123,0x00000000}},	//   ziva, _اميد, _tryk, --,
   {{0x443e0506,0xdb010176,0xdb1811cb,0x44387500}},	// [79e0] št_, _culé, rsvø, syr_,
   {{0x6d587501,0x88d50033,0x11d70037,0x00000000}},	//   xiva, ত্রক, اولة_, --,
   {{0x6d587502,0xa2e6027a,0xcae30067,0x00000000}},	//   viva, _йонд, _गांड_, --,
   {{0x5276081b,0x69db7503,0xada60210,0x00000000}},	//   _бугу, krue, гадл, --,
   {{0xee3a0bbc,0xd83802d0,0x62860228,0xed5a2aa9}},	//   энд_, zyč_, _uzko, нод_,
   {{0xa0a3191f,0xfcaa0365,0x6b8b0103,0xe7e4049c}},	//   _гард, راتو_, _ahgg, _कमला_,
   {{0x6d587504,0x7c6600e0,0x00000000,0x00000000}},	//   riva, داشل, --, --,
   {{0x20180065,0x00000000,0x00000000,0x00000000}},	//   _irri_, --, --, --,
   {{0x6d581130,0x0d8618e2,0x9e666d3d,0x69db7505}},	//   piva, _блан, _свад, grue,
   {{0x6f0201ef,0x4dfb0070,0x00000000,0x00000000}},	//   leoc, _אפמא, --, --,
   {{0x645a00ee,0x9f582c60,0x3ea90a66,0x00000000}},	//   útil, _apré_, žate_, --,
   {{0xfaa63f96,0x63a57506,0x69db7507,0x2ee6081b}},	//   _садо, _ruhn, brue, ngof_,
   {{0x69db123d,0xa3d70066,0x66e60c57,0x2d9e33e6}},	//   crue, _सिह_, _कारक_, _kite_,
   {{0x1dc60026,0x20187508,0xe8942dc3,0x63a50124}},	//   रीयत, _orri_, _каль, _puhn,
   {{0xa3e40b54,0x7a480080,0x53350183,0x27f7024e}},	//   _नमः_, sūtī, аевт, čená_,
   {{0x2d9e7509,0x290e064b,0xa2b5750a,0x236d008b}},	//   _lite_, _hafa_, рбач, čejo_,
   {{0x1dc60567,0x290e750b,0x26cb539a,0xb33b0c6f}},	// [79f0] रीमत, _kafa_, maco_, _niçe,
   {{0xf1da0722,0x26cb750c,0x2d9e750d,0x00000000}},	//   यंजन, laco_, _nite_, --,
   {{0x8eb50365,0xe522060a,0x290e00fe,0x00000000}},	//   لماش, मारि_, _mafa_, --,
   {{0x7ff40082,0xcae30035,0x2d9e01a6,0x273b01f4}},	//   إسلا, _गाइड_, _aite_, _bëni_,
   {{0x6cc5005f,0x398b0c71,0x2018750e,0x2d9e750f}},	//   айла, løse_, _erri_, _bite_,
   {{0xabd52b9e,0x200a0118,0x2d9e4390,0x11da00a5}},	//   ациј, _fsbi_, _cite_, _בחשב,
   {{0x2d9e7510,0x2d990118,0x00000000,0x00000000}},	//   _dite_, _èsem_, --, --,
   {{0x60c7008c,0xb33b01d6,0x2d9e7511,0x00000000}},	//   _hejm, _hiçb, _eite_, --,
   {{0x26cb2000,0x290e7512,0xcce70934,0x2d9e7513}},	//   daco_, _bafa_, _مساي, _fite_,
   {{0x69db7514,0x2d9e7515,0x290e7516,0x5895002d}},	//   rrue, _gite_, _cafa_, ишну,
   {{0x8c676685,0x18691e9f,0x3ad500f8,0xe7667517}},	//   _стад, тани_, _نياز, ивоп,
   {{0x7d037518,0x61fd7519,0x3a751aa1,0xaa560105}},	//   lens, _opsl, _клер, الیا_,
   {{0xb52211b5,0x7d0303c4,0x80d00083,0xe5a62701}},	//   मालय_, oens, স্ট্, риги,
   {{0x7d03751a,0x60c700b8,0x290e751b,0x00000000}},	//   nens, _nejm, _gafa_, --,
   {{0xa87902b5,0x987902b5,0x7d031b4a,0x69c20223}},	//   _באַר, _באַט, iens, _zwoe,
   {{0xa3d708a9,0x200a012f,0x26cb0183,0x2d010775}},	//   _सिर_, _rsbi_, caco_, लजुल_,
   {{0xdcfa01c0,0xb226005f,0x60c701f4,0xb77b00a5}},	// [7a00] _chtě, шмал, _bejm, _שאפש,
   {{0x290e0176,0x20181ea7,0xa63b00a5,0x60d500ec}},	//   _xafa_, _prri_, _סגיר, _cdzm,
   {{0x6f02751c,0x3f8d009e,0x98a700af,0x35dc07b5}},	//   teoc, _bheu_, _zonă_, _बिड़,
   {{0x2d9e1c9e,0x91e6751d,0xee3a751e,0xd5a5073f}},	//   _site_, _коме, кне_, _गूँज,
   {{0x6f023061,0xcbb20033,0x3f8d751f,0x00000000}},	//   reoc, _ঘটেছ, _dheu_, --,
   {{0x7d0302b1,0x6f0202c4,0x61e4141d,0x60c70009}},	//   gens, seoc, muil, _gejm,
   {{0x2d9e7520,0x9b580854,0xcc240033,0xe4ee07b5}},	//   _vite_, ликт_, বন্ধ_, _जानि_,
   {{0xcfb70052,0x60c701c0,0x2d9e0afe,0x8fa30279}},	//   _כללי_, _zejm, _wite_, _фате,
   {{0x7d037521,0xd5a50084,0x61e40341,0x26cb7522}},	//   bens, _गूंज, nuil, vaco_,
   {{0x7d037523,0x2d9e002d,0xa3d70775,0x00000000}},	//   cens, _uite_, _सिल_, --,
   {{0xb8ce20d8,0x00000000,0x00000000,0x00000000}},	//   _कल_, --, --, --,
   {{0x290e2d69,0x61e45d00,0x00000000,0x00000000}},	//   _wafa_, kuil, --, --,
   {{0x0a160df3,0x26cb7524,0x290e7525,0x2f970070}},	//   _خوشح, raco_, _tafa_, יכטן_,
   {{0x97a6095d,0x26cb0952,0x00000000,0x00000000}},	//   _крил, saco_, --, --,
   {{0xf2c74219,0x60c77526,0x93970037,0xf79500af}},	//   исан, _rejm, لجرا, _лакэ,
   {{0x442d0537,0x7d037527,0x61e40079,0x9f53045e}},	//   će_, zens, fuil, üdür_,
   {{0x443f0080,0x7d037528,0x61e47529,0xa0a7002d}},	// [7a10] ņu_, yens, guil, ашел,
   {{0x2b460955,0x660d752a,0x7d03752b,0x867c00a5}},	//   _lloc_, _isak, xens, _ברחו,
   {{0x7d03308a,0xe8190084,0xc67800d1,0x2d4b0a8a}},	//   vens, धिया_, _محیط_, _høeg_,
   {{0x7d03752c,0x25a902d7,0xdb0100d4,0x00000000}},	//   wens, _kual_, _utlø, --,
   {{0x25a90ce8,0x60c727c3,0x00000000,0x00000000}},	//   _jual_, _tejm, --, --,
   {{0x25a90034,0x320900a2,0x660d6637,0x6d4a752d}},	//   _mual_, mway_, _msak, ghfa,
   {{0x2b46752e,0x3209752f,0x81e90033,0x3f8d3e1e}},	//   _bloc_, lway_, _মনি_, _theu_,
   {{0x660d7530,0x9984010b,0x1ee73c96,0x2b4600e5}},	//   _osak, kymų_, _خوری_, _cloc_,
   {{0x7d037531,0x32097532,0x6d4a0079,0x660d4734}},	//   pens, nway_, bhfa, _nsak,
   {{0x5d85004f,0x6d4a7533,0x394524ee,0x7d54021f}},	//   _الطل, chfa, сног, _двух,
   {{0xe73a3183,0x660d7534,0x2b46099e,0x61e4002f}},	//   ген_, _asak, _floc_, zuil,
   {{0x32090cca,0x25a97535,0x2bf60d85,0x5f050354}},	//   kway_, _bual_, _למען_, _रसोई_,
   {{0x25a90083,0x9b74004f,0x3a290095,0xab74004f}},	//   _cual_, _بالص, _çap_, _بالإ,
   {{0x61e40086,0x9f58027a,0x89d600fd,0x98a50382}},	//   vuil, _aprì_, _اوور_, _уике,
   {{0x290502a7,0x32090602,0x98b80035,0x39420029}},	//   mela_, eway_, órą_, īkst_,
   {{0x29056fc9,0x3ea00496,0x61e40421,0x59c400b4}},	//   lela_, žiti_, tuil, लीवर,
   {{0x32097536,0x67240009,0x25a97537,0x7ae9095a}},	// [7a20] gway_, _inij, _gual_, iget,
   {{0x29053e0d,0xe2977538,0x61e47539,0x4096753a}},	//   nela_, сау_, ruil, брет,
   {{0x32091292,0x672402a2,0x7ae9753b,0x29050065}},	//   away_, _knij, kget, iela_,
   {{0x290548a4,0x80c6000c,0x67240009,0x487a0070}},	//   hela_, िरहे, _jnij, אטעס,
   {{0x61e4753c,0x29051c9a,0x6d4a753d,0x7ae9593a}},	//   quil, kela_, thfa, dget,
   {{0x2905753e,0x8bc6159e,0x2b4601da,0x00000000}},	//   jela_, бсид, _sloc_, --,
   {{0x7ae9033b,0x2b4601da,0x672400f4,0x00000000}},	//   fget, _ploc_, _onij, --,
   {{0x1de0018d,0x6d4a753f,0x7ae97540,0xdb0100fe}},	//   _निपत, shfa, gget, _fulí,
   {{0x29055527,0x00000000,0x00000000,0x00000000}},	//   fela_, --, --, --,
   {{0x67247541,0x795822cc,0x395801a6,0xee370043}},	//   _anij, риор_, òrs_, _уну_,
   {{0x6c860082,0x25a90095,0x6d5a0095,0x6d484103}},	//   _الام, _sual_, _imta, _ilda,
   {{0x32097542,0x2a69030a,0x9984010b,0x09e67543}},	//   yway_, _žabe_, tymų_, _годн,
   {{0x25a92cc9,0xa3cb004e,0xb33b0176,0x25a13a07}},	//   _qual_, रीन_, _niça, _pihl_,
   {{0x29051075,0x80de00c8,0x660d108a,0x67240009}},	//   cela_, ন্ত্, _vsak, _enij,
   {{0x395e56f0,0x00000000,0x00000000,0x00000000}},	//   mits_, --, --, --,
   {{0x660d0dc3,0x67244abd,0x79440260,0x322b0746}},	//   _tsak, _gnij, _kòwo, лізм_,
   {{0x6d4800f5,0x6d5a2895,0x660d7544,0x776d008c}},	// [7a30] _olda, _omta, _usak, _ijax,
   {{0x21030324,0x32097545,0xf2df016e,0x30a71285}},	//   रजेश_, rway_, _glân_, срав,
   {{0xe4ee0bc1,0x3f1502f2,0xdb0100a0,0x53351126}},	//   _जाति_, ждес, _sulí, _дент,
   {{0x6d480291,0x29055b67,0xc7b302b5,0x3cfb000c}},	//   _alda, zela_, לבע_, ल्ने_,
   {{0x395e7546,0xd01000b5,0x00000000,0x00000000}},	//   kits_, ولے_, --, --,
   {{0xfe7000d1,0x527a0122,0x29057547,0x6d5a0312}},	//   ردن_, _כנרא, xela_, _cmta,
   {{0x395e7548,0x7ae929ca,0x4fc40f9d,0x00000000}},	//   dits_, tget, _нста, --,
   {{0xa3cb0d00,0xe9d913f9,0x80de00c8,0x29057549}},	//   रीय_, аки_, ন্দ্, wela_,
   {{0x2905754a,0x1de0175f,0x7f490024,0xc9a668be}},	//   tela_, _नियत, _ileq, овые_,
   {{0x395e754b,0x6724754c,0xe8f613ad,0x7ae9754d}},	//   gits_, _snij, оль_, sget,
   {{0x2905754e,0x1cb80789,0xa3cb0141,0xc90900b4}},	//   rela_, _طالب_, रीम_, _वसीम_,
   {{0xbf870019,0x23690a66,0x6d4309bd,0x7f49009f}},	//   _điền_, jnaj_, lkna, _jleq,
   {{0x67240009,0x395e56f0,0x00000000,0x00000000}},	//   _vnij, bits_, --, --,
   {{0x395e754f,0x6d437550,0x03a611d0,0xaa880037}},	//   cits_, nkna, живо, _انهم_,
   {{0x3cfb065a,0x64a3010b,0x00000000,0x00000000}},	//   ल्ये_, дара, --, --,
   {{0x96ba0370,0xb33b0183,0x2b4d021d,0x00000000}},	//   _туку_, _piça, nhec_, --,
   {{0xa3cb02b4,0x00000000,0x00000000,0x00000000}},	// [7a40] रीब_, --, --, --,
   {{0x601a170e,0x6d430223,0x00000000,0x00000000}},	//   ицер_, jkna, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfcf11c0,0x1e8600c9,0x0cb40ed1,0x4eba0033}},	//   ئين_, олем, ुर्म, ুল্ল,
   {{0xdd8f00f8,0x00000000,0x00000000,0x00000000}},	//   چون_, --, --, --,
   {{0xdd8f0071,0x00000000,0x00000000,0x00000000}},	//   نون_, --, --, --,
   {{0x2240006c,0x395e7551,0xfbcf017e,0x7f497552}},	//   lyik_, vits_, نتي_, _fleq,
   {{0x3ce001d6,0x21380009,0x657c011e,0x5a343cc0}},	//   şiv_, _horh_, horh, знит,
   {{0x395e0495,0x14bf0d91,0x6f1d0300,0xa92a00d8}},	//   tits_, ्रमण, _ósca, аіне_,
   {{0x6d437553,0x3f867554,0x23697555,0x6d5a7556}},	//   ckna, llou_, znaj_, _umta,
   {{0x2138022f,0x395e7557,0x66e600b4,0x00000000}},	//   _morh_, rits_, कलंक_, --,
   {{0x395e56f0,0x00000000,0x00000000,0x00000000}},	//   sits_, --, --, --,
   {{0x657c0c61,0x395e4460,0x23690bc9,0xbf9b0070}},	//   forh, pits_, vnaj_, ייטש,
   {{0x2369004e,0xb4d500a1,0x2240011e,0xdb080107}},	//   wnaj_, हणे_, dyik_, _sudè,
   {{0xdb01007e,0x00000000,0x00000000,0x00000000}},	//   _hulá, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23690097,0x657c00a5,0xa3d700b4,0x224000fd}},	// [7a50] rnaj_, borh, _सिक_, gyik_,
   {{0x34952f4c,0x59dd26c6,0xdb0802d7,0x00000000}},	//   _напр, _मिसर, _dudé, --,
   {{0x2fc77558,0x7f490031,0x21380124,0x98b80067}},	//   èng_, _pleq, _dorh_, órę_,
   {{0xa3cb0099,0xbf5801e0,0x00000000,0x00000000}},	//   रीण_, орії_, --, --,
   {{0x7bc80297,0xdd1401ba,0x22520067,0x2138008c}},	//   _awdu, _dĺžk, czyk_, _forh_,
   {{0x3f8601ef,0xf1c40067,0x00000000,0x00000000}},	//   alou_, _लौटन, --, --,
   {{0x6d430d0f,0xbc1900c7,0x26c2004e,0x7e6d0160}},	//   rkna, сілі_, ybko_, _ţipă,
   {{0x3f860443,0x05dc252c,0x6d434a11,0xe6b500b4}},	//   clou_, _बिलब, skna, ंडोज,
   {{0xa3cb7559,0x5d5518ea,0x6d68003e,0x00000000}},	//   रीत_, _екат, ðrað, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb01021d,0x657c755a,0xb33b00a2,0x00000000}},	//   _eulá, vorh, _niço, --,
   {{0xabfa00a5,0xe4ee1b8f,0x52aa021a,0xc6150831}},	//   _להער, _जाहि_, _कलेस, ামনা_,
   {{0xf1a70084,0xae1e0af9,0xdb011da9,0x7afb755b}},	//   _कंगन, पियन_, _gulá, mfut,
   {{0x3f860009,0x7afb2845,0xa3d70f19,0x5d79016b}},	//   zlou_, lfut, _सिख_, מאָק,
   {{0xf7460b66,0x1866151d,0x657c00d7,0xdb020176}},	//   _неко, _наши_, rorh, _bioè,
   {{0xd2aa00d8,0x7afb755c,0x21f400ab,0xdb08021d}},	//   скае_, nfut, täh_, _pudé,
   {{0xe297755d,0x00000000,0x00000000,0x00000000}},	// [7a60] зат_, --, --, --,
   {{0xf8bd14ab,0x409620b4,0x66042792,0x00000000}},	//   ोरिय, прет, _ipik, --,
   {{0x22520035,0xb53b00a5,0x2614060a,0x00000000}},	//   szyk_, _הגיש, दिकी_, --,
   {{0x2d87755e,0x00000000,0x00000000,0x00000000}},	//   elne_, --, --, --,
   {{0x539b0319,0x3eab00d5,0xbb440421,0x00000000}},	//   _ליטו, _šitá_, äämä, --,
   {{0xf98700f5,0x660401e9,0x261d0099,0x3f86755f}},	//   _سب_, _mpik, मिती_, slou_,
   {{0x69dd0038,0xa2b3018d,0x3f8600ac,0x00000000}},	//   ásen, _अलम्, plou_, --,
   {{0x2d877560,0x60ce0009,0x2a6901a0,0x63a60069}},	//   alne_, _hebm, _žaba_, _jikn,
   {{0x64430723,0x00000000,0x00000000,0x00000000}},	//   _üniv, --, --, --,
   {{0x62867561,0x63a60533,0x753a033b,0x00000000}},	//   _myko, _likn, ötzl, --,
   {{0x660400f8,0xdcf819be,0x628609dd,0x00000000}},	//   _apik, novč, _lyko, --,
   {{0x61e41851,0x63a60fdf,0x98a700b8,0x7d0a108c}},	//   kril, _nikn, _koně_, lefs,
   {{0x5fce11b5,0x6b827562,0x62860df7,0x00000000}},	//   _हौसल, _ikog, _nyko, --,
   {{0xdcf80506,0x25a52c7a,0xda650934,0x63a6013a}},	//   kovč, öll_, _تامي, _aikn,
   {{0x66047563,0xd404111d,0x61e47564,0x78fb00a5}},	//   _epik, няти, eril, _לפגו,
   {{0xc6a7081b,0x62867565,0xb33b0132,0x53347566}},	//   _эрки, _byko, _viço, нест,
   {{0xd7f8002d,0xe6c30355,0xdb020118,0x63a60345}},	// [7a70] ltă_, _व्यङ, _cioé, _dikn,
   {{0x69c4003c,0x69c000a5,0xd0ab0369,0x62860523}},	//   _ħiel, ipme, стад_, _dyko,
   {{0xd7f80012,0xdcf800cd,0x61e47567,0x00000000}},	//   ntă_, govč, aril, --,
   {{0xa2bc0380,0x6b820027,0x00000000,0x00000000}},	//   षुद्, _nkog, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc2120122,0x61e2008b,0xf1b2011d,0x14bf022e}},	//   _שהם_, šolc, _בסך_, ्रिण,
   {{0x3b9503e6,0xa194005f,0x00000000,0x00000000}},	//   мјит, _чарч, --, --,
   {{0x2bde00b4,0x79880051,0x60dc0207,0x00000000}},	//   _नटरा, eldw, _zdrm, --,
   {{0x14bf00e7,0x6ca703d0,0x6609027d,0x00000000}},	//   ्राण, _ереж, çekl, --,
   {{0x7afb310f,0x00000000,0x00000000,0x00000000}},	//   sfut, --, --, --,
   {{0x661d0031,0x66047568,0x00000000,0x00000000}},	//   evsk, _spik, --, --,
   {{0xd90f0332,0x501a0122,0xa5b205e7,0x61e47569}},	//   ئیں_, קורו, _इंदौ, yril,
   {{0xe8ee3a49,0x6b892129,0x63a6756a,0xd7f800af}},	//   _ил_, mleg, _rikn, ată_,
   {{0x6b89756b,0x61e4756c,0x4421756d,0x6286435e}},	//   lleg, vril, _brh_, _ryko,
   {{0xe5a30b30,0x35a3253f,0x4421756e,0xd7f8002d}},	//   тири, тарг, _crh_, ctă_,
   {{0x6b892129,0x61e4391b,0x6b9b00d7,0x378701d3}},	//   nleg, tril, nmug, _общо_,
   {{0x6f190297,0x63a6756f,0x61e47570,0xf26a45ae}},	// [7a80] ddwc, _vikn, uril, циал_,
   {{0x6286290b,0xa3cb22a7,0x92ce0033,0x61e435f9}},	//   _vyko, रीह_, রলে_, rril,
   {{0x6286006a,0xa00a211b,0x6b89200b,0x1de0073f}},	//   _wyko, تقال_, kleg, _निहत,
   {{0x61e40d7c,0x0e66081b,0xc4fa006c,0xddc20035}},	//   pril, мкен, _اٹھا_, czoś,
   {{0x6b890044,0x60ce006d,0xf2d30070,0xdcfa035f}},	//   dleg, _tebm, _בער_, _jitħ,
   {{0xa3cb1ef5,0x6b820533,0xdcfa009f,0x4c940421}},	//   रीव_, _skog, _mitħ, нилс,
   {{0x6b892ffb,0x69cb0118,0x656e0079,0xf1a70761}},	//   fleg, _awge, inbh, _कूटन,
   {{0x6b892129,0x6e200009,0x6b9b011e,0xda140274}},	//   gleg, _trmb, gmug, едињ,
   {{0x201e003d,0xf1bf0098,0xdcfa0069,0x3cfb0ec5}},	//   _štih_, _grád_, _nitħ, ल्हे_,
   {{0xd8f802ce,0x0d4a1ee1,0x799a006d,0x6b890069}},	//   чної_, _بشري_, umtw, aleg,
   {{0x79887571,0x6b820207,0x2d4b11cb,0x93c500cc}},	//   rldw, _tkog, _køen_, _chắ,
   {{0xb7d80332,0x6b890035,0xd7f8002d,0x69c051f2}},	//   _ہوتا_, cleg, rtă_, ppme,
   {{0xd7f80043,0xdb087572,0x3cfb00a1,0x56940d13}},	//   stă_, _judí, ल्वे_, кают,
   {{0xd7f8002d,0x6b807573,0xf80600af,0x09120033}},	//   ptă_, lomg, _жчин, ়াহু_,
   {{0xe7e50755,0xdb1a000d,0x00000000,0x00000000}},	//   _किया_, _atté, --, --,
   {{0x14bf0b35,0x4421231d,0x56950036,0x4916000c}},	//   ्रहण, _vrh_, _пайт, भएको_,
   {{0xdb0800ac,0x00000000,0x00000000,0x00000000}},	// [7a90] _nudí, --, --, --,
   {{0x290c7574,0x4421024e,0xddc2004e,0xdb01033b}},	//   neda_, _trh_, szoś, _zulä,
   {{0xa3cb02e4,0xdb087575,0x44214565,0x00000000}},	//   रीश_, _audí, _urh_, --,
   {{0x290c01d3,0xdb080097,0xc49a011d,0x14bf012f}},	//   heda_, _budí, _משתת, ्रवण,
   {{0x290c7576,0xa3cb0066,0x7bda0118,0x1622198f}},	//   keda_, रीर_, _avtu, मियर_,
   {{0x290c029d,0x61ed7577,0xdb0800ee,0x00000000}},	//   jeda_, mual, _dudí, --,
   {{0x6b894290,0x290c00d8,0x61ed00c3,0x1b180033}},	//   tleg, deda_, lual, থানে_,
   {{0x49c90171,0x394e0024,0x70942aa9,0xe0d000fd}},	//   плин_, _alfs_, _расф, _مزہ_,
   {{0x6b896037,0x7d010283,0x61ed5f00,0xda1604aa}},	//   rleg, _tbls, nual, तिगत_,
   {{0xd102073f,0x6b897578,0x290c0a47,0x6b9b0c75}},	//   र्पण_, sleg, geda_, smug,
   {{0x6b897579,0xef19003c,0x5ed20033,0x1da80354}},	//   pleg, _każ_, _হাতে, _छूटत,
   {{0xa8220088,0x4426124b,0xb33b00da,0x61ed06a2}},	//   اکون, _čo_, _diçk, kual,
   {{0x290c757a,0xdb0801dd,0xef19007a,0xbebd004b}},	//   beda_, _xudí, _maż_, _anūk,
   {{0x61ed757b,0x93c500e2,0x00000000,0x00000000}},	//   dual, _thắ, --, --,
   {{0xf1bf0514,0xa3cb00a1,0x232a757c,0x00000000}},	//   _atá_, रील_, пови_, --,
   {{0x3ead757d,0xf7720088,0xc7960f8f,0x00000000}},	//   _nget_, _حات_, _ярлы, --,
   {{0x3126081b,0x91e3039e,0x6abd008e,0x00000000}},	// [7aa0] ндаг, лоте, ðsfy, --,
   {{0xdce300d8,0x9657011d,0x26d20139,0x79811f6c}},	//   monė, _נשיא_, _heyo_, nolw,
   {{0xdd99021e,0x4f0a290a,0x00000000,0x00000000}},	//   _epňk_, знен_, --, --,
   {{0x60c306d0,0xa3e50722,0x61ed00d7,0x798100e9}},	//   ınma, _नित_, bual, holw,
   {{0x61ed0464,0x79812d79,0xef19009f,0x753e0051}},	//   cual, kolw, _daż_, _kopz,
   {{0x3ead0bf3,0x28bf012f,0x3cfb0b35,0x00000000}},	//   _eget_, _श्लि, ल्ले_, --,
   {{0xdee6757e,0x290c757f,0xd007341b,0x9c7c0097}},	//   _пови, veda_, _пере_, _odče,
   {{0x2d850723,0x7bd8071b,0x8fa34275,0x26d26b23}},	//   _ekle_, rsvu, _басе, _neyo_,
   {{0x290c0124,0x6b807580,0x8ccb0067,0x49740368}},	//   teda_, romg, _सड़को, клис,
   {{0x0e6300af,0xccf80355,0x00000000,0x00000000}},	//   _скун, _změn_, --, --,
   {{0x61ed7581,0x290c0936,0x315702b5,0xf1bf00fe}},	//   zual, reda_, גיין_, _krác_,
   {{0x6d4a7582,0x00000000,0x00000000,0x00000000}},	//   lkfa, --, --, --,
   {{0x7d1a066e,0x290c481c,0xd9464599,0xb6044025}},	//   _kats, peda_, _педи, лярк,
   {{0xd90e00d1,0x00000000,0x00000000,0x00000000}},	//   _اید_, --, --, --,
   {{0x7d1a7583,0xa3cb0e04,0x15ed0035,0xc88501ae}},	//   _mats, रीं_, _जमकर_, ößte_,
   {{0x3ea92209,0xb33b0095,0x26d201ed,0xe3b02489}},	//   žati_, _kiçi, _geyo_, صرف_,
   {{0xb5a711aa,0x672d0054,0xf7701a95,0x00000000}},	// [7ab0] _прой, _inaj, _داو_, --,
   {{0x7d1a7584,0x61ed7585,0x35f80037,0xef190069}},	//   _nats, rual, _أريد_, _saż_,
   {{0x61ed7586,0xdcb10023,0x34bf00b4,0x26d20103}},	//   sual, _bản_, ्रीद, _yeyo_,
   {{0xa3cb021a,0x2d8500ac,0x00000000,0x00000000}},	//   रीः_, _skle_, --, --,
   {{0x5f740180,0x7d1a6f7b,0x672d7587,0x61ed7588}},	//   دالر, _bats, _mnaj, qual,
   {{0xdb080176,0xcc89141d,0x2d5800af,0x00000000}},	//   _audà, мбле_, ничь_, --,
   {{0x2ef50798,0x1af50083,0x4cca0033,0xd045013b}},	//   _извр, _আসবে_, _রাখু, yahə,
   {{0xb33b1249,0x3eb900d0,0x6d4a0a1f,0x672d073a}},	//   _biçi, _üst_, akfa, _nnaj,
   {{0xfe7300f5,0x7d1a7589,0xf2d40070,0xdb080183}},	//   _صدر_, _fats, נעץ_, _sudã,
   {{0x7cd90a86,0x98a52c49,0x6d4a758a,0x39452eb3}},	//   _آواز_, кипе, ckfa, тног,
   {{0xcb1500af,0x798100e5,0x1ae30831,0x00000000}},	//   _афлы, rolw, ক্ষে_, --,
   {{0xe7f20302,0x66161f49,0x6f1b221d,0x7981758b}},	//   _अमरा_, _psyk, _jauc, solw,
   {{0x7d1a758c,0xa3d40026,0xd04500a8,0xdb2600fd}},	//   _yats, सीन_, rahə, _جونی,
   {{0x7dd8004f,0x6f1b758d,0x672d758e,0xd04700a8}},	//   _húsá, _lauc, _enaj, şməs,
   {{0x94790202,0x6b6700e0,0x69db05ee,0xdb0807c0}},	//   есту_, _gègè, lsue, _hudá,
   {{0x6f1b2531,0x672d0009,0x00000000,0x00000000}},	//   _nauc, _gnaj, --, --,
   {{0x03a32846,0x69db758f,0xe8190edf,0xe1fa1eb9}},	// [7ac0] рито, nsue, धिका_, ьга_,
   {{0x672d7590,0x25d70779,0xe2974025,0xd5b70299}},	//   _znaj, _שוין_, тау_, _इंतज,
   {{0x7d1a7591,0x6f1b7592,0xf1bf00a0,0xc05901e0}},	//   _rats, _bauc, _prác_, нії_,
   {{0x6f1b7593,0x7d1a543e,0xdee6036e,0x69db2726}},	//   _cauc, _sats, тоди, ksue,
   {{0xed5a4cd3,0x7d1a7594,0x00000000,0x00000000}},	//   мод_, _pats, --, --,
   {{0xde930202,0xe7f20066,0xdb0801f7,0x00000000}},	//   јашњ, _अमला_, _sudà, --,
   {{0x6f1b7595,0x7d1a00c3,0x3f6a0c94,0x6d4a003e}},	//   _fauc, _vats, _живо_, rkfa,
   {{0x7d1a7596,0x6f1b7597,0x5b147598,0xdb0101ef}},	//   _wats, _gauc, умит, _zulú,
   {{0x7d1a7599,0x6f021a0c,0x9cf60043,0x00000000}},	//   _tats, mfoc, _ачеш, --,
   {{0x672d0024,0x7d1a01e8,0x35dc0067,0x00000000}},	//   _snaj, _uats, _बिज़, --,
   {{0x96f90fa7,0x00000000,0x00000000,0x00000000}},	//   нент_, --, --, --,
   {{0x6f021d35,0x69db0453,0x00000000,0x00000000}},	//   nfoc, bsue, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34bf021a,0x64bf111a,0x00000000,0x00000000}},	//   ्रेद, ्रेश, --, --,
   {{0x1af50083,0x893700a5,0x44250079,0xa2a52a06}},	//   _আসতে_, _ברגע_, íl_, चेन्,
   {{0x291c06d0,0x672d000e,0x3a2601b4,0x97a41ac5}},	//   _hava_, _unaj, _krop_, _крыл,
   {{0x291c759a,0x6f1b01ae,0x2018759b,0xceb90355}},	// [7ad0] _kava_, _rauc, _asri_, _jaře_,
   {{0x291e006c,0xe3b0006c,0x291c759c,0x00000000}},	//   ndta_, صرہ_, _java_, --,
   {{0x60d700a8,0x7ae20086,0x6f02027a,0x6b5e0029}},	//   raxm, _odot, ffoc, lūgu,
   {{0x7ae270f2,0x26d90036,0x7f400176,0xe7e507b5}},	//   _ndot, naso_, _comq, _किसा_,
   {{0xdef815eb,0xfce51470,0x6f1b759d,0x201e011c}},	//   тых_, голо, _vauc, _štit_,
   {{0x7ae2759e,0xe3b003fc,0x2249179a,0x0d8412ea}},	//   _adot, _دری_, myak_, алін,
   {{0xdb08759f,0x26d975a0,0x6f1b01ae,0x7ae20024}},	//   _sudá, kaso_, _tauc, _bdot,
   {{0xe4e30bc1,0x69db06a2,0x7ae201ef,0x291c00ab}},	//   कृति_, tsue, _cdot, _aava_,
   {{0x2249203f,0x6ec900b4,0x291c2506,0xdea1006c}},	//   nyak_, _ह्यु, _bava_, _ایشی,
   {{0x291c1ab8,0x7ae206a2,0x2369006f,0x6ce400d8}},	//   _cava_, _edot, hiaj_, _віце,
   {{0x69db75a1,0x3a260120,0x6d4175a2,0x291c678e}},	//   ssue, _erop_, _iola, _dava_,
   {{0xf0920122,0x26d9018e,0xdb0800b5,0x22490159}},	//   מני_, gaso_, _tudá, kyak_,
   {{0x09e50086,0x291c325f,0xdb0b0031,0x55f61482}},	//   _солн, _fava_, _ligë, ычну,
   {{0x6d4175a3,0x60d5156f,0x22496e35,0x14a50066}},	//   _jola, _nezm, dyak_, _गृहण,
   {{0xc9840043,0x8cca0099,0x5faf035d,0x26d90065}},	//   _туци, _स्फो, _जंगल, baso_,
   {{0x26d90b4c,0x7c2e75a4,0x6d41034d,0x2b4d07e7}},	//   caso_, _ábre, _lola, nkec_,
   {{0x60d575a5,0xb22600d8,0x201800a8,0x291c313a}},	// [7ae0] _bezm, ымал, _ssri_, _yava_,
   {{0x6d4175a6,0x205632a6,0x2ecc052b,0x291c002a}},	//   _nola, лтер, ार्त, _xava_,
   {{0xd46a4a7f,0xdb0b0132,0x6f020051,0xb4d043fd}},	//   _чине_, _vigê, tfoc, शरी_,
   {{0xf1bf365a,0x6d414fb4,0x22490118,0x00000000}},	//   _irán_, _aola, byak_, --,
   {{0x6d4175a7,0xdee30be8,0xf1bf00ee,0x00000000}},	//   _bola, сочи, _hrán_, --,
   {{0x3f8f00ab,0x63800139,0x60d50225,0xa3b8073f}},	//   algu_, _dânş, _gezm, _चढा_,
   {{0x69c2152b,0xfbaa004c,0xab5c0029,0x7f400221}},	//   _stoe, нтий_, _atļa, _tomq,
   {{0x6d410514,0x3a2675a8,0x291c75a9,0x26d901b7}},	//   _eola, _prop_, _sava_, xaso_,
   {{0xdd8f0ef2,0x6d4175aa,0x26d9027a,0x00000000}},	//   _کول_, _fola, vaso_, --,
   {{0xdb0b0310,0xa9670279,0x00000000,0x00000000}},	//   _ligè, лиња_, --, --,
   {{0x31370122,0x291c0260,0xb8dc22d4,0x23690221}},	//   אריך_, _vava_, _अल_, yiaj_,
   {{0x3a2675ab,0x6d4175ac,0xa3b80299,0x236901e8}},	//   _trop_, _zola, _चढ़_, xiaj_,
   {{0x291c75ad,0x26d975ae,0xe66775af,0xb5fb00b5}},	//   _tava_, raso_, утно, zzáf,
   {{0x040e0b52,0x26d946c7,0x6d5875b0,0xf65f01b4}},	//   হিনী_, saso_, nhva, lbæk_,
   {{0x26d92487,0x88bb02b5,0x60d575b1,0x00000000}},	//   paso_, _אזוי, _rezm, --,
   {{0xe3150274,0xdce30409,0x98bc0107,0x00000000}},	//   јмањ, vinč, _movč_, --,
   {{0x236937e6,0x070500b4,0xdb0b0118,0x6234002d}},	// [7af0] riaj_, ष्णव_, _digè, бету,
   {{0x7c283e11,0x2369004e,0x660d0d0d,0xdce30207}},	//   _ordr, siaj_, _ipak, tinč,
   {{0xa3cb017a,0x30151dd0,0xd0110df3,0x60d50187}},	//   रीख_, рдер, تلا_, _vezm,
   {{0xdce3010b,0x398b082b,0x00000000,0x00000000}},	//   rinč, løst_, --, --,
   {{0x6d4175b2,0x3219022e,0xa91c01ba,0x7c2875b3}},	//   _pola, _ussy_, voľn, _ardr,
   {{0x660d2b38,0x6da56bde,0x61ed0211,0xdce31710}},	//   _mpak, шила, mral, pinč,
   {{0xeab1004f,0x628f00d7,0x8cc10162,0x3f8601ef}},	//   يعة_, _hyco, रुषो, boou_,
   {{0x660d75b4,0x0b451126,0x05b50026,0xd5b50099}},	//   _opak, рнин, ंदाब, ंदाज,
   {{0x5f4409b9,0x6d415a06,0x660d010d,0x61ed048f}},	//   _انقل, _tola, _npak, nral,
   {{0x6d580187,0x63af011c,0x61ed75b5,0x6e2904fb}},	//   chva, _licn, iral, _ireb,
   {{0x2d8775b6,0x660d75b7,0x200101ca,0x61ed01ba}},	//   mone_, _apak, nthi_, hral,
   {{0x61ed75b8,0x6e2975b9,0x3b1f012f,0x63af0211}},	//   kral, _kreb, qduq_, _nicn,
   {{0x0ab410ad,0x7f3a02b5,0xbb84004f,0xdb0b75ba}},	//   _احمد, דערו, _الني, _nigé,
   {{0x98a51126,0x2d8775bb,0x18a55195,0x3dd70033}},	//   _киле, none_, _калм, _সমাল,
   {{0x64a65446,0x6f0975bc,0x660d0009,0x61ed75bd}},	//   рава, _obec, _epak, eral,
   {{0x2d8775be,0x2bd7012f,0x58940037,0x0cd101c0}},	//   hone_, णीया, _اجهز, हरुम,
   {{0x2d8775bf,0xa5bb01dd,0x52aa75c0,0xdb0b0392}},	// [7b00] kone_, nvól, твам_, _vigè,
   {{0x2d8775c1,0x29050103,0xe3ba00c3,0xf1bf00e2}},	//   jone_, nfla_, _ибо_, _trán_,
   {{0x2d8775c2,0x46ba0299,0xd10206bc,0x6e2975c3}},	//   done_, _इलाह, र्षण_, _areb,
   {{0x61ed00be,0x6e2975c4,0xf1bf1dab,0xdb0b00a2}},	//   bral, _breb, _král_, _figé,
   {{0x2d8775c5,0x6e290df1,0x6d5875c6,0x63a439a6}},	//   fone_, _creb, thva, mmin,
   {{0x2d8775c7,0xb5fb006c,0xcbe64a79,0x63a475c8}},	//   gone_, szág, ации, lmin,
   {{0x8fa66cbe,0x317b016b,0x6ca302fb,0x69c92069}},	//   _ваве, _סאלד, оръж, epee,
   {{0xa3cb02e4,0x6d580506,0x6e290282,0x00000000}},	//   रीट_, shva, _freb, --,
   {{0x63a475c9,0x6e2975ca,0x2d8775cb,0x998201c0}},	//   imin, _greb, bone_, íků_,
   {{0x63a475cc,0x3eab00ac,0x00000000,0x00000000}},	//   hmin, _úcta_, --, --,
   {{0xeb361a95,0x63a475cd,0x00000000,0x00000000}},	//   _پراخ, kmin, --, --,
   {{0xdce30029,0x8cca05f8,0x7bca033b,0x61ed75ce}},	//   minā, _स्तो, mpfu, yral,
   {{0xdce30029,0x7bca00a5,0x63a4190f,0x00000000}},	//   linā, lpfu, dmin, --,
   {{0x61ed048f,0x00000000,0x00000000,0x00000000}},	//   vral, --, --, --,
   {{0x6b552edc,0x63a40ea5,0xf36775cf,0xd7fa002d}},	//   _hága, fmin, атан, _рул_,
   {{0x2d8775d0,0xe7380202,0x63a4043d,0x63b7013c}},	//   zone_, _већ_, gmin, _vuxn,
   {{0x660d75d1,0x2d8775d2,0xa3cb1db9,0xf1bf0fb5}},	// [7b10] _upak, yone_, रीज_, _grál_,
   {{0x61ed75d3,0x63a475d4,0x2001022e,0xdb0b2278}},	//   rral, amin, tthi_, _vigé,
   {{0x63a475d5,0x61ed75d6,0x2b810035,0x6f0100b5}},	//   bmin, sral, rócz_, jábó,
   {{0x6e290bc9,0xdce30080,0x2d8775d7,0x200175d8}},	//   _preb, dinā, wone_, rthi_,
   {{0xfe700125,0x1af50083,0x9f04026b,0x200100bf}},	//   وده_, _আসলে_, تونو, sthi_,
   {{0x6e29011c,0x9f050987,0x00000000,0x00000000}},	//   _vreb, _گورو, --, --,
   {{0x2d8775d9,0xdce100d5,0xb5fb002a,0x80dc0387}},	//   rone_, _umlč, nzáb, _फ़ते,
   {{0x6e2975da,0x9f054cbc,0x00000000,0x00000000}},	//   _treb, _دورو, --, --,
   {{0x2d8775db,0xaa490086,0x6e2901d5,0x6b550952}},	//   pone_, уппа_, _ureb, _cága,
   {{0x69c90086,0x63a475dc,0xdce300ea,0x6b4e0284}},	//   rpee, zmin, binā, _lùgh,
   {{0x1b1f00c8,0x69c975dd,0xdce30080,0x7c95004f}},	//   ভাবে_, spee, cinā, _الاص,
   {{0x63a400a8,0x69c975de,0x6b5575df,0x2a690124}},	//   xmin, ppee, _fága, _žabu_,
   {{0x4e790070,0x00000000,0x00000000,0x00000000}},	//   ראָצ, --, --, --,
   {{0x04460923,0x28bf021a,0x9c7c00ee,0x6b890973}},	//   бегн, _श्चि, _odčl, loeg,
   {{0x63a4007c,0x857902fb,0x6845002d,0x00000000}},	//   tmin, рсят_, _ынка, --,
   {{0x675600bf,0x6b890b0d,0x63a475e0,0xe61a0036}},	//   _دختر, noeg, umin, _бди_,
   {{0xdce30080,0x78c6006c,0x6b4e0284,0x6d8d213c}},	// [7b20] zinā, _érvé, _dùgh, núas,
   {{0x1aff0033,0x05b5021a,0x00000000,0x00000000}},	//   ্যিই_, ंदरब, --, --,
   {{0xd8da02b5,0x4fea12a2,0x251b025a,0x6b8901ed}},	//   רקער, умен_, _גויא, koeg,
   {{0x656e70cc,0xdce300ea,0x644e010b,0x27fa00d4}},	//   libh, vinā, mybi, _åpne_,
   {{0x527502c4,0xa3d40963,0x644e75e1,0x00000000}},	//   _дуру, सीर_, lybi, --,
   {{0xdce300ea,0x6d8d01ef,0x00000000,0x00000000}},	//   tinā, dúas, --, --,
   {{0x61f6027d,0x644e00c7,0x3157016b,0x00000000}},	//   luyl, nybi, _פילן_, --,
   {{0xf06375e2,0xdce30029,0x6b552ec0,0xa06700af}},	//   _эксп, rinā, _pága, _уаса_,
   {{0xdce30029,0x61f60225,0xdd920cd1,0xdb020523}},	//   sinā, nuyl, _فور_, _nioå,
   {{0x6b550987,0x26c2004e,0x644e010b,0x290a01ba}},	//   _vága, ecko_, kybi, ýba_,
   {{0x61f601a2,0x238100d8,0x656e0098,0x00000000}},	//   huyl, lėje_, dibh, --,
   {{0x644e010b,0x290200b8,0x61f6043d,0x7988016e}},	//   dybi, řka_, kuyl, sodw,
   {{0x238101c8,0xa25b021d,0x60de0345,0x00000000}},	//   nėje_, _afôn, kapm, --,
   {{0x67d40e75,0x2b4675e3,0x6d5d010b,0x6b4e009e}},	//   _доку, _hooc_, _įsak, _sùgh,
   {{0xd82f081b,0x60de00d7,0x64b90066,0xa3d422c7}},	//   _ээ_, dapm, _आलीश, सील_,
   {{0x443f01cc,0xa91c016f,0x5b7b0070,0x92b70037}},	//   ću_, koľk, ָרמא, صحرا,
   {{0xdb08016f,0xe8200b54,0x2b4600d5,0xf1bf007e}},	// [7b30] _budú, यिका_, _mooc_, _irák_,
   {{0xa2a51371,0xba9b00a5,0x1a9b016b,0xa25b099e}},	//   चेष्, רסמי, רימע, _ffôn,
   {{0x442775e4,0x691e009f,0x5fa40099,0x00000000}},	//   _én_, _għeż, _ओळखल, --,
   {{0xdddb0076,0x6235002d,0xd7fb0070,0x00000000}},	//   _využ, _дему, רהאל, --,
   {{0x6b8904ce,0xf1272539,0x9e070fa7,0x9f5800b5}},	//   voeg, _льво, счел, _apró_,
   {{0x629d00ea,0x00000000,0x00000000,0x00000000}},	//   _izso, --, --, --,
   {{0xdca21b96,0xa4fc0070,0x8c420382,0x00000000}},	//   маши, אלוט, деще, --,
   {{0x6d8d0391,0x1b490f8c,0x39e90274,0x238100c7}},	//   túas, рзии_, адио_, bėje_,
   {{0x6b890223,0xfaf900ea,0x499000b5,0x644e0067}},	//   roeg, rgū_, کیور, zybi,
   {{0x764f004e,0x00000000,0x00000000,0x00000000}},	//   dycy, --, --, --,
   {{0x07a61958,0xe73a029f,0x6b8900be,0x00000000}},	//   жанн, аен_, poeg, --,
   {{0x16aa0896,0x656e012f,0x644e00c7,0x00000000}},	//   ивни_, wibh, vybi, --,
   {{0x656e75e5,0xf1b500ab,0x2bb500ea,0x65a0033b}},	//   tibh, _अंगन, _vācu_, höhe,
   {{0x644e75e6,0xdcf80355,0x7afb75e7,0x9f410055}},	//   tybi, dově, lgut, fshë_,
   {{0x656e75e8,0xa34a02fb,0x394775e9,0x00000000}},	//   ribh, азва_, _ions_, --,
   {{0x42ca75ea,0x7afb75eb,0xe81e0084,0x394700d7}},	//   рган_, ngut, _बनता_, _hons_,
   {{0xb1466c89,0xc8780095,0x00000000,0x00000000}},	// [7b40] онал, mağa_, --, --,
   {{0x67240054,0x40964a35,0x21a30370,0x39470282}},	//   _haij, орет, диум, _jons_,
   {{0x64a6196c,0x672475ec,0x3cfe02d7,0xb17b01ff}},	//   _фана, _kaij, _rctv_, _tvån,
   {{0x25b700d1,0x2381010b,0x672401ed,0x394700a2}},	//   _دهید_, tėje_, _jaij, _lons_,
   {{0x67240080,0x3cfe0118,0xeda62641,0x6fe00098}},	//   _maij, _pctv_, ошко, _bácá,
   {{0x61e4037a,0x6b55002a,0xfd0f0312,0x8bc616b6}},	//   msil, _bágo, نجى_, осид,
   {{0x61e475ed,0x6b5c0248,0x3cfe0023,0x60dc009f}},	//   lsil, _lége, _vctv_, _ierm,
   {{0x672475ee,0x8cca164f,0x80d8046c,0x00000000}},	//   _naij, _स्रो, यरवे, --,
   {{0x394775ef,0x60dc75f0,0x61e475f1,0xc87800a8}},	//   _bons_, _kerm, nsil, dağa_,
   {{0x60dc0ce8,0x61e40196,0x6b551e15,0xf1bf0168}},	//   _jerm, isil, _fágo, _dráh_,
   {{0xed590009,0x6d5a0086,0x61e405f9,0x394775f2}},	//   _dužd_, _ilta, hsil, _dons_,
   {{0xd6db282d,0x6d4875f3,0x6724006d,0x61e475f4}},	//   што_, _hoda, _caij, ksil,
   {{0x6d4875f5,0x394775f6,0x61e40865,0x6b5c00b5}},	//   _koda, _fons_, jsil, _cége,
   {{0xd5b801c8,0x6d4875f7,0x02d30026,0x7ae010ab}},	//   ўся_, _joda, तर्न, lamt,
   {{0x29c00028,0x61e64f97,0xdb1a017b,0x2d4b0b3e}},	//   _hòa_, _avkl, _ettå, _køer_,
   {{0x7ae075f8,0x533411ca,0x6d4800f1,0x61e475f9}},	//   namt, мест, _loda, fsil,
   {{0x60dc49ec,0x776d1a71,0x6d5a75fa,0x6d48007c}},	// [7b50] _berm, _imax, _olta, _ooda,
   {{0x6d4875fb,0x7d180690,0x60dc0ce8,0x7ae00008}},	//   _noda, jevs, _cerm, hamt,
   {{0x60dc75fc,0x3f150145,0x7ae075fd,0xd7f8002d}},	//   _derm, здес, kamt, nuă_,
   {{0x442100da,0x441a02da,0xdcf8000c,0x61e40312}},	//   _ish_, _פורס, pově, bsil,
   {{0x60dc75fe,0x6d4875ff,0x433a0d85,0xed590c8c}},	//   _ferm, _boda, _הערב, _luže_,
   {{0x60dc7600,0x8d650f28,0xdb0b7601,0xabd50166}},	//   _germ, явле, _vigí, пциј,
   {{0x6d487602,0x7aef01ef,0x8cc1021a,0x2d4b008c}},	//   _doda, ócto, रुगो, _søes_,
   {{0xe9d9172a,0x6d5a7603,0xb5fb00b5,0x39471762}},	//   бки_, _elta, zzáa, _sons_,
   {{0x394701f7,0x7afb7604,0x4421003e,0x6d484a55}},	//   _pons_, rgut, _lsh_, _foda,
   {{0x395e0052,0x7afb02b3,0x60dc0391,0x6b5c00b5}},	//   ghts_, sgut, _xerm, _rége,
   {{0x7d7a02b5,0xe72a00af,0x661d0067,0x60c502b1}},	//   _פרעג, бонд_, ewsk, ichm,
   {{0x6d480a75,0xed590254,0x6f1900e9,0x7ae00fa0}},	//   _zoda, _duže_, newc, camt,
   {{0xe8ee3449,0x39471691,0x44217605,0x45d3010b}},	//   _пл_, _tons_, _ash_, ноўс,
   {{0x69d9007a,0x395e7606,0x6b5c006c,0x88bc00b8}},	//   _iwwe, chts_, _vége, nděl,
   {{0x68e17607,0x03a60214,0x7e620036,0xf1b500b4}},	//   mald, зиво, zzop, _अंजन,
   {{0x61e47608,0x442112d9,0x68e17609,0x97ae00a8}},	//   tsil, _dsh_, lald, üşdü,
   {{0xd29a01e0,0x44210055,0x6f19016e,0x7d18760a}},	// [7b60] стві_, _esh_, dewc, yevs,
   {{0x68e1760b,0x64a6760c,0x4421002a,0x69d90107}},	//   nald, _напа, _fsh_, _mwwe,
   {{0x60dc3fbd,0x14d70070,0x73e30421,0x351b00a5}},	//   _verm, _מויל_, _поэз, _פוטנ,
   {{0x6d48760d,0x68e1760e,0x60c523d5,0x61e4760f}},	//   _soda, hald, achm, psil,
   {{0x6d487610,0x68e17611,0xf3f10019,0xa3b500b1}},	//   _poda, kald, ợc_, _छूट_,
   {{0x63be7612,0x68e10093,0xdd8f0698,0xb146002d}},	//   _kupn, jald, هون_, _энгл,
   {{0x7d183e17,0x7ae07613,0x6d5a1dab,0x68e17614}},	//   revs, tamt, _vlta, dald,
   {{0xed597615,0x5a3406c2,0xad6600d1,0x207b0070}},	//   _ruže_, днит, _کاره, _האלא,
   {{0x63be029d,0x6d4815b7,0x68e120f4,0x7ae07616}},	//   _lupn, _toda, fald, ramt,
   {{0x7ae06921,0x68e17617,0x237f00b8,0x776d01ef}},	//   samt, gald, čuji_, _smax,
   {{0x69d9048c,0x7ae00254,0xa91c016f,0xdb1a2ade}},	//   _ewwe, pamt, koľv, _luté,
   {{0x29c001a5,0x68e100be,0x442101e9,0xdc3b00a5}},	//   _tòa_, aald, _rsh_, _לעבר,
   {{0x68e10291,0xf1bf0028,0x9b430312,0x9f53000d}},	//   bald, _trái_, _سنوو, édés_,
   {{0x5e5700c2,0x68e17618,0x442101f4,0x657c0221}},	//   ליכע_, cald, _psh_, gnrh,
   {{0xdb1a0b4c,0x439500d4,0xbf1c0099,0x00000000}},	//   _auté, давс, _नसून_, --,
   {{0xa87b02b8,0x88bc00b8,0x2138099e,0xdc37016b}},	//   _לאור, zděl, _anrh_, האלט_,
   {{0x248d006a,0x238100c7,0x67c806fe,0x00000000}},	// [7b70] łem_, gėja_, _děje, --,
   {{0x92cd0083,0x30a71bc0,0x00000000,0x00000000}},	//   রণে_, прев, --, --,
   {{0xb4d90963,0x60c55a42,0x7d0100d7,0x490e0355}},	//   ारी_, rchm, _rcls, त्यो_,
   {{0x60c502c9,0x68e101d7,0xdb1a00a2,0x00000000}},	//   schm, zald, _futé, --,
   {{0x7bda003c,0xe2ab00d1,0x6b8400cd,0x63be0207}},	//   _awtu, _دادن_, čigl, _zupn,
   {{0xa3d40302,0x628001c8,0x21380e8f,0x5187117a}},	//   सीक_, _žmog, _gnrh_, _хума,
   {{0xea0000e8,0x68e115d6,0x3209048f,0x69cb01ed}},	//   _đại_, vald, ltay_, _stge,
   {{0x5f9400af,0x68e17619,0xb4d900ab,0x9f5a0345}},	//   _зист, wald, ारु_, hupê_,
   {{0x3209761a,0x68e10291,0x4ea70798,0x3f8f761b}},	//   ntay_, tald, _хрва, mogu_,
   {{0x57e9761c,0xdb0b02d7,0x00000000,0x00000000}},	//   одом_, _digá, --, --,
   {{0x68e1761d,0xb17b0282,0x2b5f00e2,0x8cc808cf}},	//   rald, _avåk, phuc_, _رونق_,
   {{0x68e16260,0xe73a1e31,0x80a50067,0xb5fb01ef}},	//   sald, цем_, _करने, rzán,
   {{0x68e1761e,0xb4d9007c,0x63be0159,0x80e30033}},	//   pald, ारू_, _supn, _পান্,
   {{0x64a600d8,0x68e100a8,0x00000000,0x00000000}},	//   дага, qald, --, --,
   {{0x3f8f0006,0xaad11db1,0x9c7c023a,0x00000000}},	//   kogu_, _सभाक, _večg, --,
   {{0x130a01c8,0xf7720a72,0x224001a3,0x03a3761f}},	//   ўнай_, _جات_, txik_, висо,
   {{0x3209011e,0xe2972e76,0x2fcd01cc,0xb5fb0f56}},	// [7b80] gtay_, дат_, _čega_, nzál,
   {{0x6b5c7620,0x238100c7,0x00000000,0x00000000}},	//   _méga, rėja_, --, --,
   {{0x6b5c02e1,0x40961682,0x9c7c00f4,0x7f46010b}},	//   _léga, фрат, _keče, межж,
   {{0x2bc40299,0x3f8f7621,0xba4500fe,0x00000000}},	//   _लंबा, gogu_, _klůč, --,
   {{0x9c7c055f,0x6b5c7622,0xdee310e3,0x00000000}},	//   _meče, _néga, точи, --,
   {{0x9c7c0274,0xdfd2004f,0x1ea901b2,0xf1bf0334}},	//   _leče, _ليس_, ساني_, _práv_,
   {{0xab9402ce,0x3f8f1942,0x55770070,0x1d19010b}},	//   никі, bogu_, ועסן_, яюць_,
   {{0x9c7c6826,0x6b5c1f55,0xdb0200cc,0x00000000}},	//   _neče, _béga, _khoé, --,
   {{0x8bb30037,0x2986005f,0xdccf021a,0x00000000}},	//   خصوص, дынг, _स्वछ, --,
   {{0x6b5c00f7,0x4cd80033,0x99860207,0xdb0b0183}},	//   _déga, _ঠাকু, _broš_, _vigá,
   {{0x9cd70122,0xd0f70122,0x9c7c01f2,0x00f700a5}},	//   _חובה_, ומית_, _beče, וזים_,
   {{0x32097623,0xf1bf0237,0xd6ad0831,0x9c7c02a7}},	//   ytay_, _krát_, _ক্ষয, _večd,
   {{0x9966257f,0x9c7c0b67,0x09c80033,0x00000000}},	//   _откл, _deče, _শিকা, --,
   {{0xb4d91ede,0x88bc01c0,0xd7fa0370,0x6d587624}},	//   ारे_, zděj, _дуи_, nkva,
   {{0xa3d9007c,0x628601ed,0xf1bf0952,0x9c7c3b48}},	//   ठीं_, _axko, _suá_, _hečb,
   {{0x799a0297,0xed594340,0xf1c30026,0xe3b300b5}},	//   lltw, _muža_, _वंदन, ئرس_,
   {{0xf1bf0028,0x06ad0083,0x43943de2,0xdb02055c}},	// [7b90] _quá_, _ক্রি, татс, _choé,
   {{0x32090a21,0x51f815eb,0x1af50083,0x9c7c116d}},	//   rtay_, ьную_, _আসছে_, _zeče,
   {{0x3209010d,0x6d583e48,0x628600d5,0x3f8f7625}},	//   stay_, dkva, _exko, togu_,
   {{0x171c0070,0x6b8216c2,0x490e178c,0x0fd50035}},	//   ַווע, _njog, त्तो_, डीगढ,
   {{0x63ad7626,0x238100d8,0x3f8f00ec,0xa2f600a5}},	//   mman, lėjo_, rogu_, _אמרה_,
   {{0x11da035e,0xdca50ece,0x237f0a78,0x6b5c000d}},	//   _מחשב, нали, čuju_, _réga,
   {{0xaf0701d3,0x63ad7627,0x238100c7,0x5bb53efc}},	//   _очак, oman, nėjo_, нсиф,
   {{0x63ad7628,0xe9d90573,0xed5900cd,0x73fa016b}},	//   nman, пки_, _duža_, פּצו,
   {{0x9c7c1851,0x8cca131c,0x443e00e2,0xf8da0355}},	//   _reče, _स्को, ̣t_, णरूप,
   {{0xb4d90587,0x6b555014,0x9c7c2e37,0xb5fb1d8a}},	//   ारो_, _mági, _seče, rzál,
   {{0x06ad00c8,0x63ad7629,0x661603bc,0xb5fb006c}},	//   _ক্লি, kman, _spyk, szál,
   {{0x63ad1851,0x238100d8,0x61f602ee,0xdc0300d5}},	//   jman, dėjo_, yryl, nčít,
   {{0x9c7c1164,0x63ad1eef,0x7bc1762a,0x636300ab}},	//   _veče, dman, _hulu, _mõnd,
   {{0x6b9b762b,0x7bc1762c,0x186902fb,0x64550097}},	//   llug, _kulu, _нали_, fyzi,
   {{0x7bc1149f,0xa87902b5,0x63ad762d,0x98790070}},	//   _julu, _מאַר, fman, _מאַט,
   {{0x63ad762e,0x7bc11138,0x66250328,0xdc0301ba}},	//   gman, _mulu, ätkä, jčít,
   {{0xe1fa762f,0x7bc12090,0x45150033,0xdc0300d5}},	// [7ba0] яга_, _lulu, ায়ক_, dčít,
   {{0x63ad7630,0x7bc100c3,0x2381010b,0xe8160761}},	//   aman, _oulu, bėjo_, _तहमा_,
   {{0x5ed10b52,0xdfcf2d7c,0x63ad049a,0x7bc17631}},	//   _হয়ে, ميل_, bman, _nulu,
   {{0xeaa70514,0xed59287d,0x5de601d3,0x6b9b006d}},	//   _مع_, _ruža_, ежда, jlug,
   {{0xfe720413,0x7bc10a8a,0x00000000,0x00000000}},	//   ددا_, _aulu, --, --,
   {{0x7bc17632,0x6b820009,0xed5900cd,0xac262e50}},	//   _bulu, _sjog, _puža_, ефик,
   {{0xa0a31401,0x40950036,0x6d587633,0x6b9b2b7f}},	//   _бард, _артт, rkva, flug,
   {{0xa3e22f41,0x67c8000c,0x6d587634,0x6b9b0093}},	//   नीय_, _něja, skva, glug,
   {{0xc33300a5,0x7bc10139,0x80e30033,0x00000000}},	//   רוח_, _eulu, _পাত্, --,
   {{0x63ad3656,0x65a001ae,0x7bc17635,0x9c7c023a}},	//   zman, wöhn, _fulu, _večb,
   {{0x63ad7636,0x7bc17637,0xf71000e2,0x00000000}},	//   yman, _gulu, _vầng_, --,
   {{0xb5fb006c,0xb4d900a1,0x6f027638,0x6363007c}},	//   szám, ार्_, ngoc, _kõne,
   {{0x28d122a7,0xf71001a5,0xf8d1022e,0x9f4700f8}},	//   _द्वि, _tầng_, _द्वय, éné_,
   {{0xb524086c,0x6363007c,0xd5b80086,0xe8000437}},	//   льск, _mõne, есс_, लंदा_,
   {{0x63ad0955,0x25ba7639,0xb4d90355,0x7f98021d}},	//   tman, _dipl_, ारौ_, líqu,
   {{0x6b55763a,0x291e27df,0x63ad763b,0x238100d8}},	//   _pági, leta_, uman, rėjo_,
   {{0x20180382,0x7f980300,0x60db0506,0x9f5a000d}},	// [7bb0] _apri_, níqu, _đumb, cupé_,
   {{0x63ad14c2,0x00000000,0x00000000,0x00000000}},	//   sman, --, --, --,
   {{0x6b5c00f7,0x63ad763c,0x4ae00d91,0xdb1a0097}},	//   _négo, pman, नराव, _autí,
   {{0x7ff40180,0x291e763d,0x7eb5006c,0xb5fb00ac}},	//   اسلا, heta_, نماؤ, vzáj,
   {{0x291e763e,0x7bc1763f,0x59b20035,0xdb1a1d2b}},	//   keta_, _sulu, ीदार, _cutí,
   {{0x291e2676,0x212a09c3,0x394e003c,0x7f9802d7}},	//   jeta_, _gabh_, _nofs_, díqu,
   {{0xf1bf7640,0x7ae27641,0x9c7c02c4,0x7bc10be2}},	//   _trás_, _beot, _rečc, _qulu,
   {{0x6b5c000d,0x7ae2009e,0x7f980453,0x6e2201d5}},	//   _dégo, _ceot, fíqu, bwob,
   {{0xdcbb03ad,0x6b9b7642,0x44230189,0x7bc101cb}},	//   _еще_, rlug, hwj_, _wulu,
   {{0x7bc17643,0x69c20a8a,0xdb1a0183,0x00000000}},	//   _tulu, _duoe, _cutâ, --,
   {{0x6b9b7644,0xf7720fab,0x8cca1343,0xd7f800af}},	//   plug, لاح_, _स्टो, gră_,
   {{0x32190b88,0x00000000,0x00000000,0x00000000}},	//   _opsy_, --, --, --,
   {{0x291e7645,0xd7f80043,0x25ba1a73,0x00000000}},	//   beta_, ară_, _pipl_, --,
   {{0x5e5600c2,0xb60602c6,0x26cb0036,0x61ff00a8}},	//   דישע_, vešč, acco_, duql,
   {{0x3d09009a,0xf9900789,0x212a0037,0x68e37646}},	//   _साने_, _ابن_, _rabh_, _iend,
   {{0x68e374d8,0x6b5c00f7,0x27f800a0,0x7ae2002a}},	//   _hend, _négl, árne_, _xeot,
   {{0x68e37647,0x98bc00b8,0xe64600af,0xe29a0036}},	// [7bc0] _kend, _nově_, _репп, фаа_,
   {{0x20563aab,0x68e37648,0x3ebf01f7,0xe5770043}},	//   ктер, _jend, _agut_, _азь_,
   {{0xd12f036b,0xdb1a002a,0x00000000,0x00000000}},	//   تمل_, _sutí, --, --,
   {{0x291e7649,0x9c7c0a69,0xc91e00b4,0x20070443}},	//   zeta_, _neča, _भस्म_, ània_,
   {{0x291e0f3a,0x33200443,0x6b5c00a2,0x7ae2764a}},	//   yeta_, meix_, _ségo, _reot,
   {{0x68e3764b,0x7ae2007c,0xcbcd0033,0x6b55764c}},	//   _nend, _seot, _রয়েছ, _mágu,
   {{0x1fb62681,0x291e2c26,0x5f060ca6,0x69c201ef}},	//   _асар, veta_, _изва, _suoe,
   {{0x33200443,0x291e3736,0x68e3764d,0x2907055c}},	//   neix_, weta_, _aend, _acna_,
   {{0x9c7c764e,0x291e05e2,0x1d260896,0x68e37605}},	//   _deča, teta_, _имам, _bend,
   {{0x68e30452,0xdbd90370,0xd7f80043,0x1b1f0083}},	//   _cend, _açõe, tră_, ভাগে_,
   {{0x68e3764f,0x013502b5,0xdd8f126b,0x44230221}},	//   _dend, אָרט_, _بول_, xwj_,
   {{0x68e31516,0x7c287650,0xa5f900c3,0x9c7c0409}},	//   _eend, _isdr, нему_, _geča,
   {{0x291e24a8,0x33200443,0x3a26028b,0xcb070088}},	//   peta_, deix_, _usop_, _شيون_,
   {{0x68e37651,0xceb302b8,0xa2d500ab,0xd8760037}},	//   _gend, ייר_, युन्, _لاعب,
   {{0x68e8001c,0x478b03fa,0x2ee40298,0x332b0160}},	//   madd, _осим_, _oemf_, _pacx_,
   {{0x68e87652,0x68e34806,0x332012c3,0x490e0167}},	//   ladd, _zend, geix_, त्रो_,
   {{0x6b5c0248,0x6115081b,0x68e37653,0x442301e8}},	// [7bd0] _régl, лдау, _yend, swj_,
   {{0x68e83450,0x68e37654,0x443100fe,0xed590124}},	//   nadd, _xend, pvz_, _ružo_,
   {{0xe8d700a5,0x672d7655,0x33200310,0x332b008c}},	//   דובר_, _kaaj, beix_, _tacx_,
   {{0x68e87656,0x672d02d7,0x611300fe,0x00000000}},	//   hadd, _jaaj, _bělí, --,
   {{0x61ff01c2,0x68e80273,0x672d7657,0x25e600dc}},	//   quql, kadd, _maaj, जीपी_,
   {{0xac090cf9,0x68e8046a,0x672d0086,0x9c7c02c4}},	//   енка_, jadd, _laaj, _seča,
   {{0x4c150082,0x68e33993,0x9c7c030a,0x63bd3910}},	//   ابتس, _rend, _peča, _kisn,
   {{0x3ebf0a4e,0x8b251e26,0xdb1a0176,0x20017658}},	//   _ugut_, удие, _cutà, muhi_,
   {{0x68e37659,0x61ed765a,0x63bd765b,0x68e84c02}},	//   _pend, nsal, _misn, fadd,
   {{0x68e301d2,0x6e290027,0x629d765c,0x68e801a8}},	//   _qend, _iseb, _myso, gadd,
   {{0x68e30b73,0x9c7c765d,0x2001005d,0x61ed0095}},	//   _vend, _teča, nuhi_, hsal,
   {{0x68e3765e,0x2121765f,0x3ce57660,0x9b440118}},	//   _wend, hehh_, _helv_, _پنهو,
   {{0x68e809d6,0x7ae901ed,0xfa3402fd,0x6e290024}},	//   badd, maet, _پرند, _jseb,
   {{0x7ae90297,0x68e8027a,0x6b550987,0x68e37661}},	//   laet, cadd, _vágu, _uend,
   {{0x63bd7662,0x33200955,0x672d006d,0x49b80c26}},	//   _bisn, teix_, _faaj, _شاهد_,
   {{0x7ae902c7,0x6e29108a,0x23273626,0x672d7663}},	//   naet, _oseb, лоси_, _gaaj,
   {{0x61ed1c3f,0x332012c3,0xd3872698,0xe7850166}},	// [7be0] gsal, reix_, уйте_, _њујо,
   {{0x29c90019,0x6f097664,0x7ae900e9,0xdb1a605e}},	//   _múa_, _acec, haet, _mutá,
   {{0x61ed3070,0x5ecd0083,0x29c97665,0x672d006d}},	//   asal, ারনে, _lúa_, _yaaj,
   {{0x6db900a0,0x2fd70e3a,0xf427002d,0x68e801a8}},	//   _dňam, اوند_, _союл_, zadd,
   {{0x68e8018e,0x7ae902c7,0x80e300c8,0x21210159}},	//   yadd, daet, _পার্, behh_,
   {{0x20017666,0x3a3a02c4,0x16c10440,0x6c5403e6}},	//   buhi_, _čpp_, _एल्ब, иклу,
   {{0x50b508a6,0x6e296476,0xcd270166,0xdb1a7667}},	//   _всту, _eseb, ужје_, _autá,
   {{0x7ae90297,0x29c97668,0x3d090006,0x68e80273}},	//   gaet, _búa_, _साथे_, wadd,
   {{0xee3a01c8,0x7f754697,0x68e87669,0x672d0328}},	//   _яна_, _турц, tadd, _raaj,
   {{0xd6e10083,0xd7fa48d0,0x7764002a,0x672d03a6}},	//   _ভাইয, нум_, _alix, _saaj,
   {{0x68e8766a,0x7764766b,0xe0fb0070,0x88bc0355}},	//   radd, _blix, עלטל, jdět,
   {{0x68e8018e,0x77640176,0x61ed766c,0x70e10035}},	//   sadd, _clix, ysal, _फ़्ल,
   {{0x628001c8,0x63bd766d,0x9b93004f,0xab930037}},	//   _žmon, _risn, _النت, _النغ,
   {{0x7764043f,0x68e8766e,0x672d1d50,0x63bd021d}},	//   _elix, qadd, _waaj, _sisn,
   {{0x7764766f,0x63bd7670,0x672d0421,0x80e30033}},	//   _flix, _pisn, _taaj, _পাল্,
   {{0x61ed7671,0x25660248,0x870900b5,0x72d500af}},	//   tsal, _rôle_, _شعبہ_, роаф,
   {{0x63bd1e8b,0x61ed4ab4,0x00000000,0x00000000}},	// [7bf0] _visn, usal, --, --,
   {{0x629d0076,0x20010ec0,0x9c7c7672,0xeb210325}},	//   _vyso, tuhi_, _rečn, _मस्त_,
   {{0x629d004e,0x63bd7673,0x7ae900e9,0x9c7c02a7}},	//   _wyso, _tisn, yaet, _sečn,
   {{0x61ed7674,0x3ce51953,0x6b552278,0x28970070}},	//   psal, _selv_, _lágr, נדאן_,
   {{0x2d760035,0x98a700d5,0x1d0907c7,0x3d002df6}},	//   ałem_, _ranč_, вели_, _राखे_,
   {{0xf1a91d81,0x29c90391,0xee380332,0x6e29108a}},	//   _कठिन, _rúa_, اقوں_, _vseb,
   {{0x29c94a07,0x7ae9001e,0xe0570609,0xdd8e026e}},	//   _súa_, taet, _حیات_, بوو_,
   {{0x9c7c3727,0x2369046a,0x7ae900e9,0x29c90138}},	//   _tečn, nhaj_, uaet, _púa_,
   {{0x7ae9001e,0x69252f6c,0x6e297675,0x29c900cc}},	//   raet, ампа, _useb, _qúa_,
   {{0xa2d50a90,0x290501f2,0xec6b0112,0xc8b50421}},	//   युत्, ugla_, _прек_, исны,
   {{0x98a50fc5,0x670a0864,0xe3bf0065,0x77860d6e}},	//   рине, _वादक_, _oiñ_, илоз,
   {{0x29c90391,0xe8160006,0x27f87676,0xe3bf02d7}},	//   _túa_, _तहरा_, árna_, _niñ_,
   {{0xd9457677,0x2d760067,0x00000000,0x00000000}},	//   _вели, złem_, --, --,
   {{0x2d760067,0xe3bf01ed,0x00000000,0x00000000}},	//   yłem_, _aiñ_, --, --,
   {{0x6363007c,0x9c7c2d5b,0xb97a00a5,0x00000000}},	//   _sõna, _nečl, _בנסי, --,
   {{0xdb020028,0xe3636b7f,0x2b4d0693,0x00000000}},	//   _khoá, окси, njec_, --,

   {{0x6d417678,0x42c70210,0x00000000,0x00000000}},	// [7c00] _onla, ргун_, --, --,
   {{0xb17b022a,0xe0d75950,0xb14320c3,0xe3bf0065}},	//   _svår, иву_, онул, _eiñ_,
   {{0xb4fb0122,0xd0260804,0xaec63289,0x04467679}},	//   _בפיי, рмей, абел, _тенн,
   {{0x6d41767a,0xa2d50d91,0x2369767b,0x9c7c41c8}},	//   _anla, युद्, chaj_, _sečo,
   {{0x645c767c,0x443a01a2,0xdce1027d,0x9c7c2187}},	//   lyri, _hrp_, _aklı, _pečo,
   {{0x443a767d,0x91e31e96,0x00000000,0x00000000}},	//   _krp_, _форе, --, --,
   {{0x50aa022e,0x7b663f27,0xed570fb4,0x9c7c023a}},	//   _करिष, итие, рој_, _večo,
   {{0x6d4129ff,0x6b550079,0x00000000,0x00000000}},	//   _enla, _ságr, --, --,
   {{0x3f86053d,0xdb020023,0x657c02c4,0xdb0b0031}},	//   mnou_, _choá, kirh, _zhgë,
   {{0x3f86024e,0x6b5c006c,0x29180093,0x6da62252}},	//   lnou_, _mégi, ýra_, _тиза,
   {{0x01370122,0x6b5c767e,0x3f860f84,0x657c767f}},	//   ברית_, _légi, onou_, dirh,
   {{0x3f867680,0x9c7c20dc,0x23690031,0x00000000}},	//   nnou_, _ječm, xhaj_, --,
   {{0x7bc80657,0xaac50037,0x3f860183,0x00000000}},	//   _hudu, _اتمن, inou_, --,
   {{0x7bc87681,0x443a01a2,0x645c7682,0xdcf8010b}},	//   _kudu, _brp_, fyri, rovė,
   {{0xe51600c0,0x7bc838bf,0xdcfa0029,0xa3e24068}},	//   द्धि_, _judu, _aktī, नील_,
   {{0x7bc84d53,0x3d16035d,0x3f860314,0x224901a3}},	//   _mudu, प्ते_, jnou_, txak_,
   {{0x3f86033a,0x7bc87683,0x657c0159,0xe7f600ab}},	// [7c10] dnou_, _ludu, birh, ूंवा_,
   {{0xdb090037,0x7c3a0009,0x443a34e0,0x23697684}},	//   imeá, _ortr, _frp_, shaj_,
   {{0x442714f4,0x2fc70028,0x7bc800f8,0x2d760035}},	//   _èn_, êng_, _nudu, ałek_,
   {{0x3f860519,0x9c7c02a7,0x00000000,0x00000000}},	//   gnou_, _večl, --, --,
   {{0x7bc81d48,0x929400d8,0xd3360317,0x765d0282}},	//   _audu, _маюц, _פרשה_, nysy,
   {{0x7bc87685,0x645a01ae,0x200e12c3,0xed59022f}},	//   _budu, ätig, àfic_, _kuži_,
   {{0x7bc80168,0xf1b20122,0x3f860187,0x251c016b}},	//   _cudu, _מסך_, bnou_, דווא,
   {{0x5f944311,0x7bc80452,0xed59024e,0x88e30033}},	//   _дист, _dudu, _muži_, _মাইক,
   {{0x5ecd0033,0x7c3a033b,0xdce30009,0x6f1b0027}},	//   ারদে, _ertr, sinđ, _ibuc,
   {{0x6d413990,0x7bc847dc,0x670a0026,0x97d92c4c}},	//   _unla, _fudu, _वाहक_, льму_,
   {{0x315802b5,0x6e3b024e,0x201301a3,0x213100e0}},	//   ייזן_, _hrub, ntxi_, _mazh_,
   {{0xdb0201a5,0x321203ad,0x6e3b0523,0x6363018d}},	//   _thoá, ytyy_, _krub, _sõnn,
   {{0x443a7686,0x657c7687,0x98a501d6,0x2d8700f7}},	//   _srp_, tirh, rklı_, onne_,
   {{0xceb20052,0x6b5c7688,0x645c7689,0x69db0831}},	//   פים_, _régi, tyri, mpue,
   {{0x2d87148b,0xa3e20006,0x26e70083,0x7bc80510}},	//   inne_, नीं_, _কারো_, _xudu,
   {{0xed59011c,0x321200c3,0x6e3b0065,0x443a00f6}},	//   _duži_, ttyy_, _orub, _vrp_,
   {{0x645c768a,0x3f86024e,0x52aa2351,0xa1c318c3}},	// [7c20] syri, vnou_, увам_, збуд,
   {{0x9c7c0200,0x6606768b,0x6b5c00b5,0x6f1b768c}},	//   _dečj, mukk, _végi, _abuc,
   {{0x66060b88,0x628f768d,0x3f86768e,0x443a07e5}},	//   lukk, _exco, tnou_, _urp_,
   {{0x2d87768f,0x6e3b2d3c,0x442a0159,0x7bc87690}},	//   enne_, _brub, mwb_, _rudu,
   {{0xf2d30779,0x7bc87691,0x63a427fe,0xb14800bf}},	//   _מער_, _sudu, mlin, _پیام_,
   {{0xf9870789,0x63b60093,0x3f867692,0x7bc8013a}},	//   _رب_, lmyn, snou_, _pudu,
   {{0x3d090026,0x63a42031,0x9c7c022f,0x38c804e8}},	//   _सारे_, olin, _zečj, یادی_,
   {{0x672600da,0x660673ed,0x2d877693,0xbf1600d1}},	//   jekj, kukk, anne_, _دورب,
   {{0x6e3b7694,0x66067695,0x7bc83ea1,0x442a006d}},	//   _grub, jukk, _wudu, hwb_,
   {{0xb5fb00f5,0x7bc8486e,0x6606128c,0x57f41858}},	//   zzás, _tudu, dukk, опот,
   {{0x63a474d8,0x319b02b5,0xcb0a00f8,0xb19b0070}},	//   klin, רבינ, _ميان_, רייכ,
   {{0xb76718b6,0xed590506,0x31af0225,0x00000000}},	//   стой, _ruži_, müze_, --,
   {{0x63a47696,0x7a36126b,0x66067697,0xb8ce0033}},	//   dlin, _دعائ, gukk, _কল_,
   {{0x9c7c01f2,0x6e2000d7,0x237900d7,0x00000000}},	//   _rečj, _mpmb, _smsj_, --,
   {{0x765d00d7,0xdcf80207,0x00000000,0x00000000}},	//   sysy, jivč, --, --,
   {{0x63a47698,0x63b6008a,0xe3b0211f,0x290e0069}},	//   glin, gmyn, فرق_, _hcfa_,
   {{0xe800162b,0x3d09020d,0x9c7c011c,0xa2d500e7}},	// [7c30] लंका_, _साले_, _bečk, युष्,
   {{0x63a47699,0xf77f769a,0x9c7c02c6,0x6f1b027a}},	//   alin, liç_, _večj, _sbuc,
   {{0x63a4769b,0x9c7c029d,0x61e60069,0x6e3b06bc}},	//   blin, _dečk, _ewkl, _srub,
   {{0x2d8c0c21,0xceeb00bf,0x63a4769c,0x25e60266}},	//   _ajde_, اران_, clin, जीवी_,
   {{0x4421769d,0x67c800b8,0xf1bf00ac,0x9c7c00ee}},	//   _hph_, _ději, _mráz_, _fečk,
   {{0x3d0e00a1,0xabd5052c,0x5bb306fe,0x4421769e}},	//   _ठाणे_, оциј, ुद्व, _kph_,
   {{0x4c69027a,0x6b5c769f,0x70590210,0x998600ac}},	//   рийн_, _légu, _тавр_, _brož_,
   {{0x6f1b0010,0x88bc00b8,0x2d9e01e0,0x00000000}},	//   _ubuc, vděp, _ekte_, --,
   {{0x6e3b0232,0xc8da00a1,0x291c0ddb,0x6b5c01ef}},	//   _urub, _म्हट, _bbva_, _négu,
   {{0x69db0ddb,0x3ead01e9,0x799a76a0,0x00000000}},	//   rpue, _izet_, gotw, --,
   {{0x69db00c8,0xfd100037,0x442100cc,0x63b60090}},	//   spue, _سجل_, _nph_, ymyn,
   {{0xae0d0d1f,0x660657fa,0x63a43af9,0x65a0033b}},	//   _समान_, tukk, xlin, höht,
   {{0x3f9f19c6,0xe8ee1a1c,0x63a4022a,0xf3f10023}},	//   _mkuu_, _ол_, vlin, ận_,
   {{0x6b8976a1,0x660676a2,0x6b5c00f7,0xdb0b0176}},	//   lneg, rukk, _dégu, _ligü,
   {{0x66065f64,0x68e11835,0x44213705,0x63a476a3}},	//   sukk, mbld, _cph_, tlin,
   {{0x44210076,0x69cb76a4,0xf8b20122,0x6b8976a5}},	//   _dph_, _kuge, _קשה_, nneg,
   {{0x7aeb0332,0x69cb76a6,0x442176a7,0x00da3345}},	// [7c40] _megt, _juge, _eph_, لبات_,
   {{0x63a40044,0x69cb44fa,0x7aeb76a8,0xdb0b0443}},	//   slin, _muge, _legt, _aigü,
   {{0x4f9600af,0x69cb76a9,0x3ead016f,0x4421012f}},	//   орду, _luge, _azet_, _gph_,
   {{0x80da074f,0xee3a0e79,0xe29a6901,0x69c35f00}},	//   _प्रे, ине_, _вам_, _line,
   {{0x6b8976a1,0x69cb76aa,0x69c301d7,0x7c210107}},	//   dneg, _nuge, _oine, _aplr,
   {{0xafe63cf6,0x463b02b5,0xc0aa097f,0x69c376ab}},	//   _могл, יענע, _نازل_, _nine,
   {{0xa0a31783,0x69cb76ac,0x6ab41bc6,0x69d92967}},	//   _жард, _auge, ुश्र, _atwe,
   {{0x69cb76ad,0x69c376ae,0x0b8a76af,0x6b9b02c4}},	//   _buge, _aine, јски_, goug,
   {{0x69c376b0,0x7aeb00c7,0xf77f76b1,0x69cb00af}},	//   _bine, _degt, viç_, _cuge,
   {{0x6b5c0248,0x9c7c76b2,0x69c376b3,0xdc3e0187}},	//   _régu, _leči, _cine, líče,
   {{0x69c376b4,0x69d9030d,0x6b8967bf,0x6b5c76b5}},	//   _dine, _etwe, bneg, _ségu,
   {{0x69c3328b,0x2d9c76b6,0x7bda76b7,0x6b9b01ef}},	//   _eine, love_, _ittu, coug,
   {{0x69cb1138,0x3a3d00e9,0x69c33430,0xf77f76b8}},	//   _guge, _grwp_, _fine, riç_,
   {{0x2d9c05e2,0x27690d4f,0x80da073f,0x6b80034d}},	//   nove_, _گشتی_, _प्ले, limg,
   {{0xd37b1797,0x69cb02c9,0x9c7c023a,0x00000000}},	//   ача_, _zuge, _beči, --,
   {{0x569503ad,0x2d9c1851,0x69c306a2,0x44212ae3}},	//   _найт, hove_, _zine, _vph_,
   {{0x2d9c0877,0x9c7c5dd8,0x60f9021f,0x69c30225}},	// [7c50] kove_, _deči, йная_, _yine,
   {{0x69c31083,0x7bda003c,0x290c0ff5,0x44210051}},	//   _xine, _ottu, ngda_, _tph_,
   {{0x2d9c0ba8,0x4421012f,0x7bda0103,0x00000000}},	//   dove_, _uph_, _nttu, --,
   {{0x6b5c00b5,0xf1bf76b9,0x43955f6e,0x9c7c005f}},	//   _mégs, _spád_, _хамс, _geči,
   {{0x7bda76ba,0x7aeb0626,0xa2a20437,0x6b9b0200}},	//   _attu, _regt, _कुप्, voug,
   {{0x2d9c0fd5,0xa3e2004e,0x69cb0010,0x6b89004e}},	//   gove_, नीक_, _ruge, wneg,
   {{0x69c376bb,0x6b8916d9,0x6b9b0009,0x80d60099}},	//   _rine, tneg, toug, मुळे,
   {{0x69c3122c,0x2b4604e6,0xed593202,0x69cb76bc}},	//   _sine, _cnoc_, _ružu_, _puge,
   {{0x6b9b0052,0x34a80311,0x6b8976bd,0x2d9c01a0}},	//   roug, _गर्द, rneg, bove_,
   {{0x69c301da,0x6b8976be,0x2eed0051,0x290c76bf}},	//   _qine, sneg, _heef_, ggda_,
   {{0xe73a029f,0x07a62e1b,0xc7a676c0,0xa2a204aa}},	//   бен_, занн, зинк, _कुन्,
   {{0x69cb76c1,0x69c376c2,0xfb380037,0x00000000}},	//   _tuge, _wine, _وأنت_, --,
   {{0x1dcb04bc,0x69c376c3,0x9c7c52eb,0x656e09c3}},	//   ादित, _tine, _reči, thbh,
   {{0x2eed0173,0x9c7c38cb,0x2ca50282,0x69c3009e}},	//   _leef_, _seči, _kyld_, _uine,
   {{0x80aa004e,0x98a23d35,0x70aa0006,0x044362a2}},	//   _करें, _пише, _करेल, нерн,
   {{0x1dcb0026,0x2d9c01a0,0x2eed0fdb,0x57fa00a5}},	//   ादात, zove_, _neef_, _הלקו,
   {{0x320976c4,0x9c7c02c6,0x02060733,0x00000000}},	// [7c60] guay_, _veči, язан, --,
   {{0xdce300d8,0xe1f72327,0x6b5c13cf,0x3cf70067}},	//   minė, ягу_, _jégr, ीलों_,
   {{0xdce300d8,0xb4d876c5,0x6d050066,0x2d9c00cd}},	//   linė, ाडी_, _राजग_, vove_,
   {{0x7981043d,0xed5800a0,0x00000000,0x00000000}},	//   hilw, _soľ_, --, --,
   {{0x2d9c2f6e,0xdce300d8,0x673676c6,0x733b0070}},	//   tove_, ninė, _mayj, _העכס,
   {{0x09da0083,0x2ca5008c,0x6b5c00a2,0xd6ae0831}},	//   _দিলা, _byld_, _négr, _গলায,
   {{0xdee6477c,0x2d9c19be,0x80e30083,0xfe6f006c}},	//   _нови, rove_, _পাচ্, نگے_,
   {{0x2d9c0060,0x3947004a,0x2eed0a75,0xa3ac0084}},	//   sove_, _anns_, _geef_, गति_,
   {{0xa2a21a75,0x0e6601c8,0x2d9c0ce9,0x9c7c0207}},	//   _कुम्, _экан, pove_, _nečv,
   {{0x49730c9d,0xdce3010b,0x2eed0051,0x2ca50b3e}},	//   ельс, dinė, _zeef_, _fyld_,
   {{0x6d4876c7,0xa3ac0e04,0x53be0084,0x6b5c00f7}},	//   _inda, गता_, ्दाश, _dégr,
   {{0x6d5a0a5d,0x290201d6,0x61f60eb1,0x9c7c06fe}},	//   _hota, şka_, ksyl, _bečv,
   {{0xd05c01c2,0xdce3010b,0xda3400c3,0x8f9b100a}},	//   _verə, ginė, _целы, מיטי,
   {{0x6d5a03ad,0xe5c400c3,0xca330200,0x00000000}},	//   _jota, ессо, _чешћ, --,
   {{0x6d5a76c8,0xb33b0225,0xf36706d8,0x6d48034d}},	//   _mota, _akça, птан, _mnda,
   {{0x637106d7,0x26c9381d,0xdce3010b,0xd3a400af}},	//   _mång, _ugao_, binė, еруп,
   {{0x6d4876c9,0x637176ca,0x6d5a007c,0xdce300d8}},	// [7c70] _onda, _lång, _oota, cinė,
   {{0x6d5a76cb,0x636300ab,0x00000000,0x00000000}},	//   _nota, _mõni, --, --,
   {{0x776d123d,0x9c7c00d5,0x63710523,0x00000000}},	//   _klax, _keču, _nång, --,
   {{0x6d4876cc,0x00000000,0x00000000,0x00000000}},	//   _anda, --, --, --,
   {{0x320900cc,0x00000000,0x00000000,0x00000000}},	//   quay_, --, --, --,
   {{0x6d5a76cd,0xdca50e05,0x4d6401e0,0x63710282}},	//   _cota, мали, нків, _bång,
   {{0x6d5a76ce,0x6b5c0e8c,0x2eed1e7e,0x256f0225}},	//   _dota, _régr, _teef_, _güle_,
   {{0xe9d90423,0x8d770919,0x92c10083,0xa2a2021a}},	//   оки_, _کارا, ুরী_, _कुड्,
   {{0x6d5a76cf,0xed050987,0x7f4976d0,0x00000000}},	//   _fota, _يورپ, _ineq, --,
   {{0x637176d1,0xdce3010b,0xceb2011d,0x776d01ed}},	//   _hånd, vinė, _יין_, _alax,
   {{0x6371022a,0x6b5c006c,0x1c210026,0x79811ebb}},	//   _gång, _végr, _महिल_, rilw,
   {{0xdce301c8,0x6d5a6fb9,0x61f600e9,0x776d0139}},	//   tinė, _zota, ysyl, _clax,
   {{0x27e00a78,0x6371022a,0x00000000,0x00000000}},	//   _čine_, _månd, --, --,
   {{0xdce300d8,0x186976d2,0x44330036,0xb4d81fc3}},	//   rinė, _мали_, _bsx_, ाडे_,
   {{0x64a366b3,0x776d76d3,0xdce3010b,0xa2c009a0}},	//   вара, _flax, sinė, लेन्,
   {{0x70aa0066,0xdce3010b,0x04100033,0xb4ae00ab}},	//   _करौल, pinė, াবলী_, _औरी_,
   {{0x03a32f54,0xa3e20026,0x3aba0070,0x256f00be}},	// [7c80] тито, नीज_, ַמענ, _süle_,
   {{0xa2a232b1,0x7e620054,0x61f600e9,0x37e00033}},	//   _कुण्, vyop, rsyl, _ভিতর,
   {{0x443c006c,0x68fc0183,0x6371082b,0x61f65124}},	//   _év_, órdi, _bånd, ssyl,
   {{0x6d5a76d4,0x00000000,0x00000000,0x00000000}},	//   _sota, --, --, --,
   {{0xf1af20a3,0x63a9003c,0x6371013c,0xf1bf00b8}},	//   _जीवन, ċent, _sång, _psát_,
   {{0x7e62046a,0x00000000,0x00000000,0x00000000}},	//   ryop, --, --, --,
   {{0xa2d5114e,0xa2a21db9,0x7e620260,0x90c30949}},	//   युक्, _कुत्, syop, _абре,
   {{0x5a3411ca,0x6d5a40f7,0xd00f0037,0xcf26097f}},	//   енит, _wota, _خلف_, _ترسي,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4876d5,0x9c7c0009,0x5886057a,0x00000000}},	//   _unda, _seču, дыма, --,
   {{0x776d002a,0x9c7c0690,0x3cfe0051,0x63710b3e}},	//   _plax, _peču, _idtv_, _håne,
   {{0x95cb0370,0xd7cf3100,0x636300ab,0xe81f00ab}},	//   жува_, _संरच, _tõni, _बहरा_,
   {{0x9f650248,0x00000000,0x00000000,0x00000000}},	//   étés_, --, --, --,
   {{0x63710909,0xe8944b41,0xdb19081b,0x00000000}},	//   _måne, _паль, _eiwä, --,
   {{0xd7ef0009,0x776d00de,0x637102df,0x00000000}},	//   _шу_, _tlax, _låne, --,
   {{0x3a2676d6,0x3cfe02d7,0x57fb00a5,0x395c0282}},	//   _kpop_, _ldtv_, _ולהו, _hovs_,
   {{0xe1f01629,0x7afd08c0,0xa2d5021a,0x3a2600cc}},	// [7c90] لسل_, ósti, युग्, _jpop_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f5b0a39,0xd7f8002d,0x92c10033,0xb4eb258f}},	//   _pouq, nsă_, ুরে_, मरी_,
   {{0x20df0803,0xb0df09a8,0xd34701cb,0x50df00b8}},	//   _प्रध, _प्रग, _تیره_, _प्रष,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee386559,0x236901e9,0xae110099,0x3cfe023a}},	//   ьні_, lkaj_, डंबन_, _cdtv_,
   {{0xdca20aec,0x3cfe0160,0x77b60042,0x7f5b00a2}},	//   лаши, _ddtv_, láxe, _touq,
   {{0x23690207,0x3cfe0345,0xe51f2160,0x9c7c023a}},	//   nkaj_, _edtv_, म्ति_, _rečt,
   {{0x9915010b,0xa3b602b4,0x3f8f023c,0x3a2600cc}},	//   ньні, _चीफ_, mngu_, _cpop_,
   {{0xa3b60e7f,0x7d7906c9,0x3cfe0282,0x00000000}},	//   _चीन_, _عمار_, _gdtv_, --,
   {{0xe73a2701,0x63710282,0x00000000,0x00000000}},	//   пен_, _månb, --, --,
   {{0xe73a07bc,0x66000097,0x6d1b0067,0x00000000}},	//   чем_, ámko, प्रग_, --,
   {{0x2b140035,0x15ba00c3,0xd7f800af,0x66080067}},	//   _धातु_, зывы_, asă_, ądko,
   {{0x636300ab,0x25660168,0xdb090345,0x00000000}},	//   _mõnu, _kôli_, kleë, --,
   {{0xa5bb0035,0x7afd0067,0x671800b4,0x2b5d0024}},	//   twór, óstw, _थापक_, _kowc_,
   {{0x636a0187,0x00000000,0x00000000,0x00000000}},	//   _výno, --, --, --,
   {{0x672401d5,0xe2972ae1,0x00000000,0x00000000}},	// [7ca0] _ibij, еат_, --, --,
   {{0x6fd40084,0x764401d5,0x6b5500b5,0x249f027b}},	//   _बंदू, _iriy, _vágy, şuma_,
   {{0x80a80033,0xaf0600af,0x00000000,0x00000000}},	//   কেন্, епел, --, --,
   {{0x444476d7,0x764453db,0x91e6189d,0x23690e31}},	//   _ir_, _kriy, _поме, ckaj_,
   {{0x444476d8,0x672476d9,0x3cfe1c35,0xcf2505f5}},	//   _hr_, _mbij, _pdtv_, ئرمي,
   {{0x61e42b63,0x444476da,0x256f00ab,0xdb1a00d5}},	//   mpil, _kr_, _küla_, _dutý,
   {{0x61e476db,0x672476dc,0xcfaa00b5,0x8bc6002d}},	//   lpil, _obij, _فارم_, нсид,
   {{0x44440122,0x09c8021a,0x764476dd,0x67240051}},	//   _mr_, रद्य, _oriy, _nbij,
   {{0x6d4b0037,0x00000000,0x00000000,0x00000000}},	//   álaí, --, --, --,
   {{0x444435d9,0xc27b0100,0x3f8676de,0x672476df}},	//   _or_, פריי, liou_, _abij,
   {{0x764476e0,0xe89400d8,0x224000be,0x9c7c08b7}},	//   _ariy, тань, hvik_, _večs,
   {{0xc6a70de3,0x61e476e1,0x3f8600ee,0x387602c4}},	//   ерги, kpil, niou_, _đerđ_,
   {{0x444476e2,0x764400e0,0x3d172493,0x00000000}},	//   _ar_, _criy, _नामे_, --,
   {{0x444476e3,0x76440feb,0x224076e4,0xb4eb0127}},	//   _br_, _driy, dvik_, मरे_,
   {{0x97a7022c,0x332076e5,0x779309b9,0xa3ac0099}},	//   _прил, ffix_, _میدا, गतं_,
   {{0x53341c2e,0xe3b3211b,0x64430b4c,0x69ca0176}},	//   лест, ارس_, _ánim, _hife,
   {{0x444476e6,0x69ca2804,0x61e42700,0x76440703}},	// [7cb0] _er_, _kife, gpil, _griy,
   {{0x7c2876e7,0x23695510,0x660f532b,0x60dc0139}},	//   _opdr, skaj_, muck, _cfrm,
   {{0x444476e8,0x6b820888,0x63630006,0x660f76e9}},	//   _gr_, _omog, _sõnu, luck,
   {{0x661d76ea,0xb4bf0567,0x673d1b4b,0x69ca76eb}},	//   otsk, ेशी_, ndsj, _life,
   {{0x63ad00a3,0x660f0602,0x7c280029,0x4444345d}},	//   mlan, nuck, _apdr, _zr_,
   {{0x44441973,0x69ca0297,0x63ad3ea6,0xdb002154}},	//   _yr_, _nife, llan, lomè,
   {{0xeb990108,0x32090107,0x63ad76ec,0x98a700b8}},	//   мик_, lray_, olan, _daně_,
   {{0x3f8676ed,0x0b450183,0xdb0076ee,0x661d76ef}},	//   ciou_, тнин, nomè, ktsk,
   {{0xdb1a76f0,0x320976f1,0x660f19cd,0x27e0011c}},	//   _autó, nray_, juck, _čina_,
   {{0x63ad76f2,0x7c2c27c2,0x644576f3,0x6b820036}},	//   hlan, ñorí, _orhi, _emog,
   {{0x2d873914,0x66e676f4,0x644501a9,0x61e400ea}},	//   mine_, кона, _nrhi, zpil,
   {{0x63ad76f5,0x444476f6,0x764476f7,0x320931dc}},	//   jlan, _rr_, _priy, kray_,
   {{0x644576f8,0x4444141f,0x2d87003b,0x7ae976f9}},	//   _arhi, _sr_, oine_, mbet,
   {{0x7bcb390a,0x320900f6,0x7ae976fa,0x61e40029}},	//   _higu, dray_, lbet, vpil,
   {{0x64a6587d,0x63ad76fb,0x7bcb76fc,0x61fd370d}},	//   тава, flan, _kigu, _avsl,
   {{0x63ad03d0,0x32092c60,0x2d8776fd,0x672410ec}},	//   glan, fray_, hine_, _ubij,
   {{0x7bcb1845,0x3f8676fe,0x644501ae,0xa2a20066}},	// [7cc0] _migu, viou_, _erhi, _कुश्,
   {{0x444476ff,0x61e40ac8,0x7bcb7700,0x2d877701}},	//   _tr_, rpil, _ligu, jine_,
   {{0x2d877702,0x44447703,0x61e47704,0xa2a2073f}},	//   dine_, _ur_, spil, _कुर्,
   {{0xe809142a,0x63ad7705,0x0e662349,0x7bcb7706}},	//   _विना_, clan, ккен, _nigu,
   {{0x63a43cd9,0x3f867707,0x7ae93008,0x2d877708}},	//   moin, riou_, dbet, fine_,
   {{0x7bcb4c70,0x63a47709,0x2d872e0f,0x71760088}},	//   _aigu, loin, gine_, _شهزا,
   {{0x69ca27f8,0xdb003675,0x7bcb2710,0x3c3c00b8}},	//   _rife, lomé, _bigu, dává_,
   {{0x63a400c3,0xdb1a0443,0x7bcb770a,0x7ae9770b}},	//   noin, _autò, _cigu, gbet,
   {{0x2d870169,0x7bcb4367,0x69ca0176,0xf1bf00ee}},	//   bine_, _digu, _pife, _opál_,
   {{0x7bcb0093,0x63a4770c,0x63ad770d,0x63710533}},	//   _eigu, hoin, zlan, _måna,
   {{0x63ad770e,0x3d170907,0x63a40086,0x7ae9770f}},	//   ylan, _नाते_, koin, bbet,
   {{0x69ca2ea2,0x7bcb043d,0x63ad0095,0x661d7710}},	//   _wife, _gigu, xlan, ttsk,
   {{0xa2a20992,0x673d31cb,0x63ad08d7,0x69ca035f}},	//   _कुल्, rdsj, vlan, _tife,
   {{0x661d6a40,0x58d35654,0x63ad7711,0xdb0025ec}},	//   rtsk, _кошт, wlan, domé,
   {{0xb4bf08b0,0x661d0076,0x660f00a0,0x3f84009f}},	//   ेशे_, stsk, suck, _ommu_,
   {{0x63a47712,0x63ad7713,0x661d0009,0xcc3b016b}},	//   goin, ulan, ptsk, ועלט,
   {{0x32090260,0xdb007714,0xa7fc0225,0x80d7073f}},	// [7cd0] uray_, romè, zyıl, _बलदे,
   {{0xdb007715,0x3f841b43,0x32090cd5,0x63710282}},	//   llmä, _ammu_, rray_, _dåna,
   {{0x31c40328,0x7ae9027d,0x77b601ef,0x00000000}},	//   рств, ybet, láxa, --,
   {{0x63ad00a8,0x2d870118,0x394e002a,0xa5bb0132}},	//   qlan, wine_, _lnfs_, stód,
   {{0xfe7022c4,0x7bcb01d3,0xdb000519,0x59ce0067}},	//   يده_, _rigu, comé, _हंगर,
   {{0x2cac02c7,0x7ae900e9,0xa2c000e7,0x6aab008c}},	//   _bydd_, wbet, वधर्, _rygf,
   {{0x2d877716,0x7ae95cd7,0x41af162b,0x00000000}},	//   rine_, tbet, _जीएस, --,
   {{0x2d877717,0x2cac0297,0x9c7c0116,0x00000000}},	//   sine_, _dydd_, _večp, --,
   {{0x7ae97718,0x2d877719,0x7bcb771a,0xd6ae0083}},	//   rbet, pine_, _vigu, _গল্প,
   {{0x7ae9771b,0x2cac0297,0x7ae6027d,0x57e91dd6}},	//   sbet, _fydd_, ıkta, ндом_,
   {{0x7bcb02b3,0xb4bf018d,0x18690432,0x378a1362}},	//   _tigu, ेशो_, хани_, ебно_,
   {{0x2d8500ee,0x1dcb09b4,0xab843537,0x7bcb03c1}},	//   _hmle_, ादकत, _кучк, _uigu,
   {{0x7988771c,0x63a4771d,0x6b89771e,0x2fcd7650}},	//   bidw, voin, mieg, _mieg_,
   {{0x6b89771f,0x2fcd03bc,0x395801ff,0x637101ff}},	//   lieg, _lieg_, örst_, _råna,
   {{0x63a44cff,0x232a0847,0x69c17720,0xe1ff2314}},	//   toin, нови_, mmle, _avó_,
   {{0x69c101d6,0x6b897721,0xa2bb06fe,0xf77200f8}},	//   lmle, nieg, _शृङ्, _دات_,
   {{0x63a4710c,0x256f0006,0x637803e6,0xe29a0036}},	// [7ce0] roin, _küll_, _líng, хаа_,
   {{0x63a43671,0xdb007722,0x6b8901d7,0xa2c00bad}},	//   soin, romé, hieg, लेष्,
   {{0x6b89006a,0xf3f10023,0x63a47723,0x4f0a1d13}},	//   kieg, ật_, poin, енен_,
   {{0xdfcf017e,0x200753b1,0x443a0147,0xdb00021d}},	//   سيه_, ánia_, _isp_, pomé,
   {{0x2cac02c7,0xa2c00084,0x6b892af3,0xef2100ea}},	//   _sydd_, लेश्, dieg, daļā_,
   {{0xa0a67724,0x69c10009,0x6da30274,0x00000000}},	//   _багд, jmle, бича, --,
   {{0x7988003c,0x637801ef,0x69dd0138,0x63710523}},	//   vidw, _cíng, ísen, _månn,
   {{0x40930082,0x3f840a12,0x6b897725,0x69c10298}},	//   _الفر, _ummu_, gieg, emle,
   {{0xfce6141d,0x4974093c,0x443a00f8,0x298a2e50}},	//   _бозо, илис, _lsp_, есно_,
   {{0x2918018d,0x20b8018d,0xaac00835,0x443a7726}},	//   üra_, _अराध, शेषक, _osp_,
   {{0xa3c4006a,0x6b897727,0x443a00ee,0x79887728}},	//   एगा_, bieg, _nsp_, ridw,
   {{0x7c3a7729,0xa3d80567,0x09e30083,0x68e400d0}},	//   _istr, ादन_, _মিরা, _şidd,
   {{0xb8cb0775,0x7afd0093,0x637801ef,0x00000000}},	//   _कु_, ðste, _zíng, --,
   {{0xda7b0d85,0x1c181746,0x26d2018e,0x15eb021a}},	//   _אנדר, _धमाल_, _egyo_, जीगर_,
   {{0x443a02d4,0x27e90009,0x753e1491,0x68fa772a}},	//   _csp_, _čang_, _dapz, matd,
   {{0x1dd407b3,0x75d5132d,0x68fa013b,0xdb2100a0}},	//   ददात, _پيدا, latd, _štúr,
   {{0xa2c00429,0x325501f2,0x50f50af5,0x0f3501cb}},	// [7cf0] लेल्, швар, изат, یکرد,
   {{0x63783612,0x7c3a772b,0xa5bb772c,0x6b896cc0}},	//   _aínd, _ostr, stób, zieg,
   {{0x491c0084,0xb03518cd,0x443a17d0,0x7c3a0210}},	//   _मानो_, рнеш, _gsp_, _nstr,
   {{0x3ead01f4,0x68fa013b,0x2fcd0024,0x00000000}},	//   _pyet_, hatd, _qieg_, --,
   {{0x68fa772d,0x6b890228,0x12fa00a5,0x00000000}},	//   katd, vieg, _בהרב, --,
   {{0x6b89772e,0xe0d403fa,0x443a011e,0xe5f8016b}},	//   wieg, _горњ, _ysp_, נזור_,
   {{0x6b89772f,0x636a008a,0xe80911b5,0x6db900a0}},	//   tieg, _sýni, _विधा_, _kňaz,
   {{0x290a006c,0x3d1729ce,0x7d1a0065,0x8a05195c}},	//   óban_, _नावे_, _ects, азие,
   {{0xc95510b0,0x3f9c00f7,0x63710044,0x00000000}},	//   атны, évue_, _låno, --,
   {{0x636a01ba,0x6b897730,0x637801ef,0x6e3b705b}},	//   _výni, sieg, _tíng, _isub,
   {{0x6b897731,0xb8dd1365,0x7c840185,0x7a4b00cc}},	//   pieg, _आर_, _луце, _bêtô,
   {{0x07a67732,0xc7a600d4,0x316302a7,0xdb260d4f}},	//   рамн, римк, _lojz_, _نومی,
   {{0xda080088,0x68fa013b,0x443a7733,0x7afb4e6d}},	//   _مينه_, batd, _ssp_, maut,
   {{0x443a7734,0x7afb03ad,0xb17b01ff,0x7c3a016e}},	//   _psp_, laut, _stån, _ystr,
   {{0x69db7735,0x63787736,0x673f00da,0x7c3a01a2}},	//   lque, _líne, _faqj, _xstr,
   {{0x7afb1010,0x68e40009,0x6e3b030d,0x00000000}},	//   naut, _đidi, _osub, --,
   {{0xd186081b,0x2b9a00ea,0x6e3b1815,0xd5af00fd}},	// [7d00] алай, nīca_, _nsub, سفہ_,
   {{0x637838bc,0xa3b60066,0x6f1b02d7,0x7afb7737}},	//   _sínd, _चीर_, _acuc, haut,
   {{0x205674e3,0x7afb7738,0x6e3b30c6,0x6b5c006c}},	//   штар, kaut, _asub, _végz,
   {{0xf8b20122,0x7afb7739,0x888c0070,0xd007002d}},	//   חשב_, jaut, עראַ, реце_,
   {{0x68fa00a8,0x4438001e,0xee7a00d1,0x776411fa}},	//   yatd, lwr_, خصات_, _moix,
   {{0x7afb773a,0x7c3a1c7b,0x00000000,0x00000000}},	//   eaut, _pstr, --, --,
   {{0x7afb0657,0x998d004e,0x6e3b773b,0x443800e9}},	//   faut, steś_, _esub, nwr_,
   {{0xe45702b5,0x7c3a74f0,0x7afb773c,0x63783503}},	//   שיקט_, _vstr, gaut, _fíne,
   {{0x32000107,0x3f670bfe,0x0dca005f,0x4438016e}},	//   nsiy_, _тито_, _алай_, hwr_,
   {{0x9f5a0036,0xd90e0416,0xd90d00f8,0x6e22228c}},	//   cupò_, ذیب_, فیه_, mtob,
   {{0x7c3a0169,0x68fa00a8,0x7afb773d,0x776411fa}},	//   _ustr, ratd, baut, _boix,
   {{0x69db63ca,0x4438001e,0x61e60254,0x70d300a9}},	//   bque, dwr_, _otkl, _तल्ल,
   {{0xdb0009ab,0x6e22773e,0x7ae2773f,0x68fa08dd}},	//   nomí, ntob, _ifot, patd,
   {{0x61e97740,0xe81800af,0x68fa0510,0x4438016e}},	//   _çeli, _бокч_, qatd, fwr_,
   {{0x61e60029,0x4438001e,0x77640176,0x999900a0}},	//   _atkl, gwr_, _foix, ísť_,
   {{0x8c3c0095,0x88770122,0x539800d4,0x68f800d4}},	//   _uyğu, _כתוב_, ався_, _hevd,
   {{0x3d170026,0xb7f80033,0xdb1b02b1,0x00000000}},	// [7d10] _नाले_, _অমিত_, hluß, --,
   {{0x2fd87741,0x9f5802fb,0xdb0000ac,0x6f1b0036}},	//   _burg_, _avrà_, domí, _scuc,
   {{0x7bde3207,0x69db0b4c,0x75357742,0x53352aac}},	//   ípul, zque, mezz, _лент,
   {{0x75357743,0xa2a218da,0x68f87744,0x3ef9002d}},	//   lezz, _कुक्, _levd, ундэ_,
   {{0xfce52dbb,0x7afb5087,0x69db00f7,0x03561804}},	//   боло, vaut, xque, _הירש_,
   {{0x7535027a,0x290a42ae,0x68f800d5,0x2fd8021d}},	//   nezz, óbal_, _nevd, _furg_,
   {{0x7afb1467,0x6565007a,0x7094021d,0x00000000}},	//   taut, _mohh, _дарф, --,
   {{0xd4980bed,0x753502fb,0xa3d80066,0x6e3b7745}},	//   יכות_, hezz, ादत_, _tsub,
   {{0x7afb7746,0x8e85004f,0x656508dd,0x1efa0070}},	//   raut, _الذه, _oohh, _תּלמ,
   {{0x69db3253,0x77644802,0x7ae229b0,0xdd9000b5}},	//   rque, _soix, _efot, _ہوۓ_,
   {{0x69db7747,0x2001070b,0x6d412873,0x75357748}},	//   sque, nshi_, _iala, dezz,
   {{0x20010054,0xb17b2bf2,0x6d437749,0xf09200a5}},	//   ishi_, _stål, ldna, לני_,
   {{0x6d414853,0x20010103,0x7535774a,0x254b010b}},	//   _kala, hshi_, fezz, kėlė_,
   {{0x6d411221,0x2001774b,0xf1db08a9,0x6d43774c}},	//   _jala, kshi_, _बढ़न, ndna,
   {{0x6d41774d,0x69d9774e,0x290700d7,0xa3b30099}},	//   _mala, _huwe, _idna_, टतं_,
   {{0x6d4103a2,0x69d9774f,0x443800e9,0x77bd002a}},	//   _lala, _kuwe, rwr_, téxe,
   {{0x69d90e54,0x7af90024,0x7535001c,0x2907002a}},	// [7d20] _juwe, _mewt, bezz, _kdna_,
   {{0x6d417750,0x865b0122,0x69d97751,0x20561346}},	//   _nala, _עדיי, _muwe, йтер,
   {{0xa2b44068,0x600a2705,0xd46a0f88,0x69d90f42}},	//   _आरक्, унем_, _сине_, _luwe,
   {{0x6d4100a7,0xdb002b83,0x66047752,0x4f957753}},	//   _aala, tomí, _kvik, орчу,
   {{0x6d417754,0x471b02b5,0x69d97755,0xde5812ea}},	//   _bala, רונג, _nuwe, ралі_,
   {{0x6d413676,0x6e227756,0xdb007757,0xd2b70122}},	//   _cala, rtob, romí, _ללכת_,
   {{0x6d417758,0x6e227759,0xa3d80f06,0x7f40055c}},	//   _dala, stob, ादि_, _tamq,
   {{0x6d41148b,0x5f960082,0x68f806d3,0xdb0005d3}},	//   _eala, _الرئ, _sevd, pomí,
   {{0x8d1a042c,0x7afd0093,0x386c00e9,0x3914097b}},	//   _مزار_, ðsta, wydr_, омпр,
   {{0xa3d80325,0xdb1a0279,0xad650037,0x69d900f8}},	//   ादा_, _autô, _واله, _duwe,
   {{0x69d950cf,0x2c0b0609,0x7535775a,0xd90f00b5}},	//   _euwe, _معنی_, vezz, ریٹ_,
   {{0x6d41775b,0x7d080159,0xbfb60023,0x69d9034d}},	//   _zala, _hdds, _điềm_, _fuwe,
   {{0x753564bf,0x6d41775c,0x66040a69,0x7bda775d}},	//   tezz, _yala, _cvik, _hutu,
   {{0x7bda775e,0x6d411d82,0xdceb0506,0x442101ef}},	//   _kutu, _xala, čići, _pqh_,
   {{0x7535775f,0x20010be2,0x7bda1c55,0x7aed0043}},	//   rezz, xshi_, _jutu, _întâ,
   {{0xa5bb68b5,0x7bda3f9e,0x56951b50,0x257401ff}},	//   ctón, _mutu, _майт, _häll_,
   {{0x75357760,0x6d437761,0x637801ef,0x2fc600cd}},	// [7d30] pezz, ydna, _sínc, dmog_,
   {{0x7bda0bb0,0x20070bc6,0x20017762,0xdb190107}},	//   _outu, šnim_, tshi_, _jiwò,
   {{0x6d417763,0x7bda7764,0x660400d5,0x610b0029}},	//   _rala, _nutu, _zvik, vēlē,
   {{0x20017765,0x63782132,0x7d080725,0x256f00a8}},	//   rshi_, _vínc, _adds, _sülh_,
   {{0x672d00da,0x8f3400d8,0x787f00b5,0x7bda7766}},	//   _mbaj, яецц, _kávé, _autu,
   {{0x6d410095,0x61ed7767,0x7bda7768,0x1be909c2}},	//   _qala, mpal, _butu, адки_,
   {{0x6d417769,0x7bda3022,0x672d7701,0x6d431d2f}},	//   _vala, _cutu, _obaj, rdna,
   {{0x6d41776a,0x69d900a7,0x7bda01d5,0x764d0448}},	//   _wala, _puwe, _dutu, _oray,
   {{0x6d41776b,0x2ca9004e,0x61ed776c,0x33290625}},	//   _tala, ład_, npal, ifax_,
   {{0x672d776d,0x2d8e03e6,0xe8f95cdf,0x63780093}},	//   _abaj, cife_, шло_, _mína,
   {{0x764d776e,0x7bda3782,0x66047106,0x98bc021e}},	//   _aray, _gutu, _svik, _favč_,
   {{0x69d9776f,0x764d7770,0x3f8f00c7,0xa6ca1e9f}},	//   _tuwe, _bray, nigu_, илна_,
   {{0x99d70bdf,0x764d1c9e,0x6b8b0069,0x25740282}},	//   _اتصا, _cray, _imgg, _fäll_,
   {{0x764d5ddf,0x1a9a0070,0x7bda7771,0x63af00ac}},	//   _dray, _דינע, _yutu, _akcn,
   {{0x764d0381,0x3f8f01d7,0x04431fd8,0x81d60033}},	//   _eray, kigu_, мерн, _সবই_,
   {{0x3f8f0a78,0x764d7772,0x672d0069,0xb5fb00b5}},	//   jigu_, _fray, _gbaj, gyás,
   {{0x27e001cc,0x61ed149b,0xc20a01cb,0x2bca00e7}},	// [7d40] _čini_, gpal, شقان_, ागता,
   {{0x6f0954cf,0xa5bb0473,0x80a80033,0xa1c301e0}},	//   _adec, ntól, _কৃষ্, дбуд,
   {{0x397a0070,0x232a0d46,0x00000000,0x00000000}},	//   סטענ, _кони_, --, --,
   {{0x7bda163a,0x6378008d,0xdce100ec,0x00000000}},	//   _rutu, _fína, _dolč, --,
   {{0x7bda7773,0x6f09001e,0xc6280083,0x3ea07774}},	//   _sutu, _ddec, মিকা_, çit_,
   {{0xa2b90bad,0xbbb400b4,0xdb00006c,0x63a91916}},	//   ्धर्, ुष्क, domá, čene,
   {{0x3f8f3b25,0x60237281,0xd0074e91,0xd47a0070}},	//   bigu_, _одра, _мере_, יאַל,
   {{0x63b60297,0x3f8f00cd,0xdb090079,0x00000000}},	//   nlyn, cigu_, tleá, --,
   {{0x81dc0033,0x7bda01cb,0x61e90381,0x3fc900fd}},	//   ণীর_, _wutu, _çelt, _اگلی_,
   {{0x7bda4f32,0x6f090035,0x77bd002a,0x256f00be}},	//   _tutu, _zdec, déxa, _tüli_,
   {{0x61ed7775,0x3137011d,0xdb090079,0x60db1804}},	//   zpal, חנים_, sleá, יקינ,
   {{0xdbf00033,0x764d7776,0x478b5dbe,0x00000000}},	//   _টিপস_, _pray, рсом_, --,
   {{0xd9463c29,0x61e2004f,0x63b600e9,0xe738010b}},	//   _меди, íoll, dlyn, цеў_,
   {{0xd49b291f,0x00000000,0x00000000,0x00000000}},	//   арб_, --, --, --,
   {{0x7bc27777,0x9f4701d2,0x63780093,0xd7fa0009}},	//   _khou, ënë_, _sína, _тул_,
   {{0x764d7778,0xe5170299,0x200704c3,0x63b67779}},	//   _tray, _ताकि_, šnik_, glyn,
   {{0x764d007b,0xc17502fb,0xbb3b0070,0x6f090116}},	// [7d50] _uray, плащ, סעמי, _rdec,
   {{0x61ed777a,0x799a0bcf,0x3d040035,0xdce11b89}},	//   rpal, nntw, रणों_, _polč,
   {{0x61ed777b,0xe5200006,0x80071ac5,0x00000000}},	//   spal, _बाति_, ючае, --,
   {{0x61ed777c,0x26120803,0x2d9e0506,0x64580a66}},	//   ppal, _तिमी_, _ajte_, _švig,
   {{0x3f8f777d,0x63ad777e,0xfce507bc,0x249f0448}},	//   rigu_, moan, поло, ğumu_,
   {{0x63ad3a06,0x799a006d,0xf1bf007e,0x3f8f00b9}},	//   loan, jntw, _cpát_, sigu_,
   {{0x3f8f777f,0x7afd008d,0x00000000,0x00000000}},	//   pigu_, ðsto, --, --,
   {{0x7bc27780,0x63ad7781,0xdb002140,0x4433163f}},	//   _chou, noan, tomá, _mpx_,
   {{0xdb0e004f,0x3f8d023a,0x3eb9008d,0x00000000}},	//   ódál, _imeu_, _ást_, --,
   {{0x8d7718dd,0x63ad4ede,0x88850374,0xdb007782}},	//   _بارا, hoan, злож, romá,
   {{0xa3bd006a,0xf8ce1bb5,0x5eb00083,0x63ad7783}},	//   ेगा_, _हृदय, জেদে, koan,
   {{0x7bc20298,0xa5bb68e6,0x63ad01ed,0x917900e2}},	//   _ghou, stól, joan, _lần_,
   {{0x200702dd,0xf1bd0d41,0x63ad7784,0x7bc97785}},	//   šnih_, ्गान, doan, mmeu,
   {{0x7bc27786,0x00000000,0x00000000,0x00000000}},	//   _zhou, --, --, --,
   {{0x69c31bed,0x63ad002d,0x44330160,0x9879016b}},	//   _ihne, foan, _cpx_, _לאַט,
   {{0x63ad7787,0x6b9b7788,0x46a60823,0x7bc9213d}},	//   goan, nnug, _найв, nmeu,
   {{0x171b0122,0x63b67789,0x00000000,0x00000000}},	// [7d60] _הופע, rlyn, --, --,
   {{0x63b60435,0x91790023,0x00000000,0x00000000}},	//   slyn, _cần_, --, --,
   {{0x63ad778a,0x63b600ac,0x00000000,0x00000000}},	//   boan, plyn, --, --,
   {{0x63ad778b,0xdfcf1301,0x63a9778c,0x77b6002a}},	//   coan, هيل_, čenc, fáxi,
   {{0x69c800e9,0x3322002a,0x69c3033b,0x7bc90223}},	//   ymde, _ickx_, _ohne, dmeu,
   {{0x7bc20052,0x2574013c,0xc8ff0033,0x917900cc}},	//   _shou, _sälj_, ্ভুত_, _gần_,
   {{0x64581dad,0x62840036,0x00000000,0x00000000}},	//   _ávid, lzio, --, --,
   {{0x26c00036,0x316a0069,0x69c3778d,0x7bc97014}},	//   _ozio_, _hobz_, _ahne, gmeu,
   {{0x6284778e,0xc3330052,0x2574022a,0x6f0201f2}},	//   nzio, תוח_, _välj_, maoc,
   {{0x6284778f,0x63ad7790,0x69c3239a,0x6f020079}},	//   izio, zoan, _chne, laoc,
   {{0x7bc20052,0x63ad0054,0xac76126b,0x00000000}},	//   _thou, yoan, _عائش, --,
   {{0x628406a2,0xe69500c3,0x6f02002f,0xba2a00d1}},	//   kzio, димы, naoc, _هستم_,
   {{0x27e02fbd,0x637801ef,0x3cfe004b,0x00000000}},	//   _činu_, _pínn, _ketv_, --,
   {{0x6284297a,0xa3d801d1,0xf80600af,0x69c30211}},	//   dzio, ादं_, _ечин, _ghne,
   {{0x92b900c8,0x62847791,0x26c0027a,0x26120437}},	//   _চলে_, ezio, _ezio_, _तिथी_,
   {{0x201a1b1e,0x57c80ed1,0xa5d81328,0x636808ce}},	//   dupi_, रगृह, _کبير_, пруг_,
   {{0xa2cd37dd,0x6f021269,0x63ad7792,0x6234002d}},	// [7d70] _दृश्, daoc, roan, нету,
   {{0x932700d1,0x63ad7793,0x645800d8,0x291e7794}},	//   _کردن, soan, _švie, ngta_,
   {{0x62847795,0xf1c8004f,0x44277796,0xf1bf0037}},	//   azio, أولى_, _ën_, _spás_,
   {{0x27f87797,0x3cfe021d,0x00000000,0x00000000}},	//   árny_, _aetv_, --, --,
   {{0xa3aa0035,0x09140083,0xa3e305e7,0x325400d8}},	//   खकर_, ত্যু_, _फंड_, _звяр,
   {{0xdd91211b,0x3cfe06fe,0xed560f08,0x361c00a5}},	//   ضوع_, _cetv_, дош_, מודד,
   {{0x40342147,0x201a027a,0xdbf10355,0xdca27798}},	//   _перс, cupi_, příj, каши,
   {{0x291e00ea,0xdce100ea,0x69c37799,0x00000000}},	//   egta_, _dolā, _shne, --,
   {{0x7bc9779a,0x00000000,0x00000000,0x00000000}},	//   rmeu, --, --, --,
   {{0x98bc0029,0x64481f8b,0xfe7012de,0x00000000}},	//   _savā_, ædik, _صدق_, --,
   {{0xa3ad2fa9,0x7d03779b,0x07a6311c,0xc7a61743}},	//   गवा_, mans, данн, динк,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63781d2b,0x2eff00a2,0xe809021a,0x00000000}},	//   _síno, _meuf_, _विका_, --,
   {{0xa3b6111e,0xdd990260,0xe00d1365,0x00000000}},	//   _चीज_, _dwňg_, _हिंद_, --,
   {{0x2eff779c,0x66060159,0x98bc0228,0x6fad0099}},	//   _oeuf_, sskk, _tavā_, टकां,
   {{0x3947779d,0x2eff02e1,0x7d03504f,0x62840b9b}},	//   _hans_, _neuf_, hans, tzio,
   {{0x6f020b16,0x3947779e,0x672402c4,0x7d030147}},	// [7d80] vaoc, _kans_, _icij, kans,
   {{0x7d030888,0x628401d3,0x1de10084,0x201a1034}},	//   jans, rzio, _पढ़त, tupi_,
   {{0x3947779f,0x6f021269,0x672402c4,0x753c77a0}},	//   _mans_, taoc, _kcij, merz,
   {{0x444435d9,0x213a77a1,0x200703e6,0x394777a2}},	//   _is_, seph_, ânia_, _lans_,
   {{0x444477a3,0x6f020009,0x7d0377a4,0x201a012f}},	//   _hs_, raoc, fans, supi_,
   {{0x753c2754,0x7644023c,0xa3e30ec5,0x2d570421}},	//   nerz, _msiy, _फूड_, дишь_,
   {{0x6724044d,0xac97017e,0x00000000,0x00000000}},	//   _ocij, ونها_, --, --,
   {{0x753c77a5,0x444406b5,0x672402c4,0xdd990107}},	//   herz, _ms_, _ncij, _awňd_,
   {{0x44440ae0,0x7d0377a6,0x3d170084,0x442a012f}},	//   _ls_, bans, _नाचे_, htb_,
   {{0x444477a7,0x7d0377a8,0x67240200,0x7981016e}},	//   _os_, cans, _acij, ghlw,
   {{0x3947168b,0xed4f0088,0x6d5a77a9,0x753c77aa}},	//   _dans_, _خپل_, _inta, derz,
   {{0x6d4877ab,0x6d4a77ac,0x6d5a0159,0x657e77ad}},	//   _hada, ldfa, _hnta, _alph,
   {{0x444401f3,0x6d4877ae,0xa5bb004f,0x6a860210}},	//   _as_, _kada, ltói, _юлда,
   {{0x444477af,0x6d4877b0,0xe9440118,0x442a0069}},	//   _bs_, _jada, _سرتی, ftb_,
   {{0xa5bb004f,0x6d480cec,0x44445294,0xca480023}},	//   ntói, _mada, _cs_, _hờ_,
   {{0x444477b1,0x69d877b2,0x6d4877b3,0x7d0377b4}},	//   _ds_, _hive, _lada, zans,
   {{0x444477b5,0x7d0377b6,0x69d8418e,0x753c77b7}},	// [7d90] _es_, yans, _kive, berz,
   {{0x7d0377b8,0xca480019,0x776d0088,0x6f000176}},	//   xans, _mờ_, _hoax, _aemc,
   {{0x69d8006c,0x7d0377b9,0x661d77ba,0x776d1cc5}},	//   _mive, vans, lusk, _koax,
   {{0x644577bb,0x6d4877bc,0x7d0377bd,0xc7b90207}},	//   _ishi, _aada, wans, buđe_,
   {{0x6d4877be,0x427900c2,0x444477bf,0x661d3efc}},	//   _bada, _זאָג, _zs_, nusk,
   {{0x6d4877c0,0x320977c1,0x6d5a0069,0x7c2a2af9}},	//   _cada, msay_, _cnta, ftfr,
   {{0x7d0377c2,0x6d4877c3,0xfc3100d2,0xabd511b9}},	//   rans, _dada, احت_, нциј,
   {{0x394777c4,0x6d5a77c5,0x661d77c6,0x6d48004a}},	//   _sans_, _enta, kusk, _eada,
   {{0x7d0377c7,0x320977c8,0x6d4877c9,0xca480019}},	//   pans, nsay_, _fada, _cờ_,
   {{0x6d4877ca,0x661d00ab,0xf991004f,0x08890043}},	//   _gada, dusk, طبخ_, збой_,
   {{0x7b672294,0x64450232,0x673d1379,0x661d01b7}},	//   _отде, _nshi, fesj, eusk,
   {{0x6d4877cb,0x70dc20d8,0x673d00f7,0xc0520070}},	//   _zada, _बल्ल, gesj, אזט_,
   {{0x753c77cc,0x644577cd,0x39470173,0xb4d80026}},	//   terz, _ashi, _tans_, िश्_,
   {{0x69d877ce,0x7d010332,0x3209026e,0x18a55195}},	//   _give, _jels, dsay_, _палм,
   {{0x290577cf,0x44442400,0x64a30aef,0x7d010409}},	//   mala_, _qs_, гара, _mels,
   {{0x290577d0,0x7ae977d1,0x753c02fb,0x3878177c}},	//   lala_, ncet, serz, ørre_,
   {{0x44445566,0xd2a71d5b,0x64455db9,0x3209010d}},	// [7da0] _ws_, екте_, _eshi, gsay_,
   {{0x290577d2,0x444477d3,0x644501f4,0xf1a9028f}},	//   nala_, _ts_, _fshi, واله_,
   {{0x4444355f,0x6d5c01a6,0xc7b9011c,0x251b0070}},	//   _us_, _òrai, suđe_, _צוטא,
   {{0x6d4877d4,0x290577d5,0xdee653b7,0x59df02e4}},	//   _sada, hala_, ходи, नदार,
   {{0x6d4877d6,0x290577d7,0x7d01006c,0x61e4009f}},	//   _pada, kala_, _bels, qqil,
   {{0x290502b2,0x6d480095,0x29fd016f,0xd00a02c4}},	//   jala_, _qada, dňa_, _неге_,
   {{0x6d4877d8,0x6d4a77d9,0x69d85f00,0x7d012a94}},	//   _vada, rdfa, _rive, _dels,
   {{0x6d4877da,0x69d877db,0x5a345b66,0xa3e30084}},	//   _wada, _sive, внит, _फंस_,
   {{0x7d0177dc,0xbea31d99,0x7c2a038d,0x6d4818cc}},	//   _fels, _батк, stfr, _tada,
   {{0x290577dd,0x7d0177de,0xf8ab0023,0x7bde77df}},	//   gala_, _gels, ười_, ípus,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3209300c,0x661d77e0,0xca4801a5,0x7ae936c1}},	//   ysay_, tusk, _tờ_, ccet,
   {{0x290577e1,0x69d80bb0,0x95cb0800,0x673d77e2}},	//   bala_, _tive, зува_, resj,
   {{0x661d77e3,0xceb30319,0xbf0c00a1,0x64450160}},	//   rusk, ריש_, हणुन_, _pshi,
   {{0x94a81e38,0x3cf31ef5,0xf48412ea,0xf434010b}},	//   етта_, ुरते_, гутн, лерэ,
   {{0x661d77e4,0x32090107,0x63a900cd,0x58bb00a5}},	//   pusk, tsay_, čeno, _ממוצ,
   {{0xdb1b0279,0xdcfa0260,0xaac9000c,0x00000000}},	// [7db0] fluê, _altč, ाइएक, --,
   {{0x644501a9,0x20070132,0x00000000,0x00000000}},	//   _tshi, ânio_, --, --,
   {{0x644577e5,0xbf0c0429,0x7d01008c,0xd01000b5}},	//   _ushi, हणून_, _rels, یلے_,
   {{0x29056d30,0x7d01177c,0x29fd01ba,0x660d0506}},	//   zala_, _sels, yňa_, _kvak,
   {{0x29053998,0x7bd9012f,0xe8d90023,0x7d0177e6}},	//   yala_, _riwu, _đọ_, _pels,
   {{0x23690a16,0x29fd016f,0xb17b008c,0x7bd9030d}},	//   ljaj_, vňa_, _etår, _siwu,
   {{0x7d0111cb,0xae020084,0xdd8e026e,0x7bd900f8}},	//   _vels, रीबन_, توو_, _piwu,
   {{0x660d01cc,0xd9c9112b,0x236903ab,0x257401ae}},	//   _ovak, रष्ट, njaj_, _hält_,
   {{0x7ae977e7,0x7d0177e8,0x99dd00a0,0xa3e3052f}},	//   rcet, _tels, yvňu, _फूस_,
   {{0x7ae977e9,0xc79800b5,0x00000000,0x00000000}},	//   scet, کھتا_, --, --,
   {{0x29052cb7,0x98a5235d,0x78863f18,0xd7f800d8}},	//   rala_, тине, _révé, нуў_,
   {{0xc6260083,0xf4270033,0x637864ec,0x00000000}},	//   যবসা_, মবার_, _vínk, --,
   {{0x29050ac8,0x07a300af,0xfbd00088,0x2369022f}},	//   pala_, раян, _اتل_, djaj_,
   {{0x29051787,0x660d3e39,0x2b4d0207,0x64a677ea}},	//   qala_, _dvak, ldec_, вага,
   {{0x232a31d3,0x5fd10067,0x00000000,0x00000000}},	//   мови_, तगाल, --, --,
   {{0xd7ca2149,0x00000000,0x00000000,0x00000000}},	//   _توبه_, --, --, --,
   {{0xe29748b4,0x91e332fa,0x3a2d77eb,0x59c60035}},	// [7dc0] ват_, иоте, ntep_, _रीडर,
   {{0xdce86367,0x30760fdd,0x91a70023,0x1617073f}},	//   _podč, куес, _địa_, _तितर_,
   {{0x63780955,0x660d77ec,0x00000000,0x00000000}},	//   _líni, _zvak, --, --,
   {{0x311e00b4,0x443a6150,0xbf0c00e7,0x00000000}},	//   _पाकः_, _ipp_, हणेन_, --,
   {{0x257401ff,0x443a1575,0x637801ef,0xae020066}},	//   _fält_, _hpp_, _níni, _रौशन_,
   {{0x1ea90125,0xa5bb0132,0x61f635a1,0x3c0c0355}},	//   راني_, stóv, mpyl, těv_,
   {{0xa2d6142a,0x50c60f17,0x443a0260,0xed5700ed}},	//   _मृत्, _वरिष, _jpp_, тој_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443a3e38,0x63710282,0x00000000,0x00000000}},	//   _lpp_, _månp, --, --,
   {{0x3f8677ed,0x443a0044,0xa3c90437,0x1e8312ea}},	//   lhou_, _opp_, _लीन_, _тлум,
   {{0x660d1254,0x9963005f,0x63780132,0xdca30af4}},	//   _svak, ртыл, _tính, _кафи,
   {{0xa3e60992,0x3f8677ee,0x68f50448,0x7c850200}},	//   _पढ़_, nhou_, ızda, _суђе,
   {{0xb5fb006c,0xa93400af,0x00000000,0x00000000}},	//   lyáz, _белш, --, --,
   {{0xe85402aa,0x443a77ef,0xdb110093,0x00000000}},	//   _منتد, _bpp_, ðgön, --,
   {{0x6b8201b4,0x984a02fb,0xdb1b0310,0x3f860298}},	//   _klog, _цяла_, fluè, khou_,
   {{0x443a77f0,0x31db0808,0x64430132,0x61f60345}},	//   _dpp_, बद्ध, _ânim, fpyl,
   {{0x31350f08,0x443a77f1,0x236908b7,0x2eed0138}},	// [7dd0] леар, _epp_, rjaj_, _rfef_,
   {{0x6b8277f2,0x7c3a77f3,0x23690506,0x3d1c0035}},	//   _llog, _optr, sjaj_, नलों_,
   {{0x6b820024,0x439516bc,0x00000000,0x00000000}},	//   _olog, _банс, --, --,
   {{0x5ecc0033,0x547a025a,0x3f860b88,0x00000000}},	//   িশনে, _נטרו, ghou_, --,
   {{0xb287325e,0x61e20037,0x3ea90443,0x7c3a04ff}},	//   _рынк, íolt, çat_, _aptr,
   {{0x6b8230af,0xdca51353,0x3ea90484,0x00000000}},	//   _alog, лали, ħat_, --,
   {{0xe8d901a5,0x6378004f,0x443a00fe,0xa19477f4}},	//   _đỏ_, _síni, _xpp_, _тарч,
   {{0x2918451f,0x0a490fdd,0x0b4506e4,0x637800ee}},	//   óran_, езий_, унин, _píni,
   {{0xe9d90e75,0x69ca0082,0x29c20093,0x2b4d77f5}},	//   нки_, _bhfe, rðan_, rdec_,
   {{0x6b8277f6,0x3ea00098,0xd9450200,0x5ac6081b}},	//   _elog, úite_, ћени, ылым_,
   {{0x63a90496,0x6b8277f7,0x2d8702a8,0xa3e313ab}},	//   čenj, _flog, mhne_, _फूल_,
   {{0x443a77f8,0xeb7400d8,0x29190448,0xa5bb0098}},	//   _rpp_, _вышэ, şsa_, nróf,
   {{0x645777f9,0x6378008d,0x00000000,0x00000000}},	//   _arxi, _kínv, --, --,
   {{0xceb20052,0x1a9a00c2,0x3f8677fa,0x5eb00083}},	//   צים_, _אינע, zhou_, জেকে,
   {{0xc7b900cb,0x3ceb0461,0x23360525,0x00000000}},	//   suđa_, _चलने_, лхар, --,
   {{0xf77204cd,0xe5200006,0x6e3b0035,0xb17b029e}},	//   _چاک_, _बाकि_, _opub, _ståp,
   {{0x2d87012f,0x31710118,0xf7720fa2,0xa5bb002a}},	// [7de0] khne_, _bozz_, _ناک_, dróf,
   {{0x7afb0088,0x201a00f4,0x00000000,0x00000000}},	//   hbut, trpi_, --, --,
   {{0x443a77fb,0xef1a0896,0x3f860626,0x2d8701a6}},	//   _upp_, еме_, thou_, dhne_,
   {{0x20551813,0xa5bb0473,0x77bd01dd,0x5f0677fc}},	//   штур, stót, téxi, узда,
   {{0x63a409bd,0x5276094f,0x7afb03c1,0x3f86053e}},	//   mnin, _суну, dbut, rhou_,
   {{0x63a477fd,0xa5bb77fe,0xf987211b,0x3f8677ff}},	//   lnin, ltór, _طب_, shou_,
   {{0x63a47800,0x6b827801,0xa3c90084,0x61e60159}},	//   onin, _plog, _लीड_, _hukl,
   {{0x63a47802,0x7afb2487,0x61e67803,0xa5bb184d}},	//   nnin, gbut, _kukl, cróf,
   {{0xe8d900e8,0x3f840464,0x63a47804,0xcd43006c}},	//   _đề_, _ilmu_, inin, _گھنٹ,
   {{0xdd8f2e63,0x63a44808,0x7afb2af6,0x00000000}},	//   _فوق_, hnin, abut, --,
   {{0x63a403c1,0xa5bb004e,0x61e67805,0x6b82022e}},	//   knin, któr, _lukl, _tlog,
   {{0x6b8201cc,0x63a47806,0x8c1b02b8,0x7d0a55e5}},	//   _ulog, jnin, _טובי, lafs,
   {{0x63a410fa,0x7ae201d7,0x6e220409,0x00000000}},	//   dnin, _igot, nuob, --,
   {{0x7d0a0657,0x63a439df,0x6378008a,0xddc201c0}},	//   nafs, enin, _mínu, tvoř,
   {{0x64583641,0x63a4008a,0x61e67807,0x63780093}},	//   _ávil, fnin, _aukl, _línu,
   {{0x63a47808,0x98130071,0x61e67809,0x7d0a780a}},	//   gnin, _ابوا, _bukl, hafs,
   {{0x31710c21,0x799a08c7,0x6e2200f4,0x00000000}},	// [7df0] _pozz_, oitw, juob, --,
   {{0x61e6219e,0xa5bb780b,0xf527002d,0x3f84009f}},	//   _dukl, dróg, _сфин, _almu_,
   {{0x63a412ac,0x31c40086,0x645701ef,0x6e3b0176}},	//   bnin, сств, _urxi, _spub,
   {{0x7ae2780c,0xa5bb0f84,0x63a4780d,0xc7b901f2}},	//   _ngot, ctór, cnin, brđe_,
   {{0x2d870094,0x11d9004f,0xaf0402ce,0x44236064}},	//   thne_, _لوحة_, спіл, luj_,
   {{0x3f84780e,0x7ae2112c,0x4431780f,0x7bc002a2}},	//   _elmu_, _agot, otz_, elmu,
   {{0x44317810,0x7afb1058,0x799a2063,0x4c690036}},	//   ntz_, tbut, ditw, тийн_,
   {{0x69ca1e79,0x543c02b5,0x443101d7,0x61e610b1}},	//   _सीबी, געהא, itz_, _yukl,
   {{0x7afb7811,0x2d877812,0x4423024e,0xa3d606bc}},	//   rbut, phne_, huj_, िगत_,
   {{0x44237813,0x7ae206a2,0x63a40121,0x661d03ab}},	//   kuj_, _egot, znin, drsk,
   {{0x2d857814,0x63a47815,0x661d7816,0xfd10004f}},	//   _ille_, ynin, ersk, _رجل_,
   {{0x6d43778f,0x3ebf1fd9,0x44233f44,0x63a401ff}},	//   lena, _kyut_, duj_, xnin,
   {{0xf1c52fa9,0x63a47817,0x44317818,0xe8ee5da8}},	//   वतान, vnin, etz_, _мл_,
   {{0x6d43725f,0x44317819,0x63780079,0x7ae241d8}},	//   nena, ftz_, _línt, _zgot,
   {{0x63a474d8,0x4423006a,0x61e6781a,0xa50713f8}},	//   tnin, guj_, _sukl, реса_,
   {{0x6d43781b,0x6b9b781c,0x61e6103c,0x29072318}},	//   hena, niug, _pukl, _hena_,
   {{0x6d43781d,0x2907781e,0x63a4781f,0x44310065}},	// [7e00] kena, _kena_, rnin, atz_,
   {{0x63a40075,0xa5bb76ed,0x69c15917,0x6d430d7c}},	//   snin, stór, nlle, jena,
   {{0x69c17820,0x637800fb,0x29077821,0x63a47822}},	//   ille, _sínu, _mena_, pnin,
   {{0x2d850d51,0x29077823,0x61e67824,0x3fcb0ef2}},	//   _alle_, _lena_, _tukl, ندنی_,
   {{0x2bdf0fd1,0x7d0a484c,0x2fcd01cb,0x799a01d5}},	//   _पंजा, tafs, _dheg_, yitw,
   {{0x6d437825,0x29072f8b,0xdd8f0c74,0x660408c6}},	//   gena, _nena_, وون_, _mwik,
   {{0xa0a31334,0xa06702fb,0x29180037,0x3f9c000d}},	//   _дард, _кара_, óram_, évus_,
   {{0x2d85105d,0x27e00d36,0x69c17826,0x29070d9a}},	//   _elle_, _niin_, elle, _aena_,
   {{0x6d43431f,0xfe0200ab,0x44237827,0x69c10176}},	//   bena, रीशस_, zuj_, flle,
   {{0x63a90ba8,0x6d432993,0x27e0009e,0x27e70185}},	//   čeni, cena, _aiin_, _bunn_,
   {{0xe8d9098b,0x2bdf0821,0x29070291,0x3ceb0b4a}},	//   _để_, _पंचा, _dena_, _चलते_,
   {{0x7ae202c6,0x6b9b0382,0xdc9b0317,0x200700af}},	//   _ugot, ciug, _ביבל, ânii_,
   {{0x27e003be,0xaad209b1,0x799a08c7,0x29070225}},	//   _diin_, देशक, pitw, _fena_,
   {{0x44237828,0x66040ac8,0xd943021d,0xe4a70804}},	//   tuj_, _dwik, _мечи, арбо,
   {{0x7d087829,0xdb0901dd,0x27e7782a,0x67d50043}},	//   _meds, cleó, _gunn_, _локу,
   {{0x052700c8,0x4423782b,0x6d43782c,0x4431782d}},	//   য়ের_, ruj_, zena, rtz_,
   {{0x4423782e,0x2907073a,0x6d43782f,0xa7870416}},	// [7e10] suj_, _yena_, yena, _مشکو,
   {{0x63787830,0x2d9c1851,0x7d0802df,0x6d437831}},	//   _sínt, jive_, _neds, xena,
   {{0x50670279,0x2d9c25ea,0x290c0519,0x6378002a}},	//   штаа, dive_, iada_, _pínt,
   {{0x290c2929,0x6d437832,0xa14600ec,0x00000000}},	//   hada_, wena, _apķē, --,
   {{0x290c18cc,0x7d080022,0x2d9c0055,0xef1801e0}},	//   kada_, _beds, five_, рмі_,
   {{0x2bdf43fd,0x764d0159,0x2d9c08c8,0x2249011e}},	//   _पूजा, _msay, give_, mwak_,
   {{0xeb997833,0x29077834,0x672d022f,0x6d4335f9}},	//   лик_, _rena_, _ocaj, rena,
   {{0x29077835,0x672d01e8,0x290c1d2b,0xa6db0093}},	//   _sena_, _ncaj, eada_, veðn,
   {{0x290c7836,0x6d437837,0x69c112c3,0x61ed7838}},	//   fada_, pena, tlle, nqal,
   {{0x8d740082,0x27e00006,0x7d74004f,0x6f09055c}},	//   _والا, _siin_, _والط, _heec,
   {{0x69c10297,0x6d8a006c,0x66e67229,0x764d7839}},	//   rlle, _حملہ_, йона, _asay,
   {{0x4cd00083,0x290702d7,0x07a600af,0x103a0070}},	//   _স্কু, _wena_, самн, נגרע,
   {{0x290c783a,0x29070657,0x6fda00b8,0x27e0783b}},	//   bada_, _tena_, _důch, _viin_,
   {{0x225e053d,0xa5bb002a,0x00000000,0x00000000}},	//   _čtk_, erób, --, --,
   {{0x39450afc,0x764d04ee,0xa3b4000c,0xf7f528c0}},	//   mels_, _esay, टवल_, _استد,
   {{0x2d9c783c,0x087602b5,0x66044d0b,0x6f090160}},	//   zive_, _לעצט_, _twik, _neec,
   {{0xae1c0518,0x42ca083e,0x22490159,0x98a500c7}},	// [7e20] _निधन_, уган_, gwak_, telė_,
   {{0x2d9c2b28,0x39451762,0x00000000,0x00000000}},	//   xive_, nels_, --, --,
   {{0xa99a0070,0x7ee60037,0x557700a5,0x7d08783d}},	//   נבער, مكان, _העין_, _reds,
   {{0x290c1423,0x543b02b5,0xdb1b0391,0x394503bc}},	//   zada_, _געטא, fluí, hels_,
   {{0x290c0716,0x2d9c783e,0x39450626,0xdb00783f}},	//   yada_, tive_, kels_, romü,
   {{0xa1160357,0x290c1561,0x13bd0083,0x00000000}},	//   _دوست, xada_, _আওয়, --,
   {{0x3086004f,0x39457840,0x7d080f0a,0xe4fb01c0}},	//   _الأف, dels_, _veds, ्रति_,
   {{0x7d080244,0x290c7841,0x207b016b,0x00000000}},	//   _weds, wada_, _גאלא, --,
   {{0x290c7842,0xdb1b59d6,0x39457843,0x1e8603d0}},	//   tada_, cluí, fels_, _улам,
   {{0xdb004a74,0x996613f9,0xd7fa55c5,0xd90e04e8}},	//   tomó, стил, лум_, ریب_,
   {{0x91bb0317,0xc1bb016b,0x31571804,0x7776055c}},	//   רמיי, רמיש, זיין_, _boyx,
   {{0xe61f0279,0x3a247844,0x00000000,0x00000000}},	//   trô_, pump_, --, --,
   {{0x290c06ad,0x8f9b0122,0xa3be2874,0x39450a2e}},	//   pada_, ריכי, ेतन_, bels_,
   {{0x290c013b,0x394500ec,0x00000000,0x00000000}},	//   qada_, cels_, --, --,
   {{0xa2db0afa,0x96f91b96,0x8937024b,0x00000000}},	//   पेन्, _кейт_, _לרגע_, --,
   {{0x07a404bf,0xc7b90009,0x26120099,0x00000000}},	//   _најн, brđa_, _तिची_, --,
   {{0x1620045c,0x5215218b,0x764d0103,0x00000000}},	// [7e30] _बियर_, юдат, _usay, --,
   {{0x61ed72a4,0x35f80037,0x27e10097,0x00000000}},	//   rqal, _اريد_, _činy_, --,
   {{0xa5bb07cf,0x6f097845,0xd498002d,0x00000000}},	//   prób, _peec, _гря_, --,
   {{0xe7c9112b,0x657700da,0xd7c908b0,0x201c7846}},	//   रतिप, _hoxh, रतिच, ávia_,
   {{0x61ed013b,0xa3d60066,0x7dcd0392,0x6db540b4}},	//   qqal, िगर_, júsc, ойду,
   {{0xed594d2e,0xdb02064b,0xb4fb0e6f,0x00000000}},	//   рок_, _skoð, ्रिय_, --,
   {{0x39450122,0xd7c900a1,0xe7c90b35,0x6577078b}},	//   vels_, रताच, रताप, _moxh,
   {{0xa2d000a1,0x2a600612,0xa2be0067,0xdd990107}},	//   _दरम्, _šiba_, _वुड्, _kwňk_,
   {{0x69251b4f,0x84fb05dc,0x39451de8,0xb4fb074f}},	//   омпа, ्राट_, tels_, ्राय_,
   {{0xe8df00e8,0x3cf100a8,0x397900c3,0x00000000}},	//   _giới_, _üzv_, рсию_, --,
   {{0x39457847,0xa3d9073f,0xa6db003e,0x0cab02fb}},	//   rels_, ाषा_, seðl, _стаи_,
   {{0x39457848,0x656500e2,0xa3c923db,0x00000000}},	//   sels_, _anhh, _लील_, --,
   {{0x39457849,0x70c63933,0x65770523,0xa9691159}},	//   pels_, _वर्ल, _boxh, _вила_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe732004f,0xc7b9012e,0xa5bb0035,0x00000000}},	//   _قصة_, srđa_, wróc, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7e40] --, --, --, --,
   {{0x92cb0139,0x65770031,0x10a67517,0xb1430043}},	//   _dacπ_, _goxh, оизн, мнул,
   {{0xa2e6784a,0xd46a002d,0x25e30084,0xf21e22a3}},	//   _монд, _тине_, _टूटी_, यूज़_,
   {{0xddc9004e,0x7dcd00de,0x645e07e5,0xd00f0987}},	//   _treś, yúsc, _irpi, ئلن_,
   {{0x645e0124,0x88cf0033,0xa3e30ec5,0x00000000}},	//   _hrpi, রশিক, _फूट_, --,
   {{0x645e0a18,0x7c660957,0x00000000,0x00000000}},	//   _krpi, قابل, --, --,
   {{0x0b8a2351,0x00000000,0x00000000,0x00000000}},	//   исии_, --, --, --,
   {{0x386000cd,0x447b016b,0x00000000,0x00000000}},	//   _čir_, ינצע, --, --,
   {{0x6f0220d9,0x9f4d02b1,0x00000000,0x00000000}},	//   mboc, _hieß_, --, --,
   {{0x290a6e4c,0x7afd00a8,0x2fc6784b,0x6d230200}},	//   úba_, ısta, llog_, _одуз,
   {{0x6c4a00f5,0x81570070,0x28d500b4,0xd7f40104}},	//   _خلاف_, קסטע_, डेलि, язны,
   {{0x6f02784c,0x7dcd1ea3,0xa3c9007c,0x2fc6784d}},	//   nboc, púsc, _लीं_, nlog_,
   {{0x8bd700c2,0xdb0901ae,0x9f4d033b,0x645e784e}},	//   _וואו_, ließ, _ließ_, _arpi,
   {{0x26c50029,0x753b0009,0x94ab0382,0x00000000}},	//   ālo_, đuzo, атба_, --,
   {{0x2fc66c6b,0x6e221cc5,0x7dcd0037,0xe8d90019}},	//   klog_, hrob, núsa, _đệ_,
   {{0x27fe022e,0x645e022f,0x00000000,0x00000000}},	//   mptn_, _drpi, --, --,
   {{0xe1f00a86,0x51f8021f,0xdb09033b,0x3be70023}},	// [7e50] نسل_, жную_, hieß, _hđqt_,
   {{0x6e221834,0x94d5002d,0x1620046c,0x7d1a0027}},	//   drob, _нопц, _बितर_, _ndts,
   {{0x6e22784f,0xf48500d1,0x6616024e,0x2fc600e9}},	//   erob, _رادی, _zvyk, flog_,
   {{0x63a90076,0xb4d704eb,0x2fc600cd,0x4fe80409}},	//   čens, िधी_, glog_, імін_,
   {{0x6e227850,0x8d651583,0x51873b8b,0x00000000}},	//   grob, звле, _дува, --,
   {{0xf2d20317,0x2708021a,0x317802d6,0xc27a00a5}},	//   _נעם_, _वज्र_, _gorz_, _הרשי,
   {{0x1fa730ca,0x30a404bf,0x4e1701c0,0xe9ce12ea}},	//   _драг, _жртв, _निकै_, _якi_,
   {{0x6e227851,0x63710282,0x00000000,0x00000000}},	//   brob, _påny, --, --,
   {{0x6f1b7852,0x80e00033,0x00000000,0x00000000}},	//   _iduc, _প্প্, --, --,
   {{0xacf402fd,0x7dcd0098,0x00000000,0x00000000}},	//   _قسمت, búsa, --, --,
   {{0x7c5900d1,0x00000000,0x00000000,0x00000000}},	//   _دلار_, --, --, --,
   {{0xaadf021a,0xe73a3622,0x7b641583,0xeaae00b5}},	//   _पृथक, щем_, _отче, ئٹی_,
   {{0x987708b7,0x00000000,0x00000000,0x00000000}},	//   _išče_, --, --, --,
   {{0x386a0082,0x2fc602f0,0x645e0124,0xa2af00e7}},	//   óirí_, zlog_, _prpi, ंपन्,
   {{0x6f1b7853,0x2fc67854,0x6e220035,0x00000000}},	//   _oduc, ylog_, zrob, --,
   {{0x6d86008a,0x00000000,0x00000000,0x00000000}},	//   _aðal, --, --, --,
   {{0xe8d900e8,0x00000000,0x00000000,0x00000000}},	// [7e60] _độ_, --, --, --,
   {{0x6f1b0043,0x7dc412c3,0x645e704e,0x201c0279}},	//   _aduc, pòsi, _trpi, ávio_,
   {{0xdefa00c3,0x757b0122,0xfbcb112b,0x00000000}},	//   был_, _הטיפ, ाताम, --,
   {{0x91e6487d,0x6e227855,0x442a007c,0x444400a5}},	//   _номе, trob, mub_, _ip_,
   {{0x442a7856,0x2fc61516,0x44382b22,0x645c7857}},	//   lub_, rlog_, ltr_, lvri,
   {{0x2fc638b9,0x6f1b3ec3,0x763b0070,0x2a6002a7}},	//   slog_, _educ, מענג, _šibo_,
   {{0x44447858,0x442a01c2,0x44380043,0x2fc62981}},	//   _jp_, nub_, ntr_, plog_,
   {{0x44440122,0x7dcd1529,0x76440107,0x00000000}},	//   _mp_, rúsa, _opiy, --,
   {{0x442a7859,0x3f860187,0xa5bb785a,0xaa58785b}},	//   hub_, mkou_, drón, ципу_,
   {{0x4444785c,0x442a0daa,0x41be166b,0x3f860314}},	//   _op_, kub_, ्तिस, lkou_,
   {{0x4444004e,0xdd8f004f,0xa3be13ab,0x6d4a0054}},	//   _np_, _حول_, ेता_, mefa,
   {{0x3f86142f,0x6d4a2e1a,0x442a007c,0xdce10009}},	//   nkou_, lefa, dub_, _golđ,
   {{0x44440c05,0xf1be252b,0x41be0e61,0xab271958}},	//   _ap_, ्तान, ्तास, _хоча_,
   {{0x6d58785d,0x6d4a401f,0xcaa50ad9,0x4438008e}},	//   ndva, nefa, _تصمي, ftr_,
   {{0x4444785e,0x69da01ae,0x442a00ab,0x76440176}},	//   _cp_, mmte, gub_, _epiy,
   {{0x69c8785f,0x6d4a021d,0x9f440031,0xa5bb62b6}},	//   llde, hefa, _dimë_, crón,
   {{0x6d4a7860,0x290e40fe,0x443800e9,0x717903e6}},	// [7e70] kefa, _kefa_, atr_, обар_,
   {{0x290e0453,0x442a00be,0x6d5802a2,0x7c380051}},	//   _jefa_, bub_, jdva, ktvr,
   {{0x6d4a7861,0x69da0120,0x7bc27862,0x44447863}},	//   defa, imte, _okou, _gp_,
   {{0x2d8c0291,0x290e6314,0x69da033b,0xddc90160}},	//   _alde_, _lefa_, hmte, _breş,
   {{0x059600bf,0xddc90043,0x63ad7864,0xd244002d}},	//   _رایگ, _creş, mnan, _пэри,
   {{0x6d4a7865,0x7bc20359,0xd83802d0,0xe1ff0093}},	//   gefa, _akou, ktč_, _próf_,
   {{0xeb995c7c,0xfd100bdf,0x3f8600ac,0xe1ff0098}},	//   жий_, اجه_, bkou_, _bróg_,
   {{0x3f860076,0x69c87866,0x2d8c027d,0x224d00ac}},	//   ckou_, elde, _elde_, _šeky_,
   {{0x63ad7867,0x6d4a0909,0x290e0176,0xddc9002d}},	//   inan, befa, _befa_, _greş,
   {{0xdb00008a,0x442a22cb,0x7bc2021e,0x88851052}},	//   rnmá, yub_, _ekou, длож,
   {{0xa5bb40e7,0x6d417868,0x8af90133,0x61e70043}},	//   trón, _ibla, _днес_, _mijl,
   {{0x69c806a2,0xb6a60424,0x63ad7869,0x69da786a}},	//   alde, димл, jnan, amte,
   {{0x63ad786b,0x4444786c,0x2bb8004f,0x7bdb02e2}},	//   dnan, _sp_, _عامة_, mmuu,
   {{0x7bc91010,0x442a786d,0x290e008a,0x7bc201c0}},	//   lleu, tub_, _gefa_, _zkou,
   {{0x290512c3,0x63ad008a,0x61fd0029,0xf8d100b1}},	//   mbla_, fnan, _atsl, _हरिय,
   {{0x63ad786e,0x442a786f,0x61ef7870,0x645c28e9}},	//   gnan, rub_, _bucl, rvri,
   {{0x44387871,0x442a7872,0x61e70a75,0x3f86024e}},	// [7e80] str_, sub_, _bijl, vkou_,
   {{0x44447873,0x63ad7874,0x442a198c,0x61ef7875}},	//   _tp_, anan, pub_, _ducl,
   {{0x44447876,0x3f8d7877,0x7bc97878,0x3f860187}},	//   _up_, _bleu_, kleu, tkou_,
   {{0x6d417879,0xddc90043,0xe1ff0079,0x61e70282}},	//   _abla, _preş, _bród_, _eijl,
   {{0x63a418af,0x6d4a787a,0xb5fb05f5,0x3f8606e7}},	//   miin, tefa, rvág, rkou_,
   {{0x63a4787b,0x7bc2053e,0xf9870148,0x20180ec0}},	//   liin, _skou, _شب_, _tvri_,
   {{0x7bc9001e,0x6d586cfb,0x290e4287,0x98a5010b}},	//   fleu, rdva, _refa_, delį_,
   {{0x63a4787c,0x6d41787d,0xb50a06bc,0x6e2b010d}},	//   niin, _ebla, वरुप_, bugb,
   {{0x6d4a3cba,0xa5bb006c,0x61ef0392,0xc27b016b}},	//   pefa, rtóz, _xucl, ַרטי,
   {{0x63ad54b9,0x63a40103,0x2bce11b5,0xa2af0026}},	//   znan, hiin, _हीरा, ंपत्,
   {{0x69c8022a,0x63a4787e,0x69da0a8d,0x9f441f10}},	//   rlde, kiin, rmte, _aimé_,
   {{0xfa6a081b,0x63a45d11,0x29c20093,0x7bc9787f}},	//   _маек_, jiin, gðar_, cleu,
   {{0x63a401a8,0x63ad5861,0x2918004f,0xb50a2afe}},	//   diin, vnan, óras_, वरूप_,
   {{0x63ad0035,0x7bc00763,0xa5bb002a,0x27fc00e2}},	//   wnan, lomu, cról, _ttvn_,
   {{0x63ad7880,0x63a4002d,0x69cb0461,0x61e70223}},	//   tnan, fiin, हतरी, _rijl,
   {{0x63a42af6,0xb4af00a1,0x394c017b,0x72050413}},	//   giin, _कशी_, leds_, فورم,
   {{0x61e701e4,0xdce800b8,0xb60400b8,0xc2992c4c}},	// [7e90] _pijl, _podě, tvář, чках_,
   {{0xef19006a,0x649300d8,0x27e9022e,0x63ad00f8}},	//   _może_, ežiū, _hian_, snan,
   {{0x31c464cc,0xfe7000bf,0x27e90ec0,0x63a40273}},	//   тств, یده_, _kian_, biin,
   {{0x660d6a5b,0x27e90f5d,0x394c08c8,0x63a42423}},	//   _kwak, _jian_, heds_, ciin,
   {{0x27e9004f,0xdb00004f,0x6458008e,0x61e70221}},	//   _mian_, cimé, _ávir, _tijl,
   {{0x660d289f,0xc105004f,0x6e2b7881,0x00000000}},	//   _mwak, _سوري, rugb, --,
   {{0x660d0273,0x41be0355,0x394c0159,0x6fca0501}},	//   _lwak, ्तरस, deds_, kých,
   {{0xa5bb01ef,0xef190067,0x2d871649,0x660d030d}},	//   dróm, _boże_, skne_, _owak,
   {{0xa5bb08c0,0x7bdb6d0b,0x6fca0097,0x00000000}},	//   tról, rmuu, dých, --,
   {{0x6d4101a0,0x63a43736,0x7bc92b87,0x2dd400ed}},	//   _ubla, ziin, sleu, _ажур,
   {{0x63a4288d,0x27e94d8c,0xf8b100b5,0x7bc900a2}},	//   yiin, _bian_, دکش_, pleu,
   {{0x63a40160,0x29180093,0x660d2107,0x1cb80a72}},	//   xiin, órar_, _bwak, _غالب_,
   {{0x29c200fb,0x27e97882,0x394c0345,0x63a47883}},	//   rðar_, _dian_, beds_, viin,
   {{0x80a000ab,0x201c17fc,0x00000000,0x00000000}},	//   _गइले, ávik_, --, --,
   {{0xf8c60ca1,0x69c17884,0x63a47885,0xd467002d}},	//   _रुपय, mole, tiin, нире_,
   {{0x27e900e8,0x69c17886,0xe1fa20b4,0xdb007887}},	//   _gian_, lole, зга_, timé,
   {{0x63a42951,0xd24f006c,0x660d018e,0xe29a0132}},	// [7ea0] riin, ینہ_, _gwak, чаа_,
   {{0x63bb02dd,0x69c17888,0x63a44dd3,0x71a328d7}},	//   čuna, nole, siin, гауз,
   {{0x64a633ed,0x7bc07889,0x6b893f99,0xb5fb0300}},	//   _чана, yomu, kkeg, rváe,
   {{0x69c1788a,0xd00f0125,0x00000000,0x00000000}},	//   hole, صله_, --, --,
   {{0x69c1788b,0x649300d8,0x59b104e9,0x657e0cfd}},	//   kole, ržiū, ीकार, _koph,
   {{0x6b8901ed,0x00000000,0x00000000,0x00000000}},	//   ekeg, --, --, --,
   {{0x69c1788c,0x7bc0788d,0x3cf0007c,0x961d162b}},	//   dole, tomu, _चलीं_, _भट्ट_,
   {{0xa3d00803,0x443a788e,0x225f0207,0x00000000}},	//   षति_, _mqp_, _šuki_, --,
   {{0x7fd702b5,0x6fca0187,0x69c1788f,0x27e926c9}},	//   _טולס_, vých, fole, _rian_,
   {{0x69c12bb2,0x27e97890,0x7c963d1a,0x660d01d5}},	//   gole, _sian_, _прец, _rwak,
   {{0x394c7891,0xa3d01db1,0x27e97892,0x660d053e}},	//   reds_, षता_, _pian_, _swak,
   {{0x6d5a7893,0x27e9022e,0x61be0355,0x6b8903d0}},	//   _hata, _qian_, ्तुष, ckeg,
   {{0x69c17894,0x27e96351,0x657e0298,0x3cfd018d}},	//   bole, _vian_, _boph, रुवे_,
   {{0x69c17895,0x6d5a7896,0x26c90054,0x9f4a027a}},	//   cole, _jata, _vyao_, _subì_,
   {{0x6d5a7897,0xf367129e,0x80a000a1,0x657e0b88}},	//   _mata, нтан, _गेले, _doph,
   {{0x660d0b69,0x00000000,0x00000000,0x00000000}},	//   _twak, --, --, --,
   {{0x660d035a,0xe1f30d93,0x776d7898,0x070725d8}},	// [7eb0] _uwak, اسر_, _inax, _व्यव_,
   {{0x9f580098,0x9f4a00fe,0x00000000,0x00000000}},	//   _dtrí_, _dubí_, --, --,
   {{0xfbb200b8,0x2bac0355,0xf524002d,0xf48462a6}},	//   ुकाम, pěch_, _сфын, _буян,
   {{0x6d5a7899,0x8fc7414b,0x657e008c,0x69c135d8}},	//   _aata, رزان, _zoph, zole,
   {{0x69c1789a,0xa28213cf,0x59d008b0,0x69d8018d}},	//   yole, _پیلو, हतार, _ohve,
   {{0x6d5a3ec3,0xdca50947,0x69c101ed,0x00000000}},	//   _cata, кали, xole, --,
   {{0x6d5a789b,0x69c105d3,0xe73f00ab,0x21644567}},	//   _data, vole, lnõu_, _стяг,
   {{0x69c114ff,0x6d5a0719,0x69d802e2,0x00000000}},	//   wole, _eata, _ahve, --,
   {{0x69c1789c,0x6d5a09bd,0xe9d90072,0x6b89789d}},	//   tole, _fata, мки_, rkeg,
   {{0x6d5a789e,0x776d77c2,0x6b89008b,0xd94503fa}},	//   _gata, _anax, skeg, њени,
   {{0x69c10147,0x00000000,0x00000000,0x00000000}},	//   role, --, --, --,
   {{0xf0ee07ba,0x7dcd01ba,0x69c119a6,0x69d81fef}},	//   _जल्द_, kúsk, sole, _ehve,
   {{0x6d5a0848,0x69c1789f,0x98b106d3,0x657e00d7}},	//   _yata, pole, ızı_, _poph,
   {{0x6d5a78a0,0x9f4a78a1,0x6845082a,0x443a0183}},	//   _xata, _rubí_, _анка, _pqp_,
   {{0xf9920122,0x983500d8,0x9f4a0453,0x6fd80d2e}},	//   _דרג_, _рэлі, _subí_, líce,
   {{0x7afb78a2,0x69d801f4,0x260f0099,0x7dc40176}},	//   ncut, _zhve, तीही_, hòsp,
   {{0xcb1200c2,0xf5060133,0x657e78a3,0xb5fb0334}},	// [7ec0] ילן_, _изпо, _toph, rvác,
   {{0x61be175f,0xc486034b,0x3cf00354,0x00000000}},	//   ्तेष, _алок, _चलें_, --,
   {{0x98bc00c7,0x00000000,0x00000000,0x00000000}},	//   _davė_, --, --, --,
   {{0x34b700a5,0x63780176,0x7f5b02d7,0x1e86027a}},	//   _יפים_, _nínx, _cauq, клем,
   {{0x6d5a78a4,0xa3bf0299,0x261b046c,0x753b00f4}},	//   _pata, इवर_, _बिछी_, đuzv,
   {{0x6d5a2e60,0x3cfd000c,0x569b016b,0xbea3751e}},	//   _qata, रुले_, וינצ, шачк,
   {{0x71a34025,0x6d5a01d6,0x80e00083,0xdce1010b}},	//   _тарз, _vata, _প্র্, _molė,
   {{0x6d5a78a5,0x7c8334a2,0x26cc0095,0x6fd80132}},	//   _wata, руше, ədov_, fíce,
   {{0x6d5a78a6,0xa92a0409,0x4e0b0035,0x8ca200b4}},	//   _tata, міне_, सीआई_, _केरो,
   {{0xce370bed,0x0e9b00a5,0x9f4401ef,0x59cf0f3d}},	//   _באמת_, _חשמל, _mimí_, _सीआर,
   {{0x7d1878a7,0x6d8f03d0,0x00000000,0x00000000}},	//   mavs, _køan, --, --,
   {{0x7d1878a8,0x00000000,0x00000000,0x00000000}},	//   lavs, --, --, --,
   {{0x07a401c8,0x95cb0370,0xdb0001ef,0xc6a4081b}},	//   раўн, дува_, nimí, арри,
   {{0x7d1878a9,0x61be0355,0x00000000,0x00000000}},	//   navs, ्तोष, --, --,
   {{0x499200d1,0x6fc200a1,0x2a6600ac,0x25ad0124}},	//   _میکر, षकां, _hrob_, đel_,
   {{0x63bb068b,0x7d180c61,0x779400b5,0xaac601c0}},	//   čuno, havs, _نیپا, _लडाक,
   {{0x7f5b78aa,0x7d1801a0,0x25f40099,0x61d92ad9}},	// [7ed0] _rauq, kavs, ंदणी_, емая_,
   {{0xa2a702cb,0x90e74dc0,0xdb00024e,0xe4a700af}},	//   _घेण्, نسان, dimí, _армо,
   {{0x7d1878ab,0x661d78ac,0xd498002d,0x21380183}},	//   davs, lssk, _аря_, _dcrh_,
   {{0x443106d3,0x9f4a01f7,0xdcfa06fe,0x00000000}},	//   muz_, _cubà_, _dotč, --,
   {{0x661d78ad,0x2a66006d,0x637801f7,0x7afb0225}},	//   nssk, _nrob_, _rínx, vcut,
   {{0xaac60953,0x395c0069,0x5bcb012f,0xef19007a}},	//   _लड़क, _navs_, ात्व, _doża_,
   {{0x44310d6f,0x3cfe0183,0xa5bb0098,0x997c013a}},	//   nuz_, _dftv_, grói, _bāžu_,
   {{0x28c6021a,0x386978ae,0x00000000,0x00000000}},	//   _रुधि, _čar_, --, --,
   {{0x99151728,0x7dcd0093,0xe8d90019,0x3cfe012f}},	//   льні, húsi, _đố_, _fftv_,
   {{0x7afb78af,0x443178b0,0x2a660af3,0x395c026e}},	//   scut, kuz_, _drob_, _cavs_,
   {{0xe73a78b1,0x5fb71ae9,0x3cf00187,0x443178b2}},	//   нен_, _अदाल, ňové_, juz_,
   {{0x44311202,0x6f190035,0x2a660392,0xddc900ee}},	//   duz_, nawc, _frob_, _speň,
   {{0x661d78b3,0x2a6660a7,0x395c78b4,0xd9450ea0}},	//   gssk, _grob_, _favs_, _бели,
   {{0x395c78b5,0x442a78b6,0x443178b7,0x2bcb0efa}},	//   _gavs_, trb_, fuz_, ातका,
   {{0x443101a3,0x28020355,0x661d448b,0x00000000}},	//   guz_, ěrné_, assk, --,
   {{0xf3e60208,0x2b5f78b8,0xe7bb0d4e,0x00000000}},	//   ужбо, nduc_, _उदयप, --,
   {{0xe29778b9,0x6f19004e,0xb5fb006c,0xe0b00033}},	// [7ee0] гат_, dawc, lván, _করেন,
   {{0xdcfa0b16,0x443178ba,0x660478bb,0x20030345}},	//   _potč, buz_, _itik, _btji_,
   {{0x03a60714,0x00000000,0x00000000,0x00000000}},	//   _бино, --, --, --,
   {{0xc7b90009,0xdb0078bc,0x7c3c00be,0x3a3f0225}},	//   brđu_, timí, _ärri, ktup_,
   {{0x527578bd,0x2b4600d7,0x7d1878be,0xde5812ea}},	//   _куру, _rboc_, tavs, талі_,
   {{0x6604002f,0xf1b8021a,0x41b8018d,0xad2600e0}},	//   _mtik, _आदिन, _आदिस, ارشو,
   {{0x7d18510f,0x672478bf,0x0b8a0036,0x4c940b3a}},	//   ravs, _odij, еспи_, рийс,
   {{0xa2db143a,0x2a6670b9,0x61ee1292,0xb5fb00b5}},	//   पेक्, _prob_, _hibl, dván,
   {{0x224078c0,0x443178c1,0x38670042,0x66040b69}},	//   ntik_, zuz_, _arnr_, _ntik,
   {{0x6e930082,0x2fc678c2,0x224078c3,0x325700a5}},	//   _الكا, loog_, itik_, נסים_,
   {{0x660478c4,0x1bed0084,0xeaaf03c5,0x6724022f}},	//   _atik, _चंचल_, قعی_, _bdij,
   {{0x224078c5,0x661d78ad,0x443100d0,0x16200066}},	//   ktik_, tssk, vuz_, _बिखर_,
   {{0x395c0029,0xc6a708bb,0x61ee0079,0x2a66148a}},	//   _tavs_, урни, _oibl, _urob_,
   {{0x6b827405,0x44310291,0x2fc60a75,0x1a9b02b5}},	//   _hoog, tuz_, hoog_, _אידע,
   {{0x660478c6,0xdb090279,0x68fb00a5,0x6b8278c7}},	//   _etik, lneá, _אלוה, _koog,
   {{0x6b821b43,0x443178c8,0x69d852cf,0x61ee462c}},	//   _joog, ruz_, _नीती, _aibl,
   {{0x6d48076e,0x248d0029,0x4431037a,0x224001a2}},	// [7ef0] _obda, ņem_, suz_, gtik_,
   {{0x6b821b43,0x61ee78c9,0x6f190035,0x44310381}},	//   _loog, _cibl, wawc, puz_,
   {{0x61ee00f8,0x224078ca,0xc7b900f4,0x720500fd}},	//   _dibl, atik_, srđu_, _چہرہ_,
   {{0x6d485ff2,0x6b827259,0x283702b5,0x2240043d}},	//   _abda, _noog, רנאך_, btik_,
   {{0xb5fb0187,0x61ee0176,0x22870036,0x6f190067}},	//   zván, _fibl, _сунг, rawc,
   {{0x320927f9,0x61ee78cb,0x7dcd008e,0x6d43033b}},	//   mpay_, _gibl, húsv, ufna,
   {{0x6b8278cc,0x3209009e,0x6c67006c,0xfaf10037}},	//   _boog, lpay_, البہ_, يثة_,
   {{0x5f941878,0x3b850923,0x44212172,0xba253b8b}},	//   _лист, рлиг, _mvh_, адик,
   {{0x320902d0,0x7f84004f,0x3947028b,0x499901e0}},	//   npay_, _القن, _pbns_, втня_,
   {{0xa9a5095d,0x7e6978cd,0xb5fb006c,0x442178ce}},	//   риод, _irep, tván, _ovh_,
   {{0xe8d900e8,0xfbd00088,0x6fd801dd,0x224001d7}},	//   _đồ_, _کتل_, líca, ztik_,
   {{0x7e696aa0,0x6b820147,0xfc300041,0xb5fb78cf}},	//   _krep, _goog, _رحم_, rván,
   {{0xcaf40332,0x6fd80300,0xe1ff0098,0x00000000}},	//   _اسمب, níca, _srón_, --,
   {{0xceb26f51,0x3209099e,0x6b822cfa,0x4421055c}},	//   קים_, dpay_, _zoog, _bvh_,
   {{0x443e0248,0x61ee00cd,0x2fc6006d,0xe7ef0534}},	//   ît_, _ribl, yoog_, _घंटा_,
   {{0x6b8212ff,0x25aa001e,0x2fc601e8,0x130603c6}},	//   _xoog, sibl_, xoog_, рзам,
   {{0x5725004f,0xdb002eef,0x61ee0c1f,0x79830035}},	// [7f00] _طريق, nimá, _pibl, _konw,
   {{0x224078d0,0x6fd827c2,0xa06a78d1,0x645a78d2}},	//   rtik_, díca, каза_, ætis,
   {{0xb5fb024e,0xc2e70083,0xef1a0370,0x7e6901cb}},	//   hvál, গুলি_, вме_, _arep,
   {{0x6fd80b4c,0x7e2a2327,0x9e663f1b,0xa5bb00b5}},	//   fíca, віка_, ивед, csób,
   {{0x5de6071d,0xee370ddc,0x2fc60b08,0x7dcd008d}},	//   ажда, инц_, roog_, húsu,
   {{0x7e6978d3,0xe0da00f0,0xac2678d4,0x6b82398b}},	//   _drep, _авг_, афик, _soog,
   {{0x20b903ad,0xdb090187,0xe6d30567,0x16d30963}},	//   _быть_, šnýc, _सर्ज, _सर्ब,
   {{0x4f9610b4,0x7b66005f,0x63b678d5,0xdcfa02d4}},	//   _тргу, ртке, nnyn, _dotā,
   {{0xcb6709ea,0x7e6978d6,0xb5fb006c,0xfe720037}},	//   рање_, _grep, gvál, _بدأ_,
   {{0xd7fa4b4f,0x7983001e,0x6b825556,0xf96a1743}},	//   кум_, _conw, _woog, трий_,
   {{0x3f8478d7,0x6b82525a,0xdddb00ea,0xd0f700a5}},	//   _komu_, _toog, _bruņ, ימית_,
   {{0x32096b9d,0x00000000,0x00000000,0x00000000}},	//   ypay_, --, --, --,
   {{0xdb001e49,0x798351c7,0x00000000,0x00000000}},	//   cimá, _fonw, --, --,
   {{0xd5b800c3,0x3f840228,0x680100ea,0x00000000}},	//   асс_, _lomu_, _sēde, --,
   {{0x5fb805b7,0xd5b878d8,0x6fb80099,0x00000000}},	//   ेकाल, рся_, ेकां, --,
   {{0x3f8478d9,0x320907df,0xe3b300b5,0x987b00a5}},	//   _nomu_, tpay_, زرز_, _ירוק,
   {{0x764d0614,0x675400f8,0xb7dc011d,0x68010228}},	// [7f10] _upay, _ذخير, _בקהי, _vēde,
   {{0x69c878da,0xf65000fd,0x7e69163e,0x25f400b4}},	//   node, _آئي_, _rrep, ंदरी_,
   {{0x32090359,0xd3710037,0x3f84002f,0x7e690088}},	//   spay_, _فهد_, _bomu_, _srep,
   {{0x7e6956fa,0xdb090120,0xe4560070,0xff5300b5}},	//   _prep, rieë, _פירט_, تخط_,
   {{0xd37a00c2,0x6db2006a,0x63ad78db,0x3f841c7b}},	//   _ערשט, kład, mian, _domu_,
   {{0x63ad78dc,0xfd4701c8,0xdb090b0d,0x9877011c}},	//   lian, рэдн, pieë, _ušće_,
   {{0x40950082,0x7dcd6489,0xe0e50083,0x3f840054}},	//   _الأر, dúst, _প্রভ, _fomu_,
   {{0xa3d73123,0x63ad78dd,0x8f3401c8,0xdb001d85}},	//   िति_, nian, _месц, timá,
   {{0x69c878de,0x2fdf0159,0x49c91f39,0x7e690065}},	//   fode, _ihug_, ллин_, _urep,
   {{0x63ad78df,0x389701c2,0x69c878e0,0x7dcd0132}},	//   hian, lərə_, gode, gúst,
   {{0xa3d70127,0x63ad78e1,0x6ca74a7f,0x61e50719}},	//   िता_, kian, _траж, imhl,
   {{0x63ad78e2,0x3a2d06fe,0x2d8578e3,0x25f41b8f}},	//   jian, prep_, _hole_, ंदली_,
   {{0x69c878e4,0x2d8578e5,0x63ad1651,0xe8d901a5}},	//   bode, _kole_, dian, _đổ_,
   {{0xb8dd12eb,0x799a04ce,0x2d856e62,0x7dcd0138}},	//   _আর_, chtw, _jole_, cúst,
   {{0x63ad78e6,0x232a32c9,0xdcfa002d,0xccf200a5}},	//   fian, лови_, _hotă, לכם_,
   {{0x96960131,0x73992839,0x7bc93c7a,0x2d850124}},	//   _грош, атус_, noeu, _lole_,
   {{0x63b600c7,0x00000000,0x00000000,0x00000000}},	// [7f20] rnyn, --, --, --,
   {{0x3f840228,0x59c70b57,0xdb1b0132,0x422301e0}},	//   _somu_, रकिर, bouç, ядув,
   {{0x442e008e,0x389700a8,0xaace2df6,0x27e003d0}},	//   _íf_, fərə_, _हुनक, _khin_,
   {{0x645e78e7,0x69c878e8,0x7bc90207,0x2fdf055c}},	//   _ispi, zode, joeu, _chug_,
   {{0x59c721b2,0xdfcf0ad9,0x2d8578e9,0x7bc978ea}},	//   रकार, ريه_, _bole_, doeu,
   {{0xbbb2009a,0xb6060b67,0x2d852d71,0x3f84030d}},	//   ुक्क, mašč, _cole_, _womu_,
   {{0x3f8405d3,0x69c815b5,0xfd7900b5,0x3897013b}},	//   _tomu_, vode, ششوں_, bərə_,
   {{0x09d005f7,0x6fb6036b,0x6b9b129d,0xa3ab0026}},	//   हत्य, _امرا, ghug, कोप_,
   {{0x69c82172,0xc33300a5,0xb99802bb,0x2d850055}},	//   tode, פוז_, ивих_, _fole_,
   {{0x63ad78eb,0x645e78ec,0x291878ed,0x63bb04c3}},	//   zian, _ospi, úra_, čuni,
   {{0x69c878ee,0x7d1a0b0d,0x317b0070,0x27e001ed}},	//   rode, _iets, ארימ, _bhin_,
   {{0x69c878ef,0x63ad549e,0x7d1a5c6e,0x6b9b78f0}},	//   sode, xian, _hets, chug,
   {{0x98b82c7c,0x6e221642,0x7d1a1eb8,0x9f58021d}},	//   ırı_, nsob, _kets, _purê_,
   {{0x63ad004e,0x7d1a78f1,0xe8941a6d,0x38970095}},	//   wian, _jets, _маль, zərə_,
   {{0x291e20af,0x63ad0655,0x7d1a0d4c,0x6f02012f}},	//   mata_, tian, _mets, kcoc,
   {{0x7d1a78f2,0x52150945,0xdb090183,0x27e00341}},	//   _lets, ждат, rneç, _ghin_,
   {{0x15f302b4,0x00000000,0x00000000,0x00000000}},	// [7f30] _इंटर_, --, --, --,
   {{0x63ad78f3,0x6e221bd8,0xdb002119,0x00000000}},	//   sian, dsob, limä, --,
   {{0x63ad78f4,0x6616004e,0x2d8578f5,0x92d90033}},	//   pian, _zwyk, _role_, াশে_,
   {{0x291e78f6,0x63ad0069,0xdcee00b8,0x2d850dbb}},	//   hata_, qian, žděn, _sole_,
   {{0x28cf06bc,0xdce800d8,0x2bcc0761,0x2d8519a6}},	//   _सुनि, _kodė, ावना, _pole_,
   {{0xac0978f7,0xdb002933,0x00000000,0x00000000}},	//   анка_, himä, --, --,
   {{0x291e78f8,0xef19006a,0xeae500c8,0x2fdf1093}},	//   data_, _też_, _নভেম, _thug_,
   {{0x7d1a78f9,0x6f020036,0x2cb800ac,0x00000000}},	//   _eets, ccoc, _šedý_, --,
   {{0x291e78fa,0x7bc93762,0x7d1a0282,0x2d85008b}},	//   fata_, roeu, _fets, _tole_,
   {{0x291e78fb,0x6b9b000e,0x7d1a78fc,0x6f1b490c}},	//   gata_, shug, _gets, _heuc,
   {{0x9f4b0098,0x680102d4,0x00000000,0x00000000}},	//   _ómós_, _bēda, --, --,
   {{0xe73a78fd,0x7d1a78fe,0x443100ac,0xdc88021d}},	//   шем_, _zets, drz_, _усул_,
   {{0x291e78ff,0x06cd0083,0x7d1a7900,0x6f1b7901}},	//   bata_, রেসি, _yets, _meuc,
   {{0x291e7902,0x6f1b7903,0x290100ab,0x6f027904}},	//   cata_, _leuc, _üha_, zcoc,
   {{0x6fc909a8,0xe8d90019,0xe9b8006c,0x6e24003c}},	//   िकां, _đỗ_, _دنوں_, ġibi,
   {{0x130a00d8,0x6f1b7905,0x6f020138,0x27e001a3}},	//   рнай_, _neuc, xcoc, _uhin_,
   {{0x645e0035,0xd5e40023,0x44311140,0x422602fb}},	// [7f40] _wspi, _trì, arz_, юдав,
   {{0xb606341e,0x6fd80300,0x77640392,0xa50a0274}},	//   rašč, tíco, _haix, _њена_,
   {{0x645e0470,0x7d1a7906,0x6f1b0211,0x776401d7}},	//   _uspi, _rets, _beuc, _kaix,
   {{0x44387907,0x7d1a7908,0x291e7909,0x6fd80a20}},	//   mur_, _sets, zata_, cícl,
   {{0x4438790a,0x91e61906,0x291e790b,0x7d1a790c}},	//   lur_, _моме, yata_, _pets,
   {{0x44380069,0x7981006d,0x4444790d,0x291e2051}},	//   our_, jjlw, _kq_, xata_,
   {{0x4438790e,0x6f1b09cf,0x645c790f,0x7d1a7910}},	//   nur_, _feuc, nwri, _vets,
   {{0x444401d3,0x291e7911,0x7d1a7912,0x207b0070}},	//   _mq_, wata_, _wets, _דאלא,
   {{0x44387913,0x7d1a006c,0x7c23006d,0x68ef00a8}},	//   hur_, _tets, asnr, əkdə,
   {{0x44387914,0x59dd0084,0x44447915,0x2b915b84}},	//   kur_, _नीदर, _oq_, _lách_,
   {{0x291e7916,0x77642ce4,0x6d587917,0x26180e7f}},	//   rata_, _baix, meva, बीसी_,
   {{0x77642b5c,0x291e00a1,0x645c00e9,0x37ab08ce}},	//   _caix, sata_, dwri, ртон_,
   {{0x291e19c6,0x44440c34,0x443802e1,0x7c38025c}},	//   pata_, _aq_, eur_, luvr,
   {{0x443870b2,0x6d580006,0x95cb2294,0x291e610f}},	//   fur_, neva, рума_, qata_,
   {{0x44387918,0x77647919,0x2b910019,0x4444791a}},	//   gur_, _faix, _bách_, _cq_,
   {{0x442d0690,0x2b9100e8,0x776406a2,0x6d58791b}},	//   če_, _cách_, _gaix, heva,
   {{0xdce800d8,0x6d58791c,0xdb1100b5,0x44440f00}},	// [7f50] _todė, keva, áfér, _eq_,
   {{0x6d581635,0x44385112,0x44440031,0x4431791d}},	//   jeva, bur_, _fq_, prz_,
   {{0x6d58791e,0x291c12c3,0x155a0122,0x6f1b37a5}},	//   deva, _meva_, _הכתב, _peuc,
   {{0x6565765f,0x9ee90082,0x291c791f,0x6d4a0345}},	//   _hahh, مفضل_, _leva_, effa,
   {{0x1d097920,0x6447053e,0x260f00a1,0xee386c6a}},	//   бели_, ltji, तीची_, жні_,
   {{0x6d580276,0xed5928cc,0x291c7921,0x65650de8}},	//   geva, сок_, _neva_, _jahh,
   {{0xd8380528,0x64470173,0x44441725,0x61fd7922}},	//   juč_, ntji, _xq_, _husl,
   {{0x2b9101a5,0x644703bc,0x61f57923,0x65657924}},	//   _xách_, itji, _hizl, _lahh,
   {{0x60d5279b,0x44387925,0x6d587926,0x77640176}},	//   _hyzm, zur_, beva, _raix,
   {{0x291c0012,0x39453121,0x6d587927,0x397900c3}},	//   _ceva_, чног, ceva, ссию_,
   {{0x291c7928,0x6d410095,0x77640f84,0x6445006f}},	//   _deva_, _icla, _paix, _nqhi,
   {{0x44387929,0xf09202b5,0x6565792a,0x6db20035}},	//   vur_, גנט_, _aahh, płac,
   {{0xa5bb792b,0x443800bf,0x2b910023,0x644703bc}},	//   rsón, wur_, _rách_, etji,
   {{0x4438792c,0x2b9100e8,0x4444792d,0xa5073c60}},	//   tur_, _sách_, _pq_, зера_,
   {{0xa3d700e7,0x61fd02c9,0x444429e0,0x3e5d02e9}},	//   ितं_, _ausl, _qq_, _lňt_,
   {{0x4438792e,0x61f50029,0x9f46053e,0x6d585228}},	//   rur_, _aizl, rmoë_, zeva,
   {{0x2bcc065a,0x4438792f,0x44440c1f,0x61f500d0}},	// [7f60] ावता, sur_, _wq_, _bizl,
   {{0x44387930,0x44440019,0x61fd7931,0x29057932}},	//   pur_, _tq_, _dusl, ncla_,
   {{0x443800da,0x6d587933,0x2b910019,0x61fd7934}},	//   qur_, veva, _tách_, _eusl,
   {{0xa3d70355,0x6d410890,0x61f500d7,0x20077935}},	//   ितः_, _acla, _eizl, ínia_,
   {{0xc3330bed,0x6d58018d,0xf1bf400d,0x29077936}},	//   _אור_, teva, _iván_, _ofna_,
   {{0x61f50d6f,0x6d4a0248,0x51554166,0x6da31fff}},	//   _gizl, uffa, _отсу, нича,
   {{0x6d587937,0x6e39011e,0x6d4a7938,0xe537016b}},	//   reva, auwb, rffa, לטסט_,
   {{0x291c162d,0x6d4111b8,0x6d587939,0x7bc4010b}},	//   _seva_, _ecla, seva, čiuo,
   {{0x6d58793a,0x291c793b,0x8d1a00bf,0xacf6004f}},	//   peva, _peva_, _هزار_, _فسات,
   {{0xe7d60033,0xd90d00d1,0x644703bc,0x0e6332dd}},	//   _সংগঠ, لیه_, ytji, _якун,
   {{0x291c793c,0x6565009e,0xf1bf06fe,0x00000000}},	//   _veva_, _rahh, ्वतन, --,
   {{0x656505af,0x00000000,0x00000000,0x00000000}},	//   _sahh, --, --, --,
   {{0x291c12c3,0xb88601ef,0xe1ff00e2,0x66cb00af}},	//   _teva_, _baíñ, _trói_, сунг_,
   {{0x25f40b4a,0x246700b8,0xa37b055c,0x00000000}},	//   ंदगी_, jímá_, _chõn, --,
   {{0x58d330ba,0x38c800f8,0x61f507e7,0x61fd4704}},	//   _пошт, _باشی_, _rizl, _susl,
   {{0xb4bd02cb,0x61fd01c8,0x64470626,0x61f500d0}},	//   _अशी_, _pusl, rtji, _sizl,
   {{0x95cb0036,0xa5bb02d7,0x680806fe,0xdce8013a}},	// [7f70] _гуна_, lsóm, _děde, _bodī,
   {{0xe7e10d1f,0x660d793d,0x61f50be2,0xd1310037}},	//   _गीता_, _itak, _qizl, ئما_,
   {{0xf99300c2,0xe2f900d4,0x660d0054,0x61f50009}},	//   ערע_, _мені_, _htak, _vizl,
   {{0x29050831,0x6d41793e,0x63bb03ab,0x9ed90c9f}},	//   zcla_, _scla, čuns, омет_,
   {{0x8d740e3a,0x7c2801ff,0xdef800d8,0x61f5793f}},	//   کانا, _avdr, чых_, _tizl,
   {{0x660d000e,0xddc90035,0xdce800ea,0x22497940}},	//   _mtak, _speł, _godī, mtak_,
   {{0x1b2100c8,0x22497941,0x41d905e7,0x672d1f3d}},	//   _যাবে_, ltak_, _बीएस, _odaj,
   {{0x23697942,0x2b980248,0xdfd1004f,0x672d7943}},	//   ndaj_, _déco_, _شيء_, _ndaj,
   {{0x22493f79,0x660d1cf5,0xd95900d8,0x7d0800fe}},	//   ntak_, _ntak, ошні_, _ffds,
   {{0x2369009e,0x672d0260,0x2fcf1281,0xdce10168}},	//   hdaj_, _adaj, logg_, _halč,
   {{0x660d7944,0xb8860391,0xa3bf10aa,0x3c9000fd}},	//   _atak, _raíñ, ेवा_, _میوز,
   {{0x22497945,0x6e297946,0x2369006d,0x00000000}},	//   ktak_, _kveb, jdaj_, --,
   {{0xf1bf5f12,0xe9ce2872,0x41bf1cc3,0xdce16dc8}},	//   ्वान, _ак_, ्वास, _malč,
   {{0xe1ff004e,0x6b8b0d3a,0x672d0009,0x2249394e}},	//   _osób_, _hogg, _edaj, dtak_,
   {{0x660d7947,0xb8860042,0x6b8b0298,0x22490065}},	//   _etak, _vaíñ, _kogg, etak_,
   {{0xb4ae02cb,0xd8d602b5,0x660d035f,0xfbdd00b8}},	//   _कधी_, _קוקט_, _ftak, मतिम,
   {{0x6b8b7948,0x680800b8,0x224900e4,0x2fcf008e}},	// [7f80] _mogg, _věde, gtak_, dogg_,
   {{0x6b8b1cdb,0x2366011c,0x672d7949,0x6fd81e60}},	//   _logg, žoj_, _zdaj, míci,
   {{0x6fd8794a,0x01090088,0x757b00a5,0x6e290371}},	//   líci, ستلو_, _וטיפ, _aveb,
   {{0x6b8b376a,0x00000000,0x00000000,0x00000000}},	//   _nogg, --, --, --,
   {{0x5e5a006c,0x6fd8794b,0x6da659d4,0x6e290207}},	//   تجاج_, níci, мида, _cveb,
   {{0x6db2004e,0xd9c70edf,0x6b8b0103,0x20561172}},	//   ałan, रकोट, _aogg, _отбр,
   {{0x6b8b225b,0x61431783,0x798a0298,0x00000000}},	//   _bogg, _шера, _rofw, --,
   {{0x1ea903fc,0x200500e0,0xc0e30f99,0x00000000}},	//   _کافي_, _élia_, _роск, --,
   {{0xf1bf00d5,0x6b8b40bb,0x00000000,0x00000000}},	//   _ovál_, _dogg, --, --,
   {{0xc27b0319,0x6fd8794c,0xb33b01d6,0xc86400af}},	//   קריי, díci, _ilçe, еӂии,
   {{0x31375c8e,0xe8df00e8,0x6b8b794d,0x01370122}},	//   ונים_, _thời_, _fogg, ורית_,
   {{0x6b8b794e,0x3f8602d0,0xfc6700b5,0x660d794f}},	//   _gogg, njou_, _زخمی, _ptak,
   {{0x4ae20bc1,0xaae20567,0x2d8c633f,0x79a60beb}},	//   _परिव, _परिक, _kode_, _орке,
   {{0x28cf0567,0xa5bb008a,0xe8df0019,0x2d8c053e}},	//   _सुवि, msók, _giỏi_, _jode_,
   {{0x2d8c7950,0x1b210083,0x94d44025,0x28c60127}},	//   _mode_, _যাতে_, ворц, _रुचि,
   {{0x69da7951,0x2249006c,0x2d8c7952,0x672d0096}},	//   llte, ttak_, _lode_, _udaj,
   {{0x660d7953,0x45d520b6,0xe8df01a5,0xdb020279}},	// [7f90] _utak, _поис, _khởi_, _emoç,
   {{0x22497954,0x3ea60029,0x20070132,0xa3e41db9}},	//   rtak_, dzot_, ínio_, _पीठ_,
   {{0x69da0014,0x224906a2,0xdce1219c,0x55760070}},	//   ilte, stak_, _palč, _װערן_,
   {{0x2d9e7955,0x69da01ae,0xa3ab0f06,0x671f22c7}},	//   _alte_, hlte, कोश_, परिक_,
   {{0x2d8c7956,0x6b8b29ca,0xdce17957,0x1d095846}},	//   _bode_, _rogg, _valč, пели_,
   {{0x7bc21b13,0x6db2006a,0xa3ab06bb,0x6b8b01d3}},	//   _ajou, słan, कोर_, _sogg,
   {{0x6fd84681,0x6b8b7958,0x2d8c7959,0x7bc20260}},	//   zíci, _pogg, _dode_, _bjou,
   {{0x69da1bb3,0xdcfa00fe,0x6e290d51,0x00000000}},	//   elte, _kotě, _tveb, --,
   {{0x3e3509b9,0x2b4d0069,0x7bc20260,0x2d8c0183}},	//   _سفار, rfec_, _djou, _fode_,
   {{0x2d8c0b41,0x8d776846,0x7bc2008c,0x00000000}},	//   _gode_, _تارا, _ejou, --,
   {{0x28cf795a,0x2bcc258f,0xf7463945,0x00000000}},	//   _सुशि, ावशा, нено, --,
   {{0x6fd86428,0x2d870496,0x69da2e04,0x2bac0067}},	//   tíci, ljne_, alte, yści_,
   {{0xddc90160,0x28cf00b4,0xf6d501e0,0x00000000}},	//   _greţ, _सुरि, віря, --,
   {{0x7bdb0dfa,0x6fd8795b,0x387a01f2,0xd94522a9}},	//   lluu, ríci, _špre_, _чеки,
   {{0x64a601c8,0x68080355,0x2edc0d4e,0x00000000}},	//   хава, _vědc, _बर्त, --,
   {{0xb4e00429,0x864601e0,0xdce80355,0xa3ab00b4}},	//   _तरी_, _зниж, _andě, कोल_,
   {{0x211a004f,0xa1360037,0x5a0c0070,0x7bdb00c3}},	// [7fa0] كتاب_, فراش, ַלאַ, iluu,
   {{0xb5fb795c,0x4ae2018d,0xdcfa00fe,0x00000000}},	//   rvát, _परसव, _dotě, --,
   {{0xe8df01a5,0x3f9f08c7,0x98a602c4,0xd00f0833}},	//   _khối_, _bluu_, ćiće_, ملل_,
   {{0x6726795d,0x6db2004e,0x28b206bc,0x2d8c795e}},	//   nakj, ałal, ुपति, _sode_,
   {{0x2d8c130f,0xdb0001f4,0x63a4795f,0xaace00b4}},	//   _pode_, shmë, mhin, _हुंक,
   {{0x63a43e32,0x7bc20223,0x3f9f0069,0x63b6016e}},	//   lhin, _sjou, _eluu_, liyn,
   {{0x2d8c041a,0x8fa60cf9,0x71d700a5,0xaad50066}},	//   _vode_, _заве, _נולד_, _डुबक,
   {{0x63a4001e,0xddc9002d,0xe1ff00e2,0x2d870031}},	//   nhin, _preţ, _trót_, ajne_,
   {{0x8fa37960,0x6726046a,0x6284002a,0x2d8c0110}},	//   _сате, dakj, nxio, _tode_,
   {{0x69c30036,0x7a530c74,0x3202018e,0xddc90395}},	//   _cjne, اضيا, _muky_, _vreţ,
   {{0x63a4777e,0x320200ac,0x41be0387,0x7bc20260}},	//   khin, _luky_, _एआईस, _tjou,
   {{0xe8df0019,0x7c2a1360,0x6296010d,0x69c30b3e}},	//   _chối_, msfr, kyyo, _ejne,
   {{0x63a47961,0xd6db7962,0x81d70033,0x12c40033}},	//   dhin, ято_, াগত_, ্ধুদ,
   {{0xddc94be5,0x779300b5,0xa6db0093,0x2a66034d}},	//   _kreš, ئیکا, ggða, _isob_,
   {{0x6fd809ab,0xa9670431,0x67260223,0x3cfe021d}},	//   lícu, _чија_, bakj, _mgtv_,
   {{0x395e7963,0xa3ab006a,0x7c33024e,0x998d022f}},	//   lets_, कों_, _údrž, mreš_,
   {{0x27e903ad,0x44380094,0x2d87004e,0xdcfa0355}},	// [7fb0] _ihan_, arr_, yjne_, _potě,
   {{0x63a42759,0xddc903c9,0xb6bc0122,0x442a021d}},	//   ahin, _oreš, _מצחי, bsb_,
   {{0x6fd80f56,0x63a4184f,0x31c4052c,0x55ac0070}},	//   hícu, bhin, уств, _זייַ,
   {{0x63a47964,0x2a6600b8,0x7c2a2d31,0x395e7965}},	//   chin, _osob_, dsfr, hets_,
   {{0xf2e44ed5,0x395e039b,0x9f580392,0x8e0801e0}},	//   _бюро, kets_, _durà_, енів_,
   {{0x395e02e1,0x998d0009,0xddc900cd,0x00000000}},	//   jets_, kreš_, _breš, --,
   {{0x395e4409,0x27e90cca,0x7c2a7966,0xdce100ec}},	//   dets_, _ohan_, gsfr, _balā,
   {{0x27e90019,0xddc90009,0xe7e10066,0x20116b06}},	//   _nhan_, _dreš, _गीला_, _itzi_,
   {{0x27200b52,0x3b82081b,0x395e0248,0x8afd00b8}},	//   _ভালো_, рлыг, fets_, ndři,
   {{0x395e7967,0x27e90027,0x6ca70328,0x63a47968}},	//   gets_, _ahan_, _преж, zhin,
   {{0xe73a014d,0x07a63e3d,0xddc90a78,0xe8df01a5}},	//   мен_, ванн, _greš, _phối_,
   {{0x27e97969,0x20032181,0x63a401f4,0x2918008d}},	//   _chan_, _muji_, xhin, ðrar_,
   {{0x27e90014,0x395e796a,0x7c240009,0x2a660371}},	//   _dhan_, bets_, ćire, _gsob_,
   {{0x6d43796b,0x6b892898,0x32020187,0x26060132}},	//   ngna, ljeg, _ruky_, _vôo_,
   {{0x63a4796c,0x44380107,0x6d43796d,0xb5fb01ba}},	//   thin, urr_, igna, tvár,
   {{0x6b89796e,0x2fdd01e8,0x6fd801ba,0x32021cc5}},	//   njeg, jlwg_, níct, _puky_,
   {{0x442a0207,0xb5fb796f,0x20117970,0x00000000}},	// [7fc0] ssb_, rvár, _atzi_, --,
   {{0x63a47971,0x40966685,0xd5af0082,0x63b60297}},	//   shin, крет, _وفي_, siyn,
   {{0x69c17972,0x657e0037,0xd59b00a5,0x67240328}},	//   inle, _inph, _חביל, _keij,
   {{0x66046497,0xd00f01b2,0x20032181,0x32020097}},	//   _kuik, زله_, _duji_, _tuky_,
   {{0x67247973,0xf7730070,0x201101a3,0x644e4617}},	//   _meij, יקא_, _etzi_, ltbi,
   {{0xdd8f00ad,0xddc90928,0x6d43022a,0xde9303fa}},	//   يون_, _preš, ggna, рашњ,
   {{0x395e039b,0x8bc60de2,0x644e093a,0x2fc40132}},	//   vets_, ксид, ntbi, _tjmg_,
   {{0x6fd800c8,0x6b897974,0xfbcf00ad,0x6b9b0008}},	//   tícu, gjeg, يتي_, gkug,
   {{0x27e90297,0x60270332,0x395e1e54,0x61fc1d1b}},	//   _rhan_, _témá, tets_, _kirl,
   {{0xddc97975,0x6fd80a20,0x644e038e,0xa3e40026}},	//   _treš, rícu, ktbi, _पीस_,
   {{0x67247976,0x395e3f5a,0x6b890470,0x27e95753}},	//   _beij, rets_, bjeg, _phan_,
   {{0x2a66006f,0x66047977,0x395e7978,0x6fd8002a}},	//   _tsob_, _buik, sets_, pícu,
   {{0x395e6277,0x644e00e2,0x61fc7979,0x6f0d20d9}},	//   pets_, etbi, _oirl, ñaci,
   {{0x7e7d0a20,0x61fc022e,0x660428e9,0x644e0137}},	//   _áspe, _nirl, _duik, ftbi,
   {{0x27e90052,0xd40403fe,0xb33b797a,0x672408cb}},	//   _than_, ияти, _alça, _feij,
   {{0x2003028b,0x61fc797b,0x752701a0,0x6724797c}},	//   _ruji_, _airl, sajz, _geij,
   {{0x61fc06a8,0x68e601c2,0xe5c701c8,0x6d43797d}},	// [7fd0] _birl, əkda, _асно, ygna,
   {{0x61bf0d34,0x61fc0160,0x200308eb,0xb1140044}},	//   ्वेष, _cirl, _puji_, имуш,
   {{0x61fc797e,0x351a0122,0xa5bb01dd,0xd47902b5}},	//   _dirl, _אותנ, dróx, _װאָל,
   {{0x5ecc00c8,0x224001a2,0xff5302e7,0x6fd401e0}},	//   ়েছে, buik_, شخص_, аціє,
   {{0xdd9515eb,0x69c12cce,0x228440b4,0x290e00e5}},	//   лады, ynle, _кург, _offa_,
   {{0xdce806d3,0x61fc2fb6,0x61140eb1,0x6d43067f}},	//   _aldı, _girl, _вдру, ugna,
   {{0x6d432556,0x201106a2,0x6f0439a2,0x44210069}},	//   rgna, _utzi_, žica, _jwh_,
   {{0x5f945084,0xdfd50086,0x77a601ef,0x6aa93c4d}},	//   _кист, _собы, _kóxe, tzef,
   {{0x67240846,0x69d8013a,0x6b9b797f,0x00000000}},	//   _reij, _bkve, rkug, --,
   {{0x66047980,0x672402ee,0x6aa90124,0x6b9b7981}},	//   _ruik, _seij, rzef, skug,
   {{0x6845010b,0x6b897982,0x69c17983,0x66047984}},	//   ынна, pjeg, rnle, _suik,
   {{0x660452ee,0x290e7985,0x6fd801ef,0x00000000}},	//   _puik, _effa_, lícr, --,
   {{0x44210118,0x657e0176,0x75257986,0x00000000}},	//   _awh_, _pnph, _behz, --,
   {{0x66034baf,0xdb090014,0x1dc300e7,0x67247987}},	//   спра, cneò, वचित, _weij,
   {{0x64a367a5,0x657e0023,0x5fd30127,0x672402ee}},	//   бара, _vnph, तवाल, _teij,
   {{0x644e4df9,0x3878054e,0x61fc7988,0xe5140026}},	//   rtbi, ærre_, _sirl, _त्रि_,
   {{0x3a2d78c0,0x644e7989,0xade30461,0x00000000}},	// [7fe0] nsep_, stbi, गतान_, --,
   {{0x22400136,0xc5664133,0xa3e40722,0xdb0002d0}},	//   ruik_, _скок, _पीर_, nimò,
   {{0x7e69798a,0xd5a401df,0x00000000,0x00000000}},	//   _asep, _ملکی, --, --,
   {{0xdd2f00b8,0x00000000,0x00000000,0x00000000}},	//   měři, --, --, --,
   {{0xa5bb01dd,0x61fc00e9,0x9f44798b,0x7e6900b5}},	//   tróx, _tirl, _simó_, _csep,
   {{0x61fc004f,0xec6a0c5a,0x7bd90027,0x7d01016e}},	//   _uirl, ерик_, _akwu, _cgls,
   {{0x7e690359,0x2d9c0a0b,0x00000000,0x00000000}},	//   _esep, rkve_, --, --,
   {{0x5a34798c,0x2d9c0168,0x69d8798d,0xe5140066}},	//   анит, skve_, _skve, तुति_,
   {{0x6f93004f,0xdee32dbb,0x00000000,0x00000000}},	//   _القض, _готи, --, --,
   {{0x9f440176,0x9f580225,0x99665128,0x00000000}},	//   _timó_, _burç_, утил, --,
   {{0x61d702b5,0x9f580176,0x81570070,0x680800b8}},	//   רויף_, _curç_, נסטע_, _vědo,
   {{0xb8ec0299,0xdb005856,0xa3e4021a,0x00000000}},	//   _रख_, rimó, _पील_, --,
   {{0x12bf0083,0x00000000,0x00000000,0x00000000}},	//   _আর্দ, --, --, --,
   {{0x290e027a,0x2bcc01c0,0xcad700a5,0x00000000}},	//   _uffa_, ावका, _עוגת_, --,
   {{0xd37b0aec,0x4d7b0070,0x6fd40099,0xb80b0f06}},	//   нча_, ערלע, धकां, _संयम_,
   {{0xdce800ac,0x28490070,0x5679002d,0xc2c50037}},	//   _nadč, _סעפּ, _абия_, ليزي,
   {{0x0ce10d34,0x00000000,0x00000000,0x00000000}},	// [7ff0] _फर्म, --, --, --,
   {{0xdb000037,0xdcfa0260,0x32091505,0x200513cf}},	//   dhmí, _antč, rqay_, _élik_,
   {{0xe1e50099,0xe6100088,0x7e696fad,0x00000000}},	//   _कठीण_, _وشی_, _ssep, --,
   {{0xf3670212,0x0eb91482,0x7f27186e,0xda040354}},	//   _стон, кулы_, اءال, रदात_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed59798e,0x51870b25,0xdcfa02d0,0xa3bf09b8}},	//   ток_, _сума, _entč, ेवक_,
   {{0x962600ea,0x1db60067,0xdb0b0090,0x00000000}},	//   _ziņā, _अगरत, _amgá, --,
   {{0x7e690345,0x200c0118,0x69c600fd,0x00000000}},	//   _tsep, _édia_, éken, --,
   {{0x49c91b2e,0x386000f4,0x00000000,0x00000000}},	//   клин_, _ćira_, --, --,
   {{0x49950142,0x00000000,0x00000000,0x00000000}},	//   ршит, --, --, --,
   {{0xdd7a00c2,0x28cf018d,0xdb00798f,0x00000000}},	//   _שטעל, _सुखि, rimò, --,
   {{0xc5e90122,0xdd2f00b8,0xa3e400ab,0x7bd90371}},	//   _חד_, věři, _पीं_, _ukwu,
   {{0xf3eb0033,0x00000000,0x00000000,0x00000000}},	//   কদার_, --, --, --,
   {{0x64a6005f,0xdb020260,0x690700d8,0x7ae60225}},	//   аага, _aloè, _сядз, ükte,
   {{0x232a3851,0x07a600d8,0xe8df0023,0x9f9c0098}},	//   кови_, _вайн, _phổi_, ríú_,
   {{0xda080019,0xdce10409,0x99860207,0x00000000}},	//   _hỏa_, _galą, _ivoš_, --,

   {{0xe297051b,0x6db20035,0x03a30336,0x00000000}},	// [8000] аат_, cław, цито, --,
   {{0x23bf0086,0x311600af,0x00000000,0x00000000}},	//   täjä_, рфас, --, --,
   {{0x21672f44,0xaf060012,0xe8df0023,0x80662031}},	//   рихи_, апел, _thổi_, рвеж,
   {{0xdfcf017e,0x645e027a,0xf3ff0023,0x00000000}},	//   ويل_, _ippi, _giã_, --,
   {{0x3ea00082,0x00000000,0x00000000,0x00000000}},	//   áit_, --, --, --,
   {{0xa5bb0183,0x00000000,0x00000000,0x00000000}},	//   lsór, --, --, --,
   {{0x3ea001c0,0xdc8702fb,0xbc671ef9,0x7c860009}},	//   šit_, исъл_, لمون_, руле,
   {{0xa5bb0279,0x00000000,0x00000000,0x00000000}},	//   nsór, --, --, --,
   {{0xe8d901a5,0x2fc60254,0xaab80416,0xa9c603e6}},	//   _đỡ_, mnog_, دگار_, исок,
   {{0x2fc601cc,0x645e7990,0x9997002d,0xddc907c0}},	//   lnog_, _oppi, икыт_, _preť,
   {{0xdb2400f8,0xab862682,0x2fc602c4,0x1ddf046c}},	//   _هوای, _вулк, onog_, _पीटत,
   {{0x22523e5c,0x2fc600e9,0xeb9a01fd,0x2cf40099}},	//   ktyk_, nnog_, _шие_, ेखील_,
   {{0x645e7991,0x6b8224fc,0x00000000,0x00000000}},	//   _appi, _inog, --, --,
   {{0x2b9800f7,0xd8b700b5,0x2fc60207,0xddc907c0}},	//   _vécu_, ادیا_, hnog_, _treť,
   {{0xd4982b33,0x89370122,0x6db20035,0x6b827992}},	//   арт_, _כרגע_, sław, _knog,
   {{0x248d01cc,0x2fc60a78,0x7afd016f,0x291e00d8}},	//   ćem_, jnog_, ľstv, lbta_,
   {{0x2fc60537,0x6b820496,0x7afd0076,0x6d5a0122}},	// [8010] dnog_, _mnog, žstv, _obta,
   {{0xd5b80352,0x9258141d,0x00000000,0x00000000}},	//   _всю_, рафт_, --, --,
   {{0x6b820b56,0xbf220026,0xa5bb01ef,0xa3d50b00}},	//   _onog, मरून_, bsór, _гонч,
   {{0x02d9014a,0x2fc67993,0x6b82030d,0x6d5a0110}},	//   _موجب_, gnog_, _nnog, _abta,
   {{0x4431006c,0xceb900fe,0x00000000,0x00000000}},	//   lsz_, _keři_, --, --,
   {{0x69c600b5,0x6b827994,0xf296025a,0x00000000}},	//   ékel, _anog, _הכשר_, --,
   {{0x2fc60254,0x40342bfc,0x6d5a0107,0xdb091dab}},	//   bnog_, _мерс, _dbta, šníc,
   {{0x69ca0200,0x6d5a0fa0,0x2fc6003a,0xa3ab0e04}},	//   _ajfe, _ebta, cnog_, कोच_,
   {{0xe9d9262e,0x29180463,0x3d9500af,0x31710024}},	//   лки_, ıran_, _лиар, _kazz_,
   {{0x6b827995,0xa96903fa,0xd94503fa,0x31717996}},	//   _enog, ћина_, љени, _jazz_,
   {{0xa3d72b22,0x8d740172,0x66160d51,0xe9d60043}},	//   ाका_, _باقا, _styk, скэ_,
   {{0x291e0211,0x4431006c,0x6b820211,0x1b210033}},	//   abta_, dsz_, _gnog, _যাকে_,
   {{0xeab35f8a,0x4431004e,0x9c7c0187,0xda080023}},	//   _بعض_, esz_, _vyče, _tỏa_,
   {{0x2fc60a78,0xb21b01b4,0x4df902b5,0x201a00c3}},	//   znog_, _kræf, רפֿא, yppi_,
   {{0x64a37997,0x28cf0de8,0x68130160,0x00000000}},	//   пара, _सुचि, _băde, --,
   {{0x681300af,0x7e7b0103,0x00000000,0x00000000}},	//   _căde, _orup, --, --,
   {{0x2fc601cc,0x68130395,0xa3d70067,0x00000000}},	// [8020] vnog_, _dăde, ाक़_, --,
   {{0xa5bb0370,0x31710036,0xda0a1b8f,0x00000000}},	//   ssór, _cazz_, _हंसत_, --,
   {{0x2fc601cc,0x645e5750,0x7e7b00d1,0xa9ba0070}},	//   tnog_, _uppi, _arup, נזער,
   {{0x43860082,0xa2d302d1,0xfdb02135,0x7e7b03d0}},	//   _الحق, _भुक्, जफ्फ, _brup,
   {{0x2fc601cc,0xddcb0a66,0x7e561a76,0x80d40099}},	//   rnog_, _šišk, стец, _बँके,
   {{0x2fc67998,0x3a3f082b,0x6b827999,0xdcfa02d4}},	//   snog_, drup_, _snog, _antā,
   {{0x2fc60254,0x409602e7,0x3860022f,0x3d14018d}},	//   pnog_, _الزر, _ćiro_, नुषे_,
   {{0x798327b0,0x20180036,0x2240799a,0x200a00af}},	//   _annw, _itri_, orik_, _iubi_,
   {{0x22405c1b,0x752e0221,0xa92a010b,0x200a023a}},	//   nrik_, kabz, ліне_, _hubi_,
   {{0x388e0669,0xf96a002d,0x44310035,0x2b9800b5}},	//   ləri_, урий_, ysz_, _pécs_,
   {{0x3bd62780,0x2240799b,0x00000000,0x00000000}},	//   _людс, hrik_, --, --,
   {{0x65ab027d,0x25ba0176,0x200a010a,0x7983030d}},	//   _mühe, _ampl_, _mubi_, _ennw,
   {{0x4431799c,0x65ab00be,0x200a799d,0x00000000}},	//   wsz_, _lühe, _lubi_, --,
   {{0x2240799e,0x4431006c,0x6d4a799f,0x388e00a8}},	//   drik_, tsz_, ngfa, həri_,
   {{0xe8d90028,0x69c8397f,0x200a59a6,0x69da79a0}},	//   _đủ_, mnde, _nubi_, mote,
   {{0x7ae279a1,0x224079a2,0x4431278b,0x67d401d3}},	//   _kyot, frik_, rsz_, _нощу,
   {{0x4431006c,0x201879a3,0x69c879a4,0xc1b92c4c}},	// [8030] ssz_, _atri_, onde, алах_,
   {{0x69da79a5,0x672f006a,0x69c879a6,0x64410443}},	//   note, lacj, nnde, àlis,
   {{0x388e0095,0x200a13fb,0x43950819,0x64410300}},	//   fəri_, _cubi_, _данс, álid,
   {{0x200a7805,0x661d3c90,0x672f0035,0x388e00a8}},	//   _dubi_, opsk, nacj, gəri_,
   {{0x63ad066a,0x69da79a7,0x7e7b01c2,0x7ae20245}},	//   mhan, kote, _qrup, _nyot,
   {{0x63ad79a8,0xd6580122,0x69da79a9,0x37cf0033}},	//   lhan, ציות_, jote, রতির,
   {{0x645503cb,0x672f006a,0x69da79aa,0x200a0254}},	//   ntzi, kacj, dote, _gubi_,
   {{0xa3e9051d,0x69c879ab,0xeb991eea,0x7e7b79ac}},	//   यति_, ende, рии_, _trup,
   {{0x200a79ad,0x7e7b0010,0x69da79ae,0xbfa806c2}},	//   _zubi_, _urup, fote, _утре_,
   {{0x499979af,0xfeb804e8,0x6447002f,0x3b1f3ed9}},	//   ртия_, _طاقت_, kuji, sbuq_,
   {{0xa3e900db,0x63ad79b0,0x661d0345,0xb21b0093}},	//   यता_, khan, epsk, _fræg,
   {{0x9986004e,0x69c817fd,0x8b6721a0,0xaa594cc1}},	//   _ktoś_, ande, _دائم, _виду_,
   {{0x63ad79b1,0x69da79b2,0x6db20035,0xe80b0066}},	//   dhan, bote, płat, _संवा_,
   {{0x69da79b3,0x98a5496c,0x7bc91a47,0x00000000}},	//   cote, _миле, lneu, --,
   {{0x63ad152b,0x2fcd012f,0xc3960274,0x64a62b4d}},	//   fhan, _ojeg_, ојањ, цава,
   {{0x63ad79b4,0x7bc979b5,0x2fcd0124,0x422602fb}},	//   ghan, nneu, _njeg_, ждав,
   {{0xa3bb1033,0x200a482b,0x68e379b6,0x7bc9399b}},	// [8040] _अगर_, _subi_, _hynd, ineu,
   {{0x224079b7,0x68e33e21,0x644701d5,0x0f220026}},	//   rrik_, _kynd, buji, मर्स_,
   {{0x63ad79b8,0x106a5320,0x27e001ed,0x13a800f8}},	//   bhan, рией_, _kkin_, _هندی_,
   {{0x68e34601,0x63ad6c03,0x7e60012f,0x69da79b9}},	//   _mynd, chan, _ppmp, zote,
   {{0xa3d70b4a,0x68e379ba,0x69da79bb,0x69c814d3}},	//   ाकर_, _lynd, yote, ynde,
   {{0x672f006a,0x200a3b02,0x63a479bc,0x7ae2028b}},	//   zacj, _tubi_, lkin, _ryot,
   {{0x69da79bd,0xa3ae045c,0x8fa600d8,0x201807e5}},	//   vote, _कता_, _даве, _utri_,
   {{0x63a479be,0x7bc90248,0x69c800e9,0x291800a8}},	//   nkin, gneu, wnde, ıram_,
   {{0x69da79bf,0x63a479c0,0x298a2afc,0x8cda0ec5}},	//   tote, ikin, асно_, _पुरो,
   {{0x69c83236,0x7ae20054,0x672f0035,0x63a40dfa}},	//   unde, _vyot, wacj, hkin,
   {{0x20040669,0x672f004e,0x68e30090,0x69c8119b}},	//   _kimi_, tacj, _cynd, rnde,
   {{0x2907022a,0x63a40120,0x69da79c1,0x3a260359}},	//   _egna_, jkin, sote, _twop_,
   {{0x200419c6,0x672f006a,0x69da0f93,0x68e30051}},	//   _mimi_, racj, pote, _eynd,
   {{0x1dbc0266,0x7bc079c2,0x63ad010d,0x200479c3}},	//   ्चित, limu, whan, _limi_,
   {{0x63ad79c4,0x3d0b0096,0x00000000,0x00000000}},	//   than, ाशते_, --, --,
   {{0x20040303,0x645506a2,0x661d360f,0x52153f20}},	//   _nimi_, rtzi, ppsk, здат,
   {{0x1dbc23db,0xe8100084,0x64553f4a,0x3e5e00ea}},	// [8050] ्चात, _ठंडा_, stzi, nātā_,
   {{0x63ad77e5,0xddc2004e,0x7bc03fb0,0x6447028b}},	//   shan, rtoś, himu, puji,
   {{0x63a479c5,0x35f84c87,0x7bc079c6,0x672d1581}},	//   bkin, _بريد_, kimu, _keaj,
   {{0x63a40122,0xedc320ab,0x7bc02d1b,0xb21b1f8b}},	//   ckin, वच्छ, jimu, _præd,
   {{0x7bc079c7,0xa77c02b5,0xa3e40084,0xa3d804bc}},	//   dimu, יראפ, _पीट_, िवर_,
   {{0x98a50043,0x7bc9001e,0xcddb03fa,0x6aa000e9}},	//   nală_, wneu, шње_, dymf,
   {{0x224906a2,0x8cbe0035,0xdd8e0037,0x660500ab}},	//   luak_, _वेदो, اوى_, _mihk,
   {{0x7bc079c8,0xb21b08c8,0x7bc900f6,0xe1ff0067}},	//   gimu, _træd, uneu, _psów_,
   {{0xdce379c9,0x224901d7,0x68e600a8,0x0f3200b5}},	//   menč, nuak_, əkdi, _سکند,
   {{0x63a40291,0x20040254,0x27e000a5,0xdce379ca}},	//   zkin, _zimi_, _skin_, lenč,
   {{0x7bc079cb,0x63a479cc,0x660d011e,0xb33b05f9}},	//   bimu, ykin, _auak, _elçi,
   {{0xf77214ac,0x224901d7,0x6e2979cd,0x40b6016b}},	//   راج_, kuak_, _kweb, פּיל_,
   {{0xddc91851,0xa3c1073f,0x68e30090,0x63a479ce}},	//   _mrež, ्चन_, _wynd, vkin,
   {{0x68e379cf,0xdb000279,0x224901d7,0x6e291939}},	//   _tynd, rimô, duak_, _mweb,
   {{0x63a479d0,0x69c179d1,0x2a6d79d2,0x5fdb0e61}},	//   tkin, mile, lweb_, यकाल,
   {{0x69c179d3,0xdce302c6,0x6f0979d4,0x63a479d5}},	//   lile, jenč, _ngec, ukin,
   {{0xc64a0082,0x69c10094,0xdce30252,0x200479d6}},	// [8060] _اجعل_, oile, denč, _rimi_,
   {{0x63a479d7,0x69c179d8,0x7bc008c6,0x867b134d}},	//   skin, nile, zimu, _פריו,
   {{0xddc90169,0x036a0deb,0xa06702fb,0x6f6605ac}},	//   _brež, _линк_, заха_, звез,
   {{0x64412d17,0x69c179d9,0xb21b054e,0x22491859}},	//   šlic, hile, _dræb, buak_,
   {{0x69c179da,0x7bc000d8,0xff0302a4,0xddc901a0}},	//   kile, vimu, няшн, _drež,
   {{0x69c179db,0x2a6d79dc,0x00000000,0x00000000}},	//   jile, dweb_, --, --,
   {{0x69c179dd,0x200479de,0xdce30124,0x6e2929c5}},	//   dile, _timi_, benč, _eweb,
   {{0x65ab01c2,0xdce30a69,0xdb0000c3,0xddc9005f}},	//   _müha, cenč, yhmä, _grež,
   {{0xe94400bf,0xadc300e8,0xd91000ff,0x69c179df}},	//   وردی, _quản, نیش_, file,
   {{0x7bc079e0,0x69c179e1,0xddc9023a,0x00000000}},	//   simu, gile, _zrež, --,
   {{0x7bc03122,0x224901d7,0x660d79e2,0x672d79e3}},	//   pimu, zuak_, _suak, _peaj,
   {{0x37ab0374,0xeb972830,0x660d028b,0x69c11a07}},	//   стон_, _них_, _puak, aile,
   {{0x98a5002d,0xa3d000b4,0xcb070037,0x224901a3}},	//   tală_, वचन_, _عيون_, xuak_,
   {{0x69c179e4,0xe94400bf,0xceb30122,0xf9c403c5}},	//   cile, _آرشی, גיש_, _تحصی,
   {{0x98a50043,0x6605005b,0xe7e86882,0x660d0118}},	//   rală_, _vihk, _टीका_, _wuak,
   {{0x443f25e5,0x22490291,0x9c7c0207,0x00000000}},	//   ču_, tuak_, _uzču, --,
   {{0xdce301ba,0x250900b5,0xe2f80185,0x98a500af}},	// [8070] venč, _وردی_, зеті_, pală_,
   {{0x224906a2,0x67d200ea,0xddc90207,0x6e2925db}},	//   ruak_, māja, _srež, _rweb,
   {{0xddc936a5,0x224901d7,0xe7cf0033,0xdce3023a}},	//   _prež, suak_, রতীয, tenč,
   {{0x69c179e5,0x657701f4,0xa3d8007e,0x6e29009e}},	//   zile, _haxh, िवः_, _pweb,
   {{0xddc90009,0xee386c6a,0x69c179e6,0x67d20228}},	//   _vrež, зні_, yile, nāja,
   {{0xfce51c87,0x9c7c00ac,0x05010033,0xb21b0b3e}},	//   моло, _vyčn, ্রীর_, _træb,
   {{0x65770031,0x00000000,0x00000000,0x00000000}},	//   _maxh, --, --, --,
   {{0x09b702cb,0x2a6d00fe,0x6e293a34,0xa2c20ec5}},	//   ेच्य, tweb_, _tweb, _रेड्,
   {{0x69c179e7,0x00000000,0x00000000,0x00000000}},	//   tile, --, --, --,
   {{0x9c7c007e,0x00000000,0x00000000,0x00000000}},	//   _kyčl, --, --, --,
   {{0x69c108a1,0xe3c206d0,0xf74607be,0x4b5502fb}},	//   rile, lmış_, мено, _жълт,
   {{0x69c13d99,0x08d4010b,0x00000000,0x00000000}},	//   sile, эцыя, --, --,
   {{0x65b01ba4,0xe3c206d0,0x69c179e8,0x78a179e9}},	//   _lähe, nmış_, pile, sylv,
   {{0x65ab007c,0x9c7c08b7,0x6b8401a6,0x00000000}},	//   _püha, _izčr, _òigr, --,
   {{0x65b079ea,0xa5070b90,0x00000000,0x00000000}},	//   _nähe, дера_, --, --,
   {{0xe3c2027d,0x25b4010b,0x13fa046c,0x00000000}},	//   kmış_, _šalį_, ्देह_, --,
   {{0xd5b21062,0x00000000,0x00000000,0x00000000}},	// [8080] _لفظ_, --, --, --,
   {{0xa0a60d6e,0xb1431c62,0x65ab033b,0x00000000}},	//   мазд, кнул, _hühn, --,
   {{0xb21b01b4,0x00000000,0x00000000,0x00000000}},	//   _præc, --, --, --,
   {{0xa3e925d8,0x201c0029,0x443a0298,0xddc90069}},	//   यतः_, īvi_, _ivp_, _ereż,
   {{0xdef7081b,0xddc90069,0x65b000c3,0x00000000}},	//   мыш_, _freż, _tähd, --,
   {{0x7e6d0132,0x443a79eb,0x21ef018d,0x00000000}},	//   çapa, _kvp_, püha_, --,
   {{0x91030086,0x443a022f,0xadc300e2,0x44380051}},	//   _апре, _jvp_, _quạn, nsr_,
   {{0xda0800e8,0x3a7479ec,0xe8df00e2,0x31781bb3}},	//   _hỏi_, елир, _chọi_, _harz_,
   {{0x290a13a6,0x443a0051,0x9c7c00ac,0x7c2d0207}},	//   žbam_, _lvp_, _tyčo, ćara,
   {{0x6e2279ed,0xd90d00f8,0x67d200ea,0x09d802b4}},	//   mpob, میه_, vāja, डवेय,
   {{0xda080019,0x65ab01ae,0x31780298,0xc90e0026}},	//   _mỏi_, _bühn, _marz_, _सलीम_,
   {{0x67d20029,0xcb6a00af,0xdca3066d,0x31780282}},	//   tāja, _фаде_, _шахи, _larz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67d202d4,0xdb0b2ddc,0x58d410be,0x443a00c7}},	//   rāja, _algè, _полт, _bvp_,
   {{0x443a0225,0x9f5802d7,0x798a0260,0xe3c201fb}},	//   _cvp_, _juró_, _infw, zmış_,
   {{0x67d20029,0x7c380051,0xe3c201fb,0x00000000}},	//   pāja, isvr, ymış_, --,
   {{0x05010083,0x9f9c0093,0x65b028ef,0xddc9003c}},	// [8090] ্রের_, víð_, _sähe, _preż,
   {{0xd13102de,0x2a6600d7,0x51f8021f,0x443a0051}},	//   اما_, _mpob_, дную_, _fvp_,
   {{0x9f9c0093,0x753579ee,0x533509eb,0x443a006d}},	//   tíð_, mazz, _пент, _gvp_,
   {{0x75352e4b,0x65b02efa,0x78fb0070,0xa2952659}},	//   lazz, _vähe, קלאפ, _замі,
   {{0x59de4092,0x9f580176,0x9f9c008d,0x7c3a2433}},	//   नकार, _auró_, ríð_, _avtr,
   {{0x65b00006,0x7535003c,0xe3c200d0,0x5067081b}},	//   _tähe, nazz, rmış_, _отба,
   {{0x3ea92163,0xfce203e6,0xe0e4010b,0xdce1013b}},	//   šat_, лошо, _аўто, _dalğ,
   {{0x6aca20ab,0x9f5800de,0xe3c2033e,0x6e2201ef}},	//   ापूर, _duró_, pmış_, bpob,
   {{0x7535048c,0x67f600b8,0xb4bc0066,0x99580355}},	//   kazz, náje, _अध्_, láři_,
   {{0xf9910082,0x753579ef,0x201179f0,0xf1b20070}},	//   ابة_, jazz, _kuzi_, ָסט_,
   {{0xa3c136e3,0x39580014,0x20110054,0x7535035f}},	//   ्चा_, òrsa_, _juzi_, dazz,
   {{0x201101d5,0x248600a0,0x798a0107,0x443a00fe}},	//   _muzi_, _čom_, _enfw, _rvp_,
   {{0xa68317e0,0x6b8b1034,0xe9f90210,0x80d90083}},	//   гляд, _ingg, _енді_, ভেচ্,
   {{0xceb25019,0x753507c9,0xf9c70235,0x6e3b0371}},	//   נים_, gazz, _ющен, _mvub,
   {{0xdb0b0248,0x77a60391,0x6f1b0124,0x00000000}},	//   _algé, _lóxi, _ofuc, --,
   {{0x4438021d,0x67d20228,0x00000000,0x00000000}},	//   rsr_, mājo, --, --,
   {{0xe8df01a5,0x65ab01ae,0x201109e0,0xda080023}},	// [80a0] _khỏi_, _kühl, _auzi_, _sỏi_,
   {{0x753507e5,0x443a2b70,0x6b8b0103,0x3ec2013b}},	//   cazz, _tvp_, _lngg, _üstə_,
   {{0x03a6291e,0x65ab033b,0x04ca0c74,0x67d200ea}},	//   _зино, _mühl, _روحي_, nājo,
   {{0x63af0e8f,0x656e00f1,0x38780093,0x645c081c}},	//   _glcn, lebh, ærri_, mtri,
   {{0xdfcf0037,0x31780225,0xb21b0a8a,0x00000000}},	//   حين_, _tarz_, _træa, --,
   {{0x6b8b272d,0xdd90004f,0x201100d7,0xda080023}},	//   _angg, شوب_, _fuzi_, _tỏi_,
   {{0x6e2207a6,0xa067094f,0x9f580036,0x201179f1}},	//   spob, _пара_, _durò_, _guzi_,
   {{0x67d200ea,0x6e22052a,0x645c79f2,0x00000000}},	//   dājo, ppob, itri, --,
   {{0x645c79f3,0x644e79f4,0xa3ae0066,0xdd8f042c}},	//   htri, hubi, _कतई_, _گول_,
   {{0x644e79f5,0x6b8b16ab,0x77640065,0x9f580310}},	//   kubi, _engg, _abix, _turó_,
   {{0x2d8c79f6,0xa3d01e79,0x7535035f,0xd8f802ce}},	//   _inde_, वचा_, vazz, ьної_,
   {{0xe7cf0083,0x645c4ed3,0x2fc600e9,0x2d9e00a2}},	//   রত্য, dtri, niog_, _hote_,
   {{0x2d9e142f,0x75350484,0xe9a601c8,0x65ab01ae}},	//   _kote_, tazz, _падп, _fühl,
   {{0xb21b390d,0x2d9e01f4,0x645c01ae,0xb8940037}},	//   _bræn, _jote_, ftri, _للتع,
   {{0x7535048c,0xdb090037,0xa4d400d4,0x2d9e03d0}},	//   razz, mheá, горі, _mote_,
   {{0x61fe02d7,0x201101b5,0xb21b0b3e,0x00000000}},	//   empl, _ruzi_, _dræn, --,
   {{0x2d8c79f7,0x21310107,0x753579f8,0x717903fa}},	// [80b0] _onde_, _pezh_, pazz, мбар_,
   {{0x2d9e79f9,0xb21b008a,0x764f007b,0x3ea608dd}},	//   _note_, _fræn, mucy, dyot_,
   {{0x645c1121,0xb21b79fa,0x80bd0026,0x03f903e6}},	//   ctri, _græn, ्पें, _оној_,
   {{0x4421239a,0x2d8c79fb,0x61fe5b2b,0x67f600b8}},	//   _ith_, _ande_, ampl, páje,
   {{0x2d9e79fc,0x442179dc,0x3ea602b3,0x539a024b}},	//   _bote_, _hth_, gyot_, _חירו,
   {{0x7bc279fd,0x2d9e79fe,0x201179ff,0x22491e85}},	//   _amou, _cote_, _tuzi_, mrak_,
   {{0xeb99159e,0xabd50798,0x2d9e7a00,0xe81001c0}},	//   дий_, кциј, _dote_, _ठूला_,
   {{0x2d8c7a01,0x77a63207,0x291c0107,0xdd9100fd}},	//   _ende_, _tóxi, _afva_, _ھوا_,
   {{0xdddb0160,0x98ac00ea,0x644e7a02,0x2d8c0183}},	//   _cruţ, vadā_, zubi, _fnde_,
   {{0x598203d4,0x4421026e,0x764f0027,0x8d7400f8}},	//   альб, _oth_, ducy, _ماما,
   {{0x645c007a,0xb604000c,0xe80b0084,0x6d4100e0}},	//   xtri, ntář, _सूखा_, _idla,
   {{0x2d9e0657,0x6b8b09df,0x2ca70093,0x22497a03}},	//   _zote_, _ungg, mynd_, krak_,
   {{0x2d9e0657,0x44217a04,0x61fe351b,0xdb090079}},	//   _yote_, _ath_, ympl, bheá,
   {{0x645c7a05,0x644e7a06,0xa5bb6143,0xdce80355}},	//   ttri, tubi, spón, _nadě,
   {{0x442141a3,0x224906a2,0x656e0e0b,0x657c033b}},	//   _cth_, erak_, rebh, rdrh,
   {{0x224971b3,0x2c7c00b8,0x63790009,0x764f7a07}},	//   frak_, ládá_, нсур_, bucy,
   {{0x644e7a08,0x6d4101cc,0x44217a09,0x7e69006d}},	// [80c0] subi, _odla, _eth_, _npep,
   {{0xb21b054e,0x3f8d0310,0xa92401ba,0x7aeb00c7}},	//   _træn, _aneu_, peľň, _mygt,
   {{0x2d9e7a0a,0x7e690359,0x9c7c00ac,0x224901ed}},	//   _rote_, _apep, _vyčk, arak_,
   {{0x6d417a0b,0x2d9e7a0c,0xdce80038,0x09d50083}},	//   _adla, _sote_, _podľ, _সীমা,
   {{0x69c37a0d,0x2d9e0c1f,0xa3c10246,0x9c7c00d5}},	//   _omne, _pote_, ्चर_, _tyčk,
   {{0x2fc600d8,0x4421012f,0x6296006d,0x7bc20298}},	//   siog_, _yth_, mxyo, _smou,
   {{0x6da30d44,0x6aca3d0a,0x2d9e7a0e,0xfc640ef2}},	//   рија, ाप्र, _vote_, اختی,
   {{0x2d9e0657,0x65ab00ab,0x62867a0f,0x3f8d0176}},	//   _wote_, _rühm, _krko, _gneu_,
   {{0xcb67192f,0x2d9e7a10,0x00000000,0x00000000}},	//   тање_, _tote_, --, --,
   {{0x2d8c0012,0x7aeb01b4,0x6286011c,0x0d832b32}},	//   _unde_, _dygt, _mrko, _клун,
   {{0x31370122,0x22497a11,0x1cba34d9,0x00000000}},	//   כנים_, zrak_, _غائب_, --,
   {{0x97a77a12,0x69c30909,0x765d7a13,0x22490225}},	//   трол, _emne, ttsy, yrak_,
   {{0xdddb156f,0xa2c200a1,0x6296006d,0x00000000}},	//   _hruš, _रेल्, jxyo, --,
   {{0x44217a14,0xdddb1c1a,0x765d17ad,0xdbd10093}},	//   _pth_, _kruš, rtsy, lýðs,
   {{0xd5b80d36,0xd37b0210,0xb4ad0518,0x81d80033}},	//   тся_, мча_, कने_, াতা_,
   {{0x9cd70122,0x62860a16,0x7c4500d5,0x2bb8021a}},	//   דולה_, _brko, _útrž, इफटा,
   {{0x27e90f1a,0x69c800c3,0xd6d8002d,0x6286080a}},	// [80d0] _ikan_, oide, _атэ_, _crko,
   {{0x69c87a15,0x224903cb,0x645a12c3,0x44217a16}},	//   nide, rrak_, àtic, _tth_,
   {{0x3f8d7a17,0xe0d00934,0x69c8009e,0x44210118}},	//   _pneu_, يزم_, iide, _uth_,
   {{0x63b67a18,0x69c87a19,0x22497a1a,0x4815016b}},	//   chyn, hide, prak_, אַסן_,
   {{0x69c87a1b,0xdddb0009,0x3f8100b8,0x25090609}},	//   kide, _aruš, ěhu_, _ترکی_,
   {{0xdddb15ce,0x7aeb08c8,0x5fc400b4,0x69c80a21}},	//   _bruš, _rygt, लोबल, jide,
   {{0x69c87a1c,0x61e5024e,0x25a100b8,0x27e97a1d}},	//   dide, mohl, _mohl_, _okan_,
   {{0x63ad7a1e,0xdddb1851,0xdb090370,0xb5fb7a1f}},	//   nkan, _druš, nheç, ntáb,
   {{0x7e690054,0x63ad7a20,0x7c260009,0x1a650609}},	//   _upep, ikan, _čkre, ایتی_,
   {{0x27e9203f,0x69c87a21,0x63ad005d,0xdddb042a}},	//   _akan_, gide, hkan, _fruš,
   {{0x07a6311c,0xa3e30387,0x644104d9,0xbb5500d1}},	//   ганн, धवा_, šlij, _مناب,
   {{0x63ad7a22,0x61e5007e,0xb21b008c,0x00000000}},	//   jkan, hohl, _præl, --,
   {{0x69c803cb,0x200d01d3,0xdddb053d,0x61e57a23}},	//   bide, _miei_, _zruš, kohl,
   {{0x27e9357b,0x7bc97a24,0x63ad29a0,0x23a700ab}},	//   _ekan_, lieu, ekan, _mõju_,
   {{0x63ad0298,0x74162604,0x98ac00af,0x63b6016e}},	//   fkan, اورا, radă_, thyn,
   {{0xa6967a25,0x7bc97a26,0x63ad1c04,0x6b9b00a2}},	//   _број, nieu, gkan, njug,
   {{0x6abb02c9,0x63b67a27,0xe1fa2770,0x9c7c7a28}},	// [80e0] nzuf, rhyn, ега_, _vyči,
   {{0x7c3e7a29,0x201c0132,0x65b0033b,0x628600d5}},	//   špri, ívio_, _zähn, _vrko,
   {{0x64a61bc4,0x11d70082,0x63ad0ac8,0x68130160}},	//   _сана, دولة_, bkan, _bădi,
   {{0x69c87a2a,0x63ad7a2b,0xaf36017e,0xe29a290a}},	//   zide, ckan, ارات, _зам_,
   {{0xdddb0289,0x6da612f3,0x6b9b7a2c,0x657e00b5}},	//   _sruš, лида, djug, _kaph,
   {{0x657e1b68,0xdddb023a,0x6e9300af,0x00000000}},	//   _japh, _pruš, сишу, --,
   {{0xb5fb53b1,0x7bc900a2,0x00000000,0x00000000}},	//   ltác, fieu, --, --,
   {{0x7bc956cc,0xafe63669,0x69c87a2d,0xbc672489}},	//   gieu, _собл, wide, امين_,
   {{0xb5fb7a2e,0x69c87a2f,0xdb0b099e,0x00000000}},	//   ntác, tide, _algâ, --,
   {{0x657e7a30,0x69c80211,0xb33b1ffd,0x27e97a31}},	//   _naph, uide, _moça, _skan_,
   {{0x69c87a32,0x63ad7a33,0x0c260b32,0x6b9b035f}},	//   ride, ykan, _смен, bjug,
   {{0x7bc90248,0x7a860493,0x63ad01a3,0x644100ea}},	//   cieu, _مشتم, xkan, šlik,
   {{0xb8eb065a,0x657e0027,0x78ba00b5,0x25a1532b}},	//   _रे_, _baph, sztv, _pohl_,
   {{0x2d9c01f4,0x3eb90225,0x657e5790,0x00000000}},	//   njve_, _üste_, _caph, --,
   {{0xf3677a34,0x63ad7a35,0x69d80223,0x61e500fe}},	//   лтан, tkan, _ijve, vohl,
   {{0x25a102c9,0x65ab7a36,0x67f600a0,0x63ad7a37}},	//   _wohl_, _mühi, pája, ukan,
   {{0x6d5a022e,0x65ab007c,0x45d500af,0xb33b0183}},	// [80f0] _octa, _lühi, _вопс, _coça,
   {{0x291e2000,0x61fc00ac,0x657e2014,0xb5fb628c}},	//   ncta_, _chrl, _gaph, stáb,
   {{0x63ad2ed3,0x62843ad5,0x3f155a4b,0xb5fb1e15}},	//   pkan, avio, адес, ptáb,
   {{0x61fc033b,0xa85700a5,0xfe790355,0x00000000}},	//   _ehrl, ריאה_, _psů_, --,
   {{0xb5fb6828,0xed591d30,0x7bc900a2,0x61e500d5}},	//   ctác, вол_, vieu, pohl,
   {{0xdcfa0d6f,0xdca51960,0x777f0024,0x00000000}},	//   _altı, иали, _laqx, --,
   {{0x9f6b01c8,0x7bc97a38,0x00000000,0x00000000}},	//   _праз_, tieu, --, --,
   {{0x69d80009,0x747c00a5,0x0ec00099,0x00000000}},	//   _ajve, תנהג, _शेकड, --,
   {{0x7bc97a39,0xe9d91f39,0x6b9b7a3a,0x00000000}},	//   rieu, кки_, rjug, --,
   {{0x7bc902e1,0xa2d800a1,0xf86509c0,0xe8190026}},	//   sieu, _यशस्, авоо, _नंदा_,
   {{0xe8f60b7d,0x6abb01ae,0x7bc9000d,0x8afd00b8}},	//   иль_, szuf, pieu, teřs,
   {{0x657e7a3b,0xd7067a3c,0x628300ea,0xe73a0421}},	//   _saph, изни, ānoj, ъем_,
   {{0x2bb8004f,0xaf760070,0x67d200ea,0x777f0069}},	//   _حالة_, בערס_, nāji, _daqx,
   {{0xc9870274,0xb33b0183,0x00000000,0x00000000}},	//   _људи, _roça, --, --,
   {{0x8883006c,0xc9d400f8,0xab5d003c,0xb21b08c8}},	//   _ایجن, _دموک, viżj, _fræk,
   {{0x03260011,0xc3261353,0x65b001ae,0xb21b08c8}},	//   рдан, рмак, _zähl, _græk,
   {{0x311600d8,0x130a010b,0x290a0207,0x61fc0211}},	// [8100] афес, тнай_, žbat_, _phrl,
   {{0x62847a3d,0xc0460841,0x67d20228,0xb5fb040f}},	//   rvio, لخصو, dāji, rtác,
   {{0x7e7b0043,0x67f6016f,0x62847a3e,0x753c0067}},	//   _asup, nájo, svio, marz,
   {{0x753c0035,0x0eaa02ee,0xdce10409,0x00000000}},	//   larz, ккей_, _halė, --,
   {{0xfe720e3a,0xdce1010b,0x7e7b00b5,0x471b0070}},	//   تدا_, _kalė, _csup, דונג,
   {{0x7981006d,0x9c460e9f,0x753c3c84,0x2478021e}},	//   jdlw, ахил, narz, _kōm_,
   {{0x22401292,0x10a60217,0x7e7b2884,0x65b00110}},	//   lsik_, _тивн, _esup, _nähm,
   {{0xafe302ce,0x207b0070,0xaa6612b1,0x644e0098}},	//   _досл, _באלא, аток, irbi,
   {{0x753c004e,0x68130139,0x00000000,0x00000000}},	//   karz, _mădu, --, --,
   {{0x1daa0ac4,0x20187a3f,0x65ab00ab,0x753c0035}},	//   _कवित, _kuri_, _tühi, jarz,
   {{0x20182a62,0x753c004e,0x7e627a40,0xdcfa0107}},	//   _juri_, darz, ltop, _katč,
   {{0x201825a2,0x65b002c9,0x22407a41,0xab2a4bf9}},	//   _muri_, _wähl, ksik_, _рода_,
   {{0x95cb06c2,0x22400009,0x644e66a8,0xdcfa62fc}},	//   вува_, jsik_, erbi, _matč,
   {{0x6d587a42,0x670302cb,0x753c01ed,0x9c7c0107}},	//   ngva, रेषक_, garz, _fyčt,
   {{0x20187a43,0x94a81614,0xb21b054e,0x44257a44}},	//   _nuri_, атта_, _træk, ël_,
   {{0x7e620830,0xf77f0279,0x47357172,0xdcfa0009}},	//   ktop, moço_, _унис, _natč,
   {{0x20181047,0x22401292,0x7c2d0124,0x7e6200cd}},	// [8110] _auri_, gsik_, ćari, jtop,
   {{0x20180232,0xdce101c8,0x4433022e,0x673d7a45}},	//   _buri_, _galė, _twx_, lasj,
   {{0x20187a46,0xd6d90033,0x7e7b0069,0x00000000}},	//   _curi_, _সরিয, _ssup, --,
   {{0x9f050514,0x64557a47,0x20187a48,0x67d20080}},	//   موضو, muzi, _duri_, tāji,
   {{0x64557a49,0xd2440043,0x7e62008c,0x20187a4a}},	//   luzi, _мэри, gtop, _euri_,
   {{0x518760f8,0x20180160,0x2b460036,0x67d2013a}},	//   _тума, _furi_, _adoc_, rāji,
   {{0x20187a4b,0x645513fb,0x673d02ce,0xb5b800a5}},	//   _guri_, nuzi, kasj, שלוח_,
   {{0x7e6200d7,0x3a3f008c,0x3219096b,0x7e7b08dd}},	//   btop, tsup_, _kusy_, _tsup,
   {{0x20187a4c,0xa3af0006,0xefc8021d,0xef190069}},	//   _zuri_, _कवन_, _турк_, _gaża_,
   {{0x64557a4d,0x00000000,0x00000000,0x00000000}},	//   kuzi, --, --, --,
   {{0xe73a4db5,0x3a26030d,0x4998010b,0x480a7a4e}},	//   лен_, _etop_, ртыя_, леон_,
   {{0x64557a4f,0x753c004e,0xf3ff0023,0x3a3f1b82}},	//   duzi, warz, _nhã_, psup_,
   {{0xa969562d,0x753c7a50,0x31af027d,0xe9690421}},	//   _била_, tarz, _kızı_, _балл_,
   {{0x657500fd,0x64a6093e,0xf77f0183,0xa2c27a51}},	//   gezh, бага, boço_, _रेग्,
   {{0x64557a52,0xa34a01d3,0x6813002d,0x753c0b38}},	//   guzi, лзва_, _pădu, rarz,
   {{0xb4e80084,0x22407a53,0x201801d5,0x753c3c84}},	//   _बडी_, tsik_, _ruri_, sarz,
   {{0xe2970854,0x17570122,0x67f60187,0x20187a54}},	// [8120] бат_, _הספר_, nájm, _suri_,
   {{0x64557a55,0x04462a24,0xb5fb7a56,0xf1aa1ee1}},	//   buzi, _леон, ltán, داره_,
   {{0x64557a57,0x22407a58,0x32110118,0xe3b20dc0}},	//   cuzi, ssik_, _dizy_, _فرح_,
   {{0xb5fb0300,0x7e6238a2,0xa3bc08b6,0x20180031}},	//   ntán, ttop, _अति_, _vuri_,
   {{0x44447a59,0x201801cb,0x9f5f0023,0x0cb0012f}},	//   _hv_, _wuri_, _khuê_, जन्म,
   {{0x20187a5a,0x3f80010b,0x62830035,0x2c610098}},	//   _turi_, žiu_, łnoc, fód_,
   {{0x7e627a5b,0x444400d1,0x63a67a5c,0x20187a5d}},	//   stop, _jv_, _kokn, _uuri_,
   {{0x1ae10033,0x3a2601f7,0x6ad3021a,0x7e627a5e}},	//   খেছে_, _ptop_, दपूर, ptop,
   {{0x44447a5f,0x67d20ae0,0xa5bb004f,0xc986465e}},	//   _lv_, nāju, spói, буни,
   {{0x44447a60,0x67246666,0x63a6008d,0x9d430c46}},	//   _ov_, _afij, _lokn, _неуд,
   {{0xd90d00d1,0x6d487a61,0x76440260,0x673d00d4}},	//   نیه_, _idda, _aviy, tasj,
   {{0x200600e2,0x20050176,0xf77f0183,0x00000000}},	//   nmoi_, _èlit_, roço_, --,
   {{0x44447a62,0x673d02ce,0x386e01ef,0x6af60079}},	//   _av_, rasj, _wpfr_, _اثار,
   {{0x64557a63,0x44447a64,0xb21b054e,0x67d20029}},	//   tuzi, _bv_, _kræv, dāju,
   {{0x657500fd,0x6b820159,0x63a601ff,0x7afc00a8}},	//   rezh, _kaog, _bokn, ərta,
   {{0x44447a65,0x645501d3,0xb5fb0b06,0x6d480103}},	//   _dv_, ruzi, ctán, _ldda,
   {{0x6d487a66,0x44447a67,0x67d200ea,0x64557a68}},	// [8130] _odda, _ev_, gāju, suzi,
   {{0x6b827a69,0x00000000,0x00000000,0x00000000}},	//   _laog, --, --, --,
   {{0x63a67a6a,0x00000000,0x00000000,0x00000000}},	//   _fokn, --, --, --,
   {{0x6d487a6b,0x776d0024,0x6b820e4e,0x61ee5eec}},	//   _adda, _jbax, _naog, _ekbl,
   {{0xa77c02b5,0x44441e28,0x2c610035,0x6da50a9f}},	//   טראפ, _zv_, wód_, жила,
   {{0x5bb12893,0x2bb17a6c,0x6b82009e,0x98a700b8}},	//   जस्व, जस्थ, _aaog, _ceně_,
   {{0x65b003ad,0x6b827a6d,0x4c920274,0x00000000}},	//   _sähk, _baog, дијс, --,
   {{0x2c61004e,0x6d4801a8,0x0a4902ee,0xaba902fb}},	//   ród_, _edda, азий_, рвиз_,
   {{0x602500d8,0x00000000,0x00000000,0x00000000}},	//   _dėme, --, --, --,
   {{0x65ab02b1,0x00000000,0x00000000,0x00000000}},	//   _mühs, --, --, --,
   {{0xa3e96ecd,0x18697a6e,0x6b820284,0x98a500af}},	//   मका_, шани_, _faog, цине,
   {{0x2a7d0221,0x4e1d2869,0x69ca0103,0x44447a6f}},	//   _tswb_, _पढाई_, _emfe, _rv_,
   {{0x63a6007a,0xe9ce1172,0xd9453f74,0x69cf76b5}},	//   _rokn, _жк_, _дели, éces,
   {{0x67d20029,0xb5fb7a70,0x6b820124,0x63a67a71}},	//   vāju, stán, _zaog, _sokn,
   {{0x63a6023a,0xb4b422a3,0x833a7a72,0xa50a09a5}},	//   _pokn, झने_, ичат_, рева_,
   {{0x67d20080,0x0457004f,0x79830090,0x65b000b9}},	//   tāju, تلفة_, _hanw, _mähi,
   {{0x9f5f0028,0x65b01246,0xdce300b8,0xe29a0132}},	// [8140] _thuê_, _lähi, teně, шаа_,
   {{0x44440122,0xb5fb122d,0x3ce0027d,0xa7fd045e}},	//   _tv_, ntál, şivi_, ntın,
   {{0xef1a2e76,0x79837a73,0xdce10080,0x44447a74}},	//   аме_, _manw, _dalī, _uv_,
   {{0xf1bf0332,0xb5fb0037,0x79837a75,0xa2cb00e7}},	//   _után_, htál, _lanw, _सेव्,
   {{0x644101ba,0x20060031,0x5de6218b,0x6b820211}},	//   šlit, rmoi_, ожда, _raog,
   {{0x6b820014,0x7bcb001e,0x26c201d7,0xdce100ea}},	//   _saog, _amgu, izko_, _galī,
   {{0x6e29030d,0xb4e80067,0x201e0139,0x00000000}},	//   _eteb, _बडो_, _îti_, --,
   {{0xdee61453,0x0b8a1714,0x79830244,0x00000000}},	//   _доби, рски_, _aanw, --,
   {{0x79830a2d,0xed5a751e,0x290305ee,0x22527a76}},	//   _banw, _воз_, ýjan_, nryk_,
   {{0x6d480022,0x19aa0036,0x3f840054,0x65b0033b}},	//   _udda, ртип_, _hamu_, _fähi,
   {{0x3f840a99,0xd7fb519c,0xa3ea00be,0x79837a77}},	//   _kamu_, иум_, यवा_, _danw,
   {{0x3f860519,0x3f847a78,0xa7fd3833,0xc7c701e0}},	//   ndou_, _jamu_, atın, існи,
   {{0x3f847a79,0x8ad6006c,0x798300e9,0x236901e8}},	//   _mamu_, _بتائ, _fanw, vfaj_,
   {{0x69ca0e34,0xd5b81172,0x3f847a7a,0x98a50228}},	//   _umfe, осс_, _lamu_, galē_,
   {{0x26c201a3,0x00000000,0x00000000,0x00000000}},	//   azko_, --, --, --,
   {{0xdce10029,0x3f847a7b,0x3f8600b8,0x00000000}},	//   _salī, _namu_, jdou_, --,
   {{0xdce10080,0x69da2930,0x1ddb0cf1,0x23ae008a}},	// [8150] _palī, onte, _बदलत, _nýju_,
   {{0x69da7a7c,0xd25000b5,0x7afd0093,0x3f840421}},	//   nnte, کنے_, ýsti, _aamu_,
   {{0x65ab02c9,0x6e297a7d,0x3f847a7e,0xb5fb25a8}},	//   _führ, _steb, _bamu_, ntám,
   {{0xa3af0bc1,0xd47a00c2,0xb5fb006c,0x69da033b}},	//   _कवि_, _פארל, ztál, hnte,
   {{0x3f840054,0xa7fd00a8,0x539a00a5,0xa3c200b4}},	//   _damu_, ytın, _הירו, _्गत_,
   {{0xa7fd0095,0xa5bb0132,0xf2d20070,0xd65800a5}},	//   xtın, mpós, _װעל_, קיות_,
   {{0x6ad30380,0x21ef01ae,0x9f3501e0,0x3f8400fe}},	//   दप्र, bühr_, _неві, _famu_,
   {{0x69da7a7f,0xeb991cf7,0x79830260,0xb21b05ee}},	//   ente, сии_, _sanw, _fræt,
   {{0x6e297a80,0x2fcd00fe,0xa7fd0225,0x00000000}},	//   _uteb, _imeg_, ttın, --,
   {{0x65b0007c,0x7db70037,0x3f84002f,0x49991172}},	//   _tähi, _بصرا, _zamu_, стия_,
   {{0xb5fb122d,0x79830c7c,0xa7fd00d0,0x63ba00ea}},	//   rtál, _vanw, rtın, ūtni,
   {{0x69da0473,0xb5fb6d9b,0x2d851dfa,0x628f07a6}},	//   ante, stál, _hale_, _orco,
   {{0x2d857a81,0x199502fb,0x79834087,0xa2cb3f52}},	//   _kale_, _надя, _tanw, _सेल्,
   {{0x2d87590a,0x2d85156b,0x64a62ccc,0xa7fd01fb}},	//   ndne_, _jale_, пага, ltıl,
   {{0x64a60c0e,0x2d857a82,0x291c00a0,0xb5fb0138}},	//   чава, _male_, ázať_, ctám,
   {{0x42260b32,0xa7fd06d3,0x22527a83,0x03a30a80}},	//   здав, ntıl, tryk_, нисо,
   {{0x27e00703,0xe29703e6,0x3f845bd3,0xab5d0035}},	// [8160] _ijin_, пат_, _ramu_, liżs,
   {{0xb46603b1,0x76467a84,0x628f0a8a,0x22527a85}},	//   _екол, msky, _drco, rryk_,
   {{0xe1ff0370,0x628f7a86,0x76467a87,0xb21b008c}},	//   _após_, _erco, lsky, _bræs,
   {{0x205518f0,0x2d8503d0,0xb21b0a8a,0xa6db008d}},	//   ьтур, _aale_, _præt, laða,
   {{0x2d857a88,0x76463d2e,0x3f860015,0x63a427df}},	//   _bale_, nsky, rdou_, mjin,
   {{0x63a47a89,0xa6db008a,0x63b67a8a,0x2d857a8b}},	//   ljin, naða, lkyn, _cale_,
   {{0x2d857a8c,0x3f847a8d,0xb21b4777,0xc0e3010b}},	//   _dale_, _tamu_, _fræs, _зорк,
   {{0x69dd1010,0x63a4341d,0xb21b0249,0x27e00124}},	//   ésen, njin, _græs, _njin_,
   {{0x2d857a8e,0xc9860274,0x6fb10067,0xa6db008d}},	//   _fale_, пуни, _अकतू, kaða,
   {{0x69da7a8f,0x27e000d7,0x764644df,0x291801e0}},	//   unte, _ajin_, dsky, øra_,
   {{0x69da10c0,0x76460345,0x7d020079,0x7bdb0b88}},	//   rnte, esky, _dírí, bnuu,
   {{0x2d857a90,0x3cfb0317,0x7ae201a3,0x38c200f6}},	//   _zale_, _פלאנ, _txot, _aéré_,
   {{0x2c0b006c,0x443a0098,0x63a47a91,0x2d857a92}},	//   _اعلی_, _awp_, djin, _yale_,
   {{0x7afd3025,0xa2a700a1,0xa3cf021a,0x00000000}},	//   üste, _टॅग्, वोन_, --,
   {{0x628f00f4,0x20040160,0x00000000,0x00000000}},	//   _srco, _ohmi_, --, --,
   {{0x27e00055,0x63a400da,0xa3bc0d55,0x08770070}},	//   _gjin_, gjin, _अतः_, _זעהט_,
   {{0x52150dba,0x628f0176,0x00000000,0x00000000}},	// [8170] ддат, _qrco, --, --,
   {{0xbba900dc,0x940b00a8,0x673f01f4,0x38c2000d}},	//   _छक्क, _əmək_, _heqj, _géré_,
   {{0xb21b054e,0x2d8502d0,0x673f0031,0x00000000}},	//   _præs, _rale_, _keqj, --,
   {{0x2d857a93,0x6455012e,0x7d1a0b88,0x200400fe}},	//   _sale_, mrzi, _agts, _chmi_,
   {{0x2d857a94,0x63bd009f,0x66170065,0x673f035f}},	//   _pale_, _ilsn, _kixk, _meqj,
   {{0x645501e4,0x00000000,0x00000000,0x00000000}},	//   orzi, --, --, --,
   {{0x2d853ca6,0xac097a95,0x2d877a96,0xdcfa0160}},	//   _vale_, онка_, rdne_, _rată,
   {{0x2d850657,0x2fdf01cb,0x395e00ea,0x7998021e}},	//   _wale_, _ujug_, egts_, _anvw,
   {{0x2d857a97,0xfe7000bf,0xa7fd01fb,0x6f1b0027}},	//   _tale_, _مدل_, rtıl, _iguc,
   {{0x3ce81556,0x27f27a98,0xb5fb00b5,0x95880067}},	//   _चुके_, _skyn_, stáj, _krąż,
   {{0x6d43007e,0x3cf0024e,0xdddb0254,0xa6db003e}},	//   mana, čové_, _kruž, vaða,
   {{0x65b041b7,0x7bc07a99,0x2fdd00e9,0x64551793}},	//   _läht, chmu, nnwg_, drzi,
   {{0xb8f43ded,0xa6db0093,0xdcfa00af,0x443a099e}},	//   _से_, taða, _tată, _swp_,
   {{0x76467a9a,0x273c0028,0x65b01c55,0x6b893a41}},	//   rsky, ận_, _näht, ldeg,
   {{0xdddb0a78,0x69c17a9b,0x76467a9c,0x80ad0033}},	//   _oruž, mhle, ssky, _টেস্,
   {{0x6d43640d,0x6f1b00f8,0x764600a0,0x661f0024}},	//   hana, _nguc, psky, _fuqk,
   {{0xdb0b1f37,0x59e1114e,0xa3af0243,0x41aa7a9d}},	// [8180] _algú, _पदार, _कवर_, ован_,
   {{0x63b67a9e,0x443a4d47,0x63a43dd1,0x69c17a9f}},	//   skyn, _twp_, sjin, nhle,
   {{0x657c7aa0,0x7bc7010b,0x628b01ff,0x6e3b0027}},	//   merh, _įjun, ågor, _awub,
   {{0x645c7aa1,0x3fbe0083,0xdd8f0e3a,0x657c7aa2}},	//   muri, েক্ষ, یون_, lerh,
   {{0xdddb4beb,0x79880297,0x6d437aa3,0xdfcf0037}},	//   _druž, yddw, fana, جين_,
   {{0x6d437aa4,0x657c02c9,0x60c900b8,0x6b8977f1}},	//   gana, nerh, _řeme, edeg,
   {{0x645c7aa5,0xe8190084,0x69c17aa6,0x7bc07aa7}},	//   nuri, _नंगा_, dhle, thmu,
   {{0x6b897aa8,0x6d430008,0x657c1ca7,0x00000000}},	//   gdeg, aana, herh, --,
   {{0x645c7aa9,0x6d4322fb,0x657c7aaa,0x53c60067}},	//   huri, bana, kerh, रोएश,
   {{0x645c7aab,0x657c0453,0x7bc00031,0x69c126c9}},	//   kuri, jerh, shmu, ghle,
   {{0x6e2001d2,0x7988001e,0x315700a5,0x6da30009}},	//   _humb, rddw, ויין_, _шифа,
   {{0x645c7aac,0x6e207aad,0x9b930037,0xb5fb00d5}},	//   duri, _kumb, _للمت, pták,
   {{0xdce800d8,0x6e200b4f,0x661701d7,0x657c7aae}},	//   _padė, _jumb, _pixk, ferh,
   {{0xceb300c2,0x645c7aaf,0x69c140cb,0x64470345}},	//   דיש_, furi, chle, tsji,
   {{0x6e201e77,0x67d55f13,0xb5fb004f,0x645c7ab0}},	//   _lumb, _поку, ntái, guri,
   {{0x6d437a43,0x62830067,0x6e200523,0x00000000}},	//   zana, łnom, _oumb, --,
   {{0x6e207ab1,0x657c7ab2,0x65951174,0xb5fb0037}},	// [8190] _numb, berh, _запу, htái,
   {{0x6d4300a8,0x645c7ab3,0x44310523,0x4905000c}},	//   xana, buri, ppz_, हेको_,
   {{0xdddb011c,0x645c4afe,0x765d1c3f,0x104801e0}},	//   _pruž, curi, lusy, дячи_,
   {{0x6d437ab4,0x93c9006c,0xef19007a,0x32180090}},	//   wana, _راجہ_, _każi_, _eiry_,
   {{0x6d437ab5,0x6e207ab6,0x65b01c55,0xee381112}},	//   tana, _cumb, _täht, дні_,
   {{0xa2bf0722,0xdd94005f,0x9f4d01da,0x44217ab7}},	//   लैण्, качы, _cheò_, _kuh_,
   {{0x6d437ab8,0x442100a0,0x22497642,0x69dd2d03}},	//   rana, _juh_, lsak_, ésem,
   {{0x6d437ab9,0x65b001ae,0x6e207aba,0x6b89018d}},	//   sana, _jähr, _fumb, udeg,
   {{0x6d437abb,0x6b897abc,0x645c7abd,0x6e207abe}},	//   pana, rdeg, zuri, _gumb,
   {{0x6d430c54,0x645c7abf,0x44217ac0,0x6b897ac1}},	//   qana, yuri, _ouh_, sdeg,
   {{0x657c3569,0x442100d6,0x6d410029,0x3e6900fd}},	//   verh, _nuh_, _iela, lút_,
   {{0x6d417ac2,0x22497ac3,0xf09202b5,0x657c7ac4}},	//   _hela, ksak_, אנט_, werh,
   {{0x6d410b0e,0x657c7ac5,0x3e6901ba,0xe3c200d0}},	//   _kela, terh, nút_, nlış_,
   {{0x9aa410ee,0x6d410452,0xdb090086,0x394e7ac6}},	//   _جمهو, _jela, rkeä, _gdfs_,
   {{0x6d41120d,0xa3bc0299,0xccf202b5,0x39457ac7}},	//   _mela, असल_, ָכן_, mals_,
   {{0x6d414323,0x645c7ac8,0x2249053e,0x765d0927}},	//   _lela, ruri, fsak_, busy,
   {{0x657c2311,0x22497ac9,0x442161d8,0x23602d89}},	// [81a0] perh, gsak_, _euh_, rgij_,
   {{0x6d417aca,0xe88901a5,0x39454790,0x6e200f4f}},	//   _nela, _kẻ_, nals_, _rumb,
   {{0x6e200452,0x65b001ae,0xdddb0035,0x21f4033b}},	//   _sumb, _fähr, _druż, fähr_,
   {{0xa2cb162b,0xfe462264,0xe8890023,0x6e207acb}},	//   _सेक्, ендо, _mẻ_, _pumb,
   {{0xe88901a5,0x39450029,0xc17400b5,0x00000000}},	//   _lẻ_, kals_, _لگات, --,
   {{0x6da35a7e,0x6e2026df,0x57ad00a1,0xdce10448}},	//   лича, _vumb, _चव्ह, _anlı,
   {{0x8d1a0332,0x7c21009e,0x91e30421,0x00000000}},	//   _ہزار_, _culr, _соре, --,
   {{0x6e201581,0xb5fb004f,0x6d41007c,0x8aa61682}},	//   _tumb, rtái, _eela, ерод,
   {{0x6d417acc,0xb5fb0082,0x628602c4,0xa3e80461}},	//   _fela, stái, _jsko, _बदन_,
   {{0xbe131b15,0x39457acd,0x7afd01c2,0xdca63d1a}},	//   _موقع, gals_, üsta, _пази,
   {{0x815702b5,0x888101cb,0x00000000,0x00000000}},	//   עסטע_, لیون, --, --,
   {{0xfa88098b,0x6d410291,0xb5fb03e6,0x44217ace}},	//   _từ_, _zela, ntáv, _ruh_,
   {{0x44217acf,0x39457ad0,0x42db0083,0x628601f2}},	//   _suh_, bals_, _দর্শ, _nsko,
   {{0x39457ad1,0x44210086,0x6d41002a,0xc8f402fb}},	//   cals_, _puh_, _xela, _излъ,
   {{0x62867ad2,0xd90e0919,0x9f5f0098,0x00000000}},	//   _asko, _دید_, _shuí_, --,
   {{0x22497ad3,0x765d7ad4,0xdcf800f4,0xdcfa02d4}},	//   tsak_, pusy, jevč, _antī,
   {{0xd2513e7c,0x672d4374,0x44210118,0x798a034d}},	// [81b0] شنا_, _ifaj, _wuh_, _kafw,
   {{0x65b002c9,0x21f401ae,0x22497ad5,0x60e72d93}},	//   _währ, währ_, rsak_, нцез,
   {{0x62867ad6,0xe8890023,0x6adc157d,0x22497ad7}},	//   _esko, _xẻ_, मपुर, ssak_,
   {{0x6d41120d,0x3fcf0033,0x3e69726f,0x672d0069}},	//   _sela, িক্ষ, tút_, _jfaj,
   {{0x6d41247e,0xdb0b00da,0x69dd006c,0x6286034d}},	//   _pela, _vogë, ések, _gsko,
   {{0xdce80080,0x3e697ad8,0x00000000,0x00000000}},	//   _gadī, rút_, --, --,
   {{0x63af0124,0xdbd70282,0x00000000,0x00000000}},	//   _kocn, _låån, --, --,
   {{0xe8890028,0x6d417ad9,0x0ed20026,0x1adc0067}},	//   _rẻ_, _wela, _देवड, मपंथ,
   {{0x39457ada,0x6d41203f,0xe8890028,0x63af088d}},	//   tals_, _tela, _sẻ_, _mocn,
   {{0x798a00e9,0x00000000,0x00000000,0x00000000}},	//   _cafw, --, --, --,
   {{0x39450955,0xb90200d4,0x39580098,0x00000000}},	//   rals_, изьк, órsa_, --,
   {{0x39457adb,0xe88901a5,0xb90900a1,0x63af3eae}},	//   sals_, _vẻ_, _यश_, _nocn,
   {{0x39455f49,0xae210066,0xdb190107,0x5fa600b4}},	//   pals_, मदिन_, _emwò, कॉटल,
   {{0xceb20052,0xeab00037,0xe88900e2,0x798a016e}},	//   סים_, _دعم_, _tẻ_, _gafw,
   {{0xddc20029,0xdce80029,0xb5fb0097,0x6b8b7adc}},	//   ntoš, _radī, ytáv, _kagg,
   {{0x087602b5,0x5eb70033,0x00000000,0x00000000}},	//   _יעצט_, _আইনে, --, --,
   {{0x6b8b7add,0x63af042a,0x61e200f7,0x98be00ea}},	// [81c0] _magg, _docn, éolo, matā_,
   {{0x00da017e,0xb65b025a,0xdb0b00f6,0x6286068f}},	//   وبات_, _קדיש, _cogé, _vsko,
   {{0xdce80080,0xb33b013b,0x645a002a,0x00000000}},	//   _vadī, _poçt, átid, --,
   {{0x6b8b03be,0xb4ae0907,0x705300d1,0x628602c4}},	//   _nagg, कही_, شنها, _tsko,
   {{0x62867ade,0xb5fb7adf,0x6da61303,0x5d78002d}},	//   _usko, rtáv, кида, ейля_,
   {{0xb5fb05d3,0x8d630202,0xe62600e2,0x00000000}},	//   stáv, авље, _đôla_, --,
   {{0x6b8b7ae0,0xb5fb01c0,0xcbe67ae1,0x3ea000af}},	//   _bagg, ptáv, кции, ţit_,
   {{0x6b8b0036,0x61fe3308,0xc0e31f39,0xe4570070}},	//   _cagg, llpl, _тоск, דיקט_,
   {{0xd00f0082,0x6b8b7ae2,0x2a6d006d,0x798a02d0}},	//   _ذلك_, _dagg, gteb_, _pafw,
   {{0xb5fb1d8a,0x6b8b099e,0x672d0069,0x00000000}},	//   ntát, _eagg, _sfaj, --,
   {{0x2d9e1304,0x6b8b7ae3,0x2d8c0225,0xdddb00d5}},	//   _inte_, _fagg, _iade_, _usuš,
   {{0x2d8c06d7,0x6b8b7ae4,0xe8e00023,0x98be013a}},	//   _hade_, _gagg, _ngụy_, gatā_,
   {{0x2d8c7ae5,0xc9aa04bf,0x63af7ae6,0x2d9e0211}},	//   _kade_, _овде_, _rocn, _knte_,
   {{0xea770122,0xa4d500d4,0x7bc200b8,0x9f4f00a2}},	//   _סגור_, гогі, _hlou, rogé_,
   {{0x2d8c0052,0x7bc27ae7,0xc7c73d22,0x63af4096}},	//   _made_, _klou, _аспи, _pocn,
   {{0x2d8c7ae8,0x61fe09b0,0xa6db003e,0xd4070421}},	//   _lade_, elpl, naðk, тяги,
   {{0xf8e20f0d,0x2fc600f8,0x2d9e0042,0x63af0124}},	// [81d0] _पशुप, dhog_, _onte_, _vocn,
   {{0x2d8c7ae9,0x7bc20176,0x80be0033,0xa3af0067}},	//   _nade_, _llou, ্পন্, _कवक_,
   {{0x44271a24,0x63af06cc,0x69dd00b5,0xaad90066}},	//   _în_, _tocn, ései, _बेनक,
   {{0x2d9e09ab,0xb4c1004e,0x44337aea,0x2fc608dd}},	//   _ante_, ्छी_, _itx_, ghog_,
   {{0x6b8b7aeb,0x44337aec,0x4ea702fb,0xb5fb01ef}},	//   _ragg, _htx_, ържа, stáu,
   {{0xf2d20052,0x7bc27aed,0x2d8c6ba3,0xfce52c61}},	//   _פעם_, _alou, _cade_, лоло,
   {{0x6b8b32e1,0x7bc27aee,0x2d8c7aef,0x80d10831}},	//   _pagg, _blou, _dade_, _তুর্,
   {{0x2d9e7af0,0x7bc27af1,0xddc27af2,0x2fc600e5}},	//   _ente_, _clou, rtoš, chog_,
   {{0xb5fb7af3,0xddc211c6,0x7bc201c0,0xee840733}},	//   ntás, stoš, _dlou, _выхо,
   {{0xdcbb0021,0x2d8c0c1f,0x8d7413cf,0x6b8b0273}},	//   _още_, _gade_, _ناما, _wagg,
   {{0x6b8b7af4,0x2dd8004f,0xf7462626,0x2a6d01e8}},	//   _tagg, _شبكة_, лено, steb_,
   {{0xf7720642,0x7ae40bec,0x628400e9,0xa6ca02c4}},	//   حاد_, _žite, ywio, елма_,
   {{0xb5fb00b5,0xa6db008d,0x2d8c7af5,0x63a00310}},	//   jtás, naðh, _yade_, _òmni,
   {{0x88c500d2,0x7bc20254,0xd9452d7a,0x2bcf2874}},	//   _متعل, _zlou, _секи, तोरा,
   {{0x79810afc,0x987902b5,0x43761018,0xa3ea02fb}},	//   melw, _טאַט, луат, едва_,
   {{0xb5fb01ba,0x78fa0070,0xa7661ab4,0x7c2e00fd}},	//   tuác, _אפצו, _скид, _ébre,
   {{0x4ebe0033,0x00000000,0x00000000,0x00000000}},	// [81e0] _অশ্ল, --, --, --,
   {{0x81460bf5,0xb1430210,0x6d450093,0x7981016e}},	//   انان, йнул, ðhal, nelw,
   {{0xb5fb7af6,0x2d8c7af7,0xdce300d8,0x98be00af}},	//   rtát, _rade_, menė, mată_,
   {{0xb5fb7af8,0x2d8c7af9,0xf1bf7afa,0x3f8d01dd}},	//   gráf, _sade_, _stát_, _caeu_,
   {{0x79810051,0xdef72ad9,0x2d8c04c3,0xdcf800ea}},	//   kelw, лыш_, _pade_, devā,
   {{0x7bc201c0,0x98be002d,0xb5fb00b5,0x00000000}},	//   _slou, nată_, ltár, --,
   {{0x6adc0edf,0x644e45cd,0x6da33ab9,0x2d8c0ad0}},	//   मप्र, nsbi, сија, _vade_,
   {{0xb5fb7afb,0xba54192f,0xaa545544,0x80ad0033}},	//   ntár, авиј, авиш, _টেক্,
   {{0x2d8c7afc,0x79812596,0x7dc6008d,0x6b8000b9}},	//   _tade_, felw, _aðse, remg,
   {{0x79814224,0x753c7afd,0x00000000,0x00000000}},	//   gelw, jbrz, --, --,
   {{0x6d4a7afe,0x98be002d,0x29187aff,0xd91700c3}},	//   mafa, dată_, ära_, лью_,
   {{0x6d4a7b00,0xa6db008a,0x81ea0033,0x644e0542}},	//   lafa, laði, মতি_, dsbi,
   {{0x44330a8a,0x645c01d7,0x644e0176,0x7bdb016b}},	//   _stx_, erri, esbi, _אקאו,
   {{0xa6db0093,0x6d4a7b01,0xb5fb03e6,0xf98a01cb}},	//   naði, nafa, etár, _سخته_,
   {{0xb4c10035,0x69c804e6,0x644e7b02,0x998e0260}},	//   ्छे_, mhde, gsbi, _pifņ_,
   {{0xa3cf07ba,0x3cfe00e2,0x00000000,0x00000000}},	//   वों_, _mytv_, --, --,
   {{0xf77000bc,0x6d4a7b03,0x645c0065,0x5b7b02b5}},	// [81f0] _راي_, kafa, arri, ערמא,
   {{0x645a0aca,0xb5fb006c,0x6d4a7b04,0x98be0043}},	//   átic, rtás, jafa, cată_,
   {{0x4438021d,0xb5fb4469,0x6d4a7b05,0x00000000}},	//   cpr_, tráf, dafa, --,
   {{0xb5fb7b06,0x83ab00c3,0x09e10b35,0x00000000}},	//   ctár, _чтоб_, _पद्य, --,
   {{0x6d4a0054,0x236b0160,0x926b002d,0x00000000}},	//   fafa, _iccj_, _ярна_, --,
   {{0x6d4a01d5,0x2b490207,0xa6db008d,0x98a7005f}},	//   gafa, _žac_, gaði, _genė_,
   {{0xa2d91bb5,0xa7fd037a,0x63ad00d8,0x9f4f02d7}},	//   _नेत्, ntıs, ojan, logí_,
   {{0x63ad0ce8,0xeb991eea,0x98be002d,0x7981001e}},	//   njan, тии_, zată_, welw,
   {{0x69da7b07,0x2b460107,0x79817b08,0x6d4a041b}},	//   fite, _deoc_, telw, bafa,
   {{0x69c8009c,0x2b460359,0x27e97b09,0x63ad0196}},	//   ghde, _eeoc_, _ajan_, hjan,
   {{0xe73a034b,0x63ad7b0a,0x98be00af,0x29c000e2}},	//   кен_, kjan, vată_, _tòan_,
   {{0xc6000f9f,0x661e00ee,0x63ad018e,0x798102b1}},	//   ोग्य_, _sipk, jjan, selw,
   {{0x63ad7b0b,0x98be002d,0xaa452f44,0x27e90088}},	//   djan, tată_, _телл, _djan_,
   {{0x69c801ae,0x7bc90248,0x644e711e,0x69da7b0c}},	//   chde, lheu, tsbi, cite,
   {{0x39470051,0x98be0043,0x645c7b0d,0x644e02b1}},	//   _iens_, rată_, urri, usbi,
   {{0xdb0b7b0e,0x394731dc,0x7bc90248,0x63ad7b0f}},	//   _logí, _hens_, nheu, gjan,
   {{0x6d4a4d6a,0x661e40b3,0x644e038e,0xe1fa1614}},	// [8200] yafa, _tipk, ssbi, вга_,
   {{0x394728a9,0x6d4a01f7,0xb5fb7b10,0x443803d0}},	//   _jens_, xafa, stár, ppr_,
   {{0x64a60b5e,0x200d009e,0x6f097b11,0x057700a5}},	//   _тана, _bhei_, _azec, _דגים_,
   {{0x69da7b12,0x6d4a7b13,0x76440010,0x63ad7b14}},	//   zite, wafa, _kwiy, cjan,
   {{0xe8e20567,0x6d4a7b15,0x69da035a,0x2ba929ce}},	//   _पश्च, tafa, yite, काना,
   {{0x44441642,0x394712c3,0x69da0510,0xdb0b02d7}},	//   _kw_, _nens_, xite, _cogí,
   {{0x6d4a7b16,0x67240c99,0xa6db0093,0x7e9600b5}},	//   rafa, _ogij, raði, انڈر_,
   {{0x69da7b17,0x44440428,0x6d4a7b18,0xa0370122}},	//   wite, _mw_, safa, _כאלה_,
   {{0x44440273,0xada600c7,0x39470bc8,0x79a64025}},	//   _lw_, _каал, _bens_, арне,
   {{0x44440273,0x63ad003c,0x39470310,0x49730f92}},	//   _ow_, zjan, _cens_, ольс,
   {{0x44442cfc,0x39471217,0x3b860370,0x6d4800ea}},	//   _nw_, _dens_, _влег, _ieda,
   {{0x69da7b19,0x39470261,0x6d4806a2,0x7bc97b1a}},	//   site, _eens_, _heda, cheu,
   {{0x44447b1b,0x6d480ad6,0xd6d80fa4,0xaa582365}},	//   _aw_, _keda, атр_, _силу_,
   {{0x6d480537,0x44442f38,0x39470495,0x69da01f4}},	//   _jeda, _bw_, _gens_, qite,
   {{0x6d4803d0,0xf77f6489,0x63ad5f49,0x58d31847}},	//   _meda, ança_, tjan, _мошт,
   {{0x44447b1c,0x6d487b1d,0x394c7b1e,0x7c280af1}},	//   _dw_, _leda, lads_, _mudr,
   {{0x7c281872,0x71790714,0xcb130070,0xadf6017f}},	// [8210] _ludr, лбар_, ַלע_, इवान_,
   {{0x6f09006a,0x394c5280,0xddc200ea,0x7c280345}},	//   _rzec, nads_, lsoņ, _oudr,
   {{0x444409d6,0x63ad7b1f,0x2ba90099,0x26f80647}},	//   _gw_, pjan, कामा, _مریخ_,
   {{0xf1bf00ee,0xdb0b021d,0x749a016b,0x22be013a}},	//   _etáp_, _jogã, _עירפ, _bākā_,
   {{0x6d487b20,0x7c287b21,0x8db500d8,0x69d87b22}},	//   _beda, _audr, йскі, _omve,
   {{0x444402c7,0xdef801c8,0x7c280081,0x62830035}},	//   _yw_, шых_, _budr, łnos,
   {{0x444430bc,0x6d487b23,0xa6db008a,0x7c2801a6}},	//   _xw_, _deda, maðu, _cudr,
   {{0x1dd900db,0x39477b24,0x236902d0,0x7ae401a0}},	//   _भगवत, _sens_, ngaj_, _žita,
   {{0x67240009,0x6d487b25,0x7bc91472,0x7bdb145d}},	//   _rgij, _feda, rheu, riuu,
   {{0x6d487b26,0xa6db008a,0x764404fb,0x9f4f021d}},	//   _geda, naðu, _rwiy, bogã_,
   {{0xa3e80ca1,0x7c287b27,0x5dfa02b5,0x6e297b28}},	//   _बदल_, _gudr, _עפענ, _hueb,
   {{0x4444070b,0x39470136,0x6fc70026,0x5fc700b1}},	//   _rw_, _wens_, लसिं, लसिल,
   {{0xa7fd027d,0x34b24eee,0xa6db008d,0x7bd90027}},	//   ttır, ीन्द, kaðu, _imwu,
   {{0x44447b29,0x6e290033,0x6e214225,0x6d4806a2}},	//   _pw_, _mueb, _jilb, _xeda,
   {{0x44440221,0x6e217b2a,0xdb0b0132,0x00000000}},	//   _qw_, _milb, _fogã, --,
   {{0xf1bf01a5,0x44447b2b,0x69c101bf,0xa7fd0225}},	//   _quán_, _vw_, lkle, stır,
   {{0xa7fd027d,0x6e297b2c,0x98be1640,0x6e210211}},	// [8220] ptır, _nueb, ratą_, _oilb,
   {{0x44447b2d,0x69c17b2e,0x01d70082,0xb5fb7b2f}},	//   _tw_, nkle, موقع_, nuál,
   {{0x444425cb,0x7d010b88,0x459b016b,0xb5fb7b30}},	//   _uw_, _nyls, _עסטע, bráb,
   {{0x68fc3a5b,0x38970139,0x6e217b31,0x69c100be}},	//   ürdi, _măr_, _ailb, hkle,
   {{0x6e210291,0x7f49410f,0x7c287b32,0x09b90099}},	//   _bilb, _deeq, _sudr, ेसाठ,
   {{0x44227b33,0x226500b8,0x6e21009e,0x171b0070}},	//   _hik_, ňský_, _cilb, אונע,
   {{0x7c284530,0x6d487b34,0xb5fb024e,0x44227b35}},	//   _qudr, _veda, duál, _kik_,
   {{0x5a340e0a,0x44223850,0x6d4840f4,0x6f000035}},	//   онит, _jik_, _weda, _tymc,
   {{0x394c7b36,0x44227b37,0x6d487b38,0x15f80907}},	//   tads_, _mik_, _teda, ंकार_,
   {{0x6d4800e0,0x2a640395,0xd83a002d,0x6e217b39}},	//   _ueda, rumb_, лэм_, _gilb,
   {{0xf4c30033,0x7c280176,0xb21b008c,0xe8050067}},	//   _ঈশ্ব, _uudr, _isæt, रतला_,
   {{0x44227b3a,0xaad90299,0x69dd00f7,0x6e211297}},	//   _nik_, _बेवक, éser, _zilb,
   {{0x66c81c1b,0x645a05ee,0x95cb03e6,0x69c10345}},	//   бург_, átin, гува_, bkle,
   {{0xf1bf0033,0x4422013c,0x7c2201a6,0x69c17b3b}},	//   _cuál_, _aik_, _hior, ckle,
   {{0x645a7b3c,0x44227b3d,0x7c221b7b,0xb9db00a5}},	//   štin, _bik_, _kior, _תחוש,
   {{0xeda500a9,0x44220080,0xdc370070,0x00000000}},	//   _गच्छ, _cik_, מאלט_, --,
   {{0x44227b3e,0x7c227b3f,0xa6db0093,0xf8b0006c}},	// [8230] _dik_, _mior, taðu, _رکھ_,
   {{0x44227b40,0x7c223b7c,0x6e297b41,0xe4e712ea}},	//   _eik_, _lior, _rueb, _гімн,
   {{0x44220022,0x6e29009e,0xa6db003e,0x28de00b4}},	//   _fik_, _sueb, raðu, _फेमि,
   {{0xdb0b0082,0x6e290083,0x6e9912da,0x4422054e}},	//   _logá, _pueb, ивер_, _gik_,
   {{0x80da0083,0x6e21251a,0x69c17b42,0x6e291c1d}},	//   _বুদ্, _pilb, ykle, _queb,
   {{0x628f0024,0xb5fb053d,0x7c227b43,0x44227b44}},	//   _isco, xuál, _aior, _zik_,
   {{0x7c227b45,0x4422028b,0x6e217b46,0xb21b008c}},	//   _bior, _yik_, _vilb, _dsæt,
   {{0x23c90325,0xa91c0038,0x7c223593,0xdb0b0312}},	//   रसिद, teľn, _cior, _aogá,
   {{0xb5fb7b47,0x6e217b48,0x3e720043,0x69c1089c}},	//   tuál, _tilb, cât_, tkle,
   {{0x80be00c8,0x8d770357,0xe9d905c2,0x38970395}},	//   ্পর্, _دارا, рко_, _păr_,
   {{0x2d877b49,0x69c17b4a,0x7c227b4b,0x23c90e61}},	//   mene_, rkle, _fior, रसाद,
   {{0x7c220021,0x2d8702ce,0xdd0e1a68,0x7bd90010}},	//   _gior, lene_, lışm, _umwu,
   {{0x4422711e,0x2d8703bc,0x26c47b4c,0xdb0b00b5}},	//   _rik_, oene_, ámo_, _fogá,
   {{0x44227b4d,0x2d877b4e,0xdd0e06d3,0x992b00c3}},	//   _sik_, nene_, nışm, _сюда_,
   {{0x628f01d3,0x629d0211,0x26c46633,0x00000000}},	//   _asco, _arso, šmo_, --,
   {{0xb5fb0332,0x2d877b4f,0x44220031,0x628f00fe}},	//   trác, hene_, _qik_, _bsco,
   {{0x2d877b50,0xb5fb016f,0x4ac9012f,0x442247a5}},	// [8240] kene_, urác, िनिव, _vik_,
   {{0x2d871851,0x2252005f,0xe1660037,0xdb0b002a}},	//   jene_, rsyk_, تدري, _xogá,
   {{0x44227b51,0x2d8702ce,0x308603c7,0x628f409c}},	//   _tik_, dene_, تلاف, _esco,
   {{0xb5fb0076,0x443a004e,0x4ac9060a,0x987a0070}},	//   prác, _itp_, िनाव, ירעק,
   {{0xfe6f0372,0x7c227b52,0x2d877b53,0xe4d701cb}},	//   ندو_, _rior, fene_, _هویت_,
   {{0x2d877b54,0x7c220014,0x7ae40c99,0x443a01cb}},	//   gene_, _sior, _žito, _ktp_,
   {{0x7c227b55,0x50b5002d,0xa3c3021a,0x00000000}},	//   _pior, _есту, _्तम_, --,
   {{0xe3bf02d7,0x00000000,0x00000000,0x00000000}},	//   _tiñe_, --, --, --,
   {{0xf41302da,0xa91c0038,0x7c2200af,0x7f4201ef}},	//   ופה_, teľo, _vior, mboq,
   {{0x200600da,0x443a7b56,0x00000000,0x00000000}},	//   lloi_, _otp_, --, --,
   {{0x09b70514,0x645a2736,0x7c227b57,0x443a0185}},	//   تطيع_, átil, _tior, _ntp_,
   {{0xc6a73d58,0x7c3a003c,0x61b77b58,0xfbc364cc}},	//   орги, _ittr, _आक्ष, _обхо,
   {{0x645a0254,0xf98f0a86,0x00000000,0x00000000}},	//   štil, ربی_, --, --,
   {{0x443a7452,0x63a60301,0x00000000,0x00000000}},	//   _btp_, _ankn, --, --,
   {{0xd4986871,0x79880103,0x69ca0210,0x667200f8}},	//   орт_, medw, _ilfe, وگیر,
   {{0x79887b59,0xd6db257b,0x443a7b5a,0xe2350200}},	//   ledw, _вто_, _dtp_, знањ,
   {{0x2d877b5b,0xa6db0093,0x6d5a0a8e,0x249700c7}},	// [8250] yene_, raðs, _odta, _žemė_,
   {{0x2d871d35,0x79887728,0xd13b38ab,0xed8800c7}},	//   xene_, nedw, рха_, šųjų_,
   {{0x2d877b5c,0xf8ca2b6d,0x443a7b5d,0x9618063d}},	//   vene_, ानिय, _gtp_, _بغير_,
   {{0x6d5a7b5e,0x2d8700f8,0x7e6201a2,0x628f0051}},	//   _adta, wene_, frop, _tsco,
   {{0x2d8702ce,0x7c3a3699,0x6da52e50,0x7e627b5f}},	//   tene_, _attr, зила, grop,
   {{0xb2ba00a5,0xa2ba00a5,0xf8ca0cea,0x00000000}},	//   _המשר, _המשט, ानाय, --,
   {{0x2d877b60,0x7d1c0093,0x23bf074f,0xdd0e06d3}},	//   rene_, _úrsl, _एकाद, rışm,
   {{0x5ba935ea,0x2d877b61,0x69ca7b62,0x628d023c}},	//   ским_, sene_, _alfe, owao,
   {{0xe9d970e1,0x2d877b63,0x7e627b64,0x7f5b01ed}},	//   йки_, pene_, crop, _iduq,
   {{0x6ca716c0,0x79887b65,0x2ba90d91,0x6e3b04fb}},	//   _мреж, gedw, काहा, _itub,
   {{0x6d437b66,0x98a5516d,0xdcfa00ec,0x2903008d}},	//   mbna, чине, _datē, æja_,
   {{0x69ca7b67,0xe29f008a,0x443a7b68,0x00000000}},	//   _elfe, _orð_, _rtp_, --,
   {{0xb9021ea2,0x62980029,0x443a7b69,0xfaa564a1}},	//   _ने_, āvok, _stp_, _хало,
   {{0xceb27b6a,0x6b897b6b,0x645a0ce9,0x7c3a013c}},	//   עים_, leeg, štim, _yttr,
   {{0x64557b6c,0x64a31ce4,0x443a0069,0xa50a1566}},	//   gszi, нара, _qtp_, сева_,
   {{0x3cde0006,0x443a063c,0xe8d600a5,0x78bc7b6d}},	//   _कइसे_, _vtp_, _מוצר_, ärve,
   {{0x273701a5,0xa3bd00b4,0x6e3b04fb,0x00000000}},	// [8260] _ủng_, _अवर_, _ntub, --,
   {{0x7e6271c6,0x64555549,0x00000000,0x00000000}},	//   vrop, bszi, --, --,
   {{0x2ec407df,0x6e3b7b6e,0x55bb0122,0x7bcb7b6f}},	//   वन्त, _atub, _המיו, _olgu,
   {{0x63a600a5,0x79887b70,0x2ca200d5,0x7dcf0a8a}},	//   _unkn, zedw, _čkd_, _løsd,
   {{0xdfcf38b7,0x7e627b71,0x539b00a5,0x25ba00fe}},	//   دين_, urop, _היכו, _kopl_,
   {{0xb5fb7b72,0xf2d302b5,0x7f5b0176,0x2b980019}},	//   hrán, _טער_, _eduq, _ức_,
   {{0x20061010,0xb5fb008a,0xa02401ae,0xa91c01ba}},	//   ploi_, krán, größ, teľm,
   {{0x7e627b73,0x7988016e,0x6b892542,0x00000000}},	//   prop, wedw, geeg, --,
   {{0x6e460d47,0xdcfa00ea,0xb5fb7b74,0x00000000}},	//   _رنام, _patē, drán, --,
   {{0xe3bf0391,0xed577b75,0x6d5a01b4,0x1805021a}},	//   _miña_, _ноу_, _udta, रत्व_,
   {{0xe3bf043f,0x798800e9,0x7c3a053c,0x645a7b76}},	//   _liña_, redw, _uttr, štij,
   {{0x61fe0274,0x79887b77,0x22400430,0x2fc600cd}},	//   hopl, sedw, kpik_, nkog_,
   {{0x2ba904eb,0x61fe7b78,0xe3bf0033,0xfba9052b}},	//   कारा, kopl, _niña_, कारम,
   {{0x6455006c,0xb5fb0098,0x61fe0051,0x2fc60207}},	//   tszi, arán, jopl, hkog_,
   {{0x61fe0736,0xe97b0122,0xb5fb0314,0xa97b00a5}},	//   dopl, _הנוש, brán, _האוכ,
   {{0xd6d128c0,0xb5fb7b79,0x64557b7a,0x00000000}},	//   _لقب_, ntáz, rszi, --,
   {{0x69a10302,0x0edb04bc,0x6455006c,0x61fe09d8}},	// [8270] _कोडी, _मेंड, sszi, fopl,
   {{0x61fe00cd,0x2902013b,0x00000000,0x00000000}},	//   gopl, əkar_, --, --,
   {{0x25d802b5,0x06380416,0x25fc046c,0x00000000}},	//   _מוזן_, _وسیع_, ोतरी_, --,
   {{0xe29f0093,0x00000000,0x00000000,0x00000000}},	//   _eyða_, --, --, --,
   {{0x6ff5004e,0xf8a90e04,0x98be0355,0x7dcf082b}},	//   jące, _छप्प, tatě_, _løse,
   {{0x61fe002a,0x6b894c71,0xbea27b7b,0xdb07000d}},	//   copl, weeg, ташк, _éléc,
   {{0x2ba90aad,0x6b897b7c,0xa3c300b4,0xfba90355}},	//   काला, teeg, _्ता_, कालम,
   {{0x2fc6011c,0x5f942dbb,0x6aa40009,0x7f941c4d}},	//   ckog_, _пист, _šifa, _пасх,
   {{0x6b897b7d,0x60180086,0xc3340122,0x8d8707b4}},	//   reeg, _хотя_, עוץ_, _нужд,
   {{0x26c2010b,0x08c50374,0x00000000,0x00000000}},	//   vyko_, дбон, --, --,
   {{0x8d740df3,0xb5fb05fa,0x378a1583,0x69a10099}},	//   _سالا, trán, обно_, _कोणी,
   {{0x66e6010b,0x645a7b7e,0x61fe5315,0x7bcb0553}},	//   дома, štik, zopl, _ulgu,
   {{0xb5fb0b4c,0x25ba00ac,0xab0b00d1,0xa3c309b4}},	//   rrán, _popl_, _اتاق_, ्सन_,
   {{0x26110084,0xb21b0ffb,0xe3bf02d7,0x26c27b7f}},	//   _दीदी_, _spæn, _riña_, ryko_,
   {{0x61fe0c99,0x2fcd7b80,0x00000000,0x00000000}},	//   vopl, _oleg_, --, --,
   {{0xe3bf1725,0xf7720037,0x00000000,0x00000000}},	//   _piña_, _شاب_, --, --,
   {{0x42260eb4,0x13a800fd,0x00000000,0x00000000}},	// [8280] ддав, _ہندی_, --, --,
   {{0x3cde0006,0xe3bf0b4c,0x2fcd00af,0x7ae40bc5}},	//   _कइले_, _viña_, _aleg_, _žitk,
   {{0x61fe7b81,0x2fc60254,0x2fcd7b82,0x00000000}},	//   ropl, tkog_, _bleg_, --,
   {{0xe3bf1a71,0x61fe7b83,0x4f0a4de5,0xb5fb00b8}},	//   _tiña_, sopl, онен_, hrál,
   {{0xa91c01ba,0xddc202c4,0xa24800f8,0x2fc600cd}},	//   teľk, rtož, _ریال_, rkog_,
   {{0x2fc67b84,0x7d1c0093,0xddc20355,0xb5fb0079}},	//   skog_, _úrsk, stož, tuái,
   {{0x6da3015a,0x290700ee,0x27e00328,0xfba90099}},	//   тија, _nyna_, _omin_, कांम,
   {{0xcfaa02e7,0x27e008dd,0xeb970274,0xdbf2013b}},	//   _باسم_, _nmin_, дић_, qşün,
   {{0x29077b85,0xb5fb0138,0xdb190260,0x298a7b86}},	//   _ayna_, rtáz, _jowè, осно_,
   {{0x27e00269,0x2907053e,0x0e630009,0xb5fb7b87}},	//   _amin_, _byna_, _шкун, stáz,
   {{0xf1bf0019,0x00000000,0x00000000,0x00000000}},	//   _quái_, --, --, --,
   {{0x62867b88,0x2907001e,0x5ba501e0,0x6e28005f}},	//   _opko, _dyna_, _пріз, _hidb,
   {{0xbc1b0070,0x6b827b89,0xb5fb7b8a,0x27e01202}},	//   _וואש, _ibog, brál, _dmin_,
   {{0x6e280069,0x27e000d0,0x34953242,0x394e0183}},	//   _jidb, _emin_, нагр, _uefs_,
   {{0x6e2809b3,0xe4e400d4,0x628600ea,0x41fa06fe}},	//   _midb, вітн, _apko, ्तैः_,
   {{0xddc900b8,0x6aa202a7,0x7d0803d0,0x6e280523}},	//   _dveř, _krof, _myds, _lidb,
   {{0x52154ae8,0xe0d000f8,0x6b8240e9,0x7d080687}},	// [8290] едат, یزم_, _mbog, _lyds,
   {{0xdddb13a9,0x2fcd053e,0x91e40274,0x69c81789}},	//   _opuš, _sleg_, вође, nkde,
   {{0x3cde0429,0x6b8215d7,0x35f80037,0x2b0501c0}},	//   _केले_, _obog, _تريد_, _हुनु_,
   {{0x764d7b8b,0x799802d0,0x2ef50fb4,0x6e28026e}},	//   _kway, _lavw, нзер, _aidb,
   {{0xf8ca045c,0x733a02b5,0xddc900b8,0xde5800d4}},	//   ानुप, _מערס, _zveř, дачі_,
   {{0x6b827b8c,0x764d53a9,0x72050037,0x29c902d7}},	//   _abog, _mway, _أوسم, _cúal_,
   {{0x6aa27b8d,0x63bd008a,0x764d7b8e,0x7e6b0159}},	//   _arof, _kosn, _lway, sugp,
   {{0x672d00d1,0x6aa2001e,0xe3bf4193,0x32010187}},	//   _ngaj, _brof, _miño_, lohy_,
   {{0xba250ecb,0xb5fb0332,0xe3bf0042,0xa7fd00a8}},	//   ндик, trál, _liño_, trın,
   {{0x672d030d,0x320100fe,0x6e28009f,0x63bd7b8f}},	//   _agaj, nohy_, _gidb, _losn,
   {{0xe3bf2e7d,0x764d7b90,0x5eb70033,0x1dac0099}},	//   _niño_, _away, _আইটে, चारत,
   {{0xb21b05ee,0x63bd00ac,0xc5fa0b35,0x69c8011e}},	//   _spæl, _nosn, ृत्य_, akde,
   {{0x6aa27b91,0x34c80387,0x0aeb00bf,0xd90f006c}},	//   _grof, रन्द, _براي_, دیں_,
   {{0x69c80ef0,0x764d0260,0x6b8228c2,0x7bc97b92}},	//   ckde, _dway, _zbog, lkeu,
   {{0x63bd10d3,0x00000000,0x00000000,0x00000000}},	//   _bosn, --, --, --,
   {{0x6b9b325a,0x7bc97b93,0x63bd009d,0xdb1902d0}},	//   ndug, nkeu, _cosn, _powè,
   {{0x7bc900c3,0x63bd7b94,0x6f1d00ac,0x6f090118}},	// [82a0] ikeu, _dosn, _úsch, _nyec,
   {{0x7bc90328,0x42070274,0x00000000,0x00000000}},	//   hkeu, енуо_, --, --,
   {{0x7bc97b95,0xb5fb0187,0x71730037,0xddc90355}},	//   kkeu, kráj, اهما, _uveř,
   {{0x78bc0044,0x543b0070,0x9f5f0023,0x6b99009f}},	//   ørvi, _מעטא, _thuý_, _nawg,
   {{0xdddb15b5,0x49060084,0x7bc909a6,0x7d0822ac}},	//   _spuš, _सुनो_, dkeu, _syds,
   {{0x2fda04a3,0x6aa20031,0x7bc90051,0x00000000}},	//   _کورد_, _rrof, ekeu, --,
   {{0x6e280282,0x00000000,0x00000000,0x00000000}},	//   _vidb, --, --, --,
   {{0x6b9b03be,0xe8df0023,0xdb0b0183,0xb5fb002a}},	//   gdug, _chửi_, _ingê, stáx,
   {{0x0d867b96,0x6e287b97,0x60e000d8,0x6b994e8b}},	//   _план, _tidb, žymė, _dawg,
   {{0x7d08053e,0xb5fb01ef,0x764d7b98,0xf77f0183}},	//   _tyds, trám, _rway, diça_,
   {{0x69c80051,0xe0be0033,0xdddb6192,0x5fc4017f}},	//   rkde, _আধুন, _upuš, _वकाल,
   {{0x6b82085e,0x2d9c006c,0x2d8e0453,0xb5fb01ef}},	//   _ubog, ldve_, lefe_, rrám,
   {{0xcf9300c2,0x63bd7b99,0xdb090031,0x00000000}},	//   נטש_, _rosn, vjeç, --,
   {{0x764d02e9,0x63bd1140,0x00000000,0x00000000}},	//   _vway, _sosn, --, --,
   {{0x63bd02c6,0x6b9901e8,0xc95300a5,0x5886005f}},	//   _posn, _yawg, _עמק_, _чыла,
   {{0xe3bf01dd,0x764d1815,0x7dd4009e,0xdd10005f}},	//   _viño_, _tway, _fàsg, _ažūr,
   {{0x3201031d,0xe1670274,0x8c1b00a5,0x764d04fb}},	// [82b0] tohy_, еђен, לולי, _uway,
   {{0x8cb10035,0x63bd03d0,0x00000000,0x00000000}},	//   _अपलो, _wosn, --, --,
   {{0x320100ac,0xc95302b5,0x61e53009,0x7bc90051}},	//   rohy_, רמע_, rihl, ykeu,
   {{0x60c50086,0x00000000,0x00000000,0x00000000}},	//   ryhm, --, --, --,
   {{0xee3876f4,0xa3e60907,0x442b00d7,0xd3560d85}},	//   ені_, _भगत_, _iic_, _שישי_,
   {{0x442b7b9a,0xfce52ab4,0x7bc901e4,0x31350274}},	//   _hic_, коло, wkeu, _јевр,
   {{0x7bc92931,0x645a0f3e,0xace8006c,0x6b9b7b9b}},	//   tkeu, štiv, ٹرول_, tdug,
   {{0x44337b9c,0xddc200d8,0x7bc90051,0xa3c306fe}},	//   _mux_, ruoš, ukeu, ्सि_,
   {{0x44336699,0x7bc94e92,0x6b9b7b9d,0xdfd402ee}},	//   _lux_, rkeu, rdug, _соты,
   {{0x3f8f008a,0x7bc97b9e,0x442b1f83,0xddc2010b}},	//   legu_, skeu, _lic_, puoš,
   {{0x442b2edd,0x443339c5,0x9991006c,0x6b997b9f}},	//   _oic_, _nux_, öző_, _tawg,
   {{0x442b75bc,0xf7720c36,0x3f8f0297,0x290b02d4}},	//   _nic_, جاد_, negu_, āca_,
   {{0x4433105d,0xed580168,0x2f5a00a5,0x00000000}},	//   _aux_, _hoľa_, ודרנ, --,
   {{0x442b7ba0,0x7d0401d6,0xdce10644,0xf77f021d}},	//   _aic_, şise, _halı, riça_,
   {{0xdce101d6,0x60181bea,0x3f8f01d7,0x02bc0266}},	//   _kalı, líme, kegu_, ोन्न,
   {{0x4433002a,0x442b7ba1,0x3f8f7ba2,0x7c2b007a}},	//   _dux_, _cic_, jegu_, _jigr,
   {{0x2ebd0026,0x442b7ba3,0x443302e1,0xa2060340}},	// [82c0] ्नोत, _dic_, _eux_, впад,
   {{0x7c2b1d75,0xb1437ba4,0x442b005f,0x44330282}},	//   _ligr, инул, _eic_, _fux_,
   {{0xe0d2004f,0x27f70df3,0xd12f0037,0xd6a90609}},	//   جزء_, _سفید_, زمن_, _قدیم_,
   {{0x2d850122,0x442b7ba5,0xddce0035,0xbe8a0274}},	//   _able_, _gic_, żdża, дске_,
   {{0xc3200033,0x645c095a,0x7dd40392,0x6ff300ab}},	//   _ফ্রি_, lsri, _làse, _अदरख_,
   {{0x614300d8,0x442b002d,0x3f8f00ab,0xf1bf0023}},	//   _вера, _zic_, aegu_, _quát_,
   {{0xdce106d3,0x44200be3,0x645c00d4,0x91e31e38}},	//   _balı, omi_, nsri, _торе,
   {{0x4420142f,0xd9ca04cc,0xb5fb2c0e,0x7c2b7ba6}},	//   nmi_, िस्ट, nuár, _cigr,
   {{0xde77006c,0x60180453,0x44207ba7,0xdce10448}},	//   _لینڈ_, gíme, imi_, _dalı,
   {{0x44207ba8,0x79a60ec9,0x98b803e6,0x683e00ea}},	//   hmi_, трие, елот_, _līde,
   {{0x6d587ba9,0x44207baa,0x4ce00083,0xc15700a5}},	//   mava, kmi_, _পুরু, כשיו_,
   {{0x6d587bab,0x44207bac,0x7c2b7bad,0xbb460eb5}},	//   lava, jmi_, _gigr, _редк,
   {{0xb5fb006c,0x2902004e,0xf4080083,0x442046e8}},	//   nság, łka_, লগার_, dmi_,
   {{0x442b7bae,0x6d587baf,0x44203115,0x7dcf0909}},	//   _sic_, nava, emi_, _løsn,
   {{0x645c7bb0,0xdb0b00f8,0xdce1027d,0x44330118}},	//   gsri, _angè, _yalı, _qux_,
   {{0x6d583a2e,0xdce10510,0xa3dd004e,0xa7750798}},	//   hava, _xalı, थों_, _слич,
   {{0x6d582119,0xb5fb0037,0xf1ae0099,0x442b5e62}},	// [82d0] kava, hrái, घांन, _vic_,
   {{0x6d581c08,0x44207bb1,0x6155042c,0x645c0d92}},	//   java, ami_, انائ, bsri,
   {{0x442b7bb2,0x3c38006c,0x44207bb3,0x7dcf008c}},	//   _tic_, _név_, bmi_, _bøsn,
   {{0x926b10d4,0x442b01f7,0xb5fb03e6,0x44207bb4}},	//   _орга_, _uic_, cuár, cmi_,
   {{0x35a84909,0x645a287d,0x765d6037,0x798100e9}},	//   _छोड़, štit, nssy, yflw,
   {{0x6d587bb5,0x65757bb6,0x3e7b02e1,0x7c2b7bb7}},	//   gava, ngzh, rêt_, _sigr,
   {{0xdb0b0248,0x7c2b7bb8,0xc172011d,0x3c38007e}},	//   _ingé, _pigr, _לחם_, _cév_,
   {{0x7c3e0076,0xdce10095,0x1fa47bb9,0xf77f021d}},	//   ípra, _qalı, _круг, diço_,
   {{0x6d58679b,0xce940036,0xb5fb0079,0x765d0223}},	//   bava, _катъ, arái, jssy,
   {{0x44207bba,0x3c380248,0x6018171c,0x3cde22a7}},	//   zmi_, _fév_, ríme, _केके_,
   {{0x44207bbb,0xd7ea5b1d,0xd7af0099,0x6018002a}},	//   ymi_, емне_, टांच, síme,
   {{0x366a260f,0x1b050033,0x7c2b0612,0x442001ed}},	//   намо_, শেষে_, _uigr, xmi_,
   {{0xff7a0070,0x44207bbc,0xaba80413,0x00000000}},	//   עטשמ, vmi_, _جهنم_, --,
   {{0x645c7bbd,0x00000000,0x00000000,0x00000000}},	//   tsri, --, --, --,
   {{0x07a61023,0x44207bbe,0x2a7f00ab,0xb5fb7bbf}},	//   _байн, tmi_, ltub_, tuár,
   {{0x6d587bc0,0x44207bc1,0xdb0b45d3,0x80a70099}},	//   zava, umi_, _angé, घटने,
   {{0x44207bc2,0x6d583a3c,0xdcfa0029,0x2e3902d0}},	// [82e0] rmi_, yava, _patī, _nèf_,
   {{0xd05a03d0,0x64410473,0xddd4016f,0x6d58021d}},	//   ерді_, ílic, _ťažk, xava,
   {{0x6d580d98,0x2a7f00ab,0x44207bc3,0x8fa66d5b}},	//   vava, htub_, pmi_, лаже,
   {{0x444435d9,0xb4c252cf,0x2a7f7bc4,0x2e3902e9}},	//   _it_, ्नी_, ktub_, _bèf_,
   {{0x6d581b43,0x44447bc5,0xa3c30b4a,0x2a7f01e8}},	//   tava, _ht_, ्सर_, jtub_,
   {{0x44447bc6,0x27030019,0xb5fb0079,0x00000000}},	//   _kt_, ổng_, trái, --,
   {{0x6d580d5c,0xb5fb006c,0x44447bc7,0x3f6a7bc8}},	//   rava, sság, _jt_, _пиво_,
   {{0x44447bc9,0x6d587bca,0x7dc6008a,0xb5fb0037}},	//   _mt_, sava, _aðst, rrái,
   {{0x44447bcb,0x6d5e043f,0x0aea004f,0x9fb8024e}},	//   _lt_, ópas, عربي_, nčí_,
   {{0x44447bcc,0xf27b0070,0x77640065,0xc27b0070}},	//   _ot_, עריש, _adix, עריי,
   {{0x26e20083,0x28f87bcd,0x249a0009,0x7d0501ae}},	//   _গুলো_, тень_, _nspm_, ühst,
   {{0x765d038d,0x2a7f011e,0x2006053e,0x2d9e024b}},	//   tssy, btub_, nooi_, _hate_,
   {{0x444401f3,0xa91c016f,0x2d9e024b,0x00000000}},	//   _at_, teľs, _kate_, --,
   {{0xb5fb0076,0x0cb60083,0x9fb80187,0x44443993}},	//   hráv, জনীত, dčí_, _bt_,
   {{0x44440dc5,0xa3c322c7,0x2d9e42dd,0x76447bce}},	//   _ct_, ्सल_, _mate_, _etiy,
   {{0x44447bcf,0x261a0084,0xd3780328,0x2d9e3adc}},	//   _dt_, _मीठी_, лчу_, _late_,
   {{0x44447bd0,0x56950409,0xfc3f024e,0xe5e503c5}},	// [82f0] _et_, _тапт, _čím_, _نزدی,
   {{0x2d9e7bd1,0x44447bd2,0x54552b32,0x00000000}},	//   _nate_, _ft_, _квот, --,
   {{0x92b50033,0xa0a70421,0x20060298,0x2e390107}},	//   জনে_, ышал, fooi_, _sèf_,
   {{0xb4d14f52,0x64457bd3,0x2006053e,0x2d9e02ea}},	//   वनी_, _ithi, gooi_, _aate_,
   {{0x2d9e7bd4,0xd244002d,0x290e008c,0xa3d208b0}},	//   _bate_, _гэси, _lyfa_, वसर_,
   {{0xd6580052,0x6da57bd5,0x22495112,0x2d9e0043}},	//   ניות_, рика, mpak_, _cate_,
   {{0x2d9e5062,0xeb993121,0xabd509ea,0x2249010d}},	//   _date_, вий_, ициј, lpak_,
   {{0x3ff902b5,0x9e9501cb,0xb5fb01dd,0x2d9e030d}},	//   _ספּע, _پارچ, nsáb, _eate_,
   {{0x59a60084,0x22492e72,0x7bc201ef,0x05c600b4}},	//   _कोहर, npak_, _doou, रॉडब,
   {{0x49c91126,0x180e00b4,0xe8857bd6,0x2d9e7bd7}},	//   тлон_, सत्व_, агоп, _gate_,
   {{0x7c9505bc,0x2902027d,0x2a7f00ab,0x6ce400d4}},	//   _خلاص, şkan_, stub_, _ліце,
   {{0x2249067f,0x2d2100a1,0x444476c2,0x2d9e08b7}},	//   kpak_, मधील_, _rt_, _zate_,
   {{0x2d9e7bd8,0xa3b907ba,0x64457bd9,0x63a00138}},	//   _yate_, चान_, _athi, _ómni,
   {{0x7bc2006d,0x98a50166,0x9fb80355,0xa9690036}},	//   _zoou, _вике, včí_, _рика_,
   {{0xb4c24f02,0x69c37bda,0x44447bdb,0xa50a2c4e}},	//   ्ने_, _ione, _qt_, тева_,
   {{0xa3a90084,0xb5fb21a4,0x69c33963,0x6441002a}},	//   _गोद_, dráu, _hone, ília,
   {{0x44440c1f,0x64457bdc,0x6018086d,0x66070528}},	// [8300] _wt_, _ethi, jíma, bojk,
   {{0xbbd209b1,0x44447bdd,0x69c3293c,0xe47600af}},	//   _तत्क, _tt_, _jone, _кумэ,
   {{0x44447bde,0x69c37bdf,0x673b2d5b,0x2d9e0122}},	//   _ut_, _mone, žuje, _rate_,
   {{0x6d417be0,0xddc20080,0x03a6204b,0x2d9e7be1}},	//   _afla, droš, _тимо, _sate_,
   {{0x2d9e7be2,0x6d410312,0x00000000,0x00000000}},	//   _pate_, _bfla, --, --,
   {{0x2b4d00f6,0x69c30232,0x8c6602c4,0x7dd40284}},	//   ebec_, _none, атид, _bàsa,
   {{0xb5fb024e,0x090b0033,0x00000000,0x00000000}},	//   práv, হেতু_, --, --,
   {{0x0b8a16c0,0xa3b92893,0x2d9e01a2,0xbae70033}},	//   тски_, चाय_, _wate_, _পড়ছ,
   {{0x2a6d7be3,0x6d4100e9,0x9e650286,0x69c34a48}},	//   greb_, _ffla, _هالن, _bone,
   {{0x69c33a89,0x4e7b0052,0x64437be4,0x7dd400f1}},	//   _cone, _באמצ, _énig, _fàsa,
   {{0x69c37be5,0x31371759,0x6607326f,0xb4c2000c}},	//   _done, ינים_, vojk, ्नो_,
   {{0x961f065f,0x0aea171d,0xe69500c3,0xb4c201c0}},	//   पष्ट_, _идей_, бимы, ्नै_,
   {{0xb5fb0097,0x867401e0,0x00000000,0x00000000}},	//   krát, оляє, --, --,
   {{0x69c36208,0x00000000,0x00000000,0x00000000}},	//   _gone, --, --, --,
   {{0xe4a40272,0xb4d10456,0xb5fb7be6,0xb8eb0083}},	//   орто, वने_, drát, _রে_,
   {{0x69c37be7,0x00000000,0x00000000,0x00000000}},	//   _zone, --, --, --,
   {{0x66070523,0x69c37be8,0x6018002a,0x00000000}},	// [8310] pojk, _yone, xíma, --,
   {{0x22497be9,0xf5950037,0x683e0228,0x3f8600a2}},	//   rpak_, _الدج, _zīda, efou_,
   {{0xd13801d3,0x27e97bea,0x439521f7,0x644504be}},	//   рху_, _kman_, _ланс, _uthi,
   {{0x60187beb,0x2fc40176,0x27e90069,0x7dd4009e}},	//   tíma, _comg_, _jman_, _ràsa,
   {{0x6d4101ae,0xb5fb05f6,0x7dd40211,0x98a7005f}},	//   _pfla, brát, _sàsa, _igną_,
   {{0xddc20888,0xb5fb1ec0,0x0cb60083,0x629d035f}},	//   troš, crát, জনৈত, _isso,
   {{0x27e97bec,0x69c303bc,0x3c930105,0x25a10a63}},	//   _oman_, _rone, تیاز, _mahl_,
   {{0x69c37bed,0x27e97bee,0x2a6d7bef,0x351c00a5}},	//   _sone, _nman_, treb_, כוונ,
   {{0x69c37bf0,0x2b4d7bf1,0x00000000,0x00000000}},	//   _pone, rbec_, --, --,
   {{0x27e909df,0xdef810b0,0x69da0122,0x8d773fec}},	//   _aman_, _тыс_, ghte, _خارا,
   {{0x69c37bf2,0x07a628fa,0x50da016b,0x7dcf008c}},	//   _vone, банн, ָקרא, _løsk,
   {{0x629d7bf3,0x69c30120,0xb5fb2e79,0xc3000033}},	//   _osso, _wone, krás, ্ধতি_,
   {{0x69c3245b,0x7bdb009e,0xf98900e0,0xeaae0c28}},	//   _tone, mhuu, _منشي_, _эй_,
   {{0x69da7bf4,0x27e90291,0x69c308c7,0x601a00fe}},	//   chte, _eman_, _uone, _důmy,
   {{0x629d6ee7,0x044611b9,0x25a10304,0xb5fb0187}},	//   _asso, себн, _dahl_, vrát,
   {{0xe29a06e4,0x083a0070,0xb5fb008e,0x3dc50103}},	//   лаб_, _געקל, frás, _lolw_,
   {{0x673b0009,0xb5fb2d95,0xaaa700ab,0xe1fa0009}},	// [8320] žujc, trát, कटिक, гга_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f1b2675,0x629d7bf5,0x7bdb0051,0x00000000}},	//   _azuc, _esso, khuu, --,
   {{0x25a101ae,0x201f7bf6,0xdb0b00ac,0x27e90355}},	//   _zahl_, _chui_, _angí, _xman_,
   {{0x443a7bf7,0x7bdb0118,0x63a47bf8,0x248c003c}},	//   _hup_, dhuu, mdin, ħdmu_,
   {{0x63a47bf9,0x443a5b4e,0x628401ff,0xa3e40a44}},	//   ldin, _kup_, mtio, भोर_,
   {{0x62840086,0x29c90042,0xf41f00c3,0xb33b0510}},	//   ltio, _lúas_, _yhä_, _haça,
   {{0xd00a7bfa,0x443a0254,0x5bd200a1,0xb33b7740}},	//   _себе_, _mup_, तसेव, _kaça,
   {{0x63a47bfb,0x62847bfc,0x69da7bfd,0x443a7bfe}},	//   idin, ntio, thte, _lup_,
   {{0x27e905ca,0xb33b7347,0x984a01d3,0x69da0453}},	//   _sman_, _maça, ляма_, uhte,
   {{0xdb4f7bff,0x443a5512,0xc1bb0070,0x8b6600f8}},	//   _ню_, _nup_, אמיש, _هاشم,
   {{0x62847c00,0x69da01d2,0x6d5a013c,0x63a47c01}},	//   ktio, shte, _heta, jdin,
   {{0x63a47c02,0x6d5a7c03,0x34d10387,0x689200b5}},	//   ddin, _keta, सन्द, _کیجئ,
   {{0x29c91a71,0x7c3a0024,0xd6d800d4,0x64410279}},	//   _dúas_, _kutr, стю_, ílio,
   {{0xdce80723,0x6d5a7c04,0x395e7c05,0x69d803a6}},	//   _kadı, _meta, mats_, _ilve,
   {{0x6d5a7c06,0x395e7c07,0x63a47c08,0x7c3a06a2}},	//   _leta, lats_, gdin, _mutr,
   {{0xb33b3203,0x82f80037,0x6d5a0118,0x7e620223}},	// [8330] _caça, مركز_, _oeta, jsop,
   {{0x7c3a130c,0x395e7c09,0xb5fb006c,0xa3a90722}},	//   _outr, nats_, rrás, _गोर_,
   {{0x62847c0a,0xceeb00bf,0xb5fb01dd,0x443a0207}},	//   atio, گران_, brár, _gup_,
   {{0xb33b7c0b,0x395e7c0c,0x6d5a00b9,0xdea100d1}},	//   _faça, hats_, _aeta, ویزی,
   {{0x62847c0d,0x7c3a105d,0x6d5a7c0e,0x69d80138}},	//   ctio, _autr, _beta, _olve,
   {{0x313563f5,0x6d5a7c0f,0xdcf800d8,0x1c110035}},	//   _февр, _ceta, nevė, _डीजल_,
   {{0x395e7c10,0x7c3a5e88,0x201f0019,0x59a601c0}},	//   dats_, _cutr, _thui_, _कोइर,
   {{0x69d87c11,0x7c3a1214,0x00000000,0x00000000}},	//   _alve, _dutr, --, --,
   {{0xe9d97c12,0x6d5a00da,0x7c3a01da,0x7bdb7c13}},	//   ики_, _feta, _eutr, rhuu,
   {{0x395e7c14,0x63a47c15,0x7bdb001c,0x29c90391}},	//   gats_, zdin, shuu, _rúas_,
   {{0x29c91a71,0x63a47c16,0x628401d7,0xd7ca2149}},	//   _súas_, ydin, ztio, لوده_,
   {{0x69d87c17,0xa3a90e96,0x6d5a1b71,0x443a5b1a}},	//   _elve, _गोल_, _zeta, _rup_,
   {{0x395e3201,0x6d5a001c,0x443a34f3,0x63a46f1e}},	//   bats_, _yeta, _sup_, vdin,
   {{0x395e7c18,0x443a7c19,0xb33b0132,0x6d5a7c1a}},	//   cats_, _pup_, _raça, _xeta,
   {{0x64a35b70,0x63a47c1b,0x044305ac,0xdce800a8}},	//   мара, tdin, десн, _yadı,
   {{0x63a47c1c,0x7f5b0831,0x29c901dd,0x62847c1d}},	//   udin, _neuq, _túas_, ttio,
   {{0x63a41fd0,0x98a506d3,0x62847c1e,0xb33b013b}},	// [8340] rdin, malı_, utio, _qaça,
   {{0x31167c1f,0x628420df,0x63a47091,0x6d4301f2}},	//   офес, rtio, sdin, jcna,
   {{0x62843104,0xdbd101d6,0x443a7c20,0x6d5a7c21}},	//   stio, _güçl, _uup_, _reta,
   {{0x6284504e,0x7c3a0282,0x98a5037a,0x7e627c22}},	//   ptio, _rutr, nalı_, tsop,
   {{0x6d5a4efc,0x7c3a7c23,0x6e3b00d7,0x4e960c26}},	//   _peta, _sutr, _cuub, تشار,
   {{0x7c3a34c2,0x3ead12c3,0x6e3b7c24,0x2bd200a1}},	//   _putr, _dret_, _duub, तस्थ,
   {{0xaff50332,0x395e0443,0x98a5037a,0x7e627c25}},	//   _کہنا_, vats_, kalı_, ssop,
   {{0xdce801c2,0xaa661e31,0x6d5a7c26,0xd007027a}},	//   _qadı, оток, _weta, _десе_,
   {{0x6d5a4367,0x395e162d,0x3ead7c27,0x98a50457}},	//   _teta, tats_, _gret_, dalı_,
   {{0x670e0299,0xddc2004e,0x2360006d,0x6e21009e}},	//   _सड़क_, społ, haij_, _ghlb,
   {{0x395e7c28,0xeb9a28f3,0x2cac00e9,0x98a5033e}},	//   rats_, _вие_, _urdd_, falı_,
   {{0xf8ad04cd,0x395e061a,0x56950dec,0x00000000}},	//   اکو_, sats_, памт, --,
   {{0x395e7c29,0x3949002d,0x37076823,0x7c2204fb}},	//   pats_, _şase_, ючов, _ihor,
   {{0x69d80b41,0xe8ea0220,0x00000000,0x00000000}},	//   _ulve, _پرتو_, --, --,
   {{0xd90f4ca7,0x7c22023c,0x6fdd021a,0x00000000}},	//   _ць_, _khor, पसमू, --,
   {{0xedb7035d,0x98a53833,0xb5fb171c,0x28a7007e}},	//   _इच्छ, calı_, rráq, गिरि,
   {{0x7c227c2a,0xe1f3096a,0xa2ad03de,0x44227c2b}},	// [8350] _mhor, وسط_, ीमध्, _dhk_,
   {{0x4422007c,0xdddb003a,0x644801dd,0x7dd40211}},	//   _ehk_, _spuž, ídic, _bàsm,
   {{0x6e3b6908,0x7c2201d7,0x395c0107,0x00000000}},	//   _suub, _ohor, _mevs_, --,
   {{0x3ead7c2c,0x623517d0,0xf4940df3,0x7ddd0951}},	//   _pret_, _нему, _کشید, _mèse,
   {{0x44297c2d,0xb3ba0122,0xe298010b,0x00000000}},	//   mma_, _המרכ, _даў_, --,
   {{0x7c2200c8,0x270a00e8,0x2ba70019,0x3ead0031}},	//   _ahor, ờng_, _ốc_, _vret_,
   {{0x98a50463,0x7c22184f,0x6b89011e,0x50645f11}},	//   yalı_, _bhor, tfeg, _отта,
   {{0x44297ace,0x3ead7c2e,0xb33b7c2f,0x6d430037}},	//   nma_, _tret_, _maço, scna,
   {{0x7c227c30,0x6aa4030a,0xab650d99,0xb33b0132}},	//   _dhor, _šifr, _aqüí, _laço,
   {{0xe9d916c0,0x44296596,0x9b0200d8,0x7c2201b7}},	//   ско_, hma_, эзыд, _ehor,
   {{0x7c22358f,0x442957fc,0x07a61018,0x98a5033e}},	//   _fhor, kma_, панн, talı_,
   {{0x442936e8,0x7c227c31,0x2360006d,0xdb0b0042}},	//   jma_, _ghor, xaij_, _engá,
   {{0x44297c32,0x98ab01d6,0xbb3a0397,0x98a500d0}},	//   dma_, ılık_, _העני, ralı_,
   {{0x7c297c33,0x44297c34,0x7c220187,0x44220055}},	//   lmer, ema_, _zhor, _shk_,
   {{0x98a5008f,0x7c297c35,0xb5fb7c36,0x44221872}},	//   palı_, omer, psán, _phk_,
   {{0x44297c37,0x7c297980,0xc24610b0,0x395c38cb}},	//   gma_, nmer, знак, _zevs_,
   {{0xb77b00a5,0x224b00e2,0x00000000,0x00000000}},	// [8360] _האפש, _ctck_, --, --,
   {{0x44297c38,0xb33b02e1,0x7c297c39,0xa7fd04d4}},	//   ama_, _faço, hmer, nsın,
   {{0x7c297c3a,0x655700a5,0x7e790051,0x44297c3b}},	//   kmer, _מביא_, euwp, bma_,
   {{0xb4b80084,0x7c290055,0x00000000,0x00000000}},	//   चमी_, jmer, --, --,
   {{0xa3b90127,0x7c290cc1,0xa7fd027d,0xb33b027d}},	//   चार_, dmer, ksın, _maçl,
   {{0x7c225c6f,0x63a67c3c,0x1ea91301,0x7c2901ba}},	//   _shor, _hakn, غاني_, emer,
   {{0x7c227c3d,0x490b06d9,0x395c0699,0x7c29033b}},	//   _phor, _ठुलो_, _revs_, fmer,
   {{0x63a60a18,0x7c297c3e,0xdcf800ea,0x8fa3010b}},	//   _jakn, gmer, levī, _пасе,
   {{0x291a023a,0x7f4402d7,0x00000000,0x00000000}},	//   _špa_, ñiqu, --, --,
   {{0x44297c3f,0xdca67c40,0x7c290300,0x6e93028c}},	//   zma_, _нази, amer, _سلما,
   {{0x660e00ac,0x7c297c41,0x44297c42,0xa31907ba}},	//   dobk, bmer, yma_, _दर्ज_,
   {{0x63a6247c,0x44297c43,0x7c227c44,0xd0f7024b}},	//   _nakn, xma_, _uhor, למית_,
   {{0x61ee02d7,0x44297c45,0x00000000,0x00000000}},	//   _ombl, vma_, --, --,
   {{0x1a9b02b5,0xdb0b0037,0x44297c46,0xb33b0132}},	//   _לידע, _ungá, wma_, _paço,
   {{0x44297c47,0x25787c48,0x63a67c49,0xdcf800ea}},	//   tma_, ябрь_, _bakn, devī,
   {{0x61ee7c4a,0x799a0054,0x7dd40176,0x9259021d}},	//   _ambl, letw, _bàsk, жаат_,
   {{0x63a67c4b,0x6d480051,0xdb0b021d,0x6aa2009f}},	// [8370] _dakn, _ofda, _fogõ, _jsof,
   {{0x7c2901fe,0x764d61c1,0x799a7c4c,0xd13b7c4d}},	//   zmer, _itay, netw, сха_,
   {{0x7c297c4e,0xf8dc00ab,0x9f4f00f7,0x4429027d}},	//   ymer, मनिय, ligé_, pma_,
   {{0xc1040ad9,0xa7fd027d,0x08770070,0x6d487c4f}},	//   روني, zsın, לעבט_, _afda,
   {{0x6da57c50,0x799a1ebf,0x7c290009,0x9ac50103}},	//   дила, ketw, vmer, _kuŋŋ,
   {{0x6b820831,0x69ca00e9,0x764d08c7,0x2d81099d}},	//   _acog, _nofe, _mtay, ühe_,
   {{0x63a63101,0x70944e4f,0xdca201d3,0x6aa20107}},	//   _yakn, _парф, ващи, _asof,
   {{0x69ca0069,0x764d030d,0x00000000,0x00000000}},	//   _aofe, _otay, --, --,
   {{0x69ca014c,0x200f7c51,0x764d04fb,0xcf9200a5}},	//   _bofe, mogi_, _ntay, _בטן_,
   {{0x7c297c52,0x39e902ce,0x6b827c53,0x27e10484}},	//   smer, ідно_, _ecog, _ċina_,
   {{0xdd1c024e,0x764d2ed0,0xa7fd037a,0x3ff90070}},	//   _záži, _atay, rsın, ַפֿע,
   {{0x200f4759,0x7e692152,0x764d030d,0x61ca00b4}},	//   nogi_, _kvep, _btay, _ाक्ष,
   {{0x799a0f1e,0x7dcf008c,0x7bcb1e97,0x00000000}},	//   betw, _føst, _iogu, --,
   {{0x63a603c1,0x7bcb02d7,0x69ca2596,0xa7fd013b}},	//   _sakn, _hogu, _gofe, qsın,
   {{0x660e15db,0x7bcb0006,0x764d030d,0xa3b908b0}},	//   robk, _kogu, _etay, चां_,
   {{0x660e00ac,0xc3070831,0x00000000,0x00000000}},	//   sobk, লেছি_, --, --,
   {{0x7bcb0537,0xa3e41022,0x63a67c54,0x64430118}},	// [8380] _mogu, भोग_, _vakn, _énin,
   {{0x7bcb7c55,0x6b9b0120,0x00da0037,0x020303d0}},	//   _logu, heug, يبات_, взун,
   {{0x63a67c56,0x7dcf0a8a,0x7e6d013a,0x00000000}},	//   _takn, _løss, šapl, --,
   {{0x7bcb7c57,0xef1a2e20,0x200f7c58,0x799a0035}},	//   _nogu, оме_, gogi_, zetw,
   {{0x60180176,0xde5800d8,0xb33b00a8,0x539b011d}},	//   ními, чалі_, _xaçm, _ויכו,
   {{0x6b8207e5,0x61ee7c59,0xdd1c0097,0xed4f0088}},	//   _scog, _umbl, _váži, لپه_,
   {{0xb4bc018d,0x7bcb4e45,0x6aa23288,0x200f3cb1}},	//   _आपो_, _bogu, _ssof, bogi_,
   {{0x69ca7c5a,0x7bcb7c5b,0x7dcf1217,0x6b9b023c}},	//   _sofe, _cogu, _bøss, geug,
   {{0x7bcb7c5c,0x1eaa00d1,0x5a3401d3,0x61fe0051}},	//   _dogu, _بازي_, ннит, onpl,
   {{0x7dcf008c,0x00000000,0x00000000,0x00000000}},	//   _døss, --, --, --,
   {{0x2d9c01d2,0x7bcb6098,0x764d7c5d,0x799a7c5e}},	//   meve_, _fogu, _stay, retw,
   {{0x2d9c7c5f,0x00000000,0x00000000,0x00000000}},	//   leve_, --, --, --,
   {{0xda630036,0xeafa03fc,0x69ca29c5,0xb33b013b}},	//   _авчи, _برات_, _tofe, _qaçm,
   {{0x2d9c00da,0x7dd412c3,0x9f4f000d,0x7bcb7c60}},	//   neve_, _bàsi, rigé_, _zogu,
   {{0x200f7c61,0x163400c3,0x4395384b,0x7bcb16a3}},	//   yogi_, теря, навс, _yogu,
   {{0x6b807c62,0x2d9c7c63,0x7bcb0042,0x764d030d}},	//   ngmg, heve_, _xogu, _ttay,
   {{0x4e0e006a,0x2d9c01f4,0x764d08c6,0x200f0093}},	// [8390] ाकाई_, keve_, _utay, vogi_,
   {{0x2d9c3c97,0x6b9b02c9,0xdbd6007c,0x7dcf0a8a}},	//   jeve_, zeug, _hääl, _løsr,
   {{0xdb0b022a,0x7e692d2c,0x2d9c7c64,0x200f3014}},	//   _ingå, _svep, deve_, togi_,
   {{0x4f940370,0x61fe2069,0x00000000,0x00000000}},	//   вршу, anpl, --, --,
   {{0x7bcb062c,0x2d9c0055,0x00000000,0x00000000}},	//   _rogu, feve_, --, --,
   {{0x44390052,0x0ea800d4,0x2d9c0031,0x7bcb512e}},	//   _his_, ькій_, geve_, _sogu,
   {{0x44397c65,0x7bcb539f,0x7ddd0392,0x23d3060a}},	//   _kis_, _pogu, _cèsa, _सवाद,
   {{0x44397c66,0x00000000,0x00000000,0x00000000}},	//   _jis_, --, --, --,
   {{0x44397c67,0xeab10037,0x2d9c0031,0x00000000}},	//   _mis_, اعب_, beve_, --,
   {{0x44397c68,0x2d9c7c69,0x7bcb47ed,0xdb090298}},	//   _lis_, ceve_, _wogu, ldeë,
   {{0x443900c3,0x7bcb7c6a,0x2fdf7c6b,0x00000000}},	//   _ois_, _togu, _klug_, --,
   {{0xf77218dd,0x4439004a,0xddc200b8,0xdb0b1b2f}},	//   داد_, _nis_, dpoř, _angå,
   {{0xa3b9073f,0x2fcd053e,0x96ba02c4,0x00000000}},	//   चाई_, _moeg_, чуну_, --,
   {{0x44397c6c,0xa2c30355,0x64a6010b,0x64480132}},	//   _ais_, रमन्, нага, ídio,
   {{0x44397c6d,0xb8f40b52,0x60187c6e,0x00000000}},	//   _bis_, _সে_, sími, --,
   {{0x2d9c7c6f,0xdb0b017b,0x04570037,0x443909e8}},	//   zeve_, _engå, علقة_, _cis_,
   {{0x44397c70,0x27e001c2,0x42267c71,0xb2260368}},	// [83a0] _dis_, _ilin_, едав, емал,
   {{0x44397c72,0x2fdf011e,0x7981016e,0x67240add}},	//   _eis_, _alug_, nglw, _izij,
   {{0x44397c73,0x40960d8a,0x61fe77d9,0x2fcd0d35}},	//   _fis_, эрат, rnpl, _boeg_,
   {{0x44397c74,0x8afd00b8,0x61fe010d,0x24f5010b}},	//   _gis_, zařa, snpl, _шчыр,
   {{0x2d9c7c75,0x27e002f6,0x245e00b8,0x5ed30033}},	//   teve_, _mlin_, lům_, _দেবে,
   {{0x44397c76,0x2d8e00f7,0x3d941403,0x00000000}},	//   _zis_, uffe_, тикр, --,
   {{0x2d9c01d2,0x27e00f67,0x44397c77,0x2fdf7c78}},	//   reve_, _olin_, _yis_, _flug_,
   {{0x4439006f,0x2d9c01f4,0x802603c5,0x2d85009e}},	//   _xis_, seve_, _سرزم, _ecle_,
   {{0x7c390297,0x2d9c01f4,0xd0077c79,0x6724001c}},	//   _diwr, peve_, _чете_, _nzij,
   {{0x27e07c7a,0x2c570035,0x2d9c01f4,0x245e00b8}},	//   _alin_, _będę_, qeve_, kům_,
   {{0xdbd60086,0x2918704d,0x27e07c7b,0x224201e0}},	//   _pääl, æra_, _blin_, _lukk_,
   {{0x1ae67c7c,0x245e0355,0xa3b020af,0x2362023a}},	//   _поем, dům_, _टोल_, _nekj_,
   {{0x44397c7d,0x6e3a035f,0x6d4a0037,0x7bc600be}},	//   _ris_, _kitb, ocfa, ökuu,
   {{0x443901a9,0x27e07c7e,0x7afd0176,0x6e3a007a}},	//   _sis_, _elin_, úste, _jitb,
   {{0x44397c7f,0xdbd60086,0x6e3a033b,0xdb027c80}},	//   _pis_, _tääl, _mitb, _maoí,
   {{0x4439006f,0xa4010033,0x69da28c5,0x75d800d0}},	//   _qis_, ্ষ্য_, lkte, _ağzı,
   {{0x1b0e0083,0x98ac037a,0x466800d8,0x69da0159}},	// [83b0] াইকে_, madı_, _прэм_, okte,
   {{0x443901ca,0x69da0c7d,0x98ac037a,0x6e3a0024}},	//   _wis_, nkte, ladı_, _nitb,
   {{0x2fcd00be,0x2c10021a,0x69da0223,0x44397c81}},	//   _poeg_, ावां_, ikte, _tis_,
   {{0x6e3a009e,0xddc2093f,0x98ac10b1,0x64550051}},	//   _aitb, grož, nadı_, mpzi,
   {{0x6e3a7c82,0x2fcd0903,0x2fdf11ad,0x00000000}},	//   _bitb, _voeg_, _vlug_, --,
   {{0x20040009,0x69da0051,0x00000000,0x00000000}},	//   _ejmi_, jkte, --, --,
   {{0x301b004f,0x63ad7c83,0x2fcd0223,0x6e3a008c}},	//   _فترة_, odan, _toeg_, _ditb,
   {{0x31630009,0xae0f1ab2,0x69da7c84,0xeb995b1f}},	//   _hejz_, िवहन_, ekte, фии_,
   {{0x628d7c85,0x63ad7c86,0x6e3a00d7,0x8ca10026}},	//   ntao, idan, _fitb, _कैरो,
   {{0x63ad7c87,0x00000000,0x00000000,0x00000000}},	//   hdan, --, --, --,
   {{0x27e07c88,0x63ad7c89,0x9b950037,0xac740079}},	//   _plin_, kdan, _للات, _مانش,
   {{0x7981001e,0x69da12ba,0x00000000,0x00000000}},	//   sglw, akte, --, --,
   {{0x63ad7c8a,0x21e401ae,0x7d1a01ed,0x4de5021a}},	//   ddan, _höhe_, _zyts, _कताई_,
   {{0x7ae90332,0x69da7c8b,0x628d0159,0x245e00b8}},	//   mzet, ckte, dtao, tům_,
   {{0xa80601d3,0x7ae90420,0x63ad0345,0x00000000}},	//   _изкл, lzet, fdan, --,
   {{0x63ad7c8c,0x6f16004e,0x245e00b8,0x9f4f0037}},	//   gdan, życi, rům_, figí_,
   {{0x7ae97c8d,0x628d011e,0x61460274,0xd5b10023}},	// [83c0] nzet, gtao, веза, ốc_,
   {{0x63ad7c8e,0x867b00a5,0xa3220354,0x7ae901ed}},	//   adan, _קריו, _मरीज_, izet,
   {{0x3d1602cb,0xa50a144b,0x7bdb00c3,0x106a004c}},	//   _पुढे_, _цена_, kkuu, фией_,
   {{0x44441bbe,0x63ad045e,0x7ddd0118,0x776401ed}},	//   _iu_, cdan, _bèso, _jeix,
   {{0x44447c8f,0x2bc50d2b,0x77640042,0xa2c300b4}},	//   _hu_, वाना, _meix, रमण्,
   {{0x44447c90,0x7dd40392,0x77640952,0x7ae97c91}},	//   _ku_, _nàst, _leix, dzet,
   {{0x44447c92,0x6f091116,0xddc24cc3,0x321800ee}},	//   _ju_, _exec, prož, _ikry_,
   {{0x44447c93,0x3d1602cb,0xb5fb004f,0x6e3a7c94}},	//   _mu_, _पुणे_, rsái, _witb,
   {{0x44440248,0x249a012f,0x7ae900b5,0xdb020138}},	//   _lu_, _lppm_, gzet, _taoí,
   {{0x44447c95,0xbda55002,0x63ad35b9,0x6e3a02e6}},	//   _ou_, _محمو, zdan, _uitb,
   {{0x44447c96,0x63ad7c97,0x3b8603f8,0x77641c02}},	//   _nu_, ydan, _алег, _beix,
   {{0xb5fb0370,0x63ad0be2,0x3834002d,0x00000000}},	//   nsáv, xdan, инэр, --,
   {{0x44447c98,0x77642b5c,0x051f0083,0x63ad4bf4}},	//   _au_, _deix, _দলের_, vdan,
   {{0x44447c99,0xceb300a5,0x7dd401f7,0x63ad00ee}},	//   _bu_, ביש_, _gàst, wdan,
   {{0x44441a24,0x657a004f,0x77647c9a,0x63ad360f}},	//   _cu_, ótha, _feix, tdan,
   {{0x44447c9b,0x776427c7,0x2bc51371,0x63ad19a9}},	//   _du_, _geix, वाया, udan,
   {{0x44447c9c,0xa2c300a1,0x76442a2b,0x2ebe0026}},	// [83d0] _eu_, रमध्, _guiy, ्होत,
   {{0x44447c9d,0xa2940131,0x628d0036,0xddc20035}},	//   _fu_, рафі, rtao, groż,
   {{0x4444060e,0x7ae97c9e,0x94d57c9f,0x3213300e}},	//   _gu_, zzet, _сонц, roxy_,
   {{0x65657ca0,0x7ddd0c1f,0x66157ca1,0x7e600090}},	//   _hehh, _pèso, lozk, _bwmp,
   {{0x4444328b,0x442b081c,0x7e6000e9,0x644508c7}},	//   _zu_, _ihc_, _cwmp, _huhi,
   {{0x44447ca2,0x64457ca3,0xee3802ce,0x7ae97ca4}},	//   _yu_, _kuhi, вні_, vzet,
   {{0x44447ca5,0x6445007c,0x656500be,0x442b0168}},	//   _xu_, _juhi, _mehh, _khc_,
   {{0x64452176,0x7ae97ca6,0xac960c74,0x6f090392}},	//   _muhi, tzet, انيا_, _txec,
   {{0x7ae90f44,0xdce30409,0x7e6000e9,0x776447fb}},	//   uzet, manč, _gwmp, _reix,
   {{0xdce37ca7,0x77644f54,0x7ae97ca8,0x7bdb7ca9}},	//   lanč, _seix, rzet, skuu,
   {{0x6d41469d,0x77647caa,0x7ae9006c,0x66150065}},	//   _igla, _peix, szet, dozk,
   {{0x44447cab,0xdce346e8,0x9ac4003c,0x23697cac}},	//   _ru_, nanč, _biċċ, jaaj_,
   {{0x644500ab,0x7dd40176,0x77640176,0xe737022b}},	//   _auhi, _tàst, _veix, лею_,
   {{0x44447cad,0x644512db,0x661501d7,0xdb0b0055}},	//   _pu_, _buhi, gozk, _lagë,
   {{0x4444105d,0x77647cae,0xdce3010b,0x3a0500b5}},	//   _qu_, _teix, kanč, _لکھی_,
   {{0x44447caf,0xdce37cb0,0x644504fb,0x9ac40069}},	//   _vu_, janč, _duhi, _fiċċ,
   {{0x6d4139ea,0x44447cb1,0x032638bb,0xdce3010b}},	// [83e0] _ogla, _wu_, удан, danč,
   {{0x44447cb2,0x6d4110ee,0x00000000,0x00000000}},	//   _tu_, _ngla, --, --,
   {{0x44447cb3,0x64450232,0x442b0132,0xdb0b0055}},	//   _uu_, _guhi, _fhc_, _bagë,
   {{0x2a6d003c,0xbe8a0274,0x6d4100ae,0xdce300c7}},	//   kseb_, еске_, _agla, ganč,
   {{0x44202de7,0x44327cb4,0xdce10069,0x4e9310ab}},	//   mli_, mmy_, _felċ, مشور,
   {{0x44321298,0xc6930122,0x61431f67,0xb33b0183}},	//   lmy_, צאו_, _гера, _caçu,
   {{0x44207cb5,0xdce37cb6,0xb5fb01ef,0xa3b90099}},	//   oli_, banč, rráx, चाच_,
   {{0x442006d3,0x3a740de3,0x75f40095,0x44324d6d}},	//   nli_, алир, _düzə, nmy_,
   {{0xaf062211,0xe20b0035,0x6aad3c2c,0x00000000}},	//   _спал, łóż_, _šafr, --,
   {{0x44207a11,0x2a970082,0x3f867cb7,0x79a61172}},	//   hli_, ائية_, lgou_, урие,
   {{0x02170397,0x683e3cf1,0xbb861301,0x75f400a8}},	//   רחים_, _būda, _ملاي, _güzə,
   {{0x3f8602e9,0x64457cb8,0x44320f86,0x313700a5}},	//   ngou_, _ruhi, jmy_, טנים_,
   {{0xeab203c7,0x64457cb9,0xec130594,0xdb190035}},	//   _دعا_, _suhi, _اوند, _dowó,
   {{0x44207cba,0x44320035,0x1dc700b8,0x64457cbb}},	//   eli_, emy_, लायत, _puhi,
   {{0x44207cbc,0xe5350421,0x66157cbd,0x00000000}},	//   fli_, ревь, rozk, --,
   {{0x44207cbe,0xdb0b0ea5,0xb3550200,0x65650118}},	//   gli_, _bagè, ркаш, _wehh,
   {{0x81ae0033,0xdce300f4,0x2bc50517,0x00000000}},	// [83f0] কান_, vanč, वाता, --,
   {{0x44207cbf,0x64457cc0,0x44327cc1,0x442b012f}},	//   ali_, _tuhi, amy_, _whc_,
   {{0x44203c1f,0xdce37cc2,0x439500d8,0xa3b00380}},	//   bli_, tanč, _канс, _टोक_,
   {{0xb4c302cb,0x44207cc3,0x673b011c,0x442b0282}},	//   ्ही_, cli_, žuju, _uhc_,
   {{0x8d652830,0xdce37cc4,0xea000019,0x6d410159}},	//   авле, ranč, _giầy_, _pgla,
   {{0x3f7500e8,0x7dd40443,0x127a0070,0xc27a00a5}},	//   ều_, _bàsq, _באשע, _ברשי,
   {{0x5ed300c8,0x228f0db0,0x463c0100,0xdce34cc5}},	//   _দেশে, lük_, געגע, panč,
   {{0x0b453cc0,0x2a6d007c,0xf0b3006c,0x2bc500b8}},	//   шнин, tseb_, _پیچھ, वाधा,
   {{0x63af7cc5,0x4a4504bf,0xdb0b0118,0xc4b304aa}},	//   _macn, јнов, _kagé, ुमुख,
   {{0x6d4101cc,0x44200448,0xe9d90c9f,0x63af016f}},	//   _ugla, zli_, тко_, _lacn,
   {{0x44207cc6,0x48065a1a,0x2bc510aa,0x44320035}},	//   yli_, ипов, वादा, ymy_,
   {{0x629d7cc7,0x442000a8,0x5b1502fb,0xd5b100e2}},	//   _opso, xli_, _кмет, ốn_,
   {{0x228f006c,0x44207cc8,0x00000000,0x00000000}},	//   jük_, vli_, --, --,
   {{0x2d877cc9,0x25a30009,0xdb1902d0,0x44207cca}},	//   ngne_, gejl_, _fowò, wli_,
   {{0x64a60a87,0x44207ccb,0x629d0d77,0xf1c9021a}},	//   шава, tli_, _apso, रानन,
   {{0x44207ccc,0x864618fd,0x24072526,0xdb0b0310}},	//   uli_, _книж, анси_, _pagè,

   {{0x443215b3,0x44207ccd,0xade50e1d,0xf3470dee}},	// [8400] rmy_, rli_, कसान_, рпул_,
   {{0xd5a404e8,0xe2976cef,0x63af0037,0x68e400b8}},	//   _الدی, раф_, _eacn, _řidi,
   {{0xdce1082d,0x673b0a69,0xb5fb7cce,0x161f1db9}},	//   _belč, žujt, rsát, _मीटर_,
   {{0x442040eb,0x03965189,0x2d877ccf,0x228f0225}},	//   qli_, _троя, egne_, bük_,
   {{0x63a40408,0x3f867cd0,0x61463537,0xdce17cd1}},	//   mein, rgou_, _вега, _delč,
   {{0xdd901b15,0xa2c30edf,0x9f4f021d,0x00000000}},	//   سوب_, रमर्, rigá_, --,
   {{0xcbe67cd2,0x8fa63ad5,0x00000000,0x00000000}},	//   иции, _каве, --, --,
   {{0xdb000332,0x63a47cd3,0x2d91027d,0xa7fd027d}},	//   lemé, nein, _özen_, nsıt,
   {{0xee3a1b5d,0x75e2016f,0x3d160a44,0xef1a00af}},	//   _ана_, _rôzn, _पुरे_, _рма_,
   {{0x63a47cd4,0xe61f0248,0x3e32006c,0xdce1146c}},	//   hein, ntôt_, _بہتر, _zelč,
   {{0x63a47cd5,0x228f5f16,0x7e6d0506,0x777b01ef}},	//   kein, zük_, šapt, óuxo,
   {{0x228f06a8,0x61d30d00,0xab830374,0xdce80168}},	//   yük_, _दक्ष, _душк, _obdĺ,
   {{0xf1c9009a,0x34df07df,0xdce302d4,0x7bc27052}},	//   रामन, नन्द, manā, _inou,
   {{0x7bc200fe,0x00000000,0x00000000,0x00000000}},	//   _hnou, --, --, --,
   {{0xf3671a55,0x63a47cd6,0xb4c32207,0xd4370037}},	//   итан, fein, ्हे_, لعرب,
   {{0x63a47cd7,0xe3b0126b,0x228f7cd8,0x255700fe}},	//   gein, ورق_, tük_, _bělé_,
   {{0x4df80084,0xe695004f,0x2d8c00f6,0x628400f6}},	// [8410] ्चाई_, _الخد, _ocde_, guio,
   {{0x228f7cd9,0x673b0009,0xf487002d,0xf1a70bfe}},	//   rük_, žujs, _кумн, јран,
   {{0xea000028,0x63a47cda,0x63af7cdb,0x80a40037}},	//   _giấy_, bein, _tacn, يمكن,
   {{0x64570291,0x63a40248,0x5f740037,0x320a008c}},	//   _itxi, cein, قاهر, _ejby_,
   {{0x2bc50099,0xa3bc0084,0xfbc500b8,0xf1a70fb4}},	//   वासा, _आफत_, वासम, _крвн,
   {{0x51840dfc,0x7bc27cdc,0x75eb0716,0xa1843122}},	//   _муса, _anou, _düzg, _мысл,
   {{0x2d877cdd,0xddc9002d,0xa7fd00a8,0xeb991f7c}},	//   rgne_, _aveţ, nsıs, гий_,
   {{0x3ff902b5,0x6e4500d1,0x91450448,0x7ddd0260}},	//   _עפּע, _هنرم, şığı_, _mèsi,
   {{0x75eb00b5,0x61e70069,0x00000000,0x00000000}},	//   _küzd, _kljl, --, --,
   {{0x1ddb01d1,0x7bc20122,0x2bc57cde,0x63a47cdf}},	//   _भवित, _enou, वाहा, zein,
   {{0x645701a9,0x34b30433,0x63a47ce0,0xa889010b}},	//   _ntxi, ुमोद, yein, ыйна_,
   {{0x3ead0124,0x63a401ef,0x628401ef,0xdb0000b5}},	//   _kset_, xein, yuio, zemé,
   {{0xe9ce2186,0x645706a2,0xca4800e2,0x00000000}},	//   _ек_, _atxi, _hờn_, --,
   {{0x63a4001e,0x2bc5193c,0x00000000,0x00000000}},	//   wein, वावा, --, --,
   {{0x69c37ce1,0x8afd00b8,0x04b510be,0xb42602e7}},	//   _inne, daři, остя, معرو,
   {{0x6b895504,0x680b0035,0xa7660200,0x00000000}},	//   ngeg, lędn, _укид, --,
   {{0x63a47ce2,0xb5fb03e6,0xdb0000b5,0x645701b7}},	// [8420] rein, rsár, temé, _etxi,
   {{0xb5fb0370,0x05aa7ce3,0x45862c49,0x75eb0225}},	//   ssár, _свой_, _угов, _rüzg,
   {{0x656e4374,0xe1ff2314,0x92d80033,0xdb0000b5}},	//   mabh, _avós_, ়ছে_, remé,
   {{0x645c7ce4,0x656e7ce5,0x6b8902a2,0x00000000}},	//   mpri, labh, jgeg, --,
   {{0x6b8907b6,0x645c038d,0x69c30086,0x527539e8}},	//   dgeg, lpri, _onne, _муру,
   {{0x2d910723,0x41c90084,0x656e01a6,0x244e01ba}},	//   _özel_, राणस, nabh, _kým_,
   {{0x3ead7ce6,0xa3cc0084,0x27040d4e,0x26f600dc}},	//   _eset_, लाप_, रपुर_, ीपुर_,
   {{0x69c37ce7,0x656e0125,0x62490009,0x6b894f47}},	//   _anne, habh, _džof, ggeg,
   {{0x6ff5006a,0x75eb01d6,0xe51f252c,0xdb0001cf}},	//   jący, _yüzd, _मुनि_, ndmø,
   {{0xd9100416,0x656e347f,0xdce30228,0x645c7ce8}},	//   ویش_, jabh, sanā, kpri,
   {{0x645c753e,0x621b0122,0x656e0211,0x2fc40051}},	//   jpri, רויק, dabh, _knmg_,
   {{0x69c37ce9,0xa3cc1db6,0x645c7cea,0x61fe01d6}},	//   _enne, लाफ_, dpri, hipl,
   {{0x645c7ceb,0x2bc500a1,0xead418f0,0x61fe0225}},	//   epri, वारा, _фоль, kipl,
   {{0x656e7cec,0xa2cc06fe,0x645c0223,0x997e0160}},	//   gabh, समन्, fpri, _dăţi_,
   {{0x645c7ced,0x61fe7cee,0x0f050035,0xdd0807c0}},	//   gpri, dipl, _शख्स_, _lôžo,
   {{0x98a700c7,0x244e007e,0x61fe0345,0x00000000}},	//   _agnė_, _dým_, eipl, --,
   {{0x27e97cef,0x61f9010b,0x00000000,0x00000000}},	// [8430] _ilan_, анаў_, --, --,
   {{0xddc90009,0xb33b00a8,0x672d04fb,0x656e45bd}},	//   _oveš, _qaçq, _izaj, cabh,
   {{0x463c00c2,0x27e97cf0,0x765d0a8c,0x637f009e}},	//   _געזע, _klan_, lpsy, _cànà,
   {{0x75eb0723,0xdb090037,0x2b467cf1,0xd5bf0029}},	//   _düze, hdeá, _ngoc_, žādi_,
   {{0xf41f00c3,0x27e97a75,0x0f3500e0,0x00000000}},	//   _ikä_, _mlan_, زکرد, --,
   {{0x27180028,0x321a0019,0x61fe05f5,0x00000000}},	//   ọng_, copy_, cipl, --,
   {{0x27e90eab,0x75eb0723,0x2bc50517,0x6b890b19}},	//   _olan_, _güze, वाला, tgeg,
   {{0x5f941a24,0xa3cc0099,0x8c421583,0x224b0bf7}},	//   _нист, लाय_, меще, _kuck_,
   {{0x6b897cf2,0xdd3a0012,0x656e7cf3,0x22430a75}},	//   rgeg, tăţi, yabh, _kijk_,
   {{0x6b895745,0x645c7cf4,0x75eb027d,0x27e97cf5}},	//   sgeg, ypri, _yüze, _alan_,
   {{0xa3cc00c4,0x27e902e9,0x17ca00af,0x672d04fb}},	//   लाम_, _blan_, агни_, _azaj,
   {{0xb8d102e4,0x61fe7cf6,0xe73a0dee,0x645c0a8c}},	//   _ऑन_, zipl, иен_, vpri,
   {{0x27e919cd,0x00000000,0x00000000,0x00000000}},	//   _dlan_, --, --, --,
   {{0xcb360122,0x27e97cf7,0x1a9a0070,0x672d07c0}},	//   _ואני_, _elan_, _כינע, _dzaj,
   {{0x2ea600b8,0x656e184f,0x236001e4,0x89377cf8}},	//   _गन्त, rabh, tbij_, _اعشا,
   {{0x27e97cf9,0x656e7cfa,0x645c07b9,0xa6ca4e87}},	//   _glan_, sabh, rpri, _نوبل_,
   {{0xe1fa7cfb,0x236004ce,0xa3cc1db9,0x656e009e}},	// [8440] ага_, rbij_, लाब_, pabh,
   {{0xf6530052,0xf77f0723,0x645c7cfc,0x244e290b}},	//   _קצת_, rkçe_, ppri, _tým_,
   {{0x321a06bc,0x224301e4,0x397a0070,0xf0aa031a}},	//   ropy_, _dijk_, שטענ, ркел_,
   {{0x389a0070,0x22430223,0xa3de018d,0x00000000}},	//   ייענ, _eijk_, _तकि_, --,
   {{0xddc97cfd,0x2d580f78,0x224b5b2e,0x00000000}},	//   _sveš, биль_, _guck_, --,
   {{0x8cb8021a,0xddc901c0,0x661c565f,0x75eb0222}},	//   ्मलो, _kteř, nork, _tüze,
   {{0xc0c900c9,0x9cca010b,0xafe6002d,0x8ed80033}},	//   _луѓе_, рыла_, _довл, _দেশগ,
   {{0xd00a534c,0x394701da,0x63b67cfe,0x60c100fd}},	//   _тебе_, _agns_, ndyn, _álma,
   {{0x62967cff,0x661c7d00,0x49a60279,0xe80e021a}},	//   ntyo, kork, ојна, ाचना_,
   {{0x661c7d01,0x27e90284,0x5edc0033,0x00000000}},	//   jork, _slan_, _মেথে, --,
   {{0x27e97d02,0xf2df0028,0x67240371,0x00000000}},	//   _plan_, _ngân_, _ayij, --,
   {{0x67240371,0x00000000,0x00000000,0x00000000}},	//   _byij, --, --, --,
   {{0x99d30220,0x63b600e9,0x661c29f1,0x67240027}},	//   ستیا, ddyn, fork, _cyij,
   {{0xdcfa01d6,0xda6500ce,0x27e9033b,0x6aa20036}},	//   _hatı, _راهي, _wlan_, _ipof,
   {{0xdcfa0723,0x224301e4,0x765d079a,0x200700b5}},	//   _katı, _rijk_, spsy, énik_,
   {{0x69d81953,0x27e97d03,0x7ddd0392,0xdce800ee}},	//   _hove, _ulan_, _hèst, _obdľ,
   {{0x672d3aa0,0x69d87305,0x2d9e01ef,0x661c7d04}},	// [8450] _uzaj, _kove, _obte_, bork,
   {{0x69d836aa,0x661c0034,0x681200ea,0x6aa20345}},	//   _jove, cork, rāde, _mpof,
   {{0x69d87d05,0x764d7d06,0x00000000,0x00000000}},	//   _move, _huay, --, --,
   {{0x6d4813d0,0x22430120,0x2bb60518,0x9f970310}},	//   _agda, _wijk_, _अफगा, _açò_,
   {{0xed593df1,0x9e6400d4,0xca4800e2,0x81d70033}},	//   бол_, двід, _bờm_, ়োগ_,
   {{0xa37b00ab,0x764d027d,0xb5fb002a,0xdce10160}},	//   _slõh, _muay, lpáb, _nelă,
   {{0x459c00c2,0x5ed30083,0xdcfa00d0,0xdb0b00ac}},	//   יסגע, _দেখে, _batı, _vagí,
   {{0x6e950086,0x69d8023a,0xf1c908b0,0x78530160}},	//   _нибу, _aove, रावन, _năva,
   {{0x81ae0b52,0x69d804ce,0xa3cc0325,0x7ddd7d07}},	//   কার_, _bove, लात_, _bèst,
   {{0x69d80122,0x2cbe009f,0xdce10395,0x67247d08}},	//   _cove, _frtd_, _celă, _ryij,
   {{0x69d81530,0x661c07c0,0x31bd0083,0x6c490037}},	//   _dove, vork, _আকাশ, _الصف_,
   {{0x764d7d09,0x3ebf7d0a,0x201d0035,0x69ce19ee}},	//   _buay, _krut_, nowi_, öber,
   {{0xdce801c0,0x7ddd021e,0xf71a010b,0x00000000}},	//   _oddě, _fèst, сіны_, --,
   {{0x69d87d0b,0x2ca90035,0xdef600a5,0x7e6908c7}},	//   _gove, ładu_, למרט_, _mwep,
   {{0xdcfa008f,0x201d0035,0x661c5bd9,0x00000000}},	//   _yatı, kowi_, rork, --,
   {{0x69d87d0c,0xdcfa0095,0x6b9b030d,0xddc90355}},	//   _zove, _xatı, nfug, _vteř,
   {{0x661c005d,0x764d7d0d,0x7ddd0176,0x63b67d0e}},	// [8460] pork, _guay, _jèss, rdyn,
   {{0x42230370,0x69d801dd,0x3f9f023c,0xd9a90099}},	//   едув, _xove, _abuu_, _कसोट,
   {{0x81ae0b52,0x9476004f,0x62967d0f,0x68e100e5}},	//   কাল_, _عددا, styo, nyld,
   {{0x3ebf7d10,0x26c07d11,0x6d480176,0xe29a021d}},	//   _brut_, _krio_, _sgda, _лам_,
   {{0x442201b4,0x2bbf00a1,0xe81d0066,0xdee319b6}},	//   _ikk_, _शोधा, नवता_, ноци,
   {{0xdcfa0d6f,0x61fc0888,0x68e17d12,0xec6a1e31}},	//   _satı, _umrl, kyld, брик_,
   {{0x64580248,0xa0a30d46,0x78a40009,0x8afd00b8}},	//   _évid, _пард, _ćivo, kařs,
   {{0x75eb01c2,0xbe06006c,0xdcfa00a8,0x26c07d13}},	//   _müza, _کوئٹ, _qatı, _orio_,
   {{0x69d804c3,0x64467d14,0xfbcf0079,0x5a347d15}},	//   _pove, _miki, اتى_, мнит,
   {{0x64467d16,0x68e101b4,0x7c6603c5,0x6284010b}},	//   _liki, fyld, _فاصل, irio,
   {{0x44227d17,0x9b4600d1,0x69d87d18,0x776d0042}},	//   _okk_, _فناو, _vove, _peax,
   {{0x64467d19,0x4422012f,0x7bd90103,0x683f010b}},	//   _niki, _nkk_, _gowu, _kūdi,
   {{0x764d022e,0x7c220232,0x9f4d013c,0x69d85339}},	//   _quay, _ikor, _umeå_, _tove,
   {{0x64467d1a,0x4a7b0100,0x62847d1b,0x5558002d}},	//   _aiki, _פרוב, drio, заря_,
   {{0x2c550029,0x44227d1c,0xa99b011d,0xc9b700a5}},	//   _kāda_, _bkk_, _הבור, _זהות_,
   {{0x671e1e79,0x64467d1d,0x683f0080,0x26c07d1e}},	//   _युवक_, _ciki, _līdz, _frio_,
   {{0x4422054e,0x644609df,0xe802004e,0x5edc0033}},	// [8470] _dkk_, _diki, _लगता_, _মেসে,
   {{0x645a1fca,0x98b0000c,0x44227d1f,0x681200ec}},	//   ític, _जनाए, _ekk_, māda,
   {{0x628433d9,0x64464f32,0xdb0b0332,0x7c227d20}},	//   ario, _fiki, _magá, _okor,
   {{0xd9a902e4,0x64467d21,0x7c2201d5,0x683f0e3c}},	//   _कस्ट, _giki, _nkor, _būdi,
   {{0x44297d22,0x4ea701c8,0xdfce00d1,0x68120228}},	//   mla_, яржа, شيو_, nāda,
   {{0x44291129,0x7c225822,0x64467d23,0x3ebf002d}},	//   lla_, _akor, _ziki, _vrut_,
   {{0x44297d24,0x611403e6,0xd9a90066,0x6234002d}},	//   ola_, _здру, _कसौट, _черу,
   {{0x44294f10,0x69dc06d2,0x681200ea,0x7ddd0392}},	//   nla_, ören, kāda, _pèss,
   {{0x4429393b,0x6b9b1f9d,0x3ebf08eb,0x52df0033}},	//   ila_, rfug, _urut_, _নেতৃ,
   {{0x44297d25,0x7c22104e,0xf2df0023,0xbebd005f}},	//   hla_, _ekor, _ngâm_, _dzūt,
   {{0xf3ff021d,0x7bd9073a,0x00000000,0x00000000}},	//   _omã_, _towu, --, --,
   {{0xad1a0779,0x3f8f1b0f,0x44297d26,0x9d1a0070}},	//   _ווער, nggu_, jla_, _וועט,
   {{0x44297d27,0x7c2908a1,0x64467d28,0xa3cc0653}},	//   dla_, mler, _riki, लास_,
   {{0x64a67d29,0x64467d2a,0x4422016f,0x682f01a6}},	//   мага, _siki, _skk_, rùda,
   {{0x44297d2b,0xe6437d2c,0x64461d86,0x4422037a}},	//   fla_, терп, _piki, _pkk_,
   {{0x7c290723,0x26c07d2d,0x62840b73,0xdb007d2e}},	//   nler, _trio_, trio, lemá,
   {{0x64460009,0xe2973d17,0x41c91e79,0xec090028}},	// [8480] _viki, мат_, रांस, yến_,
   {{0x7c297d2f,0xa3cc0243,0x5ef3000c,0xea000023}},	//   hler, लाह_, ्छन्_, _phẩy_,
   {{0x44297d30,0x64467d31,0x7c297d32,0xb802020d}},	//   bla_, _tiki, kler, _लगाम_,
   {{0xe8d602b5,0xd8d60070,0x1eaa0934,0x44220421}},	//   ווער_, וועט_, قاتي_, _ukk_,
   {{0x7c291123,0x44207d33,0x4e934cbc,0x2c550228}},	//   dler, moi_, نشور, _rāda_,
   {{0x44207d34,0xa3cc0f8a,0x00860009,0x7bdd01ae}},	//   loi_, लाव_, _олго, ösun,
   {{0x7c2901d6,0x61ee0036,0x0c7300ff,0x212c0079}},	//   fler, _ilbl, نديد, _ádh_,
   {{0x7c291f49,0x44207d35,0xdb000443,0xa2c300b4}},	//   gler, noi_, temà, रमच्,
   {{0x34ab00c0,0xdb0b7d36,0x7c22023a,0x6aa802b4}},	//   _चन्द, _pagá, _vkor, कबेर,
   {{0x44291a68,0x7e627d37,0x645e011c,0x7c3b002f}},	//   zla_, mpop, _otpi, amur,
   {{0x44291a68,0x7c2911cb,0x44206745,0xca4801a5}},	//   yla_, bler, koi_, _mời_,
   {{0xca4800e8,0x7c220010,0x442001f4,0x44297d38}},	//   _lời_, _ukor, joi_, xla_,
   {{0x44297d39,0x8c43195c,0x44207d3a,0xdb0b126b}},	//   vla_, _реце, doi_, _tagá,
   {{0x6d583e17,0x7c207d3b,0x44297d3c,0x7e6208c7}},	//   ncva, lomr, wla_, ipop,
   {{0x44297d3d,0x68120228,0xf1d2018d,0x44200064}},	//   tla_, sāda, सानन, foi_,
   {{0x442901a8,0x44207d3e,0x61ee20e4,0xdb0b008c}},	//   ula_, goi_, _albl, _dagæ,
   {{0x44293ede,0x7e627d3f,0x6d5a6ea0,0x63ad1575}},	// [8490] rla_, jpop, _ofta, _činč,
   {{0x4429446d,0x7c290723,0x68ed0355,0xca4800e2}},	//   sla_, zler, _řadi, _bời_,
   {{0x7c2901d6,0x62492b6c,0xa3cc00dc,0x96180037}},	//   yler, _džoa, लाश_, _تغير_,
   {{0x6d5a3d3b,0x44297d40,0x3f150346,0x44207d41}},	//   _afta, qla_, ндес, coi_,
   {{0x63ad7d42,0xa3cc0e04,0x7c297d43,0xed597d44}},	//   mean, लार_, vler, пол_,
   {{0x63ad003b,0xed590f23,0x69dc013c,0x657501f4}},	//   lean, чок_, örel, nazh,
   {{0x7c2908a1,0x09b70033,0x53c40d41,0x4c920200}},	//   tler, জামা, _लोडश, гијс,
   {{0x63ad7d45,0x69ca7d46,0x7f850041,0x7c2901ed}},	//   nean, _anfe, _سلطن, uler,
   {{0x7c2908a1,0xdb001423,0x00000000,0x00000000}},	//   rler, temá, --, --,
   {{0x63ad1093,0x7c297d47,0xe1ff004e,0x44207d48}},	//   hean, sler, _swój_, zoi_,
   {{0x7c2901d6,0xbc680082,0x31717d49,0x63ad7d4a}},	//   pler, _يمكن_, _mezz_, kean,
   {{0x63ad7d4b,0xcc5600a5,0x44207d4c,0xd0fa016b}},	//   jean, _טבעי_, xoi_, פּיר,
   {{0x7bcb7d4d,0x63ad62a0,0x44207d4e,0x6d47006c}},	//   _ingu, dean, voi_, _újab,
   {{0xba3902b5,0x657501f4,0x31716ced,0xe80207b5}},	//   _צײַט, gazh, _nezz_, _लगवा_,
   {{0x44207d4f,0x64a32faf,0xe1ff004e,0xa3cc23f0}},	//   toi_, лара, _twój_, लाल_,
   {{0xca480019,0x934615ae,0x63ad7d50,0x3d0200ab}},	//   _rời_, енбе, gean, _वइसे_,
   {{0x44207d51,0x6f160035,0xb5fb10ab,0x75f000a0}},	// [84a0] roi_, życz, mpán, _väzb,
   {{0x44207d52,0x171b00a5,0x31166cef,0x00000000}},	//   soi_, _מופע, нфес, --,
   {{0x63ad7d53,0x44200043,0xef8616b8,0xc22200b5}},	//   bean, poi_, елеп, نکڑو,
   {{0x63ad7d54,0xca480019,0xa25b0183,0x2c7a013a}},	//   cean, _vời_, _irôn, vīd_,
   {{0x2bd33779,0xfbd301c0,0x3f9a0035,0xa2e302fb}},	//   थाना, थानम, ępu_, _бояд,
   {{0x7bcb7d55,0xa25b00cc,0x00000000,0x00000000}},	//   _angu, _krôn, --, --,
   {{0x3f6a0896,0x987e00b8,0x7e6200ec,0x7e7c00ea}},	//   _ниво_, _péče_, spop, _ārpu,
   {{0xa2c402e4,0x22b20260,0x6d580207,0x00000000}},	//   रिप्, _kņk_, scva, --,
   {{0xa3e8210a,0x7c20038d,0x7a381309,0x20065aa9}},	//   _भवन_, romr, мпир_, mioi_,
   {{0x7bcb7d56,0x7c200b87,0x200601d7,0xdc120448}},	//   _engu, somr, lioi_, rşın,
   {{0x2bb80d00,0x63ad0cdf,0xa7fd0448,0x681200ea}},	//   _आसपा, yean, msız, rādn,
   {{0xc02e00e8,0x9cd70122,0x7c650b8d,0x00000000}},	//   _điều_, _רואה_, _شامل, --,
   {{0x09e64b66,0x63ad7d57,0xf1b2012f,0x95cb0be8}},	//   _подн, vean, ीयान, пува_,
   {{0xa2c410b7,0x69ca7d58,0xae200066,0xa7fd00d0}},	//   रिन्, _unfe, मकिन_, nsız,
   {{0x63ad21d0,0xa3cc00b4,0xa25b0279,0xf4840674}},	//   tean, लां_, _crôn, лутн,
   {{0x657500da,0xb21b0b3e,0x683601ef,0xa25b099e}},	//   sazh, _kvæg, táde, _drôn,
   {{0x63ad0f46,0x624966f6,0x96350011,0x75eb00d0}},	// [84b0] rean, _džon, _иниц, _yüzl,
   {{0x63ad1093,0x22b20260,0x00000000,0x00000000}},	//   sean, _dņk_, --, --,
   {{0x63ad7d59,0xdb000196,0xddc9027d,0x00000000}},	//   pean, lemä, _ateş, --,
   {{0x660725cb,0xa3cc164f,0x200f7d5a,0x22b2021e}},	//   lijk, लाः_, ungi_, _fņk_,
   {{0x44396b13,0x236900af,0xdb0002e2,0x00000000}},	//   _ihs_, mbaj_, nemä, --,
   {{0x6da57d5b,0xada53b6c,0xdee27d5c,0xd6580122}},	//   тика, такл, роши, עיות_,
   {{0x1fa70560,0xdb0000be,0x270d12e7,0xdd8e2149}},	//   _праг, hemä, सपुर_, زوي_,
   {{0xdb000086,0x30350421,0x00000000,0x00000000}},	//   kemä, _ребё, --, --,
   {{0x66070a75,0xdce8013a,0x44390090,0x386000f4}},	//   kijk, _vedā, _mhs_, _čira_,
   {{0x7d7900bf,0x3ea201ff,0x00000000,0x00000000}},	//   _آمار_, _äkta_, --, --,
   {{0x44390024,0x9be700d4,0x660764f4,0x2fcd0b88}},	//   _ohs_, _підк, dijk, _kneg_,
   {{0x7bcb7d5d,0x6e237d5e,0xeab100b5,0xdb0b0282}},	//   _ungu, lonb, _نعت_, _aagå,
   {{0x26c401c0,0xaae400f8,0x9f4f0453,0x98a200ea}},	//   ímo_, _مسوو, ligó_, ākā_,
   {{0xb5fb0300,0xa25b00a2,0x6e237d5f,0x00000000}},	//   spán, _prôn, nonb, --,
   {{0x2bb80299,0x44397d60,0xdce300b8,0xb5fb104b}},	//   _आसमा, _bhs_, vaně, mpál,
   {{0x3fbc0033,0x6f1e0067,0xa3cc7d61,0x00000000}},	//   _অক্ষ, ępcz, लाइ_, --,
   {{0xe61a0370,0x4439123d,0x6e231b71,0x93460fb4}},	// [84c0] _оди_, _dhs_, konb, тнае,
   {{0xf1aa00bf,0xf1d202e4,0xa25b0019,0x44397d62}},	//   باره_, साधन, _trôn, _ehs_,
   {{0x27e07d63,0xdce300b8,0x2fdf021e,0x63861566}},	//   _koin_, raně, _boug_, _игна,
   {{0x27e07d64,0x3dde262d,0x4f0a02ee,0xcf250987}},	//   _join_, _sotw_, мнен_, گرمي,
   {{0x6e237d65,0x27e07d66,0x1e9600af,0xa7fd0448}},	//   fonb, _moin_, трер, tsız,
   {{0x27e00248,0x27f200e9,0x00000000,0x00000000}},	//   _loin_, _llyn_, --, --,
   {{0xa7fd033e,0xa37b00be,0x60267d67,0xfd7900b5}},	//   rsız, _klõp, _адва, رشوں_,
   {{0xeb970202,0x27e003ad,0x6ce300d4,0x0b8a1199}},	//   вић_, _noin_, ріше, фски_,
   {{0x2d966341,0xea0001a5,0x3dde7d68,0x78ad0124}},	//   _арес, _nhảy_, _totw_, _ćava,
   {{0xee37059d,0x09d00083,0x27e00341,0x99d00033}},	//   _ану_, িস্থ, _aoin_, িস্ক,
   {{0x16cb07df,0x67360260,0x7afd0183,0xfbd200b5}},	//   ाम्ब, _azyj, ústr, _پتا_,
   {{0x6a860d46,0x66070120,0xb8fa0067,0xdb000303}},	//   _алда, wijk, _ठप_, temä,
   {{0xb4cb021a,0xa3cc4e90,0x4ab60567,0xea000019}},	//   लम्_, लाई_, _अनिव, _chảy_,
   {{0x44390b23,0x27e009c3,0xa25b00f7,0x4b3700a5}},	//   _shs_, _eoin_, _drôl, _סרגל_,
   {{0x66073440,0x443900d7,0x48e30836,0x27e000a2}},	//   rijk, _phs_, _војв, _foin_,
   {{0xe7877d69,0x1ab60a44,0xe41400d4,0x4ab60683}},	//   _руко, _अनाथ, адсь, _अनाव,
   {{0x6b82000e,0x98be05f9,0x236940f1,0x66070051}},	// [84d0] _mdog, matı_, rbaj_, pijk,
   {{0x35b50a2b,0xbbdf29ad,0x2fcd0693,0x98be0644}},	//   _сбор, _फक्क, _sneg_, latı_,
   {{0x21a402ce,0x68e80297,0x683605d3,0xc05801c8}},	//   риєм, nydd, láda, віч_,
   {{0x6b823eb0,0x98be0644,0x28c3157d,0x672d001c}},	//   _ndog, natı_, षिति, _kyaj,
   {{0x6e23022a,0xdd0100cb,0x68e800e9,0xe7a509b4}},	//   tonb, _čuđe, hydd, ग्यप,
   {{0x68e801ff,0x2004081b,0x00000000,0x00000000}},	//   kydd, _emmi_, --, --,
   {{0x63bd0496,0xa0b84e91,0x98be045e,0x6e2303d0}},	//   _kasn, _игру_, katı_, ronb,
   {{0x68e8001e,0x5f4514ac,0xa3cc111b,0xeb9912fa}},	//   dydd, _منزل, लाए_, хии_,
   {{0x63bd7d6a,0xba25002d,0x0a49004c,0x6b82001e}},	//   _masn, лдик, нзий_, _ddog,
   {{0xa2c425d8,0xfe6e0118,0x27e07d6b,0x63bd1a08}},	//   रित्, _رگه_, _soin_, _lasn,
   {{0x9b950580,0x27e01e2b,0x779400bf,0x27f20187}},	//   _ملات, _poin_, لیغا, _plyn_,
   {{0x69da0221,0x8cc01bb5,0xf6490317,0x672d010a}},	//   ajte, विरो, _זצ_, _byaj,
   {{0xa9a51ec2,0x27e000c3,0x672d007b,0xdb0b3536}},	//   _билд, _voin_, _cyaj, _lagú,
   {{0x68e8001e,0x7bdb023f,0x00000000,0x00000000}},	//   bydd, ljuu, --, --,
   {{0x7ae97d6c,0x63bd201d,0xdb007d6d,0xa25b000d}},	//   lyet, _basn, remå, _drôm,
   {{0x63bd7d6e,0x62490506,0x6f1b00a8,0x683600ac}},	//   _casn, _džom, _oxuc, báda,
   {{0x6aab7d6f,0x7ae97d70,0x4375005f,0x59b704aa}},	// [84e0] _jpgf, nyet, руст, _असार,
   {{0x3c3a01f4,0x764b000d,0x63bd0079,0xdb0b026e}},	//   mëve_, _égyp, _easn, _bagú,
   {{0x3c3a01f4,0x63bd00e9,0x98a6011c,0xf1c9057c}},	//   lëve_, _fasn, čiće_, राजन,
   {{0x7ae92104,0x41d207df,0xa2c401d1,0xe3b21015}},	//   kyet, साहस, रिद्, _ارد_,
   {{0x3c3a00da,0x7e2a2327,0x63a47d71,0x42d5010b}},	//   nëve_, ніка_, mfin, _кіру,
   {{0x63bd1577,0x63a47d72,0xdcba01d3,0x6b82027a}},	//   _zasn, lfin, ещи_, _sdog,
   {{0xa11616a4,0x98be06d3,0xea000023,0x3c3a01f4}},	//   _صورت, yatı_, _nhạy_, hëve_,
   {{0x3c3a01f4,0x200400d7,0x63a409e8,0x5fab0067}},	//   këve_, _ummi_, nfin, _टॉपल,
   {{0x68e81973,0x3c3a01f4,0x63a4008d,0x7ae97d73}},	//   wydd, jëve_, ifin, gyet,
   {{0x7d1a03d0,0x68e87d74,0x3c3a0031,0x63a4427f}},	//   _txts, tydd, dëve_, hfin,
   {{0xea000028,0xd90d00f8,0x63a47d75,0x481553b7}},	//   _chạy_, ویه_, kfin, имос,
   {{0x59d2000c,0x63a40124,0x68e84742,0x00000000}},	//   ताहर, jfin, rydd, --,
   {{0x624902c4,0x68e8001e,0x6b7b0319,0x3c3a01f4}},	//   _džoj, sydd, _טראנ, gëve_,
   {{0x63bd0029,0x65950370,0xb60400af,0x68367d76}},	//   _sasn, јаву, бяск, ráda,
   {{0x63bd209f,0x81da0033,0x7a340176,0x00000000}},	//   _pasn, ়সা_, làto, --,
   {{0xa3cc1163,0x75eb0723,0x59d20517,0x68361d8a}},	//   लाग_, _müzi, तावर, ládn,
   {{0x2ba67d77,0xfba606fe,0x917554d3,0x92953367}},	// [84f0] क्या, क्यम, игац, разц,
   {{0xddc9536c,0x63a47d78,0x395e123d,0x78530160}},	//   _svež, afin, ncts_, _săvi,
   {{0x7afb027a,0x63a40b3e,0x155a00a5,0xfaf9010b}},	//   zzut, bfin, _בכתב, lbūt_,
   {{0xa2952327,0x26c90124,0x7ae900a8,0x63a40312}},	//   _камі, _krao_, yyet, cfin,
   {{0xe37a024b,0x00000000,0x00000000,0x00000000}},	//   _שרשר, --, --, --,
   {{0x7bc70080,0x644f0033,0xfce52264,0x7ae97d79}},	//   ējum, _hici, иоло, vyet,
   {{0x5fc6009a,0x644f7d7a,0xc21200a5,0x3c3a0031}},	//   _रोवल, _kici, _והם_, zëve_,
   {{0x7afb14db,0xddc9042a,0x645721b4,0x7ae9018f}},	//   tzut, _uvež, _muxi, tyet,
   {{0x644f7d7b,0x5fab0026,0xde5900d4,0x628d7d7c}},	//   _mici, _टॉयल, _разі_, nrao,
   {{0x644f405e,0x7ae97d7d,0x7bdb00ab,0x7afb0035}},	//   _lici, ryet, sjuu, rzut,
   {{0x7ae97d7e,0x387e01ca,0x63a47d7f,0x7cd9036b}},	//   syet, gstr_, yfin, _جواز_,
   {{0x644f7d80,0x3c3a00da,0x7ae97d81,0x26c90207}},	//   _nici, tëve_, pyet, _brao_,
   {{0xaa677d82,0x681202d4,0x65770055,0x00000000}},	//   _стек, nādi, _bexh, --,
   {{0xd9450a22,0x3c3a01d2,0xdce30129,0x442b01a2}},	//   _кели, rëve_, lanđ, _akc_,
   {{0x3c3a0031,0x442b055c,0x00000000,0x00000000}},	//   sëve_, _bkc_, --, --,
   {{0x3ead505f,0x4aa90174,0x69c17d83,0x442b01a2}},	//   _opet_, _कहाव, ldle, _ckc_,
   {{0x63a47d84,0x628d0176,0x02062ad7,0x26c90391}},	// [8500] rfin, grao, азан, _grao_,
   {{0x69c17d85,0x63a47d86,0x64570391,0xdce30129}},	//   ndle, sfin, _fuxi, hanđ,
   {{0x03a60573,0x69c100e9,0x645701f4,0x63a4290f}},	//   _кино, idle, _guxi, pfin,
   {{0x25ad003a,0x657c2c7a,0x8fa61355,0x644f7d87}},	//   đele_, larh, раде, _gici,
   {{0xfe461499,0x64440328,0x681200ea,0x3ead009e}},	//   андо, mmii, gādi, _cpet_,
   {{0x44327d88,0x657c7d89,0x64440086,0x23600612}},	//   lly_, narh, lmii, lcij_,
   {{0xeb0e2f41,0x69c17d8a,0x644f04fb,0x2025008d}},	//   ाप्त_, ddle, _yici, ósið_,
   {{0x8aa67d8b,0x317801ae,0x443200a5,0x69c11032}},	//   арод, _herz_, nly_, edle,
   {{0x1ea900bc,0x44327d8c,0x7d0f00a8,0xa25b021d}},	//   _مالي_, ily_, _əksə, _esôf,
   {{0x44327d8d,0x657c7d8e,0x2c0b064e,0x69c10223}},	//   hly_, jarh, _یعنی_, gdle,
   {{0x245c024e,0x62490009,0x657701f4,0x44327d8f}},	//   _ním_, _džoh, _rexh, kly_,
   {{0x2a7f043d,0xfaa60d8a,0x26c94663,0x645701ef}},	//   bsub_, _вадо, _prao_, _ruxi,
   {{0x64570391,0x644f7d90,0x44327d91,0x442b7d92}},	//   _suxi, _rici, dly_, _rkc_,
   {{0x644f7d93,0x442b0c99,0xfaf92686,0x2b9200b5}},	//   _sici, _skc_, rbūt_, _ایکس,
   {{0x6ab609b4,0x644f7d94,0x245c006c,0xe7871362}},	//   _अनुर, _pici, _cím_, _купо,
   {{0x26c90028,0x44327d95,0xa7750adb,0x00000000}},	//   _trao_, gly_, _улич, --,
   {{0xa2c4166b,0xf1d200a1,0x657c071b,0xd25105bc}},	// [8510] रिष्, सांन, barh, سنا_,
   {{0x2ba609b1,0x644f7d96,0x628d0566,0x6444145d}},	//   क्ता, _wici, rrao, amii,
   {{0x44327d97,0x644f7d98,0x3ead02c6,0xceb400a8}},	//   bly_, _tici, _spet_, çən_,
   {{0x1ab60084,0xa2c409b1,0x442b08b7,0x681200ec}},	//   _अनूठ, रिश्, _ukc_, tādi,
   {{0x44297d99,0x683d69eb,0xdce30200,0x7a3d0248}},	//   moa_, céde, vanđ, lète,
   {{0x44297d9a,0x68120228,0xa2c406fe,0xed580168}},	//   loa_, rādi, रिर्, _paľa_,
   {{0x22592b6f,0xa3cc00a1,0x7a3d175d,0x681202d4}},	//   _husk_, लाच_, nète, sādi,
   {{0x44297d9b,0x5f9403b1,0x2a7f7d9c,0x2a66000d}},	//   noa_, _мист, tsub_, _btob_,
   {{0x8d87064e,0x2ef50409,0x657c00d7,0x4e940037}},	//   _نشان, _узар, yarh, _وشكر,
   {{0x44297d9d,0x44320fbf,0x00000000,0x00000000}},	//   hoa_, zly_, --, --,
   {{0x44297d9e,0x69c12e04,0x44320791,0x225900ee}},	//   koa_, rdle, yly_, _lusk_,
   {{0x44297d9f,0x98160037,0xdb1b01ef,0x62490b1a}},	//   joa_, إبدا, lduí, _džoi,
   {{0xf3ff0083,0x44297da0,0x290b004e,0x657c7da1}},	//   ্কার_, doa_, ńca_, tarh,
   {{0xd99903c5,0x69dc7da2,0x7c2939d4,0xdb1b2314}},	//   _صنعت_, öret, loer, nduí,
   {{0x1da9022e,0x44297da3,0x443200a5,0x2bbd065f}},	//   च्यत, foa_, tly_, ्यपा,
   {{0x44297da4,0x7ddd02e9,0x245c00b8,0x22597da5}},	//   goa_, _vèsy, _vím_, _busk_,
   {{0x44320052,0x64447da6,0xd1860036,0x77647da7}},	// [8520] rly_, rmii, йлай, _ifix,
   {{0x44327da8,0x245c7da9,0x51567258,0x2ca90067}},	//   sly_, _tím_, стау, łady_,
   {{0x44327daa,0xef650d6f,0x44297dab,0x2c550029}},	//   ply_, ğını_, boa_, _kādu_,
   {{0x44297dac,0x7c290b88,0xea0001a5,0xef6504d4}},	//   coa_, joer, _thầy_, şını_,
   {{0x2bbd1782,0x3178007a,0x63b622ca,0x7c290088}},	//   ्यना, _terz_, meyn, doer,
   {{0x63b67dad,0x62960515,0x21f60037,0x75eb00a8}},	//   leyn, muyo, _اكسس, _füzu,
   {{0xec090028,0x62967dae,0xb21b34b7,0x2a66009e}},	//   yết_, luyo, _kvæn, _stob_,
   {{0x8fa37daf,0x660e00a8,0x30752a2d,0x77640069}},	//   _насе, hibk, _фурс, _nfix,
   {{0x629601d6,0x00000000,0x00000000,0x00000000}},	//   nuyo, --, --, --,
   {{0x660e0ec0,0x442906a2,0xa2bb0070,0x77647db0}},	//   jibk, zoa_, נמיט, _afix,
   {{0x69cd009a,0x7c297db1,0x4429011e,0xe1ff002a}},	//   ताजी, boer, yoa_, _otón_,
   {{0x313702b8,0x62967db2,0x44297db3,0x7c2923ff}},	//   מנים_, kuyo, xoa_, coer,
   {{0x44297db4,0x63b600a8,0x41c800c0,0xf1c8035d}},	//   voa_, deyn, रयास, रयान,
   {{0xe1ff002a,0x7764002a,0x2259198d,0xa2ae07df}},	//   _atón_, _efix, _rusk_, ुबन्,
   {{0x44297db5,0x7bc20107,0x25fa0354,0x2d9e009f}},	//   toa_, _kaou, _उतरी_, _mcte_,
   {{0x2bbd01d1,0x7a3d00f7,0x320a099e,0x00000000}},	//   ्यया, rète, _amby_, --,
   {{0x44297db6,0x8af70095,0x62967db7,0x717903c6}},	// [8530] roa_, _çəti, guyo, ибар_,
   {{0x44297db8,0xf77f7db9,0xbb3b0070,0x7bc200f6}},	//   soa_, laç_, רעמי, _laou,
   {{0x2bbd317c,0x9735006c,0x44297dba,0xd13b257f}},	//   ्यमा, _دکھا, poa_, уха_,
   {{0x2d9e7dbb,0x753a033b,0x62964a9e,0x200900e2}},	//   _acte_, ütze, buyo, òai_,
   {{0x539a0052,0x7c293440,0x201c0279,0x9f4d0312}},	//   _דירו, voer, évia_, _bleá_,
   {{0x2bbd05f8,0xdc3c00ea,0x2ba609b1,0x00000000}},	//   ्यभा, kšēj, क्सा, --,
   {{0x7c297dbc,0x0cd70083,0x7bc233e5,0xdcf80009}},	//   toer, তন্ত, _baou, bavč,
   {{0xea8906cd,0x7bc2000d,0x61e77dbd,0xa2cd00b4}},	//   абил_, _caou, _hojl, सिप्,
   {{0x7bc223ca,0x0ae60086,0x62490009,0x7c292193}},	//   _daou, ждый_, _džov, roer,
   {{0x200f7dbe,0x888505e8,0xc9a600c3,0xf8a91303}},	//   ligi_, олож, овье_, авок_,
   {{0xdb090300,0x7bc200f6,0x61e70282,0x00000000}},	//   rdeñ, _faou, _mojl, --,
   {{0x200f7dbf,0x69dc01ff,0x4a75010b,0xdb090138}},	//   nigi_, örer, _дыкт, sdeñ,
   {{0xe9d90645,0xddc200ea,0x3cdf0785,0x9f440031}},	//   _вкл_, lpoš, _कपडे_, _romë_,
   {{0xf3f10019,0xdce800b8,0xa2cd01c0,0x2a6d006d}},	//   ện_, _nedě, सिन्, mpeb_,
   {{0x7bc223bb,0x2c550029,0x2ba604aa,0x63b60510}},	//   _yaou, _tādu_, क्वा, teyn,
   {{0x69c37dc0,0x6b9b7dc1,0x629603be,0x25ad0254}},	//   _hane, ngug, tuyo, đela_,
   {{0xe29a7dc2,0x69c303a6,0x63b67dc3,0x2c550029}},	// [8540] раз_, _kane, reyn, _kāds_,
   {{0x69c37dc4,0xea0000e8,0x09b70083,0x63b60095}},	//   _jane, _thấy_, জাকা, seyn,
   {{0x69c3032b,0x09ac0033,0x7f8603fb,0xddc200f4}},	//   _mane, _কোডা, قلان, jpoš,
   {{0x69c306a2,0xe29a7dc5,0x888a02b5,0xd7dd00a1}},	//   _lane, _кам_, שרײַ, यायच,
   {{0x2a6d006d,0xdcf810a5,0x61e70069,0xb21b08c8}},	//   jpeb_, ravč, _fojl, _kvæl,
   {{0x7bc27dc6,0x6286011c,0xdc8a692c,0x8c660185}},	//   _saou, _ivko, асил_, отид,
   {{0xf77f027d,0xe7ca084b,0x00000000,0x00000000}},	//   yaç_, ियाप, --, --,
   {{0x69c301bf,0x7a340955,0xdfd200d1,0x62497dc7}},	//   _aane, màti, _تير_, _džou,
   {{0x2ba609a8,0x62845c22,0xfba60931,0x69c35491}},	//   क्षा, nsio, क्षम, _bane,
   {{0x094a0b46,0xc3330122,0x3ebb0d85,0x6284001e}},	//   ични_, ווח_, _דצמב, isio,
   {{0x69c37dc8,0x61e302c9,0x25de04bc,0x415b0070}},	//   _dane, önli, खानी_, ידיג,
   {{0x62847dc9,0x2fc6190b,0x2ba60864,0xdb0b0310}},	//   ksio, ndog_, क्शा, _yagü,
   {{0x0aba0332,0x7a2f0909,0x6b80010d,0xf77f027d}},	//   _خطاب_, tøtt, mamg, raç_,
   {{0x69c37dca,0xfba609a8,0x62847dcb,0x200f018e}},	//   _gane, क्रम, dsio, zigi_,
   {{0x09ac0083,0xd37b7c1f,0x62860df7,0xb21b0a8a}},	//   _কোথা, ича_, _avko, _dvæl,
   {{0x248d1405,0x683f0029,0x6b800054,0x3ea611e9}},	//   čem_, _lūdz, namg, ktot_,
   {{0x2bbd0266,0x27e97dcc,0x4abc0026,0xaabc1119}},	// [8550] ्यता, _ioan_, ्टिव, ्टिक,
   {{0x69c3043f,0x27e90019,0xdb00478a,0xef6500c1}},	//   _xane, _hoan_, lemó, ğımı_,
   {{0x7e697dcd,0x200f7dce,0x7fd500c7,0x61e70009}},	//   _step, tigi_, зілі, _vojl,
   {{0x2fc6027c,0x27e97dcf,0xdb0b2a1c,0xaabc1cce}},	//   gdog_, _joan_, _magò, ्टाक,
   {{0x200f7dd0,0x6b800008,0x15ff0a40,0xdb0b0107}},	//   rigi_, damg, _उतार_, _lagò,
   {{0xdd9107f6,0x27e900a5,0x8e0800d4,0x61fe033b}},	//   روع_, _loan_, онів_, chpl,
   {{0xc18200b5,0x200f7dd1,0x69c50093,0x00000000}},	//   _سینٹ, pigi_, _óhei, --,
   {{0x69c300bf,0x251c02b5,0x6b800159,0x2ba60e61}},	//   _sane, יווא, gamg, क्ला,
   {{0x68360097,0xddc20693,0x7e697dd2,0xaffa0070}},	//   sádk, spoš, _utep, _פּלי,
   {{0xa9a500af,0x00000000,0x00000000,0x00000000}},	//   чиод, --, --, --,
   {{0x69c30006,0x2a6d006d,0x16d40af9,0x27e90107}},	//   _vane, speb_, दम्ब, _boan_,
   {{0x62847dd3,0x2c63027d,0xdb0002d7,0xb21b0a8a}},	//   ysio, _gıda_, gemó, _svæl,
   {{0x27e97dd4,0x249856e9,0xe1ff7dd5,0xfb35005f}},	//   _doan_, wurm_, _atóm_, _эндэ,
   {{0x63af009e,0x2c550029,0xdcf8013a,0x24987dd6}},	//   _abcn, _tāds_, lavā, turm_,
   {{0x2eb80992,0x8cce0035,0x6f02027a,0x79810cb9}},	//   _इन्त, थियो, zzoc, malw,
   {{0x62840ccf,0x683d7dd7,0xdcf8013a,0x27e90312}},	//   tsio, lédn, navā, _goan_,
   {{0x9f441fca,0x2bad02cb,0x628400d8,0xe1fa0036}},	// [8560] _tomé_, झ्या, usio, бга_,
   {{0x62840db7,0x2bb8084b,0x2fc40009,0x200d0132}},	//   rsio, _आस्थ, _samg_, _amei_,
   {{0x62847dd8,0xfbbd2095,0x201c0279,0x2fc67dd9}},	//   ssio, ्याम, évio_, tdog_,
   {{0x62847dda,0x657e44d1,0x79810173,0x683f00ea}},	//   psio, _heph, halw, _sūdz,
   {{0x7882006c,0xb5fb7ddb,0xed50006c,0x645e7ddc}},	//   _kívá, mpár, چھا_, _hupi,
   {{0x645e7ddd,0x2bd10299,0x62490df4,0x6f027dde}},	//   _kupi, _दोबा, _džos, rzoc,
   {{0xa2c40ebd,0x3ea67ddf,0x324300d4,0x7981016e}},	//   रिक्, stot_, _черг, dalw,
   {{0xdcf8013a,0x645e024c,0xdb00002a,0x00000000}},	//   gavā, _mupi, xemó, --,
   {{0x798100e9,0x20070031,0x8b6600b5,0x6836021d}},	//   falw, ënie_, _ہاشم, cádi,
   {{0xeaaf0ad9,0x27e975e3,0x3dc5001e,0x39580c71}},	//   اعي_, _soan_, _galw_, ørs_,
   {{0x6d5a043d,0x645e010b,0xb5fb00b5,0xdb000176}},	//   _igta, _nupi, kpár, gemò,
   {{0x1ae67de0,0x200700a2,0x00000000,0x00000000}},	//   _ноем, énix_, --, --,
   {{0xa3c01fe0,0x645e0b88,0x7981001c,0x27e97de1}},	//   ंजन_, _aupi, balw, _voan_,
   {{0x09e35b66,0x2bda035d,0x657e7de2,0x645e08b5}},	//   _почн, भावा, _ceph, _bupi,
   {{0x27e90019,0x69c8001e,0x67247de3,0x78822e11}},	//   _toan_, mdde, _exij, _dívá,
   {{0xc2c500f8,0x645e18a2,0x69c8172b,0x03c42746}},	//   ويزي, _dupi, ldde, нсум,
   {{0x32550210,0x69c8016e,0x683d000d,0xa2c40096}},	// [8570] двар, odde, lédo, रिग्,
   {{0x69c87de4,0xb21b008c,0x645e034d,0x00000000}},	//   ndde, _ivæk, _fupi, --,
   {{0x69c801e0,0xdb0b0093,0x645e7de5,0x61fc0160}},	//   idde, _lagð, _gupi, _dlrl,
   {{0xa2cd31d7,0x683603e6,0x2d8c7de6,0xdbcb0093}},	//   सिद्, tádi, _adde_, jóðf,
   {{0x62497de7,0x69d80136,0x63ad7de8,0xfbbd0355}},	//   _džor, _onve, mfan, ्यसम,
   {{0x63ad7de9,0xfe7001b2,0x645e7dea,0x00000000}},	//   lfan, ادن_, _yupi, --,
   {{0x64580248,0x63ad0054,0x79817deb,0xdcf802d4}},	//   _évit, ofan, valw, tavā,
   {{0xeb991cf7,0x69d87dec,0x63ad7ded,0xdb1b0132}},	//   ции_, _anve, nfan, nduç,
   {{0x79817dee,0x8b640088,0x06e30033,0xdcf800ec}},	//   talw, رايم, নৈতি, ravā,
   {{0x7d180079,0x9ce7002d,0x63ad4c7c,0xada607c0}},	//   éasú, _нцел, hfan, _prúž,
   {{0x02ba00dc,0x394510a9,0xf8af0416,0x7e7b027a}},	//   _उन्न, ьног, اکت_, _hwup,
   {{0x6d4125d6,0x645e7def,0xe73a3d35,0x7981030d}},	//   _izla, _rupi, жем_, salw,
   {{0x63ad6252,0x41e0007e,0x7bd90345,0x7c2d7df0}},	//   dfan, नामस, _inwu, čard,
   {{0x2bbd13ab,0x7bc97df1,0x4abc0437,0x645e11f0}},	//   ्यवा, ldeu, ्टरव, _pupi,
   {{0x64a31ed5,0x6aa92aab,0x683d00a2,0x63ad7c81}},	//   кара, ltef, cédo, ffan,
   {{0x7bc94c63,0x6724006d,0x0443107a,0x680b0035}},	//   ndeu, _txij, весн, zędz,
   {{0x6aa97df2,0xa1c600af,0xc1ea3e3d,0x9f4a027b}},	// [8580] ntef, мбад, одаж_, ümün_,
   {{0x26d20010,0x3f8d0392,0x00000000,0x00000000}},	//   _iryo_, _adeu_, --, --,
   {{0x106a1663,0x764000b8,0xafe601e0,0x4fa612a2}},	//   цией_, ůmys, можл, диев,
   {{0x26d200ee,0x00000000,0x00000000,0x00000000}},	//   _kryo_, --, --, --,
   {{0x6d410a4e,0x69c87df3,0x7bc9727c,0x2d8c021d}},	//   _azla, ydde, ddeu, _pdde_,
   {{0xb8060083,0x44220328,0x00000000,0x00000000}},	//   োকিত_, _hjk_, --, --,
   {{0xdb0b00fb,0xd839011c,0x29051575,0x7bc90223}},	//   _sagð, luče_, jzla_, fdeu,
   {{0xc3fb016b,0x26d2030d,0x7bc90b88,0x00000000}},	//   ַליש, _oryo_, gdeu, --,
   {{0xe7dd0099,0x628300f4,0x4a54059b,0xa2c4021a}},	//   यासप, ćnog, нкис, रिट्,
   {{0x4422012f,0x00000000,0x00000000,0x00000000}},	//   _ljk_, --, --, --,
   {{0x69c8645d,0x63ad7df4,0x26d2096c,0x7e600cec}},	//   rdde, yfan, _aryo_, _hump,
   {{0x7e607df5,0xb8e6004e,0x628b00b5,0x44220282}},	//   _kump, _उन_, ágok, _njk_,
   {{0x26d20051,0x7c2201d5,0xd839030a,0x7e6005d6}},	//   _cryo_, _ijor, juče_, _jump,
   {{0xc1c80d53,0x69d87df6,0x7e607df7,0x44220a4e}},	//   रयोग, _unve, _mump, _ajk_,
   {{0x7e6003c3,0x63ad008a,0x26d2018e,0x44227df8}},	//   _lump, tfan, _eryo_, _bjk_,
   {{0xeac80028,0x64460024,0x60c900ea,0x7c220298}},	//   _kỹ_, _chki, _ņemo, _jjor,
   {{0x4caa00c8,0x63ad6430,0x7e6000d1,0x22580a8a}},	// [8590] কিটু, rfan, _nump, _birk_,
   {{0xeac800e8,0x63ad7df9,0x9f441c5b,0x7a340176}},	//   _mỹ_, sfan, _comí_, pàtu,
   {{0x62490df4,0x63ad7dfa,0x22585092,0x4422023a}},	//   _džop, pfan, _dirk_, _fjk_,
   {{0x66157dfb,0x7c22034d,0x7e60062c,0x629605f0}},	//   lizk, _njor, _bump, bryo,
   {{0x7e607dfc,0x644d7dfd,0x6d410035,0xef190069}},	//   _cump, mmai, _szla, _beża_,
   {{0x7c227dfe,0xc27a00a5,0x0dc80274,0x00000000}},	//   _ajor, _מרשי, дући_, --,
   {{0x271b00b1,0xdce30029,0x5c5519fa,0x644d7dff}},	//   नपुर_, manī, нтиф, omai,
   {{0x6aa9039b,0xa2c40edf,0x7bc94cbb,0x22580345}},	//   ttef, रिच्, udeu, _zirk_,
   {{0x7bc97e00,0x7e60046a,0x4ea41474,0x661501a3}},	//   rdeu, _gump, _арха, kizk,
   {{0xdf447e01,0x644d7e02,0x89a902f2,0x7bc9095a}},	//   _рэсп, hmai, чков_, sdeu,
   {{0x07a600ef,0x6d417e03,0xf1b202b5,0x66150291}},	//   нанн, _uzla, נסט_, dizk,
   {{0x7c221e74,0x29050207,0x60da00b5,0x00000000}},	//   _gjor, rzla_, _átme, --,
   {{0x644d7e04,0x7c3b021d,0xaffa0070,0x44220345}},	//   dmai, mlur, פּטי, _rjk_,
   {{0x6a1704e8,0xd8390254,0x44227e05,0x3ea2013c}},	//   _تبصر, vuče_, _sjk_, _åkte_,
   {{0x442200d7,0x2ba6658f,0xa3cb00e7,0x00000000}},	//   _pjk_, क्का, लयं_, --,
   {{0xa7fd00a8,0x22587e06,0x62960260,0x644d2388}},	//   lqın, _sirk_, tryo, gmai,
   {{0x130a00d8,0x7c3b7e07,0x66150065,0x00000000}},	// [85a0] чнай_, ilur, bizk, --,
   {{0xe7ac09b4,0x644d7e08,0xbbbd01d1,0x167700a5}},	//   ट्रप, amai, ्युक, _רגיל_,
   {{0xdcfa3f84,0x00000000,0x00000000,0x00000000}},	//   _petč, --, --, --,
   {{0x644d00e0,0x4ea62e90,0xd8390e31,0x00000000}},	//   cmai, ерка, puče_, --,
   {{0x44207e09,0x44320f3a,0x61f3082b,0x20070031}},	//   mni_, moy_, ådlø, ënia_,
   {{0x44320269,0xf2df0023,0xf48700f8,0x7c220223}},	//   loy_, _ngây_, _تایی, _sjor,
   {{0x44207e0a,0x614300d8,0xeac801a5,0x7e60011e}},	//   oni_, _бера, _sỹ_, _wump,
   {{0x44207e0b,0x44327e0c,0x2bba0082,0x7e6065fc}},	//   nni_, noy_, ساعة_, _tump,
   {{0x61ee02ce,0x63a6271e,0x7e6008dd,0xe7e40630}},	//   _kobl, _mckn, _uump, गाना_,
   {{0x44207e0d,0x4432190b,0x3f860107,0xfce67e0e}},	//   hni_, hoy_, laou_, _позо,
   {{0x44207e0f,0x61ee7e10,0x443200a7,0x7c3b7e11}},	//   kni_, _mobl, koy_, blur,
   {{0x44200888,0x2ba60035,0x644d011e,0x443200a5}},	//   jni_, क्खा, xmai, joy_,
   {{0xd6d84674,0x44322a81,0x61ee0159,0x644d00ec}},	//   нтр_, doy_, _oobl, vmai,
   {{0x44207e12,0x6b82067f,0x63a6024b,0x61ee012c}},	//   eni_, _heog, _ackn, _nobl,
   {{0x44207e13,0xa4d803f8,0x661501a3,0x644d07d6}},	//   fni_, ндру_, rizk, tmai,
   {{0x44207e14,0x44327e15,0x493b0122,0x69ca7e16}},	//   gni_, goy_, _מגוו, _hafe,
   {{0x61ee4763,0x23690af3,0x65870043,0x644d222b}},	// [85b0] _bobl, rcaj_, _пынз, rmai,
   {{0x44207e17,0x644d7e18,0x61ee7e19,0x6b827e1a}},	//   ani_, smai, _cobl, _leog,
   {{0x44327e1b,0x44200169,0x61ee7e1c,0x25de111e}},	//   boy_, bni_, _dobl, खारी_,
   {{0x44206cae,0x69ca7e1d,0x6b827e1e,0xa28303fc}},	//   cni_, _lafe, _neog, _میرو,
   {{0x539a02da,0x2bd105f8,0xfbd1021a,0x69a129ce}},	//   _קישו, _दोषा, _दोषम, _खाली,
   {{0x44d101c8,0x61ee7e1f,0xdce80080,0xa2a60967}},	//   _ką_, _gobl, _nedē, _चमत्,
   {{0x6b827e20,0x44d157c2,0xe7e43123,0x7c3b00af}},	//   _beog, _ją_, गामा_, tlur,
   {{0xbbbd04eb,0xa1581112,0x5bbd022e,0xdce10395}},	//   ्येक, _часу_, ्येव, _află,
   {{0x2fc000ab,0x9f440176,0x69ca5ba6,0x7c3b01ff}},	//   õige_, _gomà_, _bafe, rlur,
   {{0x44201757,0x69ca7e21,0x7c3b7e22,0xdce8013a}},	//   zni_, _cafe, slur, _cedē,
   {{0xd7dd0429,0x44207e23,0x4432067f,0x7c3b7e24}},	//   यांच, yni_, yoy_, plur,
   {{0x2d877e25,0x5b15519c,0x2b9a00d0,0x24b90033}},	//   lane_, _имет, rücü_, ুমাহ,
   {{0x442002dd,0x25de00a1,0x2d8700af,0x00000000}},	//   vni_, खाली_, oane_, --,
   {{0xa7fd01c2,0x7bcb7e26,0x44207e27,0x2d877e28}},	//   qqın, _hagu, wni_, nane_,
   {{0x44327e29,0x59a60302,0x7bcb7e2a,0x2aab01b4}},	//   toy_, _खातर, _kagu, løb_,
   {{0x2d877e2b,0x44207e2c,0x6b82043f,0x61ee6968}},	//   hane_, uni_, _xeog, _sobl,
   {{0x61ee7e2d,0x2d870ba4,0x660600c3,0x6b84007c}},	// [85c0] _pobl, kane_, _аппа, _õige,
   {{0x7bcb03cb,0x44327e2e,0x60d50035,0x6836002a}},	//   _lagu, soy_, _brzm, cádr,
   {{0x44207e2f,0x2d870fe2,0x44327e30,0x942603f5}},	//   pni_, dane_, poy_, _амне,
   {{0x7bcb7e31,0x4420163e,0x2bd108b0,0xcbbc0033}},	//   _nagu, qni_, _दोला, _আচ্ছ,
   {{0xa2c10299,0x2d877e32,0xe7aa0534,0x61ee4808}},	//   रौद्, fane_, _कानप, _tobl,
   {{0xb1461906,0x2d877e33,0x63a47e34,0x998c00b8}},	//   _англ, gane_, lgin, vodů_,
   {{0x6abc2afe,0x7bcb7e35,0xc0e30812,0x69ca7e36}},	//   ्ट्र, _bagu, _корк, _rafe,
   {{0x63a47e37,0x25ad044d,0x69ca0122,0x7bcb1c5b}},	//   ngin, đeli_, _safe, _cagu,
   {{0x5a340b32,0xf4130bed,0x7bcb008a,0x67ff00da}},	//   лнит, יפה_, _dagu, _bëjn,
   {{0x2d877e38,0x683d7e39,0x7c2d1851,0x2ba7021a}},	//   cane_, médi, čara, _गाथा,
   {{0x7bcb7e3a,0x683d00a2,0x7983099e,0x00000000}},	//   _fagu, lédi, _denw, --,
   {{0x7bcb7e3b,0x79830298,0x63a401e4,0x00000000}},	//   _gagu, _eenw, jgin, --,
   {{0x44d10755,0x69ca59ed,0x8a061e92,0x79833889}},	//   _są_, _tafe, _изде, _fenw,
   {{0x7bc00006,0x7bcb7e3c,0x79837e3d,0x63a47e3e}},	//   lemu, _zagu, _genw, egin,
   {{0x6d5c016f,0x7bcb0b69,0x8cd5021a,0xa7fd00a8}},	//   _úrad, _yagu, भियो, lqım,
   {{0x7bc006b3,0x798800e9,0x63a47e3f,0xee1f00b4}},	//   nemu, ladw, ggin, _बद्ध_,
   {{0x2d877e40,0x36d57e41,0x81ac0033,0x3869012e}},	// [85d0] yane_, _сопр, কজন_, _čari_,
   {{0x44d11648,0x7bc07e42,0x26c9022f,0x798800e9}},	//   _tą_, hemu, _isao_, nadw,
   {{0x7bc07e43,0x21640eee,0xd7aa7e44,0xe7aa0355}},	//   kemu, ртуг, _कामच, _कामप,
   {{0xf8b30779,0x2d877e45,0x3f84025c,0x7bc05112}},	//   ישע_, wane_, _cemu_, jemu,
   {{0x539a0052,0x2d870ba4,0x8f3401c8,0x645d00a7}},	//   _אירו, tane_, аецц, _iisi,
   {{0x7bcb7e46,0x3dcc001e,0x645d0054,0x798800e7}},	//   _sagu, _cadw_, _hisi, jadw,
   {{0x2d877e47,0x645d7e48,0xdd8e00bc,0x7988016e}},	//   rane_, _kisi, سوي_, dadw,
   {{0x2bda00a1,0x645d7e49,0x7bc07e4a,0x5ac97e4b}},	//   भागा, _jisi, gemu, елим_,
   {{0x645d0c2f,0x2d870053,0x798300e9,0x5f3800af}},	//   _misi, pane_, _penw, _аптя_,
   {{0x3dcc001e,0x63a47e4c,0x7bcb4ab3,0x2d870055}},	//   _gadw_, zgin, _wagu, qane_,
   {{0x7bcb7e4d,0x7bc07e4e,0x63a47e4f,0xa2ca1ab2}},	//   _tagu, bemu, ygin, _सैन्,
   {{0x2d850687,0x645d7e50,0x7bcb034d,0x6aa004fb}},	//   _hele_, _nisi, _uagu, bumf,
   {{0xa3e700dc,0x2d85382a,0xf4090033,0x63a4027b}},	//   पान_, _kele_, রচার_, vgin,
   {{0x64a605e8,0x645d7e51,0x2d857e52,0xd83900cb}},	//   лага, _aisi, _jele_, ruča_,
   {{0x69c145c9,0x645d7e53,0x5e5602b5,0x63a40345}},	//   mele, _bisi, טישע_, tgin,
   {{0x69c17e54,0x63a4010b,0x645d7e55,0xd8397e56}},	//   lele, ugin, _cisi, puča_,
   {{0xe2977e57,0x645d69c3,0x63a408a3,0x628d043d}},	// [85e0] лат_, _disi, rgin, gsao,
   {{0x645d7e58,0x69c17e59,0x44393f9a,0x2d851c4b}},	//   _eisi, nele, _eks_, _nele_,
   {{0x645d7e5a,0x34aa4a2f,0x5a160070,0x27e000cd}},	//   _fisi, _явно_, נקען_, _knin_,
   {{0x69c17e5b,0x645d7e5c,0xf3f10019,0x443963b6}},	//   hele, _gisi, ệt_, _gks_,
   {{0x69c17e5d,0x2d857e5e,0x877b02b5,0x765e24ed}},	//   kele, _bele_, גאני, _kipy,
   {{0x2d8509eb,0x69c17e5f,0x645d28f7,0x765e0054}},	//   _cele_, jele, _zisi, _jipy,
   {{0x2d857e60,0x69c127df,0x3f847e61,0x7bc07e62}},	//   _dele_, dele, _temu_, temu,
   {{0x683d7e63,0x29180037,0xab5d0035,0x9bf4002d}},	//   pédi, úram_, zeże, рзич,
   {{0x69c17e64,0x7bc07e65,0x20047e66,0xcff700a5}},	//   fele, remu, _ilmi_, _עצמה_,
   {{0x69c1245b,0x7bc01d11,0xdcfa002d,0x2d857e67}},	//   gele, semu, _cetă, _gele_,
   {{0x7988001e,0x7bc0022e,0x27e00024,0x6e3a7e68}},	//   radw, pemu, _bnin_, _iktb,
   {{0x2d857e69,0xa8350274,0x00000000,0x00000000}},	//   _zele_, ремљ, --, --,
   {{0x69c17e6a,0xcaf60125,0xa7fd00a8,0x645d7e6b}},	//   bele, _حساب, qqım, _risi,
   {{0x69c17e6c,0x645d7e6d,0x682800d0,0x75eb027d}},	//   cele, _sisi, rıda, _yüzy,
   {{0xe4e41958,0x765e00e9,0xab5d003c,0xc8a80e96}},	//   бітн, _dipy, reże, _कमिट,
   {{0x33753379,0x645d6476,0xe78703fa,0xddc20506}},	//   ргар, _qisi, _суко, jpož,
   {{0x645d7e6e,0x5215110a,0x65956b47,0x20070031}},	// [85f0] _visi, адат, _капу, ënim_,
   {{0x94750a86,0xf8a80324,0x91e40274,0x645d7e6f}},	//   _نگرا, _कमाय, бође, _wisi,
   {{0x2d85142f,0x645d1e85,0x2a66010d,0x443946a6}},	//   _rele_, _tisi, _luob_, _tks_,
   {{0x69c17e70,0x2d853f84,0x628f7e71,0x25ad0506}},	//   zele, _sele_, _tvco, đelu_,
   {{0x69c126ad,0x2d857e72,0xdee50eee,0x66f70d1f}},	//   yele, _pele_, роли, ुनिक_,
   {{0x2bda08b6,0x20040095,0x69c11e6e,0xb882031d}},	//   _मोबा, _elmi_, xele, _číns,
   {{0x69c17e73,0x2d857e74,0x06380070,0xa2cd073f}},	//   vele, _vele_, אנגט_, सिक्,
   {{0x67ff01f4,0xd6f71782,0x2d8500e5,0x753a02b1}},	//   _bëjm, ुनाथ_, _wele_, ützi,
   {{0x69c17e75,0x80040c46,0xbda702e7,0x6d480065}},	//   tele, _учре, _محاو, _ezda,
   {{0x7c870df6,0x2ba702cb,0x27e00484,0x2ef408ae}},	//   _буде, _गावा, _snin_, _узур,
   {{0xd9450f94,0x69c17e76,0xb4c4007c,0x7cdc0395}},	//   рени, rele, _एने_, _cără,
   {{0x69c145c9,0x00000000,0x00000000,0x00000000}},	//   sele, --, --, --,
   {{0x69c17e77,0x624966f6,0x248601ba,0x09e52b65}},	//   pele, _džoz, _ňom_, _волн,
   {{0x78a136a2,0xcaf4006c,0x7cdc0139,0xd8390207}},	//   pulv, _دسمب, _fără, vrče_,
   {{0x7afb00a8,0x18a57e78,0x765e002f,0xd939016b}},	//   lyut, _тайм, _vipy, _בײַש,
   {{0x3ced1ee0,0x7ae9008c,0xd8391b97,0x00000000}},	//   _अपने_, oxet, trče_, --,
   {{0x883b00a5,0x7afb7e79,0x43757e7a,0xddc20009}},	// [8600] _בתקו, nyut, суст, vpož,
   {{0xe1ff7e7b,0xb21b177c,0x93597e7c,0x9f4d0392}},	//   _stór_, _svær, урсу_, _lleó_,
   {{0x1da905f8,0x661c7e7d,0x6f6603fa,0x04460421}},	//   च्छत, mirk, авез, _венн,
   {{0x7a3d02d0,0x7afb0cca,0x661c7e7e,0x2c6a009e}},	//   pètw, kyut, lirk, _rùd_,
   {{0xdfcf004f,0x683d0248,0xddc90009,0xe29706d8}},	//   بين_, cédu, _steš, _кая_,
   {{0x661c7e7f,0x27350023,0xd0b300a8,0xa3e7021a}},	//   nirk, ụng_, hşət, पाथ_,
   {{0x6da309ea,0x6ce60044,0x7f49310f,0xb21b01b4}},	//   ција, ріле, _ezeq, _tvær,
   {{0x8fa356b1,0x661c0f1a,0x20040159,0x6d480097}},	//   _масе, hirk, _ulmi_, _vzda,
   {{0x15f80266,0x6da63494,0xa3e705f7,0x7cdc0395}},	//   ुसार_, _виза, पात_, _sără,
   {{0x99662ecf,0x3860009e,0x7cdc00af,0x00000000}},	//   штил, _aiir_, _pără, --,
   {{0x661c7e80,0x6d4817d1,0x88597e81,0xddc97e82}},	//   dirk, _uzda, лиос_, _uteš,
   {{0x290c7e83,0x7afb7e84,0xeb972503,0x00000000}},	//   rzda_, byut, _виц_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x18660202,0x661c7e85,0x77640065,0xfa3300f8}},	//   _књиг, girk, _egix, _ورود,
   {{0x3860462c,0xe65402ce,0x66050187,0xb894004f}},	//   _fiir_, івсь, _vlhk, _البع,
   {{0x672d006d,0x539800d4,0xd378748e,0xab5d0035}},	//   _txaj, ився_, ичу_, leża,
   {{0x24580086,0xe16703fa,0x661c0984,0x21671052}},	// [8610] рать_, ађен, birk, атег,
   {{0x661c0309,0x3d1700ab,0x683d00a2,0x00000000}},	//   cirk, _भइले_, rédu, --,
   {{0x92e70083,0x35f800f8,0x62800055,0x3e6b0044}},	//   বনে_, _خريد_, _çmon, _søt_,
   {{0x4e950037,0xf1e00761,0xa9e3021a,0x00000000}},	//   مشتر, नाउन, _कच्छ_, --,
   {{0x645a7e86,0x2bbc05f8,0xc25700d1,0x1de2074f}},	//   ïtie, ्जना, _نخست, पांत,
   {{0xee3802ce,0x72050037,0x442b7e87,0x00000000}},	//   ані_, _اوسم, _hjc_, --,
   {{0x93fb0099,0xa194002d,0x00000000,0x00000000}},	//   _एकाच_, _фасч, --, --,
   {{0x7afb611d,0x661c7e88,0x5fcf007c,0x7ae97e89}},	//   tyut, zirk, _सोचल, txet,
   {{0x7d0600a8,0xb5fb0042,0x442b00a2,0x201d7e8a}},	//   _əksi, bpáx, _mjc_, miwi_,
   {{0x7ae901dd,0x3ebf0159,0x65650159,0x7afb011e}},	//   rxet, _iput_, _nghh, ryut,
   {{0x661c7e8b,0x7afb0159,0x61f50067,0x386000be}},	//   virk, syut, _mozl, _piir_,
   {{0x68fc0a8a,0x661c01ae,0x7e690054,0x9f5f0176}},	//   ørda, wirk, _kuep, _lluí_,
   {{0x661c2a73,0x7e610086,0x00000000,0x00000000}},	//   tirk, _kilp, --, --,
   {{0x3860012f,0xbb3a0070,0x6d417e8c,0x99850037}},	//   _wiir_, _געני, _kyla, _الثو,
   {{0x661c7e8d,0x644f0211,0x201d7e8e,0x442b2a4b}},	//   rirk, _bhci, kiwi_, _bjc_,
   {{0x644f004e,0x317f0009,0xf3f10023,0x661c7e8f}},	//   _chci, _đuza_, ệp_, sirk,
   {{0x661c7e90,0x63b60297,0x38b17e91,0x644f009e}},	// [8620] pirk, rfyn, lár_, _dhci,
   {{0xe3b201ca,0x6d41027d,0x2928012e,0x442b0027}},	//   _کرد_, _oyla, štaš_, _ejc_,
   {{0x38b17e92,0x6d417e93,0x7c2d008b,0x644f0211}},	//   nár_, _nyla, čarj, _fhci,
   {{0xaab704bc,0xd12f7e94,0x44d8053d,0x7e61009e}},	//   _अहंक, رمن_, _ič_, _ailp,
   {{0x6d4104d4,0x248d0029,0x7e6150e8,0x38b13441}},	//   _ayla, ņemt_, _bilp, hár_,
   {{0x44d80311,0x644428e5,0x6d417e95,0x38b162a8}},	//   _kč_, llii, _byla, kár_,
   {{0x38b17e96,0xdd9901e0,0x64444466,0xa0a3052a}},	//   jár_, рші_, olii, _нард,
   {{0x6d410297,0x7bf80dbf,0x7e690036,0x8aa622a9}},	//   _dyla, рнир_, _fuep, брод,
   {{0x44d802e9,0x7e690069,0x7e61081b,0xaf061474}},	//   _lč_, _guep, _filp, _упал,
   {{0x98b80370,0x2fc626c9,0x3ea67e97,0x7e6100ee}},	//   алот_, leog_, muot_, _gilp,
   {{0xeb9a10bb,0x2cbe012f,0xdd8f03fc,0x26c00138}},	//   _бие_, _uptd_, _سون_, _apio_,
   {{0xfaa601c8,0x2fc60079,0x394200ea,0x7e612c67}},	//   _гадо, neog_, āks_, _zilp,
   {{0xab5d004e,0xa3e73933,0xe7aa0066,0xdc3b0070}},	//   leżn, पास_, _कारप, _געאר,
   {{0x86270fa4,0x6e240037,0x442b53d1,0xf2ce0033}},	//   сьме, éibh, _sjc_, রমাণ,
   {{0x61f51b66,0x9f440443,0x6d410337,0x00000000}},	//   _rozl, _comú_, _xyla, --,
   {{0x937900af,0x93f600a8,0x44d80260,0x61f50448}},	//   рбат_, _şərə, _dč_, _sozl,
   {{0x7a3d43b0,0xadfa0084,0xe3b00037,0xa3ba007c}},	// [8630] mètr, ्सान_, عرف_, _आउर_,
   {{0x44d80c1f,0x32074cbf,0x2167004b,0x6565010d}},	//   _fč_, óny_, стаг, _ughh,
   {{0x201d0858,0xe0e70033,0x7e690118,0x5f79026e}},	//   tiwi_, পন্ন, _suep, لماس_,
   {{0x64440211,0x7c2d15d7,0x7e611482,0x6d417e98}},	//   clii, čark, _silp, _ryla,
   {{0x44297e99,0x8d65172a,0x38b14b1d,0x7e690453}},	//   mna_, овле, zár_, _quep,
   {{0x443b7e9a,0xdc9908ce,0x201d0054,0xa3e729ce}},	//   loq_, атиш_, siwi_, पाव_,
   {{0x2bda0b57,0xcc8603fe,0xfbda131c,0xd7aa074f}},	//   _मोहा, обще_, _मोहम, _कालच,
   {{0x44297e9b,0x251c0070,0x6b80011e,0x6b8400be}},	//   nna_, טווא, gbmg, _õigl,
   {{0xab294640,0x7e611b99,0x34c607b5,0x6d417e9c}},	//   ропа_, _tilp, _लन्द, _wyla,
   {{0x44297e9d,0x38b17e9e,0x3ea00037,0x00000000}},	//   hna_, tár_, áite_, --,
   {{0x442909bd,0x290353b1,0x443b012f,0xd7ea002d}},	//   kna_, ája_, koq_, амне_,
   {{0x3ea07e9f,0x3f8f7ea0,0xf0920100,0x2ca77d65}},	//   šite_, nagu_, ונט_, mund_,
   {{0x34c2021a,0x7c3b7ea1,0x2ca77ea2,0x38b118fa}},	//   शब्द, mour, lund_, sár_,
   {{0x44297ea3,0x386a0037,0x38b16415,0x6b8b7ea4}},	//   ena_, úirí_, pár_, _hegg,
   {{0x44297ea5,0x7c297ea6,0x3f8f01d7,0xdb190107}},	//   fna_, oner, kagu_, _gawò,
   {{0x44297ea7,0xf1ac0632,0x6836016f,0x24075a04}},	//   gna_, _चाहन, hádz, онси_,
   {{0x2ca77ea8,0x6b8b00b5,0xdb1100f7,0x44d802d0}},	// [8640] hund_, _megg, éfèr, _wč_,
   {{0x44297ea9,0x6b8b7eaa,0x7c3b7ac0,0x7ae40037}},	//   ana_, _legg, hour, _áite,
   {{0x44290a0b,0x7c3b02e9,0x63af03ad,0x644400ab}},	//   bna_, kour, ännö, plii,
   {{0x7c3b1010,0x44297eab,0x2ca70553,0xb4c80099}},	//   jour, cna_, dund_, ोटी_,
   {{0x44207eac,0xa3e7131c,0x7c3b453e,0x7c297ead}},	//   mii_, पार_, dour, dner,
   {{0x44207eae,0xa6e3008a,0x2ca77eaf,0x7bdc0228}},	//   lii_, æðis, fund_, ērum,
   {{0x6b8b7eb0,0x798a4d80,0x61431400,0x2d8e0be7}},	//   _begg, _refw, _жера, rafe_,
   {{0x44207eb1,0x2d8e7eb2,0x7c3b175d,0xa06701f1}},	//   nii_, safe_, gour, _фата_,
   {{0x9c8701ba,0x6b8b7eb3,0x00000000,0x00000000}},	//   _počú, _degg, --, --,
   {{0x44207eb4,0x44291349,0xdb190c1f,0x2ca77eb5}},	//   hii_, zna_, _pawò, bund_,
   {{0x44297eb6,0x44207eb7,0xd839011c,0x2ca77eb8}},	//   yna_, kii_, luči_, cund_,
   {{0x442952e0,0x7c3b20ac,0x44207eb9,0x2d8c7eba}},	//   xna_, cour, jii_, _hede_,
   {{0x44290a0b,0x77640133,0x2d8c7ebb,0xcf9300a5}},	//   vna_, държ, _kede_, וטר_,
   {{0x44297082,0x6b8b0a75,0x2d8c7ebc,0x00000000}},	//   wna_, _zegg, _jede_, --,
   {{0x442904c3,0x69c87ebd,0xa3e74e90,0x44207ebe}},	//   tna_, mede, पाल_, fii_,
   {{0x4420699c,0x69c87ebf,0x4429750a,0x2d8c55b8}},	//   gii_, lede, una_, _lede_,
   {{0x442903c1,0x443b035f,0xd83904c3,0xa2db04bc}},	// [8650] rna_, roq_, juči_, निध्,
   {{0x69c87ec0,0xdb1102e1,0x2d8c7ec1,0x7c2d0bc6}},	//   nede, éfér, _nede_, čari,
   {{0x44207ec2,0x44297ec3,0x6836016f,0x7c297ec4}},	//   bii_, pna_, vádz, yner,
   {{0x44207ec5,0x69c87ec6,0x4429007a,0x98b30254}},	//   cii_, hede, qna_, žeći_,
   {{0x6b8b7ec7,0x3f8f79ff,0x69c87ec8,0x63ad7ec9}},	//   _regg, ragu_, kede, mgan,
   {{0x69c87eca,0x63ad3d83,0x6b8b7ecb,0x2ca77ecc}},	//   jede, lgan, _segg, tund_,
   {{0x7c3b7ecd,0xeb9919fa,0x7c297ece,0x69c87ecf}},	//   tour, бий_, tner, dede,
   {{0x63ad7ed0,0x2ca77ed1,0x7c297ed2,0xae1d0066}},	//   ngan, rund_, uner, _भगवन_,
   {{0x2d8c7ed3,0x2ca77966,0x7c3b00af,0x6b8b2129}},	//   _fede_, sund_, rour, _vegg,
   {{0x6b8b59ed,0x2d8c0703,0x7e7b7ed4,0x44207ed5}},	//   _wegg, _gede_, _itup, zii_,
   {{0x9f440359,0x63ad28c5,0x44202a8e,0x394502d6}},	//   _anmè_, kgan, yii_, яног,
   {{0xb8f3009a,0xdd8f006c,0xdcfa06fe,0x00000000}},	//   _सई_, _سوچ_, _letě, --,
   {{0x44200395,0x63ad0c61,0x1ae52a63,0x00000000}},	//   vii_, dgan, _холм, --,
   {{0x9c8202c6,0x44207ed6,0x7bc919c1,0x2d8c01a3}},	//   ščen, wii_, leeu, _xede_,
   {{0x442009eb,0xd9421c1b,0x00000000,0x00000000}},	//   tii_, _пеши, --, --,
   {{0x63ad7ed7,0x68fc013c,0x61e71872,0x7e7b0207}},	//   ggan, ärde, _anjl, _otup,
   {{0x44207ed8,0x7e7b0027,0x21a6002d,0xd3874c81}},	// [8660] rii_, _ntup, зизм, яйте_,
   {{0x44207ed9,0x63ad7eda,0xd8390124,0x9c7c023a}},	//   sii_, agan, vuči_, _hrče,
   {{0x2d8c7edb,0x44207edc,0x9c7c03c9,0xb5fb00a5}},	//   _rede_, pii_, _krče, _הליכ,
   {{0x69c87edd,0x35b20b4d,0xaabd0067,0x00000000}},	//   zede, _जाड़, ्बाक, --,
   {{0xf8a8051d,0x66fe02e4,0x2d8c7ede,0xef16007c}},	//   _कम्प, ॉनिक_, _pede_, _देखऽ_,
   {{0xd839011c,0x2c710079,0x00000000,0x00000000}},	//   ruči_, _bád_, --, --,
   {{0x2d8c7edf,0xe81d07b5,0x7e7b0421,0xa3e004aa}},	//   _vede_, _पगला_, _etup, _दफा_,
   {{0x8aa67ee0,0x69c87ee1,0x8cbd0035,0x00000000}},	//   прод, wede, _शहरो, --,
   {{0x69c80d51,0x62967ee2,0x7e7b0027,0x8f00010b}},	//   tede, nsyo, _gtup, кiх_,
   {{0x9c7c0009,0x63ad7ee3,0x2c717422,0x20060065}},	//   _arče, zgan, _fád_, lkoi_,
   {{0x63ad7ee4,0xf8ad1328,0x28f801f1,0xb4c80067}},	//   ygan, لکي_, цень_, ोटो_,
   {{0x62967ee5,0x69c87ee6,0x4c160416,0x661e023a}},	//   ksyo, sede, _عباس, _ampk,
   {{0x569407e5,0x78a808c8,0x20060159,0x63ad7ee7}},	//   наят, sudv, ikoi_, vgan,
   {{0xa2db06bb,0x7afd7ee8,0x00000000,0x00000000}},	//   निस्, äste, --, --,
   {{0x63ad7ee9,0x19bb0122,0x49bb0397,0x9c7c00fe}},	//   tgan, _המוב, _המוס, _frče,
   {{0x9c7c00cb,0x63ad7eea,0x2be50067,0x00000000}},	//   _grče, ugan, काएं_, --,
   {{0x63ad7eeb,0x95cb1edd,0x979c00a5,0x27e97eec}},	// [8670] rgan, _луна_, _השחק, _inan_,
   {{0x20c8004e,0x63ad7eed,0xb0c80a44,0x386e0e4c}},	//   रबंध, sgan, रबंग, _kufr_,
   {{0x7e7b15d8,0x7fd501e0,0x7e7c008b,0x83f94ae8}},	//   _stup, ділі, _črpa, _денс_,
   {{0x2c712eef,0x00000000,0x00000000,0x00000000}},	//   _rád_, --, --, --,
   {{0xdcf80228,0x0ef900b4,0x2c7100ee,0x00000000}},	//   kavē, ्नेस_, _sád_, --,
   {{0x6da57eee,0x2c710097,0x9f5f0176,0x273c00e2}},	//   фика, _pád_, _lluç_, ửng_,
   {{0xed560370,0x27e97eef,0x55780070,0xe81000b8}},	//   мош_, _onan_, לעגן_, ासमा_,
   {{0x1b1e00c8,0x7ae400e1,0xdfd40421,0x00000000}},	//   _পড়ে_, _šita, _посы, --,
   {{0x7bc91e7e,0xa7fd00a8,0x7e7b08c7,0x3ef800af}},	//   reeu, yqır, _utup, _ентэ_,
   {{0x27e902b3,0x9c7c13a6,0xf2d40070,0xe8100026}},	//   _anan_, _srče, געץ_, ासभा_,
   {{0x07a60ed2,0x200d2069,0x6aa90036,0xc7a67ef0}},	//   манн, _klei_, suef, минк,
   {{0x27e9009e,0x62962505,0xc5f8018d,0x00000000}},	//   _cnan_, ysyo, ुस्य_, --,
   {{0x6aa900f6,0xa3e714eb,0x27e901ed,0xd83901a0}},	//   quef, पाई_, _dnan_, juču_,
   {{0x200d12c3,0x69250274,0x27e90260,0xf1ac0761}},	//   _llei_, _омла, _enan_, _चाइन,
   {{0x9c7c0169,0xa6c900b5,0x00000000,0x00000000}},	//   _trče, _ہوٹل_, --, --,
   {{0x9c7c7ef1,0x6e230008,0xa41c0033,0x23d5002d}},	//   _urče, hinb, থক্য_, нцур,
   {{0xe1fa7ef2,0xa2db720e,0x04433869,0x60c90009}},	// [8680] ога_, निष्, тетн, _ćema,
   {{0x27e97ef3,0x62961c3f,0x7d037ef4,0x6e2d000d}},	//   _znan_, rsyo, kyns, éabl,
   {{0x62965ab9,0x04030033,0x6e230b77,0x200d0044}},	//   ssyo, রোধী_, dinb, _blei_,
   {{0xa2db1729,0x62967ef5,0x200d0160,0x39470b88}},	//   निश्, psyo, _clei_, _myns_,
   {{0xee3a15ae,0x200601f4,0xf1aa00d1,0x00000000}},	//   онд_, rkoi_, _واسه_, --,
   {{0xa2db09a8,0x6e2359db,0x00000000,0x00000000}},	//   निर्, ginb, --, --,
   {{0xd5ed0023,0x01630a7c,0x00000000,0x00000000}},	//   _quả, _акро, --, --,
   {{0x61fc7ef6,0x8af80370,0x92c20033,0x00000000}},	//   _horl, знис_, ্মী_, --,
   {{0x61fc1fbb,0x6e231511,0x3f8629e0,0xfbcf0413}},	//   _korl, binb, mbou_, شتي_,
   {{0x4efb00a5,0xc33332e3,0x39470523,0x27e9009e}},	//   _והמו, כוח_, _byns_, _snan_,
   {{0x61fc7ef7,0xe7eb0fff,0x27e90107,0xd9170328}},	//   _morl, टाला_, _pnan_, дья_,
   {{0x3f867ef8,0x00000000,0x00000000,0x00000000}},	//   nbou_, --, --, --,
   {{0x61fc1516,0x5bbc0af9,0xdb2400c3,0x7bc20069}},	//   _oorl, ्जीव, äräy, _ibou,
   {{0x61fc7ef9,0x8a0302fb,0x7ae20051,0x394708c8}},	//   _norl, _изче, _irot, _fyns_,
   {{0x92bb0b52,0x443f01a5,0x69d80a21,0x387c0009}},	//   _আছে_, _ưu_, _iave, _utvr_,
   {{0x27e92326,0x69da7efa,0x69d87efb,0x7ae21aa5}},	//   _unan_, ldte, _have, _krot,
   {{0x69d803ad,0x61fc7efc,0x3f860097,0x38b87efd}},	// [8690] _kave, _borl, dbou_, lér_,
   {{0x69da4793,0xf3ff01a5,0x69d87efe,0xd83900f4}},	//   ndte, _giãn_, _jave, ruču_,
   {{0x69d87eff,0x61fc756e,0x6d4803e4,0x7bc20355}},	//   _mave, _dorl, _nyda, _obou,
   {{0x69d810db,0x7ae201a3,0x2379021d,0xb21b0a8a}},	//   _lave, _orot, _ufsj_, _stæd,
   {{0x9f40064b,0x61fc7f00,0x3d170299,0x6d48045e}},	//   ðið_, _forl, _भेजे_, _ayda,
   {{0x7bc201f3,0xc3320122,0x61fc7f01,0x7cd30095}},	//   _abou, _תוך_, _gorl, _hərə,
   {{0xeb997f02,0x7ae25c48,0x8c4508ce,0x6d4800e5}},	//   пий_, _arot, неке, _cyda,
   {{0x69da7f03,0x61fc008f,0x7ae27f04,0x200d002d}},	//   edte, _zorl, _brot, _ulei_,
   {{0x7ae27f05,0x39470542,0x0e350352,0x34cb0127}},	//   _crot, _syns_, _знаю, ाबुद,
   {{0xa2a743fd,0x9c82068b,0x7ae27f06,0x7c870012}},	//   _चिन्, ščan, _drot, _жуде,
   {{0xd8260bd7,0x69d87f07,0x7ae27f08,0xb4be0006}},	//   едни, _dave, _erot, _इहे_,
   {{0x7ae27f09,0x7c2d1851,0xb6a60370,0x69d84e8b}},	//   _frot, čars, нимл, _eave,
   {{0x7ae27f0a,0x69d87f0b,0x386905b9,0x00000000}},	//   _grot, _fave, _diar_, --,
   {{0x69d8508c,0x9c7c1321,0x6d480345,0x7bdb0051}},	//   _gave, _hrča, _yyda, lduu,
   {{0x7bd97f0c,0x2ab902d0,0xddc90bc6,0x38690138}},	//   _kawu, lèb_, _otež, _fiar_,
   {{0x69d87f0d,0xe73a0086,0xb60200b8,0x7bdb018e}},	//   _zave, _ней_, _žádo, nduu,
   {{0x7cd30095,0x3f860187,0x7bd90f42,0x52aa02fb}},	// [86a0] _dərə, vbou_, _mawu, явам_,
   {{0x7bd97f0e,0x386900af,0x1dae00b8,0x715a1b81}},	//   _lawu, _ziar_, _घाइत, прес_,
   {{0xa3ea2e76,0x61fc01ae,0x4fc6136c,0x92c20033}},	//   _една_, _vorl, есла, ্মে_,
   {{0xfbae1e79,0x61fc7f0f,0x68fc008c,0xa3ba043b}},	//   _टाइम, _worl, ørdi, _आउट_,
   {{0x6d480ab8,0x7bdb001c,0x3f867f10,0x69c30116}},	//   _syda, dduu, rbou_, _obne,
   {{0x7ae20031,0x7cd300a8,0x29050746,0x69c30024}},	//   _rrot, _zərə, kyla_, _nbne,
   {{0x8fa60a93,0x44226096,0xb4be007c,0x7bd91643}},	//   _паве, _kmk_, _इहो_, _bawu,
   {{0x3ea625e5,0x6d481840,0x20557f11,0x961d114e}},	//   prot_, _vyda, _атур, _नष्ट_,
   {{0x69d87f12,0x6d48006a,0x44227f13,0x7bd92ada}},	//   _pave, _wyda, _mmk_, _dawu,
   {{0x38691093,0x7afd7aff,0x38b87b10,0x44227f14}},	//   _siar_, ästa, tér_, _lmk_,
   {{0x7ae27f15,0x0b8a0d36,0x69d802c4,0xa9340009}},	//   _wrot, _если_, _vave, тенш,
   {{0x7ae27f16,0x69d800a5,0x68e30506,0x9c7c02a7}},	//   _trot, _wave, _drnd, _grča,
   {{0x69d85a89,0x7c227f17,0x38b805f6,0x7ae27f18}},	//   _tave, _imor, sér_, _urot,
   {{0x8cd70fcf,0x290500b8,0x7cd300a8,0x6446018e}},	//   _मनमो, byla_, _sərə, _akki,
   {{0x248d0a78,0x7bd91939,0x53e70036,0xf8a400ab}},	//   ćemo_, _yawu, нцаа, _खटिय,
   {{0x60c7012f,0x7c22035f,0x00000000,0x00000000}},	//   _rpjm, _jmor, --, --,
   {{0xfbc21cce,0xf1a73e89,0x2bc200a1,0x6b840006}},	// [86b0] व्यम, ерен, व्या, _õigu,
   {{0xa2a708b0,0xddc9030a,0x64467f19,0x28d5012f}},	//   _चिठ्, _stež, _ekki, धिचि,
   {{0x7cd30669,0x20070279,0x7c227f1a,0x2ee40176}},	//   _tərə, ênio_, _omor, _armf_,
   {{0xf8b30070,0x442201ed,0x98bc0409,0x00000000}},	//   טשע_, _gmk_, _gyvą_, --,
   {{0x628301cc,0x644d7f1b,0x7bd900d1,0x00000000}},	//   ćnos, mlai, _rawu, --,
   {{0x62353275,0x2ab90c1f,0x6250007c,0x9c7c0254}},	//   _регу, vèb_, näol, _srča,
   {{0x644d7f1c,0xdce1004e,0x7bd97f1d,0x25d800a5}},	//   olai, _oglą, _pawu, גוון_,
   {{0x644d7f1e,0x8ca2045c,0x26c9042a,0x6ed500b4}},	//   nlai, _गिरो, _opao_, _मैथु,
   {{0x7bdb7f1f,0x68e300f4,0x00000000,0x00000000}},	//   rduu, _srnd, --, --,
   {{0x644d066a,0x7c227f20,0x6abb7f21,0x7bd94296}},	//   hlai, _emor, rtuf, _wawu,
   {{0x644d7f22,0x9c7c0254,0x6abb7f23,0x6bd60118}},	//   klai, _trča, stuf, رویس_,
   {{0x9c7c0252,0x00000000,0x00000000,0x00000000}},	//   _krčn, --, --, --,
   {{0x9aa40ca8,0x2bda0b7a,0x6b89317e,0x44227f24}},	//   _ممنو, _मोटा, mbeg, _rmk_,
   {{0x44227f25,0xeb0d04bc,0x7c224962,0x644d7f26}},	//   _smk_, िनीत_, _zmor, elai,
   {{0x6aa90c9c,0x644d0098,0x629d03d0,0x44227f27}},	//   lref, flai, _avso, _pmk_,
   {{0x644d175e,0x69c17f28,0x6b897f29,0x00000000}},	//   glai, lfle, nbeg, --,
   {{0xe2977f2a,0x490901c0,0x23273aee,0x00000000}},	// [86c0] кат_, ानको_, воти_, --,
   {{0x644d687b,0x175700a5,0xd179010b,0x6aa900f6}},	//   alai, _בספר_, есці_, iref,
   {{0x644d7f2b,0x6aa900e5,0x44227f2c,0x62845c35}},	//   blai, href, _tmk_, spio,
   {{0x644d01f8,0x62845024,0xd83900cd,0x32110345}},	//   clai, ppio, trči_, _elzy_,
   {{0x7ed3004f,0x37dc0083,0x443212ad,0x00000000}},	//   لزوا, ধাপর, mny_, --,
   {{0xa2a710aa,0x44320f86,0x6aa97f2d,0x7c227f2e}},	//   _चित्, lny_, dref, _smor,
   {{0x443206bb,0x61ee376a,0x6aa9290f,0x7c22023c}},	//   ony_, _inbl, eref, _pmor,
   {{0x44327f2f,0xa3b62893,0x2cf205e7,0x6b891167}},	//   nny_, च्च_, _अपील_, gbeg,
   {{0x4432614b,0xc986081b,0x6aa904da,0x8cd20026}},	//   iny_, куни, gref, _भैरो,
   {{0x443247da,0x2a6a00b5,0xd8f801e0,0x69c10051}},	//   hny_, öbb_, еної_, gfle,
   {{0x44320d14,0x644d7f30,0x26c900f4,0x38c80919}},	//   kny_, ylai, _spao_, رادی_,
   {{0x7c227f31,0x27ed1a71,0x44323d3f,0x27ff00fb}},	//   _umor, ñen_, jny_, ðun_,
   {{0x443215b3,0xa3b605dc,0x61ee0298,0x34cb0d1f}},	//   dny_, च्छ_, _onbl, ाब्द,
   {{0xb8821544,0x8ca9021a,0x27ed00fd,0x00000000}},	//   üíst, _टिमो, űen_, --,
   {{0x65947f32,0x1dc4021a,0x644d2c40,0x6e2d00a2}},	//   расу, ल्यत, tlai, éabi,
   {{0x44327f33,0x644d0ba0,0x32110097,0x61ee7f34}},	//   gny_, ulai, _slzy_, _anbl,
   {{0x644d7f35,0x26c9011c,0x2fcf0bd1,0x36051301}},	// [86d0] rlai, _upao_, vegg_, _موظف,
   {{0x44327f36,0x644d7f37,0x28a906fe,0x7cca00a8}},	//   any_, slai, _किमि, _gərg,
   {{0x2608004e,0x44320f86,0x644d00a5,0x48e5073f}},	//   _सकती_, bny_, plai, टियो_,
   {{0xa28300d1,0x44327f38,0x3f1502c4,0x61ee1024}},	//   _نیرو, cny_, лдес, _enbl,
   {{0x44297f39,0x6da514d0,0xceeb0609,0x2fcf462c}},	//   mia_, гила, بران_, regg_,
   {{0xdce80095,0xed590949,0x2fcf7f3a,0x00000000}},	//   _addı, нол_, segg_, --,
   {{0xa2db0026,0x6b8956ed,0x6abd1371,0xddc100ec}},	//   निक्, tbeg, ्ब्र, _cilš,
   {{0x6aa97144,0x8af70095,0x00000000,0x00000000}},	//   tref, _çəki, --, --,
   {{0x985f003c,0x00000000,0x00000000,0x00000000}},	//   _eċċ_, --, --, --,
   {{0x44297f3b,0x6aa97f3c,0xe8f93924,0x44327f3d}},	//   hia_, rref, ело_, zny_,
   {{0x442970de,0x44327f3e,0x69c17f3f,0xaad80d91}},	//   kia_, yny_, rfle, _बैठक,
   {{0x44297f40,0x981616e6,0xb8eb11b5,0x7cca00a8}},	//   jia_, ابدا, _रङ_, _sərg,
   {{0x44320076,0xfaa56355,0x69c17f41,0x81ab0033}},	//   vny_, _сало, pfle, ক্য_,
   {{0x3e790c1f,0x4432004e,0x98e5004f,0x7cca00a8}},	//   _mèt_, wny_, _مكتو, _fərd,
   {{0x44327f38,0x03a67f42,0x3e7902e9,0x845a7f43}},	//   tny_, ливо, _lèt_, ерат_,
   {{0x44327f44,0x00000000,0x00000000,0x00000000}},	//   uny_, --, --, --,
   {{0x44321298,0xa2db1b8f,0x3e7902e9,0xc1ea0812}},	// [86e0] rny_, निग्, _nèt_, ндаж_,
   {{0x7c297f45,0x44297f46,0x44327f47,0x613a7e81}},	//   hier, aia_, sny_, нчер_,
   {{0x7c297f48,0xd00a02fb,0x44320c3d,0x00000000}},	//   kier, неже_, pny_, --,
   {{0x3e790c1f,0x7c297f49,0xb4c01ca8,0x00000000}},	//   _bèt_, jier, ंझी_, --,
   {{0x539b0122,0xadf00e96,0x3e790118,0x7afd6d0a}},	//   _איכו, चालन_, _cèt_, ästl,
   {{0x61467f4a,0x3e7902d0,0x61ee7f4b,0x00000000}},	//   _бега, _dèt_, _unbl, --,
   {{0x16b10302,0x7c297f4c,0xa3bb70a4,0x00000000}},	//   _जम्ब, fier, _घाम_, --,
   {{0x3e79142f,0x7c297f4d,0xa0670036,0x63b67f4e}},	//   _fèt_, gier, _баса_, ngyn,
   {{0xee3a0274,0xaae60037,0xdee30fc5,0x7cca013b}},	//   _зна_, اسبو, _лоти, _sərd,
   {{0x44297f4f,0x32bb02b5,0x9c7c0097,0x7c292069}},	//   zia_, עזיד, _určo, aier,
   {{0x7c297f50,0x41c6112b,0xf1c6057c,0x9c7c11d7}},	//   bier, र्यस, र्यन, _krčm,
   {{0x7c297f51,0xaae6004f,0x386d01ff,0x00000000}},	//   cier, _مستو, öer_, --,
   {{0x95cb0370,0x6b9d05ee,0x66c86da4,0x00000000}},	//   нува_, ðsge, лург_, --,
   {{0x44295ba7,0xf1c60ac4,0x41c605f8,0x998c00c7}},	//   wia_, र्मन, र्मस, rodų_,
   {{0x44297f52,0x7cca01c2,0x799a2f59,0xa2a70067}},	//   tia_, _hərb, matw, _चिह्,
   {{0xb4c50006,0x799a7f53,0x44295bdf,0x2a6e009e}},	//   _एही_, latw, uia_, _hifb_,
   {{0x394e0523,0x466b7f54,0x00000000,0x00000000}},	// [86f0] _hyfs_, _пром_, --, --,
   {{0x44291f0b,0x7c297f55,0x799a7f56,0x00000000}},	//   sia_, zier, natw, --,
   {{0x3e7902e9,0x6013037a,0x7416042c,0x46150088}},	//   _sèt_, _açma, _چوپا, _موکر,
   {{0x7c297f57,0x442901f4,0x3e790359,0x799a0371}},	//   xier, qia_, _pèt_, hatw,
   {{0x539a0122,0x4ea71403,0x44397f58,0x799a7f59}},	//   _בירו, уреа, _ijs_, katw,
   {{0x7c29006a,0x867c02b5,0x9f5f00f7,0x7afd00be}},	//   wier, ערוו, _joué_, ästm,
   {{0x7c297f5a,0xa1585e89,0x88c70355,0x799a4ad7}},	//   tier, _бару_, _kněž, datw,
   {{0x3e79142f,0x9f5f000d,0x00000000,0x00000000}},	//   _tèt_, _loué_, --, --,
   {{0x7c290408,0x799a0010,0xfaa5002d,0x00000000}},	//   rier, fatw, шапо, --,
   {{0x7c297f5b,0x799a7f5c,0x63b60409,0x2fdf1b39}},	//   sier, gatw, zgyn, _haug_,
   {{0x63b600c7,0x2bc200a1,0xe8f60012,0xdb090138}},	//   ygyn, व्हा, алэ_, rfeñ,
   {{0x28b600b4,0xfc6702fb,0x00000000,0x00000000}},	//   _अमरि, _съзн, --, --,
   {{0x799a1d6a,0x41c643fd,0xf3ff00e2,0x00000000}},	//   batw, र्डस, _giãi_, --,
   {{0x81ab00c8,0x6b9b7f5d,0x2fdf006f,0xb21b0b3e}},	//   ক্ত_, laug, _laug_, _stæn,
   {{0xe9462292,0x44390279,0x7cca00a8,0xc3960214}},	//   _پروی, _bjs_, _zərb, ијањ,
   {{0x3ea00496,0xb38600af,0xf81400bf,0x7ae47f5e}},	//   šiti_, рлал, _دستگ, _šiti,
   {{0xd4677f5f,0xb2262901,0x27e00014,0x42267f60}},	// [8700] рите_, амал, _iain_, адав,
   {{0x27e07f61,0x27e2012f,0x26060132,0x6b9b0bd1}},	//   _hain_, ldkn_, _vôos_, haug,
   {{0x7f860312,0x2fdf7f62,0xdcf80228,0x6b9b7f63}},	//   للان, _baug_, ravī, kaug,
   {{0x2fdf006f,0xe3b245fd,0x888c0070,0x43750402}},	//   _caug_, _برد_, גראַ, _гурт,
   {{0x2fdf01c8,0x27e07f64,0x3ea07f65,0x6b9b7f66}},	//   _daug_, _main_, éit_, daug,
   {{0x27e05a95,0x7ae4004f,0x44d80260,0xeca603fa}},	//   _lain_, _áiti, _kō_, ајин,
   {{0xa0a304d9,0x10a302c8,0x7cca00a8,0x27e00065}},	//   _мард, _мирн, _sərb, _oain_,
   {{0xeca7004e,0xa3c93f3c,0x27e07f67,0x799a7f68}},	//   _गिरफ, ल्प_, _nain_, watw,
   {{0xf1c60fbf,0x41c60e61,0x799a2cfd,0x7cca00a8}},	//   र्थन, र्थस, tatw, _qərb,
   {{0x2fdf0189,0xdb09027d,0x00000000,0x00000000}},	//   _zaug_, zgeç, --, --,
   {{0x44d80260,0x27e07f69,0xa3e61365,0x20040093}},	//   _nō_, _bain_, पया_, _komi_,
   {{0xf1c60d91,0x2d9c7f6a,0x20047f6b,0x6d5a7f6c}},	//   र्तन, lave_, _jomi_, _izta,
   {{0xa3c902e4,0x27e001da,0x799a002f,0x2c0b042c}},	//   ल्फ_, _dain_, patw, _جعلی_,
   {{0x2d9c7f6d,0x200400f4,0xa3c906d9,0x44d8021e}},	//   nave_, _lomi_, ल्न_, _bō_,
   {{0x44391491,0x69ca006d,0xf8da1a75,0x62867f6e}},	//   _pjs_, _ibfe, _बनिय, _atko,
   {{0x200402fb,0x27f2010d,0x25ad7f6f,0x27e07f70}},	//   _nomi_, _gnyn_, şel_, _gain_,
   {{0x2fdf01a9,0x81e00083,0x2d9c7f71,0x93780409}},	// [8710] _raug_, থান_, kave_, рбут_,
   {{0x2d9c04c3,0xf8da004e,0x27e05e43,0x98da4f02}},	//   jave_, _बनाय, _zain_, _बनाए,
   {{0x2fdf0221,0xf1c60b54,0x2d9c6561,0x44397f72}},	//   _paug_, र्धन, dave_, _tjs_,
   {{0x2fdf006f,0x2ef51283,0x2004118e,0x28a97f73}},	//   _qaug_, йзер, _comi_, _किसि,
   {{0x20047f74,0x6d5a3b51,0xdee5141d,0x2d9c7d81}},	//   _domi_, _azta, соли, fave_,
   {{0x9c7c0a78,0x2d9c7f75,0x41c60084,0x6b822314}},	//   _grčk, gave_, र्दस, _afog,
   {{0x2fdf0189,0x4c920274,0x20047f76,0x6b9b7f77}},	//   _taug_, пијс, _fomi_, taug,
   {{0xf5380122,0x2d82006c,0x3c3a00ea,0x2ca900f4}},	//   ינוי_, _őket_, tīva_, čad_,
   {{0xa3c904aa,0x2d9c0293,0x6d5a0291,0x6b9b7f78}},	//   ल्य_, bave_, _ezta, raug,
   {{0x6b9b01c8,0x27e07f79,0x7528004e,0x2d9c0031}},	//   saug, _sain_, ździ, cave_,
   {{0x20040034,0x799802d0,0x27e07f7a,0xdea300b5}},	//   _yomi_, _devw, _pain_, _ایڈی,
   {{0xa3c91033,0xa3e60035,0x96ba7f7b,0x00000000}},	//   ल्म_, _यों_, лугу_, --,
   {{0x27e003ad,0xdce306d0,0x7bda02b8,0x3954016f}},	//   _vain_, manı, _תקנו, _časť_,
   {{0x44d80107,0xdce30092,0x27e02646,0x3f9d030d}},	//   _pō_, lanı, _wain_, hawu_,
   {{0x26c2006a,0x27e01b57,0x291e0035,0x94791a39}},	//   stko_, _tain_, czta_, исту_,
   {{0x2d9c7f7c,0xdce306d3,0x27e0006b,0x93f600a8}},	//   zave_, nanı, _uain_, _şəbə,
   {{0x38a306d0,0x7cca0095,0x20043413,0xb3440095}},	// [8720] lır_, _məra, _romi_, _keçə,
   {{0x81ab00c8,0x9c8202c6,0x66050118,0xdce305f9}},	//   ক্স_, ščin, _gohk, hanı,
   {{0x999a0779,0x38a306d0,0xdce30463,0x2d9c7f7d}},	//   רבעט, nır_, kanı, vave_,
   {{0x6b997f7e,0x68fc01ff,0xef1a0a80,0x00000000}},	//   _newg, ärdi, лме_, --,
   {{0x2d9c7f71,0x9f49008a,0x7aed0187,0x9c7c3bec}},	//   tave_, ðað_, _šatn, _trčk,
   {{0x6b820382,0x38a3027d,0x7bcb0103,0x6d5a01ed}},	//   _sfog, kır_, _abgu, _pzta,
   {{0x2d9c5fa3,0x557702b5,0x7cca00a8,0x7aeb009e}},	//   rave_, זעצן_, _bəra, _argt,
   {{0x38a30eab,0x2d9c7f6a,0x6d5a01c0,0x5b1400c3}},	//   dır_, save_, _vzta, жмит,
   {{0xa3bb0e04,0x2d9c0031,0xda7a00d8,0x34d400be}},	//   _घास_, pave_, ыяй_, दबुद,
   {{0x386012c3,0x38a3027d,0x6b990345,0xff1700a5}},	//   _ahir_, fır_, _eewg, _הקמת_,
   {{0x1958342d,0x66051eca,0x2bca02ce,0x6d5a7f7f}},	//   раны_, _rohk, _було_, _uzta,
   {{0x38600211,0x28a90d43,0xdce30448,0x00000000}},	//   _chir_, _किरि, canı, --,
   {{0x291e1f11,0x28da0099,0x00000000,0x00000000}},	//   szta_, _बनवि, --, --,
   {{0xbb3b0070,0xe84c00b8,0x9c7c7f80,0x09e300c3}},	//   _געדי, ětší, _arči, _ночн,
   {{0xe65400d4,0x386009c3,0x9c7c0506,0x6b8d0160}},	//   ївсь, _fhir_, _brči, _îngâ,
   {{0x69c803bc,0x3860009e,0x00000000,0x00000000}},	//   lfde, _ghir_, --, --,
   {{0x24580086,0x69c80223,0x00000000,0x00000000}},	// [8730] сать_, ofde, --, --,
   {{0xa3bb0907,0xdce304d4,0x7afd2933,0xdb1f0e8c}},	//   _घाव_, zanı, ästi, évér,
   {{0xdce30ec4,0xa25b016f,0x69c80298,0x00000000}},	//   yanı, _spôs, ifde, --,
   {{0x9c7c6639,0x3218030d,0x644101ef,0x3ea4055c}},	//   _grči, _elry_, élid, _bvmt_,
   {{0x38a304d4,0xdce30716,0x81ab0083,0x160d252c}},	//   zır_, vanı, ক্ষ_, _सकार_,
   {{0x38a30ec4,0x7aed0254,0x628d1f26,0x28a905a6}},	//   yır_, _šato, mpao, _किलि,
   {{0xdce30644,0x38a300a8,0xa3c90162,0xed592a21}},	//   tanı, xır_, ल्थ_, шок_,
   {{0x7cca01c2,0xe0d202b5,0x442b0107,0x69c801bf}},	//   _qəra, _קײן_, _jmc_, efde,
   {{0x41c61856,0xf1c60ed1,0x442b7f81,0xdce30463}},	//   र्वस, र्वन, _mmc_, ranı,
   {{0x38600211,0x38a31a68,0xdce306d3,0x88c90086}},	//   _shir_, tır_, sanı, алов_,
   {{0x644f0088,0x61e501a6,0xdce30644,0x999e0355}},	//   _okci, idhl, panı, nitř_,
   {{0xb901006a,0x7e7b7f82,0x38a30716,0xdce300a8}},	//   _नई_, _kuup, rır_, qanı,
   {{0xf77203c7,0x38a3027d,0x61f50009,0x2fcd0027}},	//   باد_, sır_, _onzl, _mbeg_,
   {{0x7ae97f83,0x961400b4,0x7bc95d82,0x9c7c023a}},	//   mvet, डसेट_, lfeu, _srči,
   {{0x7ae97f84,0x9c7c1575,0x38607f85,0x00000000}},	//   lvet, _prči, _thir_, --,
   {{0x69de7f86,0x00000000,0x00000000,0x00000000}},	//   _óper, --, --, --,
   {{0xa20608bb,0x628d011e,0x9c7c00c5,0x7ae97f87}},	// [8740] опад, gpao, _isče, nvet,
   {{0xe1f77a6e,0xe2460037,0x00000000,0x00000000}},	//   огу_, آخري, --, --,
   {{0x9c7c0881,0x7aed02c4,0x41c6745f,0x602612ea}},	//   _trči, _šatl, र्षस, оджа,
   {{0x9c7c0076,0x2eed7f88,0x2d8500af,0x7ae97f89}},	//   _urči, _bref_, _afle_, kvet,
   {{0xfe460c06,0xaad82b22,0x644100f7,0x6589000d}},	//   ондо, _बैंक, élie, _éphé,
   {{0xf1c60d53,0x0caa4db5,0x6ce510a6,0xb4fe0ed1}},	//   र्शन, атии_, किंग_, _उपाय_,
   {{0x90c31181,0xb7bb0279,0x7bc97f8a,0x6c830312}},	//   _обре, lhãe, ffeu, ولوم,
   {{0x8aa61b0a,0x984d0067,0x00000000,0x00000000}},	//   ород, _iść_, --, --,
   {{0xada60279,0x8af70095,0x7ae900b5,0xf1c30024}},	//   _маал, _şərh, gvet, _feġġ_,
   {{0x2fcd0009,0x82f7024b,0x00000000,0x00000000}},	//   _zbeg_, קציב_, --, --,
   {{0x7ae94c55,0xb21b0093,0x91bb00a5,0x69c80051}},	//   avet, _stæk, סמטי, rfde,
   {{0x81c20083,0xd90f00fd,0x91ca1140,0x00000000}},	//   ্যি_, ئیٹ_, स्तै, --,
   {{0xb9010311,0x2eed011e,0x69b200a1,0x7ae938cb}},	//   _नै_, _xref_, _आयपी, cvet,
   {{0x5eeb022e,0x60c57f8b,0x00000000,0x00000000}},	//   चित्_, ythm, --, --,
   {{0x81c200c8,0x70c90006,0x80c90035,0x442b7f8c}},	//   ্যা_, _रहेल, _रहें, _pmc_,
   {{0xb8672499,0x3cdd00ab,0x00000000,0x00000000}},	//   _باتو, _कईसे_, --, --,
   {{0xd763064e,0x442b28c9,0x00000000,0x00000000}},	// [8750] _تنظی, _vmc_, --, --,
   {{0xd25114ac,0x442b0051,0x628d027a,0x00000000}},	//   رنا_, _wmc_, rpao, --,
   {{0x2127098b,0xa2a7009a,0x7ae9006c,0x6ad30033}},	//   ành_, _चिक्, zvet, তিযো,
   {{0x69ca0567,0x60c500e9,0x442b0051,0x47ad0033}},	//   त्ती, rthm, _umc_, ট্রী,
   {{0x51874234,0xfd4c0019,0x387c0009,0x41c6021a}},	//   _мува, _triề, _luvr_, _रॉकस,
   {{0xc27a0122,0x0dcb07e5,0x7ae9027d,0x644d7f8d}},	//   _לרשי, руди_, vvet, loai,
   {{0xb60200ac,0x00000000,0x00000000,0x00000000}},	//   _žáko, --, --, --,
   {{0x7ae901f4,0x2eed7f8e,0x644d279d,0xa806002a}},	//   tvet, _tref_, noai, _mañá,
   {{0x9f340210,0xeab10037,0x7bc97f8f,0x00000000}},	//   _жеті, رعة_, rfeu, --,
   {{0x7ae904d5,0x644d7f90,0x00000000,0x00000000}},	//   rvet, hoai, --, --,
   {{0x7ae936a5,0xf1b202b5,0x81bd0083,0xbb7510b4}},	//   svet, עסט_, _আসা_, _егеј,
   {{0xb33b00a8,0x7ae900b5,0x00000000,0x00000000}},	//   _keçd, pvet, --, --,
   {{0xa3e63138,0x644d01d7,0x4b7a00a5,0x7c3b0160}},	//   _योग_, doai, _האנו, mnur,
   {{0xa3c94d99,0x3e6002e9,0x59c20f06,0x7afd00be}},	//   ल्स_, pòte_, _शायर, ästu,
   {{0x182800bf,0x29350070,0x7ae40079,0x00000000}},	//   _وقتی_, _מאַן_, _áitr, --,
   {{0x7c3b2339,0x00000000,0x00000000,0x00000000}},	//   nnur, --, --, --,
   {{0x3cdd006a,0xc865004f,0x9343156c,0x41aa027a}},	// [8760] _कैसे_, _تطوي, енте, йван_,
   {{0xe4760043,0x7c3b02b1,0x00000000,0x00000000}},	//   _нумэ, hnur, --, --,
   {{0x64417397,0x757b00a5,0xa806002a,0xa3c9007c}},	//   élic, _לטיפ, _gañá, ल्ह_,
   {{0x62811834,0x1eaa017e,0xdb1b021d,0x00000000}},	//   _člov, ماتي_, rguê, --,
   {{0x44326e35,0xe7c1012f,0x00000000,0x00000000}},	//   miy_, ष्टप, --, --,
   {{0x44327f91,0x00000000,0x00000000,0x00000000}},	//   liy_, --, --, --,
   {{0x39a60082,0x44200118,0x00000000,0x00000000}},	//   hísí_, ohi_, --, --,
   {{0xafe36419,0x4420149b,0x764e00ac,0x320a0282}},	//   _посл, nhi_, hoby, _hoby_,
   {{0x764e01ba,0xa067256a,0xef1a05f4,0xdb1b0176}},	//   koby, _хата_, _ума_, nguè,
   {{0x39140500,0x7de5004f,0x44327f92,0x7c420009}},	//   дмор, _يسلم, hiy_, _štrč,
   {{0x44207f93,0x69bd0567,0x3ea600ea,0x764e088a}},	//   khi_, _शारी, lsot_, doby,
   {{0x290235b9,0x442001f4,0x2d9e7f94,0x3f867f95}},	//   ćka_, jhi_, _hete_, ncou_,
   {{0x44207f96,0x2d9e071f,0x44327f97,0x3ea60159}},	//   dhi_, _kete_, diy_, nsot_,
   {{0x2d9e7f98,0x00000000,0x00000000,0x00000000}},	//   _jete_, --, --, --,
   {{0x2d9e142f,0x4432034d,0x644d00c3,0x9f4401e9}},	//   _mete_, fiy_, toai, _bamë_,
   {{0x69da394e,0x44207f99,0x2d9e7f9a,0x3957011d}},	//   lete, ghi_, _lete_, _משום_,
   {{0x644d0160,0x320a00fe,0x877c0070,0x78ba7f9b}},	// [8770] roai, _boby_, _פאזי, lutv,
   {{0x44205efb,0x2d9e7f9c,0x320a0af9,0x69da3993}},	//   ahi_, _nete_, _coby_, nete,
   {{0x776101c2,0x44321a22,0x44201c8b,0x320a0314}},	//   əlxa, biy_, bhi_, _doby_,
   {{0x69da7f9d,0x44207f9e,0x98c5011c,0x7ae201d7}},	//   hete, chi_, žući_, _osot,
   {{0xa2a77f9f,0x69da7fa0,0x2d9e06a2,0x69bd04bc}},	//   _चिट्, kete, _bete_, _शाली,
   {{0x69da7fa1,0x2d9e538e,0x41e400d8,0x7bc27fa2}},	//   jete, _cete_, _піса, _acou,
   {{0x2d9e6395,0xd0d401d3,0x7cca00a8,0xeb9900af}},	//   _dete_, _поръ, _fərm, оий_,
   {{0xdb1b7fa3,0x61e77fa4,0x7bc20051,0xea890adb}},	//   lgué, _hajl, _ccou, обил_,
   {{0x2d9e7fa5,0x81e00083,0x9e6700b5,0x09e10033}},	//   _fete_, থার_, _فائن, বাসা,
   {{0x69da7fa6,0xb33b0723,0xdb1b1ec5,0x442001f4}},	//   gete, _geçe, ngué, zhi_,
   {{0x61e71d11,0xf1cf01d1,0x186a0c87,0x41cf142a}},	//   _majl, स्यन, жани_, स्यस,
   {{0x44207fa7,0x61e7006d,0xf0920070,0x2d9e02c4}},	//   xhi_, _lajl, כנט_, _zete_,
   {{0x44320fbc,0x69da7fa8,0x764e1857,0xddc10e3c}},	//   viy_, bete, toby, _milž,
   {{0x61e77fa9,0xf1cf00ab,0x9c7c0260,0x00000000}},	//   _najl, स्मन, _trčt, --,
   {{0x44207faa,0x44321a99,0x320a55c9,0x764e7fab}},	//   thi_, tiy_, _roby_, roby,
   {{0x44200ac8,0x68fc2d31,0xe73a0043,0x7ae20036}},	//   uhi_, årde, _мей_, _ysot,
   {{0x44327fac,0x44207fad,0x69ca00b4,0xa6e3005f}},	// [8780] riy_, rhi_, त्वी, _ажыл,
   {{0x44207fae,0x7cca00a8,0xa5cd021a,0xdb1b0176}},	//   shi_, _sərm, द्दौ, rguè,
   {{0x2d9e7faf,0xb4660dc8,0x25e71db9,0x442000e2}},	//   _rete_, _окол, _छोटी_, phi_,
   {{0x69da7fb0,0xb33b0723,0x2d9e7fb1,0xa2a706fe}},	//   zete, _seçe, _sete_, _चिच्,
   {{0x61e7003c,0x63a41691,0x69da7fb2,0x3f860f84}},	//   _fajl, main, yete, rcou_,
   {{0x3f9f0aaf,0x69da01f7,0xd04c0095,0xdce801ba}},	//   _eeuu_, xete, _əhəm, _vedľ,
   {{0x69da7fb3,0x2d9e01d2,0x50d22e33,0x7ae20024}},	//   vete, _vete_, _सहिष, _ssot,
   {{0x2d9e6bb2,0x22847fb4,0x69da7fb5,0x69c30395}},	//   _wete_, _kök_, wete, _acne,
   {{0x69da7fb6,0x2d9e7fb7,0x69c30298,0xe45700a5}},	//   tete, _tete_, _bcne, ויקט_,
   {{0x63a47fb8,0x6ffe00af,0x78ba7fb9,0x0e63061c}},	//   hain, _făcâ, tutv, _акун,
   {{0x69da7fba,0x29186dff,0x63a47fbb,0x7cca01c2}},	//   rete, ára_, kain, _mərk,
   {{0x69da7fbc,0x7ae20298,0x63a46d84,0x20067fbd}},	//   sete, _tsot, jain, njoi_,
   {{0x63a47fbe,0x78ba00b7,0x44c802b1,0x00000000}},	//   dain, sutv, eß_, --,
   {{0x69da4a3e,0x00000000,0x00000000,0x00000000}},	//   qete, --, --, --,
   {{0x2edb0355,0x63a47fbf,0xdb001111,0x81bd0033}},	//   _यन्त, fain, damé, _আসল_,
   {{0x69ca065f,0x63a4006b,0x3ea92209,0x7aed168a}},	//   त्री, gain, šati_, _šati,
   {{0x2bd000a1,0xeabc0083,0x61e70221,0x5334315d}},	// [8790] थ्या, _অনুম, _pajl, ветт,
   {{0x27e97fc0,0xdb007fc1,0xd25b00d8,0xc2c40037}},	//   _haan_, ramè, іца_, ئيلي,
   {{0xd131004f,0x63a47fc2,0xe7c6045c,0x61e77fc3}},	//   دما_, bain, _वामप, _vajl,
   {{0x27e900ab,0xa29500d8,0x63a41691,0x20060055}},	//   _jaan_, _памі, cain, gjoi_,
   {{0x61e77fc4,0x27e97fc5,0x0f350416,0x22840225}},	//   _tajl, _maan_, رکرد, _gök_,
   {{0x27e97fc6,0x780c0099,0x628f00fe,0xe61f021d}},	//   _laan_, _हक्क_, _itco, mpôs_,
   {{0x25a102b1,0xf41f01ff,0x00000000,0x00000000}},	//   _mehl_, _klä_, --, --,
   {{0x7cca0095,0x3eb200d8,0x5ba90274,0x2d870079}},	//   _mərh, šyta_, чким_, scne_,
   {{0xef5402fb,0x41c6142a,0x00000000,0x00000000}},	//   _акть, र्कस, --, --,
   {{0x63a47fc7,0xfdf30722,0x7bc00051,0xf41f00c3}},	//   zain, _आफिस_, agmu, _llä_,
   {{0x27e90c7c,0x200d03bc,0x09e10033,0x7bc00176}},	//   _baan_, _koei_, বালা, bgmu,
   {{0x41cf012f,0x2b4005e2,0x9f440097,0xf1cf0ed1}},	//   स्तस, _žice_, _samé_, स्तन,
   {{0x63a47fc8,0x27e9383a,0xcc3a02b5,0x7d1801ba}},	//   vain, _daan_, _צענט, časť,
   {{0x63a449d2,0x200d3170,0x64417fc9,0x22842c7a}},	//   wain, _loei_, élin, _rök_,
   {{0x228406d7,0x33f650f1,0x63a47fca,0x6aa97fcb}},	//   _sök_, нчас, tain, lsef,
   {{0x27e9019c,0x6b89005d,0x7dd3033e,0x3c3a0029}},	//   _gaan_, nceg, lısı, tīvi_,
   {{0x41b60674,0x63a4687a,0xdb0001cb,0x6aa90b41}},	// [87a0] есет, rain, tamé, nsef,
   {{0x69c10344,0x80c90033,0xa49400e0,0x7cca00a8}},	//   ngle, রবন্, _لیست, _fərh,
   {{0x63a47fcc,0x27e918e4,0xdb007fcd,0xf1c6164f}},	//   pain, _yaan_, ramé, र्गन,
   {{0xa2b21e79,0x59cf25d8,0x81c20033,0x200d0176}},	//   ेंद्, त्तर, ্যই_, _coei_,
   {{0x7cca0095,0x200d7fce,0x201f0139,0x00000000}},	//   _tərk, _doei_, _dlui_, --,
   {{0x69c100cd,0x00000000,0x00000000,0x00000000}},	//   jgle, --, --, --,
   {{0x3243326d,0x7cca0095,0x69c17fcf,0x200d0051}},	//   _серг, _kəri, dgle, _foei_,
   {{0x59c222d4,0xdee60d15,0x200d0afc,0x388500ea}},	//   _शाहर, _поби, _goei_, _pērn_,
   {{0xdcea1a68,0x27e9010d,0xd00f0079,0x00000000}},	//   rafı, _raan_, _الق_, --,
   {{0x69c17fd0,0x27e97fd1,0xf3ff0019,0x7cca00a8}},	//   ggle, _saan_, _nhãn_, _ləri,
   {{0x27e901a2,0x395808c8,0x0dc90079,0x00000000}},	//   _paan_, ærs_, _تبقى_, --,
   {{0x7e7a7fd2,0x9be30804,0x7cca00a8,0xe7eb0066}},	//   _hitp, _бішк, _nəri, _जोखा_,
   {{0x27e903ad,0x7cca0095,0x81ab0033,0x8cc10067}},	//   _vaan_, _sərh, ক্ট_, रंथो,
   {{0x27e97fd3,0xdb020279,0x7dd300d0,0x6d5a00b8}},	//   _waan_, _adoç, cısı, _kyta,
   {{0x64410248,0x27e97fd4,0x7a240107,0x04677ef0}},	//   élio, _taan_, _pòtf, етам,
   {{0xb6f500ed,0x6d5a7fd5,0x7cca00a8,0x00000000}},	//   _азиј, _myta, _cəri, --,
   {{0x7cca0095,0x337507e5,0x200d0b88,0x00000000}},	// [87b0] _dəri, тгар, _roei_, --,
   {{0xa50700d8,0x7e7a0069,0xbbdd319c,0x38690024}},	//   _зямл, _nitp, _मस्क, _hhar_,
   {{0x6d5a7fd6,0x00000000,0x00000000,0x00000000}},	//   _nyta, --, --, --,
   {{0x69c12eaf,0x6e95170e,0x443f01ed,0xa3bb00fa}},	//   zgle, виду, _ñu_, _घाट_,
   {{0xdee54a4e,0x7dd301d6,0x644800f7,0x6d5a00a3}},	//   толи, yısı, édie, _ayta,
   {{0xed590714,0xde940037,0x7cca00a8,0x6d5a017b}},	//   мол_, اجنب, _zəri, _byta,
   {{0x6d5a004e,0x386901a3,0x6aab7fd7,0x7e7a0118}},	//   _cyta, _ohar_, _svgf, _ditp,
   {{0x2ef5798c,0x201f0043,0x7cca00a8,0x6aa9621c}},	//   _избр, _ului_, _xəri, tsef,
   {{0x6b897fd8,0x7e7a00d5,0x69c16438,0x93f6013b}},	//   rceg, _fitp, tgle, _şəkə,
   {{0x6b89027a,0x69c17fd9,0x3ead00ee,0x00000000}},	//   sceg, ugle, _ivet_, --,
   {{0x69c1345c,0xd9450dbf,0x7dd3037a,0x6aa97fda}},	//   rgle, тени, rısı, ssef,
   {{0xe73a7fdb,0x69c14843,0xdb1b0300,0xb8860093}},	//   дем_, sgle, lguí, _skíð,
   {{0x38690211,0x7dd300d0,0x26160067,0x00000000}},	//   _dhar_, pısı, _नकदी_, --,
   {{0xdb1b2a87,0x00000000,0x00000000,0x00000000}},	//   nguí, --, --, --,
   {{0xf3ff0279,0xe5a30336,0x684625ef,0x00000000}},	//   _chão_, риси, _инка, --,
   {{0x38697fdc,0xe8d600a5,0x7cca00a8,0x88ba0277}},	//   _ghar_, _יוצר_, _qəri, _חזקי,
   {{0xb33b0370,0x46e700af,0x00000000,0x00000000}},	// [87c0] _peça, _адын_, --, --,
   {{0xb21b7fdd,0x6448000d,0x42230b6b,0x00000000}},	//   _stær, édib, адув, --,
   {{0xb33b00da,0x3ead7fde,0x21764025,0xa5b70070}},	//   _veça, _avet_, туар, _בליק_,
   {{0x6e21233c,0xf1c601c0,0xdfd00372,0x6d5a010b}},	//   _allb, र्जन, صيت_, _ryta,
   {{0x4422036a,0xdfcf00ad,0x3ead0169,0x87ad0070}},	//   _ilk_, تين_, _cvet_, לשאַ,
   {{0x93f60669,0x6d5a006a,0xfe6f0286,0x37d60033}},	//   _şəhə, _pyta, يدو_, _তোমর,
   {{0xa3c91729,0x3ead01d6,0x7f492127,0x10a300d4}},	//   ल्क_, _evet_, _exeq, _висн,
   {{0x6d5a4e20,0xdc2a00f8,0x7e7a0345,0x7a240107}},	//   _vyta, بسته_, _witp, _mòte,
   {{0xdee3081e,0x629602e9,0xa3bb00ab,0x00000000}},	//   _коти, npyo, _घाघ_, --,
   {{0xf1c6021a,0x7e7a09a6,0x44220088,0x00000000}},	//   र्चन, _uitp, _llk_, --,
   {{0x33290024,0x23e20461,0xb4e1018d,0x91bb00a5}},	//   zzax_, _पसंद, _धने_, ומיי,
   {{0x28c41e79,0x3c3a00ea,0x25a70124,0x56950183}},	//   लंबि, tīvu_, _žnl_, ламт,
   {{0x387b0023,0x6441000d,0x7c220fe2,0xf848010b}},	//   _viqr_, élim, _ilor, тчэй_,
   {{0xb8f4004f,0x7c227fdf,0x44227fe0,0x569400af}},	//   _مكتب, _hlor, _alk_, рарт,
   {{0x03c701c8,0x3869009c,0x55581583,0x05d20355}},	//   ксам, _thar_, варя_, द्धब,
   {{0x7c220107,0x78ba2f70,0x41c67e44,0x996501e0}},	//   _jlor, mrtv, र्घस, _стіл,
   {{0x245803ad,0x284a0070,0x0cbf0437,0x7c2201cb}},	// [87d0] тать_, _רעפּ, _एम्म, _mlor,
   {{0x7c222c35,0x44220a45,0x9f4412c3,0x7a240107}},	//   _llor, _elk_, _camí_, _fòte,
   {{0x3ead2ce5,0x7c222b01,0x0cbd0083,0x44220088}},	//   _svet_, _olor, _আন্ত, _flk_,
   {{0x76557fe1,0x998c0009,0x442200cc,0x00000000}},	//   lozy, jndž_, _glk_, --,
   {{0x3c3a0080,0xa3cc0026,0x539a00a5,0x7cca0095}},	//   hīvs_, _शॉट_, _רישו, _məru,
   {{0x7c227fe2,0x518727de,0x09bd0033,0x7a24021e}},	//   _alor, _шума, _অস্থ, _lòtb,
   {{0xed5601ee,0xb4b105e7,0xdb1b7fe3,0x7c22216a}},	//   лош_, _ऑटो_, rguí, _blor,
   {{0x20f303fd,0x30da02b5,0x2b4005e2,0x68260bca}},	//   _ići_, _אַמע, _žica_, _kóde,
   {{0x2a7c012f,0x32110e7d,0x00000000,0x00000000}},	//   _bivb_, _kozy_, --, --,
   {{0x7c227fe4,0x20f3011c,0xb33b00f7,0x68267fe5}},	//   _elor, _kći_, _leço, _móde,
   {{0xf2d001c0,0x7c221116,0x07a600d4,0xc7a60432}},	//   _सङ्घ, _flor, ланн, линк,
   {{0x30da02b5,0x7c227fe6,0xc5e900a5,0x7cca013b}},	//   ײַטע, _glor, _מד_, _pərv,
   {{0x9f8a007c,0x6b9b7fe7,0x78ba213d,0xa3c90d1f}},	//   _tööd_, mbug, artv, ोभन_,
   {{0x2aba0122,0x7c22008b,0x20f3022f,0x6b9b596c}},	//   _נמצא, _zlor, _oći_, lbug,
   {{0x70d20084,0x44221a0c,0x00000000,0x00000000}},	//   _सहेल, _plk_, --, --,
   {{0x44220036,0x59cf1e18,0x9f4400d5,0x26020266}},	//   _qlk_, त्रर, _samí_, शाही_,
   {{0xe1fa3534,0x68260138,0x44223383,0xa92000a8}},	// [87e0] нга_, _códe, _vlk_, _çörə,
   {{0x55e60d36,0x26c27fe8,0x7cca0095,0x869b0070}},	//   _сооб, muko_, _zəru, _רייז,
   {{0x26c27fe9,0x44227fea,0x00000000,0x00000000}},	//   luko_, _tlk_, --, --,
   {{0xe29a00d4,0x7cca00a8,0x44227feb,0x00000000}},	//   _пам_, _mərt, _ulk_, --,
   {{0xdb007fec,0xdd920df3,0x26c23c6e,0x6b9b0103}},	//   tamí, موش_, nuko_, dbug,
   {{0xc1e72292,0x69d3004e,0x6abe0083,0x90a60372}},	//   _مکمل_, _बॉली, ্বমো, _محرم,
   {{0x2167027a,0x7c220310,0x26c2035a,0x62867fed}},	//   _бири_, _plor, huko_, _huko,
   {{0x62865246,0x61ee0083,0xe4f706bb,0x64447fee}},	//   _kuko, _habl, ुमति_, nnii,
   {{0x61ee7fef,0x7c2200da,0x81e70033,0x2ba50026}},	//   _kabl, _vlor, ভার_, _गजरा,
   {{0x61ee0097,0x62860198,0x26c27ff0,0xe9e612f3}},	//   _jabl, _muko, duko_, уцио,
   {{0x5bc60c36,0x61ee7ff1,0x64440086,0x325700a5}},	//   _مقال, _mabl, knii, רסים_,
   {{0x6286022f,0x61ee7ff2,0x26c22b38,0x2fc62487}},	//   _ouko, _labl, fuko_, ngog_,
   {{0xb33b00f7,0xcc570319,0x26c2780f,0x64440987}},	//   _reço, _גבאי_, guko_, dnii,
   {{0x27ed23eb,0x9f4401f7,0x63a601ed,0xd4e70338}},	//   žen_, _mamà_, _aekn, люби,
   {{0xf9930122,0x76557ff3,0x62867ff4,0x63a60fdb}},	//   _פרק_, rozy, _auko, _bekn,
   {{0x6826043f,0x64447ff5,0x26c27ff6,0x63a60168}},	//   _póde, gnii, buko_, _cekn,
   {{0x9259051b,0x61ee2181,0x60dc0009,0x6b820054}},	// [87f0] ваат_, _babl, _aprm, _mgog,
   {{0xbb3b02b5,0x6444081b,0x628655fc,0x00000000}},	//   געמי, anii, _duko, --,
   {{0xa3d53525,0x61ee7ff7,0x321100b8,0x6286052a}},	//   _конч, _dabl, _vozy_, _euko,
   {{0x63a66ce1,0x6b820404,0x3384081b,0x2ef50ded}},	//   _gekn, _ngog, _гурв, изер,
   {{0x69d87ff8,0x61ee7ff9,0x6286070b,0xddc801c8}},	//   _obve, _fabl, _guko, _didž,
   {{0x44297ffa,0xef1801c8,0x443b4e30,0x8cb5656d}},	//   lha_, ымі_, liq_, асич,
   {{0x20f3044d,0x26c2569f,0x62860110,0x00000000}},	//   _ući_, zuko_, _zuko, --,
   {{0x4429130c,0x8cc100dc,0x6abb3994,0x443b0c6f}},	//   nha_, रूषो, truf, niq_,
   {{0x26160084,0x628000f7,0x6b9b3da1,0xba252d1e}},	//   _नकली_, _émot, rbug, идик,
   {{0x44297ffb,0x443b20e2,0x26c27ffc,0x6abb7ffd}},	//   hha_, hiq_, vuko_, rruf,
   {{0x5d842d7c,0x44297ffe,0x64560371,0x6444081b}},	//   _المل, kha_, yoyi, ynii,
   {{0x26c203cb,0x44297fff,0x290b2af4,0x67fb0421}},	//   tuko_, jha_, ćca_, _räjä,
   {{0x44298000,0xd90f0332,0xfaa56245,0x8c1a0122}},	//   dha_, تیں_, _тало, _שוני,
   {{0x26c28001,0x7c298002,0xc98713f8,0x7cca00a8}},	//   ruko_, lher, _суди, _tərt,
   {{0x62868003,0x26c28004,0x64a64ece,0x443b7d40}},	//   _suko, suko_, раба, fiq_,
   {{0x44298005,0x93468006,0x62860254,0x7c3b30ad}},	//   gha_, анбе, _puko, niur,

   {{0x2bd731d7,0x61ee4f7c,0x81c10083,0x644400ab}},	// [8800] भ्या, _pabl, ্জন_, rnii,
   {{0x62860a78,0xb33b0723,0xc6930122,0x44295efb}},	//   _vuko, _geçm, _ואז_, aha_,
   {{0x44298007,0x55bb0122,0x9f868008,0xe3ba1073}},	//   bha_, _במיו, агед, _ибн_,
   {{0x44298009,0xfa880019,0xeaa7004f,0x6286800a}},	//   cha_, _lừa_, _وع_, _tuko,
   {{0x61ee800b,0xddc82b6c,0x539b0277,0x00000000}},	//   _tabl, _vidž, _ביכו, --,
   {{0x61ee009e,0x40961362,0x7bd9030d,0x9c7c0207}},	//   _uabl, _врат, _abwu, _isči,
   {{0xac261637,0xdb00800c,0x4420800d,0x7a24009e}},	//   ифик, damá, oki_, _nòta,
   {{0x6aa20c1f,0x7c29800e,0x20e80463,0x7c3b4a25}},	//   _pwof, gher, _işi_, giur,
   {{0x787f0029,0x5a3402fb,0xfa8800e2,0x7af90090}},	//   _būvn, йнит, _bừa_, _crwt,
   {{0x4420800f,0xd3140804,0x44298010,0xdb00008d}},	//   hki_, лiкт, zha_, gamá,
   {{0x44208011,0x28a6198f,0xfa880023,0x443b00a8}},	//   kki_, _कौशि, _dừa_, yiq_,
   {{0x7c298012,0xdb5a00c3,0x44208013,0x44298014}},	//   cher, _июл_, jki_, xha_,
   {{0x44208015,0x81ac00c8,0x09e10033,0x443b0031}},	//   dki_, _গান_, বাজা, viq_,
   {{0x44208016,0x4429007a,0x20c900a1,0x68f80009}},	//   eki_, wha_, ांमध, _trvd,
   {{0x44298017,0x5fd709b1,0x443b8018,0x44208019}},	//   tha_, ण्डल, tiq_, fki_,
   {{0xe97b0052,0x44200a2d,0x4429801a,0x00000000}},	//   _בנוש, gki_, uha_, --,
   {{0x44297243,0xf7730609,0x443b801b,0xdcfa007a}},	// [8810] rha_, _باغ_, riq_, _fetħ,
   {{0x4429801c,0x4420801d,0x69c81b2f,0xc7b1006c}},	//   sha_, aki_, ngde, _بڑھ_,
   {{0x44200299,0x4429024b,0x46150647,0x00000000}},	//   bki_, pha_, _نوکر, --,
   {{0x4420263f,0xa3ce0c57,0x4429035f,0x1dc900a1}},	//   cki_, _राय_, qha_, _राहत,
   {{0x63ad6969,0x44397b2b,0x161b0099,0x20e80225}},	//   maan, _ims_, _नकार_, _eşi_,
   {{0x63ad801e,0x6da200c9,0x7c29801f,0x00000000}},	//   laan, пиша, wher, --,
   {{0xeb1f009a,0xa3ce0324,0xdd8e0833,0x7c293cc2}},	//   यन्त_, _राम_, روي_, ther,
   {{0x63ad0866,0xd04500b5,0x61e58020,0x443900ab}},	//   naan, _اپري, lehl, _jms_,
   {{0x7c3b8021,0x7c298022,0xdb000093,0x28c40066}},	//   riur, rher, tamá, लूसि,
   {{0x7c2904f7,0x44208023,0x7a2402e9,0x63ad8024}},	//   sher, zki_, _pòta, haan,
   {{0x63ad8025,0xfa880028,0x4420004e,0x7cca0095}},	//   kaan, _vừa_, yki_, _fərq,
   {{0x7bd901d5,0x69c80223,0x50da1804,0x00000000}},	//   _ubwu, agde, נקרא, --,
   {{0x63ad8026,0x442002c6,0xceb20070,0x7c390069}},	//   daan, vki_, ּיל_, _imwr,
   {{0x4420004e,0x69dd00b5,0x63ad0051,0x00000000}},	//   wki_, őseb, eaan, --,
   {{0x44208027,0x63ad0273,0x64480279,0x8cca0ea3}},	//   tki_, faan, édio, संयो,
   {{0x63ad8028,0x3eb201c8,0x7bc98029,0x4420802a}},	//   gaan, šyti_, ngeu, uki_,
   {{0x61e501ae,0xd467692c,0xddd800a0,0x74130037}},	// [8820] fehl, сите_, bovň, أوقا,
   {{0x645d802b,0x44392cfc,0x7afd00c3,0x7ae90345}},	//   _eksi, _ems_, ästy, iwet,
   {{0x63ad01a8,0xf77f03e6,0x5a3a02b5,0x4420802c}},	//   baan, meça_, נגעה, pki_,
   {{0x7ae92b38,0x63ad500f,0xf77f0183,0x00000000}},	//   kwet, caan, leça_, --,
   {{0x92f601e0,0x69c801ff,0x9c7c0107,0x00000000}},	//   _учні, ygde, _trčz, --,
   {{0x7cca0095,0xd252006c,0x60c5012f,0x7ae9018d}},	//   _bərp, _رنز_, buhm, dwet,
   {{0x645d03ad,0x443900c3,0x20e80395,0x787f02d4}},	//   _yksi, _yms_, _uşi_, _būvl,
   {{0x7bc97ac0,0x69c801e8,0x2d85802d,0x9c7c0124}},	//   ggeu, wgde, _egle_, _opče,
   {{0x09ac0083,0xf1cf0355,0x9c7c0107,0xdfcf802e}},	//   _খাবা, स्कन, _osčv, _سيل_,
   {{0xb33b01c2,0x98a70723,0x23ad010b,0x63ad018e}},	//   _seçk, _aynı_, mųjų_, zaan,
   {{0xf8ad00e0,0x20040223,0x6e28008c,0xf77f0183}},	//   نکي_, _knmi_, _ildb, deça_,
   {{0xbb86004f,0x7ae925b4,0x644800a2,0x2c09022e}},	//   _الإي, bwet, édil, वाणं_,
   {{0xf1a8045c,0x63ad802f,0x291800be,0x23ad00c7}},	//   गरान, vaan, ärab_, nųjų_,
   {{0x63ad8030,0xf1c711b5,0x7afd035b,0x41c722a3}},	//   waan, _लाइन, æste, _लाइस,
   {{0x63ad8031,0x388500ec,0x00000000,0x00000000}},	//   taan, _bēru_, --, --,
   {{0x68260391,0x25bf002d,0x443901f7,0x539900c3}},	//   _tóda, şul_, _qms_, рвая_,
   {{0xb33b0669,0x63ad8032,0x59cf021a,0x521503b1}},	// [8830] _keçi, raan, त्कर, одат,
   {{0x63ad8033,0x9c7c0124,0x00000000,0x00000000}},	//   saan, _isču, --, --,
   {{0x63ad8034,0x6826024e,0x44398035,0xdb006552}},	//   paan, _módn, _tms_, lamä,
   {{0x44397e88,0x00000000,0x00000000,0x00000000}},	//   _ums_, --, --, --,
   {{0xa3ce1033,0x287c02b5,0xdb00023f,0x661701b7}},	//   _रात_, אנאמ, namä, _koxk,
   {{0xae030821,0x2c4c01c0,0x31353471,0x7c950166}},	//   लाइन_, věda_, _дегр, ориц,
   {{0x7c840274,0x661701ed,0x00000000,0x00000000}},	//   пуње, _moxk, --, --,
   {{0xa4b80122,0x291e010b,0x7ae98036,0xfc310037}},	//   צלחה_, dyta_, twet, بحت_,
   {{0x7bc90248,0x27f253d3,0x00000000,0x00000000}},	//   rgeu, _rayn_, --, --,
   {{0x7ae909ef,0x39450ebb,0x89a928cc,0xf7cb0355}},	//   rwet, жног, шков_, ážní_,
   {{0x7ae97aa2,0xa3c90930,0x00000000,0x00000000}},	//   swet, ईला_, --, --,
   {{0xe8df0028,0x660500cc,0x81c10831,0x00000000}},	//   hiệm_, _anhk, ্জি_, --,
   {{0xb6a307e5,0x66170051,0x00000000,0x00000000}},	//   миял, _boxk, --, --,
   {{0xb33b0723,0x00000000,0x00000000,0x00000000}},	//   _geçi, --, --, --,
   {{0xf77f8037,0x186a3c16,0xa9790070,0x81c10033}},	//   reça_, _каки_, _דאַכ, ্জা_,
   {{0xccf20122,0xb4660402,0xdb0000be,0xa34a0183}},	//   וכל_, ікал, bamä, азба_,
   {{0x987b0070,0xe88900e2,0x38600118,0x225a00e2}},	// [8840] _דאקט, _kẻo_, _ikir_, topk_,
   {{0x682605fa,0xfe650919,0x00000000,0x00000000}},	//   _kódo, _سگ_, --, --,
   {{0x765c129d,0xd46a0fa7,0xae034eee,0x682600ee}},	//   mory, _вине_, लाईन_, _jódo,
   {{0x81e700c8,0x6826006c,0xd5b10023,0x30761ac5}},	//   ভাগ_, _módo, ức_, цузс,
   {{0x087700c2,0x43760a80,0xaedc00d8,0x291e0067}},	//   קענט_, _фунт, ублi, zyta_,
   {{0xdcba01d3,0xa0a6145c,0xe88900e2,0x00000000}},	//   ащи_, _магд, _nẻo_, --,
   {{0x25ba0034,0x00000000,0x00000000,0x00000000}},	//   _mdpl_, --, --, --,
   {{0x765c1bd9,0xb33b06a8,0x09b400c8,0x290001c8}},	//   hory, _seçi, জ্ঞা, _čia_,
   {{0x2d9612f3,0xa2c21119,0x63b90035,0xa2b20141}},	//   _дрес, _लिफ्, ówni, ेंट्,
   {{0x291e00d8,0x386001cb,0xfce68038,0x00000000}},	//   tyta_, _akir_, _мозо, --,
   {{0x19580104,0xdb0001ff,0xe8890023,0x765c8039}},	//   саны_, damå, _dẻo_, dory,
   {{0x8c140083,0x291e11fc,0x321813fb,0x28db00ab}},	//   ়োজন_, ryta_, _lory_, _बहरि,
   {{0xec1305f5,0x765c803a,0x291e00c7,0x6d4d0448}},	//   _توند, fory, syta_, şaat,
   {{0x765c803b,0x09b40083,0xddda0107,0xb60400af}},	//   gory, জ্জা, _oktō, мяск,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69da1a38,0xdb0001ba,0x41dd022e,0x25a600cd}},	//   lfte, pamä, न्नस, _đole_,
   {{0xf77f0279,0x2602073f,0x00000000,0x00000000}},	// [8850] meço_, शाखी_, --, --,
   {{0x69da033b,0x7ae22206,0xf1c300e2,0x1a9b016b}},	//   nfte, _mpot, _giờ_, יימע,
   {{0xd25000b5,0x64410e8c,0xd258010b,0x92cb0033}},	//   ڑنے_, élis, іцу_, লবে_,
   {{0x155a0122,0x47c20831,0x00000000,0x00000000}},	//   _לכתב, ষ্ঠী, --, --,
   {{0x442b0176,0x63a242ae,0x60db00f4,0x37b00831}},	//   _ilc_, ñone, _ćumu, _কামর,
   {{0xee3801e0,0x32180067,0x69da0051,0x787f02d4}},	//   оні_, _gory_, jfte, _būvk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f5803c,0xa2c20803,0xa3ce00b4,0xc1040037}},	//   _hazl, _लिम्, रलय_, _توفي,
   {{0xa3ce0907,0xf77f0279,0x61f5010b,0x765c1b82}},	//   _रास_, deço_, _kazl, yory,
   {{0x61f5803d,0x682601ef,0x7a240260,0x00000000}},	//   _jazl, _pódo, _fòtm, --,
   {{0x41dd05f8,0x61f5803e,0x765c1846,0x442b009d}},	//   न्यस, _mazl, vory, _olc_,
   {{0x7c2d290b,0x69da0a8c,0x66e601e0,0x00000000}},	//   ďars, afte, пома, --,
   {{0x765c803f,0x249a0a4e,0x00000000,0x00000000}},	//   tory, _stpm_, --, --,
   {{0xa3ce0953,0x68260391,0xa6e30093,0xe8890023}},	//   _राह_, _tódo, óðar, _hẻm_,
   {{0xd4d500d8,0x00000000,0x00000000,0x00000000}},	//   мітэ, --, --, --,
   {{0xccf202b5,0xc48316fb,0x58ba00a5,0x2b4003c9}},	//   עכן_, елск, _המקצ, _žici_,
   {{0xe8db0026,0xf8db111b,0x32180035,0x27e0081b}},	// [8860] _बहुच, _बहुप, _pory_, _ibin_,
   {{0x17570052,0x2fdf011e,0xa3ce0785,0x7a2d021d}},	//   _מספר_, _abug_, _राव_, _fúte,
   {{0x442b17d8,0x7c2b8040,0x00000000,0x00000000}},	//   _flc_, _olgr, --, --,
   {{0x44240019,0x1fd60067,0x00000000,0x00000000}},	//   _ôm_, ठभेड, --, --,
   {{0x61f50723,0x63a40f00,0xdb0b01f4,0x32185ca1}},	//   _fazl, mbin, _degë, _tory_,
   {{0xe29714d0,0x63a48041,0x13b10083,0x61f51008}},	//   _хар_, lbin, _ছায়, _gazl,
   {{0x8fa68042,0xa116006c,0xe6a9210a,0xd1b300b5}},	//   _наве, _عورت, _कब्ज, _سینک,
   {{0x63a48043,0xdb0b0055,0x00000000,0x00000000}},	//   nbin, _gegë, --, --,
   {{0xd90d00e0,0x63a48044,0xe7c6198f,0x61f50225}},	//   ییه_, ibin, _वाजप, _yazl,
   {{0x27e03f59,0x3f8000d8,0x831b0070,0xf1cc06fe}},	//   _abin_, žius_, צויז, ालिन,
   {{0xdca302ce,0x69da8045,0x3b861052,0x27e00103}},	//   _захи, rfte, _елег, _bbin_,
   {{0x63a40169,0x00000000,0x00000000,0x00000000}},	//   jbin, --, --, --,
   {{0x7ae28046,0xf77f0370,0x63a40a78,0x69da02b1}},	//   _upot, reço_, dbin, pfte,
   {{0x998c02c4,0x4b7b00a5,0xa7fb5891,0x00000000}},	//   lidž_, _האדו, doñe, --,
   {{0x61f50888,0x7a2d09ab,0x1c200299,0x682600b5}},	//   _razl, _fútb, _बवाल_, _módj,
   {{0x63a43ace,0xd251006c,0x442b027a,0x27e00069}},	//   gbin, ھنا_, _qlc_, _gbin_,
   {{0xd7670332,0xa5f950f1,0x61f50693,0x67bc00a5}},	// [8870] _ڈاکٹ, _депу_, _pazl, _המחק,
   {{0x26cb8047,0x63a414e7,0xdb0b021e,0x61f5013b}},	//   muco_, abin, _degè, _qazl,
   {{0x4fd51109,0x21270028,0x442b8048,0xf77001cb}},	//   джет, ánh_, _tlc_, _لای_,
   {{0x35d307b5,0x787f0228,0x00000000,0x00000000}},	//   _ताड़, _būvi, --, --,
   {{0xa7fb043f,0x26d98049,0x26cb0138,0x644d26c9}},	//   coñe, ntso_, nuco_, mnai,
   {{0x2f230080,0xfce52d9c,0x63af46db,0x644d804a}},	//   _rīgā_, доко, _hecn, lnai,
   {{0x644d804b,0x00000000,0x00000000,0x00000000}},	//   onai, --, --, --,
   {{0x13b100c8,0x62870033,0x628f804c,0x9f440036}},	//   _ছাড়, _hijo, _kuco, _lamù_,
   {{0xb33b01d6,0x644d804d,0x6aa4804e,0x00000000}},	//   _geçt, inai, _çifl, --,
   {{0x644d0094,0x7afb00ab,0x26cb027a,0x62870107}},	//   hnai, rvut, duco_, _jijo,
   {{0x63a4010b,0xdb0b006c,0x6287804f,0x998c02c4}},	//   ybin, _megé, _mijo, bidž_,
   {{0x41dd007e,0xf1dd16f5,0x629d1c9a,0x21010506}},	//   न्तस, न्तन, _otso, mčić_,
   {{0x09ac0083,0x629d0189,0x2101012e,0xd83902d0}},	//   _খারা, _ntso, lčić_, nsčy_,
   {{0x62878050,0x59d40d4e,0xdb0b0176,0x56930328}},	//   _nijo, _दायर, _regè, таёт,
   {{0x1ddf0e6f,0x21010254,0x63a40e54,0x9856562d}},	//   प्यत, nčić_, tbin, _отиш,
   {{0x628f0395,0x27e0022e,0x644d8051,0x26cb014c}},	//   _buco, _ubin_, gnai, buco_,
   {{0x4b7a02b5,0x62878052,0x628f0160,0xf7d700a5}},	// [8880] ַטעג, _bijo, _cuco, _חופש_,
   {{0x644d111c,0x63a48053,0xd7ca0088,0xb5ca00d1}},	//   anai, sbin, _اوکه_, _بودم_,
   {{0x62874c70,0x644d8054,0x628f00f1,0xb33b027d}},	//   _dijo, bnai, _euco, _seçt,
   {{0x28c500dc,0xa7fb0391,0x628f01ef,0x644d26c9}},	//   _विनि, poñe, _fuco, cnai,
   {{0x62870453,0x987b0070,0x998c0009,0x628f007b}},	//   _fijo, קאנט, vidž_, _guco,
   {{0xf1dd608c,0x41dd0edf,0x62875685,0x00000000}},	//   न्दन, न्दस, _gijo, --,
   {{0x998c0009,0x628f0176,0x2167107a,0x00000000}},	//   tidž_, _zuco, _жири_, --,
   {{0x62870065,0x00000000,0x00000000,0x00000000}},	//   _zijo, --, --, --,
   {{0x98460029,0x998c02c4,0x6e930079,0x3c43021e}},	//   _dēļ_, ridž_, _للقا, _sèvè_,
   {{0x21010207,0x4d7602ed,0x00000000,0x00000000}},	//   bčić_, _قطار, --, --,
   {{0xa3c036e3,0xa3ce0914,0x3ce500d7,0x2d8c0009}},	//   ीला_, रला_, _gplv_, _igde_,
   {{0x2b4000cd,0x7852013a,0x3c430260,0x00000000}},	//   _žicu_, tāva, _vèvè_, --,
   {{0xa7744076,0x2ba400c0,0xe66701e0,0x4432034d}},	//   ключ, _ग्या, дтво, dhy_,
   {{0x26d906a2,0xb8f40083,0x68fc2c68,0x628f8055}},	//   rtso_, _হন_, årds, _ruco,
   {{0x628f0015,0x63af0124,0xdb0b00b5,0x644d8056}},	//   _suco, _pecn, _regé, tnai,
   {{0x62873122,0xdb0b00b5,0x628f8057,0x7a24009e}},	//   _sijo, _segé, _puco, _sòth,
   {{0x644d8058,0xf48410cc,0x63af5abf,0x62876251}},	// [8890] rnai, турн, _vecn, _pijo,
   {{0x644d687b,0x416b0274,0x00000000,0x00000000}},	//   snai, ојем_, --, --,
   {{0x62878059,0x682600fe,0x00000000,0x00000000}},	//   _vijo, _bódh, --, --,
   {{0x443203d0,0x628f0009,0x6287012f,0x2101011c}},	//   chy_, _tuco, _wijo, včić_,
   {{0x28c5051e,0x62870132,0xb33b0031,0xceeb00d1}},	//   _विभि, _tijo, _veçs, تران_,
   {{0x44297602,0x78760132,0x7a24021e,0x00000000}},	//   lka_, máve, _fòti, --,
   {{0x4429805a,0x78764743,0x7a240310,0x291800be}},	//   oka_, láve, _gòti, äral_,
   {{0xa3d713ab,0x2101044d,0x2d8c0282,0x00000000}},	//   _साफ_, rčić_, _egde_, --,
   {{0x44297a1e,0x7876805b,0x00000000,0x00000000}},	//   ika_, náve, --, --,
   {{0xe9d905c2,0xa2c20d2a,0x210100cd,0x00000000}},	//   чко_, _लिस्, pčić_, --,
   {{0x4429805c,0x186a2a8a,0x6846805d,0x00000000}},	//   kka_, зани_, енна, --,
   {{0x442935b9,0x00000000,0x00000000,0x00000000}},	//   jka_, --, --, --,
   {{0x4429805e,0x78760132,0x7c29805f,0x3ead0359}},	//   dka_, jáve, mker, _jwet_,
   {{0x44298060,0x78768061,0xf652004f,0xe7e1021a}},	//   eka_, dáve, ائح_, ग्बा_,
   {{0x7c298062,0xa50724c1,0xa96602fb,0x00000000}},	//   oker, нера_, _пиша_, --,
   {{0x44292aaf,0xf1dd142a,0x1ddf143a,0x787f02d4}},	//   gka_, न्सन, प्तत, _būvu,
   {{0x7c2906ba,0x28c50325,0x03f20033,0x443200ac}},	// [88a0] iker, _विडि, ঙালী_, rhy_,
   {{0x442901a8,0xe1f709a7,0x7a240260,0x3f8d021d}},	//   aka_, нгу_, _dòtw, _ageu_,
   {{0x7c290687,0x44328063,0x1dc9051d,0x3ead61f5}},	//   kker, phy_, _राजत, _awet_,
   {{0x44298064,0x7c290eef,0xbe8a03fa,0x768b0035}},	//   cka_, jker, пске_, _użyc,
   {{0x68262140,0x63b6010d,0xc8ec035d,0x78760279}},	//   _códi, mayn, _जन्म_, cáve,
   {{0x7c29727f,0x80db0083,0x3f8d0176,0x3ead0359}},	//   eker, ণিজ্, _egeu_, _dwet_,
   {{0x3da500d4,0xa3d78065,0x22963da1,0x00000000}},	//   тріб, _साम_, _hæk_, --,
   {{0x63b6010d,0x3a2e012f,0x7c298066,0x8aa60009}},	//   nayn, _slfp_, gker, нрод,
   {{0x661e54f7,0xa3ce00b8,0x7a2d07c0,0x00000000}},	//   _oopk, _राई_, _súta, --,
   {{0x44298067,0x63b6005f,0x7c298068,0x6da60079}},	//   zka_, hayn, aker, _أمام,
   {{0x4429006a,0xaac20026,0x78761438,0x63b60381}},	//   yka_, _शिवक, záve, kayn,
   {{0x2fc0004f,0x44298069,0x7c29806a,0x00000000}},	//   óigh_, xka_, cker, --,
   {{0x63b60430,0xa3d70026,0x5a46002d,0xead43e19}},	//   dayn, _साब_, _пэка, _роль,
   {{0x4429004e,0x7876805b,0xe98000d8,0x661e0160}},	//   wka_, váve, _калi_, _copk,
   {{0x661e0282,0x68260107,0x787f013a,0x00000000}},	//   _dopk, _nódw, _būvt, --,
   {{0x63b62d85,0x4429806b,0x787603e6,0x2c090035}},	//   gayn, uka_, táve, वाएं_,
   {{0x78ba806c,0xa3d70907,0x2be2022e,0x07f811c0}},	// [88b0] lstv, _साठ_, क्यं_, _سريع_,
   {{0x78762c7f,0x7c2906a2,0x51f83122,0x63b6010d}},	//   ráve, zker, нную_, aayn,
   {{0x78ba3015,0x682609ca,0x7fd512ea,0x69d800be}},	//   nstv, _sódi, вілі, _मानी,
   {{0x6448806d,0x764702e9,0x682673cb,0x2b2006d9}},	//   édit, lijy, _pódi, यहाँ_,
   {{0x141a134d,0xdb0b01b4,0x0af20831,0x00000000}},	//   _חורב, _udgø, জমুল_, --,
   {{0xf77402b5,0x78ba806e,0x00000000,0x00000000}},	//   נקס_, kstv, --, --,
   {{0x28c5258f,0x7c29806f,0xf4020043,0xc0c80fa7}},	//   _विधि, tker, _faţă_, _путе_,
   {{0x78ba02dd,0x5fd80026,0xa3e700b4,0x00000000}},	//   dstv, _डायल, _मॉम_, --,
   {{0x7c298070,0x3ed90037,0xce9500c3,0x00000000}},	//   rker, _زواج_, _разъ, --,
   {{0x28c51140,0x63b68071,0x00000000,0x00000000}},	//   _विदि, zayn, --, --,
   {{0x07a607f5,0xf9891328,0x78ba00ec,0x661e00b9}},	//   канн, بندي_, gstv, _ropk,
   {{0x25aa0517,0x661e06e7,0x7e638072,0x201f2c60}},	//   कर्ण, _sopk, lonp, _joui_,
   {{0xfc46053d,0x661e2cf6,0xe7e1020c,0xcc3a016b}},	//   ších_, _popk, ग्धा_, _קענט,
   {{0xceb25c8e,0x2c4c00b8,0x78ba15b5,0xb6a3002d}},	//   שים_, vědi_, bstv, рирл,
   {{0x63b64aec,0xdb0b006c,0x6abb008d,0xfa8800e2}},	//   tayn, _megí, lsuf, _cừu_,
   {{0x2ae51a75,0xdb0b115d,0xe8d60d85,0xa7fb0042}},	//   _कहाँ_, _legí, _סופר_, poña,
   {{0xd4670834,0x63b60095,0x661e8073,0x7e638074}},	// [88c0] тите_, rayn, _topk, konp,
   {{0xa3d70755,0x200d125e,0x2296054e,0x7d081f3c}},	//   _साथ_, _anei_, _væk_, _jérô,
   {{0x63b60159,0x644800a2,0x200d8075,0x64a664e1}},	//   payn, édis, _bnei_, _шана,
   {{0xd91a02b5,0xc95200a5,0x00000000,0x00000000}},	//   וועל, סמא_, --, --,
   {{0x78ba0187,0xd00f1ee1,0x200d0160,0x00000000}},	//   zstv, غله_, _dnei_, --,
   {{0x71a300af,0x200d023a,0x7e63055c,0x24800c6f}},	//   _варз, _enei_, gonp, lmim_,
   {{0x61fc8076,0x614618cd,0x7a2d07c0,0x6d5f013b}},	//   _iarl, _рева, _pútn, şqan,
   {{0x78ba0169,0x61fc2f42,0xdfd2004f,0x5f062e7c}},	//   vstv, _harl, _خير_, _изба,
   {{0x61fc8077,0xa3e41579,0x1e860369,0x25b88078}},	//   _karl, प्य_, _алам, karl_,
   {{0x78ba0d5c,0x68262dd3,0x61fe45a4,0x3ea68079}},	//   tstv, _módu, ndpl, mpot_,
   {{0x49731303,0x3ea6807a,0x2d9e0027,0x02de00be}},	//   ильс, lpot_, _ifte_, नझुन,
   {{0xa3ce017a,0x6d5a0453,0x9b430416,0xa3d707b5}},	//   _राग_, _ixta, انیو, _साध_,
   {{0x6f0261b1,0x68260a20,0x3ea602d0,0x8cca018d}},	//   nvoc, _nódu, npot_, संको,
   {{0x78ba6e20,0x6f022e1a,0xa4d576f4,0x7a24021e}},	//   pstv, ivoc, логі, _pòtu,
   {{0xfa7702b8,0xa3d7143a,0xa3ce5dc3,0x00000000}},	//   _שעות_, _साद_, _राख_, --,
   {{0x7876024e,0x3c310187,0x54540217,0x61fc0210}},	//   rávc, _káva_, авст, _aarl,
   {{0x61fc807b,0x2d9e1b99,0xa85800a5,0x337502f3}},	// [88d0] _barl, _ofte_, _שיחה_, угар,
   {{0x35f522da,0x6f02807c,0x41b50037,0xd49b00af}},	//   _спор, dvoc, امار, _орм_,
   {{0x61fc807d,0xdb0b0083,0x78767b47,0x6d4e02c4}},	//   _darl, _regí, láva, _žban,
   {{0xdb0b0332,0x61fc0122,0x28c507b5,0x2d9e807e}},	//   _segí, _earl, _विसि, _afte_,
   {{0x6d5a01c2,0x7876807f,0xc695016b,0x00000000}},	//   _axta, náva, נאַ_, --,
   {{0x7bc28080,0x61fc8081,0x00000000,0x00000000}},	//   _adou, _garl, --, --,
   {{0xeb991493,0x7e638082,0x8c450009,0x78761da9}},	//   ний_, ronp, леке, háva,
   {{0x200d0012,0x78762eef,0x7e63008c,0x1bb90037}},	//   _unei_, káva, sonp, رابع_,
   {{0x28c548cd,0x78763daf,0x76451f8b,0x61fc4582}},	//   _विहि, jáva, _omhy, _yarl,
   {{0x78762ab5,0x38693234,0x7bc28083,0x6b9b0036}},	//   dáva, _akar_, _edou, scug,
   {{0x2ba40d00,0x6abb05ee,0xa3e4021a,0x00000000}},	//   _ग्वा, ssuf, प्ड_, --,
   {{0x1ddf01c0,0x6e218084,0x2c090035,0xb8eb258f}},	//   प्रत, _holb, वाओं_, _लि_,
   {{0x28c50c03,0x09e50b46,0x44f500b8,0x787600b5}},	//   _विवि, _болн, _ať_, gáva,
   {{0x38698085,0xaf760070,0x7f3a016b,0x00000000}},	//   _ekar_, טערס_, געשו, --,
   {{0x69c3053d,0x6e210254,0xa3ea002d,0xa7fb01ef}},	//   _idne, _molb, ндва_, coño,
   {{0x78764078,0x24800207,0x00000000,0x00000000}},	//   báva, umim_, --, --,
   {{0x24808086,0x9f440359,0xdb000176,0x6e2103d0}},	// [88e0] rmim_, _lamò_, lamò, _oolb,
   {{0xf1a901ca,0xdb0b0176,0x2480021d,0xdb1b01ef}},	//   نامه_, _megà, smim_, nguñ,
   {{0x61fc67d8,0x3ebf0012,0x61fe1cd4,0x19b602b5}},	//   _varl, _avut_, rdpl, רפער_,
   {{0x6aad048c,0x68fc035b,0x3ea60159,0x29078087}},	//   _ħafn, ærdi, tpot_, _mrna_,
   {{0xc7d70122,0x61fc8088,0x69c3030a,0x6d5f00a8}},	//   רוני_, _tarl, _odne, şqal,
   {{0x6e218089,0xccfa0202,0x4422808a,0x3ea60298}},	//   _colb, ећи_, _hok_, rpot_,
   {{0x6aa229f1,0xf8c50518,0x442201ca,0x4095808b}},	//   _stof, _विषय, _kok_, _врут,
   {{0x69c3808c,0x3b061505,0x6826006c,0x4422808d}},	//   _adne, _proq_, _móds, _jok_,
   {{0x2907808e,0x5a347f5f,0xa3d71a75,0x2bd5808f}},	//   _arna_, инит, _सास_, _धारा,
   {{0x2ba40d00,0xa3e4258f,0xa2d50cf1,0x28c52afe}},	//   _ग्रा, प्त_, यंत्, _विशि,
   {{0x8d9302aa,0x44228090,0x290703fd,0x7d930082}},	//   _المش, _ook_, _crna_, _المؤ,
   {{0x628e8091,0x44220b41,0x815702b5,0x78762e51}},	//   _libo, _nok_, רסטע_, táva,
   {{0xa3ce0e1d,0x290751e0,0x68260176,0xdb0058ae}},	//   _राज_, _erna_, _ródt, ramó,
   {{0x7c2202e6,0x44228092,0x628e8093,0x787662a8}},	//   _hoor, _aok_, _nibo, ráva,
   {{0x44228094,0x78768095,0x7a36002d,0x55580b97}},	//   _bok_, sáva, _câte, гаря_,
   {{0x442201d6,0x26de002d,0x628e01ed,0x78761da9}},	//   _cok_, ător_, _aibo, páva,
   {{0x44220537,0x7c228096,0x628e2631,0x290700cd}},	// [88f0] _dok_, _moor, _bibo, _zrna_,
   {{0xe7e114ab,0x628e8097,0x7d0827fe,0x6aa40031}},	//   ग्रा_, _cibo, _ords, _çifu,
   {{0x645a1423,0x44228098,0xdb0b006c,0x7a3600f7}},	//   étic, _fok_, _megá, _gâte,
   {{0x7c220276,0x6e2133d4,0xe8d702b8,0x2ba40e68}},	//   _noor, _solb, רואר_, _ग्ला,
   {{0x44c100d8,0x27e98099,0x628e809a,0xb3ba0122}},	//   lė_, _mban_, _fibo, _במרכ,
   {{0x7d081269,0x628e809b,0xa194005f,0xdb0b809c}},	//   _brds, _gibo, _гарч, _negá,
   {{0x4422809d,0x44c101c8,0x7c2209a6,0xa3dc1fb4}},	//   _yok_, nė_, _boor, _ठाम_,
   {{0x0c250d07,0x63ad809e,0x628e04fb,0x3cec0139}},	//   рмин, nban, _zibo, _dpdv_,
   {{0x9ed901c8,0x63ad08dd,0x7c22809f,0x2907011c}},	//   _шмат_, iban, _door, _srna_,
   {{0x63ad64b6,0x44c100d8,0x4a451bdf,0x6f0966a7}},	//   hban, kė_, рнов, _irec,
   {{0x7c222efa,0x8e84004f,0x63ad80a0,0x4c95021d}},	//   _foor, _الله, kban, _тиес,
   {{0x6f0980a1,0x2907012f,0x7bc700d8,0x63ad80a2}},	//   _krec, _vrna_, ėjus, jban,
   {{0x44220865,0x8aa780a3,0x63ad80a4,0xf7720d93}},	//   _rok_, _сред, dban, تاد_,
   {{0x44220ef5,0xbb3a0122,0x63ad29c5,0x27e901d7}},	//   _sok_, _בעני, eban, _eban_,
   {{0x628e80a5,0xd7a7143a,0x89da0122,0x44c1010b}},	//   _ribo, _क्वच, _יחסי, gė_,
   {{0x63ad482c,0x6f0980a6,0x628e80a7,0x25a60160}},	//   gban, _orec, _sibo, _şold_,
   {{0xa3d700c4,0x967601c8,0x6aa40290,0x628e1b71}},	// [8900] _सार_, _выні, _çift, _pibo,
   {{0x154603fa,0x63ad72d8,0xb77b011d,0x78520228}},	//   _веом, aban, _באפש, dāvi,
   {{0x628e80a8,0xeaf21a75,0x442280a9,0xa2c20035}},	//   _vibo, _अन्त_, _tok_, _लिक्,
   {{0x6f0980aa,0x35dc0ccf,0x44226ad1,0xe3bf01ef}},	//   _brec, _बाड़, _uok_, _poñe_,
   {{0x628e80ab,0x6f0909ab,0xe7e800a1,0x7c224171}},	//   _tibo, _crec, ट्या_, _roor,
   {{0x7c2280ac,0x6f0980ad,0x7d00006c,0x2eed0036}},	//   _soor, _drec, járá, _dpef_,
   {{0x7c2280ae,0xdb0b0187,0xdd9903d0,0x787d00b5}},	//   _poor, _regá, уші_, léve,
   {{0x6f0980af,0x645680b0,0x69d800a1,0xf65f08c8}},	//   _frec, nnyi, _माही, træk_,
   {{0x7c221cd5,0x2be2012f,0xadba004f,0x44c1010b}},	//   _voor, क्षं_, _لهذا_, zė_,
   {{0x7c22019c,0xbae300d8,0x63ad80b1,0xc9860043}},	//   _woor, іцый, zban, иуни,
   {{0xa3d727bd,0x78760076,0x63ad80b2,0xdca302c4}},	//   _साल_, rávn, yban, _дахи,
   {{0x44c100d8,0x63ad026e,0x3e7b00f7,0x7a2d58ae}},	//   vė_, xban, rête_, _lúth,
   {{0xdc3b016b,0x787d00fd,0x00000000,0x00000000}},	//   _בעאר, jéve, --, --,
   {{0x44c101c8,0xa3e40518,0x27ff1bd8,0xdb0b08c8}},	//   tė_, प्स_, žun_, _begæ,
   {{0x3a7b0070,0xd4981346,0x9f5f021d,0xf3ff021d}},	//   _שטוד, ирт_, _cauê_, _paã_,
   {{0x27e90b04,0x44c1010b,0x645600b5,0xe3b30d93}},	//   _uban_, rė_, gnyi, ترس_,
   {{0x44c100d8,0x63ad1425,0x09dd0033,0x98ab0067}},	// [8910] sė_, rban, _ভোটা, ącą_,
   {{0xe7e80755,0x44c100d8,0xa6e30093,0x63ad80b3}},	//   ट्ठा_, pė_, óður, sban,
   {{0x26140e1d,0x6f0910e5,0x63ad15c5,0x7a2d0098}},	//   दारी_, _srec, pban, _dúth,
   {{0x6f09012c,0x78520228,0xe3b84c7b,0xe81a021a}},	//   _prec, tāvi, _ключ_, धाया_,
   {{0x6da50f68,0x644d80b4,0x7a2d0079,0x59c60099}},	//   била, miai, _fúth, लणार,
   {{0x644d80b5,0x3cf302e4,0x6f0980b6,0x14b80a86}},	//   liai, ंबले_, _vrec, _حدیث_,
   {{0x6f09001e,0x7c9401f1,0x30a4052c,0x00000000}},	//   _wrec, орыц, _мртв, --,
   {{0x6f090012,0x644d08a2,0x628580b7,0x26c480b8}},	//   _trec, niai, lmho, ámok_,
   {{0x6f09002d,0x7a240359,0x00000000,0x00000000}},	//   _urec, _pòtp, --, --,
   {{0xe8f97920,0x6ce700d4,0x644d1622,0x787600b5}},	//   гло_, _віде, hiai, távo,
   {{0x69d80456,0x644d021f,0x999e010b,0x60c30079}},	//   _मारी, kiai, entų_, ánmh,
   {{0x628501da,0x9b95004f,0x2bdd00be,0xa3e70026}},	//   hmho, _الإت, क्खू_, _मॉल_,
   {{0xbb850082,0x7c3b80b9,0x2bdc06d9,0x644d80ba}},	//   _الشي, mhur, _याता, diai,
   {{0xe5a30fc5,0x35a3005f,0x7c3b80bb,0x00000000}},	//   зири, зарг, lhur, --,
   {{0x64a6021d,0x2ba600b8,0xc98700af,0xe6435da8}},	//   саба, síců_, _туди, черп,
   {{0x7c3b80bc,0x628580bd,0x787d00b5,0x59dd073f}},	//   nhur, emho, téve, _माडर,
   {{0xd3b90a93,0x00000000,0x00000000,0x00000000}},	// [8920] русі_, --, --, --,
   {{0x26c20169,0xf77200fd,0x787d80be,0x00000000}},	//   msko_, _واک_, réve, --,
   {{0x2bf94f13,0x787d006c,0xd00a1676,0x644d7c7b}},	//   ्यां_, séve, леже_, biai,
   {{0x644d0bb0,0xdb00008d,0x764e80bf,0x00000000}},	//   ciai, mamö, liby, --,
   {{0x26c20bc9,0x2f181897,0x7c3b80c0,0x44320076}},	//   nsko_, роль_, dhur, mky_,
   {{0x4432031b,0x509603fa,0x40960dd0,0xa3e42218}},	//   lky_, _грађ, _грат, प्र_,
   {{0x4420010b,0x16190461,0x3171008c,0x00000000}},	//   oji_, दातर_, _gyzz_, --,
   {{0x44323e79,0x38970160,0xa06a1e47,0x00000000}},	//   nky_, _gări_, _саба_, --,
   {{0x26c203ab,0x443200fe,0x9b6a0f8f,0x4420023a}},	//   jsko_, iky_, ышка_, iji_,
   {{0x26c205e2,0x644d0409,0x443200d5,0x7a3600f6}},	//   dsko_, ziai, hky_, _bâta,
   {{0x290a0370,0x443280c1,0xd7f50aeb,0x7c3b009e}},	//   íba_, kky_, озны, bhur,
   {{0x442080c2,0x4432024e,0x26c218b0,0xdb0b013c}},	//   jji_, jky_, fsko_, _begä,
   {{0x4432114d,0x442080c3,0x7c65004f,0x644d6fef}},	//   dky_, dji_, _بالل, viai,
   {{0x4420010b,0x645a534f,0x291880c4,0xb4950200}},	//   eji_, étin, äras_, живљ,
   {{0x59dd05e7,0x644d80c5,0x00000000,0x00000000}},	//   _मातर, tiai, --, --,
   {{0xb4e94f02,0x442000da,0x26c20a69,0x224a008c}},	//   _यही_, gji_, bsko_, _ambk_,
   {{0x644d80c6,0x1dc80785,0xe3bf0453,0x96f900af}},	// [8930] riai, रणात, _coña_, _тепт_,
   {{0x442019c6,0x1fb30387,0x644d80c7,0xe3bf00de}},	//   aji_, ुण्ड, siai, _doña_,
   {{0x4432024e,0xdce801c0,0x43953832,0x442080c8}},	//   bky_, _vzdě, _манс, bji_,
   {{0x443280c9,0x44200755,0x2e2b08c8,0x1b1e0033}},	//   cky_, cji_, _løft_, _বেছে_,
   {{0x44391010,0x9f05004f,0xe81a0084,0x09d00083}},	//   _ils_, توشو, धाता_, ়্যা,
   {{0x81e70831,0x00000000,0x00000000,0x00000000}},	//   _মোর_, --, --, --,
   {{0xfe7000bf,0x7c3b80ca,0x4439055c,0x38970160}},	//   رده_, thur, _kls_, _tări_,
   {{0x5ac90139,0x3cfe80cb,0xeb991402,0x00000000}},	//   алим_, _dstv_, шии_, --,
   {{0xb4d60084,0x7c430c99,0x7c3b80cc,0x9c7c0107}},	//   _सम्_, _ćurč, rhur, _apčs,
   {{0x7c3b80cd,0x443228f6,0x442080ce,0x26c220ee}},	//   shur, zky_, zji_, vsko_,
   {{0x35d3004e,0x44322f62,0x9d55126b,0x26c20035}},	//   _ताज़, yky_, _بنات, wsko_,
   {{0x26c228c2,0x186a80cf,0xa4140083,0x69da0b0d}},	//   tsko_, рами_, _সত্য_, agte,
   {{0x44323255,0x28c54069,0x442080d0,0x26c200c7}},	//   vky_, _विकि, vji_, usko_,
   {{0x443980d1,0x80ca0033,0x442008c7,0x00000000}},	//   _als_, _রহস্, wji_, --,
   {{0x443268ac,0xa2c20edf,0x764e80d2,0x442080d3}},	//   tky_, _लिङ्, riby, tji_,
   {{0x26c22d17,0xd5dc0299,0x7bdb80d4,0xe3bf0042}},	//   psko_, _बावज, nguu, _poña_,
   {{0x44320076,0x42261d6b,0x442080d5,0x2bdc00a1}},	// [8940] rky_, одав, rji_, _यासा,
   {{0x4432114d,0x44394045,0x6aa4004f,0x4420004e}},	//   sky_, _els_, _éife, sji_,
   {{0x4432024e,0x10a6233a,0x442080d6,0x44390279}},	//   pky_, циен, pji_, _fls_,
   {{0x7876024e,0x4f0a290a,0x23e10325,0xa2a208b6}},	//   dávk, инен_, _फायद, _कंप्,
   {{0x7e6a1c1c,0xa25b01ba,0x69da01b4,0xdb02009e}},	//   tofp, _kvôl, ygte, _leoò,
   {{0x63a480d7,0x61460210,0x00000000,0x00000000}},	//   lcin, _дега, --, --,
   {{0x672f004e,0x61ee0024,0x443902ee,0x16b70f06}},	//   zycj, _ibbl, _yls_, _अब्ब,
   {{0x7a2d80d8,0xa7fb01ef,0x2fda0919,0x00000000}},	//   _mútu, poñi, _خورد_, --,
   {{0x63a480d9,0x6a7401f7,0xa2a2021a,0x00000000}},	//   icin, làfi, _कंफ्, --,
   {{0x200680da,0x200480db,0x00000000,0x00000000}},	//   ldoi_, _hami_, --, --,
   {{0x2004319d,0xc27b02b5,0x63a43b48,0x69da80dc}},	//   _kami_, שריי, kcin, rgte,
   {{0x200680dd,0x8b6a80de,0x63a40124,0x672f0067}},	//   ndoi_, _киев_, jcin, tycj,
   {{0x61ee27f8,0x7bc080df,0x78ad0009,0x7c65128b}},	//   _obbl, mamu, _čave, _عامل,
   {{0x7bc080e0,0x200480e1,0x63a40029,0x443980e2}},	//   lamu, _lami_, ecin, _sls_,
   {{0x6e280a8a,0x659480e3,0x27e00211,0x2aa001da}},	//   _modb, дару, _fcin_, _hòb_,
   {{0x320d06d0,0x7bc004f7,0x2aa002d0,0x6e28008c}},	//   _şey_, namu, _kòb_, _lodb,
   {{0xa3dc00a1,0x44390107,0xa3cd0067,0x2aa00359}},	// [8950] _ठार_, _vls_, रणब_, _jòb_,
   {{0x7bc080e4,0x26d9010d,0x290e0009,0xdb190107}},	//   hamu, muso_, _krfa_, _dewè,
   {{0x7bc080e5,0x31c42830,0x26d980e6,0x63a480e7}},	//   kamu, ьств, luso_, bcin,
   {{0x7bc080e8,0x200480e9,0x6e3a02b1,0xa295093e}},	//   jamu, _cami_, _altb, _намі,
   {{0x81e70b52,0xdefb03ad,0x7bc080ea,0x248980eb}},	//   _মোঃ_, рые_, damu, mmam_,
   {{0x9e340823,0x63bd008c,0x24895232,0xf1e2021a}},	//   мечч, _hesn, lmam_, _पायन,
   {{0x660580ec,0x20045ab9,0x629d4052,0x26d900e9}},	//   _mahk, _fami_, _huso, huso_,
   {{0x629d80ed,0x660580ee,0x7bc0563f,0x69ca00e9}},	//   _kuso, _lahk, gamu, _adfe,
   {{0x63bd1977,0x768b004e,0x6e28054e,0x629d80ef}},	//   _mesn, _używ, _fodb, _juso,
   {{0x2bab0bdd,0x629d80f0,0x63bd154c,0x26d924a5}},	//   _ट्रा, _muso, _lesn, duso_,
   {{0x60c501f4,0x7bc080f1,0x2004027c,0x629d80f2}},	//   nshm, bamu, _yami_, _luso,
   {{0x63bd80f3,0x26d980f4,0x7bc06cbc,0xa3d700ab}},	//   _nesn, fuso_, camu, _साग_,
   {{0x66054322,0x78760187,0x8b9a00a5,0xdb0b00b5}},	//   _bahk, návi, _הבנת, _legú,
   {{0x8b05006a,0x60c501f4,0x80cc045c,0xd9454419}},	//   _częś, kshm, _हिले, _нели,
   {{0x69c180f5,0x60c500da,0x63bd80f6,0xe3bf00de}},	//   male, jshm, _besn, _coño_,
   {{0x69c180f7,0x629d80f8,0x26d980f9,0x63bd0030}},	//   lale, _buso, buso_, _cesn,
   {{0x63a480fa,0xe363730d,0x62950332,0x63bd0121}},	// [8960] rcin, екти, _bizo, _desn,
   {{0x69c180fb,0x200480fc,0x7bc00010,0x63a410a7}},	//   nale, _sami_, zamu, scin,
   {{0x6d4380fd,0x200402e9,0x629580fe,0x7bc01643}},	//   jzna, _pami_, _dizo, yamu,
   {{0x38a10082,0x69c180ff,0x6d431bd8,0x63bd8100}},	//   _mór_, hale, dzna, _gesn,
   {{0x7bc00006,0x629d0232,0x2004308a,0x63bb00be}},	//   vamu, _guso, _vami_, _õuna,
   {{0x69c18101,0x629506a2,0x7bc00428,0x7ae400c3}},	//   jale, _gizo, wamu, _äiti,
   {{0x69c18102,0x2ee677f3,0x7bc08103,0x2004012e}},	//   dale, stof_, tamu, _tami_,
   {{0x28c50066,0xf8c51bb5,0x629d8104,0x7764002a}},	//   _विजि, _विजय, _yuso, _oxix,
   {{0x69c1504a,0x7bc08105,0x6e280b3e,0x00000000}},	//   fale, ramu, _todb, --,
   {{0x69c18106,0x7bc08107,0x7f3b0122,0x7bcb0168}},	//   gale, samu, _העמו, _edgu,
   {{0xa3dc065a,0x7bc00f3a,0x38a10098,0x00000000}},	//   ठला_, pamu, _cór_, --,
   {{0x7d7b02b5,0x3157134d,0x66058108,0x26d90409}},	//   _פראג, ליין_, _sahk, tuso_,
   {{0x69c18109,0x63bd02c6,0xe3bf01dd,0x47340012}},	//   bale, _resn, _soño_, еняс,
   {{0x69c1810a,0x38a100fb,0x28c51746,0x26d9810b}},	//   cale, _fór_, _विचि, ruso_,
   {{0x63bd810c,0x26d9810d,0x7876024e,0x629d810e}},	//   _pesn, suso_, závi, _suso,
   {{0x26d9810f,0x629d8110,0xab5d0035,0xdd3b0070}},	//   puso_, _puso, saże, זעלכ,
   {{0xdb0b0083,0x63bd15b5,0x24898111,0xe81a0d91}},	// [8970] _segú, _vesn, rmam_, धारा_,
   {{0x60c500da,0xddc301ba,0x63bd57cb,0x1758011d}},	//   tshm, konš, _wesn, _מסחר_,
   {{0x63bd45ba,0x787d00f7,0x62958112,0xe3b000b5}},	//   _tesn, névo, _vizo, ئرہ_,
   {{0x69c18113,0x60c500da,0x629d01a8,0x32180036}},	//   zale, rshm, _tuso, _enry_,
   {{0x69c18114,0x442b8115,0xe80e00b1,0xd7db030f}},	//   yale, _ioc_, ियता_, _भाईच,
   {{0x442b0019,0x78760187,0x69d800a1,0x238a00a0}},	//   _hoc_, rávi, _मागी, ňujú_,
   {{0xc2120122,0x60c50055,0x442b8116,0x00000000}},	//   _בהם_, qshm, _koc_, --,
   {{0x442b8117,0x7a2d01ef,0x2cac00e2,0x00000000}},	//   _joc_, _nútr, _dtdd_, --,
   {{0x69c18118,0x442b1a36,0xe8211db9,0x3e72000d}},	//   tale, _moc_, याना_, gâts_,
   {{0x442b0012,0x38a101dd,0x3da70c98,0x88c9263b}},	//   _loc_, _pór_, _храб, олов_,
   {{0xa3cd0517,0xda1f00a1,0xd9453c16,0x8c3c045e}},	//   रणा_, बाबत_, фени, _buğd,
   {{0x69c18119,0x442b15b3,0x7a24021e,0x6d5f013b}},	//   sale, _noc_, _mòty, şqas,
   {{0xa3d71782,0x7c2b0176,0x260a00b4,0x01d50033}},	//   _साज_, _iogr, ायली_, স্যদ,
   {{0x69c10be2,0xf1ba0019,0x7ae9811a,0x7a3f000d}},	//   qale, ươi_, mtet, _bête,
   {{0x6a7d12c3,0x442b002d,0x1de0018d,0x00000000}},	//   lèfo, _boc_, _नासत, --,
   {{0x998300d8,0x3ead811b,0x26c400b5,0x776401ed}},	//   ųjų_, _otet_, ámos_, _txix,
   {{0x7ae9811c,0x442b811d,0x7c2b4884,0xa2d50461}},	// [8980] ntet, _doc_, _mogr, यंग्,
   {{0x7c2b09ab,0x7ae903ad,0x7a3f0248,0x2fcd811e}},	//   _logr, itet, _fête, _adeg_,
   {{0x361b0100,0x7ae9811f,0x442b3752,0x26c90254}},	//   _וויד, htet, _foc_, _zvao_,
   {{0xdfcf0082,0x442b8120,0x7ae98121,0xfe6f132d}},	//   ليم_, _goc_, ktet, یدو_,
   {{0x7ae9006c,0xbea311b9,0xbefa0e0c,0xe29f0093}},	//   jtet, вачк, تراض_, _guð_,
   {{0x768b0755,0x6d090026,0x0caa2368,0xe3bf01ed}},	//   _użyt, विंग_, отии_, _zeñ_,
   {{0xa3e50b47,0xe29705f2,0xe8212160,0x16db07b5}},	//   _नाम_, _цар_, यामा_, _बम्ब,
   {{0x09c600a1,0x7ae98122,0x442b0310,0xa2d5258f}},	//   लण्य, ftet, _xoc_, यूक्,
   {{0xae1e52cf,0x78ad00cd,0x7ae93e4c,0x00000000}},	//   पादन_, _čava, gtet, --,
   {{0x1e837044,0x00000000,0x00000000,0x00000000}},	//   _алум, --, --, --,
   {{0x6d5f1505,0x7ae98123,0x7c2b8124,0x00000000}},	//   şqar, atet, _fogr, --,
   {{0x7c2b0118,0x00000000,0x00000000,0x00000000}},	//   _gogr, --, --, --,
   {{0x7ae9099e,0x5b36028c,0x6ec10ea3,0xf65305f5}},	//   ctet, _تعار, रीपु, نئس_,
   {{0xbbbe045c,0x7c2b0861,0x6b82008b,0x442b8125}},	//   _एजुक, _zogr, _izog, _soc_,
   {{0x442b12c3,0x00000000,0x00000000,0x00000000}},	//   _poc_, --, --, --,
   {{0xb7e60c67,0x7a3f0248,0xe7e6020d,0x443d0035}},	//   _कायम_, _vête, _काया_, ów_,
   {{0x442b1af8,0x52158126,0x7d1c008d,0x00000000}},	// [8990] _voc_, ндат, _ársf, --,
   {{0x7a3f00f7,0x442b008c,0x7a240107,0x6b82023c}},	//   _tête, _woc_, _pòty, _mzog,
   {{0x7ae98127,0xb06b1646,0xf77001cb,0x442b8128}},	//   ztet, ордж_, _مای_, _toc_,
   {{0x7ae98129,0x442b812a,0x644812c3,0x76550359}},	//   ytet, _uoc_, èdit, lizy,
   {{0xd00e026e,0x6b8204fb,0x00000000,0x00000000}},	//   صلو_, _nzog, --, --,
   {{0x7c2b1ec5,0xa3cd170c,0x00000000,0x00000000}},	//   _sogr, रणव_, --, --,
   {{0xdfd50086,0xba3d0355,0x6b820027,0xa2bb170c}},	//   _повы, způs, _azog, शीर्,
   {{0x9b051109,0xfd650019,0x9f5f0183,0xd7db021a}},	//   езид, _khuẩ, _cauã_, _भागच,
   {{0xed58016f,0x3ead0036,0xa3e40127,0x249902d7}},	//   _veľa_, _utet_, प्ट_, _mism_,
   {{0x7ae9812b,0xe29f0093,0xa2a200b4,0x3b0d0055}},	//   rtet, _urðu_, _कंस्, rveq_,
   {{0x7ae9812c,0x61e100fb,0x2911812d,0x7c2b0037}},	//   stet, _öllu, íza_, _togr,
   {{0x39580037,0x249908b7,0x7ae9812e,0x7c5700fd}},	//   úrsa_, _nism_, ptet, _کلچر_,
   {{0x7655812f,0x00000000,0x00000000,0x00000000}},	//   fizy, --, --, --,
   {{0xceb28130,0xa6e3003e,0x00000000,0x00000000}},	//   רים_, áðas, --, --,
   {{0xa80601d6,0x3d12046c,0x00000000,0x00000000}},	//   _alış, थिये_, --, --,
   {{0x2af3007c,0x35dc0461,0x52aa02fb,0x6287081b}},	//   _अहाँ_, _बाक़, звам_, _ahjo,
   {{0x96968131,0xfd650028,0xa6960836,0x9c82024e}},	// [89a0] _прош, _chuẩ, _прој, íčin,
   {{0xa3e500c4,0xa3dc0722,0xe8141ca8,0x00000000}},	//   _नाथ_, _ठाक_, _तोता_, --,
   {{0x261d13ab,0x78ab0043,0xc693016b,0x00000000}},	//   मारी_, _învă, _גאז_, --,
   {{0xe29a11ce,0x41e202cb,0xdfd200d1,0xa067146b}},	//   _нам_, _पावस, ايش_, наха_,
   {{0x64568132,0xe29a03e6,0xe82107df,0x00000000}},	//   miyi, _хаг_, याता_, --,
   {{0x64563b40,0x09d50033,0xdd920934,0x78ad023a}},	//   liyi, ত্তা, هوش_, _čavn,
   {{0x787600ac,0x00000000,0x00000000,0x00000000}},	//   návs, --, --, --,
   {{0x64560471,0xab5d0067,0xcd030421,0x00000000}},	//   niyi, waża, учши, --,
   {{0x81e70083,0xeaaf00d1,0x6a7401f7,0xda7a010b}},	//   _মোট_, یعی_, dàfr, зян_,
   {{0xc3330122,0x61fe8133,0x5a34029f,0xa2d50380}},	//   טוח_, nepl, тнот, यूट्,
   {{0x76551473,0xab5d0035,0x64568134,0x00000000}},	//   vizy, raża, kiyi, --,
   {{0x9cd70bed,0xfaa632c9,0x415b02b5,0x80d33010}},	//   _טובה_, _задо, לדיג, _डिसे,
   {{0x645601c2,0xe6670c9f,0x29030093,0x261d0266}},	//   diyi, етво, æjar_, माली_,
   {{0x61fe154f,0x320a0173,0x7b0600ea,0xeb070079}},	//   jepl, _naby_, ērtī, _أقوى_,
   {{0xe82127bd,0x5fd002cb,0x61fe8135,0x9f5f0132}},	//   यादा_, हणाल, depl, _mauá_,
   {{0x765502e9,0x60de046a,0x897b00a5,0x320a0a8a}},	//   sizy, dupm, _מרוצ, _aaby_,
   {{0x2fc6043d,0xc299311c,0x3a2e0176,0x7bc20107}},	// [89b0] daog_, дках_, _kofp_, _meou,
   {{0x61fe8136,0x6467024e,0x7a360248,0x56950043}},	//   gepl, _špič, _bâti, _шапт,
   {{0x659511b9,0x64560662,0x41e2049c,0xcf270088}},	//   _јану, biyi, _पारस, کراي,
   {{0x644425e4,0x26cb6f84,0x00000000,0x00000000}},	//   chii, osco_, --, --,
   {{0x44298137,0x61fe8138,0x320a0371,0x00000000}},	//   mja_, bepl, _faby_, --,
   {{0xee383665,0x20093cf1,0x00000000,0x00000000}},	//   нні_, žai_, --, --,
   {{0x25e90992,0x44291db7,0x78ad022f,0x6ecd0066}},	//   _जानी_, oja_, _čavo, _सिकु,
   {{0xeb99296f,0x2d9e03bc,0x09d90099,0x00000000}},	//   мий_, _egte_, ढल्य, --,
   {{0xe7db10a6,0x4429018f,0x0c2200af,0x00000000}},	//   _भाजप, ija_, рмын, --,
   {{0x44298139,0xc3340bed,0x6aa201a2,0x645601a8}},	//   hja_, רוץ_, _duof, ziyi,
   {{0x186a1159,0x4429813a,0x00000000,0x00000000}},	//   дани_, kja_, --, --,
   {{0x4429813b,0x2d850723,0x7bc20d35,0x2c170067}},	//   jja_, _izle_, _geou, थाओं_,
   {{0x4429813c,0xf0920779,0x7c29813d,0x3f9f002f}},	//   dja_, ינט_, mjer, _mguu_,
   {{0x7c3b813e,0x4429813f,0x16190026,0x7a3f00a2}},	//   lkur, eja_, दागर_, _fêta,
   {{0xa3cd01d1,0x644408dd,0x44298140,0x26cb027a}},	//   रणं_, thii, fja_, asco_,
   {{0x44298141,0x29070088,0x69c38142,0x3f9f0103}},	//   gja_, _isna_, _hene, _nguu_,
   {{0x69c30a13,0xe29a0132,0x645653a1,0x7c3b003e}},	// [89c0] _kene, даа_, riyi, ikur,
   {{0x64448143,0x69c38144,0x44298145,0x64568146}},	//   shii, _jene, aja_, siyi,
   {{0x69c3247e,0x7c3b8147,0xa5d902b5,0x44298148}},	//   _mene, kkur, _אַרי, bja_,
   {{0x44290755,0xdefa061c,0x69c38149,0x03a60a22}},	//   cja_, дык_, _lene, _шимо,
   {{0xab5d004e,0x7c29814a,0xdee328ea,0x57cd016b}},	//   ważn, djer, иоци, למאַ,
   {{0x60de017b,0x6f0202b1,0xdd2b0409,0x28c20067}},	//   pupm, rwoc, _dėže, वीडि,
   {{0x409628d7,0x6f02814b,0x71760833,0x78a3007b}},	//   _арат, swoc, _شهرا, _nunv,
   {{0xdb0b0370,0x629c814c,0x06b80083,0x7c29814d}},	//   _negó, _hiro, _জিনি, gjer,
   {{0x629c814e,0x4e0603fa,0xbea601d3,0x3f84011c}},	//   _kiro, _изаб, _разк, _uzmu_,
   {{0x69c3814f,0x44298150,0x6569027d,0x629c8151}},	//   _cene, zja_, şehi, _jiro,
   {{0x69c38152,0x787d0248,0x7c29054e,0x35dc004e}},	//   _dene, lévi, bjer, _बाज़,
   {{0xc1730122,0x7c3b8153,0x629c0055,0x2fc4021d}},	//   יחת_, ckur, _liro, _jemg_,
   {{0x69c38154,0x44298155,0xada2008a,0xa2a200ab}},	//   _fene, vja_, _þúsu, _कूल्,
   {{0x629c8156,0xcf9300a5,0x78a38157,0x00000000}},	//   _niro, יטר_, _funv, --,
   {{0x44296e9f,0x69c88158,0xd49b3f96,0xd5a60647}},	//   tja_, made, дра_, الفی,
   {{0x69c33a54,0x04b80332,0x030e1fc3,0x4429010b}},	//   _zene, کھیں_, सिंह_, uja_,
   {{0x629c8159,0x7ae000d7,0x69c3815a,0xd6d800af}},	// [89d0] _biro, numt, _yene, _итэ_,
   {{0x69c803c1,0x4429815b,0x69c3043f,0xa3e5255b}},	//   nade, sja_, _xene, _नाव_,
   {{0x4429815c,0x629c815d,0xdb0b0955,0x645a0443}},	//   pja_, _diro, _segü, ètic,
   {{0x629c0080,0x442900da,0x69c82f84,0x645a0248}},	//   _eiro, qja_, hade, étit,
   {{0x7c290280,0x63ad815e,0x60ce00e0,0xeabd0033}},	//   vjer, mcan, _evbm, _আম্ম,
   {{0x629c5216,0x69c8815f,0x7ae0011e,0x3ea450e8}},	//   _giro, jade, dumt, _dumt_,
   {{0x69c81423,0x7c298160,0x69c38161,0x7c3b8162}},	//   dade, tjer, _rene, tkur,
   {{0x63ad0b0e,0x69c38163,0x6edb0437,0x69c802d7}},	//   ncan, _sene, _निपु, eade,
   {{0x69c30ce8,0x7c291638,0x201f012f,0x629c0371}},	//   _pene, rjer, _inui_, _yiro,
   {{0x69c88164,0x629c8165,0x7c2901e0,0x27e98166}},	//   gade, _xiro, sjer, _acan_,
   {{0x69c38167,0x6a7d0392,0x00000000,0x00000000}},	//   _vene, nèfi, --, --,
   {{0x69c38168,0xb8cb0035,0x8c3c0a21,0x63ad07e7}},	//   _wene, _कं_, _tuğa, jcan,
   {{0x69c38169,0x69c8816a,0xeaae0043,0x7bc90118}},	//   _tene, bade, _ый_, maeu,
   {{0xe81400ab,0x69c308c7,0x2bb308b0,0x27e90027}},	//   _तोरा_, _uene, ीरवा, _ecan_,
   {{0x7a360160,0x290700f4,0x2aa90168,0x00000000}},	//   _câtu, _usna_, _húb_, --,
   {{0x629c816b,0x7bc930bc,0x6f0900cd,0x60da013c}},	//   _siro, naeu, _osec, _åtmi,
   {{0x629c5910,0xe8211282,0xe73a00af,0xa3e526c6}},	// [89e0] _piro, यारा_, _чеп_, _नार_,
   {{0x629c0024,0x63ad7979,0x09d50033,0x7bc90408}},	//   _qiro, acan, ত্রা, haeu,
   {{0x25e90f8a,0x629c816c,0x6f0902d7,0x645a00f7}},	//   _जाती_, _viro, _asec, étis,
   {{0x63ad01d3,0x61e502a8,0x4ad40084,0x69c8245d}},	//   ccan, aghl, _दिलव, zade,
   {{0x68e1816d,0x69c8816e,0x24800cca,0x6f0900fd}},	//   huld, yade, mlim_, _csec,
   {{0x248001d2,0x69c8816f,0xd2520e3a,0x9985010b}},	//   llim_, xade, _طنز_, nklų_,
   {{0x69c88170,0x6f097a57,0x61464a35,0x2ca5009e}},	//   vade, _esec, _сева, _culd_,
   {{0x69c80088,0x68e13155,0x2ca50298,0x2fc4021d}},	//   wade, duld, _duld_, _uemg_,
   {{0x69c88171,0xfbcf06ca,0x6edb114e,0x38a80248}},	//   tade, ستي_, _नियु, _sûr_,
   {{0xdd8f026b,0x7ae08172,0x2ca501b4,0x63ad8173}},	//   _کوم_, rumt, _fuld_, zcan,
   {{0x63ad0669,0xe8210429,0x6e93004f,0x68e10029}},	//   ycan, याला_, _اللا, guld,
   {{0x7bc900d7,0xdd2000fe,0x00000000,0x00000000}},	//   caeu, _kůže, --, --,
   {{0x69c88174,0xd90e00d1,0x63ad0e31,0xb8cb0722}},	//   pade, زیک_, vcan, _कू_,
   {{0xdd20000c,0x199400d8,0x69c80024,0x7a3600a2}},	//   _může, _каля, qade, _pâtu,
   {{0x68e10370,0x65950370,0x63ad4f93,0xdb0b0093}},	//   culd, раву, tcan, _hegð,
   {{0x63ad1d4c,0x93b54326,0xf1e2000c,0x24800eac}},	//   ucan, рбац, _पाउन, glim_,
   {{0x28da0803,0x32558175,0x00000000,0x00000000}},	// [89f0] _भिडि, авар, --, --,
   {{0x61e5006d,0x6fc70761,0x95391783,0x00000000}},	//   ughl, ारभू, _азот_, --,
   {{0x63ad2909,0x320105ed,0xdb0b05ee,0xdfd10037}},	//   pcan, rehy_, _legð, قيا_,
   {{0xa2dd0edf,0x6f0929e7,0x8fc704a3,0x3f150281}},	//   _पिप्, _psec, ازان, идес,
   {{0x260a00a1,0xe7e60067,0xddc51ade,0x6b84009e}},	//   ायची_, कलता_, абли, _ùigh,
   {{0xed598176,0x6a7d02d0,0xfaff0031,0x6f090355}},	//   кол_, pèfi, çëm_, _vsec,
   {{0xe7e60299,0x7bc9012f,0xb7e6046c,0x5184010b}},	//   _काला_, taeu, _कालम_, _гута,
   {{0x201f0012,0x3ff902b5,0x68e18177,0x2aa901f7}},	//   _unui_, _שפּע, vuld, _púb_,
   {{0x6f090009,0x5ac6004b,0x2ba600b4,0x00000000}},	//   _usec, алым_, _ऑलरा, --,
   {{0x3869457f,0xf2d40070,0xa2dd8178,0x68e18179}},	//   _ajar_, זעץ_, _पिन्, tuld,
   {{0xa9690de3,0xd8260cb5,0x8bd516e6,0x38690069}},	//   тина_, адни, _نقاش, _bjar_,
   {{0x68e1817a,0xe73a3f6b,0x657e0298,0x985656f6}},	//   ruld, вем_, _ryph, ртош,
   {{0x657e817b,0x81dd0033,0x3869035f,0xb887008d}},	//   _syph, থ্য_, _djar_, _smíð,
   {{0xbb840037,0xf77300ff,0xf3ff021d,0x261d0066}},	//   _الهي, تاپ_, _bjão_, मागी_,
   {{0x776d01ef,0xf4840df3,0x248000f4,0x764500ee}},	//   _exax, ماری, tlim_, _dlhy,
   {{0x76450282,0x00000000,0x00000000,0x00000000}},	//   _elhy, --, --, --,
   {{0x645a02e1,0x248024cb,0xb8650413,0x2be300ab}},	// [8a00] étiq, rlim_, _داوو, _गाईं_,
   {{0x41b607e5,0xfe6503fc,0xb22300af,0x98be0035}},	//   рсат, _رگ_, омул, sztą_,
   {{0x4fc600d8,0x248000cd,0x765c817c,0x00000000}},	//   асла, plim_, miry, --,
   {{0x41e2009a,0xf992011d,0x351b00a5,0xdfd000bc}},	//   _पाकस, קרא_, _סוכנ, سيت_,
   {{0x6446817d,0x2d81033b,0x4422024b,0x00000000}},	//   _ilki, ühen_, _ink_, --,
   {{0x44223485,0x15ee052f,0x00000000,0x00000000}},	//   _hnk_, _जाफर_, --, --,
   {{0xdb0b008d,0xc117006c,0xb4e41371,0xdce1010b}},	//   _segð, _پہنچ_, _नमो_, _mylė,
   {{0x10a33804,0x26d2002f,0xafe30009,0x765c76a0}},	//   _фитн, _ovyo_, _мосл, hiry,
   {{0x4422025c,0xd5c67b58,0x765c817e,0xaa664670}},	//   _mnk_, वराज, kiry, иток,
   {{0x4422817f,0x5cf6010b,0x00000000,0x00000000}},	//   _lnk_, _вяду, --, --,
   {{0x29188180,0x44220107,0x00000000,0x00000000}},	//   íra_, _onk_, --, --,
   {{0xdb19033b,0xdb090392,0xd9ea1b8f,0xa3e500ab}},	//   _bewä, cceï, ज्जत_, _नाइ_,
   {{0x7c228181,0x95cb2351,0x9a865568,0x29020355}},	//   _inor, кува_, _кукл, ňka_,
   {{0x644661f5,0xfd11006c,0xdbf80033,0xa8a602d5}},	//   _alki, _بجے_, _অফিস_, _крик,
   {{0x3cfe0b3e,0x00000000,0x00000000,0x00000000}},	//   _jptv_, --, --, --,
   {{0x442201f2,0x67220009,0x38695db0,0xda7800d5}},	//   _cnk_, _šoje, _ujar_, loď_,
   {{0xdb1902c9,0xf1a70011,0x499200bf,0x765c0679}},	// [8a10] _gewä, арен, _دیگر, biry,
   {{0x7d1a8182,0xe4e701e0,0xab790070,0x00000000}},	//   _orts, _кімн, אָעז, --,
   {{0x7c228183,0x245900af,0xdcfa00a0,0x1bf80963}},	//   _onor, _бань_, _bytč, ्जाल_,
   {{0x5f9503e6,0x7c2203c1,0x00000000,0x00000000}},	//   биет, _nnor, --, --,
   {{0x93fa0122,0xdfce0079,0xa28200d1,0x09de0033}},	//   _גלרי, ريو_, _کیلو, ব্যা,
   {{0xc33200c2,0xdca5081b,0x7d1a00d7,0x9f5600b5}},	//   _צום_, баки, _brts, ágát_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x765c2f7e,0x44220023,0x44d31c90,0x0c2502c8}},	//   ziry, _xnk_, ić_, смин,
   {{0x3cfe0183,0x7d1a0210,0x753c0067,0xa3e502b4}},	//   _eptv_, _erts, zyrz, _नाई_,
   {{0x4a455654,0x79e7006c,0x3e7b0248,0x2b4d0035}},	//   снов, جودہ_, rêts_, rzec_,
   {{0xc7a60fa7,0x499900c3,0x3cfe0282,0x00000000}},	//   йинк, ытия_, _gptv_, --,
   {{0xa92700ac,0x6f1b8184,0x32110147,0x00000000}},	//   _alží, _kruc, _lazy_, --,
   {{0x683f00da,0x44d3004e,0x4422042a,0xac74004f}},	//   _mëdh, eć_, _rnk_, _بالش,
   {{0x7c2247c2,0x00000000,0x00000000,0x00000000}},	//   _znor, --, --, --,
   {{0x25e95bba,0xf1ca024e,0x15431d67,0x442200d7}},	//   _जारी_, ntáž_, перм, _pnk_,
   {{0x6f1b8185,0x765c8186,0x47c61053,0xf1c700d5}},	//   _oruc, siry, _убив, hráč_,
   {{0x23270ea4,0xe1fa144b,0xa2dd01d1,0x44d30035}},	// [8a20] боти_, лга_, _पिण्, ać_,
   {{0x15460a9f,0x175700a5,0xf1ca00d5,0x3f740160}},	//   _геом, _לספר_, ktáž_, _rπu_,
   {{0x0ce20b52,0xd17901c8,0x6f1b2da5,0xdfda0382}},	//   _মন্ত, асці_, _aruc, гъл_,
   {{0xdd2c010b,0x6f1b8187,0x442205f5,0x00000000}},	//   _nėšt, _bruc, _unk_, --,
   {{0x6f1b54cf,0x21d803c5,0xa2a202e4,0xd00f0037}},	//   _cruc, _نژاد_, _कंट्, عله_,
   {{0x6f1b02c9,0xa2dd8188,0x7d1a0051,0xf1e2021a}},	//   _druc, _पित्, _prts, _पाटन,
   {{0xd132028c,0x6f1b0069,0x61e3003e,0xa7fb01ef}},	//   _عمر_, _eruc, ónle, liñe,
   {{0x6f1b8189,0xf063818a,0x3f740160,0x00000000}},	//   _fruc, _експ, _tπu_, --,
   {{0x25e9049c,0x00000000,0x00000000,0x00000000}},	//   _जाली_, --, --, --,
   {{0xd90e03c5,0x09c80033,0x683f0031,0xd9e200b4}},	//   فیت_, _শাহা, _zëdh, पलेट,
   {{0x5d860082,0x28f800d4,0x7d1a0065,0x00000000}},	//   _الال, шень_, _urts, --,
   {{0x7c22818b,0x673d0421,0x96eb00d8,0xa7fb01ed}},	//   _unor, tysj, льга_, kiñe,
   {{0x21270023,0x3c38000d,0x6c7b0070,0x1dac0067}},	//   ̣nh_, _févr_, _גראד, _चलात,
   {{0xe66755c5,0x25a50b3e,0x1bf81a75,0x6b820371}},	//   стмо, øll_, ्जवल_, _iyog,
   {{0x3211004e,0x6b82012f,0x00000000,0x00000000}},	//   _razy_, _hyog, --, --,
   {{0x94a8818c,0x6b82018e,0x290e0069,0x2d8c0168}},	//   стра_, _kyog, _isfa_, _mzde_,
   {{0xf7f400f8,0x69ca818d,0x78aa1ba3,0xa7fb01ed}},	// [8a30] _رسيد, _kefe, _hufv, giñe,
   {{0x6b820602,0xa3e50387,0x69ca818e,0x00000000}},	//   _myog, _नाक_, _jefe, --,
   {{0x66070009,0x321100d5,0x31c4010b,0x6b82001c}},	//   mejk, _vazy_, яств, _lyog,
   {{0x69ca818f,0x753a033b,0x291c0124,0x66070067}},	//   _lefe, ätze, _mrva_, lejk,
   {{0x644d41f0,0x69ca152b,0x171c02b5,0xa2830105}},	//   mhai, _oefe, ָווע, _فیرو,
   {{0x644d8190,0x6f1b8191,0x30a77d2c,0x5bb30907}},	//   lhai, _vruc, _грав, ीर्व,
   {{0x6b8209d6,0x80d30026,0x00000000,0x00000000}},	//   _ayog, _डिटे, --, --,
   {{0x69d82212,0x62850484,0x644d8192,0x6b827b8e}},	//   _adve, llho, nhai, _byog,
   {{0x69ca8193,0x6f1b8194,0x69d80176,0x291c783b}},	//   _befe, _uruc, _bdve, _arva_,
   {{0xe8f95a4f,0x6abb7b41,0x6b82010d,0x2dd4002d}},	//   ало_, rpuf, _dyog, _нжур,
   {{0x69ca1c1d,0x644d8195,0x246100d8,0x61fa006c}},	//   _defe, khai, nėms_, _ötle,
   {{0x291c2676,0x69d88196,0xc85a01e0,0xa3e50f06}},	//   _drva_, _edve, ршої_, _नाग_,
   {{0x644d0058,0x7bcb0029,0x7cef0176,0x291c092a}},	//   dhai, _iegu, _fòrç, _erva_,
   {{0x64a68197,0xe7e66017,0x69ca8198,0xceb20070}},	//   жава, _काका_, _gefe, ויך_,
   {{0x845a0eb4,0x7bcb1096,0xe5a30fc5,0x644d8199}},	//   арат_, _kegu, дири, fhai,
   {{0x644d41f0,0xe3ba4ae8,0x6285438f,0x6aa359af}},	//   ghai, рба_, elho, _hinf,
   {{0x7bcb819a,0x764b010b,0x69c10116,0x4dca0033}},	// [8a40] _megu, _įgyv, oble, _রাসূ,
   {{0x69c1819b,0xa7fb01dd,0x69ca01dd,0x7a3f000d}},	//   nble, riñe, _xefe, _bêti,
   {{0x644d41f0,0x60c70221,0x6aa3035f,0x69c1819c}},	//   bhai, _cwjm, _minf, ible,
   {{0x644d102d,0x6aa31755,0xef1a819d,0x69c15baa}},	//   chai, _linf, име_, hble,
   {{0x2f180fa7,0x63b40035,0xda090325,0x00000000}},	//   соль_, ągną, _वसंत_, --,
   {{0x6444819e,0x6edb48cd,0x6aa3819f,0x78a41b43}},	//   lkii, _निरु, _ninf, _liiv,
   {{0x69ca81a0,0xbc4a3525,0xe0d706c2,0xdd930409}},	//   _refe, ичие_, _мвр_, машы,
   {{0xdee61906,0x64440086,0x69ca81a1,0x7bcb1e60}},	//   _моби, nkii, _sefe, _cegu,
   {{0x7bcb81a2,0x9e6638d0,0x05bf04aa,0x5337016b}},	//   _degu, _двад, ्रमब, ַנטן_,
   {{0x291c1dce,0xa9540274,0x6aab008c,0x6aa3021d}},	//   _prva_, звољ, _dugf, _cinf,
   {{0x644400c3,0x644d81a3,0x78a4008c,0x2d8c1793}},	//   kkii, yhai, _biiv, _uzde_,
   {{0x69ba0f17,0x6aa381a4,0x644d0189,0x7bcb81a5}},	//   _श्री, _einf, xhai, _gegu,
   {{0x69c1029d,0x6aa30523,0x645f0031,0x78a481a6}},	//   bble, _finf, viqi, _diiv,
   {{0x7bcb81a7,0x69d808c8,0x291c00ac,0x7983016e}},	//   _zegu, _udve, _trva_, _fynw,
   {{0x644d30d2,0x660781a8,0x7bcb81a9,0x34950432}},	//   thai, rejk, _yegu, завр,
   {{0xe01902cb,0x68e881aa,0x2cac51c7,0x246100c7}},	//   _नोंद_, mudd, _mudd_, vėms_,
   {{0x644d81ab,0x68e881ac,0x645f01e9,0x00000000}},	// [8a50] rhai, ludd, riqi, --,
   {{0x659502f3,0x644d81ad,0x645f00a8,0x941b00ab}},	//   _напу, shai, siqi, _पोरच_,
   {{0xdb090082,0x68e881ae,0xceb90355,0xddda00fe}},	//   iceá, nudd, _stř_, _aktů,
   {{0x26c9000e,0x645f0510,0x224a01ed,0x00000000}},	//   _kwao_, qiqi, _elbk_, --,
   {{0x7bcb107d,0x2fcf81af,0x68e881b0,0x645d81b1}},	//   _regu, ragg_, hudd, _imsi,
   {{0x443981b2,0x2cac001e,0x26c90054,0x68e881b3}},	//   _hos_, _budd_, _mwao_, kudd,
   {{0x443981b4,0x7bcb81b5,0x6aa336c1,0xb0d800b4}},	//   _kos_, _pegu, _rinf, _डिएग,
   {{0x443981b6,0xef93006c,0x68e86ec2,0xdfd10037}},	//   _jos_, _قیاد, dudd, _سيئ_,
   {{0x443981b7,0x9f4f0831,0xab6581b8,0x7bcb81b9}},	//   _mos_, regó_, явил, _vegu,
   {{0x443981ba,0x7e550041,0x68e8018e,0x2cac00e9}},	//   _los_, _عناص, fudd, _fudd_,
   {{0x2cac00e5,0x3ead00f6,0x7bcb81bb,0x44393a21}},	//   _gudd_, _huet_, _tegu, _oos_,
   {{0xb9030084,0x69c101ae,0x186a2374,0x00000000}},	//   _फट_, sble, сами_, --,
   {{0x2fcd006d,0x3ea581bc,0x78a4073c,0x6aa32b72}},	//   _meeg_, _kilt_, _viiv, _tinf,
   {{0x4439130f,0x2fcd81bd,0x2d8581be,0x68e82c5d}},	//   _aos_, _leeg_, _kyle_, budd,
   {{0x443981bf,0x7ae981c0,0x78a418af,0x3ea50d3e}},	//   _bos_, luet, _tiiv, _milt_,
   {{0x2fcd0d4b,0x442609ab,0x443981c1,0x00000000}},	//   _neeg_, ño_, _cos_, --,
   {{0x443981c2,0x64442119,0xdcf40129,0x7ae90065}},	// [8a60] _dos_, rkii, _đačk, nuet,
   {{0x644402e2,0x7c39233c,0xa7fb1fdc,0x4ad400be}},	//   skii, _lowr, miña, _दिघव,
   {{0xe8210429,0x443981c3,0xa3e50387,0xc00600d4}},	//   याचा_, _fos_, _नाच_, зпек,
   {{0x7c393c8f,0x3ea50037,0x7ae901d7,0x443981c4}},	//   _nowr, _ailt_, kuet, _gos_,
   {{0x2fcd81c5,0x9cf80083,0xdfcf017e,0x3ea53184}},	//   _deeg_, _আছেন_, ايه_, _bilt_,
   {{0x44390189,0x3ead2c54,0xb14603fa,0x3ea5027d}},	//   _zos_, _duet_, _енгл, _cilt_,
   {{0xe7ed02cb,0x44390221,0x7c39012f,0x7d78042c}},	//   _झाला_, _yos_, _bowr, غمبر_,
   {{0x443981c6,0xbab84e91,0xaff600b5,0x3ead01f7}},	//   _xos_, огих_, _رہتا_, _fuet_,
   {{0x7ae981c7,0xdee354b8,0xa3e481c8,0x09bd0033}},	//   guet, _поти, _नयन_, _আয়া,
   {{0x2fcd0221,0x78ad0124,0x68e881c9,0xa7fb03c2}},	//   _zeeg_, _čavr, tudd, diña,
   {{0x6e28054e,0x2fcd006d,0xdb090079,0xa3c100b4}},	//   _indb, _yeeg_, rceá, ुरम_,
   {{0x68e881ca,0x7c390107,0x5f13018d,0x6fcc06fe}},	//   rudd, _gowr, _धनम्_, ारिं,
   {{0x44391e59,0xfaf704e8,0x7ae902d7,0xab831fd8}},	//   _ros_, _فروغ_, cuet, _пушк,
   {{0xc6a42626,0x7689008a,0xdb9b00a5,0xe81d135e}},	//   ерси, mþyk, _הסדר, _बोरा_,
   {{0x92e90b52,0x443981cb,0x6fcc02cb,0x92b90033}},	//   _মনে_, _pos_, ारां, _ঘটে_,
   {{0x765e018e,0x6e3a0260,0x00000000,0x00000000}},	//   _empy, _lotb, --, --,
   {{0x443981cc,0xe3b01c51,0xa7fb0391,0xe7c300db}},	// [8a70] _vos_, ارف_, ciña, _व्यप,
   {{0x443981cd,0xe6030421,0x00000000,0x00000000}},	//   _wos_, ätää, --, --,
   {{0x443981ce,0x7ae901b7,0x7d1c008d,0x00000000}},	//   _tos_, zuet, _ársh, --,
   {{0xaadd0299,0x2fcd01e8,0x645d81cf,0x4add07b5}},	//   _मिलक, _qeeg_, _umsi, _मिलव,
   {{0x3ea5007c,0x2fc00300,0x2fcd12ba,0x661743c6}},	//   _pilt_, ñiga_, _veeg_, _kaxk,
   {{0x248981d0,0x2d85334c,0x6e3a009e,0xf7740070}},	//   llam_, _pyle_, _cotb, עקס_,
   {{0x7c39004e,0x3ea581d1,0x2fcd006d,0xc87900d0}},	//   _powr, _vilt_, _teeg_, luğu_,
   {{0x3ea504ce,0x3cde0243,0x7ae906a2,0xdb022dea}},	//   _wilt_, _गिरे_, tuet, _egoí,
   {{0x6e3a81d2,0xd5bf00b4,0x4add02cb,0xa3d50066}},	//   _fotb, ्राज, _मिळव, _सजन_,
   {{0x39456bde,0x4ad7006c,0x2d85004e,0x7ae981d3}},	//   дног, _ہاتھ_, _tyle_, ruet,
   {{0x24897eec,0x2ca600d7,0x7ae901a3,0x37e60210}},	//   klam_, _fiod_, suet, монг,
   {{0x25c605f8,0x6d43010b,0x7e6300c3,0xa7fb002a}},	//   वर्ण, myna, linp, tiña,
   {{0x6d4381d4,0xba5502fb,0x00000000,0x00000000}},	//   lyna, _откъ, --, --,
   {{0xc8790d6f,0xa7fb27c2,0xdb210453,0x7e630328}},	//   duğu_, riña, _ñuño, ninp,
   {{0x6d4373a9,0xa7fb0042,0x98720097,0x00000000}},	//   nyna, siña, láč_, --,
   {{0xa7fb01dd,0x78b300ea,0x7e63081b,0x7a3f00a2}},	//   piña, ēgvā, hinp, _vêtu,
   {{0xd5af006c,0x6d43001e,0x64bc0254,0x98720097}},	// [8a80] افہ_, hyna, _očig, náč_,
   {{0x248981d5,0xe29733ed,0xdce8005f,0x63b60067}},	//   alam_, дау_, _gydė, scyn,
   {{0x987200ac,0x00000000,0x00000000,0x00000000}},	//   háč_, --, --, --,
   {{0x6d4381d6,0x7d1c0093,0x248981d7,0xb7db0070}},	//   dyna, _ársi, clam_, ַקצי,
   {{0xc8790225,0x6e3a0345,0xe29a0259,0x00000000}},	//   cuğu_, _potb, _мам_, --,
   {{0x7e6381d8,0xdcba1d13,0x64670067,0x2ca60284}},	//   ginp, ощи_, ąpił, _siod_,
   {{0x0ee002cb,0x00000000,0x00000000,0x00000000}},	//   _निवड, --, --, --,
   {{0x25de1e82,0x5b140dee,0xdb0200cc,0x61fe0110}},	//   कृती_, емит, _ngoã, lfpl,
   {{0xc5e600c8,0xa3c10006,0xf1b200dc,0x2fc681d9}},	//   খ্যা_, ुरत_, _जलान, mbog_,
   {{0x38601f1d,0x6d4381da,0x2fc61fcb,0x69340043}},	//   _amir_, byna, lbog_, еноу,
   {{0xc87f033b,0x321800a5,0x00000000,0x00000000}},	//   toß_, _mary_, --, --,
   {{0xb90626d4,0x987200d5,0x00000000,0x00000000}},	//   _पि_, báč_, --, --,
   {{0xd78b004f,0xdca378d4,0x3860009f,0x661701ed}},	//   تخدم_, _раци, _dmir_, _paxk,
   {{0x3eb90033,0x386081db,0x61fe0223,0x00000000}},	//   _éste_, _emir_, jfpl, --,
   {{0xae00021a,0x00000000,0x00000000,0x00000000}},	//   ल्यन_, --, --, --,
   {{0xd49881dc,0x66170051,0xa7fb01dd,0x32180160}},	//   дру_, _waxk, miño, _aary_,
   {{0x3218113c,0x6d43004e,0x61fe39d7,0x81ca0033}},	// [8a90] _bary_, zyna, ffpl, োলন_,
   {{0x32184c2e,0x248981dd,0xae00007c,0xd14b0bf5}},	//   _cary_, slam_, ल्मन_, يشان_,
   {{0xe3b00332,0x248901d6,0x32184a9c,0xa7fb0042}},	//   ارہ_, plam_, _dary_, niño,
   {{0x2fc681de,0x64bc009e,0x61fe0fdb,0x00000000}},	//   gbog_, _dčid, afpl, --,
   {{0xe456012b,0xdb020028,0xdee52235,0x442b81df}},	//   _נישט_, _ngoà, холи, _inc_,
   {{0x645a00ea,0x6d435bd3,0xee381645,0xef18010b}},	//   ītie, tyna, мні_, ьмі_,
   {{0x442b0118,0x6edb0355,0x7e631883,0x9ac40069}},	//   _knc_, _निकु, rinp, _loċċ,
   {{0x25ff0066,0xa19481e0,0x6d4381e1,0x442b01f7}},	//   श्ती_, _расч, ryna, _jnc_,
   {{0x442b1047,0x2ef401d3,0x00000000,0x00000000}},	//   _mnc_, _изтр, --, --,
   {{0x442b011e,0x08c52d1e,0x850f01c0,0x00000000}},	//   _lnc_, нбон, ाबाट_, --,
   {{0xa3c1046c,0xf86607be,0x00000000,0x00000000}},	//   ुरा_, евно, --, --,
   {{0x66e6182f,0x9ac4009f,0xdb0b0b3e,0x987200ac}},	//   нома, _boċċ, _afgå, páč_,
   {{0x7c2b81e2,0x7a3f00f6,0x00000000,0x00000000}},	//   _ingr, _dêtr, --, --,
   {{0x442b81e3,0xbb3a02b8,0x9ac4007a,0xa7fb01ef}},	//   _anc_, _מעני, _doċċ, biño,
   {{0xa7fb0391,0x26d90036,0xf2020461,0x3860009e}},	//   ciño, asso_, र्फ़_, _tmir_,
   {{0x321807df,0x00000000,0x00000000,0x00000000}},	//   _sary_, --, --, --,
   {{0x27e081e4,0x7afb280b,0xae000b57,0x2c010461}},	// [8aa0] _idin_, ntut, ल्डन_, व्यू_,
   {{0xb77b0122,0x98d308a9,0x7afb01a3,0x00000000}},	//   _מאפש, _दबाए, itut, --,
   {{0x26c00c21,0xaf360ef2,0x7afb00ab,0x442b021d}},	//   _htio_, کرات, htut, _fnc_,
   {{0x672481e5,0xdfcf317b,0x442b0453,0xa3c700e7}},	//   _krij, ميم_, _gnc_, _उभय_,
   {{0x2fc6049a,0x2fdf099e,0x00000000,0x00000000}},	//   rbog_, _ddug_, --, --,
   {{0x7c2b6af2,0x48e004cc,0xbea381e6,0xdb020023}},	//   _angr, _किलो_, гачк, _ngoá,
   {{0xa3e40b4a,0xafe61f6a,0xe10700af,0x7afb0176}},	//   _नया_, _повл, _перд_, etut,
   {{0x09d800a1,0x2ee6468b,0xa7fb01ef,0x00000000}},	//   ढण्य, prof_, viño, --,
   {{0x7afb383a,0xdb1901ae,0x46dc07b5,0x88bc0355}},	//   gtut, _gewü, _बिगह, zvěd,
   {{0xef1700d8,0x27e001a3,0x1f63002d,0xa0120831}},	//   _яму_, _adin_, _скум, _সচিব_,
   {{0x394500d7,0x67241ada,0x7afb01a3,0x629e8153}},	//   gyls_, _arij, atut, impo,
   {{0x67242bc6,0xa7fb0b4c,0xc17300a5,0x00000000}},	//   _brij, riño, טחת_, --,
   {{0x6724025c,0xa7fb01dd,0xdb0b0118,0x00000000}},	//   _crij, siño, _nggè, --,
   {{0x27e00092,0x672481e7,0x442b3cc0,0x34a9046c}},	//   _edin_, _drij, _snc_, कद्द,
   {{0x25a5022a,0x7c2b150b,0x27e00211,0x672414e7}},	//   äll_, _yngr, _fdin_, _erij,
   {{0x672481e8,0x6d58008b,0x6aaa008c,0x629e555d}},	//   _frij, izva, _hiff, empo,
   {{0xc6a70109,0x672481e9,0x6aaa5d82,0x88bc00b8}},	// [8ab0] _прои, _grij, _kiff, svěd,
   {{0x6aaa003c,0x6d580187,0xd9f00026,0xf77000f8}},	//   _jiff, kzva, चलित_, _چای_,
   {{0x442b7db9,0x7afb01d7,0xf1241482,0xdb190107}},	//   _tnc_, ztut, льцо, _jewò,
   {{0x629e0159,0x6aaa81ea,0x7afb0067,0xd3710413}},	//   ampo, _liff, ytut, _نهج_,
   {{0xa2cd08b0,0x798a0298,0xdb190260,0x7ff40698}},	//   दीश्, _lyfw, _lewò, اسما,
   {{0x6aaa81eb,0x2bc90569,0x00000000,0x00000000}},	//   _niff, रर्थ, --, --,
   {{0x92a6006a,0xdd910332,0xa1940036,0xa3d505e7}},	//   _dołą, گوں_, _барч, _सजा_,
   {{0x7afb01d3,0xcf7b0037,0x0c250279,0x6aaa00e5}},	//   ttut, _فإذا_, тмин, _aiff,
   {{0x5a9516e2,0xdd910332,0x6aaa684e,0x200f81ec}},	//   кроф, دوں_, _biff, megi_,
   {{0x7afb7471,0x200f81ed,0x6f0900d7,0x64bc0009}},	//   rtut, legi_, _ipec, _jčic,
   {{0x6aaa81ee,0x6724029d,0x7afb81ef,0xf1b2011d}},	//   _diff, _srij, stut, יסי_,
   {{0x672481f0,0xb8d9009a,0x201d6e3a,0x200f81f1}},	//   _prij, _अं_, ndwi_, negi_,
   {{0x6aaa1b4b,0x7bc900f1,0x64bc0c6e,0x629e5ba3}},	//   _fiff, mbeu, _očic, ympo,
   {{0x6724754c,0x6aaa0dc6,0x31cb1bb5,0x63bd35bc}},	//   _vrij, _giff, िरोध, _afsn,
   {{0x6b8b3c24,0x7ae91123,0x32cf0035,0x660501b7}},	//   _hygg, lret, eży_, _dbhk,
   {{0xc95201f3,0x27e0022e,0x15ee0035,0x6aaa5b2e}},	//   _כמו_, _udin_, _जाकर_, _ziff,
   {{0x64a316ef,0x7ae936a2,0x93431dd0,0xfbd20122}},	// [8ac0] рата, nret, анте, יתן_,
   {{0x33201d35,0x6b8b45cd,0xddd8003d,0x00000000}},	//   rvix_, _mygg, kovš, --,
   {{0xd8770332,0x64930095,0x69ce0093,0x7ae91008}},	//   _سمیت_, mçin, ðbei, hret,
   {{0x69460274,0xddd80bcc,0xe8050864,0x7a3e0355}},	//   _učeš, dovš, ष्पा_, _zátě,
   {{0x92a6004e,0x00000000,0x00000000,0x00000000}},	//   _połą, --, --, --,
   {{0x7ae904d7,0x68e8001e,0x975b00a5,0x7bc956e9}},	//   dret, yrdd, ודנט, ebeu,
   {{0x7ae93fb8,0x6f0901ef,0x200f3f83,0x00000000}},	//   eret, _epec, begi_, --,
   {{0x6b8b81f2,0x6aaa81f3,0x200f81f4,0x7ae981f5}},	//   _bygg, _siff, cegi_, fret,
   {{0xa06703fa,0x2d8101ae,0x3075002d,0x8fa31108}},	//   _рата_, üher_, _сурс, _вате,
   {{0x5ea616a4,0x3eb90033,0x628300cd,0x81e40033}},	//   _شمال, _ésta_, čnog, ভ্র_,
   {{0x67d50ded,0x7ae981f6,0x7bc9009e,0x00000000}},	//   лону, aret, bbeu, --,
   {{0x4bda0164,0x7ae981f7,0x00000000,0x00000000}},	//   _آباد_, bret, --, --,
   {{0x7ae91c1d,0xf804010b,0xa3d60387,0x6aaa81f8}},	//   cret, шчэн, हरन_, _tiff,
   {{0x25bf23db,0xceb30317,0x7d1c008d,0x200f81f9}},	//   ्रेण, ייש_, _árss, zegi_,
   {{0x984f004e,0xc7c7192f,0x3eac0c61,0x2d8c0a8a}},	//   jęć_, _испи, _midt_, _jyde_,
   {{0x3eac0022,0x57f53626,0x628733d4,0xc1cb316e}},	//   _lidt_, _спит, _skjo, िर्ग,
   {{0xb2754e91,0x200f008d,0x2d8c0249,0xbebd00c7}},	// [8ad0] глаш, vegi_, _lyde_, _arūn,
   {{0x78ad006d,0x7aef12c3,0x32541334,0xbebd0228}},	//   _hiav, àcti, авур, _brūn,
   {{0xf1a7257f,0x7ae981fa,0x2d8c08c8,0x00000000}},	//   тран, zret, _nyde_, --,
   {{0x672202c4,0x25ff0ed1,0x7ae981fb,0x3eac023a}},	//   _šoji, श्री_, yret, _aidt_,
   {{0x200f81fc,0x3eac78a3,0x78ad034d,0x00000000}},	//   regi_, _bidt_, _miav, --,
   {{0x7ae981fd,0x644d03ad,0x6b8b0b87,0xddd80b67}},	//   vret, lkai, _rygg, tovš,
   {{0x628581fe,0x30a71018,0x62830009,0xa3c70099}},	//   moho, _арав, čnod, _उभा_,
   {{0x62850187,0xc1720122,0x644d81ff,0x3a2e02d7}},	//   loho, _החל_, nkai, _anfp_,
   {{0x6a850421,0xac96004f,0x7bc98200,0xca8507e5}},	//   ллиа, دنيا_, rbeu, лгий,
   {{0x7ae98201,0x3f7a00c2,0xe8c914d0,0x62850187}},	//   rret, _אָבע, нгол_, noho,
   {{0x7ae900cb,0x644d0086,0x2ba40324,0x78ad0b3e}},	//   sret, kkai, खेबा, _biav,
   {{0x7ae90044,0x62858202,0x78ad0f38,0x6b8b8203}},	//   pret, hoho, _ciav, _tygg,
   {{0x78ad8204,0x3b092e50,0x7d1c008d,0x38ba0228}},	//   _diav, _чело_, _ársr, _vīra_,
   {{0xa2dd14ab,0x644d00c7,0x1dc60808,0x75d60037}},	//   _पिज्, ekai, रुपत, طيرا,
   {{0x62858205,0xdb0b01b4,0x78ad0036,0x649a13f8}},	//   doho, _afgø, _fiav, етар_,
   {{0x644d39cf,0x78ad8206,0x00000000,0x00000000}},	//   gkai, _giav, --, --,
   {{0x33d50044,0x28d70edf,0x8c1d0033,0x00000000}},	// [8ae0] ріст, _भौति, থাপন_, --,
   {{0x6456070b,0x628501a2,0xe8050ec5,0x7e1d0567}},	//   shyi, goho, ष्ठा_, पयोग_,
   {{0x4fea0665,0x00e68207,0x3eac007a,0x00000000}},	//   емен_, ужен, _ridt_, --,
   {{0x6493013b,0x644d291f,0xa3c107df,0x00000000}},	//   nçil, ckai, ुरः_, --,
   {{0x44208208,0x661e8209,0xbe8a3668,0x6285820a}},	//   mdi_, _kapk, нске_, boho,
   {{0x6285820b,0x661e0051,0xd252820c,0x00000000}},	//   coho, _japk, _انس_, --,
   {{0x4420820d,0x3eac0c61,0x649300c1,0x661e0c3d}},	//   odi_, _vidt_, kçil, _mapk,
   {{0x3ed60df3,0x661e010b,0x8fa60171,0x628300f4}},	//   _مقرر, _lapk, _бабе, čnoe,
   {{0x78ad0382,0x4420820e,0xa2dd07b5,0x0a6a0ece}},	//   _riav, idi_, _पिछ्, ерни_,
   {{0x644d820f,0x661e8210,0x5fcc00b4,0x2d8c8211}},	//   zkai, _napk, ारकल, _tyde_,
   {{0x19948212,0x61e3003e,0x78ad407a,0xec1304cd}},	//   раня, ónli, _piav, _گوند,
   {{0x4d7b168d,0x44201f6f,0x6ac30083,0x661e0051}},	//   _ארבע, jdi_, _শিরো, _aapk,
   {{0xead48213,0x44208214,0xa2b013a0,0x629c024e}},	//   _толь, ddi_, _अंग्, _ohro,
   {{0x44208215,0xda0800f3,0x2bd20380,0xa25b021d}},	//   edi_, _شيعه_, सरवा, _atôn,
   {{0x44208216,0x78ad006d,0x644d03ad,0xa4d500d4}},	//   fdi_, _tiav, tkai, робі,
   {{0x69da7bf9,0x44208217,0x629c0009,0x6285011e}},	//   late, gdi_, _ahro, woho,
   {{0xe8050026,0x644d4322,0x629c0094,0x335861ad}},	// [8af0] ष्णा_, rkai, _bhro, гатэ_,
   {{0x644d3caa,0x7d1a2197,0x629c09c1,0x44208218}},	//   skai, _osts, _chro, adi_,
   {{0x212700e8,0x44208219,0x62852259,0x629c09c3}},	//   ính_, bdi_, roho, _dhro,
   {{0x69da821a,0x62850010,0xa3d61343,0xa3b9007c}},	//   hate, soho, हरण_, _चलि_,
   {{0x629c01da,0x62830009,0xd2f600b5,0xa7fb01ed}},	//   _fhro, čnob, _نکلا_, giñi,
   {{0x69da821b,0x20d71dbf,0x629c0341,0xb6bc016b}},	//   jate, _مترج, _ghro, עצוי,
   {{0x69da821c,0xa3b90fd1,0x6d4a131e,0x00000000}},	//   date, _चला_, gyfa, --,
   {{0x6ee70164,0x50f4081b,0x3eb900de,0x64bc011c}},	//   _مسئل, _ызст, _ésto_, _očin,
   {{0x7c3b821d,0x69da00e9,0xa3d60084,0x92020026}},	//   rjur, fate, हरत_, र्वज_,
   {{0xf41f013c,0xc33200a5,0x7c3b01bf,0xa3b9007c}},	//   _skäl_, קוי_, sjur, _चलऽ_,
   {{0x4420821e,0x64930463,0x00000000,0x00000000}},	//   ydi_, tçil, --, --,
   {{0x186a2eb3,0x38ca00f8,0x95ee0066,0x661e821f}},	//   тами_, کایی_, जल्ट_, _sapk,
   {{0x4420003c,0x6c84004f,0x6ed800dc,0x64930be2}},	//   vdi_, _النم, नीपु, rçil,
   {{0x69da0122,0xa9a50009,0xfed70083,0x79e7006c}},	//   cate, _килд, _সমাধ, _صوبہ_,
   {{0x442000a8,0x28765087,0x35a60009,0xd46a03e6}},	//   tdi_, _выпр, равг, виве_,
   {{0x629c8220,0x44208221,0x2b09004e,0x7bdb4733}},	//   _shro, udi_, _वहाँ_, nauu,
   {{0x44208222,0x661e4e37,0x629c2d9b,0x62668223}},	// [8b00] rdi_, _tapk, _phro, аваа,
   {{0x44208224,0x91e68225,0x09a90033,0x00000000}},	//   sdi_, роже, _খ্যা, --,
   {{0x44208226,0xdb19033b,0x6f1b01ef,0xe8d30354}},	//   pdi_, _gewö, _asuc, _दबोच,
   {{0x44206476,0x69da8227,0x00000000,0x00000000}},	//   qdi_, zate, --, --,
   {{0x629c0052,0x69da8228,0x60c924d4,0x6d4a00e9}},	//   _thro, yate, _čeme, wyfa,
   {{0xa11600f8,0x69da0051,0x6d4a8229,0x629c0168}},	//   _پورت, xate, tyfa, _uhro,
   {{0x69da822a,0xc0e30b25,0x3dcf0033,0x0637016b}},	//   vate, _морк, _রাখল, ינסט_,
   {{0x6d4a0090,0x00000000,0x00000000,0x00000000}},	//   ryfa, --, --, --,
   {{0x69da822b,0xe457011d,0x00000000,0x00000000}},	//   tate, ייקט_, --, --,
   {{0x38ba08e3,0x6f020051,0x2caf0044,0x228f018d}},	//   _për_, mtoc, _eigd_, tüki_,
   {{0xa3d608a9,0x6f02822c,0x2f0002d0,0x8be80033}},	//   हरा_, ltoc, lòg_, ক্ষন_,
   {{0x69da822d,0x64bc02c4,0xcb6701cb,0x00000000}},	//   sate, _pčin, امیه_, --,
   {{0x69da5112,0x6f02110e,0x00000000,0x00000000}},	//   pate, ntoc, --, --,
   {{0x69da0055,0x7ae2822e,0xb887008d,0xa3aa00b4}},	//   qate, _ivot, _blíð, गइन_,
   {{0x2492001e,0x0467822f,0x69d80228,0x7bc20183}},	//   flym_, атам, _ieve, _kfou,
   {{0x69d88230,0x6f028231,0x290e007b,0x212d068f}},	//   _heve, ktoc, _ipfa_, _čeh_,
   {{0x64bc1851,0x69d88232,0xddc300af,0x212a0079}},	// [8b10] _učin, _keve, ninţ, _arbh_,
   {{0x35f507be,0x78b8027d,0xa2cd0066,0x69d88233}},	//   _упор, _kuvv, दीग्, _jeve,
   {{0x69d80443,0xdfd1004f,0x2455017e,0x6f0200d7}},	//   _meve, كيا_, _هندس, etoc,
   {{0x69d88234,0x661501a3,0x61fc009e,0x7ae20124}},	//   _leve, lezk, _ecrl, _ovot,
   {{0x533500c2,0x48dd0006,0x4fe80823,0x69d802a2}},	//   _האָב_, _कौनो_, рмін_, _oeve,
   {{0x9e640a55,0x69d88235,0x661506a2,0xddc30043}},	//   овід, _neve, nezk, dinţ,
   {{0xc2120122,0x7ae20029,0xd65802b8,0x9d452f44}},	//   _מהם_, _avot, שיות_, сейд,
   {{0xeb998236,0x3ce902b2,0x66158237,0x00000000}},	//   лий_, čav_, hezk, --,
   {{0x69d88238,0x6f1b0814,0x290e04fb,0xc5ff0228}},	//   _beve, _usuc, _apfa_, ļēji_,
   {{0x2fdd01e8,0x69d8023a,0x7ae2030a,0x1dc600b4}},	//   lawg_, _ceve, _dvot, रुदत,
   {{0x69d83322,0x8d950082,0x66150291,0x00000000}},	//   _deve, _الاش, dezk, --,
   {{0xa8561453,0x3d01004e,0x6e218239,0xcd96011d}},	//   стој, mów_, _halb, _הדעת_,
   {{0x6e21823a,0x8b6800d4,0x0f790070,0x41a700a1}},	//   _kalb, _київ_, ראָב, केतस,
   {{0x69d80261,0x661501d7,0x65c3823b,0x00000000}},	//   _geve, gezk, збра, --,
   {{0x3d01006a,0xa3aa0e61,0x7bd902c2,0x764500d7}},	//   nów_, गेन_, _kewu, _dohy,
   {{0x69d85ef7,0x6f0264e8,0xab5d0035,0x6e210409}},	//   _zeve, ytoc, waży, _lalb,
   {{0x3aba02b5,0x7bd91096,0x03a33997,0x04431f6a}},	// [8b20] ָמענ, _mewu, зито, четн,
   {{0x3d010755,0x69c1823c,0x64bc011c,0xb69b6947}},	//   ków_, ncle, _učio, ltân,
   {{0x3d010035,0xd46a0043,0x00000000,0x00000000}},	//   jów_, _бине_, --, --,
   {{0x7bd92c67,0x3d01004e,0x6e21054e,0x6f02823d}},	//   _newu, dów_, _aalb, ttoc,
   {{0x8bff0083,0xd9f900a1,0x442201ed,0xdbff0831}},	//   ্যান_, ्भात_, _iak_, ্যাস_,
   {{0x64463221,0x6f02823e,0xddc300af,0x471b016b}},	//   _hoki, rtoc, vinţ, טונג,
   {{0x7bd902c0,0x644601c8,0x64bc823f,0x3d01004e}},	//   _bewu, _koki, _očim, gów_,
   {{0x44228240,0x64468241,0xce060088,0x69c38242}},	//   _jak_, _joki, _گذري, _afne,
   {{0x44228243,0x6e2101a6,0x69d88244,0x6446010b}},	//   _mak_, _falb, _peve, _moki,
   {{0xc33301f3,0x69d801d2,0x6e2133d1,0x6e962e36}},	//   פות_, _qeve, _galb, _الطا,
   {{0x3d01004e,0x78b80510,0xa3b90006,0x64460103}},	//   ców_, _quvv, _चलल_, _ooki,
   {{0x44228245,0x69d82cfa,0x7bd91bc9,0x6e21138c}},	//   _nak_, _weve, _gewu, _zalb,
   {{0x69d88246,0x76450076,0x661506a2,0xe787399d}},	//   _teve, _pohy, tezk, суно,
   {{0x7aef0033,0x7c221c18,0xa3cb03de,0x44228247}},	//   ácte, _haor, रुन_, _aak_,
   {{0x661506a2,0x64465c4d,0x5558002d,0xe5730037}},	//   rezk, _boki, баря_, سطس_,
   {{0x44228248,0x38698249,0x661501d7,0x2fdd01e8}},	//   _cak_, _umar_, sezk, xawg_,
   {{0x7c22824a,0x27e9008c,0x4422824b,0x6446824c}},	// [8b30] _maor, _idan_, _dak_, _doki,
   {{0x765c00e5,0xf1a71e38,0x442201a3,0x27e94dee}},	//   chry, брен, _eak_, _hdan_,
   {{0xf6520122,0xbebd2791,0x672d0314,0x64460c53}},	//   _חצי_, _trūk, _hraj, _foki,
   {{0x672d824d,0x7c222c3f,0x64bc0254,0x44220703}},	//   _kraj, _naor, _očij, _gak_,
   {{0xc1e900b5,0x3d010035,0x9327824e,0x69c10f00}},	//   _نکال_, wów_, _ارجن, ycle,
   {{0x3d01006a,0x6e21035f,0x4422824f,0xc3320319}},	//   tów_, _qalb, _zak_, _קום_,
   {{0xed594b2a,0x6e218250,0x44228251,0x64bc0009}},	//   рой_, _valb, _yak_, _ačij,
   {{0x3d01006a,0x7c228252,0x27e98253,0x09e10099}},	//   rów_, _caor, _ndan_, पण्य,
   {{0x6e213548,0x3d01006a,0x7c221a07,0xe3bf002a}},	//   _talb, sów_, _daor, _gañe_,
   {{0x27e98254,0xe9d903f5,0x3d01004e,0xda6500d4}},	//   _adan_, шко_, pów_, івни,
   {{0xd9450705,0x27e90069,0x7c22009e,0x672d0371}},	//   цени, _bdan_, _faor, _araj,
   {{0x672d8255,0x27e98256,0x7c22009e,0x69c111be}},	//   _braj, _cdan_, _gaor, scle,
   {{0x44228257,0xb69b8258,0x64468259,0x765c825a}},	//   _rak_, rtân, _roki, thry,
   {{0x44222829,0xb69b03e6,0x8aa71362,0xe93903c5}},	//   _sak_, stân, _уред, _نسبت_,
   {{0x4422825b,0x6446825c,0xa92700ac,0x27e90069}},	//   _pak_, _poki, _doží, _fdan_,
   {{0x64bc1635,0x7c2201ef,0x74b924c1,0x229400c3}},	//   _učim, _xaor, сурс_, mäki_,
   {{0xc5d900c8,0x4422825d,0x644600d8,0x672d825e}},	// [8b40] _তারপ, _vak_, _voki, _graj,
   {{0x44224e2a,0xd1960dec,0x00000000,0x00000000}},	//   _wak_, ошењ, --, --,
   {{0x6446825f,0x29050453,0xa3d50461,0xd5d0012f}},	//   _toki, ntla_, _सड़क_, _त्यज,
   {{0xd00a382e,0xddc30009,0xdfcf0413,0x44221684}},	//   реде_, vinš, نيم_, _uak_,
   {{0x9eaa8260,0x7c22009e,0x245c00b5,0x290500be}},	//   авда_, _raor, _címe_, htla_,
   {{0xe297342d,0x5bd20808,0x7c224883,0x412a1036}},	//   _мая_, सर्व, _saor, _кого_,
   {{0x910317c2,0xf9870148,0x7c220c6f,0x25d7016b}},	//   _опре, _آب_, _paor, קוקן_,
   {{0x2fc40132,0xa4b700a5,0x9c7c021e,0xcb0a010b}},	//   _ufmg_, חלקה_, _evčn, аход_,
   {{0x6fd05dc3,0x27e90211,0x00000000,0x00000000}},	//   _ड्यू, _rdan_, --, --,
   {{0x6da60573,0xda4a1e9c,0x76480421,0x00000000}},	//   _диза, рчил_, ödyl, --,
   {{0x26c9044d,0x7c221005,0xc1bb02b5,0x41bb02b5}},	//   _stao_, _taor, ימיש, יציע,
   {{0x672d8261,0xc86701e0,0x5fb100ab,0x00000000}},	//   _praj, ітни, ुँचल, --,
   {{0x5a46002d,0xa92700ac,0x3b0700af,0xa3cb00b4}},	//   _мэка, _poží, _мецо_, _र्ष_,
   {{0x672d8262,0x00000000,0x00000000,0x00000000}},	//   _vraj, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x672d5aa7,0xd6db03ad,0x27e98263,0xa3cb021a}},	//   _traj, _кто_, _udan_, _र्श_,
   {{0xddcb0cc1,0x245800c3,0x672d0371,0x8c1b024b}},	// [8b50] _čižm, цать_, _uraj, סומי,
   {{0x245c07c0,0xbebd00c7,0x00000000,0x00000000}},	//   _ríme_, _krūv, --, --,
   {{0x30151205,0xc0150086,0x7d0d0035,0x349503fa}},	//   здер, змещ, łasz, _наор,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ada0437,0x80dc0033,0xf43a024b,0x00000000}},	//   _मौलव, মূল্, _הגרמ, --,
   {{0x5187576e,0x82d6011d,0xb2ba00a5,0x245c0355}},	//   _дуба, _מושג_, _למשר, _víme_,
   {{0xdfd547ec,0xdb1b0391,0x29058264,0x00000000}},	//   _новы, rcuí, xtla_, --,
   {{0x0b4502fb,0xc57c0122,0x8027006c,0x245c8265}},	//   знин, ירות, _برآم, _tíme_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8f9199d,0xadf40374,0xbebd02d4,0xa3cb143a}},	//   бло_, _опуш, _brūv, रुत_,
   {{0xdcef010b,0x290502d7,0xbd6b0800,0x00000000}},	//   _įdėt, utla_, _трае_, --,
   {{0x315602b5,0x00000000,0x00000000,0x00000000}},	//   פירן_, --, --, --,
   {{0x69cc2b6d,0xd5b80228,0x00000000,0x00000000}},	//   _द्वी, žām_, --, --,
   {{0xfe7901c0,0x00000000,0x00000000,0x00000000}},	//   _svůj_, --, --, --,
   {{0xceb202b8,0x64a600d8,0x845a4ae8,0xae0002b4}},	//   תים_, зава, брат_, ल्टन_,
   {{0x98a38266,0x00000000,0x00000000,0x00000000}},	//   _пище, --, --, --,
   {{0x0877016b,0xf8b3076b,0x00000000,0x00000000}},	// [8b60] _מעקט_, _אשה_, --, --,
   {{0x059401cb,0x00000000,0x00000000,0x00000000}},	//   _يادگ, --, --, --,
   {{0x657a0079,0xfe790355,0x78a403d0,0x00000000}},	//   úthd, _tvůj_, _khiv, --,
   {{0xa06a0274,0xdd1e0355,0xa3cb052f,0x00000000}},	//   љада_, tíže, रुद_, --,
   {{0xddcf01c0,0x00000000,0x00000000,0x00000000}},	//   _řeše, --, --, --,
   {{0xdd940f8f,0x00000000,0x00000000,0x00000000}},	//   малы, --, --, --,
   {{0x64930095,0x64bc009e,0x09da0033,0x20da01df}},	//   rçiv, _dōig, _দালা, _دوزخ_,
   {{0x9e660416,0x321a22a3,0x244e00b8,0xd00701e0}},	//   _کارن, lepy_, _týmu_, _несе_,
   {{0xaae60037,0xbd010051,0x00000000,0x00000000}},	//   أسبو, _éénd, --, --,
   {{0x61fe8267,0x7aef0831,0xe3bf0138,0x78a40027}},	//   ngpl, ácta, _maña_, _ahiv,
   {{0xfe4502fd,0xf4b70033,0x2d9e0065,0x00000000}},	//   _تکنی, _জব্ব, _uzte_, --,
   {{0x78a48268,0x7ac60036,0x6b82006d,0x64440793}},	//   _chiv, _еске, _txog, jjii,
   {{0x2bd214ab,0x78a48269,0xb903046c,0x81e20033}},	//   _ध्या, _dhiv, _पौ_, _ধান_,
   {{0x80d20083,0x195800c7,0x00000000,0x00000000}},	//   _হিন্, _малы_, --, --,
   {{0x5558002d,0x00000000,0x00000000,0x00000000}},	//   паря_, --, --, --,
   {{0x9584004e,0xbebd2791,0xe3bf826a,0xe97b00a5}},	//   _łącz, _krūt, _baña_, _לנוש,
   {{0xe3bf05c9,0xa2b500d4,0xe2ab05f5,0x00000000}},	// [8b70] _caña_, дбач, مائن_, --,
   {{0x645f01f4,0xe3bf0453,0x78a41a7f,0xe3b00037}},	//   shqi, _daña_, _zhiv, طرق_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4429826b,0x4439826c,0xe3bf01dd,0x645d826d}},	//   mda_, _ins_, _gaña_, _ilsi,
   {{0x4439826e,0xef182327,0x5fce0437,0x479c0070}},	//   _hns_, ямі_, हुबल, ציגס,
   {{0x442900d8,0xc105017e,0x44390409,0x00000000}},	//   oda_, _توزي, _kns_, --,
   {{0x4429826f,0xf53802b5,0xcac90086,0x68fa011e}},	//   nda_, לטור_, огие_, dutd,
   {{0x44298270,0xdb090225,0x99f500d8,0x64938271}},	//   ida_, _önüm, мяні, lçis,
   {{0x44298272,0x2bff0033,0x4439005f,0x1dc60167}},	//   hda_, ্যেই_, _lns_, रुआत,
   {{0x44398273,0x44297abb,0x3ebf011e,0xd5b800ea}},	//   _ons_, kda_, _huut_, žāk_,
   {{0x2fdf053e,0x44391f4a,0x644b018d,0x00000000}},	//   _jeug_, _nns_, ögil, --,
   {{0x44298274,0xbebd0029,0x61fe013c,0x9c7c003d}},	//   dda_, _grūt, ygpl, _ovčj,
   {{0x44298275,0x44398276,0x3ebf03ad,0x645d8277}},	//   eda_, _ans_, _muut_, _alsi,
   {{0xe96907bc,0x7afb127d,0x44398278,0x3ebf135c}},	//   _файл_, luut, _bns_, _luut_,
   {{0x44298279,0x5ed30033,0x64bc14a6,0xe3bf02d7}},	//   gda_, _সিনে, _očiv, _paña_,
   {{0x7c290938,0x3ebf0173,0xda0e0019,0x7afb0086}},	// [8b80] ider, _nuut_, _mỏng_, nuut,
   {{0x4429827a,0x4439827b,0x44262463,0xda0e0023}},	//   ada_, _ens_, žo_, _lỏng_,
   {{0x4429827c,0x27e002bf,0x661c827d,0x7c29827e}},	//   bda_, _kein_, merk, kder,
   {{0x4429013b,0x7c29827f,0x7afb2414,0x3ebf8280}},	//   cda_, jder, kuut, _buut_,
   {{0x7c298281,0x27e002bf,0x2fdf01a6,0x1be10066}},	//   dder, _mein_, _deug_, _गज़ल_,
   {{0x7c298282,0x27e00297,0x2cbe00d7,0x3a27011e}},	//   eder, _lein_, _putd_, _nanp_,
   {{0xda0e0019,0xdfcf0987,0xa3cb6ecd,0xa3aa2924}},	//   _bỏng_, _چيف_, रुव_, गेर_,
   {{0x67248283,0x27e0345c,0x661c8284,0x32c4027d}},	//   _osij, _nein_, herk, _köy_,
   {{0x1dcf09b8,0x7afb4734,0x2004022e,0x661c8285}},	//   _स्वत, guut, _icmi_, kerk,
   {{0x661c3589,0xdb22004e,0x274501f4,0x8d563f20}},	//   jerk, _źród, _lënë_, _отеч,
   {{0x44298286,0x27e08287,0x61e100ab,0x67248288}},	//   yda_, _bein_, _õlle, _asij,
   {{0x4429013b,0x7afb8289,0x6e2805f5,0x26c00382}},	//   xda_, buut, _hadb, _buio_,
   {{0x4429828a,0x27e002c9,0x6e28028b,0xfc67042c}},	//   vda_, _dein_, _kadb, _تخلی,
   {{0x4439828b,0x661c6df5,0x4429828c,0x6e2800ee}},	//   _sns_, gerk, wda_, _jadb,
   {{0x44290095,0xa3b106bb,0x27e03d4e,0x443905ca}},	//   tda_, टेन_, _fein_, _pns_,
   {{0xd5b8142c,0x4429828d,0x27e0828e,0x765e0328}},	//   ься_, uda_, _gein_, _elpy,
   {{0xa3cb0d00,0x6e3a152b,0xf77001cb,0xa3aa00a1}},	// [8b90] रुष_, _ontb, _پاي_, गेल_,
   {{0x4429828f,0x27e00291,0x661c8290,0x7c290c6e}},	//   sda_, _zein_, cerk, zder,
   {{0x7c298291,0x44298292,0x25d600a5,0x3ebf081b}},	//   yder, pda_, _אותן_, _suut_,
   {{0x44298293,0x44398294,0x245c00fb,0x603e002d}},	//   qda_, _uns_, _tíma_, _rămâ,
   {{0x69ca0a1f,0x78760009,0x229401ff,0x7c290055}},	//   _offe, nšva, täkt_, vder,
   {{0xceb8004e,0x603e002d,0x27450031,0x20040211}},	//   _cię_, _pămâ, _zënë_, _ecmi_,
   {{0x6e28099e,0xdc3a027d,0x2ca60341,0x61e50e0e}},	//   _dadb, _açıs, _bhod_, mahl,
   {{0x69ca8295,0x61e58296,0x7c298297,0x661c8298}},	//   _affe, lahl, uder, zerk,
   {{0x7c295f71,0x27e08299,0x661c129d,0x3ed9103b}},	//   rder, _rein_, yerk, _رواج_,
   {{0x27e0829a,0x3945829b,0xfeb80037,0x201d829c}},	//   _sein_, еног, _قالت_, lewi_,
   {{0x661c03c1,0x7afb829d,0x62830009,0x5bb900af}},	//   verk, suut, čnoh, _елея_,
   {{0xed560779,0x661c829e,0x66050107,0x7afb829f}},	//   _אבער_, werk, _achk, puut,
   {{0x661c82a0,0x2cad82a1,0x443e01a5,0x3a2702e9}},	//   terk, mmed_, _đt_, _tanp_,
   {{0x64bc61b2,0xe3bf82a2,0x7ae982a3,0x27e0033b}},	//   _očit, _baño_, mset, _wein_,
   {{0xa97902b5,0x7ae9663a,0xf8c61db9,0xf0fe1404}},	//   _מאַכ, lset, _रूपय, _उमेद_,
   {{0x46ea0133,0xa3cb0006,0x7bc982a4,0xe3bf0831}},	//   _един_, रुल_, nceu, _daño_,
   {{0x661c82a5,0x7ae92b3b,0xd9f30433,0x274501f4}},	// [8ba0] perk, nset, _आयात_, _vënë_,
   {{0x9985006c,0x2cad82a6,0x25e101d1,0x00000000}},	//   lelő_, hmed_, करणी_, --,
   {{0x6e280479,0x38600009,0x7ae982a7,0xf77f0132}},	//   _radb, _klir_, hset, maça_,
   {{0xceb81ea2,0x7ae918af,0x6e2800d5,0x38ba2143}},	//   _się_, kset, _sadb, _jūra_,
   {{0xe8050b57,0x24800528,0x2cad007c,0x7ae982a8}},	//   ष्टा_, mnim_, dmed_, jset,
   {{0x24801851,0x7ae982a9,0x61e5012f,0x2ca602a7}},	//   lnim_, dset, cahl, _shod_,
   {{0xf6530100,0x21a30384,0x6e28008b,0x7ae982aa}},	//   רצו_, _бирм, _vadb, eset,
   {{0x7ae947eb,0x6b9900e5,0x00000000,0x00000000}},	//   fset, _bywg, --, --,
   {{0x6e280a4e,0x7ae982ab,0x3f810644,0x2ca62d5b}},	//   _tadb, gset, şhur_, _vhod_,
   {{0xdb230037,0x386082ac,0x248001e9,0x4a541353}},	//   órái, _alir_, hnim_, ткос,
   {{0x38601bb4,0x88bc01c0,0x2cad00a5,0x67d500d4}},	//   _blir_, jvět, bmed_, кону,
   {{0xa3b13779,0x61e502c9,0x248005e2,0x9c7c02b2}},	//   टेड_, zahl, jnim_, _ovči,
   {{0x248035b9,0x64bc0612,0xe78419fa,0x00000000}},	//   dnim_, _očis, гуро, --,
   {{0x09e30083,0x69ca82ad,0xe3bf0453,0xcf930070}},	//   _মাথা, _uffe, _paño_, רטש_,
   {{0x8933097f,0xceb30070,0xa3dd0026,0x386082ae}},	//   _معيا, טיש_, डरल_, _flir_,
   {{0xd49882af,0x38607f2d,0x61e582b0,0xa3cb0096}},	//   еру_, _glir_, wahl, रुं_,
   {{0x61e582b1,0x09e30033,0xf77f0183,0xbebd013a}},	// [8bb0] tahl, _মাতা, baça_, _asūn,
   {{0x7afd12c3,0x248082b2,0xa15900af,0x00000000}},	//   àsti, anim_, мазу_, --,
   {{0x24800496,0xdfd100ad,0x61e582b3,0xf773006c}},	//   bnim_, ليا_, rahl, _جاں_,
   {{0x1b170083,0x24800a16,0xf9930070,0x7ae903d0}},	//   তিতে_, cnim_, ארע_, yset,
   {{0xd9ad0efd,0x61e506df,0xa3cb07df,0x00000000}},	//   _घण्ट, pahl, रुः_, --,
   {{0x442b82b4,0x7ae982b5,0x644f82b6,0xbd8900fd}},	//   _hac_, vset, _hoci, ونشن_,
   {{0x64bc0936,0x518461c9,0x2cad82b7,0xfc310037}},	//   _učit, _бута, tmed_, لحة_,
   {{0x63a282b8,0x7ae970e0,0x644f2acc,0xf3ff021d}},	//   żone, tset, _joci, _imãs_,
   {{0x4aa929e5,0x644f82b9,0x2cad293a,0x7bc9000d}},	//   мкин_, _moci, rmed_, rceu,
   {{0x7ae982ba,0x24800496,0x442b82bb,0x2cad11cb}},	//   rset, znim_, _lac_, smed_,
   {{0x442b0443,0x09e30033,0x00000000,0x00000000}},	//   _oac_, _মাদা, --, --,
   {{0x442b00e9,0x00000000,0x00000000,0x00000000}},	//   _nac_, --, --, --,
   {{0x24800496,0x7c2b03d0,0xa3d402b4,0x290c013b}},	//   vnim_, _iagr, सुफ_, atda_,
   {{0xf1b106bc,0x23690035,0x7c2b61da,0xa3d45756}},	//   जधान, dzaj_, _hagr, सुन_,
   {{0x442b0248,0x7c2b82bc,0xf77f2cd6,0x644f82bd}},	//   _bac_, _kagr, raça_, _boci,
   {{0x644f4efb,0xc483692a,0x442b82be,0x237f0124}},	//   _coci, алск, _cac_, _žuja_,
   {{0x7c2b82bf,0xa3e300fa,0x24800496,0x130a01c8}},	// [8bc0] _magr, _नजर_, rnim_, ьнай_,
   {{0x248005e2,0x7c2b02ce,0x442b3776,0x26113272}},	//   snim_, _lagr, _eac_, द्दी_,
   {{0x442b0012,0x24806395,0x644f4509,0xe43c00fe}},	//   _fac_, pnim_, _foci, _hříč,
   {{0x7e6182c0,0xd00f06c9,0xc05900d8,0xa3cb00ab}},	//   _allp, قلم_, ніі_, रुआ_,
   {{0x442082c1,0xbe8a0274,0x00000000,0x00000000}},	//   mei_, мске_, --, --,
   {{0x765c82c2,0x290c0095,0xdce104d4,0x13e70033}},	//   nkry, ytda_, _aylı, _ফায়,
   {{0xc0e382c3,0x3cfd000c,0xe297002d,0x290c00a8}},	//   _воск, रूले_, _рар_, xtda_,
   {{0x64810029,0x40950272,0x442b39c8,0x91bf00e2}},	//   eķij, _брут, _xac_, _đủ_,
   {{0x60c90009,0x7c2b82c4,0x442043de,0x26d23ab1}},	//   _čemi, _dagr, iei_, _ntyo_,
   {{0x7c2b0a24,0x442082c5,0x27f2099e,0x00000000}},	//   _eagr, hei_, _adyn_, --,
   {{0x442082c6,0xdd1f016f,0x5ec70033,0xbd460a42}},	//   kei_, píšt, রীদে, _جناي,
   {{0x442082c7,0x7c2b00f8,0x290c0be2,0x6d790070}},	//   jei_, _gagr, rtda_, _אָנװ,
   {{0x442082c8,0xec1300f8,0x6d5800d8,0x644f82c9}},	//   dei_, _خوند, lyva, _roci,
   {{0x7c2b82ca,0x442b82cb,0x09bc0033,0x7c2000fd}},	//   _zagr, _sac_, _আজকা, lemr,
   {{0x644f0865,0xa25b0023,0x2419021f,0x25a501ff}},	//   _poci, _buôn, новы_, åll_,
   {{0x442082cc,0x00000000,0x00000000,0x00000000}},	//   gei_, --, --, --,
   {{0x644f09ce,0x5215487a,0xf77f0183,0x00000000}},	// [8bd0] _voci, лдат, maço_, --,
   {{0xf77f0183,0x44200160,0x00000000,0x00000000}},	//   laço_, aei_, --, --,
   {{0xf7700796,0x212700e8,0xa3d400c4,0x442082cd}},	//   _های_, ình_, _स्व_, bei_,
   {{0x442082ce,0xcfde0083,0x32070035,0xe7e3012f}},	//   cei_, _ডাউন, żny_, परिप,
   {{0xd9e30084,0xd00e10ab,0x7c2b82cf,0xdea100b5}},	//   _ग़लत_, سلو_, _ragr, میری,
   {{0x3b0d3184,0x00000000,0x00000000,0x00000000}},	//   vteq_, --, --, --,
   {{0x7c2b82d0,0x69da03da,0x00000000,0x00000000}},	//   _pagr, dbte, --, --,
   {{0x0c2573a8,0xa6d90033,0x00000000,0x00000000}},	//   умин, _তিনট, --, --,
   {{0x78660033,0xf77f0132,0x9e07002d,0xfe790355}},	//   _jóve, daço_, _ачел, _dvůr_,
   {{0x442082d1,0x786682d2,0xd9e30083,0x1dc72478}},	//   zei_, _móve, _মাহম, _ललित,
   {{0x7c2b82d3,0x37e60aec,0x442000b5,0xe2a6008d}},	//   _tagr, лонг, yei_, íðin_,
   {{0x442082d4,0xbbeb0df3,0xe43c00b8,0x673600ee}},	//   xei_, _آرام_, _příč, _pryj,
   {{0x442082d5,0x7866008a,0x81e90083,0x7bdb018e}},	//   vei_, _nóve, _যান_, mbuu,
   {{0x7bdb011e,0x38ca00d1,0x00000000,0x00000000}},	//   lbuu, بایی_, --, --,
   {{0x442082d6,0x765c82d7,0x7cd100ea,0xa3b100b4}},	//   tei_, rkry, _dārg, टेस_,
   {{0x765c0626,0x786627c2,0x7bdb2069,0x6f1b5521}},	//   skry, _bóve, nbuu, _opuc,
   {{0xa25b0023,0x225107c0,0x7afb1e2e,0x26d2007b}},	// [8be0] _vuôn, _bozk_, nrut, _utyo_,
   {{0x442082d8,0x61464bfe,0x998700fe,0x00000000}},	//   sei_, леза, _janů_, --,
   {{0x442082d9,0xea7602b5,0x6f1b2e3e,0xe3b20a86}},	//   pei_, נגער_, _apuc, _گرد_,
   {{0xb4fb1899,0x04460012,0xd46a0274,0x6287073a}},	//   _אפטי, _семн, _чиме_, _ejjo,
   {{0xe3b203c5,0x7e783033,0xae050084,0x7afb0009}},	//   _درد_, tivp, _राशन_, jrut,
   {{0xb5e20083,0x6d58010b,0x11da0037,0x7afb0ccd}},	//   _বাঁচ, tyva, _سورة_, drut,
   {{0x2cc9016f,0xa3cb0246,0x7afb0553,0x7c20026b}},	//   _ľudí_, रुक_, erut, temr,
   {{0x683b02ee,0x7afb7b9c,0x7bdb043d,0x4e09000c}},	//   _mädä, frut, gbuu, _साथै_,
   {{0x7afb82da,0x30751362,0x68f5024e,0x7866002a}},	//   grut, _турс, ázdn, _xóve,
   {{0x3a740009,0x37e10033,0x9c7c021e,0x69da02b1}},	//   рлор, _ভাইর, _avčt, ubte,
   {{0x7afb00b9,0x69da509c,0x14b40026,0x00000000}},	//   arut, rbte, ंगाण, --,
   {{0x3ebe3c0e,0x7afb82db,0xd84700ed,0xf8ae0088}},	//   _hitt_, brut, ухоп, وکي_,
   {{0x7afb5a66,0xf77f03e6,0x7c93004f,0x3ebe82dc}},	//   crut, raço_, _النص, _kitt_,
   {{0x26e50299,0x6d490035,0x00000000,0x00000000}},	//   _कबीर_, ślał, --, --,
   {{0x3ebe82dd,0xf77f0370,0x00000000,0x00000000}},	//   _mitt_, paço_, --, --,
   {{0x7ae282de,0x248d129f,0x291c0279,0x3ebe00d4}},	//   _kwot, čemo_, _ipva_, _litt_,
   {{0xb2750009,0x81e90033,0x78ad0027,0xe2f80210}},	// [8bf0] алаш, _যাব_, _ihav, леті_,
   {{0x7aef09ab,0xe704006c,0x5ed30083,0x7ae2512c}},	//   ácti, _اسٹی, _সিলে, _mwot,
   {{0xcfd60083,0x6f1b82df,0x7cd1013a,0xf1a74451}},	//   _হয়ন, _spuc, _kāre, уран,
   {{0x6f02027a,0x897b016b,0xa3cb060a,0x7bc200f6}},	//   fuoc, עראצ, रुख_, _ngou,
   {{0xb817020c,0xe81737e8,0x7cd1013a,0x78bf0031}},	//   ध्यम_, ध्या_, _māre, _miqv,
   {{0x6283156f,0x7bc20107,0x3ebe027a,0x644d82e0}},	//   čnos, _agou, _citt_, ljai,
   {{0xd65802da,0x3ebe82e1,0x30a782e2,0x7ae26b23}},	//   ריות_, _ditt_, _брав, _awot,
   {{0xeb9931a8,0x3ebe2129,0x7afb82e3,0x6297002a}},	//   кий_, _eitt_, trut, loxo,
   {{0x6f1b00cb,0x3ebe0987,0x61e70088,0x7bdb82e4}},	//   _upuc, _fitt_, _kejl, rbuu,
   {{0x7cd10080,0x628582e5,0x7afb82e6,0x3ebe00d4}},	//   _pārd, nnho, rrut, _gitt_,
   {{0x78ad0176,0xa9a5002d,0x61e73fd5,0x8886392c}},	//   _bhav, ринд, _mejl, илож,
   {{0x7cd10080,0x78ad1417,0x61e782e7,0xfa250083}},	//   _vārd, _chav, _lejl, বাইল_,
   {{0xe9ce0d9e,0x7d0382e8,0xe73a0274,0x7ae282e9}},	//   _мк_, luns, њег_, _gwot,
   {{0x61e7000c,0x6e2382ea,0xe7f2000c,0x00000000}},	//   _nejl, nenb, _आएका_, --,
   {{0x62970485,0x7d0382eb,0xc6280033,0x649a0210}},	//   doxo, nuns, মালা_, втар_,
   {{0x6e2382ec,0x26c41417,0xdd0100b8,0x6a64009e}},	//   henb, ímos_, _štěs, _iòfa,

   {{0x7d0302dd,0xb89b0122,0xa3b10c03,0xe29a03e6}},	// [8c00] huns, _בבקש, टेल_, ваа_,
   {{0x61e733a5,0xf41f0282,0x00000000,0x00000000}},	//   _cejl, _hjäl_, --, --,
   {{0x3f9f0d89,0x61e7054e,0x6e2382ed,0x9f4401f4}},	//   _ayuu_, _dejl, denb, _temë_,
   {{0x3ebe01bc,0x60c700cb,0x2d9e00c7,0x78ad0031}},	//   _sitt_, _dujm, _ryte_, _xhav,
   {{0x61e782ee,0x6e2382ef,0x2d9e01f4,0x20060031}},	//   _fejl, fenb, _syte_, rgoi_,
   {{0x81b50083,0x6e2382f0,0x61e72038,0x7d03030d}},	//   ছুই_, genb, _gejl, funs,
   {{0xddc8004e,0x721b0d85,0xafe600d8,0x3ebe82f1}},	//   _podł, _שולח, _вобл, _vitt_,
   {{0x7ae20c1f,0x443206d1,0xe7f20067,0x7cd100ec}},	//   _pwot, ndy_, _आएगा_, _bārb,
   {{0x15e60299,0x6e2382f2,0x4e2a0043,0xd24f00b5}},	//   करार_, benb, _иоан_, _عنہ_,
   {{0x60c0721c,0xf1aa004e,0x443282f3,0x2d966320}},	//   _himm, _करान, hdy_, _крес,
   {{0x44320076,0x7cd100ea,0x60c0276c,0x7d03609e}},	//   kdy_, _pāre, _kimm, cuns,
   {{0x7ae20260,0x69c31923,0x60c038c9,0x68e3099e}},	//   _twot, _egne, _jimm, _dwnd,
   {{0x7ad418dd,0x629c67bf,0x628500e9,0x4432177b}},	//   _اقتص, _okro, ynho, ddy_,
   {{0x44326774,0x60c082f4,0x7afd82f5,0x00000000}},	//   edy_, _limm, áste, --,
   {{0x58870c91,0xa4d500d4,0xd49b1403,0x644d5384}},	//   _выпа, собі, вра_, tjai,
   {{0x613000f5,0x60c082f6,0x4432004e,0x6e2382f7}},	//   zólá, _nimm, gdy_, zenb,
   {{0xa3b10035,0x644d82f8,0x6e2382f9,0x61e7029e}},	// [8c10] टें_, rjai, yenb, _pejl,
   {{0x62851f3f,0x60c007c0,0xdcee0355,0xa3cb00ab}},	//   unho, _aimm, áděn, रुज_,
   {{0x628582fa,0x61e7054e,0x611301c0,0x6e2313ee}},	//   rnho, _vejl, dělá, venb,
   {{0x27e91fd3,0x6e2382fb,0x9ef50037,0x7d0382fc}},	//   _jean_, wenb, مستش, vuns,
   {{0x6e2382fd,0x53340086,0x61e782fe,0xda060325}},	//   tenb, _деят, _tejl, _शांत_,
   {{0x672d0054,0x7d0302ea,0x98a800b8,0x5f08073f}},	//   _msaj, tuns, _brně_, _समर्_,
   {{0x60c0008a,0x6e2382ff,0x245c0093,0x403501d3}},	//   _fimm, renb, _sími_, _левс,
   {{0x213e004f,0x6e238300,0x7cd10029,0x7d038301}},	//   _átha_, senb, _pārb, runs,
   {{0x6e238302,0x7d032387,0x7866002a,0x98bf00c7}},	//   penb, suns, _nóva, lytė_,
   {{0x44322d88,0x60c002c9,0x7d038303,0x26c101d5}},	//   zdy_, _zimm, puns, _niho_,
   {{0xd90c0ef2,0x44326587,0x1ddd021a,0x27e90f00}},	//   نیو_, ydy_, _न्यत, _bean_,
   {{0xed35006c,0x245c0093,0x27e90211,0x00000000}},	//   _پوچھ, _tími_, _cean_, --,
   {{0x44320187,0x78760009,0xae0e0a44,0x8c160c74}},	//   vdy_, nšvi, _सामन_, _طيور_,
   {{0x44323c86,0xa50a0ece,0x69c38304,0x6f7a016b}},	//   wdy_, лега_, _ugne, אָלג,
   {{0x672d8305,0x27e90312,0x2559002d,0xbebd02ff}},	//   _esaj, _fean_, артэ_, _brūz,
   {{0x27e9053f,0x29058306,0x232a0949,0xe81703de}},	//   _gean_, mula_, лоби_, ध्दा_,
   {{0x44320e7d,0x29058307,0xe73a2d4a,0x61ea05ee}},	// [8c20] rdy_, lula_, _сеп_, ðflo,
   {{0x200d00af,0x4432784b,0x29050952,0x00000000}},	//   _acei_, sdy_, oula_, --,
   {{0x29058308,0xd65700a5,0x62830009,0x629c00d5}},	//   nula_, _היית_, čnop, _vkro,
   {{0x3a258309,0x28cf012f,0xcf467311,0x00000000}},	//   help_, _संनि, йней, --,
   {{0x2905830a,0x60c0830b,0x00000000,0x00000000}},	//   hula_, _vimm, --, --,
   {{0x412a0a55,0x2905830c,0x5be00e68,0xa3d40722}},	//   _його_, kula_, नर्व, सुर_,
   {{0x60c0830d,0xc27b0070,0x2905830e,0x00000000}},	//   _timm, _ערלי, jula_, --,
   {{0x2905830f,0xbf4d00b8,0xbebd013a,0xcefd0225}},	//   dula_, _šířk, _apūd, üğün_,
   {{0xfbcf017e,0x7cd100ea,0x27e98310,0xdee31052}},	//   رتي_, _pārc, _rean_, _ноти,
   {{0x27e98311,0x7f3b0070,0x29050c2f,0x670700b4}},	//   _sean_, _געמו, fula_, वंसक_,
   {{0x29058312,0x6e93036b,0x6da61d05,0x27e98313}},	//   gula_, _علما, _امام, _pean_,
   {{0x6ca602fd,0xc8678314,0x26c10371,0x00000000}},	//   _اصطل, стои, _siho_, --,
   {{0x27e98315,0x26c102b3,0x25a400a8,0xb8ef0722}},	//   _vean_, _piho_, əmli_, _वू_,
   {{0x29050273,0x057700ce,0x45d41a55,0x80d90033}},	//   bula_, مازد, зорс, _ডিস্,
   {{0x290523d4,0x7cd1013a,0x27e900ab,0x81ce0033}},	//   cula_, _kāra, _tean_, ররা_,
   {{0xd49b1000,0x81c00083,0x73d90370,0xd5d90324}},	//   ург_, ীরা_, рдар_, _ब्रज,
   {{0x325500ca,0x7cd102d4,0x26c117ee,0x672d0054}},	// [8c30] овар, _māra, _tiho_, _usaj,
   {{0xf8c900e2,0x6a640260,0x00000000,0x00000000}},	//   _mẩn_, _mòfo, --, --,
   {{0x38694793,0x349502c4,0xf8c900e2,0x76450523}},	//   _klar_, _маор, _lẩn_, _inhy,
   {{0x7cd1013a,0x3e6b01e0,0x38bb013a,0x00000000}},	//   _nāra, _møte_, _būri_, --,
   {{0xddc502ce,0x24896c00,0x29058316,0xddc80107}},	//   обли, mnam_, zula_, _modņ,
   {{0xdce806d0,0x38690443,0x539a0277,0x00000000}},	//   _aydı, _llar_, _כירו, --,
   {{0xe80a0b4a,0x38690095,0x24898317,0xde940037}},	//   _वाला_, _olar_, onam_, أجنب,
   {{0xf8c90023,0x24898318,0x29055475,0x5f7401df}},	//   _bẩn_, nnam_, vula_, _کافر,
   {{0x29058319,0xf8c90019,0x00000000,0x00000000}},	//   wula_, _cẩn_, --, --,
   {{0x2905831a,0x38696b0b,0x248900d7,0xf8c900e2}},	//   tula_, _alar_, hnam_, _dẩn_,
   {{0xd826831b,0x3869831c,0x00000000,0x00000000}},	//   одни, _blar_, --, --,
   {{0x3869831d,0xe73a0645,0x764500e9,0x68fc265c}},	//   _clar_, аем_, _anhy, árda,
   {{0x2905831e,0x2489831f,0xda35010b,0x00000000}},	//   sula_, dnam_, _меды, --,
   {{0x29056412,0x2489025f,0x9bb60277,0x00000000}},	//   pula_, enam_, _והנה_, --,
   {{0x6601008e,0x1a9a016b,0x00000000,0x00000000}},	//   ólka, _דיסע, --, --,
   {{0x60c926e3,0x7645012f,0x0443741e,0x9f4f008d}},	//   _čemp, _enhy, месн, yggð_,
   {{0xd4670cac,0x03a31858,0xc889004f,0x02ed0066}},	// [8c40] ците_, дито, _دخول_, _चौदह_,
   {{0xae0e06bc,0x00000000,0x00000000,0x00000000}},	//   _साधन_, --, --, --,
   {{0x4fc6107a,0x7cf00037,0x38690282,0x00000000}},	//   осла, _mórá, _ylar_, --,
   {{0xdfd021a0,0xa2aa0e61,0x91da0066,0x1b200033}},	//   ريت_, _जीर्, _प्रै, বিতে_,
   {{0x64468320,0x81e90083,0x00000000,0x00000000}},	//   _inki, _যার_, --, --,
   {{0x72c30086,0x6b84030a,0x7cd1013a,0xccfa0200}},	//   _обяз, _žigo, _sāra, аћи_,
   {{0x26120006,0x68ed0035,0x7cd10228,0x225801ef}},	//   _तानी_, _ładn, _pāra, _iork_,
   {{0x6ab21f29,0x245c00a0,0x00000000,0x00000000}},	//   ँग्र, _tímu_, --, --,
   {{0x3ce90a78,0x3869009e,0xfbcf026e,0x3e6b0044}},	//   ćava_, _rlar_, ختى_, _søte_,
   {{0x248951e4,0x24800dda,0x7afd8321,0x22588322}},	//   znam_, hiim_, ásta, _jork_,
   {{0x2bac0243,0x7cd1013a,0x644600c3,0x20d7007a}},	//   _चरवा, _tāra, _onki, _għid_,
   {{0x0b468323,0x6f020139,0x6a640176,0x00000000}},	//   _мнен, oroc, _tòfo, --,
   {{0xf8c900e2,0x5fcb01c0,0x00000000,0x00000000}},	//   _uẩn_, िशतल, --, --,
   {{0x64468324,0x225806a2,0x661b0009,0x00000000}},	//   _anki, _nork_, đuko, --,
   {{0x24898325,0xd7fb0923,0x64c500b8,0x5558002d}},	//   tnam_, _куп_, वदेश, оаря_,
   {{0x3869005d,0xd14b0609,0x6f02088a,0x628e023a}},	//   _ular_, یشان_, kroc, _ajbo,
   {{0x24898326,0x22588327,0x00000000,0x00000000}},	// [8c50] rnam_, _bork_, --, --,
   {{0xf1a714a1,0x644638d3,0x24894c86,0x938812ea}},	//   орен, _enki, snam_, іста_,
   {{0x7ea40392,0xe7f20067,0x9c7c0107,0x00000000}},	//   còpi, _अजमा_, _pwčl, --,
   {{0xc95302b5,0xa3d400ab,0x859a00a5,0xd7af0099}},	//   ומע_, सुआ_, _לשתו, _घराच,
   {{0x44298328,0xddc18329,0x22580147,0x00000000}},	//   mea_, _bolş, _fork_, --,
   {{0x4429832a,0x26dc016b,0x00000000,0x00000000}},	//   lea_, סקומ, --, --,
   {{0x308518dd,0x28cf021a,0x00000000,0x00000000}},	//   _فلسف, _संधि, --, --,
   {{0x4429832b,0x6f02832c,0x9f4400b8,0x68ed0035}},	//   nea_, broc, _zemí_, _łado,
   {{0x4ea70d44,0x2258832d,0xa3bd000c,0x6f02832e}},	//   _држа, _york_, ेखि_, croc,
   {{0x44294343,0x28cf05e7,0xa3e209b4,0x7866832f}},	//   hea_, _संदि, _न्न_, _póvo,
   {{0x44297db5,0xd945263b,0x98a6002d,0x4ea400ed}},	//   kea_, чени, зине, _црта,
   {{0x44298330,0xa3bd0026,0xda1c0d4e,0x6fcb00b4}},	//   jea_, ेखा_, ब्बत_, िशिं,
   {{0x44298331,0xeb8e8332,0x7c298333,0x32110035}},	//   dea_, _чи_, meer, _oczy_,
   {{0xc4c60082,0x41bd0726,0x443e0160,0x00000000}},	//   كترو, ्खास, _şt_, --,
   {{0xceb20052,0xc1aa004e,0x44298334,0x44f7003c}},	//   גים_, _करेग, fea_, għ_,
   {{0x7c298335,0x44298336,0x6f028337,0x78fa00a5}},	//   neer, gea_, yroc, _הפקו,
   {{0xe1fa0812,0x24803acd,0x225838d1,0x00000000}},	// [8c60] йга_, riim_, _pork_, --,
   {{0x7c298338,0x69de007c,0x201f8339,0xb77b00a5}},	//   heer, _õpet, _abui_, _לאפש,
   {{0x35a60f08,0x23660a78,0x4429833a,0xae050ebd}},	//   _ханг, šoj_, bea_, _राजन_,
   {{0x2258833b,0x4429833c,0x7c29833d,0xdfcf00ad}},	//   _work_, cea_, jeer, هيم_,
   {{0xbea60131,0x2258833e,0x7c292576,0xddc100a8}},	//   падк, _tork_, deer, _polş,
   {{0x6f02833f,0x00000000,0x00000000,0x00000000}},	//   rroc, --, --, --,
   {{0x2a7c1bae,0x7c298340,0xf8c900e2,0xafe6051a}},	//   _rmvb_, feer, _bẩm_, _новл,
   {{0x7c298341,0x629e09df,0xae0e0992,0x3f6a0086}},	//   geer, lopo, _सावन_, _либо_,
   {{0x61ee8342,0x20f80c8c,0x7d0301da,0x00000000}},	//   _kebl, lči_, arns, --,
   {{0x44298343,0xa3b18344,0x61ee03d0,0x2a6a00b5}},	//   zea_, टेट_, _jebl, óbb_,
   {{0x7c2909d6,0x61ee0035,0x67240009,0x44298345}},	//   beer, _mebl, _apij, yea_,
   {{0x27ed0391,0x7c290a75,0x442901d7,0x629e0e31}},	//   úen_, ceer, xea_, hopo,
   {{0xb8d3111e,0x629e8346,0xf1bf00a0,0xbb490079}},	//   _जी_, kopo, čšie_, _وجهك_,
   {{0xcad70122,0x1dcc018d,0x629e0c99,0x61ee010b}},	//   _צוות_, ाशित, jopo, _nebl,
   {{0x44298347,0x629e0a69,0x0467081b,0x20f80a66}},	//   tea_, dopo, птам, jči_,
   {{0x81e90083,0xa3d4000c,0x3e6b0044,0xc7c70328}},	//   _যাই_, सँग_, _møta_, _эски,
   {{0x44298348,0xe7e30755,0x261a02cb,0x24588349}},	// [8c70] rea_, _क्या_, म्ही_, чать_,
   {{0x7c29834a,0x61fc011e,0x61ee834b,0x63a624ec}},	//   zeer, _cdrl, _cebl, _dykn,
   {{0x61ee834c,0x30150086,0x7c29018e,0x51f40037}},	//   _debl, ддер, yeer, عسكر,
   {{0x38bb013a,0x237f0124,0x5ee10033,0x00000000}},	//   _tūru_, _žuju_, _নিবে, --,
   {{0x7c29834d,0x61ee834e,0x7cd102d4,0x67f800b5}},	//   veer, _febl, _pāro, lújí,
   {{0x6da536ed,0x61ee834f,0x248d8350,0x7c290273}},	//   мила, _gebl, čemu_, weer,
   {{0x7c298351,0xa19407e5,0x388800b5,0x00000000}},	//   teer, _зарч, lőre_, --,
   {{0xccf801c0,0x0b451355,0x69d88352,0x69c32478}},	//   _dvě_, днин, _afve, _रणबी,
   {{0x7c298353,0x06e200c8,0x28cf258f,0xa0c40037}},	//   reer, _বিভি, _संहि, _سيكو,
   {{0x7c298354,0xe8f92116,0x00000000,0x00000000}},	//   seer, оло_, --, --,
   {{0x382a1eea,0x7c298355,0x67248356,0xa6dd0033}},	//   ожно_, peer, _spij, _বিষয়,
   {{0x200f1201,0x06e20033,0xddd800cd,0xc5c50033}},	//   nggi_, _বিবি, mivš, ্রাপ,
   {{0x28cf051d,0x7bcb011e,0x61aa0edf,0xb69b0132}},	//   _संवि, _iggu, _कर्ष, rrân,
   {{0x753c00b8,0x9f4f00f7,0xa9691e9c,0xab64010b}},	//   tvrz, gagé_, _мила_, _явіл,
   {{0x64a68357,0x845a1156,0xddd8011c,0x00000000}},	//   дава, орат_, nivš, --,
   {{0x161f051d,0x61ee8358,0x290501a0,0x00000000}},	//   म्बर_, _sebl, mrla_, --,
   {{0x60ce734c,0x60dc02f6,0xf1fa0e6b,0x7aed0095}},	// [8c80] _subm, _strm, قعات_, _çatd,
   {{0x9f440076,0x7cd10029,0x60ce00a5,0x452a110d}},	//   _nemá_, _pārl, _pubm, _джон_,
   {{0x629e5306,0x85bb0332,0x20f81bd8,0xddd8011c}},	//   ropo, _واپس_, uči_, jivš,
   {{0x61ee8359,0x7bcb00bf,0xddd80121,0xf8ae007c}},	//   _webl, _nggu, divš, घतिय,
   {{0x6d41835a,0x629e835b,0xa51e07b5,0x06e20033}},	//   _arla, popo, _पहुच_, _বিডি,
   {{0x7bcb835c,0xa3bd02e4,0x442240f5,0x200f07e5}},	//   _aggu, ेखर_, _hbk_, aggi_,
   {{0xa06a075c,0x44220124,0x9f440168,0x99850355}},	//   _дава_, _kbk_, _demá_, delů_,
   {{0x7d0a02c9,0xe043140e,0x290503c9,0x78a40371}},	//   rufs, _инси, drla_, _nkiv,
   {{0x6d4122dd,0xc5f40083,0x2905027a,0x9f4f00a2}},	//   _erla, _জানা_, erla_, yagé_,
   {{0xf8cf0099,0xd90e09b9,0x78a4835d,0x7bcb01a8}},	//   _संशय, لیت_, _akiv, _eggu,
   {{0xfca90987,0x6d41009e,0xddd800cd,0x00000000}},	//   _کالو_, _grla, civš, --,
   {{0xfe0e0992,0x00000000,0x00000000,0x00000000}},	//   _साँस_, --, --, --,
   {{0x7c224583,0x2905835e,0x64560118,0x00000000}},	//   _ibor, arla_, djyi, --,
   {{0x199400d8,0x645601e8,0x4422835f,0x78a48360}},	//   _паля, ejyi, _abk_, _ekiv,
   {{0xda6500ad,0x442201a3,0x200f3315,0x9f4f00a2}},	//   _ثاني, _bbk_, yggi_, ragé_,
   {{0x290c8361,0xf99300a5,0x44228362,0x9f4f00a2}},	//   muda_, _שרק_, _cbk_, sagé_,
   {{0xfe0e0084,0x290c8363,0x7c228364,0x4e0001c0}},	// [8c90] _सांस_, luda_, _mbor, ैलाई_,
   {{0x6a640176,0xe3b00037,0x44220065,0x38bb0228}},	//   _bòfi, شرق_, _ebk_, _tūrs_,
   {{0x290c6584,0x7c228365,0x7cd100ea,0x69dc0093}},	//   nuda_, _obor, _pārm, ðrey,
   {{0x41df04aa,0x5f9517e3,0xddd8011c,0xf1df0683}},	//   _प्रस, ниет, vivš, _प्रन,
   {{0x290c8366,0x645d8367,0x38b253b1,0x00000000}},	//   huda_, _iosi, nára_, --,
   {{0x44398368,0x645d030d,0x290c8369,0x81e90033}},	//   _has_, _hosi, kuda_, _যাক_,
   {{0x443955d2,0xa2d3012f,0x6da200d4,0x290c836a}},	//   _kas_, _भूत्, лиша, juda_,
   {{0x6285836b,0x645d836c,0x4439836d,0x38b218fa}},	//   liho, _josi, _jas_, kára_,
   {{0x4439836e,0x998501c0,0x645d836f,0x38b200b5}},	//   _mas_, telů_, _mosi, jára_,
   {{0x443912eb,0x69ce1851,0xc3320bed,0x62858370}},	//   _las_, žben, נוי_, niho,
   {{0x6d418371,0x60c98372,0x290c8373,0x7cd100ea}},	//   _urla, _kiem, guda_, _mārk,
   {{0x7aeb006d,0x60c900d8,0x6a6d01ba,0xfe1b021a}},	//   _twgt, _jiem, _dúfa, प्रस_,
   {{0x60c900c8,0x442200d5,0x628526d6,0x38b200b5}},	//   _miem, _rbk_, kiho, gára_,
   {{0x78660083,0x7c220bcc,0x60c98374,0x290c8375}},	//   _móvi, _zbor, _liem, buda_,
   {{0x44398376,0x645d001e,0x78a415d7,0x290c0381}},	//   _bas_, _bosi, _tkiv, cuda_,
   {{0x44398377,0x60c98378,0x645d8379,0x64a60009}},	//   _cas_, _niem, _cosi, хаба,
   {{0x4439837a,0x645d837b,0x7c390297,0x33d50185}},	// [8ca0] _das_, _dosi, _mawr, тіст,
   {{0x645d3597,0x6aa10297,0xae0e3979,0x4439837c}},	//   _eosi, nolf, _साइन_, _eas_,
   {{0x26d20657,0x4439837d,0x4422022e,0xe85300f8}},	//   _huyo_, _fas_, _tbk_, _شنید,
   {{0x60c91486,0x26d20103,0x4439837e,0x61e304d4}},	//   _ciem, _kuyo_, _gas_, ınla,
   {{0xe8180299,0x765e837f,0x8e860009,0x60c9556a}},	//   _थाना_, _kopy, нгде, _diem,
   {{0x44205b31,0x44398380,0x290c8381,0x645d8382}},	//   lfi_, _zas_, yuda_, _zosi,
   {{0x44398383,0x44201005,0x645d6e3d,0x60c98384}},	//   _yas_, ofi_, _yosi, _fiem,
   {{0x8fa68385,0x4439006f,0x44208386,0x7c3b8387}},	//   _забе, _xas_, nfi_, gdur,
   {{0x7c39035f,0xddcf0355,0x44201b91,0x3d1c07b5}},	//   _dawr, řešn, ifi_, _महके_,
   {{0x60c98388,0x4420046a,0x290c8389,0x7c3b838a}},	//   _ziem, hfi_, tuda_, adur,
   {{0x7c39016e,0x628b00a2,0x19942ee3,0x00000000}},	//   _fawr, égoi, таня, --,
   {{0x290c838b,0x7c22811a,0x26d241fa,0x38b280b8}},	//   ruda_, _ubor, _buyo_, tára_,
   {{0x26d20831,0xc6f80402,0x6d5c838c,0x00000000}},	//   _cuyo_, ннях_, _àrab, --,
   {{0xb9060033,0x6a6d00ee,0x7c390067,0x00000000}},	//   _পি_, _húfn, _zawr, --,
   {{0x4439838d,0x6e3a838e,0x6594005f,0x4420838f}},	//   _pas_, _matb, гару, ffi_,
   {{0x44398390,0x645d0c6f,0x68fa8391,0x00000000}},	//   _qas_, _qosi, mstd, --,
   {{0xe4ed13a0,0x60c98392,0x7cd10029,0xf8bf691e}},	// [8cb0] _जबकि_, _riem, _pārk, mmé_,
   {{0x44398393,0x60c98394,0x69da8395,0x645d8396}},	//   _was_, _siem, ncte, _wosi,
   {{0x44398397,0x60c98398,0x645d0086,0x81a90083}},	//   _tas_, _piem, _tosi, খেন_,
   {{0x44390d4b,0x62858399,0x81e90033,0x7c3b013b}},	//   _uas_, siho, _যাও_, xdur,
   {{0x6e3a08d4,0x60c9839a,0x6285023a,0xe80a00b4}},	//   _batb, _viem, piho, _वाघा_,
   {{0x6e3a7287,0x60c9839b,0x00000000,0x00000000}},	//   _catb, _wiem, --, --,
   {{0x60c900c8,0x6e3a0297,0x6aa10036,0x7c3b14b1}},	//   _tiem, _datb, volf, tdur,
   {{0xdd8e0082,0x20d7037a,0x6f040a66,0x6e3a0159}},	//   توى_, _içi_, šica, _eatb,
   {{0x5f9414d0,0x7cd100ea,0xaed500d4,0x26120b4d}},	//   _битт, _māri, _розш, _ताली_,
   {{0x3945839c,0x6a8600f7,0x7c3b839d,0x2ca603d0}},	//   вног, _réfè, sdur, _ekod_,
   {{0x4420839e,0x26d2839f,0x6aa1008c,0xdd1e0501}},	//   yfi_, _suyo_, rolf, píše,
   {{0xcc1400d1,0x26d2010d,0x765e0371,0x00000000}},	//   _مذهب, _puyo_, _sopy, --,
   {{0x6c7a0070,0xb3c03272,0xfbd003fb,0x2cbf018d}},	//   _קאנפ, _शृंख, _اتم_, mmud_,
   {{0x2cad0052,0x66e3081b,0xbbd10d43,0xa925010b}},	//   lled_, рора, _हलुक, _адкл,
   {{0xe5a60af5,0x4420003c,0x7afb83a0,0x7cd10228}},	//   тиви, tfi_, lsut, _bāri,
   {{0x64be06bc,0x26d283a1,0xb4ac0ca1,0x442052df}},	//   ्देश, _tuyo_, गते_, ufi_,
   {{0xe3630e75,0x442083a2,0x7afb0e6c,0x3e70009e}},	// [8cc0] акти, rfi_, nsut, _làta_,
   {{0x2cbf83a3,0x2cad01c0,0x09c50033,0x7afb2119}},	//   hmud_, hled_, _শ্যা, isut,
   {{0x6e3c1821,0xa3ea1470,0x3860028b,0xf48700b5}},	//   _órbi, _одна_, _koir_, راہی,
   {{0xdee62674,0x7afb83a4,0x00000000,0x00000000}},	//   води, ksut, --, --,
   {{0x44fe00d8,0x2cad00e9,0x3860009e,0x6e3a00e0}},	//   lį_, dled_, _moir_, _patb,
   {{0x2cad007a,0x2492324f,0x38607597,0x3e7000f1}},	//   eled_, lnym_, _loir_, _bàta_,
   {{0x44fe01c8,0x6601008d,0x6e3a1192,0x2cad0090}},	//   nį_, ólki, _vatb, fled_,
   {{0x2cad02dd,0x386002e1,0x249204fc,0x3e7000f1}},	//   gled_, _noir_, nnym_, _dàta_,
   {{0xaec6061c,0x7afb83a5,0x6e3a10b3,0x38b900b5}},	//   _абал, gsut, _tatb, nére_,
   {{0x44fe010b,0x38601861,0xf8ca00e2,0x2ca60b88}},	//   kį_, _aoir_, _mẩu_, _wkod_,
   {{0xd6e200c8,0x7afb00be,0x2cad00a5,0x38600211}},	//   _বিষয, asut, bled_, _boir_,
   {{0x2cad1b9f,0xdbcc05ee,0xb4ac0099,0x68fa0a8d}},	//   cled_, _góðk, गतो_, rstd,
   {{0xf8bf02e1,0x38600211,0xdca30a26,0x7f423253}},	//   rmé_, _doir_, _таци, nvoq,
   {{0xb7e306bc,0x7f4283a6,0x7aed0644,0x26f307b5}},	//   _क्रम_, ivoq, _çata, _अबीर_,
   {{0x7cd10029,0x38600211,0x38720533,0x00000000}},	//   _pāri, _foir_, _flyr_, --,
   {{0x48150ca6,0x38600341,0x58870409,0x2b464cc8}},	//   _смис, _goir_, _шыла, _kroc_,
   {{0xf8ca0023,0x38b900b5,0x27eb0176,0x3ce90207}},	// [8cd0] _cẩu_, gére_, mbcn_, ćavi_,
   {{0x7afd0aca,0x7ae2000e,0x291e1622,0x5ee10831}},	//   ásti, _mtot, otta_, _নিলে,
   {{0xdfd1004f,0x2cad233c,0xa2d3012f,0x291e02ee}},	//   ميا_, yled_, _भूर्, ntta_,
   {{0x5ff5021d,0x291e83a7,0x3e700211,0x249283a8}},	//   узду, itta_, _ràta_, cnym_,
   {{0x24891b84,0x9ac4007a,0x7ae20160,0x00000000}},	//   miam_, _kaċċ, _ntot, --,
   {{0x24891290,0x2cad83a9,0x6a6d0176,0x9ac4007a}},	//   liam_, wled_, _rúfo, _jaċċ,
   {{0xc2120052,0x261b0ccf,0x7ae20160,0x2cad382c}},	//   _להם_, _बानी_, _atot, tled_,
   {{0x248983aa,0x39495861,0x7afb5c2b,0x2b4683ab}},	//   niam_, _čas_, tsut, _broc_,
   {{0x2cad0699,0x291e0c46,0x7c312e37,0x89f512ea}},	//   rled_, etta_, _čerč, лянц,
   {{0x24890221,0x386083ac,0x7afb83ad,0x7bdb0051}},	//   hiam_, _soir_, rsut, scuu,
   {{0x7afb83ae,0xe73c0723,0xec151026,0x2489010b}},	//   ssut, _küçü, _مواد, kiam_,
   {{0x05a70084,0x7c8483af,0x66e6477b,0x2369027d}},	//   _गड़ब, _куче, лома, kyaj_,
   {{0x3860105d,0x248983b0,0x7e6183b1,0xc8cf0aad}},	//   _voir_, diam_, _kolp, _संकट,
   {{0x24920035,0x644f1762,0x44fe010b,0x61f583b2}},	//   wnym_, _anci, tį_, _nezl,
   {{0x05a40084,0x249221a5,0x386000f1,0x248983b3}},	//   _खुशब, tnym_, _toir_, fiam_,
   {{0x38b9006c,0x248983b4,0x44fe010b,0x21380124}},	//   tére_, giam_, rį_, _rsrh_,
   {{0x42267b75,0x2b59017b,0x9ac4009f,0x24921cca}},	// [8ce0] лдав, äsch_, _faċċ, rnym_,
   {{0xe74702e3,0x78a6003d,0x24920035,0x44fe010b}},	//   ções_, lokv, snym_, pį_,
   {{0x38b9006c,0x21670336,0x600a2dde,0x248983b5}},	//   sére_, лифи_, енем_, biam_,
   {{0x248983b6,0x39470009,0xd00f0037,0xf8ca00e2}},	//   ciam_, _mrns_, كلم_, _tẩu_,
   {{0x7e6158b0,0x43672a2d,0x7cd10228,0x00000000}},	//   _bolp, _баян_, _māru, --,
   {{0x7e6101d3,0x443233e6,0x291e0343,0x2c7100b8}},	//   _colp, ley_, ytta_, _ráda_,
   {{0x7ae26158,0xe297034b,0x60d583b7,0xad2603c7}},	//   _stot, _сар_, _guzm, ارتو,
   {{0x443283b8,0x8c3d00af,0x2b465fe0,0xd12f0413}},	//   ney_, toşa, _proc_, _عمق_,
   {{0x3a740ec9,0x33200024,0x9b940043,0x2e1600b2}},	//   илир, ntix_, рипц, _مباح,
   {{0xc3330052,0x2bc00907,0x27e002e1,0x7e6112d1}},	//   צות_, शेषा, _afin_, _golp,
   {{0xc27b02b5,0x291e0086,0x6a640260,0x7cd1013a}},	//   גריי, utta_, _bòfr, _bāru,
   {{0x7cd10080,0x291e83b9,0x6d4883ba,0x2b4683bb}},	//   _pārv, rtta_, _irda, _troc_,
   {{0x248983b4,0x27e00069,0x7ae2002f,0x394703bc}},	//   viam_, _dfin_, _utot, _erns_,
   {{0xbb3b00c2,0x2489004e,0x7ead01ba,0x44320107}},	//   _רעגי, wiam_, túpi, eey_,
   {{0x248983bc,0x60c200d7,0x443283bd,0xceb30317}},	//   tiam_, kmom, fey_, מיש_,
   {{0x6d486ee6,0x60d50506,0x61f50139,0x00000000}},	//   _mrda, _ruzm, _sezl, --,
   {{0x248983be,0xf77303c5,0xe3b00037,0xa00a0033}},	// [8cf0] riam_, _داغ_, كرك_, রভাব_,
   {{0x6d4883bf,0x7cd10080,0x248983c0,0x20040069}},	//   _orda, _kārt, siam_, _admi_,
   {{0x6601008d,0xae0e04bc,0x7e6103bc,0x24890abe}},	//   ólku, _साजन_, _rolp, piam_,
   {{0x60c283c1,0x261b0722,0x7cd100ea,0x7e6183c2}},	//   gmom, _बाडी_, _mārt, _solp,
   {{0x6d4883c3,0x7e6183c4,0x64db00a1,0x61f505f9}},	//   _arda, _polp, _मंडळ, _tezl,
   {{0x26dc02b5,0x8d651cf7,0x672d83c5,0x6d4801a0}},	//   עקומ, ивле, _mpaj, _brda,
   {{0xed593627,0x7e6183c6,0xbdf80bdf,0x00000000}},	//   той_, _volp, ارها_, --,
   {{0x7e610159,0xf0bb00b5,0x672d023a,0x00000000}},	//   _wolp, _سازش_, _opaj, --,
   {{0x6d4883c7,0x290c28c1,0xd7c70084,0x291801a6}},	//   _erda, erda_, रेमच, àran_,
   {{0x443200d0,0x2ca00009,0xa925576e,0x38960228}},	//   zey_, čida_, адол, tāro_,
   {{0x3ea783c8,0xf991004f,0x6d4800f4,0x672d02ee}},	//   mont_, تبة_, _grda, _apaj,
   {{0x18a603ad,0x92a60035,0xfbd01c64,0xf74632f2}},	//   рамм, _załą, _فته_, аемо,
   {{0xbca40833,0x443283c9,0x290c83ca,0x4a750421}},	//   _امني, vey_, arda_, _выйт,
   {{0x4b7a00c2,0x443283cb,0x3ea783cc,0x290c013b}},	//   _באנו, wey_, nont_, brda_,
   {{0x44321080,0x33f60432,0xfa3404cd,0xc6c3010b}},	//   tey_, ичас, _درند, ійск,
   {{0xd91a0070,0xfe790355,0x232a01f2,0x261200be}},	//   _סופל, _stůl_, коби_, _ताकी_,
   {{0x443283cd,0x7ae983ce,0x3ea783cf,0xa3e20324}},	// [8d00] rey_, npet, kont_, नुष_,
   {{0x23275a04,0xf2df0019,0x3ea70036,0x38b900f7}},	//   рофи_, _trân_, jont_, méra_,
   {{0x3320009f,0x7f4900de,0x261b0006,0x60c21b42}},	//   stix_, _areq, _बाती_, tmom,
   {{0x03a600d4,0x044683d0,0x628b000d,0xe6120919}},	//   _вимо, _темн, égor, _اشک_,
   {{0x3ea783d1,0x6d48044d,0x7d0111cb,0x99870409}},	//   font_, _srda, _avls, _kanų_,
   {{0x290c0523,0x3ea723b5,0x7ae90159,0x7f490031}},	//   yrda_, gont_, dpet, _dreq,
   {{0xd0120312,0xdd8f0079,0x80c600a1,0x205600c7}},	//   _ولس_, ووه_, िषदे, _ктар,
   {{0xa0670af5,0x7f495d7b,0x290c012e,0x9c7c0260}},	//   _каса_, _freq, vrda_, _etčn,
   {{0xa0670854,0x7f4900da,0xee3a1917,0x7ae93120}},	//   _тата_, _greq, _ина_, gpet,
   {{0xaa66135d,0x7cd10029,0x3ea70160,0x6d48023a}},	//   ртик, _pārt, cont_, _trda,
   {{0x672d039a,0x67d52d93,0xfce31109,0x6d4801d7}},	//   _spaj, йону, _дохо, _urda,
   {{0x7cd100ea,0x61e90009,0x245c07c0,0x00000000}},	//   _vārt, _đelm, _tímy_, --,
   {{0xab8303fa,0x628001c8,0xb71407b0,0x7ae90310}},	//   _мушк, _įmon, одящ, cpet,
   {{0xb882008d,0x5f09021a,0x9c870168,0x00000000}},	//   _þína, _सिस्_, _tečú, --,
   {{0xa5f8761c,0x3abb0d85,0x28d037e8,0xe9370037}},	//   ресу_, _שמונ, _संचि, _نسيت_,
   {{0x63af3f8b,0xb867006c,0x657a01a6,0x57f50cc7}},	//   _pycn, _خاتو, ùtha, _упит,
   {{0xaaba0084,0x78ad435f,0x4aba007c,0xb4b70066}},	// [8d10] _उठाक, _ikav, _उठाव, _छठी_,
   {{0xe7e3049c,0x00000000,0x00000000,0x00000000}},	//   कुरा_, --, --, --,
   {{0xc5f20122,0x78ad0103,0x00000000,0x00000000}},	//   _מדי_, _kkav, --, --,
   {{0x7536016b,0x00000000,0x00000000,0x00000000}},	//   _פארד_, --, --, --,
   {{0x7ee40202,0xc8d000a1,0x442b0183,0x28c80567}},	//   оцје, _संघट, _ibc_, रगति,
   {{0x14b500a1,0x00000000,0x00000000,0x00000000}},	//   ंतवण, --, --, --,
   {{0x3ea783d2,0x5d33006c,0xf1c300e7,0x1ee700b5}},	//   ront_, تہائ, वेशन, _چوری_,
   {{0x7ae900cd,0x1ee702fd,0x78ad007b,0x7f4983d3}},	//   tpet, _نوری_, _nkav, _treq,
   {{0x7cd10080,0x3ea783d4,0x442b4ede,0x00000000}},	//   _pārs, pont_, _mbc_, --,
   {{0xfc3f000c,0x78ad2072,0x7aed0095,0xfe730180}},	//   ží_, _akav, _çatm, _بدر_,
   {{0x7ae983d5,0x186a1056,0x81a90083,0x442b0176}},	//   spet, гани_, খের_, _obc_,
   {{0xe7e3021a,0x3156016b,0x290a01ef,0x7ae909e8}},	//   कुला_, צירן_, ábaa_, ppet,
   {{0x3b092235,0x38b253b1,0x23a71365,0x53a7021a}},	//   _село_, nári_, _कुलद, _कुलश,
   {{0x442b83d6,0x78ad0129,0x00000000,0x00000000}},	//   _abc_, _ekav, --, --,
   {{0x442b0211,0xceb21759,0xd9c50083,0xa2b80eff}},	//   _bbc_, פיל_, _শ্রম, ्गस्,
   {{0x28d00b35,0x38b200a0,0x475a02fb,0x442b83d7}},	//   _सूचि, kári_, _броя_, _cbc_,
   {{0xe29a0132,0xe3ba83d8,0x442b5339,0x04570037}},	// [8d20] гаа_, уба_, _dbc_, حلقة_,
   {{0x6f044cbf,0x975b016b,0x00000000,0x00000000}},	//   šick, _עדיט, --, --,
   {{0x7c2b1bfa,0x64a6010b,0x60260c88,0x64ac02b1}},	//   _obgr, _гана, йджа, ußis,
   {{0xd91a0070,0x62970051,0x3ebe00cc,0x00000000}},	//   טועל, anxo, _shtt_, --,
   {{0xb4c4004e,0x00000000,0x00000000,0x00000000}},	//   एगी_, --, --, --,
   {{0xa2e302c4,0x7c2b02b1,0xbea3031a,0x644483d9}},	//   _хорд, _abgr, пачк, ldii,
   {{0x2d9883da,0x261b14ab,0x3ebe0023,0x7167002d}},	//   _žreb_, _बासी_, _vhtt_, _ларг_,
   {{0x644409d6,0x6ab2035d,0x61fe83db,0x7a210260}},	//   ndii, ुग्र, lapl, _lňtč,
   {{0x7cd100ea,0x9e6500b5,0x3e7900a2,0x3ebe4564}},	//   _pārr, _ڈالن, _sète_, _thtt_,
   {{0x9e650082,0xc3330122,0x78ad83dc,0x61fe83dd}},	//   _والن, לוח_, _skav, napl,
   {{0x26120026,0x6f0283de,0x00000000,0x00000000}},	//   _ताजी_, lsoc, --, --,
   {{0xc19b00c2,0x13b00083,0x2db70070,0xb4b70354}},	//   רשטי, চেয়, _פלאן_, _छठे_,
   {{0x6444018e,0x6f022f6b,0x83a70066,0x61fe2434}},	//   ddii, nsoc, _कुंआ, kapl,
   {{0x6444030d,0xeb070079,0x00000000,0x00000000}},	//   edii, _اقوى_, --, --,
   {{0xd49b1da6,0x61fe0409,0xe5c402fb,0x7d1c10dd}},	//   гра_, dapl, зсто, _årsd,
   {{0x38b902e1,0xb4b300a1,0xda1813c2,0x6444010d}},	//   méro_, टते_, _दाँत_, gdii,
   {{0xf2df00e2,0x335800af,0x442b83df,0x00000000}},	// [8d30] _trâm_, батэ_, _vbc_, --,
   {{0x61fe83e0,0x6444013a,0x6f02017b,0x51f80104}},	//   gapl, adii, dsoc, йную_,
   {{0x3e6b0185,0x55590b25,0x41c3021a,0x00000000}},	//   _møtt_, _таня_, वेंस, --,
   {{0xdd00000c,0x442b83e1,0x00000000,0x00000000}},	//   štěn, _ubc_, --, --,
   {{0xda180066,0xd34100b5,0x6f02008c,0x7ce70225}},	//   _दांत_, _تہذی, gsoc, _kırg,
   {{0x999e006c,0x61fe1510,0x4cd20033,0x2c1b035d}},	//   hető_, capl, _সবগু, _याहू_,
   {{0x44290037,0x6cc52b7a,0x00000000,0x00000000}},	//   ofa_, ойка, --, --,
   {{0x4429001e,0x26d31432,0x2d980009,0xa3d9021a}},	//   nfa_, _lixo_, _žrec_, ाशि_,
   {{0x290a0332,0xeb992070,0x442983e2,0x00000000}},	//   ában_, рип_, ifa_, --,
   {{0x090500d4,0x442900e5,0xde4605f5,0x00000000}},	//   опон, hfa_, _وینو_, --,
   {{0x64440510,0xdd9b2eb3,0x224302c4,0xa3d90325}},	//   ydii, _сша_, _majk_, ाशा_,
   {{0xc5e902da,0x61fe0097,0x26d30310,0x442983e3}},	//   _יד_, zapl, _aixo_, jfa_,
   {{0x7c2983e4,0x44290297,0x27ff0093,0xdd1e01ba}},	//   mfer, dfa_, ðuna_, _víťa,
   {{0x7c2983e5,0x3e700211,0x9f4400d5,0x00000000}},	//   lfer, _càth_, _nemý_, --,
   {{0x261b0299,0x61fe01d6,0x26d30391,0x2b4900ac}},	//   _बारी_, vapl, _dixo_, _šach_,
   {{0x26d30f84,0x741601b2,0x13ea00c7,0x6f0401ba}},	//   _eixo_, تورا, рмай_, šici,
   {{0xe1fa7920,0x26d3335b,0x61fe83e6,0x644483e7}},	// [8d40] ига_, _fixo_, tapl, rdii,
   {{0x4429001c,0x7ce70225,0x00000000,0x00000000}},	//   afa_, _kırd, --, --,
   {{0x272483e8,0x22430009,0xda210456,0x7c2903d0}},	//   lön_, _dajk_, _मानत_, kfer,
   {{0x5ee10b52,0x61fe027d,0x7c290120,0x224301a3}},	//   _নিজে, sapl, jfer, _eajk_,
   {{0xee3a0043,0xd00f01b2,0xaf360bdf,0x7c2983e9}},	//   инд_, ئله_, ترات, dfer,
   {{0x999e006c,0x7c29033b,0x81a90033,0x2a67021e}},	//   zető_, efer, খেই_, _nonb_,
   {{0x7c2983ea,0x272448f4,0x7cd100ea,0x61fc0fdb}},	//   ffer, hön_, _pārp, _ierl,
   {{0x61fc83eb,0x2c7800d1,0x60c0010d,0x272483ec}},	//   _herl, _béda_, _uhmm, kön_,
   {{0x60dc83ed,0x61fc83ee,0x27247550,0x261b0963}},	//   _hurm, _kerl, jön_, _बाली_,
   {{0x61fc0dc9,0x60dc83ef,0x5ee10033,0x272400fd}},	//   _jerl, _kurm, _নিচে, dön_,
   {{0x442908a1,0x60dc83f0,0x3e70009e,0xa2ab00b8}},	//   yfa_, _jurm, _ràth_, जकत्,
   {{0xab2a014d,0xd6e20083,0x60dc83f1,0x6724035f}},	//   _вода_, _বিজয, _murm, _bqij,
   {{0xd90e0ef5,0x61fc00d7,0xa09b02b5,0x68ed0a66}},	//   ریک_, _oerl, שיכט, _čade,
   {{0x61fc017b,0xee2e0208,0x00000000,0x00000000}},	//   _nerl, енi_, --, --,
   {{0x7e686592,0x60dc465a,0x4429007a,0xf3ff00e2}},	//   _modp, _nurm, tfa_, _doãn_,
   {{0x2b491ac4,0x442983f2,0xd5b807f5,0x61fc0079}},	//   _šaci_, ufa_, юся_, _aerl,
   {{0x61fc83f3,0x442983f4,0xb2752503,0x224302a7}},	// [8d50] _berl, rfa_, плаш, _pajk_,
   {{0x4eac00c8,0x60dc2f29,0x442983f5,0x656e00b5}},	//   গগুল, _burm, sfa_, ínhá,
   {{0x60dc83f6,0x44290010,0x61fc83f7,0x2fd90037}},	//   _curm, pfa_, _derl, مواد_,
   {{0x60dc00a3,0x7e7a83f8,0x61fc152b,0x386903d0}},	//   _durm, _altp, _eerl, _joar_,
   {{0x61fc0093,0x66c082f1,0x3869008c,0xdb0700d0}},	//   _ferl, söke, _moar_, ümüz,
   {{0x0e642286,0x61fc83f9,0x38691a8a,0x3e790107}},	//   мкін, _gerl, _loar_, _bèta_,
   {{0xc69400c2,0xf3ff0370,0x7c2902c9,0x61e5004f}},	//   ואס_, _joão_, tfer, mchl,
   {{0x61e500e9,0xab654187,0x61fc02b1,0x27240421}},	//   lchl, звил, _zerl, yön_,
   {{0x7c2983fa,0x61fc06a8,0x5f9402ce,0xa3ce09b4}},	//   rfer, _yerl, _житт, षेप_,
   {{0x61e50874,0x7645012f,0x7e6800ec,0x628000c7}},	//   nchl, _nahy, _godp, _įmok,
   {{0x7c29574d,0x61e509a2,0x60dc0510,0x00000000}},	//   pfer, ichl, _xurm, --,
   {{0x201d003c,0x7e681840,0x27240086,0x88bd00b8}},	//   ngwi_, _zodp, tön_, stěn,
   {{0xacaa00f5,0x38690012,0x31b805f7,0x2cad03bc}},	//   _اپنے_, _doar_, _अर्ध, moed_,
   {{0x9f5d00d1,0x2cad0b0d,0x764500f8,0xbb421b5d}},	//   gawé_, loed_, _cahy, _чешк,
   {{0x49120311,0x272483fb,0x61e583fc,0xa979016b}},	//   _थियो_, sön_, dchl, _לאַכ,
   {{0x61fc54a9,0x38690118,0x2cad016e,0x07a60746}},	//   _serl, _goar_, noed_, _найн,
   {{0x61fc0b0e,0x60dc36c7,0xd4674697,0x6d41011e}},	// [8d60] _perl, _surm, чите_, _lsla,
   {{0x2cad5089,0x60dc0c85,0x29050079,0x6e21009e}},	//   hoed_, _purm, osla_, _nclb,
   {{0x61fc3d7d,0xd5b00332,0x290583fd,0xb5f700a5}},	//   _verl, _شہر_, nsla_, _מציג_,
   {{0x64a660e7,0x6d5c0014,0x76450187,0x61fc83fe}},	//   _хама, _àrai, _zahy, _werl,
   {{0x61fc203f,0x6d4183ff,0x60dc000b,0x24800159}},	//   _terl, _asla, _wurm, mhim_,
   {{0x64468400,0x60dc8401,0x29058402,0x44220088}},	//   _haki, _turm, ksla_, _hck_,
   {{0xdb07114d,0x628e8403,0x427b0070,0x127b016b}},	//   _člán, _imbo, _פאלג, _פאלע,
   {{0x64468404,0xc19b0122,0x2cad02e6,0x248067a4}},	//   _jaki, _השלי, goed_, nhim_,
   {{0x6d418405,0x64468406,0x8b230274,0x4f6615f8}},	//   _esla, _maki, едње, _عارف,
   {{0x64468407,0x9d468408,0x3a06006c,0x00000000}},	//   _laki, _незд, سکتی_, --,
   {{0x7645022e,0xef1f003c,0x68ed00a0,0x4422017b}},	//   _rahy, ħżen_, _čadc, _ock_,
   {{0x64468409,0x63a20035,0x9c7c00ee,0x00000000}},	//   _naki, żony, _otči, --,
   {{0x628e45cd,0x248001f4,0x61e5840a,0x38692314}},	//   _ombo, dhim_, ychl, _voar_,
   {{0xe81f08b0,0x6d41840b,0x6446840c,0x2c7100b8}},	//   _भावा_, _ysla, _aaki, _rádi_,
   {{0x6446840d,0x7647054e,0xa2c02160,0x3869012f}},	//   _baki, rdjy, वतन्, _toar_,
   {{0x628e1423,0x644600f8,0x764509df,0xa8a400d8}},	//   _ambo, _caki, _wahy, _прык,
   {{0x6446840e,0x61e5840f,0x7645028b,0x320100b8}},	// [8d70] _daki, tchl, _tahy, tahy_,
   {{0x78af8410,0x44228411,0x82340647,0x00000000}},	//   locv, _eck_, فرما, --,
   {{0x7c220bb0,0x442201b4,0x6446518d,0x61e58412}},	//   _ocor, _fck_, _faki, rchl,
   {{0x628e8413,0x61e502bf,0xdfd100ad,0x32010097}},	//   _embo, schl, نيا_, sahy_,
   {{0x2cad0b0d,0x65c70118,0x7fd40210,0x00000000}},	//   voed_, béhé, ніші, --,
   {{0x7c221014,0x443b8414,0x6d410051,0x2905008d}},	//   _acor, leq_, _psla, ysla_,
   {{0xdd910332,0x787f01f4,0x27e9008a,0x3cc900af}},	//   کوں_, _zëve, _ofan_, олко_,
   {{0xe81f2135,0x14bf111a,0x644601ed,0x987200ea}},	//   _भाषा_, ्षिण, _xaki, kšā_,
   {{0x200d7d94,0x7c22009e,0xddc10160,0x2cad7cf4}},	//   _idei_, _dcor, _bolţ, roed_,
   {{0x2cad8415,0xbdf8042c,0xddc10395,0x29057fb9}},	//   soed_, _فرما_, _colţ, tsla_,
   {{0xa9695451,0x19c538df,0x38960029,0x200d012f}},	//   цина_, ьбом, kārt_, _kdei_,
   {{0x162027bd,0x29052129,0x27e9009e,0x7d1c03db}},	//   _बाहर_, rsla_, _cfan_, _årsa,
   {{0xeaae0012,0xb9040825,0xeb8e19f0,0x7c3b0248}},	//   _ай_, _भू_, _ри_, meur,
   {{0x64468416,0x7c3b8417,0x27e90211,0x2eed0371}},	//   _saki, leur, _efan_, _mtef_,
   {{0xceb25019,0xa3d906fe,0x64468418,0xb4d81746}},	//   דים_, ाशं_, _paki, ादे_,
   {{0x7c3b8419,0x00000000,0x00000000,0x00000000}},	//   neur, --, --, --,
   {{0x23270714,0x6446841a,0x248001f2,0x4422841b}},	// [8d80] моти_, _vaki, rhim_, _vck_,
   {{0x6446484c,0x2480841c,0x7c3b841d,0xae1c021a}},	//   _waki, shim_, heur, _नाइन_,
   {{0x6446841e,0x7c3b0244,0x6f090453,0x23600221}},	//   _taki, keur, _avec, sxij_,
   {{0x7c3b841f,0x9c7c2e6f,0x44220031,0xa927031d}},	//   jeur, _kuče, _uck_, _zaží,
   {{0x9c7c029d,0x1eaa004f,0x7c3b8420,0x98a70254}},	//   _juče, ياتي_, deur, žića_,
   {{0x44208421,0x628e0093,0x9c7c01a0,0x00000000}},	//   lgi_, _umbo, _muče, --,
   {{0x9c7c8422,0x7c3b8423,0x442000e9,0x389600ea}},	//   _luče, feur, ogi_, nārs_,
   {{0x44208424,0x7c3b0248,0xf8c800ab,0x547b0070}},	//   ngi_, geur, रगोप, ַטיו,
   {{0x44208425,0x6b8d0009,0xf2df0139,0xcf4648a1}},	//   igi_, _žagr, _frâu_, _юнай,
   {{0xf2df0395,0x00000000,0x00000000,0x00000000}},	//   _grâu_, --, --, --,
   {{0x7c3b0a45,0x021702b8,0x195800d8,0x6f090a66}},	//   beur, וחים_, чаны_, _zvec,
   {{0xb4d80387,0x9c7c00d5,0x3eb900ea,0x7c3b0db4}},	//   ादो_, _buče, _īsti_, ceur,
   {{0x3f860391,0xab9a08cf,0xa9270168,0x00000000}},	//   nzou_, _بخار_, _paží, --,
   {{0x64830006,0xf98f07e4,0x442049a3,0xddda000c}},	//   _kõig, ابی_, egi_, _potř,
   {{0x08f70c9e,0x7ce70225,0xddc1210c,0x443b8426}},	//   _قريب_, _kıra, _kolš, teq_,
   {{0x44208427,0x261b193c,0x629e02ee,0x9c7c0207}},	//   ggi_, _बाकी_, enpo, _fuče,
   {{0x43940798,0x66c0022a,0x648300ab,0x443b0c6f}},	// [8d90] ватс, söka, _lõig, req_,
   {{0x629e1bc5,0x44208428,0xa3ce0e9b,0x00000000}},	//   gnpo, agi_, षेध_, --,
   {{0x30152d4d,0x2eed8429,0x33290484,0x6f09842a}},	//   едер, _stef_, stax_, _svec,
   {{0x4420011e,0x8c3d002d,0xf8ca00e2,0x629e11e7}},	//   cgi_, noşt, _bẩy_, anpo,
   {{0xa3b616c1,0xb4bd004e,0x7c3b2226,0x290a0009}},	//   _चुप_, ेगी_, veur, šbah_,
   {{0x171c0070,0x00000000,0x00000000,0x00000000}},	//   קווע, --, --, --,
   {{0x7ce701d6,0x7c3b1691,0x7bc2842b,0x3f860042}},	//   _bıra, teur, _azou, azou_,
   {{0x0b45842c,0x88bd01c0,0x7c9400d8,0x00000000}},	//   енин, stěj, крыц, --,
   {{0x7c3b842d,0xf2df0023,0x6f090124,0x009400af}},	//   reur, _trâu_, _uvec, _ритэ,
   {{0x7c3b1b11,0xdb0e004f,0xaa450eee,0x4420842e}},	//   seur, ádál, хеол, zgi_,
   {{0x9c7c00cb,0x64db00a1,0x7c3b00a2,0xa3b60726}},	//   _suče, _मंगळ, peur, _चुन_,
   {{0xb9070324,0x2c710097,0x9c7c1bd8,0x00000000}},	//   _बढ_, _pádu_, _puče, --,
   {{0x442004d4,0xd5b800ea,0x4e03046c,0xf8ca00e2}},	//   vgi_, ļām_, _रजाई_, _xẩy_,
   {{0xb4d800b4,0x9c7c011c,0x2d87080a,0x00000000}},	//   ाद्_, _vuče, ozne_, --,
   {{0xe5a30210,0x4420842f,0x38cb00e0,0x3f86034d}},	//   гири, tgi_, تایی_, zzou_,
   {{0x69c301cc,0x44208430,0x629e8431,0x9c7c0506}},	//   _izne, ugi_, wnpo, _tuče,
   {{0xb89b00a5,0x221630dd,0x00000000,0x00000000}},	// [8da0] _מבקש, ефер, --, --,
   {{0x44205a3f,0xc7d700a5,0x662900a0,0xf8ca00cc}},	//   sgi_, _אופי_, ľský, _rẩy_,
   {{0x7cd10029,0x66c000c3,0xe0580088,0x629e4f97}},	//   _dārz, löko, ویست_, rnpo,
   {{0x5f067355,0x44fe00b8,0xfbc7036b,0x4fc6005f}},	//   езда, mů_, _مت_, нсла,
   {{0x08e60b52,0xddc80035,0x44fe00b8,0x26da08c7}},	//   _কিছু_, łoże, lů_, _kipo_,
   {{0xdd94323d,0x7ce70d6f,0x3f860042,0x78a4082d}},	//   калы, _sıra, rzou_, _ljiv,
   {{0x44fe01c0,0xddc10355,0xc5f300a5,0x32cd0409}},	//   nů_, _polš, נדה_, _ežys_,
   {{0x26da8432,0xf8ca0019,0x78a4030a,0x3157011d}},	//   _lipo_, _tẩy_, _njiv, _אילן_,
   {{0xddc10009,0x44fe00b8,0x8fa3097c,0x4fa31eb9}},	//   _volš, hů_, _бате, _битв,
   {{0xdee30021,0xd90e064e,0x44fe01c0,0x26da002f}},	//   _софи, میت_, ků_, _nipo_,
   {{0x2d870755,0x2d980523,0x44fe01c0,0x00000000}},	//   czne_, _äre_, jů_, --,
   {{0x44fe01c0,0xf8ae01cb,0x6fd604d4,0xa3b600ab}},	//   dů_, يکي_, _gücü, _चुभ_,
   {{0x98742c4c,0xfb1305f5,0x00000000,0x00000000}},	//   уляц, _مونج, --, --,
   {{0x66c08433,0xb60602c4,0xba2a099f,0x7aef002a}},	//   sökn, jušč, _رستم_, ícte,
   {{0x26da012f,0x55580043,0x3eb9021d,0xddda005f}},	//   _dipo_, наря_, _êste_, _imtų,
   {{0x7ae28434,0xf96901e0,0x00000000,0x00000000}},	//   _kuot, _юрій_, --, --,
   {{0x291e423f,0x48140086,0x7ae20421,0xe3b38435}},	// [8db0] luta_, _смыс, _juot, ارز_,
   {{0x979c0052,0x64830006,0x7ae20086,0x78bd1aee}},	//   _משחק, _sõid, _muot, llsv,
   {{0x291e8436,0xf1a70426,0x7ae20086,0x82a40bfe}},	//   nuta_, хран, _luot, уште,
   {{0x26da0054,0x224a01ed,0xc07801e0,0xf8b3018d}},	//   _zipo_, _eabk_, нсії_, ीतिय,
   {{0x7ae201c8,0x54541142,0x6483007c,0x645d8437}},	//   _nuot, _свят, _võid, _insi,
   {{0x291e8438,0x644d8439,0x88bd0355,0x00000000}},	//   kuta_, ldai, stěh, --,
   {{0xd6580bed,0xa3d900c4,0x291e843a,0x644d843b}},	//   תיות_, ाशक_, juta_, odai,
   {{0x291e843c,0x2d87843d,0x4c35010b,0x645d03d0}},	//   duta_, rzne_, тэкт, _jnsi,
   {{0x7ae2843e,0x5ba90d13,0x66074962,0x60c904fb}},	//   _cuot, ьким_, kajk, _ihem,
   {{0x291e843f,0x644d0014,0xc3320122,0x7ae2010b}},	//   futa_, hdai, סוי_, _duot,
   {{0x645d8440,0x60c90a4e,0x60db0054,0xa9a50036}},	//   _onsi, _khem, _kium, тинд,
   {{0x26da8441,0x9b925b0c,0x69c32018,0x44fe0355}},	//   _sipo_, الیت, _vzne, vů_,
   {{0x26da8442,0x6ec50803,0x644d016e,0x60c98443}},	//   _pipo_, ितपु, ddai, _mhem,
   {{0x70ad0035,0x44fe0355,0x09e216bc,0x44e700cc}},	//   टकुल, tů_, _кошн, _bõ_,
   {{0x69c31ac4,0x291e31f7,0x26da8444,0x9c7c0168}},	//   _uzne, cuta_, _vipo_, _huča,
   {{0x44fe01c0,0x644d1b82,0x9c7c0169,0x6b9600c7}},	//   rů_, gdai, _kuča, _žygi,
   {{0xe1f2147f,0x44fe01c0,0x6b892fe9,0x6297002a}},	// [8dc0] لسا_, sů_, nzeg, fixo,
   {{0x645d4466,0x644d148b,0x6f1900e9,0x44fe00b8}},	//   _ensi, adai, drwc, pů_,
   {{0x9c7c8445,0x44e701a5,0x68e30279,0xb606023a}},	//   _luča, _gõ_, _jund, rušč,
   {{0x60db8446,0xc2f60033,0x644d055c,0x00000000}},	//   _cium, _চিঠি_, cdai, --,
   {{0x68e38447,0x16162064,0x60c98448,0x60db8449}},	//   _lund, _तयार_, _dhem, _dium,
   {{0x7ae203fe,0x68e30523,0x291e844a,0x60c9844b}},	//   _ruot, _ound, yuta_, _ehem,
   {{0x60db02fb,0x68e3844c,0x29110187,0x60c90069}},	//   _fium, _nund, ázal_, _fhem,
   {{0x291e844d,0x69b50035,0x7d1c0542,0x9c7c1f45}},	//   vuta_, _उड़ी, _årsm, _buča,
   {{0x7ae2844e,0xdee61b50,0x68e3780f,0xeb970274}},	//   _quot, _рози, _aund, кић_,
   {{0x291e03cb,0x7ae220b6,0x3a275a67,0x68e3844f}},	//   tuta_, _vuot, _ccnp_, _bund,
   {{0x200401d2,0x0c268450,0x68e38451,0x644d001e}},	//   _kemi_, _амен, _cund, ydai,
   {{0x7ae203ad,0x200401d2,0x291e8452,0x44e70028}},	//   _tuot, _jemi_, ruta_, _rõ_,
   {{0x6b89006a,0x6d5c0a20,0x291e8453,0xda341397}},	//   czeg, _árab, suta_, _белы,
   {{0x27e003cb,0x68e30b73,0xd954036b,0x00000000}},	//   _egin_, _fund, _منتخ, --,
   {{0x644d009e,0x00000000,0x00000000,0x00000000}},	//   tdai, --, --, --,
   {{0x44e701a5,0x200474d9,0x61ee5f6d,0xed1000e2}},	//   _võ_, _nemi_, _afbl, _đổi_,
   {{0x644d8454,0xe374004b,0x62970069,0x68e38455}},	// [8dd0] rdai, алты, tixo, _zund,
   {{0x60c9632e,0xf8bf8456,0x644d01a6,0x25f6258f}},	//   _shem, llé_, sdai, ्रणी_,
   {{0x60c9006d,0x60db8457,0x6b892afb,0x648300ab}},	//   _phem, _pium, zzeg, _võib,
   {{0x645d8458,0xd1c8027a,0x6285055c,0x7d1c00c3}},	//   _unsi, тууд_, shho, _ärsy,
   {{0x20043645,0x60db0054,0xe8e00023,0x672d0024}},	//   _demi_, _vium, _ướt_, _jqaj,
   {{0x9c7c0c0a,0x290c00d7,0xf8bf8459,0x672d0024}},	//   _ruča, ksda_, hlé_, _mqaj,
   {{0x60c9845a,0x62950055,0x6605008b,0x20040055}},	//   _them, _imzo, _mehk, _femi_,
   {{0x68e31b99,0x9c7c022f,0x6605845b,0x6b89845c}},	//   _rund, _puča, _lehk, tzeg,
   {{0xa2b923db,0x09e55604,0xf8bf0097,0x672d0069}},	//   ्तप्, лопн, dlé_, _nqaj,
   {{0x68e3845d,0x6b890035,0x2004845e,0xb88600ac}},	//   _pund, rzeg, _zemi_, _mníš,
   {{0x6b89845f,0x7ce701d6,0x69250409,0x8d7401cb}},	//   szeg, _kırm, ымна, _پالا,
   {{0x9b450a72,0x68e38460,0x672d009f,0xf8bf000d}},	//   _منصو, _vund, _bqaj, glé_,
   {{0x68e38461,0x9cd60122,0xc7960f99,0x9c7c0124}},	//   _wund, _עונה_, урны, _kučn,
   {{0x68e38462,0x6d5c004f,0x2cbf00be,0x66e32682}},	//   _tund, _árac, llud_, сора,
   {{0x68e38463,0xf8bf8464,0x9c7c05e2,0xc22400d1}},	//   _uund, blé_, _mučn, یکسو,
   {{0x9c7c63db,0x61fb0009,0x672d0069,0xf8bf000d}},	//   _lučn, _đula, _fqaj, clé_,
   {{0x741300bf,0x7ce7027d,0x38600051,0x3b0d021d}},	// [8de0] صولا, _sırl, _inir_, nseq_,
   {{0x20048465,0xe3b7032f,0xe2976cbe,0x09d70033}},	//   _semi_, убу_, гау_, _দ্যা,
   {{0xed450987,0x7a7a02b5,0x7f4905c9,0xda7a0070}},	//   _بھ_, ערעס, _aseq, ענער,
   {{0xdee6095d,0xc4831c20,0x19b6016b,0x00000000}},	//   годи, _глюк, אפער_, --,
   {{0x9c7c0169,0x43760043,0x3ae900e2,0x2cbf0207}},	//   _bučn, _сунт, _núp_, dlud_,
   {{0x91e31578,0x3ce500ec,0x00000000,0x00000000}},	//   _горе, _bulv_, --, --,
   {{0x20048466,0x7f490036,0xf8bf8467,0x11d50208}},	//   _temi_, _eseq, ylé_, _вітр,
   {{0x115b02b5,0x3ae90023,0x20551403,0xa177016b}},	//   _אדלע, _búp_, _ктур, _געלד_,
   {{0x543b0070,0x3ae90019,0xc61c0033,0x00000000}},	//   געפא, _cúp_, দ্যা_, --,
   {{0xfce68468,0x38600345,0x00000000,0x00000000}},	//   _божо, _anir_, --, --,
   {{0x09d70083,0x02b70070,0x8c260833,0x3ce508c8}},	//   _দ্বা, רליך_, _مفاه, _gulv_,
   {{0x2cbf00af,0xf8bf00a2,0x81d60033,0x00000000}},	//   clud_, ulé_, _সভা_, --,
   {{0xf8bf00f7,0xed580168,0x00000000,0x00000000}},	//   rlé_, _szľh_, --, --,
   {{0xf8bf0187,0xa3d8111b,0xe45f01ff,0x3ea00098}},	//   slé_, ाधन_, _snö_, éith_,
   {{0xf8bf8469,0x998c042a,0x45d5846a,0x6e351008}},	//   plé_, ledž_, ровс, _özbe,
   {{0x660501e4,0xd498002d,0x93f50144,0x3e790260}},	//   _wehk, гру_, рпац, _vèti_,
   {{0x6605846b,0xd5b10066,0x00000000,0x00000000}},	// [8df0] _tehk, _आँकड़, --, --,
   {{0xa1590c0d,0x63bd1615,0xa1ab1129,0x00000000}},	//   казу_, _vysn, нтез_, --,
   {{0x9c7c0184,0xa2b90355,0xd011414b,0x63bd2308}},	//   _ručn, ्तब्, قلا_, _wysn,
   {{0xb4fa00c2,0x7ce700a8,0xdb020176,0x40350a19}},	//   _שפרי, _qırm, _oxoà, редс,
   {{0x44394831,0x24891a07,0xde052bc4,0x9c7c0116}},	//   _ibs_, mham_, апли, _pučn,
   {{0x644f846c,0x2489846d,0xd3360070,0x9c7c846e}},	//   _haci, lham_, _דרשה_, _bučo,
   {{0x644f42b7,0x442b073a,0x3ae900e2,0x365c00a5}},	//   _kaci, _kcc_, _súp_, תכונ,
   {{0x644f846f,0xaf341c0c,0x24898470,0x44398471}},	//   _jaci, _گرفت, nham_, _jbs_,
   {{0x644f8472,0x9c7c5e42,0xfd4c01a5,0x6a8554d3}},	//   _maci, _tučn, _khiể, илиа,
   {{0x644f12c3,0x7f840037,0xdd9529d6,0x00000000}},	//   _laci, _الكن, _казы, --,
   {{0xf866190a,0x44398473,0x00000000,0x00000000}},	//   авно, _obs_, --, --,
   {{0x44398474,0x442b8475,0x2bd200b4,0xcb960088}},	//   _nbs_, _ncc_, देहा, انیش_,
   {{0x248928c3,0x66e6094f,0x9c7c023a,0x00000000}},	//   dham_, рога, _mučl, --,
   {{0x44398476,0xe9a800b5,0x9620021a,0x00000000}},	//   _abs_, ئدین_, बलेट_, --,
   {{0xa5070be8,0xf4960f99,0x00000000,0x00000000}},	//   иера_, араю, --, --,
   {{0x2bd2009a,0x3d081033,0x24898477,0xc48362c5}},	//   देवा, _सबसे_, gham_, олск,
   {{0x644f8478,0xa206066f,0x02068479,0xb6a600d4}},	// [8e00] _daci, ипад, изан, _випл,
   {{0x442b01d3,0x5eaa0083,0x4439010d,0xe1f730fe}},	//   _ecc_, _চীনে, _ebs_, игу_,
   {{0x2489002a,0xb1460de2,0x361b076b,0x600a208b}},	//   bham_, рнел, _בויד, внем_,
   {{0x644f847a,0x2489847b,0x92e40033,0x00000000}},	//   _gaci, cham_, _নবী_, --,
   {{0x24804aec,0x00000000,0x00000000,0x00000000}},	//   mkim_, --, --, --,
   {{0x644f847c,0x5f1714eb,0x9757011d,0x24800067}},	//   _zaci, _निर्_, יינו_, lkim_,
   {{0x644f847d,0x4439012f,0x27f200e9,0xe297005f}},	//   _yaci, _ybs_, _ofyn_, _тар_,
   {{0x24800bc5,0x9c7c0009,0x644f01ef,0xc0e3847e}},	//   nkim_, _vučo, _xaci, _фотк,
   {{0x8aa63649,0x00000000,0x00000000,0x00000000}},	//   ирод, --, --, --,
   {{0xc33302da,0x60c2847f,0x4f9500af,0x24808480}},	//   קות_, llom, _урсу, hkim_,
   {{0xa2b9022e,0xc27b0070,0xfc6602fb,0x24808481}},	//   ्तत्, דריי, _вълн, kkim_,
   {{0x5faa0099,0xdd7b016b,0x00000000,0x00000000}},	//   _कशाल, _שטאל, --, --,
   {{0x07a401c8,0x2bd20253,0xfaa6141d,0xfbd200b8}},	//   жаўн, देशा, _кадо, देशम,
   {{0x6d5a1cb0,0x4b7b0277,0x00000000,0x00000000}},	//   _krta, _באדו, --, --,
   {{0x2419021f,0x9c7c02a7,0x44390147,0x27f20090}},	//   ловы_, _lučm, _pbs_, _ffyn_,
   {{0x6d5a0254,0x38b200ac,0x00000000,0x00000000}},	//   _mrta, káry_, --, --,
   {{0x24898482,0x644f8483,0x2284013c,0x60c28484}},	// [8e10] rham_, _vaci, _söka_, dlom,
   {{0x6d5a0d6f,0x442b018e,0x644f5ddb,0x2ca900f4}},	//   _orta, _wcc_, _waci, čadi_,
   {{0x644f8485,0x442b8486,0x24898487,0x75d50934}},	//   _taci, _tcc_, pham_, _ديدا,
   {{0x24808488,0x60c28489,0x9c7c023a,0x644f009e}},	//   ckim_, glom, _bučm, _uaci,
   {{0x4429848a,0x6d5a03d0,0xfd4c0019,0x543a0070}},	//   mga_, _arta, _thiể, _גערא,
   {{0x5285004f,0x291e012f,0x7c3900e9,0x7ce70225}},	//   _السك, krta_, _sbwr, _hıri,
   {{0x4429848b,0x60c2848c,0x6d5a0a78,0xddc800d5}},	//   oga_, blom, _crta, _podš,
   {{0x4429848d,0x00000000,0x00000000,0x00000000}},	//   nga_, --, --, --,
   {{0x291e0033,0x6d5a848e,0x6d5c848f,0x628700f4}},	//   erta_, _erta, _áran, _kljo,
   {{0x44292db0,0xf2d2016b,0x8e740037,0x6d5a0207}},	//   hga_, ּעט_, _والض, _frta,
   {{0xd9458490,0xb4e60755,0x24801591,0x291e00f4}},	//   щени, _पढे_, ykim_, grta_,
   {{0x4429085e,0x9c7c023a,0x8c46013b,0x913a016b}},	//   jga_, _lučj, yişə, נערק,
   {{0x44296041,0x291e0037,0x6d5a0207,0x6287017b}},	//   dga_, arta_, _zrta, _oljo,
   {{0x7bcb0888,0x44298491,0xf7430279,0x00000000}},	//   _izgu, ega_, џеро, --,
   {{0xe8f52e63,0x248002f6,0x291e011c,0x4429373d}},	//   _استخ, tkim_, crta_, fga_,
   {{0x44298492,0xdb23008a,0x628702a7,0x20d70024}},	//   gga_, _þróu, _aljo, _għix_,
   {{0xf8b31abe,0x24808493,0x9c7c0009,0x7afb8494}},	// [8e20] _משה_, rkim_, _bučj, nput,
   {{0x248035b9,0x3d08007c,0x6fce07b5,0x7c298495}},	//   skim_, _सबले_, _तरबू, hger,
   {{0x27ed0888,0xc6930122,0x442907e7,0xd6db00a5}},	//   žene_, _מאז_, bga_, _תחיל,
   {{0x7c298496,0x53a68497,0x00000000,0x00000000}},	//   jger, _гамб, --, --,
   {{0x60c26338,0x8c460095,0x7afb00ec,0x7c290147}},	//   rlom, qişə, jput, dger,
   {{0x44ee00e8,0xacf812bd,0x7c295ff4,0x60c28498}},	//   _ký_, анку_, eger, slom,
   {{0x7c298499,0x629e849a,0x00000000,0x00000000}},	//   fger, mipo, --, --,
   {{0x629e849b,0x6d5a0a4c,0x317b0070,0x291e00f4}},	//   lipo, _vrta, _גאלד, vrta_,
   {{0x44ee00e8,0xeaf700bf,0x320a016f,0xa3d800c0}},	//   _lý_, یریت_, _keby_, ाधि_,
   {{0xaa66271c,0x44290881,0x33770122,0x391405a3}},	//   стик, zga_, צעים_, омор,
   {{0x4429849c,0x6d5a06a2,0x44ee008a,0x291e081b}},	//   yga_, _urta, _ný_, urta_,
   {{0xc17300a5,0x9c7c01a0,0x00000000,0x00000000}},	//   לחת_, _mučk, --, --,
   {{0x629e849d,0x9c7c04c3,0x4429849e,0xa09b0070}},	//   kipo, _lučk, vga_, ריכט,
   {{0x44290553,0x7bc20159,0x8bd7011d,0x15fb0066}},	//   wga_, _iyou, _הודו_, ्रधर_,
   {{0x44290409,0xa2b9035d,0x787f00da,0x629e849f}},	//   tga_, ्तस्, _lëvi, dipo,
   {{0xcd02006a,0x442984a0,0x18a404bf,0x98a40274}},	//   mość_, uga_, _најм, _није,
   {{0x442962dd,0x660e1201,0x628700cd,0x320a0371}},	// [8e30] rga_, babk, _pljo, _beby_,
   {{0x442984a1,0x5b7b02b5,0x260700af,0x25580107}},	//   sga_, ארמא, _учиг, _fčl_,
   {{0xcd02004e,0x320a2d0d,0x9c7c00cd,0x44291901}},	//   ność_, _deby_, _vučj, pga_,
   {{0xf8c900c0,0x332084a2,0x3218028b,0x7bc200d7}},	//   रतिय, brix_, _edry_, _oyou,
   {{0x629e84a3,0x3f690d15,0x7bc20260,0x1eea00fd}},	//   bipo, рило_, _nyou, لونی_,
   {{0xcd02004e,0x629e84a4,0xee3800d4,0x9c7c0207}},	//   kość_, cipo, йні_, _fučk,
   {{0x7bc2023c,0x00000000,0x00000000,0x00000000}},	//   _ayou, --, --, --,
   {{0xa2b906bc,0x6ab30ed1,0x7c2984a5,0x7f5b3203}},	//   ्तव्, ुत्र, uger, _truq,
   {{0x7c291425,0x61fb0009,0x200f84a6,0x15fb0ca1}},	//   rger, _đulj, magi_, ्रार_,
   {{0x200f84a7,0x7afb84a8,0x7c2984a9,0x8cc90084}},	//   lagi_, rput, sger, _हीरो,
   {{0x68462fa5,0x9f460093,0xddab0086,0x7afb46c8}},	//   онна, lboð_, _стал_, sput,
   {{0x6d4101a6,0x200f007c,0x7afb00c3,0xfd100037}},	//   _ipla, nagi_, pput, _أجل_,
   {{0x61c61bb5,0xc1c61bb5,0x31c60253,0x3b095a45}},	//   _वर्ष, _वर्ग, _वर्ध, _тело_,
   {{0x200f84aa,0x96ba17e0,0x25580107,0x66c00421}},	//   hagi_, руму_, _pčl_, yöku,
   {{0x649a4e35,0x7ae308dd,0x660e3536,0xa50a18d0}},	//   атар_, _iint, rabk, реба_,
   {{0x9c7c4205,0x07a600d4,0x200f84ab,0xc6270033}},	//   _ručk, _майн, jagi_, য়গা_,
   {{0x200f0006,0x629e84ac,0x7ae306f9,0x8c3d01c2}},	// [8e40] dagi_, tipo, _kint, mişd,
   {{0x7ae30484,0x9c7c012e,0x44ee84ad,0x21a609ce}},	//   _jint, _pučk, _tý_, оизм,
   {{0x6d41006f,0x7aeb84ae,0x4fea1e38,0x68e400ab}},	//   _npla, _lugt, амен_, _kiid,
   {{0x69c30297,0x7ae365fc,0x629e84af,0x320a0187}},	//   _myne, _lint, sipo, _weby_,
   {{0xa2cb0c67,0x7ae384b0,0x69c384b1,0xa2b9012f}},	//   _तीव्, _oint, _lyne, ्तश्,
   {{0x7ae384b2,0x68e46edd,0xddc102c6,0x629e0031}},	//   _nint, _liid, _dolž, qipo,
   {{0xa2b910b7,0x200f00a1,0xfd0f0934,0x629c0118}},	//   ्तर्, bagi_, نجي_, _imro,
   {{0x7ae384b3,0x7aeb32e7,0x68e428e5,0x6d5c1dff}},	//   _aint, _bugt, _niid, _áram,
   {{0x0a6a0674,0xcd02006a,0xc4d30122,0x3ea61583}},	//   арни_, wość_, וגה_, _диаг,
   {{0x7ae33c5d,0xd90e09b9,0x34a705dc,0x9c7c0bc6}},	//   _cint, نیت_, _गद्द, _muči,
   {{0x7ae384b4,0x9c7c00cd,0x69c3016e,0x648300be}},	//   _dint, _luči, _cyne, _sõim,
   {{0x7ae384b5,0x8c4684b6,0x57f401d3,0x6c3403c5}},	//   _eint, _феде, мпют, _رفتا,
   {{0x68e439c1,0x629c84b7,0x9874311c,0x00000000}},	//   _diid, _omro, фляц, --,
   {{0x64830ccf,0x7ae384b8,0x69c300e9,0x200f84b9}},	//   _võim, _gint, _fyne, zagi_,
   {{0xd49b84ba,0x29110c5d,0x200f00fd,0x78ad0116}},	//   ара_, ázat_, yagi_, _tjav,
   {{0xd7fb0133,0x7ae384bb,0x629c05ca,0x9c7c0409}},	//   _тук_, _zint, _amro, _buči,
   {{0x53340382,0x78bd0c8c,0x7ae32973,0x27e91cc0}},	// [8e50] метт, mosv, _yint, _igan_,
   {{0x64830006,0x9c7c02c4,0x78bd565f,0xa3e70722}},	//   _kõik, _duči, losv, _पलक_,
   {{0x75830416,0x200f84bc,0x00e501cb,0x8c3d0225}},	//   _غیرم, tagi_, ستای, lişe,
   {{0x92ab0b52,0xa2cb111a,0x66c001ff,0xddc108b7}},	//   খতে_, _तीर्, sökt, _polž,
   {{0x6483007c,0x161f0722,0x6d413587,0x00000000}},	//   _lõik, _बयार_, _spla, --,
   {{0xe7e3046c,0xfce505ac,0x7aeb84bd,0x9f46003e}},	//   _गणना_, поко, _rugt, rboð_,
   {{0x7ae384be,0x27e91ea7,0x8c3d00a8,0x7aeb84bf}},	//   _rint, _ogan_, yişd, _sugt,
   {{0x27e984c0,0x69c30035,0x8c3d033e,0x6d4184c1}},	//   _ngan_, _ryne, kişe, _vpla,
   {{0x69c3177c,0xdd91006c,0x68e41b43,0xeb997a3c}},	//   _syne, بوں_, _riid, сип_,
   {{0x628584c2,0x68e40303,0x27e902d7,0x7aeb0051}},	//   nkho, _siid, _agan_, _vugt,
   {{0x68ed0009,0x8c3d013b,0x527c016b,0x00000000}},	//   _čads, tişd, ינזא, --,
   {{0x7aeb84c3,0x7ae384c4,0x69c30187,0x26c10069}},	//   _tugt, _wint, _vyne, _akho_,
   {{0x69c3001e,0x8c3d0be2,0x68e4127d,0x7c3b84c5}},	//   _wyne, rişd, _viid, mfur,
   {{0x9c7c0393,0x8afa00a5,0x69c384c6,0xaa4100c3}},	//   _ruči, _הפסק, _tyne, ärää_,
   {{0x68e400b9,0x9c7c84c7,0xf48402fd,0x00000000}},	//   _tiid, _suči, واری, --,
   {{0x7c3b6eb3,0x9c7c6158,0x34b600b4,0x62850223}},	//   nfur, _puči, ंवेद, ekho,
   {{0x6456011e,0x6aa10098,0x00000000,0x00000000}},	// [8e60] rdyi, oilf, --, --,
   {{0x9c7c011c,0x27e90051,0x7ce701fb,0x2ee503d0}},	//   _vuči, _zgan_, _yırt, _nilf_,
   {{0x867b0122,0x66c0013c,0xf67b00a5,0x00000000}},	//   _הריו, söks, _האימ, --,
   {{0x6aa101ae,0xd12f0833,0x00000000,0x00000000}},	//   hilf, طمه_, --, --,
   {{0xd00f2e63,0x2ee5016e,0x00000000,0x00000000}},	//   اله_, _bilf_, --, --,
   {{0x628506d7,0x629c012f,0x7c3b012f,0x216a84c8}},	//   ckho, _umro, efur, _лиги_,
   {{0x61430a93,0x7c3b84c9,0x40961dd0,0x6aa10a4e}},	//   _пера, ffur, _ерат, dilf,
   {{0xd00f004f,0x61fb00cd,0x00000000,0x00000000}},	//   _ملف_, _đuli, --, --,
   {{0x3d080992,0x6aa184ca,0x769000c3,0x78bd579f}},	//   _सबके_, filf, _käyd, vosv,
   {{0x02be05f8,0x68ed023a,0x7c3b0160,0x00000000}},	//   ्तिभ, _čadr, afur, --,
   {{0xe8e001a5,0x6f0901ae,0xd05c00a8,0x78bd84cb}},	//   _ngồi_, _zwec, _surə, tosv,
   {{0xab2a47ec,0x6483007c,0x7c3b011e,0xd7f80c93}},	//   _года_, _võik, cfur, зур_,
   {{0x2bdb0299,0xac97004f,0x7ce701d6,0x02be0355}},	//   मेदा, _عنها_, _fırs, ्ताभ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x941200a8,0x2a3b011d,0x78bd00fd,0x7e7a3789}},	//   liyə_, _העומ, posv, _motp,
   {{0x52c5057c,0x27e90103,0x00000000,0x00000000}},	//   वत्स, _ugan_, --, --,
   {{0x38690037,0xe66784cc,0x9412013b,0x00000000}},	// [8e70] _inar_, _етно, niyə_, --,
   {{0x09e000c8,0xedf84092,0x7e7a4ccb,0xf8bf84cd}},	//   _ম্যা, ुरोध_, _notp, loé_,
   {{0xc5fb0821,0x00000000,0x00000000,0x00000000}},	//   ्रीय_, --, --, --,
   {{0xa3e70084,0x7e6803d0,0xdbf10355,0x00000000}},	//   _पलट_, _andp, třík, --,
   {{0x3dc5001e,0x00000000,0x00000000,0x00000000}},	//   _sylw_, --, --, --,
   {{0x7c3b00d7,0x6e940362,0x941200a8,0x00000000}},	//   wfur, ничу, diyə_, --,
   {{0x25f007b5,0x3869361c,0x2d8a02b1,0x30150d6e}},	//   _आलसी_, _onar_, _übel_, _одвр,
   {{0xdbf101c0,0x7e6884ce,0x00000000,0x00000000}},	//   přík, _endp, --, --,
   {{0x6aa10024,0x7c3b84cf,0x7e7a2433,0x2ee5008c}},	//   tilf, rfur, _fotp, _tilf_,
   {{0x386984d0,0x3e180012,0x660200cd,0x3ce80066}},	//   _anar_, _ноуэ_, _đoko, _चूके_,
   {{0x7c3b04fb,0x998e0260,0x6fd90099,0x38b97905}},	//   pfur, _jefň_, बेरं, léry_,
   {{0xc6890779,0x9c7c0009,0xe73a00c3,0x3ce60036}},	//   _דא_, _buču, оем_, _giov_,
   {{0x2cad84d1,0xf3ff0183,0x386902a7,0x2cbf034d}},	//   mned_, _anão_, _dnar_, moud_,
   {{0x2cbf84d2,0xcb120122,0xdce3010b,0xf1c30409}},	//   loud_, _ילד_, tynė, _košė_,
   {{0x66e32dbe,0x2cad00a5,0x59d106bc,0xf8bf0118}},	//   тора, oned_, _हरिर, boé_,
   {{0x2cad84d3,0x130a00d8,0x2cbf60e2,0xf8d200be}},	//   nned_, жнай_, noud_, _सठिय,
   {{0x2cad84d4,0x03a31d32,0x00000000,0x00000000}},	// [8e80] ined_, вито, --, --,
   {{0x2cbf0a45,0x021900d8,0x38b900d5,0x00000000}},	//   houd_, зіць_, déry_, --,
   {{0x63a9008a,0x2cbf6ad8,0x00000000,0x00000000}},	//   _þenn, koud_, --, --,
   {{0xb4ea00b4,0x6d5c06ee,0xd095010b,0x7e7a03d0}},	//   मदी_, _árai, ншчы, _sotp,
   {{0x7e7a0537,0x76900086,0x7e680107,0x00000000}},	//   _potp, _täyd, _pndp, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60440359,0x00000000,0x00000000,0x00000000}},	//   _pčmč, --, --, --,
   {{0x2cad84d5,0x225801d7,0x38b900a2,0x628e00a0}},	//   gned_, _hark_, béry_, _hlbo,
   {{0x7e7a0176,0x8c4310b4,0x20061702,0x00000000}},	//   _totp, тење, mboi_, --,
   {{0x6f020033,0x38697254,0xd0130033,0x9412013b}},	//   mpoc, _snar_, _হায়_, riyə_,
   {{0x2918290b,0x22580122,0x2cbf2de6,0xf8bf0132}},	//   éra_, _mark_, boud_, toé_,
   {{0x648300be,0x3b86051a,0x594200b5,0x200601ed}},	//   _hõiv, _олег, _یکجہ, nboi_,
   {{0x27ed0690,0x00000000,0x00000000,0x00000000}},	//   ženo_, --, --, --,
   {{0x7afd00a0,0x3b5301e0,0x95fb0826,0xc5fb178c}},	//   íste, _шкір, ्रेट_, ्रेय_,
   {{0x7aef0038,0xd90f0043,0x870900fd,0x5558002d}},	//   íctv, _шь_, _کعبہ_, маря_,
   {{0x2bdb051d,0x628e84d6,0x3cfe021d,0x3869007b}},	//   मेवा, _albo, _mttv_, _unar_,
   {{0x20060159,0x628e0097,0x225884d7,0x00000000}},	// [8e90] dboi_, _blbo, _bark_, --,
   {{0x2cbf02d0,0x1b000033,0x2cad00fd,0x00000000}},	//   zoud_, _এটাই_, zned_, --,
   {{0x225884d8,0x66155819,0x00000000,0x00000000}},	//   _dark_, mazk, --, --,
   {{0x8c3d01c2,0x2eb9170c,0xdfd1026e,0x661584d9}},	//   kişa, ेत्त, هيا_, lazk,
   {{0x225884da,0x248984db,0x644d84dc,0x44f5057f}},	//   _fark_, mkam_, meai, _hå_,
   {{0xd3460088,0x8d55730d,0xed592611,0x2cbf84dd}},	//   _سیمه_, етич, зок_, woud_,
   {{0x3ea9022f,0x20e800d0,0x3f89010b,0x00000000}},	//   đat_, _işin_, šau_, --,
   {{0x44f543a5,0x248984de,0xa2b906bc,0x1017006c}},	//   _må_, nkam_, ्तक्, _زبرد,
   {{0x2cbf081f,0x2cad0122,0x661584df,0x44f50c71}},	//   roud_, rned_, kazk, _lå_,
   {{0x17fa0d53,0x2a7c0176,0x2b46002a,0x24890553}},	//   ूर्व_, _covb_, _dpoc_, hkam_,
   {{0xa9692235,0x44f50c60,0x661501a3,0x24897253}},	//   чина_, _nå_, dazk, kkam_,
   {{0x2d510009,0xf1b20317,0x00000000,0x00000000}},	//   _iše_, רסט_, --, --,
   {{0xeb8e16bc,0x66150ac8,0x644d84e0,0x920f09b4}},	//   _си_, fazk, deai, िराज_,
   {{0x66150291,0x2006002d,0x248900ea,0xba390070}},	//   gazk, zboi_, ekam_, _זײַט,
   {{0xceb25c8e,0x98a606cd,0x49bb01ca,0x224e01c2}},	//   אים_, _пике, _باشد_, _ölkə_,
   {{0x44f584e1,0x644d7597,0x00000000,0x00000000}},	//   _då_, geai, --, --,
   {{0x225884e2,0x661501ed,0x00000000,0x00000000}},	// [8ea0] _park_, bazk, --, --,
   {{0x44f504ca,0x201f0054,0x77640485,0x82a300af}},	//   _få_, _adui_, _irix, гауж,
   {{0x44f50b87,0xe5a667d7,0x35a60336,0x648300be}},	//   _gå_, _чини, _чанг, _rõiv,
   {{0x78a61bd8,0x24890e31,0x1af50831,0x765c448b}},	//   nikv, ckam_, _ইবনে_, ldry,
   {{0xde580eb9,0x225800be,0xa2cb0b35,0x2d5100fe}},	//   далі_, _tark_, _तीक्, _aše_,
   {{0x471b02b5,0x628e011e,0x443200fd,0x6f020510}},	//   לונג, _ulbo, lgy_, rpoc,
   {{0x6483007c,0x52be0fcf,0x9ce6002d,0x02be074f}},	//   _võiv, ्तीस, нцил, ्तीन,
   {{0x443200ac,0x77641a71,0x6f0284e3,0x661501a3}},	//   ngy_, _orix, ppoc, zazk,
   {{0x23600009,0x61f30031,0x00000000,0x00000000}},	//   nvij_, _çelë, --, --,
   {{0x2d960525,0x60c2007c,0xd8f801e0,0xadba0037}},	//   _прес, loom, мної_, _فهذا_,
   {{0xd9170421,0xe89501c8,0x6f1b044d,0xddc8201d}},	//   нья_, вань, _zvuc, _hodž,
   {{0xddc80c99,0x02be0b35,0x60c21361,0x236084e4}},	//   _kodž, ्तुन, noom, kvij_,
   {{0x44f57817,0x661506a2,0xe78700d4,0x776446bf}},	//   _så_, tazk, хуно, _crix,
   {{0x44f50b87,0x36d54e8a,0x60c20345,0x765c0345}},	//   _på_, тогр, hoom, gdry,
   {{0xd5b80cd0,0x661584e5,0x776484e6,0x046706a9}},	//   ест_, razk, _erix, нтам,
   {{0x3f860107,0x776484e7,0x391302fb,0x661501a3}},	//   kyou_, _frix, _смър, sazk,
   {{0xe80700a1,0x644d2314,0x439402c8,0x925903e6}},	// [8eb0] _व्या_, reai, гатс, маат_,
   {{0x6d4808b4,0x66d20093,0x7aea035f,0x00000000}},	//   _opda, lækn, _jift, --,
   {{0x673d84e8,0x7aea003c,0x26c300d8,0x644d02ca}},	//   ltsj, _mift, mojo_, peai,
   {{0x251a0d85,0x26c384e9,0x2ff8002d,0x00000000}},	//   _קורא, lojo_, енць_, --,
   {{0x23d51ea9,0x673d720f,0x6d482791,0x841600a5}},	//   _दरिद, ntsj, _apda, _בקרב_,
   {{0x7aea84ea,0xddc80009,0x26c3010b,0xd5b50066}},	//   _nift, _dodž, nojo_, _उखाड़,
   {{0xd6580122,0x60c284eb,0x8cb51956,0x5ff51052}},	//   גיות_, boom, ксич, _азбу,
   {{0x2d51000c,0x0b4569a8,0x764e0067,0x00000000}},	//   _vše_, внин, zeby, --,
   {{0x9e1501c8,0x26c3010b,0x6f1b0506,0x291c401f}},	//   _адзі, kojo_, _uvuc, _avva_,
   {{0x3947012f,0x44320168,0x26c300c7,0x7aea84ec}},	//   _ppns_, zgy_, jojo_, _cift,
   {{0xe9d92830,0x3ea7006c,0x69ca0297,0x7aea84ed}},	//   ько_, mint_, _cyfe, _dift,
   {{0x64830006,0x3ea784ee,0x98a64d2e,0x8c3d002d}},	//   _mõis, lint_, тиме, mişo,
   {{0x7aea00a5,0x291c008c,0x768b0225,0x00000000}},	//   _fift, _evva_, _tüyl, --,
   {{0x3ea784ef,0x60c284f0,0xb69b0ebc,0x26c384f1}},	//   nint_, zoom, spân, gojo_,
   {{0x69ca02c7,0x765c84f2,0x673d02a2,0x6d5c0093}},	//   _gyfe, rdry, atsj, _árat,
   {{0x290584f3,0x776484f4,0xb4be035d,0x764e84f5}},	//   mpla_, _trix, ेते_, seby,
   {{0x753c006a,0x443284f6,0x78a401d5,0x7f4d013b}},	// [8ec0] strz, rgy_, _imiv, çaql,
   {{0x6483007c,0xddc833ad,0x60c2018e,0x23602d7e}},	//   _sõit, _rodž, woom, rvij_,
   {{0x3ea784f7,0x60c2023f,0xfbc700f8,0x00000000}},	//   dint_, toom, _چت_, --,
   {{0x2eca1f4c,0xfbc722c4,0xddc803c9,0x47c80033}},	//   ित्त, _نت_, _podž, রেণী,
   {{0x60c284f8,0x64830006,0x00000000,0x00000000}},	//   room, _võit, --, --,
   {{0x60c20b31,0xb14632e2,0xeaa70037,0x6d480044}},	//   soom, _ингл, _ضع_, _ppda,
   {{0x205600af,0x7aea05ee,0x90c6010b,0xdfd202fd}},	//   _итар, _rift, _абве, _چيز_,
   {{0x70560a42,0xdfd200d1,0x69ca00e9,0x3ea70719}},	//   _جنرا, _نيز_, _ryfe, aint_,
   {{0xee3a84f9,0x442284fa,0xa03b0070,0x8c3d0644}},	//   _она_, _mdk_, _קעמפ, mişl,
   {{0x63a93262,0x7afd00ac,0xaa6603e6,0x3ea73094}},	//   _ženk, ísta, ттик, cint_,
   {{0x6d4884fb,0x7aea84fc,0x26c300c7,0x66d20093}},	//   _upda, _vift, vojo_, tækn,
   {{0x387f2ea0,0x386d0391,0xa9c302ce,0x8c3d0463}},	//   ður_, ñer_, рськ, nişl,
   {{0x26c300d8,0x7aea0484,0x7c226a41,0x66d284fd}},	//   tojo_, _tift, _idor, rækn,
   {{0x6d5c0037,0x673d0c1e,0x672f0124,0x78a4001c}},	//   _áras, rtsj, rucj, _emiv,
   {{0x4422012f,0x26c384fe,0x673d279f,0x7c220116}},	//   _bdk_, rojo_, stsj, _kdor,
   {{0x332984ff,0x998e0107,0x3ea78500,0x00000000}},	//   trax_, _jefō_, zint_, --,
   {{0x7c220069,0x00000000,0x00000000,0x00000000}},	// [8ed0] _mdor, --, --, --,
   {{0x68ed1631,0x44220282,0x00000000,0x00000000}},	//   _hiad, _edk_, --, --,
   {{0x68ed006c,0x7c228501,0x3ea70443,0x76900086}},	//   _kiad, _odor, vint_, _käyn,
   {{0x66020129,0x6483007c,0x7c228502,0x6fb90374}},	//   _đoki, _võis, _ndor, нгер_,
   {{0x68ed8503,0x3ea78504,0xaab400b8,0x645d8505}},	//   _miad, tint_, ुवाक, _iasi,
   {{0x0ccb0e6f,0x645d2b02,0x2bc60299,0xaec40eb9}},	//   ात्म, _hasi, _लड़ा, абіл,
   {{0x41e41112,0x3ea78235,0x00000000,0x00000000}},	//   _віта, rint_, --, --,
   {{0x799a004e,0x68ed2326,0x3ea78506,0x7d010051}},	//   dztw, _niad, sint_, _vtls,
   {{0x645d8507,0x2d878508,0x60c9007b,0x60db04fb}},	//   _masi, syne_, _ikem, _ihum,
   {{0x4439030d,0x7c2201b7,0x2fcd0118,0xf41f0282}},	//   _lcs_, _edor, _iyeg_, _kläs_,
   {{0x8c3d01d6,0x68ed01a6,0x60db8509,0x00000000}},	//   lişm, _biad, _khum, --,
   {{0x645d850a,0x7bcb0159,0x68ed850b,0xe45f01ff}},	//   _nasi, _tygu, _ciad, _skön_,
   {{0x7bcb0723,0x68ed78c0,0x60db035f,0x291805ee}},	//   _uygu, _diad, _mhum, árar_,
   {{0xb4be022e,0x645d6934,0x2905013c,0x8f9a00a5}},	//   ेत्_, _aasi, ppla_, גישי,
   {{0x68ed0608,0x44220031,0x60c9030d,0x8c3d00c1}},	//   _fiad, _pdk_, _okem, yişl,
   {{0x64a3850c,0x68ed850d,0x78a40c4b,0xa3ea23d7}},	//   баса, _giad, _umiv, едба_,
   {{0x2fcd01e8,0x23270374,0x6b89850e,0x6b9b01ae}},	// [8ee0] _nyeg_, лоти_, nyeg, nzug,
   {{0x68ed850f,0x60c922e5,0x645d0122,0x60db8510}},	//   _ziad, _akem, _easi, _ahum,
   {{0x645d8511,0x60db8512,0x00000000,0x00000000}},	//   _fasi, _bhum, --, --,
   {{0x60db8513,0x645d8514,0x44390079,0x3dcc00e9}},	//   _chum, _gasi, _gcs_, _rydw_,
   {{0x69ca0e1d,0x43750043,0x60db00d1,0x8c3d037a}},	//   _सुनी, _курт, _dhum, rişl,
   {{0x645d8515,0x00000000,0x00000000,0x00000000}},	//   _zasi, --, --, --,
   {{0x645d5f29,0x765e0054,0xa2c100b4,0x00000000}},	//   _yasi, _mapy, ववर्, --,
   {{0x27ed1851,0x645d013b,0x765e010d,0x27f2010d}},	//   ženi_, _xasi, _lapy, _ngyn_,
   {{0x68ed016f,0xa2ba074f,0x7988001e,0x2aaa095d}},	//   _riad, ्वप्, wydw, етно_,
   {{0xdee60328,0x7c2400ea,0x68ed8516,0x00000000}},	//   _сози, _ķiru, _siad, --,
   {{0x68ed68c6,0xaa6300c7,0xada300ee,0x5d860bf5}},	//   _piad, стык, _chúď, _حلال,
   {{0x6d5a8517,0x2d952dc3,0x81b90033,0x7c220118}},	//   _ista, _трус, _চরম_, _udor,
   {{0x44398518,0x2ca601b4,0x321a0345,0x6d5a0069}},	//   _rcs_, _imod_, kapy_, _hsta,
   {{0x68ed8519,0x66f4002d,0x6d5a00fe,0x00000000}},	//   _wiad, спру, _ksta, --,
   {{0x645d851a,0xa3e70096,0x68ed1d11,0x644402ea}},	//   _pasi, येन_, _tiad, ffii,
   {{0x24580b7d,0x645d035f,0x7528016f,0x6d5a0054}},	//   лась_, _qasi, ádza, _msta,
   {{0x645d851b,0x521537f8,0x291e851c,0x443903e6}},	// [8ef0] _vasi, идат, lsta_, _vcs_,
   {{0x60db08e3,0x645d0657,0x60c9851d,0x291e851e}},	//   _shum, _wasi, _skem, osta_,
   {{0x645d4507,0x6d5a851f,0x41551a82,0x60db3084}},	//   _tasi, _nsta, рвес, _phum,
   {{0x291e0dba,0x765e004e,0x3cfb0035,0xd4790070}},	//   ista_, _zapy, _लंबे_, _סאָל,
   {{0x83350779,0x6d5a8520,0x6d5c0009,0xa3ac0026}},	//   _דאָס_, _asta, _šrap, _केप_,
   {{0x291e8521,0x69d800ac,0x2ca600e9,0x8c3d00a3}},	//   ksta_, _ozve, _amod_, rişm,
   {{0x60db8522,0x2ca60069,0x6d5a0345,0x69ce027d}},	//   _thum, _bmod_, _csta, übel,
   {{0xac8503c6,0x9f0500f8,0x291e01ff,0x60db8523}},	//   ргил, _نورو, dsta_, _uhum,
   {{0x291e8524,0x6d5a8525,0x69ca0067,0x00000000}},	//   esta_, _esta, _सुबी, --,
   {{0xea891de4,0x7aa58526,0x6b9b01ae,0x394500d4}},	//   тбол_, риоз, rzug, аног,
   {{0xd9452aac,0xa3ac0026,0x291e8527,0xe80702cb}},	//   шени, _केन_, gsta_, _व्हा_,
   {{0x290300ea,0x00000000,0x00000000,0x00000000}},	//   īja_, --, --, --,
   {{0xb8fc3e8a,0x291e4e4e,0x765e02e9,0xa3e700be}},	//   _ती_, asta_, _papy, येम_,
   {{0x6d5a0411,0xb87b0138,0x00000000,0x00000000}},	//   _ysta, rmía, --, --,
   {{0x44160370,0x6d5a055c,0xe6170374,0x00000000}},	//   ифат, _xsta, рдс_, --,
   {{0x62958528,0x765e0054,0x778601d3,0x99d40833}},	//   _alzo, _wapy, _влиз, _اتها,
   {{0xd38765e1,0x644428ef,0x765e8529,0x321a012f}},	// [8f00] айте_, rfii, _tapy, tapy_,
   {{0x38606053,0x644400af,0x76900421,0x42070274}},	//   _hair_, sfii, _käym, инуо_,
   {{0xf67b00c2,0x867b0122,0xae140084,0x321a5ea7}},	//   _סאטמ, _סרטו, डरसन_, rapy_,
   {{0x50464234,0x661c852a,0x62950009,0x3860072c}},	//   редб, lark, _elzo, _jair_,
   {{0xdfcf07f6,0x44fc852b,0x3860739a,0x00000000}},	//   ويم_, _hí_, _mair_, --,
   {{0x661c852c,0x44fc01a5,0x291e852d,0x386000d1}},	//   nark, _kí_, ysta_, _lair_,
   {{0xb87b000c,0x44fc01c0,0x66d2008d,0x00000000}},	//   dmín, _jí_, tækj, --,
   {{0x44fc852e,0x661c852f,0x38608530,0x6d5a8531}},	//   _mí_, hark, _nair_, _vsta,
   {{0x661c8532,0xb7fd007c,0x44fc8533,0x6d5a0035}},	//   kark, _एलबम_, _lí_, _wsta,
   {{0x661c8534,0x7f3b011d,0x6d5a0069,0x44fc0453}},	//   jark, _בעמו, _tsta, _oí_,
   {{0x44fc8535,0x6d5a8536,0x661c8537,0x291e8538}},	//   _ní_, _usta, dark, usta_,
   {{0x291e8539,0x3860853a,0x66171037,0xaba700f8}},	//   rsta_, _cair_, _sexk, اهیم_,
   {{0x44fc0bc8,0x3860853b,0x7f420036,0x291e0523}},	//   _aí_, _dair_, ntoq, ssta_,
   {{0x44fc853c,0x661c853d,0x3f420023,0x27fe00b8}},	//   _bí_, gark, _mưu_, ětna_,
   {{0x4acf009a,0x3f4200e8,0x45d5853e,0x69d81715}},	//   _सीटव, _lưu_, совс, _uzve,
   {{0xd498853f,0x316d8540,0x44fc8541,0x386000e9}},	//   ару_, _čez_, _dí_, _gair_,
   {{0x69ca018d,0x245800c3,0x7cf5010b,0x661c0147}},	// [8f10] _सुती, шать_, _išre, bark,
   {{0x8c3d0225,0x38600139,0x00000000,0x00000000}},	//   tişk, _zair_, --, --,
   {{0xd5b80352,0x44fc8542,0xd011026e,0x3ff5026e}},	//   _вся_, _gí_, كلا_, مكار,
   {{0x3f420019,0x27ed8543,0x40350466,0x00000000}},	//   _bưu_, ženu_, седс, --,
   {{0x7535003c,0xb87b0079,0x32180118,0x3f4200cc}},	//   luzz, hmío, _fery_, _cưu_,
   {{0x5187151c,0xee3800d4,0x76558544,0x321803bc}},	//   _куба, ині_, nezy, _gery_,
   {{0x31e500c8,0x01e500c8,0x8c3d06d3,0x44fc0023}},	//   _প্রশ, _প্রদ, lişi, _xí_,
   {{0x69ca193c,0x45b80122,0x1a6801cb,0x40348545}},	//   _सुधी, יפול_, یینی_, _месс,
   {{0x201d486a,0x661c8546,0x8c3d0457,0x00000000}},	//   mawi_, yark, nişi, --,
   {{0x38605ad4,0x66d201b4,0x661c8547,0x00000000}},	//   _sair_, rækk, xark, --,
   {{0xa2ba0c03,0xa3e70099,0xb87b024e,0x661c8548}},	//   ्वत्, येत_, rmín, vark,
   {{0x201d01ca,0x661c8549,0x75350484,0x44fc0037}},	//   nawi_, wark, duzz, _rí_,
   {{0x2d8a0446,0x44fc854a,0x7e61854b,0x2cad17f0}},	//   _über_, _sí_, _kalp, mied_,
   {{0x201d854c,0x2cad854d,0x7e6102d7,0x44fc350d}},	//   hawi_, lied_, _jalp, _pí_,
   {{0x7e61854e,0x201d854f,0x6d438550,0x38604f7d}},	//   _malp, kawi_, ntna, _tair_,
   {{0x661c1201,0x386004d6,0x44fc8551,0x2cad024b}},	//   sark, _uair_, _ví_, nied_,
   {{0x201d8552,0xd46707b4,0xb2268553,0x32188554}},	// [8f20] dawi_, щите_, ймал, _pery_,
   {{0x44fc8555,0x67240009,0x7535035f,0x6d435a84}},	//   _tí_, _ivij, buzz, ktna,
   {{0x32180052,0x3f4201a5,0x201d046a,0x44fc0037}},	//   _very_, _sưu_, fawi_, _uí_,
   {{0x7f420036,0x26ca3599,0x201d336d,0x00000000}},	//   ttoq, lobo_, gawi_, --,
   {{0x6d413ed9,0x6d438556,0xa2ba112b,0x543b0070}},	//   _aqla, etna, ्वद्, _געכא,
   {{0x6d4305f5,0x7e618557,0x7f422428,0x645606d3}},	//   ftna, _calp, rtoq, leyi,
   {{0x2cad8558,0x7f42003c,0x201d2326,0x0d4a0118}},	//   fied_, stoq, bawi_, اشتي_,
   {{0x64568559,0x201d00d7,0x6724030a,0x2cad4655}},	//   neyi, cawi_, _ovij, gied_,
   {{0x6d690080,0x81cd0083,0x26ca010f,0x7c2f20d9}},	//   _īpaš, শেদ_, kobo_, ócra,
   {{0x7e61855a,0x7af90223,0x6fb30dc0,0x0e6a0079}},	//   _galp, _duwt, _عملا, _حصري_,
   {{0x67240b16,0x2cad0a45,0x6d4301e4,0x26ca855b}},	//   _avij, bied_, ctna, dobo_,
   {{0x8c3d0095,0x63bb0093,0x00000000,0x00000000}},	//   yişi, _þung, --, --,
   {{0x67242ba7,0x27ed00c3,0x24800124,0x6d5100cd}},	//   _cvij, äen_, djim_, čkaš,
   {{0x67240289,0x7535003c,0x95cb855c,0x1994149e}},	//   _dvij, tuzz, губа_, _маля,
   {{0x344b0036,0x00000000,0x00000000,0x00000000}},	//   лчан_, --, --, --,
   {{0x7535323f,0x8c3d0723,0x24800031,0x200403d0}},	//   ruzz, tişi, gjim_, _nfmi_,
   {{0x26ca855d,0x6e280f52,0xe7590210,0x2123008c}},	// [8f30] bobo_, _oddb, _типі_, _svjh_,
   {{0x63a904c3,0x8c3d00d0,0x6d43008e,0x26ca855e}},	//   _žens, rişi, ytna, cobo_,
   {{0x6724029d,0x201d855f,0x3201109e,0x6456518d}},	//   _zvij, tawi_, rchy_, beyi,
   {{0x2ec10d91,0x6e2808dd,0xd00e0118,0x4fd5111d}},	//   शक्त, _addb, پلو_, ожет,
   {{0x643a02b5,0x7ff40037,0x743a016b,0x00000000}},	//   _דערנ, أسما, _דערװ, --,
   {{0x3eae0307,0x171c02b5,0x6d438560,0x2cad8561}},	//   gift_, נווע, ttna, wied_,
   {{0x7e618562,0xdc9918cd,0x5184002d,0x201d067f}},	//   _valp, итиш_, _еута, pawi_,
   {{0x6d438563,0x13ad0033,0xcf2e0225,0x6aaa0090}},	//   rtna, _কুয়, üğüm_, _amff,
   {{0x62870537,0x6d438564,0x7e618565,0x2cad25a6}},	//   _kojo, stna, _talp, ried_,
   {{0xa9251204,0x60cb4157,0x64568566,0x4ea71ee7}},	//   одол, logm, zeyi, _урба,
   {{0x67240280,0x3f8f02c7,0x62870fe3,0x2d670254}},	//   _svij, lygu_, _mojo, _uđe_,
   {{0x62873ad3,0x776d8567,0x6105004b,0x00000000}},	//   _lojo, _brax, _gėle, --,
   {{0x776d8568,0x78bd01dd,0x26ca024c,0x00000000}},	//   _crax, érva, tobo_, --,
   {{0xd4910023,0xa9690834,0xf1be00b8,0x6287081b}},	//   ền_, _вика_, ्थमन, _nojo,
   {{0xa2ba09a8,0xd05f00a8,0x64568569,0xdbd4003e}},	//   ्वस्, şvət, teyi, _húði,
   {{0x7c3b856a,0x776d002a,0x6f090168,0x26ca54df}},	//   ngur, _frax, _otec, sobo_,
   {{0x67240280,0x6287856b,0x776d0391,0x52aa856c}},	// [8f40] _uvij, _bojo, _grax, авам_,
   {{0x6287856d,0x2480856e,0x6456033e,0xd36f0079}},	//   _cojo, sjim_, seyi, ضهم_,
   {{0x62875b15,0x00000000,0x00000000,0x00000000}},	//   _dojo, --, --, --,
   {{0xd46a0274,0x00000000,0x00000000,0x00000000}},	//   _тиме_, --, --, --,
   {{0x4420856f,0x7c3b023a,0x161e21a8,0x6f0900fe}},	//   mai_, dgur, _बजार_, _ctec,
   {{0x62878570,0xddc1004b,0xe29a03c6,0x00000000}},	//   _gojo, _galū, _таг_, --,
   {{0x412702ee,0x3eae521d,0x68f9013b,0xbea30279}},	//   _моро_, rift_, _əbdü, ќајк,
   {{0x44202143,0x6ab40096,0xc5f3011d,0xa2ba0ed1}},	//   nai_, ुव्र, ודו_, ्वव्,
   {{0x1fd10083,0x44200160,0x46da0099,0x3fb600fd}},	//   ়েবস, iai_, णताह, _بھاگ_,
   {{0x7c3b8571,0x20e80225,0x13ad0033,0xcfa90079}},	//   agur, _eşit_, _কুড়, _طاقم_,
   {{0x44208572,0x69ca1649,0x41d00084,0xa3ac0325}},	//   kai_, _सुशी, _तुमस, _केस_,
   {{0x44208573,0x776d6a46,0x7d0d00cd,0x290c02d7}},	//   jai_, _prax, ćast, rpda_,
   {{0x44208574,0xe6671d67,0x7cf5010b,0x69ca00ab}},	//   dai_, отво, _išra, _सुरी,
   {{0x24550019,0x7c208575,0x00000000,0x00000000}},	//   _ấm_, lamr, --, --,
   {{0x44208576,0x62870a17,0x2bce01d1,0x1a9b016b}},	//   fai_, _rojo, _हुता, _דיגע,
   {{0x44201760,0x776d1a71,0x7c202d0d,0x00000000}},	//   gai_, _trax, namr, --,
   {{0x8c3d01d6,0x62878577,0xddc12143,0x78ad240f}},	// [8f50] mişt, _pojo, _palū, _imav,
   {{0x8c3d8578,0x320b0036,0x7afd8579,0x2369003d}},	//   lişt, рхан_, ísti, rvaj_,
   {{0x4420857a,0x6f0901ae,0xddc10029,0x7c20857b}},	//   bai_, _stec, _valū, kamr,
   {{0x4420857c,0x8c3d857d,0x00000000,0x00000000}},	//   cai_, nişt, --, --,
   {{0xb4d704eb,0xa2ba0534,0x53440573,0x62873f2e}},	//   िती_, ्वश्, _охра, _tojo,
   {{0x81cd00c8,0x66d2008d,0x00000000,0x00000000}},	//   শেষ_, bæku, --, --,
   {{0xa2ba073f,0x78ad007c,0x442b857e,0x8cc748cd}},	//   ्वर्, _omav, _kdc_, ावलो,
   {{0x442b5f4a,0xed4e0118,0x00000000,0x00000000}},	//   _jdc_, اپي_, --, --,
   {{0xbf151b15,0x7c3b857f,0x998e0260,0xdaa90382}},	//   _رواب, rgur, _jefņ_, йвид_,
   {{0x44208580,0x7c3b8581,0x78ad0010,0xb4d70066}},	//   zai_, sgur, _amav, ितु_,
   {{0x81cd00c8,0x44208582,0x88ca0c46,0x8d740098}},	//   শের_, yai_, йлов_, _ياما,
   {{0xa3ac0006,0x44208583,0x29e10183,0xf1be01c0}},	//   _कइल_, xai_, _açaí_, ्थतन,
   {{0x44208584,0x2be2018d,0xf7720037,0xd5b70023}},	//   vai_, _परया, راح_, ống_,
   {{0x44205443,0x442b8585,0x59cf0324,0x644f8586}},	//   wai_, _adc_, _सुथर, _abci,
   {{0x44208587,0x049601c8,0xd5b20037,0x6ac701d1}},	//   tai_, праў, رفر_, रकीर,
   {{0x2be2020c,0x8c3d34c3,0x442b05f0,0x00000000}},	//   _परमा, mişs, _cdc_, --,
   {{0x442015d6,0x5ede021a,0x59cf1b8f,0xf1fa0c9e}},	// [8f60] rai_, गतम्_, _सुतर, معات_,
   {{0x442b66cd,0x27e08588,0x2bce07b5,0x00000000}},	//   _edc_, _izin_, _हँसा, --,
   {{0x442b001c,0x68e402c2,0x2be2052f,0xa3ac0084}},	//   _fdc_, _khid, _परभा, _केर_,
   {{0xfbcb06fe,0xe0d208cf,0x6ac771ff,0x00000000}},	//   ाथाम, رزا_, रकुर, --,
   {{0x672602ce,0x68e40211,0x661e53d6,0x68f60225}},	//   nskj, _mhid, _kepk, _miyd,
   {{0x4255798c,0x7c2b0159,0xbea37a34,0x543600f8}},	//   _отст, _adgr, начк, _برگر,
   {{0xfd0f026e,0x63a48589,0x68e401ed,0x00000000}},	//   هجي_, lzin, _ohid, --,
   {{0xc5f300a5,0x63a4858a,0x59cf0f06,0x00000000}},	//   עדה_, ozin, _सुधर, --,
   {{0x8fa3206f,0x69c30036,0xe4570070,0x00000000}},	//   _зате, _axne, ליקט_, --,
   {{0x63a42173,0x3a740ea7,0x8f9b011d,0x7c20858b}},	//   izin, флор, _הימי, samr,
   {{0xade804cc,0x68e400f1,0x8c3d23ee,0x59cf0266}},	//   टेशन_, _bhid, tişt, _सुदर,
   {{0x290a0ae0,0x68e4858c,0x63a401b7,0x2006858d}},	//   ība_, _chid, kzin, ncoi_,
   {{0x68e4858e,0x4bda6846,0x63a40a75,0x8c3d858f}},	//   _dhid, _اباد_, jzin, rişt,
   {{0x63a48590,0xf1be1bb5,0x7cc10029,0x27e00409}},	//   dzin, ्थान, mēra, _dzin_,
   {{0xd49b8591,0x27e00291,0xe5c42d35,0x78ad024e}},	//   бра_, _ezin_, есто, _tmav,
   {{0xb4d72fa9,0xe45f00fb,0x68e48592,0x68f60225}},	//   िते_, _mjög_, _ghid, _giyd,
   {{0xa3e707ba,0x442b12ec,0x63a40223,0xe45f0523}},	// [8f70] यें_, _vdc_, gzin, _ljög_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442b08c8,0x78bd4df9,0x66d20093,0x2bbe00cc}},	//   _tdc_, onsv, rækt, ịch_,
   {{0x442b3cba,0x629c0987,0x63a48593,0x00000000}},	//   _udc_, _elro, bzin, --,
   {{0x644d8594,0x5f9400d4,0x00000000,0x00000000}},	//   mfai, ницт, --, --,
   {{0x644d8595,0x661e0176,0x7d1a099e,0x7a2900fd}},	//   lfai, _xepk, _bwts, _kötő,
   {{0x7d1a0090,0x00000000,0x00000000,0x00000000}},	//   _cwts, --, --, --,
   {{0x644d8596,0xfd5e0019,0xeb99290a,0x61050409}},	//   nfai, _huyề, жии_, _gėla,
   {{0x76900d36,0x00000000,0x00000000,0x00000000}},	//   _käyt, --, --, --,
   {{0x68e48597,0x6f1b0027,0x00000000,0x00000000}},	//   _shid, _iwuc, --, --,
   {{0x63a48598,0x661e8599,0xdd9b002d,0x6e2310e2}},	//   zzin, _repk, _уша_, manb,
   {{0xb4d7661a,0x61ec00a8,0x7cf5005f,0x00000000}},	//   ितो_, ünlə, _išro, --,
   {{0x644d004f,0x02bf6ff9,0xa3ac07b5,0xb4d7018d}},	//   dfai, ्वाभ, _कें_, ितै_,
   {{0x7afd0076,0x769003ad,0xddc3006c,0x68e4010d}},	//   ístu, _näyt, lenő, _whid,
   {{0x644d6208,0xa507059b,0x67264b19,0x2362023a}},	//   ffai, деса_, sskj, _sskj_,
   {{0x63a4859a,0x6e230168,0x644d859b,0x27e00160}},	//   tzin, hanb, gfai, _tzin_,
   {{0xc61d00c8,0x6e23859c,0x661e027d,0x7ce50183}},	// [8f80] _তারা_, kanb, _tepk, mórd,
   {{0x77640298,0xe1f22ac4,0x4ecf0033,0x2a670260}},	//   _isix, نسا_, িগুল, _janb_,
   {{0x81d60083,0x63a4859d,0x64a61023,0x644d1c31}},	//   াইভ_, szin, _жана, bfai,
   {{0x765c859e,0xd12f00ce,0x644d0037,0x38ab0035}},	//   lery, شمه_, cfai, _górę_,
   {{0x09b10033,0x2be200be,0xa3c800ab,0x213a08c7}},	//   _ঘুমা, _परधा, _ऊँट_, suph_,
   {{0xfe6f026e,0xc3330319,0x765c859f,0x81cd0831}},	//   لدى_, _בוש_, nery, শেই_,
   {{0x201f022e,0x60260dec,0x91030279,0x00000000}},	//   _feui_, _одва, _апсе, --,
   {{0x2be2018d,0x7764002a,0x6e230051,0xdcb700af}},	//   _परदा, _osix, aanb, дщь_,
   {{0x9ce800f5,0xd00f1b15,0x00000000,0x00000000}},	//   _ہوئے_, _خلق_, --, --,
   {{0xee37075a,0xed5a0185,0x00000000,0x00000000}},	//   _ону_, _моз_, --, --,
   {{0x644d85a0,0x765c85a1,0x7e7a158c,0xd91700c3}},	//   yfai, dery, _intp, мья_,
   {{0x6f000054,0x00000000,0x00000000,0x00000000}},	//   _kumc, --, --, --,
   {{0xb9051365,0xfbe209b1,0x61fc28c2,0x765c85a2}},	//   _बी_, _परिम, _ogrl, fery,
   {{0xb4d700dc,0x59cf0099,0x765c448b,0x7ce50042}},	//   ित्_, _सुवर, gery, tórg,
   {{0x77640391,0x3ce6006f,0x7e6808c8,0xdef8007a}},	//   _esix, _khov_, _madp, _miċ_,
   {{0xfbe20803,0x7ce560fd,0x260f0d1f,0x290e0024}},	//   _पराम, córd, _त्री_, _itfa_,
   {{0x644d85a3,0xf8bf1840,0x69d80120,0x765c0273}},	// [8f90] rfai, mné_, _hyve, bery,
   {{0x3869019c,0xfd5e0028,0x7e680e7d,0xf8bf031b}},	//   _haar_, _quyề, _nadp, lné_,
   {{0xb0351a24,0xf8bf85a4,0x673d00d4,0x6e238362}},	//   енеш, oné_, lusj, vanb,
   {{0xf8bf2afa,0x3869201e,0x6f000024,0x9f9c0093}},	//   nné_, _jaar_, _bumc, tæða_,
   {{0x386985a5,0x6e231a68,0x769003ad,0xe0d800d4}},	//   _maar_, tanb, _täyt, єві_,
   {{0x9e640823,0x6d4a626d,0x9f9c0093,0x38694a26}},	//   квід, ftfa, ræða_, _laar_,
   {{0xf8bf85a6,0xa2cc09b4,0x7e7a0176,0x6e2385a7}},	//   kné_, तकर्, _dntp, ranb,
   {{0x38694cca,0x6ac70d91,0x6e2385a8,0xf8bf05d3}},	//   _naar_, रक्र, sanb, jné_,
   {{0xf8bf114d,0xdef8003c,0x00000000,0x00000000}},	//   dné_, _fiċ_, --, --,
   {{0x2eca0e9b,0x961e01c0,0x69d80a8a,0x673d85a9}},	//   ाकृत, _बजेट_, _byve, dusj,
   {{0x765c85aa,0x38694c91,0xe9d901d3,0x186a0dde}},	//   very, _baar_, яко_, пани_,
   {{0x6e2185ab,0xf8bf0248,0x3ce6006d,0x7cc10029}},	//   _helb, gné_, _ghov_, mēro,
   {{0x3869019c,0x765c5278,0x69ce01ae,0x7d0111ad}},	//   _daar_, tery, über, _huls,
   {{0x2cbf007c,0x753c0035,0x7d012d4c,0x7ce502d7}},	//   lnud_, turz, _kuls, sórd,
   {{0x69d80a93,0xf8bf0d88,0x649a0183,0xba74006c}},	//   _gyve, bné_, птар_, _جانت,
   {{0x38695597,0xf8bf0076,0x765c2aaf,0x7ce51d2b}},	//   _gaar_, cné_, sery, bóre,
   {{0x765c70a3,0x26d185ac,0x00000000,0x00000000}},	// [8fa0] pery, bozo_, --, --,
   {{0x2be2020d,0x21a6257f,0x056685ad,0xc3090033}},	//   _परसा, низм, _звон, _লিখি_,
   {{0x6f0000ac,0x7d010b3e,0x00000000,0x00000000}},	//   _sumc, _nuls, --, --,
   {{0x38a2016f,0x76900086,0x64a60b5e,0x00000000}},	//   _fóre_, _täys, _чама, --,
   {{0x2cbf007c,0x7645001e,0xf1d00066,0x44222a2b}},	//   dnud_, _ychy, _तुरन, _iek_,
   {{0x7d0185ae,0xf8bf033a,0x442201bf,0x6d4a85af}},	//   _buls, zné_, _hek_, ttfa,
   {{0x442285b0,0xa0a602ce,0x6e2109e1,0x3ce6006d}},	//   _kek_, _завд, _delb, _phov_,
   {{0x3ce61020,0x6d4a85b1,0x628e040b,0x44224374}},	//   _qhov_, rtfa, _hobo, _jek_,
   {{0xf8bf0d88,0x628e85b2,0x7af8006d,0x38690130}},	//   vné_, _kobo, _pivt, _raar_,
   {{0xc3338130,0x6e2185b3,0x442285b4,0x628e85b5}},	//   נות_, _gelb, _lek_, _jobo,
   {{0x386985b6,0xf8bf807f,0x3ce601a9,0x7afd024e}},	//   _paar_, tné_, _thov_, ístr,
   {{0x442285b7,0x26f90821,0xdd8f00bf,0x764585b8}},	//   _nek_, ंद्र_, _دوم_, _schy,
   {{0xf8bf85b9,0x7af8006d,0x386985ba,0x26d101d5}},	//   rné_, _tivt, _vaar_, tozo_,
   {{0x3869019c,0xf8bf0076,0x7c22004f,0x442201d7}},	//   _waar_, sné_, _heor, _aek_,
   {{0xf8bf024e,0x7c22046a,0xf1d0162b,0x45d5846a}},	//   pné_, _keor, _तुलन, товс,
   {{0x44220118,0x38690036,0x7cc80355,0x7ce50067}},	//   _cek_, _uaar_, běre, mórc,
   {{0x628e85bb,0x442285bc,0x5334081b,0x7c2f0a20}},	// [8fb0] _bobo, _dek_, летт, ócri,
   {{0x442285bd,0xd0192c29,0x628e85be,0x672d0009}},	//   _eek_, दर्भ_, _cobo, _ivaj,
   {{0x628e1055,0xd0110098,0x44220359,0xc2c4600c}},	//   _dobo, للا_, _fek_, ديلي,
   {{0x6e2102bf,0x7cc10029,0x442285bf,0x672d008c}},	//   _selb, vēro, _gek_, _kvaj,
   {{0x6e212a37,0x7d0178a6,0x628e0168,0xb4bf25d8}},	//   _pelb, _suls, _fobo, ेवी_,
   {{0x628e0027,0xed592cdd,0x7bd9001e,0x7d0185c0}},	//   _gobo, док_, _rywu, _puls,
   {{0x2cbf007c,0x6e2185c1,0xa15814a9,0xdca500c3}},	//   tnud_, _velb, _пару_, каки,
   {{0x248913a6,0x6e211472,0x628e2359,0x7d0101bf}},	//   njam_, _welb, _zobo, _vuls,
   {{0x7c22053f,0x2ef53e3d,0x2cbf00ab,0x628e0371}},	//   _deor, _азар, rnud_, _yobo,
   {{0x3da703f5,0xb87b00b8,0x2be20aad,0x2cbf00be}},	//   _преб, hlíd, _पररा, snud_,
   {{0x98a641fe,0x89f400d8,0xfd100312,0x7c220211}},	//   вине, ляюц, _هجن_, _feor,
   {{0x61fa3c0e,0x7c2285c2,0xf3ff0019,0x7ce5002a}},	//   _útle, _geor, _ngã_, sórb,
   {{0xeb8e001f,0x442285c3,0xc6260083,0xda650009}},	//   _ти_, _rek_, _বাবা_, _авли,
   {{0x672d85c4,0xa7fb0391,0x2b4d00ee,0x22960093}},	//   _dvaj, xeñe, mtec_, _tæki_,
   {{0xceb25c8e,0x628e85c5,0x442285c6,0xa6db0093}},	//   בים_, _robo, _pek_, fuðb,
   {{0x7c2201dd,0x00000000,0x00000000,0x00000000}},	//   _xeor, --, --, --,
   {{0xb87b27c2,0x442285c7,0x672d082d,0xe8d700a5}},	// [8fc0] rmít, _vek_, _gvaj, _בוקר_,
   {{0x442203bc,0x2b4d0345,0x00000000,0x00000000}},	//   _wek_, itec_, --, --,
   {{0x442285c8,0x35a60368,0xe4c608d9,0xa69b00a5}},	//   _tek_, _ранг, _айни, _חשיפ,
   {{0xa7fb0138,0xb87b85c9,0x2b4d0207,0x00000000}},	//   señe, lmír, ktec_, --,
   {{0x628e85ca,0xdfd20037,0x00000000,0x00000000}},	//   _tobo, جيش_, --, --,
   {{0x7c225a95,0x5f9303fa,0xa11600e0,0x6f0d0473}},	//   _seor, ришт, _لوست, íaca,
   {{0x7c22409a,0xed5703fa,0x3f80002d,0xe046002d}},	//   _peor, вој_, ţiu_, _инви,
   {{0x64440be0,0x61e30723,0x7ce50a4a,0xfcaa0088}},	//   ngii, ünle, vórc, باتو_,
   {{0x69ca00ab,0x3dd20035,0x8af80328,0x60c285cb}},	//   _सुजी, ływ_, ннис_, mnom,
   {{0xbbe20f17,0x60c264db,0x9e4700a0,0xb87b00d5}},	//   _परीक, lnom, raďá, jmír,
   {{0x672d010b,0x5d862604,0xe6be14ab,0xbc670647}},	//   _svaj, _جلال, ोवैज, رمین_,
   {{0x6d5a027d,0x60c202ce,0x00000000,0x00000000}},	//   _ipta, nnom, --, --,
   {{0x0eb6000c,0x3cfb0066,0x7ac60336,0x3f8601ef}},	//   _अगाड, _लूटे_, _иске, nxou_,
   {{0xddc10009,0x60c257fe,0x7ce5183d,0x3f860183}},	//   _halš, hnom, móra, ixou_,
   {{0xddda01c0,0xa5040210,0x60c20298,0x7ce5026e}},	//   _patř, иятл, knom, lóra,
   {{0x60c28445,0xddc10124,0x00000000,0x00000000}},	//   jnom, _jalš, --, --,
   {{0x248985cc,0x325515d5,0xb87b0453,0x672d008b}},	// [8fd0] rjam_, лвар, smís, _uvaj,
   {{0x6d5a85cd,0x22470332,0x02bf0ed1,0x27e400be}},	//   _opta, ünk_, ्वेन, ümne_,
   {{0xa2ba143a,0xc69232e3,0xddc885ce,0xe039002d}},	//   ्वज्, _האי_, _andž, езеч_,
   {{0x60c285cf,0xc95302b5,0x00000000,0x00000000}},	//   gnom, ימע_, --, --,
   {{0x442985d0,0xc43a0052,0x6d5a26e3,0x9f040594}},	//   maa_, _אתרי, _apta, لونو,
   {{0x442985d1,0xc1050bdf,0x38a285d2,0x7cf5010b}},	//   laa_, _موسي, _móra_, _išri,
   {{0xddc101f2,0xb87b0279,0xddc80009,0x290a2dea}},	//   _balš, ilíb, _endž, íbal_,
   {{0x442985d3,0x7ce5004f,0x27ed00b8,0x00000000}},	//   naa_, fóra, ženy_, --,
   {{0xddc10311,0x63bb0009,0x7b7501b2,0x6d5a008c}},	//   _dalš, _žunj, اطبا, _epta,
   {{0x442985d4,0xd90c006c,0xc3340d85,0x2fc00079}},	//   haa_, ڈیو_, בוץ_, úige_,
   {{0x442985d5,0x2b4d85d6,0x26c302c6,0xd90c006c}},	//   kaa_, stec_, dnjo_, ویو_,
   {{0xe73a85d7,0x442985d1,0x3da40f92,0x7ce5002a}},	//   нем_, jaa_, _труб, bóra,
   {{0x442985d8,0xb8cc0f0d,0x7c2985d9,0x7ce501ef}},	//   daa_, _गत_, maer, córa,
   {{0x25ef02cb,0xd9450fc5,0x7c297984,0x5fb60026}},	//   _आणखी_, _беки, laer, _आइसल,
   {{0x44290657,0x35a31334,0xceb202b8,0xe5a33db0}},	//   faa_, барг, זים_, бири,
   {{0x38a285da,0x442985db,0xb87b0bca,0xfde80246}},	//   _fóra_, gaa_, smír, टेटस_,
   {{0x38a2004e,0x78a4000e,0x644485dc,0xb87b00b8}},	// [8fe0] _góra_, _iliv, rgii, blíb,
   {{0x7c29001e,0x610c037a,0x78a400ee,0x00000000}},	//   haer, _ağla, _hliv, --,
   {{0x442985dd,0x7c2906a2,0x78a485de,0x60c285df}},	//   baa_, kaer, _kliv, tnom,
   {{0x4fa61edd,0x1b190083,0xd5ad006c,0xfbc71c2d}},	//   лиев, _দিনে_, _کہہ_, _هت_,
   {{0xbbe2000c,0x7c2985e0,0x14d700a5,0x78a485e1}},	//   _परेक, daer, _תוכל_, _mliv,
   {{0x3fcb03fc,0x78a40176,0x3f8601ef,0x00000000}},	//   ردنی_, _lliv, rxou_, --,
   {{0xf98785e2,0x00000000,0x00000000,0x00000000}},	//   _اب_, --, --, --,
   {{0x7c2985e3,0x35db0067,0x00000000,0x00000000}},	//   gaer, _मुफ़, --, --,
   {{0x40935f8a,0x00000000,0x00000000,0x00000000}},	//   _القر, --, --, --,
   {{0x78a485e4,0x44296492,0x629e85e5,0x00000000}},	//   _aliv, zaa_, nkpo, --,
   {{0x78a485e6,0x4429755b,0x7c29010d,0xa7fb0453}},	//   _bliv, yaa_, baer, deña,
   {{0x442901ef,0xe3bf1111,0xb4ce01c0,0x7ce52fba}},	//   xaa_, _leña_, शको_, póra,
   {{0x442913c1,0x26c3219c,0x998f00f4,0xfcd300f8}},	//   vaa_, tnjo_, ćaše_, _اينج,
   {{0x386d0d5c,0x44295c3d,0xb87b002a,0x2d9800b5}},	//   žer_, waa_, flíc, _üres_,
   {{0x442985e7,0x00000000,0x00000000,0x00000000}},	//   taa_, --, --, --,
   {{0x6aba0a8a,0x78a40a0b,0x89337cf8,0x6e2a016e}},	//   litf, _gliv, _اعوا, hafb,
   {{0x442985e8,0xbbe206bc,0x68ed0069,0xa7fb0138}},	// [8ff0] raa_, _परोक, _ihad, beña,
   {{0x27e903cb,0x7ce500fb,0x442985e9,0xb60301c0}},	//   _izan_, jórn, saa_, část,
   {{0x442985ea,0x27ec0067,0x78a400c3,0x610500c7}},	//   paa_, ędne_, _yliv, _kėli,
   {{0x44290069,0x04673425,0x6f0d09ca,0x68ed0069}},	//   qaa_, _стом, íaco, _jhad,
   {{0x68ed4279,0x68ff00a8,0x7ce585eb,0x7c2985ec}},	//   _mhad, _miqd, fórn, vaer,
   {{0x1eea0a86,0x63ad00fe,0x68ed0118,0x2287081b}},	//   نونی_, mzan, _lhad, _сумг,
   {{0x63ad0382,0x7c2985ed,0x200e0093,0x00000000}},	//   lzan, taer, ækið_, --,
   {{0x1b190033,0x68ed85ee,0x61fa008d,0x27e901fb}},	//   _দিবে_, _nhad, _útla, _ozan_,
   {{0x63ad4273,0x7c290273,0xbf1514ac,0x60db85ef}},	//   nzan, raer, _ضواب, _ikum,
   {{0x78a43cd6,0xdfd80133,0x60c91953,0x68ed0054}},	//   _sliv, _със_, _hjem, _ahad,
   {{0x68ed37af,0x78a44989,0x7e6300c3,0x27e985f0}},	//   _bhad, _pliv, menp, _azan_,
   {{0x68ed85f1,0x7e6385f2,0x7d0e0187,0xe45f01ff}},	//   _chad, lenp, žisé, _sjön_,
   {{0x6d4385f3,0x68ed00f8,0x63ad0a18,0x78a400b8}},	//   luna, _dhad, jzan, _vliv,
   {{0x63ad295e,0x8f9a0070,0x7e6385f4,0x2f0b0a8a}},	//   dzan, דישי, nenp, _møg_,
   {{0x6d4385f5,0x60db85f6,0x68ed066a,0xb8250083}},	//   nuna, _okum, _fhad, _ভারত_,
   {{0x60c91ce9,0xa7fb09ab,0x68ed85f7,0x78a485f8}},	//   _njem, seña, _ghad, _uliv,

   {{0x6d4385f9,0xb2260a9f,0xd467798c,0xe3bf0922}},	// [9000] huna, имал, шите_, _peña_,
   {{0x290785fa,0x6d4385fb,0x60c90009,0x7f8600b5}},	//   _kuna_, kuna, _ajem, یلان,
   {{0x290785fc,0x6d4385fd,0x5be21022,0x7e6385fe}},	//   _juna_, juna, _पर्व, denp,
   {{0x3ea585ff,0x29078600,0x26d88601,0x6d438602}},	//   _allt_, _muna_, loro_, duna,
   {{0x29078603,0x63ad004e,0xe3bf0391,0x60c98604}},	//   _luna_, czan, _teña_, _djem,
   {{0x60c90083,0x8d762588,0x7e638605,0x6d438606}},	//   _ejem, لاعا, genp, funa,
   {{0x6d430464,0x290705ee,0x6e2a5cd7,0x7d7800d1}},	//   guna, _nuna_, rafb, امبر_,
   {{0x26d80232,0x60c98607,0x00000000,0x00000000}},	//   horo_, _gjem, --, --,
   {{0x26d88608,0x2907029c,0x6b9b5fad,0x7ac62b65}},	//   koro_, _auna_, gyug, исое,
   {{0x29078609,0x6d43860a,0x781f0cf1,0x26d801d5}},	//   _buna_, buna, पर्क_, joro_,
   {{0x63ad860b,0x2907860c,0x68ed860d,0x2be2060a}},	//   zzan, _cuna_, _phad, _परका,
   {{0x6aba860e,0x7ae1860f,0x29078610,0x27e00107}},	//   sitf, allt, _duna_, _byin_,
   {{0x26d88611,0x610500d8,0x4c3b016b,0xf804010b}},	//   foro_, _vėli, _יגאצ, ючэн,
   {{0x26d8855f,0x2907018e,0x672409e7,0xdb9b00a5}},	//   goro_, _funa_, _dwij, _בסדר,
   {{0x290706b3,0x68ed8612,0x6e282c68,0x7d080107}},	//   _guna_, _thad, _medb, _juds,
   {{0x1b1900c8,0x63ad8613,0x7cc100ea,0x6e28093a}},	//   _দিতে_, tzan, tēri, _ledb,
   {{0x26d80010,0x6d438614,0x78bd3115,0xa7fb1725}},	// [9010] boro_, zuna, misv, meño,
   {{0x63ad1c90,0x60c90c21,0x29075a67,0x26d88615}},	//   rzan, _sjem, _yuna_, coro_,
   {{0x2f0b0022,0x63ad004e,0x67248616,0x41552d7a}},	//   _søg_, szan, _zwij, свес,
   {{0x2004012f,0x6d4301a8,0xa49b01f7,0x00000000}},	//   _cgmi_, vuna, _diòc, --,
   {{0x95e90332,0x3f676245,0x7e638617,0x7ae11aef}},	//   _جبکہ_, ртеб, tenp, yllt,
   {{0x6d438618,0x7d0800d4,0x2bca142a,0x8117026b}},	//   tuna, _buds, ापना, _نذرا,
   {{0x7e638619,0x2ca62bf2,0x60c90124,0x365c00a5}},	//   renp, _blod_, _tjem, דכונ,
   {{0x290700ea,0x60db51a6,0x3a2702d0,0x60c967b3}},	//   _runa_, _ukum, _senp_, _ujem,
   {{0x29076d62,0xdd910332,0x6d437471,0xa3d73123}},	//   _suna_, توں_, suna, िथि_,
   {{0x2907861a,0x6d43861b,0x2900007c,0xe3bf002a}},	//   _puna_, puna, _siia_, _leño_,
   {{0xf76901f3,0x26d80133,0x6295861c,0x6f09861d}},	//   _רק_, voro_, _mozo, _huec,
   {{0x29070009,0x6f0963fe,0x78bd008d,0x2ca600e5}},	//   _vuna_, _kuec, gisv, _glod_,
   {{0x26d8861e,0x6f0900de,0x290000ab,0x00000000}},	//   toro_, _juec, _viia_, --,
   {{0x6f090138,0x62956658,0xfb1a00a5,0xd63a010b}},	//   _muec, _nozo, _עוצמ, ыямі_,
   {{0x29074734,0x6f0165cc,0x26d8861f,0xe5a30ddc}},	//   _uuna_, _milc, roro_, пири,
   {{0x26d88620,0xb4e200b4,0x67240120,0xb87b0300}},	//   soro_, धते_, _twij, plía,
   {{0x62958621,0x26d80010,0x6f090453,0x96ba0e9f}},	// [9020] _bozo, poro_, _nuec, _буну_,
   {{0x62950139,0x6f01021d,0xb87b451f,0x00000000}},	//   _cozo, _nilc, nlín, --,
   {{0xed45026b,0x62950d14,0x2482022e,0xb87b0079}},	//   _تھ_, _dozo, _tnkm_, ilín,
   {{0x7ce51111,0xef86010b,0x6f090110,0x6f01053f}},	//   fórm, йлеп, _buec, _ailc,
   {{0x442025b0,0x3ebc04ca,0x7d080254,0x387211a8}},	//   mbi_, tivt_, _suds, _mayr_,
   {{0x6f098622,0x62958623,0x9757011d,0x61fa00ee}},	//   _duec, _gozo, מינו_, _útlo,
   {{0x2ca602f6,0x4420018d,0x00000000,0x00000000}},	//   _plod_, obi_, --, --,
   {{0x5c980036,0x44208624,0x5b14271c,0x39450443}},	//   ркия_, nbi_, омит, duls_,
   {{0x44208625,0x6e2801fb,0x78bd05f5,0x00000000}},	//   ibi_, _tedb, visv, --,
   {{0x0a6a0812,0xd91a1a6d,0xc6010083,0x44208626}},	//   урии_, льм_, ্রতা_, hbi_,
   {{0x78bd8627,0x1958010b,0x4420010d,0x6f0902d7}},	//   tisv, шаны_, kbi_, _zuec,
   {{0x442019cd,0x2ca6011e,0x290c013b,0xab2a10b4}},	//   jbi_, _ulod_, rqda_, _бода_,
   {{0x442002dd,0x78bd0527,0x274b0086,0xa7fb276b}},	//   dbi_, risv, ычно_, reño,
   {{0x442d308b,0xa7fb0b4c,0x44202889,0x7bdc037a}},	//   _že_, seño, ebi_, ğrud,
   {{0x3abb01f3,0x629501ba,0x394501f7,0x2ba607b5}},	//   _תמונ, _rozo, culs_, गनवा,
   {{0x44208628,0x941942ee,0xd4988629,0x629500ee}},	//   gbi_, ржат_, бру_, _sozo,
   {{0x62951c7b,0x611501c2,0x7d02862a,0xe3bf002a}},	// [9030] _pozo, _işlə, _mios, _veño_,
   {{0x7d02006e,0xf8bf1f96,0x4420862b,0x6f093e66}},	//   _lios, lié_, abi_, _ruec,
   {{0xe3bf0391,0x6f09862c,0x4420862d,0x00000000}},	//   _teño_, _suec, bbi_, --,
   {{0x6f0100ee,0xb87b0098,0xf8bf00a2,0x7d020096}},	//   _silc, ilío, nié_, _nios,
   {{0x7c2000e5,0x6f09862e,0x6295082d,0xde050c7e}},	//   dbmr, _quec, _tozo, опли,
   {{0x442b862f,0x88cf0083,0xfd110037,0x3f8202a7}},	//   _hec_, রতিক, وجب_, _škuc_,
   {{0x442b01d1,0xfe7011c0,0x6f018630,0x313539bf}},	//   _kec_, عده_, _vilc, _фебр,
   {{0x7ce50035,0x802703c5,0x6f018631,0x442b0088}},	//   mórk, _درآم, _wilc, _jec_,
   {{0x7d028632,0x442b8633,0xf8bf0248,0x00000000}},	//   _dios, _mec_, dié_, --,
   {{0x442b8634,0x4420264f,0x00000000,0x00000000}},	//   _lec_, zbi_, --, --,
   {{0x7d02004a,0x4439024e,0x645d8635,0xf8bf0248}},	//   _fios, _ods_, _obsi, fié_,
   {{0x442b8636,0xc6890bed,0x2d530279,0x7d028637}},	//   _nec_, _בא_, mãe_, _gios,
   {{0x2cad054e,0xb87b8638,0xe1e609b4,0x00000000}},	//   mhed_, plín, _कर्ण_, --,
   {{0xa9a502c4,0x05db0084,0x644f409c,0x645d8639}},	//   _милд, _मुहब, _acci, _absi,
   {{0x66e31783,0x7c2b00d7,0x44394605,0x66031a5a}},	//   фора, _kegr, _bds_, дпра,
   {{0x442b863a,0x4420863b,0x03260133,0xf8bf00f7}},	//   _cec_, ubi_, ждан, cié_,
   {{0x7c2b006c,0x442b00a5,0x2bf602b5,0x00000000}},	// [9040] _megr, _dec_, ַמען_, --,
   {{0x4420863c,0x7c2b863d,0x645d0024,0x644f0382}},	//   sbi_, _legr, _ebsi, _ecci,
   {{0x7c390035,0xa3e63efe,0x600a2e14,0x00000000}},	//   _odwr, _फरक_, анем_, --,
   {{0xddc8156f,0x442b2f80,0xf0ba00fd,0x6ee40310}},	//   _nadš, _gec_, جائش_, mòbi,
   {{0xf8b30052,0x7d020037,0xbe8a1c36,0xa3bd25d8}},	//   ושא_, _rios, иске_, ेपण_,
   {{0x7d02863e,0xbea30202,0x442b73bc,0x7c2b0553}},	//   _sios, мачк, _zec_, _aegr,
   {{0x7c2b5ff5,0x7d02004e,0x10a61422,0x443908b9}},	//   _begr, _pios, _дивн, _yds_,
   {{0x61ee571c,0xc60700b4,0x442b01f7,0x2cad863f}},	//   _izbl, _शल्य_, _xec_, ghed_,
   {{0x7cc10080,0x7c2b5de2,0x320d04d4,0xfbcf00b5}},	//   vērt, _degr, _şeyi_, ہتی_,
   {{0x23620a4e,0x7d022538,0xb87b0098,0x7c39099e}},	//   _mpkj_, _wios, tlío, _edwr,
   {{0x291800da,0xf8bf0248,0x7d020183,0xfbcf00f8}},	//   ëra_, tié_, _tios, فتی_,
   {{0xbb86017e,0x7c2b8640,0xb87b004f,0x2cad35dc}},	//   _ولاي, _gegr, rlío, ched_,
   {{0x29183bc2,0x81d60083,0xf8bf00f7,0x07a400d8}},	//   ūra_, াইট_, rié_, даўн,
   {{0x442b8641,0x6ee40392,0x44398642,0xaa580841}},	//   _sec_, fòbi, _sds_, _طلبا_,
   {{0x442b8643,0x25db2088,0xa49b0211,0xf8bf2464}},	//   _pec_, _खुशी_, _diòn, pié_,
   {{0x291e8644,0xb87b01ef,0x00000000,0x00000000}},	//   mpta_, olím, --, --,
   {{0x442b8645,0x00000000,0x00000000,0x00000000}},	// [9050] _vec_, --, --, --,
   {{0x04eb0033,0x7cd300af,0xa49b00cc,0x7d1a0282}},	//   কদের_, măre, _giòn, _otts,
   {{0x644f023c,0x00000000,0x00000000,0x00000000}},	//   _tcci, --, --, --,
   {{0x644f02fb,0x443900de,0x442b3595,0x26c401ba}},	//   _ucci, _uds_, _uec_, émov_,
   {{0x8e858646,0xddc80334,0x7c2b1adb,0xb4d71cc3}},	//   згле, _radš, _regr, ाकी_,
   {{0x7ce54ef1,0x313512b3,0x644d8647,0x1b190083}},	//   móri, _негр, lgai, _দিলে_,
   {{0x2cad8648,0x62878649,0x00000000,0x00000000}},	//   thed_, _injo, --, --,
   {{0x7cc10029,0x2f100211,0x27180355,0x6aaa00e5}},	//   vērs, _fàg_, něný_, _alff,
   {{0x2cad054e,0x5f7700d1,0x7ce50132,0x7f42000d}},	//   rhed_, _بازر, nóri, croq,
   {{0x2cad0052,0x7c2b864a,0xb4d700b8,0x00000000}},	//   shed_, _wegr, ाकु_, --,
   {{0xa9695b60,0x25db0f06,0x60cb3222,0x2cad0147}},	//   щина_, _खुली_, ongm, phed_,
   {{0x7ce529f4,0x290400be,0x6aaa099e,0x66150067}},	//   kóri, öma_, _elff, eczk,
   {{0xb8e40302,0x291e002d,0x7ce5008d,0x62872884}},	//   _एग_, apta_, jóri, _onjo,
   {{0x6d438557,0xb81c0af9,0xf1bd022e,0x7ce5021d}},	//   orna, _भ्रम_, ्पान, dóri,
   {{0xa5d60324,0xb4d728bc,0x09e2010b,0x00000000}},	//   _मुखौ, ाकू_, _пошн, --,
   {{0x6287864b,0x2499008c,0xa93a00a5,0x00000000}},	//   _anjo, _cosm_, _התקפ, --,
   {{0x7ce56727,0x63061ee1,0x7cd300af,0x38600027}},	// [9060] góri, سوال, căre, _ibir_,
   {{0x644d009c,0xe29700af,0x969603fa,0x6d4302c4}},	//   agai, пау_, _хриш, krna,
   {{0xd24f00d1,0x3860003c,0x644d012f,0x869b0070}},	//   انم_, _kbir_, bgai, _הייז,
   {{0x6287864c,0x7f422dd3,0x6d430c8c,0x2f100310}},	//   _enjo, troq, drna, _pàg_,
   {{0x4432864d,0x6d437287,0x59dd052f,0xecd10033}},	//   may_, erna, _नुसर, াতাড,
   {{0x7f423612,0x4432454a,0x3320864e,0x6eed0132}},	//   rroq, lay_, mpix_, túba,
   {{0x490b000c,0x4c940340,0xacf81482,0x98bf00af}},	//   _ठूलो_, дийс, онку_, nută_,
   {{0x44326c3b,0x7f42864f,0xb87b00d5,0x00000000}},	//   nay_, proq, tlím, --,
   {{0x6d4304e6,0x33205e4b,0x66150067,0x00000000}},	//   arna, npix_, yczk, --,
   {{0x44328650,0x60c28651,0x3860007b,0x6d4300cd}},	//   hay_, liom, _abir_, brna,
   {{0x05db3652,0x44327ee5,0x765c00e9,0x28f900d4}},	//   _मुंब, kay_, dfry, жень_,
   {{0x44328652,0x60c28653,0x48ab4684,0x6d4a018c}},	//   jay_, niom, стом_, mufa,
   {{0x44320052,0x6d4a0103,0x765c00e9,0xa49b009e}},	//   day_, lufa, ffry, _diòl,
   {{0xe7e10266,0x6d4a08c7,0x9987007e,0x2be10099}},	//   _गुणा_, oufa, _genů_, _पडता,
   {{0x44322c60,0x6d4a8654,0xda5b011d,0x60c28655}},	//   fay_, nufa, _הכול, kiom,
   {{0x44328656,0x7ce500c9,0xb4d70953,0x2ea92203}},	//   gay_, tóri, ाके_, _कत्त,
   {{0x2858004f,0x38580911,0x78ad8657,0x883c00a5}},	// [9070] _رؤية_, _رشيد_, _ilav, _התחו,
   {{0x78ad114d,0x290e8658,0x644d8659,0x3860042a}},	//   _hlav, _kufa_, sgai, _zbir_,
   {{0x4432865a,0x7ce50279,0x98bf002d,0x26c308b7}},	//   bay_, sóri, cută_, mijo_,
   {{0x26c3865b,0x443208ee,0x290e865c,0x75360317}},	//   lijo_, cay_, _mufa_, _קארד_,
   {{0x78ad0478,0xb4e90b54,0x5ec50033,0x6d43016e}},	//   _mlav, यती_, _লীগে, wrna,
   {{0x78ad865d,0x26c302c6,0x6d5872ad,0x6287003c}},	//   _llav, nijo_, ftva, _unjo,
   {{0x78ad865e,0x6d4a865f,0x00000000,0x00000000}},	//   _olav, gufa, --, --,
   {{0x60c20211,0xdb0000a2,0x2d6e00fe,0x00000000}},	//   ciom, lymè, _dře_, --,
   {{0x81df0083,0x1ee70a86,0x765c00e9,0x26c38660}},	//   দেশ_, _فوری_, yfry, kijo_,
   {{0x443273e7,0x290e01f7,0x26c38661,0xa9a58662}},	//   zay_, _bufa_, jijo_, диод,
   {{0x81df12eb,0x44328663,0xa3e406bb,0x78ad8664}},	//   দের_, yay_, _पुन_, _blav,
   {{0x44321505,0xb4d70fa9,0x78ad8665,0x644a00b5}},	//   xay_, ाको_, _clav, őfiz,
   {{0x4432142f,0x610c0723,0x26c38666,0xbbeb00ff}},	//   vay_, _işle, fijo_, _ارام_,
   {{0x44328667,0x60c2004e,0x78ad8668,0x26c32463}},	//   way_, ziom, _elav, gijo_,
   {{0x44328669,0x78ad866a,0x998500d1,0x88c60037}},	//   tay_, _flav, _آلبو, _يتعل,
   {{0x78ad0496,0x61fa0093,0x1ad50033,0x00000000}},	//   _glav, _útli, _হওয়া, --,
   {{0xa8570122,0x765c0282,0x4432866b,0x26c3329e}},	// [9080] _חיפה_, pfry, ray_, bijo_,
   {{0x4432866c,0x26c3108a,0x21a6663c,0x00000000}},	//   say_, cijo_, мизм, --,
   {{0x4432866d,0x60c202d6,0x290e0176,0x00000000}},	//   pay_, tiom, _xufa_, --,
   {{0x44320510,0x3b07866e,0x3320866f,0x6aaa05f7}},	//   qay_, _linq_, ppix_, _छत्र,
   {{0x60c28670,0x3eac0159,0x60c302d0,0xdd8f0088}},	//   riom, _pldt_, ènma, یوه_,
   {{0x6d588671,0x60c213fe,0xd252234a,0xa3bd02e4}},	//   ttva, siom, _جنس_, ेपर_,
   {{0x63a48672,0x60c28673,0x00000000,0x00000000}},	//   lyin, piom, --, --,
   {{0x63a4073a,0x26c3008b,0x6d588674,0x290e002f}},	//   oyin, zijo_, rtva, _rufa_,
   {{0x629c8675,0x63a4024c,0x6d581c12,0xb87b2c8b}},	//   _koro, nyin, stva, slík,
   {{0x629c1ec8,0x3b070248,0x1eaa414b,0x68e46d42}},	//   _joro, _cinq_, _باري_, _akid,
   {{0x78ad08c2,0x629c0054,0x6da610ee,0x26c302c6}},	//   _plav, _moro, _تمام, vijo_,
   {{0x629c1034,0xa9c300d4,0x68f600e9,0x7ae30103}},	//   _loro, тськ, _chyd, _eknt,
   {{0x26c3008b,0x6f08139b,0x2fc00079,0xe81e0354}},	//   tijo_, _kidc, úigh_, पड़ा_,
   {{0xb4d7009a,0x629c8676,0x68e474a9,0x290e8677}},	//   ाक्_, _noro, _ekid, _tufa_,
   {{0x26c38678,0x6f08524e,0x291c02c4,0x257800af}},	//   rijo_, _midc, _utva_, мбрь_,
   {{0xb4e9052f,0x6b828679,0x26c3008b,0x63a400a5}},	//   यते_, _krog, sijo_, fyin,
   {{0x629c867a,0x7ce5004f,0x26c3008b,0x6f080341}},	// [9090] _boro, mórt, pijo_, _oidc,
   {{0x27e900a7,0x290901ef,0xddc300af,0x68fd867b}},	//   _iyan_, _hiaa_, nenţ, lmsd,
   {{0x629c1140,0x26c1867c,0x610c04d4,0x00000000}},	//   _doro, _imho_, _oğlu, --,
   {{0x38a2867d,0x6b82867e,0x92bf0083,0x629c009e}},	//   _fóru_, _orog, ঁকে_, _eoro,
   {{0x629c0922,0x63b6006a,0x6b82006d,0x93b4010b}},	//   _foro, czyn, _nrog, _абяц,
   {{0xd3560052,0x629c867f,0x672d65d0,0x00000000}},	//   _אישי_, _goro, _mwaj, --,
   {{0xddc30043,0x20120037,0xfce51457,0x6114010b}},	//   denţ, íniú_, ноко, _адсу,
   {{0xeb990b32,0xf1b202b5,0x394c0159,0xe45f0282}},	//   зии_, _עסן_, duds_, _gjöt_,
   {{0x68f6001e,0x27e90dc3,0x6b828680,0x1eea13cf}},	//   _rhyd, _nyan_, _crog, _کولی_,
   {{0x68e48681,0xddc3002d,0xa92505a1,0x629c1896}},	//   _skid, genţ, ндол, _xoro,
   {{0x27e98682,0x6b820382,0xa6db0093,0x672d2206}},	//   _ayan_, _erog, nuðu, _awaj,
   {{0xb4e90387,0x6b8206a2,0x2d9812c3,0xb4ae018d}},	//   यतो_, _frog, _àrea_, _कते_,
   {{0x1b1900c8,0x6b828683,0x7ba70037,0x29090024}},	//   _দিকে_, _grog, _تصام, _diaa_,
   {{0x27e900a7,0xddc300af,0x9f5600b5,0x394c008c}},	//   _dyan_, cenţ, égét_, buds_,
   {{0x629c2c67,0x27e90159,0x200d0065,0xa2d306fe}},	//   _roro, _eyan_, _ogei_, णचन्,
   {{0x629c8684,0x68e48685,0x63a40421,0x248b12ff}},	//   _soro, _ukid, tyin, _cncm_,
   {{0x629c552b,0xd8d702b5,0x672d0103,0x7ae1027a}},	// [90a0] _poro, _רופט_, _gwaj, oolt,
   {{0x63b6004e,0x629c8686,0x996e00a8,0x63a48687}},	//   rzyn, _qoro, nəş_, ryin,
   {{0x065702b5,0x64a65caf,0x63b60035,0x106a0fa7}},	//   _אייך_, _зана, szyn, зией_,
   {{0x6f08012f,0xddc3002d,0x629c47ed,0x63a48688}},	//   _sidc, zenţ, _woro, pyin,
   {{0x629c76f5,0x6eed1423,0x1fa706cd,0x00000000}},	//   _toro, públ, нкци_, --,
   {{0xfe6f0079,0x7cd3002d,0x1fdf0033,0x7f838689}},	//   مدى_, văra, _বৃহস, الون,
   {{0x6b824ca0,0x00000000,0x00000000,0x00000000}},	//   _srog, --, --, --,
   {{0x91e3868a,0x7ce5008d,0xbebd013a,0x00000000}},	//   _сосе, dórs, _atūd, --,
   {{0xddc3002d,0xbbca0099,0x7ac6129e,0x7ae1868b}},	//   tenţ, ापेक, есне, folt,
   {{0x394c0443,0x27e9024b,0x672d007b,0x00000000}},	//   tuds_, _ryan_, _rwaj, --,
   {{0x02b70070,0x0c261958,0xddc3002d,0xd2b700a5}},	//   גליך_, _змен, renţ, גלית_,
   {{0x01370052,0xeb9a01b8,0x6b823a64,0x7cd3002d}},	//   ערכת_, _ние_, _trog, păra,
   {{0xfaa65bb5,0x7ae12cd2,0xc5f9021a,0x28c02e8c}},	//   _падо, bolt, ंध्य_, शोधि,
   {{0x7ae1868c,0x38a2004f,0xddc3082d,0x394c0009}},	//   colt, _sórt_, lenš, puds_,
   {{0x7ce5556d,0x45d47275,0x7e7a4f97,0x1db0111b}},	//   pórt, горс, _matp, जनित,
   {{0x27e908dd,0x672d868d,0x00000000,0x00000000}},	//   _tyan_, _twaj, --, --,
   {{0x672d5ba0,0xcb130070,0x3255693e,0x4e10073f}},	// [90b0] _uwaj, ָלע_, квар, ाशाई_,
   {{0x7e7a0254,0x644800ea,0xa6db008d,0x1db004e9}},	//   _natp, _ēdie, tuðu, जनात,
   {{0x3ce60207,0xa7fb0065,0x00000000,0x00000000}},	//   _okov_, reñu, --, --,
   {{0xc5f21759,0x2ea90569,0x90e701cb,0x7ae100b5}},	//   _כדי_, कस्त, رسان, zolt,
   {{0x4429868e,0xef1801e0,0x64360070,0xc5e30033}},	//   mba_, емі_, _בארא_, _মণিপ,
   {{0x4429868f,0x7bdc00d0,0x7e7a00cc,0x3f840118}},	//   lba_, ğrul, _catp, _drmu_,
   {{0x442901a6,0x69170029,0x00000000,0x00000000}},	//   oba_, _aģen, --, --,
   {{0x44298690,0xfebb00bf,0x4c852fb3,0x00000000}},	//   nba_, _کارت_, тлив, --,
   {{0x44298691,0xe803000c,0x3f840124,0x7ae18692}},	//   iba_, रेमा_, _grmu_, tolt,
   {{0x44290024,0xafcf099e,0x89a90112,0x9f040cd1}},	//   hba_, _ceոe, дков_, _موقو,
   {{0x44292092,0xddc38693,0x7ae100b5,0x00000000}},	//   kba_, benš, rolt, --,
   {{0x44290484,0x7ae10e35,0xe73a6726,0x00000000}},	//   jba_, solt, мем_, --,
   {{0x44293e39,0x98bf00d8,0xa03a0070,0x7ae18694}},	//   dba_, nutę_, וערפ, polt,
   {{0xaa454ed5,0x44298695,0xbb420798,0x5ba800d8}},	//   _рекл, eba_, _тешк, _якім_,
   {{0x65c328cf,0x387b00d7,0x7d0b011e,0x4429013b}},	//   абра, _faqr_, _kigs, fba_,
   {{0x7d0b324e,0xf74a004f,0x26d10176,0xbd02008d}},	//   _jigs, _قلبي_, anzo_, _þétt,
   {{0x130a00d8,0x7c298696,0x00000000,0x00000000}},	// [90c0] днай_, iber, --, --,
   {{0xb2238697,0x44298698,0x7c2901d6,0x96fa0037}},	//   имул, aba_, hber, _تعبر_,
   {{0x44298699,0xf8c6051e,0x98c60632,0x644b25ec}},	//   bba_, _लगाय, _लगाए, ógic,
   {{0x64a6231c,0x442957f4,0x7c2902c4,0x7e7a00f8}},	//   _рама, cba_, jber, _satp,
   {{0xdfcf0082,0x7c2978de,0x7e7a23e4,0xddc3869a}},	//   ييم_, dber, _patp, venš,
   {{0x7c29869b,0x3ce601b4,0xb87b00b5,0x6d5c00be}},	//   eber, _skov_, llít, _ärak,
   {{0x628e869c,0x127b02b5,0x7c291bc9,0x3cde1404}},	//   _inbo, _קאלע, fber, खवले_,
   {{0x7c29869d,0x3ced7b8d,0x29180279,0xb87b00b5}},	//   gber, glev_, íram_, nlít,
   {{0x7d0b0345,0xe29f0093,0xaf0600c7,0x00000000}},	//   _digs, _guðs_, _апал, --,
   {{0x44296632,0xc3330122,0xa021008d,0x00000000}},	//   zba_, סות_, _þörf, --,
   {{0x7c298282,0x442943e8,0x2d850124,0x80bf0067}},	//   bber, yba_, _grle_, लोवे,
   {{0xa8a73de2,0x00000000,0x00000000,0x00000000}},	//   трок, --, --, --,
   {{0x58d4392c,0x44290237,0x628e869e,0xb87b01ef}},	//   роят, vba_, _onbo, boín,
   {{0xddda010b,0xa6db008e,0x4429869f,0x00000000}},	//   _natū, orði, wba_, --,
   {{0x442976f5,0x555886a0,0x26cd0254,0x00000000}},	//   tba_, каря_, đeo_, --,
   {{0x628e86a1,0x442986a2,0xa7750012,0x00000000}},	//   _anbo, uba_, _блич, --,
   {{0x6d4a01ae,0x93f586a3,0x00000000,0x00000000}},	// [90d0] hrfa, упац, --, --,
   {{0x44293c56,0xf1a72070,0x00000000,0x00000000}},	//   sba_, крен, --, --,
   {{0xd01106ca,0x7c2986a4,0x25a5013c,0x9f4400ee}},	//   ملا_, yber, älld_, _dymí_,
   {{0xf1c300d8,0x673b003a,0x628e01a3,0xb87b0138}},	//   _rašė_, šuju, _enbo, clít,
   {{0x7d0b0249,0xb4c10518,0xb87b86a5,0x673d86a6}},	//   _rigs, ्ची_, llís, nssj,
   {{0x7d0b1d8d,0x2d850c99,0x00000000,0x00000000}},	//   _sigs, _prle_, --, --,
   {{0x7d0b86a7,0xe8032f41,0x7c2921b8,0x3ced0c2c}},	//   _pigs, रेता_, tber, tlev_,
   {{0x7c2986a8,0x7eb401f7,0xb87b0079,0x0cd10033}},	//   uber, _ràpe, ilís, াত্ত,
   {{0x81e80083,0x3ced01cf,0x7d0b86a9,0xa3d601c0}},	//   মেদ_, rlev_, _vigs, िपय_,
   {{0x7c296d24,0x3cff006d,0x3ced08c8,0x80bf00b4}},	//   sber, smuv_, slev_, लोरे,
   {{0x7d0b0008,0xb87b0138,0x7c2986aa,0x2d850160}},	//   _tigs, roín, pber, _urle_,
   {{0xc3240033,0x00000000,0x00000000,0x00000000}},	//   _পিসি_, --, --, --,
   {{0x2a7c0176,0x4c9a025a,0xeb8e0036,0xf772063d}},	//   _favb_, _רבנו, _уи_, حاج_,
   {{0x998500b5,0x1bb818dd,0x2cad3080,0x7eb40176}},	//   _ملتو, _جامع_, lked_, _tàpe,
   {{0xb4c104bc,0x628e0176,0xd46a03e6,0x2cad0f00}},	//   ्चू_, _rnbo, ниве_, oked_,
   {{0x2cad86ab,0xb4ae021a,0x261800ab,0x00000000}},	//   nked_, कसे_, बुजी_, --,
   {{0x2f1902e9,0x2b5f00e2,0x577a0037,0xe61a0279}},	// [90e0] _nèg_, ntuc_, _أصبح_, _пдп_,
   {{0xb87b6148,0xa6db0093,0x00000000,0x00000000}},	//   slít, yrði, --, --,
   {{0xe5a616e2,0x221500af,0x35a60009,0x67243731}},	//   _сини, рфур, _санг, _htij,
   {{0x25a515d0,0x26ca043d,0xbf0f0067,0x00000000}},	//   älle_, libo_, ादून_, --,
   {{0xe3b21aa6,0xde5801c8,0x248086ac,0xbea60862}},	//   _طرح_, валі_, mdim_, ладк,
   {{0xf1240a86,0x248000d0,0x2360006d,0xdee32374}},	//   _نظری, ldim_, mtij_, бочи,
   {{0xccf801c0,0x217586ad,0x00000000,0x00000000}},	//   _opět_, _кутр, --, --,
   {{0x26ca19e9,0x248086ae,0x6d4a86af,0x00000000}},	//   hibo_, ndim_, rrfa, --,
   {{0x26ca86b0,0x24800037,0x1bd4002d,0x61ee00e9}},	//   kibo_, idim_, ропя, _hybl,
   {{0x5a340834,0xee3700d8,0x9e650919,0x61ee00fe}},	//   шнот, _бнф_, _نامن, _kybl,
   {{0xddc8011c,0xd91700c3,0x2480048f,0x672486b1}},	//   _hadž, лья_, kdim_, _atij,
   {{0x2cad0122,0x61ee86b2,0x1c0d13a0,0x37d90033}},	//   cked_, _mybl, _हलचल_, _সরবর,
   {{0x0a943e3d,0x2480009f,0xa3e40af6,0xddc80009}},	//   _валю, ddim_, _पुल_, _jadž,
   {{0x4b7b02b5,0xddc80693,0x26ca0159,0x290286b3}},	//   _נאוו, _madž, gibo_, amka_,
   {{0x0467081b,0x61ee86b4,0x00000000,0x00000000}},	//   лтам, _nybl, --, --,
   {{0xb4c1006a,0x38c90332,0x680c02d4,0x00000000}},	//   ्चे_, _جاتی_, _bēdī, --,
   {{0x36d503ad,0xddc80c99,0x92590370,0x26ca0273}},	// [90f0] _вопр, _nadž, каат_, bibo_,
   {{0xccf801c0,0x26ca2deb,0x61ee0298,0x386913ef}},	//   _zpět_, cibo_, _bybl, _hbar_,
   {{0x3869003c,0xa49b0176,0x65950183,0xddda0409}},	//   _kbar_, _biòt, _тану, _antž,
   {{0xddc80009,0x61ee00e5,0x00000000,0x00000000}},	//   _badž, _dybl, --, --,
   {{0x443b01c2,0x3869108c,0x057705f5,0x00000000}},	//   maq_, _mbar_, _شاھد, --,
   {{0x443b86b5,0x6aae0026,0x171c02b5,0x9f047407}},	//   laq_, टसोर, עווע, مونو,
   {{0xf2d200a5,0xd65800a5,0x40353cef,0x386900f1}},	//   _ועם_, איות_, _вебс, _obar_,
   {{0x0b452632,0x443b0095,0x00000000,0x00000000}},	//   анин, naq_, --, --,
   {{0x2cad86b6,0xddc87946,0x60cb1f95,0xb87b0098}},	//   rked_, _gadž, migm, roíl,
   {{0x4e780642,0x2cad86b7,0x88bd00b8,0x60cb5394}},	//   _محمد_, sked_, spěl, ligm,
   {{0x672486b8,0xbd4b00ad,0x1da9012f,0x443b01f4}},	//   _stij, _سؤال_, _कथित, kaq_,
   {{0xa3b5162b,0x254101c8,0x7645022e,0x31560070}},	//   जना_, dėl_, _adhy, סירן_,
   {{0x26ca6e93,0x7c3b0118,0xb8de0066,0x443b00a8}},	//   tibo_, maur, _इत_, daq_,
   {{0x7c3b86b9,0x644b003e,0x23600221,0x60cb010d}},	//   laur, ógin, vtij_, higm,
   {{0xceb202da,0x3cfd0189,0x26ca86ba,0x845a2360}},	//   חים_, _khwv_, ribo_, крат_,
   {{0x14264054,0xb4e02874,0x443b0c6f,0x26ca86bb}},	//   рдам, दके_, gaq_, sibo_,
   {{0x248086bc,0x0323392c,0xd49700e2,0x63830d46}},	// [9100] rdim_, ждун, ờng_, огта,
   {{0x6d410690,0x7c3b000e,0x23600120,0x6aa386bd}},	//   _ovla, haur, rtij_, _jonf,
   {{0x7c3b4733,0x6aa386be,0x236086bf,0xddc80009}},	//   kaur, _monf, stij_, _sadž,
   {{0x443b0669,0x24800095,0xddc804d9,0x92c60033}},	//   caq_, qdim_, _padž, উকে_,
   {{0x6fd6004f,0x7ccd0029,0x5f067a4e,0x44221cb5}},	//   جزائ, _mērķ, азда, _ifk_,
   {{0x44207425,0xa49b0211,0x00000000,0x00000000}},	//   lci_, _phòg, --, --,
   {{0x614386c0,0x4096095d,0x00000000,0x00000000}},	//   _мера, _крат, --, --,
   {{0x3cfd01e8,0x8fa61578,0x78a40294,0x7c3b009e}},	//   _chwv_, _кабе, _noiv, gaur,
   {{0x442501c2,0x3d16004e,0x4f0a0132,0xa3d6045c}},	//   _əl_, _पूरे_, _анан_, िपि_,
   {{0xfaa62419,0xf1eb0084,0x443b00a8,0xa3ae0f06}},	//   ршин, _जुड़_, zaq_, _कथन_,
   {{0x81e800c8,0x442006d9,0x0217011d,0x644600a0}},	//   মের_, kci_, יחים_, _odki,
   {{0x26ef052f,0x7c3b86c1,0xb4e000b8,0x00000000}},	//   छत्र_, caur, दको_, --,
   {{0x4420024e,0x78a40248,0x7c220069,0xfbd2042c}},	//   dci_, _doiv, _ifor, _بتا_,
   {{0x4420006a,0x6aa386c2,0x64461c7f,0x78b60027}},	//   eci_, _gonf, _adki, _elyv,
   {{0x443b00a8,0xd6d80012,0x4a3101ba,0x78b60b41}},	//   taq_, ртя_, äčší_, _flyv,
   {{0x3835002d,0x6eed0079,0x7c22009f,0x00000000}},	//   _унир, lúbt, _jfor, --,
   {{0x68ed3e4d,0x443b86c3,0x8afd000c,0x7cfe01f4}},	// [9110] _ikad, raq_, stře, përf,
   {{0x443b86c4,0xa49b0211,0x00000000,0x00000000}},	//   saq_, _shòd, --, --,
   {{0x443b0be2,0x442086c5,0xa2d804bc,0x7c22011c}},	//   paq_, bci_, _मदर्, _ofor,
   {{0x442086c6,0x7c2286c7,0x443b6476,0x00000000}},	//   cci_, _nfor, qaq_, --,
   {{0x443986c8,0x6d41003a,0x60cb067f,0xb4fa00a5}},	//   _ies_, _svla, rigm, _תפרי,
   {{0x443986c9,0x7cd3002d,0x63ad86ca,0x9e3c01ba}},	//   _hes_, mări, myan, _poďa,
   {{0x443938ed,0x63ad36fd,0x3cfd006d,0x2eb706fe}},	//   _kes_, lyan, _phwv_, _अतीत,
   {{0xec791f9b,0x44396ad8,0x2b4d86cb,0x3cfd0221}},	//   упи_, _jes_, trec_, _qhwv_,
   {{0x7c3b86cc,0x60db0054,0xdcb10019,0x60c986cd}},	//   raur, _ijum, _của_, _imem,
   {{0x443986ce,0x7c3b86cf,0x7c2286d0,0x2b4d12c3}},	//   _les_, saur, _efor, rrec_,
   {{0x7c2202c7,0x44390297,0x3cfd006d,0x68ed0159}},	//   _ffor, _oes_, _thwv_, _bkad,
   {{0x443986d1,0x63ad6217,0x3ea5345d,0xfdf600a5}},	//   _nes_, kyan, _holt_, _הצעת_,
   {{0x44200690,0xe803065a,0xef19006a,0x63ad0232}},	//   vci_, रेला_, _już_, jyan,
   {{0x63ad86d2,0x6aba86d3,0x68ed0282,0x7cd300af}},	//   dyan, chtf, _ekad, dări,
   {{0x3ea5162d,0x442086d4,0x78a40086,0x63ad030d}},	//   _molt_, tci_, _toiv, eyan,
   {{0x443986d5,0x25a5022a,0x2d8700ab,0x60db6e3d}},	//   _ces_, älla_, ivne_, _njum,
   {{0x443986d6,0x442086d7,0x63ad86d8,0x64a3613e}},	// [9120] _des_, rci_, gyan, чата,
   {{0x442086d9,0x443986da,0x29123c37,0x60c924ed}},	//   sci_, _ees_, _hiya_, _amem,
   {{0xc6930052,0x443986db,0x2900006d,0x6a3a0070}},	//   _זאת_, _fes_, _khia_, רגעפ,
   {{0x92d800c8,0x7c390024,0x443986dc,0x63ad86dd}},	//   াতে_, _newr, _ges_, byan,
   {{0x63ad86de,0xf987006c,0x7cd3002d,0x80ca0083}},	//   cyan, _کب_, cări, িকল্,
   {{0x7c2286df,0x291200bf,0xdee31a1c,0x443986e0}},	//   _sfor, _liya_, почи, _zes_,
   {{0x11da004f,0x443986e1,0x6da30166,0x609800b5}},	//   _صورة_, _yes_, зија, _پچاس_,
   {{0x291232e1,0x0cb800c8,0x4439006f,0x3ce0011c}},	//   _niya_, ুক্ত, _xes_, čivo_,
   {{0xdfcf0082,0x9985010b,0xe4fb07df,0xbb470037}},	//   _كيف_, kalų_, ्षति_, ملين_,
   {{0x68ed0c7d,0x9e6600bf,0xac980d4f,0x00000000}},	//   _skad, _دارن, انکا_, --,
   {{0x291286e2,0x7cd3002d,0x63ad86e3,0x25ed0066}},	//   _biya_, zări, zyan, _आँधी_,
   {{0x29000028,0x63ad1505,0x7c220c61,0x7c392193}},	//   _chia_, yyan, _ufor, _gewr,
   {{0x29004c51,0x7d1a06a2,0x657e65de,0x29120159}},	//   _dhia_, _huts, _asph, _diya_,
   {{0x443986e4,0x7d1a81ef,0x9985010b,0x63ad1435}},	//   _ses_, _kuts, galų_, vyan,
   {{0x44394859,0x7cfe01f4,0xa49b0176,0x2ca600ab}},	//   _pes_, përd, _biòp, _kood_,
   {{0x63ad86e5,0x29121b82,0x443901e8,0x7d1a86e6}},	//   tyan, _giya_, _qes_, _muts,
   {{0x443986e7,0x7d1a86e8,0x7eb401f7,0x2ca686e9}},	// [9130] _ves_, _luts, _nàpo, _mood_,
   {{0x63ad86ea,0x2d8c86eb,0x443986ec,0x7d1a86ed}},	//   ryan, _orde_, _wes_, _outs,
   {{0x443986ee,0x63ad70aa,0x97d80a86,0x7d1a86ef}},	//   _tes_, syan, _نظیر_, _nuts,
   {{0x2ca678f9,0x63ad179a,0x7cd300af,0xa49b0211}},	//   _nood_, pyan, pări, _dhòc,
   {{0x2d8c25e4,0x3ea57cc0,0x7c3910a7,0x00000000}},	//   _arde_, _polt_, _rewr, --,
   {{0x7d1a86f0,0x867c0070,0x2d8c0160,0x81e80033}},	//   _buts, ָרהו, _brde_, মেই_,
   {{0x3ea500f5,0x62950010,0x2ca60223,0x2d8c0160}},	//   _volt_, _inzo, _bood_, _crde_,
   {{0x60db86f1,0x60c9000e,0x2fdf01e8,0x2d870169}},	//   _ujum, _umem, _txug_, rvne_,
   {{0x2ca612b0,0x2900006d,0x7d1a01d7,0x2d8c033b}},	//   _dood_, _rhia_, _euts, _erde_,
   {{0x628586f2,0x291232e1,0x290086f3,0x394527fa}},	//   ndho, _siya_, _shia_, оног,
   {{0xa9690cc7,0x7d1a86f4,0x2ca60122,0x290086f5}},	//   шина_, _guts, _food_, _phia_,
   {{0x29000d4b,0x2ca60052,0x3f8d01f4,0x9b950079}},	//   _qhia_, _good_, _kreu_, _ولات,
   {{0x2bd0007c,0x62950223,0x61300260,0x00000000}},	//   _तइया, _onzo, _kòlò, --,
   {{0x6b89008d,0x6f1b02d7,0x00000000,0x00000000}},	//   mveg, _muuc, --, --,
   {{0x290086f6,0x6285184b,0x291286f7,0x6b8986f8}},	//   _thia_, ddho, _tiya_, lveg,
   {{0x628586f9,0x62950453,0x78bd033b,0x6130021e}},	//   edho, _anzo, chsv, _lòlò,
   {{0x42ca11d0,0x6b8986fa,0xe6c90124,0x7ce5002a}},	// [9140] аган_, nveg, šašć, fórz,
   {{0x7cd3002d,0x6d4386fb,0xa49b0211,0x7ce50067}},	//   măru, ksna, _phòc, górz,
   {{0x64a60202,0x69c1033b,0x248202c4,0x2bd00096}},	//   _дана, nzle, _takm_, _तेना,
   {{0xa06a7538,0x7d1a86fc,0x629586fd,0x3f8d0443}},	//   рада_, _ruts, _enzo, _breu_,
   {{0x3f8d86fe,0x2ca60120,0x628501cb,0xdb0e0187}},	//   _creu_, _rood_, bdho, ždém,
   {{0x443286ff,0xfe6f0079,0x7f420be2,0xde9303fa}},	//   lby_, ندى_, rsoq, дашњ,
   {{0x7f420176,0x0163002d,0x6d4386a9,0x2ca600ab}},	//   ssoq, _окро, gsna, _pood_,
   {{0xa3ae009a,0x5c9801d3,0x6e3a1192,0xed4f00b5}},	//   _कथा_, ския_, _wetb, کھے_,
   {{0xae7a03ad,0x3f8d8700,0x320d013b,0x6d430284}},	//   _всех_, _greu_, _şeyx_, asna,
   {{0x7d1a6dcf,0x2ca600a5,0x3860021d,0x6d438701}},	//   _tuts, _wood_, _acir_, bsna,
   {{0x44320035,0x3860009e,0xc957010b,0x2d8c01ed}},	//   kby_, _bcir_, оўя_, _urde_,
   {{0x6d588702,0x38600160,0x00000000,0x00000000}},	//   muva, _ccir_, --, --,
   {{0x44328703,0x6d580f67,0x7cfe01f4,0x6bd62ac4}},	//   dby_, luva, përb, _بتار,
   {{0x3ce9201d,0x443f00ee,0x2bd007b5,0x00000000}},	//   čave_, _žu_, _तेया, --,
   {{0xa3d002b4,0x6d588704,0x610c0225,0x00000000}},	//   _वेब_, nuva, _eşli, --,
   {{0x44328705,0xd49853e3,0x19bb0122,0xb4b50035}},	//   gby_, ору_, _כמוב, झसे_,
   {{0x6d58005b,0x7cd300af,0x291c03c1,0x7d028706}},	// [9150] huva, căru, _huva_, _mhos,
   {{0x6d5841b7,0x291c8707,0x6d43472c,0x62857cf3}},	//   kuva, _kuva_, ysna, udho,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8d12c3,0x26d18708,0x6d5800ab,0x291c030d}},	//   _preu_, lizo_, duva, _muva_,
   {{0x291c0183,0x9ac40024,0x00000000,0x00000000}},	//   _luva_, _keċċ, --, --,
   {{0x6d433238,0x7d028709,0x3d1600b4,0x9ac4009f}},	//   tsna, _ahos, _पंखे_, _jeċċ,
   {{0x7d0211d9,0x6d58870a,0x00000000,0x00000000}},	//   _bhos, guva, --, --,
   {{0x6d43870b,0x3f8d870c,0x7d023ebe,0x6b89870d}},	//   rsna, _treu_, _chos, tveg,
   {{0x6d43870e,0x38a2006a,0x26d1870f,0x3af500d8}},	//   ssna, _góry_, kizo_, зянс,
   {{0x6b898710,0x44320bca,0x7cd3002d,0x69c102b1}},	//   rveg, zby_, văru, tzle,
   {{0x443275bc,0x7d020094,0x6d588711,0x6b898712}},	//   yby_, _fhos, cuva, sveg,
   {{0x7d028713,0xf1b20070,0x291c00f4,0x2d58002d}},	//   _ghos, גסט_, _duva_, _фиць_,
   {{0x7d098714,0x69c10332,0x44320076,0x00000000}},	//   mmes, szle, vby_, --,
   {{0x7d098715,0x44320159,0x26d1002f,0x7cfe0031}},	//   lmes, wby_, gizo_, përc,
   {{0x4432024e,0x2a3a0d85,0x66032d4a,0x765c8716}},	//   tby_, _העצמ, епра, rgry,
   {{0x03260086,0x7d098717,0x7d028718,0x44320355}},	//   здан, nmes, _xhos, uby_,
   {{0x44328719,0x26d101d0,0x421a0037,0xccf2011d}},	// [9160] rby_, bizo_, مزاج_, תכן_,
   {{0x4432039b,0xb87b0d9a,0x26d1871a,0x7d09871b}},	//   sby_, gníf, cizo_, hmes,
   {{0x7d09871c,0x7cfe0055,0x6d5801ef,0x00000000}},	//   kmes, hëra, xuva, --,
   {{0xd12f46c4,0x6d580328,0x38a200d5,0x7d095f90}},	//   امن_, vuva, _póry_, jmes,
   {{0x7d09871d,0x7d0200e9,0x7cfe0031,0x00000000}},	//   dmes, _rhos, jëra, --,
   {{0x6d58871e,0x33fb0122,0xdfcf017e,0x3f7d00a0}},	//   tuva, _להכנ, ديه_, _dňu_,
   {{0x7d020719,0xda78016f,0x2056871f,0xa49b0211}},	//   _phos, veď_, _нтар, _mhòn,
   {{0x6d588720,0x26d1018e,0xa06718cd,0x672f0067}},	//   ruva, zizo_, _наса_, ypcj,
   {{0x291c8721,0x6d588722,0x7ebd0107,0x00000000}},	//   _suva_, suva, _sèpe, --,
   {{0xc33301f3,0x1ea9063d,0x7d0200a5,0x6d582933}},	//   עות_, _والي_, _whos, puva,
   {{0x7d028723,0x2eee01a2,0xf8bf0320,0x7d092bd0}},	//   _thos, moff_, thé_, bmes,
   {{0x38bb0031,0xf8bf00b8,0x3157016b,0x00000000}},	//   _bëra_, uhé_, היטן_, --,
   {{0x26d10657,0xb8e5018d,0x00000000,0x00000000}},	//   tizo_, _एत_, --, --,
   {{0xba170082,0x2eee39c6,0x6b820371,0x291c8724}},	//   _فيها_, noff_, _isog, _tuva_,
   {{0x26d101d5,0x65941ac5,0x960800d8,0x7cd300af}},	//   rizo_, нару, зэта_, părt,
   {{0x6aaa8725,0x26d11d50,0x00000000,0x00000000}},	//   _hoff, sizo_, --, --,
   {{0x6aaa8726,0xa3d00f8a,0xb87b8727,0xd3710037}},	// [9170] _koff, _वेद_, eníg, ضها_,
   {{0x6aaa8728,0x672d8729,0x6d48011c,0x6b82023c}},	//   _joff, _itaj, _ovda, _msog,
   {{0x6aaa872a,0x38bb0055,0x00000000,0x00000000}},	//   _moff, _zëra_, --, --,
   {{0xd0110088,0x92bf0083,0x98a6002d,0x7f7515df}},	//   نلا_, ুকে_, mplă_, дукц,
   {{0x248900a7,0xfaf800ea,0x8e850166,0x6b820b13}},	//   mdam_, klī_, дгле, _nsog,
   {{0x2eee872b,0x2489872c,0x7d0901cb,0x672d43d9}},	//   goff_, ldam_, wmes, _mtaj,
   {{0x2369872d,0x7d09872e,0xa3b50fbf,0x6b821857}},	//   ltaj_, tmes, जनक_, _asog,
   {{0x645f0024,0x672d872f,0x6d488730,0x62873480}},	//   ngqi, _otaj, _dvda, _hajo,
   {{0x23698731,0x7d098732,0x62878733,0x6aaa0d61}},	//   ntaj_, rmes, _kajo, _boff,
   {{0xeab1004f,0x7d098734,0x6aaa5057,0xe9d91a5a}},	//   ئعة_, smes, _coff, жко_,
   {{0x672d262b,0x6aaa0223,0x23690124,0x1eea00fd}},	//   _ataj, _doff, htaj_, _بولی_,
   {{0x8d7409b9,0x2b5204d4,0x62878735,0xf7460171}},	//   _ساما, üncü_, _lajo, мемо,
   {{0xa49b00e8,0x00000000,0x00000000,0x00000000}},	//   _phòn, --, --, --,
   {{0x62870912,0x248900ec,0x6aaa8736,0x39470051}},	//   _najo, edam_, _goff, _tvns_,
   {{0x672d8737,0x00000000,0x00000000,0x00000000}},	//   _etaj, --, --, --,
   {{0x38bb0031,0x00000000,0x00000000,0x00000000}},	//   _tëra_, --, --, --,
   {{0x62878738,0x2486016f,0xd5b80029,0x212d0009}},	// [9180] _bajo, ľom_, šā_, _čeha_,
   {{0x62870453,0x24862ba3,0x6aaa009f,0x63ab191b}},	//   _cajo, žom_, _xoff, ägna,
   {{0x62870055,0x8066195c,0x00000000,0x00000000}},	//   _dajo, двеж, --, --,
   {{0x62870103,0x00000000,0x00000000,0x00000000}},	//   _eajo, --, --, --,
   {{0xe3b20206,0x2eee8739,0x4375002d,0x78bd0031}},	//   _شرح_, toff_, _пурт, ërvi,
   {{0x5f936d73,0x67000632,0x3d160067,0x9987005f}},	//   тишт, ोगिक_, _पूजे_, _jenų_,
   {{0x6aaa1f2c,0x615400fd,0x7f4900f6,0x6b82073a}},	//   _roff, _سچائ, _eveq, _ssog,
   {{0x6aaa6c6e,0x2eee028b,0x98bf0029,0x644449d2}},	//   _soff, soff_, kstā_, naii,
   {{0x60c22998,0x7eb40176,0x6aaa0051,0xda7a188d}},	//   mhom, _làpi, _poff, оян_,
   {{0x60c2873a,0x3ce90a78,0x63ab01b4,0x2489873b}},	//   lhom, čava_, øgni, zdam_,
   {{0x6c830332,0x325700a5,0x28f90402,0xdd8f0987}},	//   رلیم, וסים_, зень_, _پون_,
   {{0x2369004e,0x6b82046a,0x60c200a2,0x7cfe0031}},	//   ytaj_, _tsog, nhom, mëro,
   {{0x6aaa873c,0x672d0024,0x24890381,0x00000000}},	//   _toff, _qtaj, vdam_, --,
   {{0xabfb024b,0x60c20553,0x00000000,0x00000000}},	//   _והדר, hhom, --, --,
   {{0x6287873d,0x60c20069,0x7eb401f7,0xa49b01da}},	//   _rajo, khom, _càpi, _fhòl,
   {{0x62877efe,0xb87b873e,0xb4e90253,0x3f8400f4}},	//   _sajo, roís, मके_, _osmu_,
   {{0x2489873f,0x672d4052,0x60c2007a,0x3d1608a9}},	// [9190] rdam_, _utaj, dhom, _पूछे_,
   {{0x24890dd6,0x23698740,0x78ad8541,0x64440345}},	//   sdam_, rtaj_, _hoav, aaii,
   {{0x236900da,0x62878741,0x7cfe0055,0x00000000}},	//   staj_, _vajo, jëro, --,
   {{0x60c28742,0xe3b000b5,0x23690506,0xc4350088}},	//   ghom, درہ_, ptaj_, _سکرت,
   {{0x62871675,0x7eb40176,0xbf640312,0x00000000}},	//   _tajo, _zàpi, ندوو, --,
   {{0x44298743,0x60c20069,0x69c500be,0x00000000}},	//   lca_, ahom, _üheg, --,
   {{0x3f840029,0x44290fc5,0x00000000,0x00000000}},	//   _esmu_, oca_, --, --,
   {{0x60c28744,0x442b055c,0x00000000,0x00000000}},	//   chom, _jfc_, --, --,
   {{0x50642e90,0x7cfe01f4,0x4fc40009,0xfe7503e6}},	//   _штра, përn, _исфа, _плаќ,
   {{0xde970071,0x3eac0b41,0x44291a64,0xa49b0211}},	//   _تجرب, _godt_, hca_, _shòl,
   {{0x644f07b3,0x98bf00d8,0x78ad5856,0x44296784}},	//   _odci, nutė_, _boav, kca_,
   {{0x442936a5,0x7eb412c3,0xb4e93874,0x18a67ef0}},	//   jca_, _ràpi, मको_, хамм,
   {{0x44294474,0xeb990ea6,0x249e0023,0xa49b00f1}},	//   dca_, _хил_, _đtm_, _chòm,
   {{0x44298745,0x09e58746,0x7c295487,0xa49b00f1}},	//   eca_, _полн, lcer, _dhòm,
   {{0x60c2009e,0x442902a7,0x64440103,0x99850037}},	//   yhom, fca_, taii, _ألبو,
   {{0x442b8747,0x78ad0107,0x4619010b,0x00000000}},	//   _cfc_, _goav, ьцяў_, --,
   {{0x425602ba,0xa3fe0033,0xa3d00066,0x00000000}},	// [91a0] етет, ংখ্য_, _वेश_, --,
   {{0xae0f06bc,0x44298748,0x60c20024,0x2d853b1a}},	//   ाधान_, aca_, whom, _osle_,
   {{0x272601a5,0x442901ba,0x60c28749,0x7c2900d7}},	//   _hôn_, bca_, thom, kcer,
   {{0x4429874a,0x70f60082,0x53a61412,0xb87b00b8}},	//   cca_, رسائ, _замб, mníc,
   {{0xb87b01c0,0x7416042c,0x7ebd0359,0x00000000}},	//   lníc, _سوسا, _sèpa, --,
   {{0x27265760,0x7cfe00da,0x60c21944,0x7c2b874b}},	//   _môn_, tëro, shom, _afgr,
   {{0x91e60b46,0x629c874c,0x2726016e,0xb87b0355}},	//   _чове, _inro, _lôn_, nníc,
   {{0x7c290443,0xcb1b00b4,0xd01200fd,0x00000000}},	//   gcer, नदंड_, _ملز_, --,
   {{0xdcfa0043,0x3eac022e,0x63a4874d,0x27260023}},	//   _astă, _todt_, nxin, _nôn_,
   {{0x4429874e,0x7c2933c4,0x78ad1751,0x63a404cb}},	//   zca_, acer, _soav, ixin,
   {{0x7cfe01f4,0xb87b0187,0x4429874f,0xad650037}},	//   qëro, jníc, yca_, _لانه,
   {{0xb87b0076,0x7c298750,0x6016037a,0x6d4a8751}},	//   dníc, ccer, _gümü, msfa,
   {{0xe80c009a,0x442905e2,0x629c01e4,0x27260019}},	//   सेला_, vca_, _onro, _côn_,
   {{0x4429004e,0x68e405c9,0x3ce000f4,0x272600e5}},	//   wca_, _ejid, čivu_, _dôn_,
   {{0x6f1a8752,0x44298753,0x6d4a0d51,0x798100e9}},	//   _mitc, tca_, nsfa, cwlw,
   {{0x44298754,0x6d580345,0x629c8755,0xa49b0211}},	//   uca_, irva, _anro, _thòm,
   {{0x44298756,0x98bf0043,0x395e62b3,0x6d5801a0}},	// [91b0] rca_, astă_, luts_, hrva,
   {{0xa3d002cb,0xb87b05d3,0x6d5802f6,0xa195021f}},	//   _वेळ_, bníc, krva, казч,
   {{0x395e12c3,0x44298757,0xa2b206bc,0x442b8758}},	//   nuts_, pca_, _आकर्, _tfc_,
   {{0x5fd2007c,0x6d4a2172,0x442900a8,0x9f3501e0}},	//   _देहल, dsfa, qca_, веді,
   {{0x27260023,0x8ca40067,0x6f1a8759,0x6d580223}},	//   _xôn_, कानो, _bitc, erva,
   {{0x6d4a56e9,0x29090118,0x6f0800e2,0x6f1a005f}},	//   fsfa, _lhaa_, _chdc, _citc,
   {{0xada502fb,0x6d4a2433,0x7c290228,0x00000000}},	//   тайл, gsfa, tcer, --,
   {{0xeb990e0a,0x3ce90620,0x5fd20ed1,0x76470371}},	//   дии_, čavo_, _देवल, hajy,
   {{0xb87b024e,0x26c103e6,0x764701d5,0xa49b01f7}},	//   zníc, _olho_, kajy, _diòx,
   {{0x2909849a,0x68f6875a,0x237900d7,0x7c290a1f}},	//   _ahaa_, _skyd, _mpsj_, scer,
   {{0x395e0443,0x272600e9,0xbbeb00b5,0x2d8523a9}},	//   guts_, _sôn_, _کرام_, _usle_,
   {{0x2d980aca,0xb87b05d3,0x2243875b,0x26c12788}},	//   _área_, vníc, _lejk_, _alho_,
   {{0x6a852a67,0xb90a0066,0xa3d00035,0x291b009f}},	//   _алла, _मद_, _वें_, _diqa_,
   {{0x395e34fc,0xb87b0076,0x290901a3,0x8afd0355}},	//   buts_, tníc, _ehaa_, ktři,
   {{0xe643875c,0x26c101ba,0x68e40118,0x7bc902b1}},	//   респ, _dlho_, _tjid, lzeu,
   {{0xb87b024e,0x272601a5,0x63a45ee4,0x98bf00af}},	//   rníc, _tôn_, txin, rstă_,
   {{0x46ea2830,0x1423081b,0xb87b0187,0x7bc9875d}},	// [91c0] _один_, рдум, sníc, nzeu,
   {{0x63a401dd,0x00000000,0x00000000,0x00000000}},	//   rxin, --, --, --,
   {{0x26d801a8,0xe45f02b1,0x6724875e,0x00000000}},	//   miro_, _blöd_, _huij, --,
   {{0x26d80273,0x6d4a875f,0xd12f0413,0x67248760}},	//   liro_, vsfa, زمه_, _kuij,
   {{0x22430282,0x6f1a024b,0xc0a9017e,0x656e0098}},	//   _fejk_, _pitc, عامل_, ltbh,
   {{0x26d80232,0x6d4a4df9,0x6d580187,0x24808761}},	//   niro_, tsfa, trva, leim_,
   {{0x71a30183,0x2caf01ef,0x61460c06,0x67243c9a}},	//   _карз, _bogd_, _шева, _luij,
   {{0x26d80010,0x7cfe00da,0x76470010,0x6d4a057f}},	//   hiro_, përm, zajy, rsfa,
   {{0xc4d30122,0x2004003a,0x6d4a8762,0x6f1a3574}},	//   יגה_, _uzmi_, ssfa, _titc,
   {{0xbe8505bc,0x395e8763,0x24808764,0x26d814cc}},	//   _مجمو, tuts_, heim_, jiro_,
   {{0xfaa300c7,0x02b70070,0x26d88765,0x24808766}},	//   ршын, דליך_, diro_, keim_,
   {{0x395e8767,0x26d80f84,0x61fc2505,0x67240051}},	//   ruts_, eiro_, _myrl, _buij,
   {{0x26c101e8,0x26d82127,0x67240223,0x764704fb}},	//   _plho_, firo_, _cuij, tajy,
   {{0xbc1b0122,0x26d869a7,0x67240223,0x99d30580}},	//   _חודש, giro_, _duij, اتیا,
   {{0x04672c4c,0xa5f88768,0x764704fb,0x29090118}},	//   ктам, веру_, rajy, _thaa_,
   {{0xba1700a5,0x27e93305,0x290f00f1,0x54540185}},	//   _בחוץ_, _txan_, _òga_, ивст,
   {{0xb7d90754,0xc2990572,0x26d88769,0x672402d7}},	// [91d0] _سودا_, нках_, biro_, _guij,
   {{0x26d80232,0x78bd6039,0xa49b01a6,0x61fc83e9}},	//   ciro_, lksv, _mhòi, _byrl,
   {{0x67240051,0x61fc0090,0x9e3c0791,0x00000000}},	//   _zuij, _cyrl, _loďs, --,
   {{0x61fc221b,0x00000000,0x00000000,0x00000000}},	//   _dyrl, --, --, --,
   {{0xb9ff02e4,0x78bd876a,0x8afd00b8,0x00000000}},	//   _उर्फ_, iksv, stři, --,
   {{0x623404bf,0x7e63006d,0x61fc2413,0x776d0069}},	//   _веру, ugnp, _fyrl, _mqax,
   {{0x51845e89,0xa49b009e,0x00000000,0x00000000}},	//   _кута, _phòh, --, --,
   {{0xa49b00f1,0x26d81642,0x7bc97358,0x76450345}},	//   _bhòi, ziro_, tzeu, _lehy,
   {{0x26d8876b,0xa49b01a6,0x7eb401f7,0xec7600d8}},	//   yiro_, _chòi, _càps, упы_,
   {{0x7bc901ae,0x89a91d30,0xa49b00f1,0x764500ac}},	//   rzeu, еков_, _dhòi, _nehy,
   {{0xdd910754,0x26d80409,0x186a1052,0x00000000}},	//   _دوا_, viro_, нани_, --,
   {{0x26d8876c,0x25f70066,0xa49b01da,0x00000000}},	//   wiro_, _एड़ी_, _fhòi, --,
   {{0xb8dc07df,0x26d8876d,0x1cb800bf,0x67240ddb}},	//   _आक_, tiro_, _جالب_, _quij,
   {{0x7c3b876e,0x00000000,0x00000000,0x00000000}},	//   lbur, --, --, --,
   {{0x649a52e8,0x26d80a74,0xd942002d,0x38690211}},	//   нтар_, riro_, _лещи, _fcar_,
   {{0x7786876f,0xa7d60071,0x26d85e6a,0x7c3b8770}},	//   _близ, _متخص, siro_, nbur,
   {{0x26d88771,0xe29a0370,0x03a31c46,0x7c3b8772}},	// [91e0] piro_, наа_, бито, ibur,
   {{0x21a62682,0x764501bf,0x24808773,0x7cfe0055}},	//   лизм, _gehy, seim_, tërk,
   {{0x25a5315b,0x3aba02b5,0x200201f2,0x021900d8}},	//   ällt_, עמענ, _ški_, віць_,
   {{0x64a685d7,0x7c3b8774,0x4fea0183,0x00000000}},	//   _сама, jbur, нмен_, --,
   {{0x6d410176,0x00000000,0x00000000,0x00000000}},	//   _awla, --, --, --,
   {{0x644660ef,0x7cfe0031,0x6e9415d5,0x7c3b0051}},	//   _heki, mëri, рику, ebur,
   {{0x64468775,0x628e0159,0x72c303fa,0x2bd90066}},	//   _keki, _iabo, _убрз, _बेबा,
   {{0x7c3b8776,0x628e8777,0x40952ad7,0xa49b0211}},	//   gbur, _habo, _крут, _phòi,
   {{0x628e8778,0x28a8045c,0x7cfe01f4,0xdce102d4}},	//   _kabo, गानि, nëri, _aplē,
   {{0x49746239,0x628e8779,0x7c3b0065,0x00000000}},	//   алос, _jabo, abur, --,
   {{0x6d410297,0x628e877a,0xe9f90023,0x7c3b05ee}},	//   _gwla, _mabo, _đả_, bbur,
   {{0x7cfe00da,0x628e3ec3,0x7c3b0644,0x44220298}},	//   këri, _labo, cbur, _ngk_,
   {{0x7c22877b,0x78bd5bd9,0x7cfe0031,0x00000000}},	//   _igor, rksv, jëri, --,
   {{0x442d0755,0x628e3326,0x78bd0009,0x4422008c}},	//   _że_, _nabo, sksv, _agk_,
   {{0x644625cb,0x05bb042c,0x4422877c,0x00000000}},	//   _beki, ردست_, _bgk_, --,
   {{0x628e067f,0x7c220024,0x69c5018d,0x00000000}},	//   _aabo, _jgor, _ühea, --,
   {{0x628e877d,0xd25b01c8,0x6446877e,0x7d0000be}},	// [91f0] _babo, еце_, _deki, ilms,
   {{0x628e2127,0xf8bf01c0,0x7c3b877f,0x25a501ff}},	//   _cabo, lké_, zbur, älls_,
   {{0xb87b004f,0x7c220121,0x7c3b8780,0x644600ee}},	//   nnío, _ogor, ybur, _feki,
   {{0x7c228781,0x38bb01f4,0x6446053e,0x25c700a8}},	//   _ngor, _bëri_, _geki, ıqlı_,
   {{0x8fa529b5,0xb87b0037,0x628e0065,0xa85800a5}},	//   рале, hnío, _fabo, רידה_,
   {{0x7c228782,0x628e8783,0x8d552626,0x7c3b04f4}},	//   _agor, _gabo, атич, wbur,
   {{0x56b802b5,0x6446001c,0x00000000,0x00000000}},	//   רפון_, _yeki, --, --,
   {{0x628e8784,0x50b90026,0x64460176,0xa3e9193c}},	//   _zabo, _आविष, _xeki, _बशा_,
   {{0x628e3c4c,0xf8bf0187,0x4b250200,0x00000000}},	//   _yabo, dké_, јмов, --,
   {{0x7c3b8785,0x3b090274,0x7c228786,0x628e0065}},	//   sbur, ђено_, _egor, _xabo,
   {{0xceb8006a,0x7c3b03bc,0x38bb01f4,0xa9690274}},	//   _więc_, pbur, _zëri_, њима_,
   {{0x7c22023a,0x00000000,0x00000000,0x00000000}},	//   _ggor, --, --, --,
   {{0x64468787,0xfaa58788,0x903a0070,0xfb850919}},	//   _reki, _вало, כערה, _خدای,
   {{0x64468789,0x98ab0080,0x7c2267bf,0xe7370374}},	//   _seki, ībā_, _zgor, рер_,
   {{0xb8cc0083,0x2bd902e4,0x44220a12,0xb87b0079}},	//   _গত_, _बेता, _pgk_, cnío,
   {{0xf8bf54d9,0xc9520122,0x7cfe01f4,0xddd802c4}},	//   cké_, _ומה_, tëri, nevš,
   {{0x628e878a,0xc246702b,0x6446878b,0x8676002d}},	// [9200] _pabo, инак, _veki, _кынц,
   {{0x6446001c,0x29020c6f,0x00000000,0x00000000}},	//   _weki, llka_, --, --,
   {{0x6446878c,0x35a60368,0x7cfe0031,0xe5a6021d}},	//   _teki, _танг, sëri, _тини,
   {{0x7cfe01d2,0x628e035a,0x2cad003c,0xddd80124}},	//   përi, _wabo, jjed_, jevš,
   {{0x09e2012f,0x7cfe00da,0xddd801c0,0xa067539c}},	//   _पश्य, qëri, devš, рача_,
   {{0xf8bf00b8,0x7c22507c,0x00000000,0x00000000}},	//   zké_, _sgor, --, --,
   {{0x91e3878d,0x00000000,0x00000000,0x00000000}},	//   _доре, --, --, --,
   {{0x320a878e,0x00000000,0x00000000,0x00000000}},	//   _izby_, --, --, --,
   {{0x04180083,0xef1a07c1,0x2bd900b4,0xcb670079}},	//   ধুরী_, _ама_, _बेदा, لميه_,
   {{0x657e02ce,0x63ab0301,0x2902847c,0x70b60387}},	//   _opph, ägni, elka_, _अकुल,
   {{0xd90f4e4a,0x6d600501,0xa92700ac,0x5d860037}},	//   ویت_, ývač, _reží, _خلال,
   {{0x26ef0380,0x2d8c009e,0x7c221197,0x00000000}},	//   चक्र_, _isde_, _ugor, --,
   {{0xdb0202bf,0x69c5007c,0x27ed01d6,0x81bc0033}},	//   _groß, _ühen, çen_, ইছি_,
   {{0xf8bf031b,0x290207df,0x4b7b0070,0x8bd700a5}},	//   ské_, alka_, _סאוו, _דודו_,
   {{0xd5b8449f,0x245900af,0xb87b0355,0x2902151a}},	//   аст_, лавь_, lním, blka_,
   {{0x2d8c0107,0x32c400a8,0x00000000,0x00000000}},	//   _msde_, _röya_, --, --,
   {{0x539900c3,0x81b40831,0x04f40208,0x00000000}},	// [9210] ывая_, _জেল_, ізую, --,
   {{0xd7fc0122,0x3ce900f4,0xddd800cd,0x2d870067}},	//   _בהחל, čavi_, zevš, ywne_,
   {{0x21270023,0xa49b0284,0xdcfa0035,0x00000000}},	//   ênh_, _bhòt, _wstę, --,
   {{0x395e0069,0xa49b01da,0x859a00a5,0xe0d00037}},	//   irts_, _chòt, _עשרו, وزن_,
   {{0x644d1c55,0x61ee02ec,0xa28300d1,0x2cad0124}},	//   maai, _exbl, _ویرو, vjed_,
   {{0x644d053e,0x141a0d85,0xb87b00b8,0xa3d000b4}},	//   laai, _תושב, dním, _वेट_,
   {{0x29027f89,0xd65800a5,0x6285633a,0x2cbf0207}},	//   ylka_, ביות_, meho, tkud_,
   {{0x644d0223,0xddc800ee,0x7cfe0055,0x00000000}},	//   naai, _medň, zërv, --,
   {{0x395e0479,0x7b060093,0x1c42021f,0x7ebd0118}},	//   erts_, rðun, чным, _lèpi,
   {{0x2cad025c,0x628502ce,0x61330069,0x2cbf878f}},	//   sjed_, neho, _eħle, skud_,
   {{0xddd802c4,0x66c200a0,0x644d525a,0x00000000}},	//   pevš, _dôkl, kaai, --,
   {{0xe73a087b,0x3ff90070,0x7c847ba4,0x62850c6f}},	//   лем_, ָפֿע, _муче, heho,
   {{0xeaae8790,0x8ca4004e,0x628501e0,0x395e2069}},	//   _ей_, कारो, keho, arts_,
   {{0x6285025c,0x6b898791,0x00000000,0x00000000}},	//   jeho, mweg, --, --,
   {{0x80b800c8,0x6285054e,0xceb20122,0x6aa38792}},	//   _আগস্, deho, הים_, _innf,
   {{0x70b60953,0x644d8793,0x6b890067,0x00000000}},	//   _अकेल, gaai, oweg, --,
   {{0x6b89648e,0x03a32bc4,0x78a402e9,0xa5070c87}},	// [9220] nweg, пито, _iniv, сета_,
   {{0x62858794,0x78b60453,0xa49b021e,0xd1690160}},	//   geho, _hoyv, _akòd, _înțe,
   {{0x78a40b87,0x657e8795,0xccf90035,0x26da0069}},	//   _kniv, _upph, koś_, _impo_,
   {{0x764e01a8,0x00000000,0x00000000,0x00000000}},	//   laby, --, --, --,
   {{0x5fd20006,0x44320035,0x00000000,0x00000000}},	//   _देखल, mcy_, --, --,
   {{0xdfa5004f,0x66fa112b,0x764e8796,0xb87b0314}},	//   تحمي, ृतिक_, naby, vním,
   {{0x171b00c2,0x78a40359,0x2d9a7846,0x3f8d0395}},	//   נוצע, _oniv, ípe_, _eseu_,
   {{0x44320052,0x6cd4234a,0x2bd90084,0xccf9004e}},	//   ncy_, تقبا, _बेहा, goś_,
   {{0xe81a2f78,0xbfc6005f,0x60c28797,0x39ae0095}},	//   नेमा_, _убак, mkom, məsi_,
   {{0x60c2543e,0x78a48798,0x39ae0095,0x28db0437}},	//   lkom, _aniv, ləsi_, मोनि,
   {{0x69c500ab,0x60c24377,0x395e00a2,0xa49b00f1}},	//   _ühel, okom, urts_, _mhòr,
   {{0x60c28799,0x26da879a,0x66cb027d,0x236005e2}},	//   nkom, _ampo_, _müke, krij_,
   {{0x02fa07ba,0xb87b024e,0x7ebd0176,0x62854583}},	//   ्ताह_, lník, _sèpi, yeho,
   {{0x39ae0095,0x78a462c2,0x98bf010b,0x224a01ed}},	//   həsi_, _eniv, putį_, _nebk_,
   {{0x60c2879b,0x7afa879c,0xb87b01ba,0xd6d84d2e}},	//   kkom, mott, nník, стя_,
   {{0xf98f004f,0x60c22168,0x26da030d,0x7cfe0055}},	//   _أبو_, jkom, _empo_, përu,
   {{0x60c25c1b,0x6285879d,0x644d879e,0x764e01d5}},	// [9230] dkom, teho, raai, baby,
   {{0x7afa03fe,0x32550131,0xa49b0284,0x15f207b5}},	//   nott, івер, _chòr, _आँचर_,
   {{0x39ae0095,0xa49b01da,0x644d879f,0x628587a0}},	//   fəsi_, _dhòr, paai, reho,
   {{0x628587a1,0x212a148b,0xb87b024e,0x7afa87a2}},	//   seho, _dubh_, dník, hott,
   {{0x628587a3,0x68ed0054,0x7afa5f7f,0x212a0211}},	//   peho, _mjad, kott, _eubh_,
   {{0x24ab0083,0x60c287a4,0xa49b0284,0x7afa87a5}},	//   _ঐতিহ, akom, _ghòr, jott,
   {{0x7afa87a6,0x39ae0095,0x60c26d4b,0x7b060093}},	//   dott, bəsi_, bkom, rðul,
   {{0x2b5f04cb,0x6b8987a7,0xa0c515f8,0x39ae00a8}},	//   truc_, tweg, _بيرو, cəsi_,
   {{0x9f0404cd,0x7afa0036,0xb87b0355,0x764e024c}},	//   _کولو, fott, mníh, yaby,
   {{0x78a487a8,0xb87b0314,0x68ed00be,0x6b890c58}},	//   _sniv, lníh, _ajad, rweg,
   {{0x6b8987a9,0xfbd95c7a,0xb87b0097,0x6b9c013a}},	//   sweg, _बेरम, cník, ārga,
   {{0xb4e800ab,0xb87b0355,0x7ae80160,0x00000000}},	//   _बदे_, nníh, andt, --,
   {{0x7afa08f5,0x764e87aa,0x69d90099,0x60c987ab}},	//   bott, taby, _फेरी, _mlem,
   {{0x4432004e,0x7afa87ac,0x272f027d,0x60c95a30}},	//   wcy_, cott, _dün_, _llem,
   {{0x60c94a73,0x764e041b,0x7cfe01f4,0xda0d0026}},	//   _olem, raby, përt, _हरित_,
   {{0x764e0a74,0xa3ea0370,0x64a3005f,0x212a009e}},	//   saby, адба_, маса, _rubh_,
   {{0x272f06a8,0xb87b0076,0x2900002f,0x779400b5}},	// [9240] _gün_, zník, _ikia_, _عیسا,
   {{0x4432004e,0xdc3c0bca,0x60db010a,0x59de22c7}},	//   scy_, váčk, _amum, _फेडर,
   {{0x60c287ad,0x39ae0095,0x60c987ae,0xd12f2e22}},	//   tkom, təsi_, _blem, نمل_,
   {{0xb87b0076,0x7afa006c,0xfbc97d61,0x63ad00a8}},	//   vník, zott, िनाम, bxan,
   {{0x39ae0095,0x888d0070,0x2bd9051d,0x26160026}},	//   rəsi_, טראַ, _बेला, फेरी_,
   {{0x6146386a,0xb87b0187,0x66cb87af,0x39ae0095}},	//   _мега, tník, _tüke, səsi_,
   {{0x60c987b0,0x7afa87b1,0x6da30431,0xb87b00b8}},	//   _flem, vott, дија, bníh,
   {{0x412787b2,0x60c92b6f,0xb87b024e,0xa0670948}},	//   _фото_, _glem, rník, _маса_,
   {{0x7afa0332,0x2aaa1f6a,0x8e760733,0xb87b0187}},	//   tott, атно_, _мужч, sník,
   {{0x7cfe00da,0x7ae80088,0x29001505,0xb87b0097}},	//   tërs, undt, _akia_, pník,
   {{0x272f05f5,0xe895002d,0xd8f900d4,0x92b50033}},	//   _sün_, пань, йної_, _জগৎ_,
   {{0x7afa87b3,0x2d9e554b,0x63ad013b,0xa9c301e0}},	//   sott, _irte_, yxan, фськ,
   {{0xdc290037,0xdb2400ab,0xc05300a5,0x00000000}},	//   _اسمه_, öpäe, וזר_, --,
   {{0x291200d7,0x6b821f26,0xe20a00b4,0x7cfe0031}},	//   _ehya_, _ipog, _वरूण_, përs,
   {{0x344b496e,0x7bc087b4,0xc4db0200,0x00000000}},	//   ичан_, lymu, ађа_, --,
   {{0x70b9007c,0x63ad87b5,0x2d9e00ee,0x6ab80282}},	//   _आवेल, txan, _mrte_, _hovf,
   {{0xb87b01c0,0x68fd01f4,0x28a80066,0x29190176}},	// [9250] vníh, mosd, गारि, mmsa_,
   {{0x63ad87b6,0x60c987b7,0x21240211,0x2d9e033b}},	//   rxan, _slem, _aimh_, _orte_,
   {{0x60c905e2,0x672d00da,0xddc80009,0xb87b00b8}},	//   _plem, _huaj, _abdž, tníh,
   {{0x397b02b5,0x15fa00a5,0x672d467b,0x7bc0010b}},	//   שטאנ, _להתע, _kuaj, kymu,
   {{0x2d9e87b8,0x4aca009a,0x6d480024,0x902801c8}},	//   _arte_, िसाव, _awda, іцца_,
   {{0x59ca0026,0x672d00da,0x2ca6028b,0x2489009e}},	//   ानार, _muaj, _anod_, leam_,
   {{0xf2d202b5,0x672d01f4,0x2d9e011c,0x2369006d}},	//   _װען_, _luaj, _crte_, luaj_,
   {{0x60db38bf,0x248987b9,0x60c987ba,0x62950371}},	//   _umum, neam_, _ulem, _hazo,
   {{0x6295073a,0x7cfe01f4,0x200d01d7,0x2d9e6719}},	//   _kazo, tërr, _uzei_, _erte_,
   {{0xdd950733,0x0b4201c8,0x629587bb,0x69c500ab}},	//   _назы, эньн, _jazo, _ühek,
   {{0x629587bc,0x23690189,0xa9a500af,0x672d0054}},	//   _mazo, huaj_, чинд, _auaj,
   {{0x62950300,0x68fd0453,0x672d757d,0x7bc00051}},	//   _lazo, gosd, _buaj, bymu,
   {{0x248987bd,0x672d0a17,0x3a27023c,0x00000000}},	//   deam_, _cuaj, _tgnp_, --,
   {{0x629587be,0x672d0055,0x291987bf,0x00000000}},	//   _nazo, _duaj, amsa_, --,
   {{0x845a14d0,0x64a62faf,0x00000000,0x00000000}},	//   йрат_, пава, --, --,
   {{0x01c300c8,0x6fbd0099,0x5fbd0931,0xb87b00b8}},	//   ্পাদ, ्नां, ्नाल, riíc,
   {{0x87b987c0,0xe45f01ff,0x7ae126c9,0xdce30124}},	// [9260] _дуэт_, _glöm_, oilt, junč,
   {{0x62950138,0xdce3011c,0x479b00a5,0x7ae187c1}},	//   _cazo, dunč, _פייס, nilt,
   {{0x69c187c2,0x91e31129,0xe9f90019,0x6295005f}},	//   nyle, нофе, _đẻ_, _dazo,
   {{0xa06a0d39,0x7ae187c3,0x248987b9,0xf8cc3b29}},	//   сада_, hilt, ceam_, ासिय,
   {{0x7ae1535b,0x629543fa,0x644414e7,0x439300d8}},	//   kilt, _fazo, mbii, _заўс,
   {{0x629587c4,0x69c11e8b,0xfbd90fd0,0x00000000}},	//   _gazo, kyle, _बेइम, --,
   {{0x6b8287c5,0x28af045c,0x7ebd07a7,0xb87b0355}},	//   _spog, टामि, _rèpt, mnív,
   {{0x212487c6,0x66cb0095,0x2d9e012e,0x7bc0010b}},	//   _uimh_, _müka, _vrte_, tymu,
   {{0xbbb8009a,0xfc3f0f56,0x629587c7,0x5b1402ee}},	//   ेनेक, ñía_, _yazo, ммит,
   {{0x7f3b0122,0x672d00da,0x7ae187c8,0x2aaa0274}},	//   _לעמו, _ruaj, gilt, стио_,
   {{0x2d9e0291,0x68fd03bc,0x6b9b0103,0xe29b0070}},	//   _urte_, tosd, avug, זשיר,
   {{0x2ca687c9,0xab5d0035,0x7ae14dbb,0x05000033}},	//   _unod_, wyże, ailt, ্দুর_,
   {{0x7ae187ca,0xfaa62aff,0x672d00da,0x8c43487f}},	//   bilt, _надо, _quaj, _чече,
   {{0x672d01f4,0x96eb0c9d,0x98ae013a,0x69c121e8}},	//   _vuaj, сьма_, ānām_, byle,
   {{0x67253115,0x00000000,0x00000000,0x00000000}},	//   _vihj, --, --, --,
   {{0x672d8014,0xb925004f,0x236987cb,0x7d020176}},	//   _tuaj, _تفعي, tuaj_, _jkos,
   {{0x629587cc,0xa3f40210,0x248987cd,0x7d02373b}},	// [9270] _pazo, епті, ream_, _mkos,
   {{0x929400af,0x97360070,0x23690055,0x00000000}},	//   науц, _קרתא_, ruaj_, --,
   {{0x7d025910,0x629587ce,0x644401a8,0xfbd90026}},	//   _okos, _vazo, bbii, _बेईम,
   {{0xc5f201f3,0x2ec5052b,0x7ae102e9,0x046700c3}},	//   _ידי_, वस्त, zilt, _этом,
   {{0x6295390a,0x44390523,0x644f00ea,0x22680355}},	//   _tazo, _ifs_, _ieci, átké_,
   {{0xc33202b5,0x7d0287cf,0xc7d800a5,0xde0532a6}},	//   _בוך_, _akos, הודי_, мпли,
   {{0x644f3635,0x443902c4,0x693a0024,0xd16402fb}},	//   _keci, _kfs_, _jċed, _пъти,
   {{0xa2d90fbf,0x645a00ea,0x3f9f018d,0x00000000}},	//   फोर्, _ētik, _truu_, --,
   {{0x644f87d0,0x7ae187d1,0x442b0176,0xeb992349}},	//   _meci, tilt, _mgc_, цип_,
   {{0x644f87d2,0x66d087d3,0x00000000,0x00000000}},	//   _leci, _käke, --, --,
   {{0x44390079,0x7ae187d4,0xa88a4ee3,0xbe640037}},	//   _ofs_, rilt, ойна_, _أهمي,
   {{0xa3ad000c,0x7ae187d5,0x66d084e0,0xf1b2016b}},	//   कमा_, silt, _mäke, דסט_,
   {{0xb8e6170c,0xe20a0026,0x66d0013c,0x7d1b665f}},	//   _एव_, _वर्ण_, _läke, mmus,
   {{0x644f0009,0x7d090d19,0x442b099e,0x6908002a}},	//   _aeci, lles, _agc_, iñei,
   {{0xcb120052,0x644f00d1,0x66d00086,0x00000000}},	//   _שלו_, _beci, _näke, --,
   {{0xe8f60037,0x442b00f6,0xf50a093e,0x656100b5}},	//   _تستخ, _cgc_, інал_, álha,
   {{0x073a004f,0x64445473,0x7d09005f,0xa3ad00b4}},	// [9280] _بسبب_, rbii, iles, _कपः_,
   {{0x244c0019,0x7d0987d6,0x05000033,0x28cc06fe}},	//   ếm_, hles, ্দের_, ासवि,
   {{0x644f00af,0x273403ad,0x63a90484,0xb87b1d2b}},	//   _feci, _hän_, _ġene, rnív,
   {{0x7d09006c,0x644f87d7,0x63a902c4,0x7bcd00ea}},	//   jles, _geci, _šene, _ļaun,
   {{0x2d850260,0x7d1b87d8,0x7d094c19,0x32110409}},	//   _aple_, dmus, dles, _ezzy_,
   {{0x2734022a,0xbea305ac,0x644f2909,0x59ad3421}},	//   _män_, качк, _zeci, टमार,
   {{0x2734022a,0x7d0987d9,0xe2971172,0x3d0a03de}},	//   _län_, fles, _юар_, ातले_,
   {{0x1ee800f5,0x997201c0,0x7d1b0282,0x00000000}},	//   _کوئی_, těže_, gmus, --,
   {{0x2d8518ee,0x00000000,0x00000000,0x00000000}},	//   _eple_, --, --, --,
   {{0x7d09108c,0x80da37e8,0x00000000,0x00000000}},	//   ales, पोरे, --, --,
   {{0x7d0987da,0x7c3900e9,0x7d1b01f7,0x00000000}},	//   bles, _ffwr, bmus, --,
   {{0x7d0987db,0x2bd90e1d,0xab2a87dc,0x7d020054}},	//   cles, _बेका, _дода_, _ukos,
   {{0xe81a065a,0xad1b00c2,0x644f449a,0xb33b03e6}},	//   नेला_, _וואר, _reci, _orça,
   {{0x644f87dd,0x443987de,0x5bb70746,0x00000000}},	//   _seci, _sfs_, _юлія_, --,
   {{0x6d5840b7,0x442b87df,0xf98f0af8,0xef0e010b}},	//   nsva, _pgc_, _نبي_, ымi_,
   {{0x7d0087e0,0x09ca0edf,0x6d5887e1,0xc9830a22}},	//   noms, ानीय, isva, _руши,
   {{0x644f54cf,0x66d006d7,0xbf0e4e29,0x63a90df4}},	// [9290] _veci, _säke, िताभ_, _šenb,
   {{0xd251036b,0x67161bc6,0x6d5887e2,0x4439008c}},	//   انا_, _दीपक_, ksva, _wfs_,
   {{0x7d0987e3,0x7d0087e4,0x44395f8c,0x644f0bc8}},	//   yles, koms, _tfs_, _teci,
   {{0x7d0901a2,0x645d01b4,0x6d581f79,0x7d0000a0}},	//   xles, _udsi, dsva, joms,
   {{0x8e85150d,0x6d5a30f6,0xe8d80319,0x7d0987e5}},	//   егле, _avta, וואר_, vles,
   {{0x2d95280a,0x2bd90084,0x7a3100b5,0x00000000}},	//   ерис, _बेगा, _műté, --,
   {{0x7d0987e6,0xdce806d3,0x7d1b74a2,0x6d5887e7}},	//   tles, _ardı, tmus, gsva,
   {{0x9f51006c,0xcf7b0037,0x6aaa00e9,0x7d0906cd}},	//   ából_, _وإذا_, _anff, ules,
   {{0x7d0964a2,0x76550035,0x443e00a8,0x6d5a02a7}},	//   rles, kazy, _ət_, _evta,
   {{0x7d1b4b7b,0xeab10082,0xaad9004e,0x39452830}},	//   smus, اعة_, योंक, нног,
   {{0x7d1b0210,0x88e60421,0x00000000,0x00000000}},	//   pmus, ежне, --, --,
   {{0x6d4387e8,0xe0bd0033,0x27340107,0x00000000}},	//   mpna, _আগুন, _pän_, --,
   {{0x6d4387e9,0xade300b4,0xbbeb0833,0xdce8005f}},	//   lpna, _केतन_, _برام_, _apdė,
   {{0x2734022a,0x76550035,0x290b080a,0x00000000}},	//   _vän_, gazy, alca_, --,
   {{0x2cbd12f1,0x24990139,0xb87b87ea,0x00000000}},	//   _kowd_, _basm_, gnís, --,
   {{0x05000083,0x27340421,0x7a3100fd,0x00000000}},	//   ্দ্র_, _tän_, _fűté, --,
   {{0x3860006e,0x290287eb,0x00000000,0x00000000}},	// [92a0] _idir_, moka_, --, --,
   {{0xe29708f1,0x290287ec,0x68e687ed,0x630629fe}},	//   нау_, loka_, likd, روال,
   {{0xa3bc22f2,0xdcff0355,0x7d0008c7,0x5637016b}},	//   _अथक_, ívěs, yoms, _ראטע_,
   {{0x232a0714,0x261508a9,0x25a501b4,0x68e60553}},	//   _номи_, _धरती_, ælle_, nikd,
   {{0x645687ee,0x656e121e,0x705300d1,0x24800183}},	//   mayi, lubh, انها, mfim_,
   {{0x64560273,0x6d5887ef,0x29020010,0x2cbd00fe}},	//   layi, tsva, hoka_, _aowd_,
   {{0x290201a8,0xe9f90019,0x7d001b86,0x00000000}},	//   koka_, _đế_, toms, --,
   {{0x645687f0,0x24806947,0xdd8e00b5,0x00000000}},	//   nayi, nfim_, لوڈ_, --,
   {{0x29020848,0x7d00812e,0x6d5887f1,0x1e866734}},	//   doka_, roms, ssva, _плам,
   {{0x645687f2,0x2fc6006d,0xdce300ea,0x98a800ea}},	//   hayi, myog_, runā, _runā_,
   {{0x29023af3,0xfbcf0e3a,0x28f97bcd,0x645687f3}},	//   foka_, لتی_, день_, kayi,
   {{0x3860009e,0x290287f4,0x00000000,0x00000000}},	//   _cdir_, goka_, --, --,
   {{0x64560e91,0x69ce0066,0xe78400af,0x3ebe018d}},	//   dayi, दनही, луро, _kott_,
   {{0x386001c2,0x3ebe76f5,0x00000000,0x00000000}},	//   _edir_, _jott_, --, --,
   {{0x3a3700c2,0x290287f5,0x645676df,0x765553d6}},	//   _ארום_, boka_, fayi, razy,
   {{0x3ebe87f6,0xade30006,0x64560186,0x29020027}},	//   _lott_, _कइसन_, gayi, coka_,
   {{0x66cb0463,0x78ad0054,0xc29914b4,0xb275004b}},	// [92b0] _yükl, _inav, мках_, клаш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64560186,0x78ad72f8,0x6d5e0207,0xa5f93fcb}},	//   bayi, _knav, špaj, _цену_,
   {{0x645687f7,0x00000000,0x00000000,0x00000000}},	//   cayi, --, --, --,
   {{0x3ebe01ff,0x5fdb021a,0x78ad0cdf,0x00000000}},	//   _bott_, _मेखल, _mnav, --,
   {{0x290287f8,0xdb020298,0x66d0017b,0x00000000}},	//   zoka_, _droë, _käka, --,
   {{0x3ebe02fb,0x290201a8,0x2bd90437,0x395c0051}},	//   _dott_, yoka_, _बेजा, _nvvs_,
   {{0x2fc60008,0x6b8400af,0x3eac11cb,0x02c10096}},	//   byog_, _ţiga, _endt_, _शकुन,
   {{0x66d0022a,0x98a8002d,0x290287f9,0x386084fa}},	//   _läka, _lună_, voka_, _rdir_,
   {{0x3ebe87fa,0x78ad87fb,0x645687fc,0x6d4387fd}},	//   _gott_, _anav, zayi, ppna,
   {{0x290287fe,0xdd910d4f,0x186a0eee,0x23690187}},	//   toka_, _خوا_, мани_, hraj_,
   {{0x23690e5e,0x6f03862c,0x48e607c1,0xa3c30775}},	//   kraj_, lonc, томв, ौना_,
   {{0x290287ff,0x2bd90243,0xda0d0ca1,0x68e68800}},	//   roka_, _बेचा, _हरकत_, rikd,
   {{0x6f038801,0x8a05150d,0x7c3b0120,0x98a8002d}},	//   nonc, _изле, lcur, _bună_,
   {{0x64568802,0x29028803,0xa50a578a,0xceb2025a}},	//   tayi, poka_, дева_, סיל_,
   {{0x320a1b66,0x78ad08c8,0x7c3b11f0,0x63a902c4}},	//   _ryby_, _gnav, ncur, _šena,
   {{0x6f030e7d,0x64568804,0xa3e5020d,0xa507204e}},	// [92c0] konc, rayi, _भेद_, тета_,
   {{0x64568805,0x69c500ab,0x2fc6006d,0x6d4128ae}},	//   sayi, _ühes, vyog_, _otla,
   {{0x6d41009f,0x64560107,0x3ebe8806,0x7c3b0051}},	//   _ntla, payi, _rott_, kcur,
   {{0x3ebe8807,0x4fea00c3,0x645600a8,0x00e602fb}},	//   _sott_, ммен_, qayi, ъжен,
   {{0x6f030248,0x6d413cdb,0xe9f900e2,0x68e40069}},	//   fonc, _atla, _đẽ_, _mmid,
   {{0x7c3b0051,0xdb026ad8,0x1ee600f8,0x00000000}},	//   ecur, _groè, ضوعی_, --,
   {{0x180f0429,0x2fc60221,0xa2e30009,0x68e40160}},	//   _सर्व_, syog_, _торд, _omid,
   {{0x629c3d9c,0xc5f300a5,0xe805007e,0xdb981205}},	//   _haro, ידו_, रथमा_, евич_,
   {{0x629c8808,0xcb67282d,0x09ca0099,0x4f2600c7}},	//   _karo, вање_, ान्य, _адаб,
   {{0x60c08809,0x629c880a,0x64bf0084,0x7053006c}},	//   _homm, _jaro, _एक्श, _منہا,
   {{0x629c86d7,0xddc8004e,0x1db60066,0x28af00b4}},	//   _maro, _wedł, _अपित, टालि,
   {{0x629c0269,0xcfa90332,0xc17300a5,0x8d740987}},	//   _laro, _تاہم_, סחר_, _لاچا,
   {{0x48e4010b,0xa2d506fe,0x60c0470b,0x98a80395}},	//   роўв, णसम्, _momm, _sună_,
   {{0x629c04c3,0x60c011cb,0x23696cc4,0x68e4880b}},	//   _naro, _lomm, vraj_, _emid,
   {{0xd6d802ce,0xe5c40d84,0x63a60176,0xa4d501e0}},	//   ття_, асто, _arkn, гові,
   {{0x629c880c,0x60c0880d,0x78ad880e,0x2369880f}},	//   _aaro, _nomm, _unav, traj_,
   {{0x629c2da5,0x7b32004e,0x63a63b64,0x69c88810}},	// [92d0] _baro, _dług, _crkn, lyde,
   {{0xfde3007c,0xade300ab,0x00000000,0x00000000}},	//   _कइलस_, _कइलन_, --, --,
   {{0x69da8811,0x6f030124,0x69c82e0c,0x66cb00ab}},	//   nzte, vonc, nyde, _lükk,
   {{0x60c01e11,0x69da01a3,0x63a60207,0xfe00060a}},	//   _comm, izte, _frkn, _लुइस_,
   {{0x6f030083,0x60c05052,0x6d41560d,0x26c10187}},	//   tonc, _domm, _stla, _koho_,
   {{0x629c8812,0x26c18813,0xaf04010b,0x66d00523}},	//   _garo, _joho_, апіл, _läkn,
   {{0xf075006c,0x8d5400d8,0x26c100f8,0xfce51eb9}},	//   _میاں_, атыч, _moho_, локо,
   {{0x60c08814,0x69c60066,0xe8140099,0x29090103}},	//   _gomm, ाहनी, _ठरला_, _nkaa_,
   {{0x7c3b1c19,0x629c0eb7,0x5f9402ee,0x6f033f40}},	//   rcur, _yaro, _китт, ponc,
   {{0x68e40c66,0xa3bb0006,0x629c5f4c,0x66cb027d}},	//   _smid, _अपन_, _xaro, _dükk,
   {{0xaad93054,0x59ca0d34,0x6d418815,0x212d0118}},	//   योगक, ानगर, _utla, _kieh_,
   {{0xf7468816,0x6fa70066,0x00000000,0x00000000}},	//   лемо, चिपू, --, --,
   {{0x6b650eeb,0x2d0f02cb,0x7b06008a,0x20f86545}},	//   _скла, ातील_, rður, nčia_,
   {{0x5a4700d8,0x69c801b4,0xdbd100ab,0x212d0168}},	//   _рэда, byde, _müüm, _lieh_,
   {{0x629c0473,0x63a60207,0x7cfe0345,0x7bdb0223}},	//   _raro, _srkn, eëry, lzuu,
   {{0x68e44f95,0x97c61062,0x69080453,0x00000000}},	//   _umid, _مقبو, añer, --,
   {{0x60c08817,0xdd03010b,0x934661ad,0xfe0000b4}},	// [92e0] _romm, ūrėj, унзе, _लुईस_,
   {{0x629c0510,0x26c100d7,0x00000000,0x00000000}},	//   _qaro, _goho_, --, --,
   {{0x629c8818,0x60c08819,0x10a6052c,0xa0a60340}},	//   _varo, _pomm, лижн, лажд,
   {{0x629c881a,0xd12f01b2,0x26c1881b,0x48b20033}},	//   _waro, سمه_, _zoho_, _চতুর,
   {{0x69c8004e,0x70c40026,0x44240014,0x69da0453}},	//   zyde, _वकील, _àm_, zzte,
   {{0x629c011e,0x63a40093,0xf8bf00f7,0xdd9a0374}},	//   _uaro, mvin, mmée_, еши_,
   {{0x8d8601cb,0xf8bf00a2,0x00000000,0x00000000}},	//   اشتن, lmée_, --, --,
   {{0xbd87317b,0x63a42d75,0x69c853d3,0x212d0024}},	//   انين_, ovin, vyde, _gieh_,
   {{0x66d0022a,0x8fa35195,0x4fa3052a,0x6e463f96}},	//   _räkn, _лате, _литв, _безз,
   {{0x69da02bf,0x69c84409,0xe45f03ad,0xc33302b5}},	//   tzte, tyde, _ylös_, זוז_,
   {{0x26c14c85,0xd2b70122,0x7dc60647,0x7c861e46}},	//   _roho_, אלית_, _حقان, _буле,
   {{0xa3e50ccf,0x69c8881c,0x8dfb0122,0x69da881d}},	//   _भइल_, ryde, _אהבת, rzte,
   {{0x69da0332,0x81bc00c8,0x63a40a75,0x26c100ac}},	//   szte, েছি_, jvin, _poho_,
   {{0x3ce60221,0x63a90690,0xa3e50066,0x99d616a4}},	//   _hmov_, _šeno, _भेष_, _متعا,
   {{0x58d500c3,0x4ab100b4,0x69c500be,0x00000000}},	//   _войт, जारव, _ühep, --,
   {{0x290f0037,0x20f800c7,0x84c40279,0xb8670413}},	//   _óga_, yčia_, бљуд, _صابو,
   {{0x26c10076,0x395e0ae0,0x63a4881e,0xbec700ea}},	// [92f0] _toho_, lsts_, gvin, ldīš,
   {{0x521500d8,0x66d001ff,0x212d02b1,0x00000000}},	//   адзт, _jäkl, _sieh_, --,
   {{0x461500bf,0xb0354745,0x66d0013c,0x7aef0138}},	//   _خودر, анеш, _mäkl, écti,
   {{0x395e881f,0x5f7500f8,0x00000000,0x00000000}},	//   ists_, لاتر, --, --,
   {{0x644d8820,0x926b0798,0xb4c32e64,0xda0b00ab}},	//   mbai, _прва_, ्सी_, _सुनत_,
   {{0x395e0080,0xddc51bfd,0xa3de0099,0x20f800c7}},	//   ksts_, ибли, _थेट_, rčia_,
   {{0xfc31004f,0x00000000,0x00000000,0x00000000}},	//   يحة_, --, --, --,
   {{0xab6522f1,0xff1500c8,0x644d06a2,0x6285026e}},	//   авил, াদেশ_, nbai, lfho,
   {{0x395e0955,0x00000000,0x00000000,0x00000000}},	//   ests_, --, --, --,
   {{0x752f006a,0x20f800d5,0x644d028b,0xb4d2060a}},	//   _licz, nčin_, hbai, _वत्_,
   {{0x63a40097,0x6ac50066,0x00000000,0x00000000}},	//   zvin, _लकीर, --, --,
   {{0x63a48821,0x752f0035,0xe73a20c3,0xaad9052b}},	//   yvin, _nicz, кем_, योजक,
   {{0xa3e5007c,0x26d88822,0xdcf40009,0xb8ee0d12}},	//   _भेल_, thro_, _šaći, _शक_,
   {{0x63a40c9a,0x20f80506,0x5f360070,0x62850223}},	//   vvin, jčin_, יטשע_, jfho,
   {{0x65c32b8e,0x2d530043,0x09e20279,0x6cec0387}},	//   обра, nţe_, _мошн, _जगमग_,
   {{0x8a1400d1,0x47c601e0,0x62850298,0x00000000}},	//   _اظها, _вбив, efho, --,
   {{0x68fd00b5,0x00000000,0x00000000,0x00000000}},	// [9300] érde, --, --, --,
   {{0x55e64166,0xf8bf00f7,0x63a405d6,0x644d8823}},	//   _вооб, rmée_, rvin, abai,
   {{0xe297479a,0x644d0211,0x00000000,0x00000000}},	//   рах_, bbai, --, --,
   {{0x64a68824,0xb3580332,0x39a50080,0x4fc654d4}},	//   _тама, _میرا_, _mēs_, исла,
   {{0xb1860d51,0x98a60448,0x00000000,0x00000000}},	//   _blåø, nslı_, --, --,
   {{0x765c8825,0x5d660970,0xfaf9010b,0x752f8826}},	//   nary, атиз, irūs_, _zicz,
   {{0xdce101d6,0x69c701b4,0x00000000,0x00000000}},	//   _aslı, øjel, --, --,
   {{0x656e066a,0x0ca70086,0xfbe70083,0x765c8827}},	//   irbh, атьи_, _পড়ত, hary,
   {{0x765c8828,0x22588829,0xafe64de5,0x0c7300f8}},	//   kary, _kerk_, _тоал, زديد,
   {{0x79a62e2d,0x0f7b0317,0x644d882a,0x765c882b}},	//   арме, _באמב, zbai, jary,
   {{0x765c01c8,0x2258882c,0x20f8010b,0x691601ef}},	//   dary, _merk_, nčio_, ráen,
   {{0x395e882d,0x1bea0e0a,0x6d4a02b1,0x00000000}},	//   rsts_, _идеи_, mpfa, --,
   {{0xd7fb1156,0x39492240,0x98bf00ea,0x765c00e9}},	//   тун_, _čase_, lstī_, fary,
   {{0x7e78024a,0x9b43026e,0x6d4a882e,0x00000000}},	//   ngvp, _بنوو, opfa, --,
   {{0x7afd882f,0x6abc0093,0x2bd4021a,0x00000000}},	//   éste, örfu, धनवा, --,
   {{0x04c90037,0xb4c323e3,0x693a0024,0x2ed301d1}},	//   دوري_, ्से_, _jċem, _थत्त,
   {{0x644d8830,0x656e09c3,0x765c8831,0xe3b00037}},	// [9310] rbai, arbh, bary, ورك_,
   {{0xf1a75562,0xf699192f,0x644d0014,0x00000000}},	//   ирен, _свој_, sbai, --,
   {{0x28cc0632,0x20f8011c,0x3ce71ef5,0x62858832}},	//   ासचि, rčin_, _जगले_, rfho,
   {{0x62850037,0x00000000,0x00000000,0x00000000}},	//   sfho, --, --, --,
   {{0xddc10139,0x2258023a,0x00000000,0x00000000}},	//   _belş, _ferk_, --, --,
   {{0xaaa68833,0x273d00e2,0x20180037,0x2258005f}},	//   _कोलक, _mìn_, جتمع_, _gerk_,
   {{0x020400d8,0xad58037c,0xdb020098,0x2c130033}},	//   _дзён, арых_, _croí, _হলেই_,
   {{0x20f80187,0x765c8834,0x85f800a5,0x225801b7}},	//   nčil_, zary, יצוע_, _zerk_,
   {{0x63a90009,0x765c8835,0x6d4a0079,0x9e6700fd}},	//   _šenj, yary, apfa, _ناان,
   {{0x7b32004e,0x9f95007c,0xbd6b00af,0x00000000}},	//   _słuc, _müüa_, _арде_, --,
   {{0x98a612b3,0x39e96f47,0x2a7c0176,0x765c83f7}},	//   бине, удно_, _dcvb_, vary,
   {{0x765c8836,0x00000000,0x00000000,0x00000000}},	//   wary, --, --, --,
   {{0xfaa501c8,0x765c8837,0xdc360070,0xcb690e9f}},	//   _гало, tary, _האנט_, _сале_,
   {{0x2cbf8838,0xe73713f8,0x7d094c02,0x00000000}},	//   ljud_, сер_, loes, --,
   {{0x765c5d63,0x66e32286,0x66d002e2,0x2aba00a5}},	//   rary, чора, _häkk, _תמצא,
   {{0xb4d208b0,0x765c6f6d,0xd3ba00d4,0x81bd0033}},	//   वसे_, sary, лузі_, ইনা_,
   {{0x765c0ea5,0x273d0023,0x00000000,0x00000000}},	// [9320] pary, _gìn_, --, --,
   {{0x05080083,0x66d08839,0x7d093952,0x00000000}},	//   লগের_, _mäkk, hoes, --,
   {{0x2258718d,0x98b9010b,0x20f800f4,0x7d09883a}},	//   _verk_, ūrą_, učio_, koes,
   {{0x225836bf,0x2cbf022e,0x693a0024,0x20f800c7}},	//   _werk_, jjud_, _bċej, rčio_,
   {{0x0eea02ce,0x787b0070,0x7d09883b,0x20f8010b}},	//   льки_, אָוו, does, sčio_,
   {{0x52752e1b,0xa2d600f8,0xdb020132,0x11d60f99}},	//   _мусу, _ايست, _proí, _любя,
   {{0x6443004e,0x2b46883c,0xbbc006fe,0xddc100b5}},	//   śnie, _stoc_, शङ्क, _belő,
   {{0xc1f700a5,0x6d4a883d,0x98af0160,0x7d090088}},	//   _המלץ_, rpfa, _mufă_, goes,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbcf01b2,0x63ab7992,0x6d4a883e,0x3e810093}},	//   عتي_, ågni, ppfa, rætó_,
   {{0x2d980248,0x7d090132,0x273d055c,0x00000000}},	//   _ère_, boes, _sìn_, --,
   {{0x2d9e7e82,0x0217011d,0x00000000,0x00000000}},	//   _iste_, מחים_, --, --,
   {{0x61e00095,0x00000000,0x00000000,0x00000000}},	//   _əmla, --, --, --,
   {{0x81de00c8,0xeaf54e96,0xb4c30026,0xf4000033}},	//   _তখন_, ीकृत_, ्स्_, ্ধার_,
   {{0x2d9e000c,0x9f9500ab,0x00000000,0x00000000}},	//   _jste_, _süüa_, --, --,
   {{0x2eee033b,0x00000000,0x00000000,0x00000000}},	//   hiff_, --, --, --,
   {{0x7e6800d7,0x38690408,0x20f8168a,0x68ef081b}},	// [9330] _oddp, _idar_, rčil_, micd,
   {{0x8c1b02da,0x290b08c0,0xa7fb0300,0x2d9e0f0a}},	//   רומי, loca_, gañe, _oste_,
   {{0x399a3bc2,0xa2bf02e4,0x2eee28c3,0x00000000}},	//   _jūs_, लॉग्, diff_, --,
   {{0x399a00ea,0x00000000,0x00000000,0x00000000}},	//   _mūs_, --, --, --,
   {{0x2d9e883f,0x98b4011c,0x6d480228,0xa7fb02d7}},	//   _aste_, šeći_, _atda, bañe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ced01ba,0xe05700f8,0x290b8840,0x31c40652}},	//   tiev_, _هیات_, koca_, _еств,
   {{0x62970621,0x645f0095,0x0b451783,0x3c2f013b}},	//   lexo, naqi, онин, _növü_,
   {{0x2d9e8841,0x7d098842,0x8c64004f,0x3ced00ee}},	//   _este_, roes, سطين, riev_,
   {{0x05ba0d43,0x399a0080,0x62976a8c,0x38698843}},	//   _उपलब, _būs_, nexo, _adar_,
   {{0xe8fa103e,0x6d5e8844,0x7d098845,0xe0d000b5}},	//   ило_, špar, poes, _غزہ_,
   {{0xa3d90461,0x6297002a,0x7e6802a7,0x00000000}},	//   ़ना_, hexo, _zddp, --,
   {{0x66d00dfa,0x68fd0453,0x98160b8d,0x3869099e}},	//   _häki, érda, تبدا, _ddar_,
   {{0x3869046a,0xf3ff0132,0x9a2900af,0xa803002a}},	//   _edar_, _adão_, _колб_, úñas,
   {{0x62978846,0xe5a317d0,0x845a01d3,0xd62a6435}},	//   dexo, мири, ират_, рове_,
   {{0x9e3c290b,0x6aa3001e,0x290b8847,0x66d00421}},	//   _maďa, _hanf, coca_, _mäki,
   {{0xb6a6107a,0x66d0018d,0x2b4d00d7,0xd3f412ea}},	// [9340] _дипл, _läki, npec_, нiст,
   {{0x78a40221,0x6aa301ed,0xa3bb0127,0x00000000}},	//   _haiv, _janf, _अपर_, --,
   {{0xd175004b,0x78a400c3,0xdb0b0031,0x9e3c00a0}},	//   зычы, _kaiv, _argë, _naďa,
   {{0x6aa38848,0x2d9e0a8a,0xa7fb01ed,0x00000000}},	//   _lanf, _rste_, sañe, --,
   {{0x78a40221,0xdfd000f8,0x5f062d9c,0x64430035}},	//   _maiv, عيت_, озда, śnic,
   {{0x78a48849,0x6aa3884a,0x00000000,0x00000000}},	//   _laiv, _nanf, --, --,
   {{0x20d7884b,0x2eee884c,0x628e0024,0x00000000}},	//   _için_, riff_, _ibbo, --,
   {{0x66cb036a,0x64447970,0xdb0b0279,0x6aa30051}},	//   _yüks, ncii, _urgê, _aanf,
   {{0xfb8600d8,0x394902c6,0x00000000,0x00000000}},	//   цыйн, _časa_, --, --,
   {{0xcb1a00c9,0x6aa3001e,0x27480139,0x00000000}},	//   јќи_, _canf, _mînă_, --,
   {{0x09f80082,0x2d9e06a2,0x3f860bc8,0x6aa3884d}},	//   صفحة_, _uste_, ltou_, _danf,
   {{0x7aef0f56,0x78a41bc8,0x60c20118,0x290300cd}},	//   éctr, _caiv, njom, čkao_,
   {{0x3f86884e,0x60350095,0x78a400e1,0xfaa6191f}},	//   ntou_, _həmç, _daiv, _мадо,
   {{0xa3ae3717,0x64460223,0x3f862314,0x6aa300e9}},	//   किन_, _afki, itou_, _ganf,
   {{0x290b2e3e,0x58d5001f,0x00000000,0x00000000}},	//   poca_, _нокт, --, --,
   {{0x628e884f,0x6aa38850,0x38691b86,0x6d460009}},	//   _abbo, _zanf, _udar_, _čkal,
   {{0x645f00da,0x24890124,0x3d0b1b8f,0xb87b002a}},	// [9350] raqi, rfam_, ावते_, rhíd,
   {{0x238e0029,0xb87b0042,0x00000000,0x00000000}},	//   dējā_, eníx, --, --,
   {{0x6297002a,0x78a4023c,0x00000000,0x00000000}},	//   rexo, _yaiv, --, --,
   {{0x629701dd,0xc1042149,0x628e0155,0x3cf60067}},	//   sexo, وولي, _ebbo, ुकों_,
   {{0x645d8851,0x443934de,0xa4f90099,0xcf9b1d77}},	//   _iesi, _igs_, ्कीच_, рје_,
   {{0x645d8852,0x6da519c3,0x63af59f1,0x335800af}},	//   _hesi, зика, _ircn, _фарэ_,
   {{0x645d8853,0xb14601ca,0x6aa302d0,0x41bf04bc}},	//   _kesi, _فیلم_, _ranf, _एपिस,
   {{0xdd8e004f,0x645d8854,0x66d000c3,0xd5fc00a5}},	//   اوي_, _jesi, _väki, יפור,
   {{0x645d1f0b,0x3f868855,0x78a48856,0xace80698}},	//   _mesi, ctou_, _raiv, ترول_,
   {{0x645d8857,0x68ed8858,0x44398859,0x78a400c3}},	//   _lesi, _amad, _lgs_, _saiv,
   {{0x4efa02b5,0x60db1be0,0x78a4885a,0xaf080037}},	//   _פלעג, _klum, _paiv, _بقلم_,
   {{0x645d6bea,0x4439011e,0x6aa3885b,0x3ea506d1}},	//   _nesi, _ngs_, _wanf, _halt_,
   {{0x78a4885c,0x3ea5885d,0x60c90d8f,0x6aa300b5}},	//   _vaiv, _kalt_, _moem, _tanf,
   {{0x60db885e,0x4439885f,0x68ed00be,0xbbb901c0}},	//   _llum, _ags_, _emad, ेहीक,
   {{0x60db8860,0x645d8861,0x78a48862,0xceb2011d}},	//   _olum, _besi, _taiv, עיל_,
   {{0x60c98863,0x274800af,0x9346031a,0x63af02a7}},	//   _noem, _pînă_, знае, _brcn,
   {{0x2d8700ab,0xdb0b0183,0x64448864,0x44390225}},	// [9360] htne_, _argé, rcii, _dgs_,
   {{0x60db3d46,0x2d878865,0x691d000d,0x44398866}},	//   _alum, ktne_, néen, _egs_,
   {{0x60db8867,0x60c90298,0x645d6d2c,0x68ed00e9}},	//   _blum, _boem, _fesi, _ymad,
   {{0x645d8868,0xe0430525,0x60c901ef,0x55bb00a5}},	//   _gesi, енци, _coem, _המטו,
   {{0x63a90009,0x74161026,0x765e8869,0x63af023a}},	//   _šenv, _روسا, _kepy, _grcn,
   {{0x59cb2bb1,0xa3e500a1,0x645d0355,0xdee37bcd}},	//   ाहार, _भेट_, _zesi, ночи,
   {{0x3f8615d8,0x645d4e57,0x3ea512c3,0x60db846d}},	//   stou_, _yesi, _dalt_, _flum,
   {{0x29000657,0x60db886a,0x3f860391,0x291225b4}},	//   _njia_, _glum, ptou_, _nkya_,
   {{0x613a01c0,0x3ea5886b,0x00000000,0x00000000}},	//   _důle, _falt_, --, --,
   {{0x6da63091,0x3ea5886c,0x2912886d,0x68ed886e}},	//   _низа, _galt_, _akya_, _smad,
   {{0x1ea907f6,0xdd8f0cd1,0xa7fb02d7,0x00000000}},	//   _باقي_, _مول_, daña, --,
   {{0xfce31523,0x66d000ee,0x00000000,0x00000000}},	//   _похо, _mäku, --, --,
   {{0x645d886f,0x443900c7,0xcce50af8,0x29000523}},	//   _resi, _rgs_, _تسلي, _djia_,
   {{0x645d8870,0xa7fb0831,0x291201a8,0x691d000d}},	//   _sesi, gaña, _ekya_, céen,
   {{0xa3e50299,0x56780086,0x44397f7e,0x765e0107}},	//   _भेज_, ября_, _pgs_, _depy,
   {{0x5fbe2095,0x68ed034d,0xba17011d,0x00000000}},	//   ्हाल, _umad, _מחוץ_, --,
   {{0xd90f0164,0x645d68de,0x60c932c5,0xa7fb112c}},	// [9370] _لیگ_, _vesi, _roem, baña,
   {{0x60db8871,0x645d0441,0x60c907d4,0x2919007a}},	//   _slum, _wesi, _soem, llsa_,
   {{0x645d8872,0x68fd8873,0x60db0b73,0x60c98874}},	//   _tesi, onsd, _plum, _poem,
   {{0x68fd03f4,0x3ea5024b,0x00000000,0x00000000}},	//   nnsd, _salt_, --, --,
   {{0x6d5a0103,0x2724008d,0x765e0448,0xbea55f0a}},	//   _awta, bönd_, _yepy, далк,
   {{0x7c39001e,0x63ad8875,0xa159010b,0x67370024}},	//   _sgwr, mvan, _магу_, _jixj,
   {{0x63ad8876,0x3ea58877,0xa194029f,0x60db8878}},	//   lvan, _valt_, _парч, _tlum,
   {{0x2d878879,0x9f5f00b5,0x66d001ff,0x29190009}},	//   rtne_, áról_, _häkt, jlsa_,
   {{0x2d87887a,0x63ad887b,0x3ea5887c,0xac160274}},	//   stne_, nvan, _talt_, моћу_,
   {{0x39451f1e,0xab5d0035,0x63ad887d,0x6d5a099e}},	//   мног, wyżs, ivan, _fwta,
   {{0x66d001ff,0x6dd50609,0x7e63887e,0xf2d20d85}},	//   _mäkt, _تقاض, manp, דעי_,
   {{0xb4f90066,0x63ad887f,0x7e638880,0x394024d4}},	//   ्कोप_, kvan, lanp, _čist_,
   {{0x691d0248,0x272401ae,0x765e32b2,0xe79c027d}},	//   péen, höne_, _pepy, _düğü,
   {{0x63ad8881,0x7e6302ee,0x6b898882,0x38621c1a}},	//   dvan, nanp, mteg, sakr_,
   {{0xaac43c96,0x6b890291,0x63ad8883,0x044607b0}},	//   _ستون, lteg, evan, дебн,
   {{0xf8e20722,0x2eda0567,0xdb020031,0xa7fb02d7}},	//   _पतिय, _भत्त, _proç, saña,
   {{0xfa8e01a5,0xccf20122,0xa7fb1e6e,0x59cb0964}},	// [9380] _mừng_, דכן_, paña, ाहवर,
   {{0xe297002d,0x6b8901d7,0xfa8e00e2,0x00000000}},	//   мау_, iteg, _lừng_, --,
   {{0x7e6309ff,0x63a9008b,0xa87a0070,0x2c0a0035}},	//   danp, _šent, ַאַר, _हुईं_,
   {{0xdb027c5b,0x00000000,0x00000000,0x00000000}},	//   _troç, --, --, --,
   {{0x38600044,0x6aa80297,0x63ad67a4,0x66d00523}},	//   _meir_, yddf, cvan, _fäkt,
   {{0x386000f1,0x2bb10577,0x7d0400f4,0x7b140392}},	//   _leir_, जिना, čism, nàut,
   {{0xc6930052,0xfa8e0023,0x6b898884,0xa1873f20}},	//   דאו_, _bừng_, eteg, _обра_,
   {{0x6b890cfd,0xdc1300d0,0x3860013a,0x24800c6f}},	//   fteg, _ağır, _neir_, ngim_,
   {{0xdfcf0088,0xfa8e0019,0x7e638885,0x6b898886}},	//   _پيل_, _dừng_, banp, gteg,
   {{0x7e631047,0x7b32004e,0x38600079,0x00000000}},	//   canp, _tłum, _aeir_, --,
   {{0x63ad0d77,0x6b898887,0x66d01b43,0x3860006b}},	//   zvan, ateg, _läks, _beir_,
   {{0xa3de0b4a,0x63ad06d3,0x3860001e,0x612300ab}},	//   तना_, yvan, _ceir_, põle,
   {{0x38608888,0xe7848889,0x8c43888a,0x6ec20581}},	//   _deir_, куро, _рече, लापु,
   {{0x7c225b67,0x6d47000d,0x68fd027a,0x00000000}},	//   _izor, _éjac, snsd, --,
   {{0xb8e50083,0x3860009e,0x4422040c,0x7d02659e}},	//   _এত_, _feir_, _azk_, _kjos,
   {{0x63ad201e,0xadf10ccf,0x3860888b,0x44220051}},	//   tvan, _अइसन_, _geir_, _bzk_,
   {{0x7f400176,0x4422024e,0x8cb114ab,0xa7fb1111}},	// [9390] _numq, _czk_, _अफसो, maño,
   {{0x05010033,0xa7fb1725,0x63ad0a2e,0x7d024b19}},	//   ্ষের_, laño, rvan, _ljos,
   {{0x6b8906a2,0x63ad888c,0x7e63888d,0x065600a5}},	//   zteg, svan, vanp, _איתך_,
   {{0x7e63011e,0x63ad888e,0xd479016b,0x3218099e}},	//   wanp, pvan, _צאָל, _dyry_,
   {{0x752d68d5,0xfa8e01a5,0x00000000,0x00000000}},	//   mmaz, _rừng_, --, --,
   {{0x752d0332,0xaaad0324,0xfa8e0023,0xdb1100fd}},	//   lmaz, _झोंक, _sừng_, égün,
   {{0x7e6302ee,0x7d02888f,0x00000000,0x00000000}},	//   ranp, _bjos, --, --,
   {{0x752d0448,0x00000000,0x00000000,0x00000000}},	//   nmaz, --, --, --,
   {{0x38608890,0x7e638891,0x6b8901a3,0x7d020051}},	//   _reir_, panp, uteg, _djos,
   {{0x38600159,0x5fbe193c,0x00000000,0x00000000}},	//   _seir_, ्हरल, --, --,
   {{0x6b898892,0xfa8e0028,0x7bc6008c,0x7c2201ed}},	//   steg, _từng_, økur, _ezor,
   {{0xc68935d9,0x7e618893,0x6d418894,0x23690107}},	//   _לא_, _help, _iula, ksaj_,
   {{0xbd2c0779,0x6d413e2c,0x291e0029,0x7e616d0b}},	//   _וואָ, _hula, ēta_, _kelp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38608895,0x6d418896,0xa7fb07a6,0xb87b0079}},	//   _teir_, _jula, baño, mhín,
   {{0x6d418897,0x64a3741e,0x657c08dd,0x20f80355}},	//   _mula, ласа, rurh, nčit_,
   {{0x240705d2,0x03260ece,0x6d418898,0x24808899}},	// [93a0] енти_, едан, _lula, rgim_,
   {{0xe9ff00e8,0x7d1b02c9,0x6d410f04,0xdb0b0453}},	//   _giải_, hlus, _oula, _orgí,
   {{0x7d1b889a,0x6d41889b,0x7f400095,0x365b00a5}},	//   klus, _nula, _sumq, _מכינ,
   {{0x44220124,0x00000000,0x00000000,0x00000000}},	//   _tzk_, --, --, --,
   {{0x6d410d9e,0x7e610ccb,0xdc1e0026,0x7d1b00ab}},	//   _aula, _belp, _परेड_, dlus,
   {{0x6d41889c,0x201a013a,0x6e940eb4,0xd00f16e6}},	//   _bula, āpi_, тику, حله_,
   {{0x6d41889d,0x4096889e,0x7e6102ce,0xdb0b0279}},	//   _cula, _прат, _delp, _orgâ,
   {{0x629e889f,0x6d41011e,0xf8bf006c,0x61e100ab}},	//   lepo, _dula, rmék_, _ülla,
   {{0xa2c40567,0xb09b0122,0xc0e32ad7,0x7e6188a0}},	//   राप्, _צימר, _сотк, _felp,
   {{0x7c22308b,0x6d4188a1,0x7e610159,0x7d1b023f}},	//   _vzor, _fula, _gelp, alus,
   {{0x6d4188a2,0x7c220035,0x5cd600d4,0x1e5700a5}},	//   _gula, _wzor, _підх, _נשאר_,
   {{0x66090723,0x629e2a4d,0x6d4700f8,0x00000000}},	//   şekk, hepo, _éjaa, --,
   {{0xb909021a,0x7c220a78,0x629e72d5,0x6d4188a3}},	//   _यत_, _uzor, kepo, _zula,
   {{0x629e2802,0x66d0013c,0xa2c40266,0x00000000}},	//   jepo, _säkr, राफ्, --,
   {{0x659488a4,0xa7fb88a5,0xa2c4112b,0xf5270eee}},	//   лару, paño, रान्, ефан,
   {{0x57b51172,0x6aaa2d2c,0xb87b0098,0x00000000}},	//   _абит, _haff, mhío, --,
   {{0x752d88a6,0x6aaa88a7,0x2611167e,0xd3710833}},	// [93b0] rmaz, _kaff, _दुरी_, شها_,
   {{0x23690009,0x6aaa88a8,0x629e88a9,0x752d88aa}},	//   rsaj_, _jaff, gepo, smaz,
   {{0x07360122,0x6aaa88ab,0x7d1b00e9,0x00000000}},	//   _שאתם_, _maff, ylus, --,
   {{0x6d4188ac,0x7e6188ad,0x98bd0260,0x00000000}},	//   _rula, _selp, _ouvč_, --,
   {{0x8fa588ae,0xf77f027d,0x00000000,0x00000000}},	//   тале, nuç_, --, --,
   {{0x6d4149c2,0xa3ae0ccf,0x1eea0088,0x6aaa01a8}},	//   _pula, किर_, وونی_, _naff,
   {{0xf2d2012b,0xdcfa06a8,0x7d1b0006,0x6d4100a8}},	//   _דעם_, _artı, tlus, _qula,
   {{0x6d4188af,0xdb0b0132,0x7e6109b0,0xb87b0079}},	//   _vula, _orgã, _welp, dhío,
   {{0x7d1b88b0,0x6aaa01a8,0x7e6188b1,0x6d4100d1}},	//   rlus, _baff, _telp, _wula,
   {{0x6d4188b2,0x6aaa88b3,0x7d1b88b4,0x9e67006c}},	//   _tula, _caff, slus, _سائن,
   {{0x7d1b88b5,0x8d7488b6,0x6d4108dd,0x80d50066}},	//   plus, _مانا, _uula, _दवाइ,
   {{0x629e1140,0x00000000,0x00000000,0x00000000}},	//   zepo, --, --, --,
   {{0x9cd60122,0x6aaa03bc,0xb7c00033,0x629e88b7}},	//   _שונה_, _faff, উন্ট, yepo,
   {{0x6aaa88b8,0x2cad4c19,0x63a603d0,0x00000000}},	//   _gaff, lded_, _rskn, --,
   {{0xe73788b9,0x629e88ba,0x776d002a,0x00000000}},	//   тер_, vepo, _evax, --,
   {{0xa3ae0953,0x2cad88bb,0x6aaa018e,0xa2c4022e}},	//   किल_, nded_, _zaff, राभ्,
   {{0x93436255,0xd70a0370,0x6aaa01a8,0x2cad0f00}},	// [93c0] инте, _оние_, _yaff, ided_,
   {{0xf1fa2ac4,0x8c3d1505,0x00000000,0x00000000}},	//   وعات_, leşd, --, --,
   {{0x629e88bc,0xa2c4060a,0x167700a5,0x290207df}},	//   repo, राब्, _בגיל_, onka_,
   {{0x3d0b0035,0x629e88bd,0xdcfa009f,0x29020093}},	//   हकों_, sepo, _istħ, nnka_,
   {{0x2cad88be,0x290288bf,0x776200a8,0xa06788c0}},	//   dded_, inka_, _çoxd, тача_,
   {{0xf4130122,0x63a488c1,0xc7d700a5,0xd9e11b8f}},	//   _כפר_, mwin, כוני_, खनात_,
   {{0x6aaa1cc8,0x63a488c2,0xb4db0176,0x5d63010b}},	//   _raff, lwin, _diàf, атыз,
   {{0xfd0f0037,0x4caa0033,0x3fc600b5,0x5577016b}},	//   يجي_, কাভু, _لگتی_, דעקן_,
   {{0x8fa31f9b,0x63a488c3,0xfe720372,0x24840093}},	//   _кате, nwin, _ندا_, _ömmu_,
   {{0x2902560f,0xb87b0037,0x63ab01b4,0xa3aa0354}},	//   enka_, thío, ægni, _खनन_,
   {{0x63a448b3,0xfbcf0a86,0xc27b0d85,0x6aaa325f}},	//   hwin, متی_, וריי, _vaff,
   {{0x6aaa88c4,0x63a488c5,0x3eac009f,0x81570070}},	//   _waff, kwin, _hadt_, כסטע_,
   {{0x6aaa007a,0x64430035,0xa49b0107,0x63a40051}},	//   _taff, śnik, _djòl, jwin,
   {{0x290288c6,0x00000000,0x00000000,0x00000000}},	//   anka_, --, --, --,
   {{0x63a44039,0x2d8e01f7,0x00000000,0x00000000}},	//   ewin, ntfe_, --, --,
   {{0xba370122,0xa3de00e7,0xa3ae018d,0x92af0033}},	//   _בטוח_, तनं_, किं_, _ওকে_,
   {{0x63a40298,0x3949008b,0x00000000,0x00000000}},	// [93d0] gwin, _časi_, --, --,
   {{0x24730028,0x78ad18af,0x2cad0987,0x43940674}},	//   ệm_, _haav, zded_, рафс,
   {{0x7afd0a39,0x75d50037,0x78ad00c3,0x8c3d027d}},	//   ésti, _إيجا, _kaav, leşe,
   {{0x63a488c7,0xf2df0043,0xc0ab0172,0xe0d0026e}},	//   bwin, _atât_, بائل_, يزن_,
   {{0x78ad88c8,0x747a00a5,0x7f1900d8,0xaed5093e}},	//   _maav, _אנרג, ніку_, лодш,
   {{0x753d1f11,0x3ebe88c9,0xa2c432ea,0x78ad88ca}},	//   _hisz, _cntt_, राण्, _laav,
   {{0xfc3f024e,0x753d006c,0x2902088a,0x5bdb06fe}},	//   žím_, _kisz, ynka_, यन्व,
   {{0x644d88cb,0x3ae00211,0x00000000,0x00000000}},	//   ncai, _ròpa_, --, --,
   {{0x2cad88cc,0x09cb012f,0x753d0d7f,0x261a00b4}},	//   rded_, ाह्य, _misz, _मुनी_,
   {{0x628588cd,0x753d88ce,0xfff60416,0x00000000}},	//   ngho, _lisz, _حکمت_, --,
   {{0xa2c40b35,0x644f88cf,0x5dd5126b,0x63a43c84}},	//   रात्, _ofci, _حقائ, zwin,
   {{0x2902005f,0x63a4334c,0x78ad01ef,0xdce700ea}},	//   unka_, ywin, _caav, ēlēj,
   {{0x8cc00035,0x78ad88d0,0x00000000,0x00000000}},	//   वारो, _daav, --, --,
   {{0x99d5186e,0xf7430a80,0x00000000,0x00000000}},	//   _متبا, серо, --, --,
   {{0x63a40088,0x62850207,0x00000000,0x00000000}},	//   wwin, dgho, --, --,
   {{0x03a632a6,0x30ae0033,0xd5b700e2,0x753d5cc9}},	//   либо, _কক্স, ứng_, _cisz,
   {{0x753d88d1,0x63a401e4,0x7981018e,0x68e488d2}},	// [93e0] _disz, uwin, lulw, _ilid,
   {{0x63a40b3c,0x644d148f,0xa2c43010,0x33d501e0}},	//   rwin, acai, राध्, шіст,
   {{0x63a47aa2,0x394f0043,0xccf9004e,0x68e400b8}},	//   swin, _însă_, kiś_, _klid,
   {{0x63a41003,0x74550133,0x600a00d8,0x6aa14289}},	//   pwin, _върх, ннем_, helf,
   {{0x6aa16028,0xa2c40ed1,0x673e0051,0x41a41e82}},	//   kelf, राद्, _kipj, _गैरस,
   {{0x798188d3,0x71660037,0xe1660037,0x765c88d4}},	//   kulw, _مارك, _مدري, nbry,
   {{0x7d0d308b,0x91e688d5,0x68e488d6,0x8cc00067}},	//   časn, _сове, _olid, वालो,
   {{0x5ba688d7,0x7981023c,0x673e0201,0x00000000}},	//   гроз, dulw, _lipj, --,
   {{0x09dc00a1,0x16160456,0xc0061fb1,0x28af0380}},	//   मन्य, _दुसर_, _спак, _जोगि,
   {{0x78ad2efa,0xbda600bf,0x68e488d8,0x6b80038e}},	//   _saav, _محصو, _alid, rumg,
   {{0x527b02b5,0x78ad005b,0xc27b0070,0x6c862489}},	//   ענטא, _paav, ערטי, _ملام,
   {{0x27e688d9,0x28af00c0,0x8c46097c,0x00000000}},	//   _żona_, _जोखि, _седе, --,
   {{0x6aa188da,0x78ad4fd1,0x00000000,0x00000000}},	//   belf, _vaav, --, --,
   {{0x79a600af,0x78ad0103,0x6d580051,0x9f4b0044}},	//   _брие, _waav, opva, _åmås_,
   {{0x753d2510,0x78ad1b43,0x7afa88db,0x941f0095}},	//   _pisz, _taav, mitt, ərən_,
   {{0x7afa0f9e,0x54550acb,0x290320ec,0x69da88dc}},	//   litt, рват, čkas_, myte,
   {{0x753d0332,0x644d066a,0xe02000be,0xdcfa013a}},	// [93f0] _visz, rcai, _बरगद_, _aptī,
   {{0x7afa88dd,0x644d88de,0x657a0079,0x320b08ce}},	//   nitt, scai, áthc, нхен_,
   {{0x753d0332,0x628588df,0x7afa0159,0x69da88e0}},	//   _tisz, rgho, iitt, nyte,
   {{0x7afa0086,0x6aa10a75,0xf8bf000d,0x00000000}},	//   hitt, zelf, mmés_, --,
   {{0x087802b5,0x7afa88e1,0xddd000b8,0x2b460023}},	//   רעדט_, kitt, _češt, _nuoc_,
   {{0x7afa0421,0xd9f609b1,0x6aa188e2,0x60c00260}},	//   jitt, ुपात_, xelf, _enmm,
   {{0x249900d7,0x7afa88e3,0x6aa10a8c,0x00000000}},	//   _kbsm_, ditt, velf, --,
   {{0xeb995963,0x69da2c17,0x26d301ef,0x29090054}},	//   вии_, dyte, _loxo_, _njaa_,
   {{0xacc6081b,0x7981001c,0xa7fb88e4,0x2b460023}},	//   ргыз_, wulw, bañi, _cuoc_,
   {{0x7afa88e5,0x2b460019,0x68e40f00,0x26d301ef}},	//   gitt, _duoc_, _slid, _noxo_,
   {{0x68e40107,0x8a3800c3,0xdeba0319,0x98a9009f}},	//   _plid, ляют_, _שמעל, _ghaċ_,
   {{0x3c470082,0x6aa10626,0xab9500d4,0xa49b0260}},	//   _إضاف, self, _виді, _djòk,
   {{0x7d0488e6,0x39493e39,0xf74600aa,0x81bd0033}},	//   čist, _času_, рего, েনি_,
   {{0x69da88e7,0x7afa2afb,0xaa88004f,0x26d301ef}},	//   byte, citt, _منهم_, _coxo_,
   {{0xa2c46a9c,0x765c029e,0x69da88e8,0x7bdb081b}},	//   रास्, rbry, cyte, lyuu,
   {{0x81bd0083,0x2caf3109,0x68e488e9,0x00000000}},	//   েনা_, _jagd_, _ulid, --,

   {{0x394700d7,0x26d35b75,0x626603e6,0x9e3c0260}},	// [9400] _huns_, _foxo_, иваа, _haďt,
   {{0x42560af5,0x3947053e,0x26d301b7,0x28c40808}},	//   ртат, _kuns_, _goxo_, षावि,
   {{0x506688ea,0xc6930122,0x867b02b5,0x200d0814}},	//   атла, _ואת_, _בריו, _axei_,
   {{0xa2c400b4,0xe7b3064e,0x7afa88eb,0xdc3400a0}},	//   राह्, _امید, zitt, _súči,
   {{0x442488ec,0x394701dd,0x39400553,0x613a007e}},	//   _ám_, _luns_, _miis_, _hůlk,
   {{0xa2e60086,0xdd9a2497,0x394000ab,0xf2df0023}},	//   _тогд, вши_, _liis_, _huân_,
   {{0x394788ed,0xf8bf0248,0x7afa1131,0xa3ae0e61}},	//   _nuns_, llée_, vitt, किक_,
   {{0x7afa88ee,0x3d1000ab,0xa2c40099,0x00000000}},	//   witt, ावें_, राव्, --,
   {{0x7afa88ef,0x2b460019,0x64400132,0x807b00a5}},	//   titt, _quoc_, _úmid, _שנמצ,
   {{0x39472b28,0x1eaa2604,0xf2d302b5,0xf2df0019}},	//   _buns_, _جاري_, ַער_, _luân_,
   {{0x7afa88f0,0x6f180393,0x394701dd,0x26d32314}},	//   ritt, movc, _cuns_, _roxo_,
   {{0x7afa3a80,0x6f1811d7,0x394931e1,0x39470391}},	//   sitt, lovc, _čast_, _duns_,
   {{0xcb5403c7,0x6d4888f1,0x7afa0d13,0x69da29d6}},	//   _انتظ, _huda, pitt, syte,
   {{0x6d48408b,0x6f180912,0x3ce6006d,0xd7f841e4}},	//   _kuda, novc, _hlov_, рую_,
   {{0x26110084,0x9984004f,0x69da01f4,0x04675915}},	//   _दुखी_, _العو, qyte, итам,
   {{0x6d4888f2,0x657a0037,0xdb0b01ae,0xf8bf88f3}},	//   _muda, átha, _ergä, rmés_,
   {{0x213f046a,0x6d4888f4,0x26d301ef,0xf8bf00a2}},	// [9410] _riuh_, _luda, _toxo_, glée_,
   {{0xa2c40c67,0x29195f9e,0xddc30043,0x212d01f4}},	//   राष्, losa_, nanţ, _sheh_,
   {{0x6f180a69,0x6d4888f5,0x3ce6017b,0x80c30099}},	//   dovc, _nuda, _olov_, ळाले,
   {{0x68fd88f6,0xf8bf00f7,0x112800d4,0x3d100067}},	//   nisd, blée_, аючи_, ावों_,
   {{0x386988f7,0x2d9e88f8,0xa2c41ad0,0x7e680051}},	//   _mear_, _apte_, राश्, _bedp,
   {{0x6d4888f9,0xef1801c8,0x6f1802dd,0x38690037}},	//   _buda, амі_, govc, _lear_,
   {{0x29196a5b,0xa2c40ed1,0x6d4888cf,0x68fd008e}},	//   kosa_, रार्, _cuda, kisd,
   {{0x6d4888fa,0xf2df0028,0x248988fb,0xc10511cf}},	//   _duda, _xuân_, ngam_, _اوري,
   {{0x39404dc7,0x6f1800f4,0x6d4888fc,0x68fd0be2}},	//   _riis_, bovc, _euda, disd,
   {{0x3940136d,0x76450297,0xf3ff0279,0xcac91397}},	//   _siis_, _nghy, _leão_, угое_,
   {{0x291901f7,0x186a0227,0x386988fd,0x3ce60b3e}},	//   fosa_, лани_, _bear_, _flov_,
   {{0xcd960122,0xa3e70026,0x386988fe,0x00000000}},	//   _לדעת_, बना_, _cear_, --,
   {{0xe8f788ff,0x3940007c,0x38698900,0x2a670260}},	//   сля_, _viis_, _dear_, _tenb_,
   {{0x7c2b01cc,0xdc3602b5,0xddc3002d,0x6d483540}},	//   _izgr, _פאסט_, canţ, _yuda,
   {{0x29198901,0x39408902,0x442b0051,0x38698903}},	//   bosa_, _tiis_, _azc_, _fear_,
   {{0x39918904,0x29198905,0xf2df0028,0x6f1800ac}},	//   más_, cosa_, _quân_, zovc,
   {{0x399100f5,0xe29a0132,0xa3ab19b7,0x2fdd01e8}},	// [9420] lás_, лаа_, _कैद_, jywg_,
   {{0x16aa265e,0x2489542c,0x78a68906,0x7b1d0392}},	//   _свои_, agam_, lekv, cèut,
   {{0x38698907,0xe29720cc,0x39918908,0xf2df0023}},	//   _year_, сах_, nás_, _tuân_,
   {{0x6d488909,0x4fea0384,0x3d210035,0x2d9e02d7}},	//   _ruda, лмен_, मतों_, _rpte_,
   {{0xdefa1385,0x6d48890a,0x351b0052,0x6446011e}},	//   лык_, _suda, _תוכנ, _igki,
   {{0x6d483f8b,0x3ce6024e,0x7524890b,0x3991006c}},	//   _puda, _slov_, lliz, kás_,
   {{0x6f1802b2,0xfe6f1062,0x629c890c,0x42e70274}},	//   rovc, ردو_, _ibro, _умро_,
   {{0x44220626,0x39910332,0x6f1813a2,0xcb5403fa}},	//   _kyk_, dás_, sovc, овић,
   {{0x29196016,0xa3ae020d,0xddc3002d,0x75241db8}},	//   vosa_, किट_, tanţ, iliz,
   {{0x6d48890d,0x38690284,0x442208d7,0x41dc0afa}},	//   _tuda, _sear_, _myk_, _यथास,
   {{0x629c01d2,0x44220626,0xddc3002d,0x399100b5}},	//   _mbro, _lyk_, ranţ, gás_,
   {{0x23c80026,0x7aef0443,0x3ce6890e,0x7afd0138}},	//   रमाद, èctr, _ulov_, éstr,
   {{0x3f8634bb,0xb7b90083,0x657a0037,0x4422051a}},	//   nuou_, ুন্ট, áthn, _nyk_,
   {{0x68fd890f,0x399100b5,0x2919145d,0x6f040098}},	//   sisd, bás_, sosa_, éich,
   {{0x75240036,0x1dbd2874,0x7c2200e2,0xf3ff0132}},	//   fliz, ्मयत, _hyor, _peão_,
   {{0xddc30029,0x24890029,0xa3b50026,0x75242318}},	//   nanš, ugam_, झिल_, gliz,
   {{0x24898910,0x629c009e,0x6d420395,0x284a016b}},	// [9430] rgam_, _bbro, _mioa, _דעפּ,
   {{0x75248911,0x44228912,0x33740144,0xdb090637}},	//   aliz, _dyk_, ягур, rveç,
   {{0x75248913,0x1a9b02b5,0x96030083,0x66d00086}},	//   bliz, ריבע, _এরকম_, _näky,
   {{0x63ae0421,0x629c0065,0x7c220103,0x00000000}},	//   ännä, _ebro, _oyor, --,
   {{0x39910332,0x7c220053,0x7f498914,0xe0d0028f}},	//   zás_, _nyor, _queq, عزم_,
   {{0x8d551285,0xb87b8095,0x00000000,0x00000000}},	//   отич, chív, --, --,
   {{0x6d428915,0xed590086,0x39910015,0x7c2286f0}},	//   _bioa, шой_, xás_, _ayor,
   {{0x7cfe26e3,0x629c3b5e,0x63bd011c,0x7c2201d5}},	//   tūra, _zbro, _krsn, _byor,
   {{0x69dc177c,0xe0e400d8,0x6d4e171c,0x63bb00cd}},	//   øren, _эўро, _éban, _šunj,
   {{0x39918916,0x7c220430,0x0b160037,0x7aa5135b}},	//   tás_, _dyor, يقية_, циоз,
   {{0x3ea78917,0xa96903fa,0x7524088a,0xdb020310}},	//   ment_, јима_, yliz, _proò,
   {{0x2d878918,0x3ea00254,0x7c22012f,0x6d428919}},	//   mune_, đite_, _fyor, _gioa,
   {{0x7d1b891a,0x7c22006c,0x7d240086,0x7d09891b}},	//   mous, _gyor, _эффе, mnes,
   {{0x4422053e,0x2d8700f6,0x3991891c,0x7d09891d}},	//   _ryk_, oune_, pás_, lnes,
   {{0x3ea702e1,0xba390070,0x7d09891e,0x2d8704bd}},	//   ient_, _דײַט, ones, nune_,
   {{0x7d1b891f,0xe45a015c,0x3ea78920,0x39584193}},	//   nous, ржа_, hent_, írse_,
   {{0x3ea78921,0x75248922,0x2d871b22,0x7d098923}},	// [9440] kent_, rliz, hune_, ines,
   {{0x3ea78924,0x2d878925,0x75242dea,0x63bd156f}},	//   jent_, kune_, sliz, _drsn,
   {{0x3ea78926,0x2d878927,0x7d098928,0x7d1b8929}},	//   dent_, june_, knes, kous,
   {{0xa99a02b5,0x3f860b9f,0x7d09892a,0x2d87892b}},	//   יבער, tuou_, jnes, dune_,
   {{0x7d1b0391,0xbba83893,0x7d094c19,0xdb0b0176}},	//   dous, _कनेक, dnes, _esgé,
   {{0x3ea715f9,0x629c892c,0x7d09892d,0x1c1d007c}},	//   gent_, _ubro, enes, _पड़ल_,
   {{0xe8010035,0x2d87892e,0x7c2200d7,0xf98703c7}},	//   _लेना_, gune_, _syor, _تب_,
   {{0x7d1b01dd,0x00000000,0x00000000,0x00000000}},	//   gous, --, --, --,
   {{0x3ea7892f,0xe7a90035,0xcb0a0a80,0x81bd0033}},	//   bent_, _चैंप, иход_, েনঃ_,
   {{0x3ea78930,0x2126022e,0x7d098931,0x63bb1e85}},	//   cent_, lloh_, anes, _šunk,
   {{0x2d878932,0x7d1b8933,0x6e9300d1,0x395811ad}},	//   cune_, bous, _آلما, ërs_,
   {{0x7d1b0391,0xeb9a1578,0x6d5a1812,0x6ec2018d}},	//   cous, _вид_, _itta, लाकु,
   {{0x776200a8,0x5ead0033,0x8c3d0225,0x7c220027}},	//   _çoxl, চারে, neşl, _uyor,
   {{0x3f500028,0x613102df,0x7d008934,0xb33b021d}},	//   _màu_, måle, lims, _opça,
   {{0xd5b80b46,0xfc3f01c0,0xee2e2327,0x00000000}},	//   ост_, žít_, ннi_, --,
   {{0x3ea78935,0x63bd3a01,0x7d000644,0x6aa8099e}},	//   zent_, _prsn, nims, ledf,
   {{0x96470409,0x4394052c,0x2d870065,0x3ea78936}},	// [9450] _мэнд, матс, zune_, yent_,
   {{0x7d098937,0x6d5a8938,0x7d1b0391,0x7d0d016f}},	//   znes, _otta, zous, časi,
   {{0x3ea720ac,0x7d008939,0x6d5a0103,0x00000000}},	//   vent_, kims, _ntta, --,
   {{0x76550035,0x3ea7101b,0x2d87893a,0x3f5000e2}},	//   lczy, went_, vune_, _bàu_,
   {{0x6d5a38c9,0x7d1b893b,0x3ea73ec3,0x8cce0035}},	//   _atta, vous, tent_, थानो,
   {{0x643a00c2,0x63ad6376,0x2d87893c,0x5187021d}},	//   _לערנ, mwan, tune_, _муба,
   {{0x63ad0273,0x3ea74805,0x7d1b0391,0x69dc0c71}},	//   lwan, rent_, tous, ørel,
   {{0x2d87893d,0x3ea7893e,0x7aea0f52,0x7d094a6d}},	//   rune_, sent_, _alft, unes,
   {{0xff5302de,0x7d1b893f,0x6d5a0273,0x63ad8940}},	//   _آخر_, rous, _etta, nwan,
   {{0x2d870d45,0x63a0022a,0xdd000080,0x7d098941}},	//   pune_, _ämne, ētāj, snes,
   {{0x63ad8942,0x7d1b8943,0x4990006c,0x3a25051a}},	//   hwan, pous, نیور, ямог,
   {{0x63ad25b6,0x7aea8944,0x8c3d027d,0x76550067}},	//   kwan, _elft, leşm, eczy,
   {{0x7cee009e,0xb4db0211,0xdb02008d,0x00000000}},	//   _dùrd, _piàn, _troð, --,
   {{0x63ad1a25,0x79880103,0x290b8945,0xcc3a016b}},	//   dwan, budw, anca_, _פעסט,
   {{0x1dbd05f7,0xd62a8946,0x63ad0067,0x09e50409}},	//   ्मित, сове_, ewan, _хойн,
   {{0xf8bf01f7,0x63ad033b,0x00000000,0x00000000}},	//   llén_, fwan, --, --,
   {{0x63ad0273,0x03a3386a,0x00000000,0x00000000}},	// [9460] gwan, нито, --, --,
   {{0x1dbd0026,0x78b601d6,0xb87b0037,0x00000000}},	//   ्मात, _hayv, bhís, --,
   {{0xb87b0831,0x5ba80026,0x78b600d7,0x00000000}},	//   chís, _कन्व, _kayv, --,
   {{0x29028947,0x63ad25b6,0x5a0c0070,0x26da8948}},	//   nika_, bwan, סלאַ, _hopo_,
   {{0x6b890033,0x21268949,0x63ad073a,0x9f5300d8}},	//   jueg, rloh_, cwan, евіч,
   {{0x7cfe00d8,0x26da894a,0x21260009,0x8c3d0381}},	//   tūro, _jopo_, sloh_, reşl,
   {{0x2902894b,0x7d00894c,0x26da0421,0x00000000}},	//   kika_, tims, _mopo_, --,
   {{0xe0550357,0x3f5001a5,0xa2c40e9b,0x2902894d}},	//   _قیمت_, _tàu_, राक्, jika_,
   {{0x29020a12,0xddc12b6c,0x7d00894e,0x3f6701d3}},	//   dika_, _velš, rims, _нито_,
   {{0x26da01cb,0xddc90160,0x00000000,0x00000000}},	//   _nopo_, _înşa, --, --,
   {{0x2902894f,0x6d5a1d2f,0xfbcf0df3,0xbc6a00d1}},	//   fika_, _utta, نتی_, _همان_,
   {{0x63ad004e,0x6aa8009e,0x76550035,0x00000000}},	//   ywan, sedf, wczy, --,
   {{0xb4db0443,0x26da0118,0x69dc02ee,0x612300be}},	//   _diàl, _bopo_, äreb, põlv,
   {{0xa3c20026,0x26da2cd6,0xa3c00127,0x00000000}},	//   ्मन_, _copo_, ंटन_, --,
   {{0xcb1300c2,0x26da0133,0x290283c5,0x6a9b0122}},	//   _אלס_, _dopo_, bika_, _השונ,
   {{0xe81e0e6f,0x63ad8950,0x29021941,0xa4d400d8}},	//   _युवा_, twan, cika_, носі,
   {{0xa87c0052,0x68ed01ed,0x316a02a2,0x2bb10066}},	// [9470] _האחר, _ilad, _awbz_, ड़िया,
   {{0x63ad8951,0x68ed2190,0x6eef0022,0xa2c409b1}},	//   rwan, _hlad, _købe, राग्,
   {{0x68ed0097,0x63ad8952,0x9b1700a5,0xe80108a9}},	//   _klad, swan, לחמה_, _लेता_,
   {{0xf1c000e8,0x63ad0fc2,0x93c70139,0x6eef0249}},	//   ương_, pwan, _arăţ, _møbe,
   {{0x68ed0936,0x6eef054e,0x93c70139,0xa2c4112b}},	//   _mlad, _løbe, _brăţ, राख्,
   {{0x6da508ae,0x68ed46a3,0x10140ef2,0xad5901e0}},	//   дика, _llad, ربند, орих_,
   {{0xfe7001ca,0x290225b6,0xdd91006c,0x6ec222a7}},	//   اده_, yika_, ڑوں_, लाजु,
   {{0x29021a47,0x2a7c021d,0xa0c50118,0x00000000}},	//   xika_, _advb_, _تيرو, --,
   {{0x29028953,0x1dbd05f7,0x394e033b,0x2d8a01b4}},	//   vika_, ्महत, _aufs_, _åben_,
   {{0x6b89002a,0xa91d01ba,0xe57800ea,0x29028954}},	//   rueg, buľk, šķi_, wika_,
   {{0x29028955,0x68ed2d2e,0x60db0c1f,0x6f0301d3}},	//   tika_, _blad, _koum, minc,
   {{0x68ed8956,0x6f038957,0x26da00d1,0x394e008c}},	//   _clad, linc, _sopo_, _dufs_,
   {{0x29028958,0x26da00f8,0x6b891f51,0x60db8959}},	//   rika_, _popo_, queg, _moum,
   {{0x2902895a,0x68ed895b,0x6f03895c,0xb4db0392}},	//   sika_, _elad, ninc, _diàm,
   {{0xceb21759,0xf7432e87,0x60c90292,0x2902895d}},	//   כים_, теро, _onem, pika_,
   {{0x60db895e,0x60c9001c,0xa3ea0279,0x00000000}},	//   _noum, _nnem, одба_, --,
   {{0x26da0370,0x6f03895f,0x291201d5,0xa5070949}},	// [9480] _topo_, kinc, _ijya_, фета_,
   {{0x6f03336f,0x26da027a,0x6f0d0098,0x00000000}},	//   jinc, _uopo_, éacl, --,
   {{0x6f030d5c,0x2b4774c4,0xe45f0523,0x00000000}},	//   dinc, _minc_, _knöl_, --,
   {{0x61e30c61,0x2b47001e,0x23600120,0x00000000}},	//   ønla, _linc_, ppij_, --,
   {{0x4f570e6b,0x6f030382,0x60db8960,0x00000000}},	//   وجود_, finc, _doum, --,
   {{0x93461958,0x6f038961,0x60c98962,0xa3c20e11}},	//   _інве, ginc, _enem, ्मठ_,
   {{0x1ea9004f,0x409652e6,0x290000c3,0x6da300ed}},	//   ثاني_, _орат, _omia_, вија,
   {{0x629e0afc,0x60db02e9,0x2d8001ba,0x2a7c0051}},	//   lfpo, _goum, čie_, _sdvb_,
   {{0x6f038963,0xbf1601cb,0x2aaa3534,0x2b470090}},	//   binc, _قورب, отно_, _binc_,
   {{0x68ed13a6,0x2b4712c3,0x29120010,0xddc603fa}},	//   _slad, _cinc_, _ajya_, _обзи,
   {{0x6d5e114d,0x68ed054e,0xe895010b,0x2b47013b}},	//   ípad, _plad, нань, _dinc_,
   {{0x80e00083,0x63a611ad,0x2a690207,0x00000000}},	//   পোর্, _opkn, _đabe_, --,
   {{0x68ed2648,0x59b01556,0x995700ac,0xc7b8010b}},	//   _vlad, _जनवर, _váše_, мёр_,
   {{0x68ed8964,0x7bc20027,0x00000000,0x00000000}},	//   _wlad, _irou, --, --,
   {{0x442d39ea,0x6594004b,0x7bc2007e,0x3f8600ac}},	//   _še_, кару, _hrou, hrou_,
   {{0x39980b8f,0x7bc20355,0x6f038965,0x6ab80b3e}},	//   més_, _krou, zinc, _havf,
   {{0x39988966,0xe6678967,0x60db8968,0x6f03033e}},	// [9490] lés_, _отно, _roum, yinc,
   {{0x60db8969,0x35b5896a,0x60c9896b,0x3f86896c}},	//   _soum, _збор, _snem, drou_,
   {{0x6f03896d,0x3998896e,0x394930bc,0xa2c40518}},	//   vinc, nés_, _kias_, राज्,
   {{0x30152ce2,0x4f95002d,0x6ab8023a,0x6f036402}},	//   ндер, ерку, _lavf, winc,
   {{0x3949896f,0x3f8634bb,0x39980248,0xdbd603a6}},	//   _mias_, grou_, hés_, _jääm,
   {{0x39490221,0x399800b5,0x8ca1162b,0x00000000}},	//   _lias_, kés_, क्नो, --,
   {{0x6f03027b,0x7bc20122,0xada52626,0x60db8970}},	//   rinc, _arou, хайл, _toum,
   {{0x62348971,0x6f038972,0x39988973,0x3949006f}},	//   _ресу, sinc, dés_, _nias_,
   {{0x6f038974,0xa2c400a1,0x0c25002d,0xe0d20070}},	//   pinc, राच्, эмин, _גײן_,
   {{0xa3c20433,0x39988975,0x301400af,0x394900be}},	//   ्मत_, fés_, _рдур, _aias_,
   {{0x394949bf,0x39988976,0x7bc20395,0x5c930043}},	//   _bias_, gés_, _erou, _алеӂ,
   {{0xf8bf0076,0x39498977,0xa3df046c,0x00000000}},	//   blém_, _cias_, तहा_, --,
   {{0x39498978,0x7bc2472b,0x2b4712c3,0x2cad0553}},	//   _dias_, _grou, _tinc_, meed_,
   {{0xfbd00332,0x2cad8979,0x3998897a,0x00000000}},	//   _ختم_, leed_, bés_, --,
   {{0x35a30036,0x39980955,0x64a624da,0x18a61142}},	//   ларг, cés_, нава, _займ,
   {{0x2d8709c3,0x290001ef,0x291201d5,0x69c3035f}},	//   irne_, _umia_, _ujya_, _irne,
   {{0xccf202b5,0x6b9b897b,0x81dd0033,0x78a401d5}},	// [94a0] אכן_, ntug, _তেল_, _ibiv,
   {{0x22166804,0x2cad09b3,0x39490221,0x3f8603bc}},	//   нфер, heed_, _zias_, vrou_,
   {{0x39490221,0x69c30069,0xd01200b5,0x2cad0553}},	//   _yias_, _jrne, گلش_, keed_,
   {{0x3f86897c,0x705300bf,0xa3c20162,0x394901e8}},	//   trou_, هنما, ्मद_, _xias_,
   {{0x39980332,0x2d87897d,0x3f863762,0x2cad00a5}},	//   zés_, erne_, urou_, deed_,
   {{0x39980248,0x7bc400d8,0x3f86897e,0x61313ee4}},	//   yés_, _šiuo, rrou_, råla,
   {{0xf98707f8,0xc69302b5,0xa2cd00a9,0x399815f9}},	//   _حب_, טאג_, सार्, xés_,
   {{0x13e40083,0xc19b0d85,0x7cee009e,0x6146002d}},	//   _নেয়, _משלי, _bùra, _чеба,
   {{0xa3c2030f,0xdccf0028,0x02e40084,0x6b9b2487}},	//   ्मि_, _tỉnh_, _गवाह_, gtug,
   {{0x3998897f,0x7bc206ba,0x39490409,0x78a43c22}},	//   tés_, _vrou, _sias_, _abiv,
   {{0x0d868980,0x39498981,0x6aba011e,0xfaa3004b}},	//   _член, _pias_, rdtf, ушын,
   {{0x39988982,0xa3c2035d,0x7bc28983,0xfc64064e}},	//   rés_, ्मा_, _trou, _شخصی,
   {{0x39984cb2,0x39498984,0x69c38985,0x81d60033}},	//   sés_, _vias_, _erne, িনি_,
   {{0x39988986,0x8c438987,0x78a4018e,0x00000000}},	//   pés_, _сече, _ebiv, --,
   {{0x39490d4b,0x628327c2,0x2d9c00b5,0x7cf500ee}},	//   _tias_, ónom, ntve_, _dárf,
   {{0x81d60083,0x3eae29c2,0x612a008d,0x00000000}},	//   িনা_, heft_, býli, --,
   {{0x47350336,0x69c30116,0x00000000,0x00000000}},	// [94b0] _инис, _zrne, --, --,
   {{0x78bd54b2,0x78a40254,0xd5bb0279,0x249200f6}},	//   ldsv, _zbiv, _есм_, agym_,
   {{0x7d028988,0x2d8e021d,0x00000000,0x00000000}},	//   _omos, jufe_, --, --,
   {{0x823402aa,0x78bd785d,0xd47902b5,0x62950035}},	//   اركا, ndsv, _קאָל, _wczo,
   {{0xe9ff0023,0x752d8989,0x44760070,0x7d0700e0}},	//   _khải_, mlaz, _בערל_, _lèrè,
   {{0x752d898a,0x7d02898b,0x7cee009e,0x00000000}},	//   llaz, _amos, _rùra, --,
   {{0x6234898c,0x2cad00be,0x752d01b7,0x00000000}},	//   _беру, teed_, olaz, --,
   {{0x26fe0026,0x6b9b898d,0x7cf50453,0x06ad0033}},	//   _उग्र_, ttug, _márg, খাটি,
   {{0x2cad898e,0x69dc1171,0x78af00af,0xe8011ef5}},	//   reed_, ären, decv, _लेला_,
   {{0x6b9b898f,0x752d06fe,0x2cad40d5,0x7d070118}},	//   rtug, hlaz, seed_, _bèrè,
   {{0x3f8f8990,0x2d9c00a0,0x7cee009e,0x3ea1018d}},	//   lugu_, ctve_, _iùrn, õhtu_,
   {{0xa3d1000c,0xf1b20070,0x7d0701cb,0x69c308b7}},	//   वमा_, בסט_, _dèrè, _vrne,
   {{0x752d29e7,0x79880223,0x442b594d,0x907a32e3}},	//   dlaz, ardw, _nyc_, וטרי,
   {{0x6d4b8991,0x6f0d0037,0x6b898992,0xe9ff00e2}},	//   _higa, éach, mreg, _chải_,
   {{0x3f8f070b,0x6d4b1548,0x6b898993,0x752d83d5}},	//   hugu_, _kiga, lreg, flaz,
   {{0x7cfe123c,0x3f8f018e,0x752d3d14,0x442b0035}},	//   tūri, kugu_, glaz, _byc_,
   {{0x6d4b8994,0x69c145cd,0x442b542c,0x03268995}},	// [94c0] _miga, lvle, _cyc_, вдан,
   {{0x6d4b4f40,0x394a024e,0x3f8f8996,0x03a3182f}},	//   _liga, _časy_, dugu_, рифо,
   {{0xe2972918,0x752d598f,0x6d4b79e3,0x7cf501ef}},	//   тах_, blaz, _oiga, _gárg,
   {{0x6b898997,0x55770070,0xf8b20035,0x6d4b8998}},	//   kreg, _בעטן_, ज़िय, _niga,
   {{0xa8570122,0x3f8f53a0,0x602300c3,0x4f96021d}},	//   דינה_, gugu_, адца, треу,
   {{0x6b898999,0xa3ab00dc,0x57fb00a5,0x6d4b899a}},	//   dreg, _कैट_, ולנו, _aiga,
   {{0x6d4b899b,0x6b8955e4,0x7bc0006d,0xe29732dd}},	//   _biga, ereg, wvmu, _шар_,
   {{0x6d4b899c,0x2d8e033b,0x69ab111a,0x7c2b03d0}},	//   _ciga, rufe_, _जनजी, _bygr,
   {{0x6b89899d,0x6d4b1034,0x28d606bc,0x7cee009e}},	//   greg, _diga, धानि, _fùrn,
   {{0x613106d7,0x28a507df,0x6d4b1cfd,0x6ef4009e}},	//   håll, ग्नि, _eiga, _bàbe,
   {{0xa2c302cb,0x6d4b899e,0x752401a3,0xddda00b5}},	//   रयत्, _figa, koiz, _tető,
   {{0x6d4b03be,0x6b89899f,0x7cf51725,0x3ea900cb}},	//   _giga, breg, _cárd, đate_,
   {{0xe9ff00e8,0x0eb600a1,0x78bd0c60,0xfbb6112b}},	//   _phải_, _आघाड, rdsv, _अनिम,
   {{0x6d4b89a0,0x6eef08c8,0x7d0723e2,0x00000000}},	//   _ziga, _løbn, _tèrè, --,
   {{0x09e31a31,0x27ed0121,0x6ea40931,0x35e400d8}},	//   _војн, šen_, च्यु, ацтв,
   {{0x6d4b01dd,0x6d4e00f7,0xc9831e47,0xfbb625d8}},	//   _xiga, _ébau, _туши, _अनाम,
   {{0xe9ff0019,0x6d400eb1,0x00000000,0x00000000}},	// [94d0] _thải_, imma, --, --,
   {{0x7cf5006c,0x752d89a1,0x7bdf0279,0x8c3d002d}},	//   _tárg, slaz, _àque, meşt,
   {{0x2ca60478,0x224700a6,0x2d5800f7,0x8c3d23ee}},	//   _obod_, änk_, _née_, leşt,
   {{0x3f8f89a2,0xf8bf0248,0x6b890a8a,0x442b00fe}},	//   tugu_, ndé_, yreg, _tyc_,
   {{0x6d4b89a3,0x708400c7,0x8c3d566e,0x8fa510bb}},	//   _riga, ргіз, neşt, уале,
   {{0x3f8f89a4,0x6d4b89a5,0x539a02b8,0x7e780029}},	//   rugu_, _siga, _אישו, gavp,
   {{0x6b890051,0x6d4b89a6,0x3f8f53e6,0xdcef0207}},	//   wreg, _piga, sugu_, _žeđa,
   {{0x24997447,0x7cee0211,0x34e1175f,0xa3b204aa}},	//   _jcsm_, _dùro, _नवोद, _झैँ_,
   {{0x6d4b89a7,0x1b49265e,0x74c50033,0x7bcd0228}},	//   _viga, нзии_, _একাউ, _šaub,
   {{0x6b8989a8,0xe9d90202,0x6d4b00d1,0x6d4000c3}},	//   rreg, еко_, _wiga, amma,
   {{0x6d4b89a9,0x7c2b004e,0x61380355,0x7524023c}},	//   _tiga, _wygr, síle, yoiz,
   {{0x6b89130f,0x69c189aa,0x00000000,0x00000000}},	//   preg, rvle, --, --,
   {{0x7d0989ab,0xae071e79,0xfbd00312,0xfaa54c1c}},	//   mies, _वेतन_, _وته_, _бало,
   {{0x2499011e,0x2cbf00ab,0x7cf50355,0x3f590176}},	//   _acsm_, ldud_, _dáre, _mèu_,
   {{0xe73701d3,0x752489ac,0x940e013b,0x00000000}},	//   уер_, toiz, əfə_, --,
   {{0x7d0989ad,0xa3c002e4,0xf9920070,0x2cbf00ab}},	//   nies, ंटल_, _הרה_, ndud_,
   {{0x42ca0036,0x4ab700a1,0x752489ae,0x8c3d00af}},	// [94e0] нган_, _असाव, roiz, ceşt,
   {{0xe29789af,0x2cbd0221,0x7d0989b0,0x7bc4010b}},	//   лау_, _lawd_, hies, _šiuk,
   {{0xea7602b5,0x869b0100,0x7d0989b1,0xdb09002a}},	//   רגער_, _אייז, kies, nveñ,
   {{0x2cbd01e8,0x25ba0009,0x3ced006f,0x6ae0000c}},	//   _nawd_, _ispl_, jkev_, _पक्र,
   {{0x7d0989b2,0xdee674e8,0xe61202fd,0xddcf07e7}},	//   dies, лоди, _خشک_, _češe,
   {{0x2d800080,0x3f590176,0x8ca100b4,0x7cf50098}},	//   ņiem_, _dèu_, क्सो, _nárb,
   {{0x7d0989b3,0xc6930397,0x7d1c89b4,0xd1320037}},	//   fies, צאה_, _írsk, _همس_,
   {{0x7d0989b5,0x3ced006d,0x6d4016b1,0xc5f300a5}},	//   gies, gkev_, umma, מדו_,
   {{0x4e960514,0x7cf57397,0x6d5812d9,0x2126022e}},	//   _مشار, _bárb, sqva, mooh_,
   {{0x8c3d002d,0x386000ee,0x539b016b,0x63b60298}},	//   veşt, _afir_, עסיא, iwyn,
   {{0x7d0989b6,0x28f989b7,0x6eef035b,0x39153b6e}},	//   bies, вень_, _møbl, имор,
   {{0x8c3d0043,0x2ca689b8,0x3ebe00d4,0x7d0989b9}},	//   teşt, _ubod_, _hatt_, cies,
   {{0xead403d4,0xf8bf27ef,0x3ebe89ba,0x6c7b0070}},	//   _воль, rdé_, _katt_, _טראד,
   {{0x8c3d0012,0x3860013b,0xbb830037,0x2ba900ab}},	//   reşt, _efir_, _الوي, _कहता,
   {{0xe8010006,0x8c3d002d,0x4a5b0317,0x3ebe06d1}},	//   _लइका_, seşt, _אדוו, _matt_,
   {{0xa3c20067,0xdb1901ae,0xa99b0122,0x628a1111}},	//   ्मं_, _erwä, _נבחר, ófon,
   {{0x63b6016e,0x657a0098,0xb2750424,0x00000000}},	// [94f0] gwyn, áthr, илаш, --,
   {{0x7d0989bb,0x3ebe014e,0x00000000,0x00000000}},	//   zies, _natt_, --, --,
   {{0x386000fb,0xa2c900a1,0xa5f900af,0x905589bc}},	//   _yfir_, _होण्, _рену_, авец,
   {{0x439500c7,0x7cf589bd,0xb4db0176,0x160b0067}},	//   _камс, _márc, _ciàt, _हेयर_,
   {{0xa3c2021a,0x7d0989be,0x3ced006d,0x3ebe03d0}},	//   ्मः_, vies, vkev_, _batt_,
   {{0x7d0989bf,0x23690b16,0x290b19b5,0x2cbd006d}},	//   wies, mpaj_, hica_, _sawd_,
   {{0x7d0989c0,0x3ebe2129,0x290b89c1,0xd2290037}},	//   ties, _datt_, kica_, _شكره_,
   {{0x290b1851,0xa2c900a1,0xa2cd035d,0x44390116}},	//   jica_, _होत्, साक्, _kzs_,
   {{0x6e950e88,0x3ebe003c,0x3ced571a,0x8ca10067}},	//   _визу, _fatt_, rkev_, क्षो,
   {{0x7d0989c2,0x3ebe851f,0xb6080097,0x2b4e0069}},	//   sies, _gatt_, noší, _cifc_,
   {{0x290b868c,0x7cf50b4c,0x7d0989c3,0x2cbd006d}},	//   fica_, _cárc, pies, _tawd_,
   {{0x61fa0006,0x44392083,0x97c60ecd,0xdb0901dd}},	//   _ütle, _ozs_, айме, rveñ,
   {{0x443902a7,0xdb0b198d,0x07a60fb4,0x00000000}},	//   _nzs_, _asgå, јагн, --,
   {{0x96b90009,0x8ca10ac4,0xe73a89c4,0x290b0139}},	//   лусу_, क्रो, тег_, aica_,
   {{0x7ae30514,0x649a63fa,0xd62a89c5,0xaad2142a}},	//   _iont, ктар_, тове_, तारक,
   {{0x05550012,0x7ae389c6,0xb46600cf,0x3860021d}},	//   стря, _hont, ркал, _ufir_,
   {{0xdbd90279,0x42563cc0,0xe29a03e6,0xa3e7021d}},	// [9500] _açúc, атет, каа_, адта_,
   {{0x8ccc006a,0x68e40d4c,0x577b02b5,0x7ae389c7}},	//   _दोनो, _hoid, _שטיצ, _jont,
   {{0x443900d5,0x3ebe89c8,0x68e400be,0x6ef40284}},	//   _ezs_, _ratt_, _koid, _nàba,
   {{0x7ae389c9,0x3ebe89ca,0x68e40086,0xb4db0176}},	//   _lont, _satt_, _joid, _diàs,
   {{0x3ebe83c8,0x443908b7,0xa2cd018d,0x684a00c7}},	//   _patt_, _gzs_, साख्, būdž,
   {{0x290b89cb,0x7ae389cc,0xdfcf004f,0x68e401a6}},	//   zica_, _nont, بيه_, _loid,
   {{0x629c1b99,0x6ef401da,0x80c1111b,0xb4db009e}},	//   _icro, _càba, _रोके, _tiàt,
   {{0x7ae304d6,0x290b043f,0x3ebe89cd,0x3ea001c0}},	//   _aont, xica_, _watt_, řit_,
   {{0x7ae3284c,0x60c202b3,0x2eb62743,0xaad200b8}},	//   _bont, mdom, _всес, तालक,
   {{0x60c200d8,0x8f9b011d,0x68e419fd,0x3b070036}},	//   ldom, _בימי, _aoid, _cmnq_,
   {{0x7ae33e66,0x68e40284,0x68f689ce,0x325700a5}},	//   _dont, _boid, _blyd, יסים_,
   {{0x60c04aae,0x68e40391,0x68f689cf,0x8d740220}},	//   _jamm, _coid, _clyd, _ناچا,
   {{0xe8010d96,0x81ac0083,0x68e40279,0x4bd700d1}},	//   _लेखा_, কটি_, _doid, _نبود_,
   {{0x60c089d0,0x7ae389d1,0xbb430d6e,0x6b820027}},	//   _lamm, _gont, _дечк, _ivog,
   {{0xe5c454d0,0x5bb60653,0x68f60830,0x60c289d2}},	//   осто, _अनुव, _flyd, kdom,
   {{0x60c089d3,0x98750c9f,0x2fc60a78,0x629c89d4}},	//   _namm, _улиц, kvog_, _acro,
   {{0x80ca045c,0x60c289d5,0x56952746,0x335800af}},	// [9510] _सोधे, ddom, _лапт, иатэ_,
   {{0x60c289d6,0x3267010b,0xb4db009e,0x00000000}},	//   edom, ртав, _piàs, --,
   {{0x65190df3,0xb4db89d7,0x60c0018e,0x31580037}},	//   _مقدس_, _diàr, _bamm, لجنة_,
   {{0x60c089d8,0x6b820a78,0x60c20b87,0x26c17d08}},	//   _camm, _ovog, gdom, _haho_,
   {{0x60c003c1,0x7cf5290b,0xf8bf15f9,0x26c10027}},	//   _damm, _nára, llés_, _kaho_,
   {{0x629c0079,0x60c20035,0x60c00069,0xaf0401e0}},	//   _gcro, adom, _eamm, опіл,
   {{0x6b820391,0x613801c0,0x60c089d9,0x645a002d}},	//   _avog, síla, _famm, _ştii,
   {{0x60c050e8,0x7ae3480a,0xeb99151d,0x26c14a70}},	//   _gamm, _sont, гии_, _laho_,
   {{0x7ae389da,0x69ca0297,0xa2db0569,0x6d5c01ef}},	//   _pont, _arfe, नाप्, _éran,
   {{0x26c10232,0x68e489db,0x60c089dc,0x6b82011c}},	//   _naho_, _soid, _zamm, _dvog,
   {{0x68e489dd,0x7ae389de,0x60c0001c,0x2ba9007c}},	//   _poid, _vont, _yamm, _कहवा,
   {{0x673e00da,0x7ae301ca,0x26d301dd,0xa2c91ede}},	//   _shpj, _wont, _anxo_, _होस्,
   {{0x7ae389df,0x68e40086,0x6b65291c,0x69ca11cc}},	//   _tont, _void, _укла, _erfe,
   {{0x7afa5745,0x60c257a4,0xa03a016b,0x628700e0}},	//   chtt, zdom, טערפ, _ndjo,
   {{0xf8bf09ab,0x998500ad,0xa2db04aa,0xd9465454}},	//   glés_, _البو, नान्, _леки,
   {{0x6ab70266,0xe8f6042c,0xf8c60097,0x628771dc}},	//   _असुर, _دستخ, _šéfa_, _adjo,
   {{0x60c03d64,0x7cfc006c,0xb4db009e,0x611c00f4}},	// [9520] _ramm, _férf, _bhàb, jčla,
   {{0x60c00304,0x212d00bf,0xb4db0211,0xf8bf89e0}},	//   _samm, _akeh_, _chàb, blés_,
   {{0xa49401cb,0x3940006d,0x28a5258f,0xb4db0310}},	//   _ویست, _khis_, ग्वि, _viàr,
   {{0x7bcb8727,0x53a60854,0x2bbc00ab,0x03a60112}},	//   _orgu, _ламб, ्टमा, _лимо,
   {{0x44240028,0x81e600c8,0xbbb6143a,0xd12f0698}},	//   _âm_, _বেশ_, _अनेक, رمه_,
   {{0x63a489e1,0x2ee5027a,0x60c22172,0x60c001a8}},	//   mtin, _colf_, sdom, _wamm,
   {{0x7bcb89e2,0x60c00f67,0xa3c206bc,0x6b82042d}},	//   _argu, _tamm, ्मक_, _svog,
   {{0xa3bc0299,0x7cf53cf2,0x63a489e3,0xa116186e}},	//   _आना_, _pára, otin, _اورت,
   {{0xac183079,0x80c100b4,0x92da0033,0xda7a4c1c}},	//   ропу_, _रोटे, ়সী_, лян_,
   {{0x2ee589e4,0xf2d30070,0x7cf500b5,0x63a489e5}},	//   _golf_, ִער_, _vára, itin,
   {{0x7bcb89e6,0x63a489e7,0x68fd0055,0x5e570079}},	//   _ergu, htin, ërdo, _المس_,
   {{0xdd8f0312,0x6b8289e8,0x39400211,0x7cfc0093}},	//   _سوه_, _tvog, _chis_, _sérf,
   {{0x6d5a367f,0x63a45b4c,0xc1a51d78,0xd7f80424}},	//   _huta, jtin, _गङ्ग, бур_,
   {{0x6d5a002f,0xf4c50033,0xd6d70033,0x7cf568f3}},	//   _kuta, _একেব, হস্প, _járn,
   {{0x6d5a1785,0x3ce601e8,0x13d106fe,0x6ef40211}},	//   _juta, _koov_, सम्भ, _làbo,
   {{0x6d5a89e9,0x26c10371,0xa4f101d6,0x29095efb}},	//   _muta, _waho_, _dışı_, _umaa_,
   {{0x63a489ea,0x3ce689eb,0x28d60d00,0x69c80c61}},	// [9530] gtin, _moov_, धारि, lvde,
   {{0x7cfc01ef,0x7cf5021d,0xf8bf7f65,0x28a5111b}},	//   _hérd, _nárn, plés_, ग्रि,
   {{0x6d5a89ec,0x7cfc0332,0x63a400a5,0xb4db0211}},	//   _nuta, _kérd, atin, _chàc,
   {{0xd011028c,0x63a489ed,0x291901a6,0x999b0070}},	//   ولا_, btin, nnsa_, רבאט,
   {{0x6d5a89ee,0x63a489ef,0xdbf100b8,0x78ad7d19}},	//   _auta, ctin, _přív, _mbav,
   {{0x6d5a89f0,0x398301d6,0x7cf50300,0x62870207}},	//   _buta, yıs_, _cárn, _udjo,
   {{0x78ad01cc,0x7bc70029,0x3f760035,0x6d5c01ef}},	//   _obav, ājum, ału_, _éral,
   {{0x55780070,0x6d5a01d5,0xab6515dd,0x291989f1}},	//   זעהן_, _duta, овил, jnsa_,
   {{0x28dd21b2,0xeab97bff,0x00000000,0x00000000}},	//   यानि, айп_, --, --,
   {{0x6d5a89f2,0x78ad050f,0x89a907bb,0x291989f3}},	//   _futa, _abav, аков_, ensa_,
   {{0xd9467517,0x6d5a0232,0x3940006f,0x63a41a47}},	//   жени, _guta, _phis_, ztin,
   {{0x63a489f4,0x7bcb37c4,0xb4e8018d,0x2fcd0009}},	//   ytin, _trgu, _भवे_, _kreg_,
   {{0x63a489f5,0xe73a03ad,0x7cf5006c,0x386d89f6}},	//   xtin, ием_, _háro, ñera_,
   {{0x3ce6006f,0x7cf5006c,0x6d5a1af2,0x291989f7}},	//   _zoov_, _káro, _yuta, ansa_,
   {{0x394035d9,0x7bc989f8,0x3ce601e8,0x6916008b}},	//   _this_, lveu, _yoov_, jšeg,
   {{0x63a489f9,0x68fd033b,0x00000000,0x00000000}},	//   ttin, chsd, --, --,
   {{0x63a43454,0x03a389fa,0x130a00d8,0x67370093}},	// [9540] utin, мито, анай_, ðgjö,
   {{0x63a489fb,0x78ad89fc,0x16aa0afd,0x00000000}},	//   rtin, _zbav, _твои_, --,
   {{0x7cf50076,0x5bb648cd,0x021900d8,0x7bcd00c7}},	//   _náro, _अन्व, біць_, _šaul,
   {{0x63a489fd,0x6d5a6d50,0x28dd045c,0x7cfc006c}},	//   ptin, _ruta, यायि, _kére,
   {{0x6d5a122e,0x63a40069,0xae9a0037,0x2d850a8a}},	//   _suta, qtin, لضغط_, _avle_,
   {{0x6d5a0284,0x248089fe,0x7cfc006c,0x3ce600ab}},	//   _puta, laim_, _mére, _soov_,
   {{0xf8ca046c,0x28dd166b,0xccfa03fa,0x7cfc002a}},	//   ियाय, यामि, ићи_, _lére,
   {{0x6d5c89ff,0x248011d9,0x7e7a8a00,0x6ef4009e}},	//   _éram, naim_, _wetp, _tàbo,
   {{0xd0120a72,0x6d5a8a01,0x2d510124,0x2fcd1691}},	//   _غلط_, _wuta, _išel_, _greg_,
   {{0x28dd0380,0x6d5a8a02,0x78ad027a,0x79a63537}},	//   याभि, _tuta, _sbav, орме,
   {{0x7cfc4a74,0xed5a01c8,0xa2db0d1f,0x6d5a010d}},	//   _aére, _тое_, नात्, _uuta,
   {{0x7cfc00fd,0x00000000,0x00000000,0x00000000}},	//   _bére, --, --, --,
   {{0x7cf5053d,0xd83b004b,0x7cfc8a03,0x24800079}},	//   _záro, рэн_, _cére, daim_,
   {{0x7cfc60f5,0xdcf800c7,0x00000000,0x00000000}},	//   _dére, tuvė, --, --,
   {{0x6d4201a5,0xa4d51645,0x442200cc,0xc87f02b1}},	//   _khoa, пові, _axk_, paß_,
   {{0x24581470,0x7aea0029,0x78ad1b68,0x24800b0c}},	//   жать_, žotā, _ubav, gaim_,
   {{0x7cfc0248,0x2bcd0461,0xd25b5446,0xfbbc0e61}},	// [9550] _gére, ़िया, аце_, ्टिम,
   {{0x28ac0066,0x026b010b,0xa2db1140,0x82d8002d}},	//   ट्ठि, ршай_, नाध्, одус_,
   {{0x116a00d1,0x24800037,0x51843fe2,0x2fcd01cb}},	//   مللی_, baim_, дуча, _sreg_,
   {{0xfbbc1cce,0x7bcd02c4,0x2fcd03d0,0x1db40099}},	//   ्टाम, _šaum, _preg_, ंबईत,
   {{0x7c220031,0xa2db022e,0x9f3501e0,0x00000000}},	//   _nxor, नाद्, педі, --,
   {{0xdfce1c2d,0x6d4201b7,0x752d0009,0xc10505f5}},	//   ايو_, _ahoa, loaz, _کوري,
   {{0x6d42009e,0x408703e6,0x63b900c1,0x8ccc638d}},	//   _bhoa, _муаб, şanı, _दोहो,
   {{0x7cf50332,0x6d428a04,0x2fcd0031,0x63bb00c7}},	//   _váro, _choa, _treg_, _šuny,
   {{0x2d98013c,0x3ec40086,0x6d42009e,0x7bc900a2}},	//   _åren_, östä_, _dhoa, uveu,
   {{0x7bc90248,0x4fc400d8,0x7cf500b5,0x752d01b7}},	//   rveu, _ўста, _táro, hoaz,
   {{0x6d42009e,0x00000000,0x00000000,0x00000000}},	//   _fhoa, --, --, --,
   {{0x7cfc0890,0x69ac0084,0x613127fe,0x752d040c}},	//   _pére, _जहरी, måls, joaz,
   {{0x1c39005f,0x6d498a05,0x7cf500b5,0x248000be}},	//   _узды_, mmea, _járm, vaim_,
   {{0xb8f30bc1,0x36670368,0x7cfc00fd,0x00000000}},	//   _हो_, заро_, _vére, --,
   {{0x1fb8051d,0x24808a06,0x00000000,0x00000000}},	//   _इन्ड, taim_, --, --,
   {{0x7d1b8a07,0x6d4901a6,0x77860368,0x7cfc00fd}},	//   nnus, nmea, _елиз, _tére,
   {{0x2480066a,0x6d4909c3,0x7cfc0473,0x23c90931}},	// [9560] raim_, imea, _hérc, रिषद,
   {{0x6d490037,0x662700b5,0x24808a08,0x0cb800b4}},	//   hmea, érké, saim_, _आस्म,
   {{0x672e008c,0xc21901e0,0x24800098,0x00000000}},	//   mobj, оєї_, paim_, --,
   {{0x7cf5006c,0x00e600c3,0x69160009,0x7cfc8a09}},	//   _bárm, яжен, lšeb, _mérc,
   {{0x28dd084b,0xa49b0107,0x7cf5021d,0x6d490553}},	//   याति, _blòf, _cárm, dmea,
   {{0x6daa01c2,0x59db012f,0x7d1b00ab,0xd00f1301}},	//   _fəal, यमार, enus, دله_,
   {{0x1ea915f8,0x43438a0a,0xb4db0211,0x00000000}},	//   تاني_, _черв, _mhàn, --,
   {{0x7cf58a0b,0x7d1b8a0c,0xf65300a5,0x8fa60142}},	//   _fárm, gnus, עצה_, _набе,
   {{0xdd900ef2,0x395c2cfc,0xa49b021e,0x00000000}},	//   روک_, _suvs_, _imòt, --,
   {{0x6d428a0d,0xfee9004f,0xb4db0019,0x1eaa0372}},	//   _whoa, _وعلى_, _nhàn, _داري_,
   {{0x386d0831,0x6d420019,0x672e02c6,0x3f867fd7}},	//   ñero_, _thoa, dobj, lsou_,
   {{0x28dd0ac4,0x7c2201d7,0xddc88a0e,0x7cee0211}},	//   याधि, _txor, _kedž, _cùrt,
   {{0x3f862314,0xb4db0211,0x2c0800d1,0x752d0009}},	//   nsou_, _bhàn, _بعضی_, voaz,
   {{0xb4db8a0f,0xddc801c8,0x7bc201a2,0x6d5501ef}},	//   _chàn, _medž, _isou, _ézar,
   {{0x28dd143a,0xa2db0ebd,0xbb2b00b5,0xb4db0211}},	//   यादि, नास्, _اتنے_, _dhàn,
   {{0x2eb90953,0x645a0043,0x799a2506,0x7aea8a10}},	//   _इस्त, _ştir, mutw, _hoft,
   {{0x28ca045c,0x3f8601c0,0x69c5008a,0xd06400a8}},	// [9570] ियरि, jsou_, _áher, _ürəy,
   {{0xd25b2b4d,0xd7fc0122,0x7bcd010b,0x04ff0033}},	//   сца_, _להחל, _šauk, ্কের_,
   {{0xaaae05b7,0x4aae0266,0x7aea0139,0xf1c20228}},	//   ज्यक, ज्यव, _moft, jušā_,
   {{0x291900f8,0xddc80124,0xa2db018d,0x6ef4009e}},	//   érah_, _bedž, नाह्, _hàbh,
   {{0x3ce00325,0x00000000,0x00000000,0x00000000}},	//   काने_, --, --, --,
   {{0xe8da27bd,0x2bb60243,0x2d5100b8,0x799a05db}},	//   _बच्च, _अनजा, _všem_, kutw,
   {{0x7bc20107,0x00000000,0x00000000,0x00000000}},	//   _asou, --, --, --,
   {{0xed560133,0x6ef40211,0x799a007b,0x00000000}},	//   мощ_, _làbh, dutw, --,
   {{0x6d4903c0,0xddc80009,0x0b450dc8,0x7d1b8a11}},	//   rmea, _gedž, мнин, rnus,
   {{0x3cff01ef,0x38698a12,0xff53004f,0x6d498a13}},	//   shuv_, _afar_, _أخر_, smea,
   {{0x7bc20107,0x7cee00f1,0x7aea01ff,0x6eef008c}},	//   _esou, _cùrs, _doft, _døbt,
   {{0x7cf500b5,0x38690031,0x00000000,0x00000000}},	//   _márk, _cfar_, --, --,
   {{0xfaa51ce8,0xe97201cb,0x672e0bf7,0xe9db00f8}},	//   _жало, _یهود, tobj, _گذشت_,
   {{0x3cfd006d,0xa3c10026,0x6ef4009e,0x2bbc01c0}},	//   _hlwv_, ंबन_, _càbh, ्टरा,
   {{0x7cfc8a14,0xe5a32264,0xe7370a80,0x64a68a15}},	//   _héra, кири, фер_, мава,
   {{0x69c38a16,0x3ce0073f,0x672e8a17,0x2cad2aea}},	//   _isne, काये_, sobj, nfed_,
   {{0xb4db098b,0xb4be004e,0x672e0124,0x6ef40211}},	// [9580] _thàn, _इसी_, pobj, _fàbh,
   {{0x61382cc9,0xb0c60e96,0x2d878a18,0xfbc704cd}},	//   míli, _रोजग, ksne_, _یت_,
   {{0x7cf5006c,0xddd8011c,0x0219010b,0x6eef0b3e}},	//   _várj, kavš, піць_, _løbs,
   {{0x7cf501c0,0x0cd80033,0x31be0355,0x69c35e06}},	//   _dárk, _তত্ত, _vůz_, _msne,
   {{0xddd8011c,0x6ef40443,0xa2db012f,0xb4db0211}},	//   davš, _hàbi, नाश्, _mhàl,
   {{0x6b9b011e,0x3f862314,0x69c30107,0x81b60033}},	//   duug, rsou_, _osne, জিব_,
   {{0xa2db0825,0xf98700f5,0x3f8603e6,0xa49b0211}},	//   नार्, _جب_, ssou_, _flòd,
   {{0x7aea6e9c,0x6721068b,0xddd8011c,0x3f868a19}},	//   _soft, člji, gavš, psou_,
   {{0x29020c6f,0x7aea00af,0x6b9b0ad2,0x7cfc000d}},	//   dhka_, _poft, guug, _céra,
   {{0x7aea00da,0x7cfc00f7,0x78a4002a,0x38690371}},	//   _qoft, _déra, _aciv, _sfar_,
   {{0xb4db009e,0xd9152ad9,0x6aba23b5,0x00000000}},	//   _bhàl, едны, retf, --,
   {{0x61e3013c,0x7bc20107,0xb4db009e,0x38690031}},	//   änli, _tsou, _chàl, _qfar_,
   {{0x628e531e,0x7aea04c1,0x7cfc20d0,0x69c38a1a}},	//   _odbo, _toft, _géra, _esne,
   {{0xaff902b5,0xbbbc0d91,0x7cee0211,0x00000000}},	//   פּרי, ्टीक, _tùrs, --,
   {{0xa2c206fe,0xb4db009e,0xe93b103b,0x1634218b}},	//   रजन्, _fhàl, _وسعت_, веря,
   {{0x3ea9044d,0x628e001e,0x26da0359,0x27ee0031}},	//   đati_, _adbo, _enpo_, ëjnë_,
   {{0x61380183,0xa87c00a5,0x7cfc0042,0xa2db258f}},	// [9590] cíli, _ואחר, _xéra, नाल्,
   {{0x78bd002a,0x28dd0099,0xddd801a0,0x68ed00cc}},	//   lesv, यावि, zavš, _hoad,
   {{0x68ed01d7,0x6ef401f7,0x00000000,0x00000000}},	//   _koad, _gàbi, --, --,
   {{0x78bd8a1b,0x2d9c02d7,0x68ed0c6f,0x659a016b}},	//   nesv, duve_, _joad, _צירק,
   {{0x68ed02b3,0x645d0008,0xa2a7012f,0xb4cb0380}},	//   _moad, _igsi, _चाप्, लयी_,
   {{0x68ed8a1c,0x6efd0118,0x2bd2164f,0xb4db009e}},	//   _load, _bèba, तिना, _mhàm,
   {{0x62854405,0xddd8011c,0x78bd2a5e,0x44393f85}},	//   maho, tavš, kesv, _hys_,
   {{0xd6580052,0x62858a1d,0x44398a1e,0x61f808c8}},	//   ויות_, laho, _kys_, øvle,
   {{0x60db8a1f,0x2cad79dc,0x613868ff,0x645d0159}},	//   _inum, rfed_, xíli, _mgsi,
   {{0x62858409,0x7cf58a20,0x78a40382,0x7cfc8a21}},	//   naho, _mári, _sciv, _véra,
   {{0xa2a7065a,0x44398a22,0x68ed0d9a,0x7cf5004f}},	//   _चान्, _lys_, _boad, _lári,
   {{0xb4be004e,0x7cfc8a23,0x68ed8a24,0x78bd8a25}},	//   _इसे_, _hérn, _coad, gesv,
   {{0xb8e8006a,0x62858a26,0x68ed8a27,0x4439093a}},	//   _उस_, kaho, _doad, _nys_,
   {{0x29028a28,0x6d598a29,0x61382127,0x62852889}},	//   shka_, _hiwa, ríli, jaho,
   {{0x6d5973fd,0x61388a2a,0x386b004f,0x69c300b8}},	//   _kiwa, síli, éirí_, _usne,
   {{0x07a600ca,0x6d592b63,0x44398a2b,0x78bd01e9}},	//   _заин, _jiwa, _bys_, cesv,
   {{0x442600c9,0x28dd045c,0x2bd21af6,0x6d598a2c}},	// [95a0] ço_, यारि, तिया, _miwa,
   {{0x60db8a2d,0x28ac0311,0xa8570122,0x6d598a2e}},	//   _anum, ट्रि, _איפה_, _liwa,
   {{0x290025bb,0x5ec80083,0x44390051,0x6d590103}},	//   _klia_, লামে, _eys_, _oiwa,
   {{0x2bd20761,0x6d598a2f,0x44398a30,0x6b8900b9}},	//   तिमा, _niwa, _fys_, kseg,
   {{0x62854ff9,0x087702b5,0x44391c9b,0x29120159}},	//   baho, גענט_, _gys_, _mmya_,
   {{0x2d9c8a31,0x6d5900d5,0x8f7500d4,0x040b0023}},	//   tuve_, _aiwa, туці, _lưỡn,
   {{0x32430f08,0x2bd2018d,0xb87b300b,0x6d598a32}},	//   _берг, तिभा, rkíz, _biwa,
   {{0xed570202,0x6d590fa0,0x3f9d0118,0x6efd0359}},	//   ној_, _ciwa, buwu_, _vèba,
   {{0x6d5909df,0x6b898a33,0x68ed8a34,0xd1171804}},	//   _diwa, gseg, _road, _נקמה_,
   {{0x68ed0042,0xa3c30066,0x2912018e,0xa49b021e}},	//   _soad, ्ित_, _amya_, _klòc,
   {{0xf8dd8a35,0x13170122,0x29000284,0xa3d22478}},	//   यालय, תחיל_, _blia_, विड_,
   {{0x6d5939c5,0x29008a36,0x040b0023,0x62858a37}},	//   _giwa, _clia_, _cưỡn, zaho,
   {{0x62858a38,0x040b01a5,0x7cfc8a39,0x78bd8a3a}},	//   yaho, _dưỡn, _héro, resv,
   {{0xfde400dc,0x44398a3b,0x6d591ebf,0x7f5a035f}},	//   _कपास_, _rys_, _ziwa, _jitq,
   {{0x68ed300e,0x645d011e,0x443f8a3c,0x62858a3d}},	//   _toad, _pgsi, _šu_, vaho,
   {{0xf98f2e36,0x98a500ea,0x9a3b00a5,0x29000027}},	//   _ابو_, ēlē_, _מתוק, _glia_,
   {{0x62858a3e,0x5455029f,0x00000000,0x00000000}},	// [95b0] taho, тват, --, --,
   {{0x2d8c8a3f,0x7cf50370,0x60c90d89,0x69160097}},	//   _ovde_, _vári, _saem, nšen,
   {{0x44390626,0x3949124f,0xa2d000a1,0x6ea400db}},	//   _wys_, _khas_, _डोळ्, च्छु,
   {{0x62858a40,0x44390035,0x00000000,0x00000000}},	//   saho, _tys_, --, --,
   {{0x7cfc0248,0x31580037,0xc1040079,0x44390b88}},	//   _aéro, رجمة_, دوني, _uys_,
   {{0x63ad03be,0x6d598a41,0x7cfc0088,0xa3c01282}},	//   mtan, _siwa, _béro, ूटर_,
   {{0x69160187,0x6d598a42,0xa92801ba,0x6e3a00e5}},	//   dšen, _piwa, nažé, _cytb,
   {{0x92580133,0x7cfc8a43,0x6b898a44,0x63ad8a45}},	//   _част_, _déro, tseg, otan,
   {{0x6d59000e,0x2d8c027d,0x6b8900be,0x6d5e3c2b}},	//   _viwa, _evde_, useg, ípar,
   {{0xdb00008d,0xa3d20e62,0x3949067f,0xe6cb09b1}},	//   ttmá, वित_, _ahas_, ायोज,
   {{0x6b898a46,0x2900006d,0x63ad8a47,0x39490284}},	//   sseg, _plia_, htan, _bhas_,
   {{0x39498a48,0xdb00024e,0xa3c10ca1,0x6b8900be}},	//   _chas_, rtmá, ंबा_, pseg,
   {{0x394901da,0x752900cd,0x7cfc00b5,0x00000000}},	//   _dhas_, čezl, _mérl, --,
   {{0xf7463c29,0x2cbf4db8,0x6ef40176,0x63ad0408}},	//   тего, leud_, _fàbu, dtan,
   {{0x28aa060a,0x394901da,0x6efd0107,0x29000284}},	//   _कापि, _fhas_, _lèbo, _tlia_,
   {{0x2cbf02c7,0x63ad07a4,0x69de0a66,0x3949007a}},	//   neud_, ftan, _špeg, _ghas_,
   {{0xa3d202cb,0x63ad8a49,0xe363021d,0xb46332dc}},	// [95c0] विध_, gtan, икти, ркул,
   {{0x1303368a,0xc7d700a5,0x6efd0118,0xf8bf00e0}},	//   азум, _יופי_, _sèbn, boés_,
   {{0x63ad8a4a,0xa50a2235,0x69240506,0x776402d7}},	//   atan, _жена_, nđeo, _huix,
   {{0x63ad043d,0x28aa0437,0x25f10035,0xa3d20066}},	//   btan, _काफि, ीनरी_, विद_,
   {{0x10a323b8,0x63ad409c,0x7cfc7620,0x7cf500b5}},	//   ричн, ctan, _séro, _járu,
   {{0x7cfc8a4b,0x09c80083,0xdd9007f6,0x776438bc}},	//   _péro, ষমতা, موت_, _muix,
   {{0x91e38a4c,0x51560009,0x78b6024e,0xe29700c9}},	//   _коре, _атау, _obyv, _јас_,
   {{0x7cfc000d,0x60970037,0x80ca2e99,0x00000000}},	//   _véro, _لنفس_, _सोचे, --,
   {{0x9eaa00c9,0xf8bf0248,0xfd0f00bf,0x7cf50097}},	//   _оваа_, nnée_, تجو_, _náru,
   {{0x38608a4d,0x69160355,0x8c430bfe,0x3ae907c0}},	//   _agir_, ušen, шење, _kúpy_,
   {{0x63ad06a2,0x69240254,0x39490098,0x00000000}},	//   ztan, rđen, _phas_, --,
   {{0x63ad0fe2,0x77640176,0xd90f0df3,0x644602a7}},	//   ytan, _buix, تیب_, _ozki,
   {{0x691673cc,0xd8380409,0x776401f7,0x69de2dc6}},	//   pšen, вэр_, _cuix, _šped,
   {{0xd7f821f5,0x8c431eea,0x6f180187,0xb8fa00ab}},	//   тую_, _тече, nivc, _डो_,
   {{0x2bbc00b4,0x39490221,0xb9090083,0x6d5c02d7}},	//   ्टका, _thas_, _যত_, _éras,
   {{0xd4983967,0x69240a78,0x69160009,0x00000000}},	//   кру_, nđel, nšel, --,
   {{0x29198a4e,0x63ad8a4f,0xf8bf0248,0x77640392}},	// [95d0] misa_, utan, gnée_, _guix,
   {{0x291987f3,0x6f1818b0,0x64430095,0xb4db0014}},	//   lisa_, jivc, ənil, _mhài,
   {{0xc8aa0302,0xf8aa0299,0x7cf58a50,0x28aa04bc}},	//   _कामट, _कामय, _záru, _कामि,
   {{0x29198a51,0x63ad379b,0xdb000282,0x7cf500b5}},	//   nisa_, ptan, ltmä, _járt,
   {{0x7cf52e36,0x1fa7002d,0x6efd0260,0x2489013a}},	//   _márt, трег, _fèbl, maam_,
   {{0x24890657,0x29192e73,0x7d028a52,0x2cbf001e}},	//   laam_, hisa_, _alos, weud_,
   {{0x29198a53,0x00000000,0x00000000,0x00000000}},	//   kisa_, --, --, --,
   {{0x7d020052,0x24890244,0xb4db00f1,0xa2db364c}},	//   _clos, naam_, _bhài, नाक्,
   {{0x29198a54,0x7cfc8a55,0xb4db00f1,0x3ea500b5}},	//   disa_, _kérj, _chài, _مشاہ,
   {{0x2bc4009a,0x81b60033,0xb4db0284,0x7d028a56}},	//   _वनरा, জির_, _dhài, _elos,
   {{0x2919000e,0x3ce006fe,0x248900ec,0x7cf58a57}},	//   fisa_, काशे_, kaam_, _bárt,
   {{0x7cf5004f,0x291901a8,0xc19a0070,0x24898a58}},	//   _cárt, gisa_, עשרי, jaam_,
   {{0x3ce04f9a,0x77648a59,0xb4db004a,0x24898a5a}},	//   कारे_, _quix, _ghài, daam_,
   {{0x9b920098,0x67350484,0x7d0200cd,0xa3d20f0d}},	//   _الوت, gozj, _zlos, विस_,
   {{0x291905ba,0xd6274de5,0x442b013b,0xa2c20355}},	//   bisa_, горе_, _axc_, रजस्,
   {{0x2919031a,0x64990c14,0x65650118,0x77640392}},	//   cisa_, ктур_, _duhh, _tuix,
   {{0xe3ba01c8,0x93aa036b,0x03260f29,0x442b0168}},	// [95e0] эба_, عارف_, гдан, _cxc_,
   {{0xf8bf02e1,0x3cda0066,0x91e65b4f,0x03a318cd}},	//   rnée_, _खोने_, лозе, сифо,
   {{0xaaa6198f,0xdd1e00fe,0x00000000,0x00000000}},	//   _खासक, _líšn, --, --,
   {{0xbfaa1000,0x7cfc01ef,0x6b9b8a5b,0x647500af}},	//   етке_, _pérm, krug, _вырф,
   {{0x752468fb,0xb4c02cb0,0x6f1801a0,0xd0f50026}},	//   mniz, ंजी_, tivc, _आवरण_,
   {{0xa3c11fe0,0x2919018e,0x51860172,0x9186097f}},	//   ंबर_, zisa_, _مشرق, _مجرم,
   {{0x3ce0000c,0x291901a8,0x7d028a5c,0x00000000}},	//   काले_, yisa_, _plos, --,
   {{0x7cfc2303,0xb4db0014,0x3fa60206,0xb88701dd}},	//   _térm, _phài, _مصطف, _muíñ,
   {{0x29198492,0xd02611c5,0x6b9b8a5d,0x2aaa0374}},	//   visa_, _смай, grug, нтно_,
   {{0x60c22d73,0x24890120,0x6d4b3815,0x7d020067}},	//   leom, zaam_, _ehga, _wlos,
   {{0x691600d8,0x7cf58a5e,0x6ef40443,0x2bd21a0c}},	//   pšel, _párt, _fàbr, तिहा,
   {{0x6b9b01b4,0xb4db01a6,0x60c20a8c,0x7d0200c3}},	//   brug, _thài, neom, _ulos,
   {{0x29198a5f,0x6d400211,0x68fd30e5,0x7cf500fd}},	//   risa_, mlma, rksd, _várt,
   {{0x29198a60,0xa49b0176,0x6d40190f,0xda1500fd}},	//   sisa_, _clòn, llma, اسیک,
   {{0x29191f92,0xb887002a,0x2bd2111a,0x442b0282}},	//   pisa_, _cuíñ, तिवा, _sxc_,
   {{0x69ca003c,0x1b1a0083,0x75248a61,0x442b0392}},	//   _isfe, _নীচে_, gniz, _pxc_,
   {{0x6d40066e,0x28aa111e,0xd37116e6,0xb4c50826}},	// [95f0] ilma, _काति, زها_, _एसी_,
   {{0x2bb70084,0x75248a62,0x24898a63,0x6b828a64}},	//   _अहसा, aniz, saam_, _mwog,
   {{0xf77001cb,0x26c347f2,0x521503e6,0x6b82073a}},	//   _وای_, mejo_, јдет, _lwog,
   {{0x26c38a65,0x60c28a0d,0x69d800ee,0xe5c401e0}},	//   lejo_, geom, _mrve, _усьо,
   {{0xa2d000a1,0xafe50421,0x00000000,0x00000000}},	//   _डोक्, ролл, --, --,
   {{0xa3d206bb,0x26c38a66,0xdb0201dd,0x2d950368}},	//   विर_, nejo_, _opoñ, арис,
   {{0x6b820359,0x00000000,0x00000000,0x00000000}},	//   _awog, --, --, --,
   {{0x2d510009,0x2d6700cd,0x6b822967,0x6b9b16f9}},	//   _ašer_, _uđem_, _bwog, trug,
   {{0x28d904cc,0x69d88a67,0x62873382,0x2d9c8a68}},	//   _बोधि, _arve, _kejo, arve_,
   {{0x6b9b8a69,0x26c3108a,0x69d833a5,0x6d40458a}},	//   rrug, jejo_, _brve, alma,
   {{0x628700c8,0x69d8505f,0x26c37cc2,0xbe640413}},	//   _mejo, _crve, dejo_, _اهمي,
   {{0x62878a6a,0x69d80a78,0x69de016f,0x6b9b0a78}},	//   _lejo, _drve, _špec, prug,
   {{0x69d88a6b,0x7d1b01ef,0x290c00d8,0x3cff006d}},	//   _erve, mius, ėda_, mkuv_,
   {{0x7cf50332,0x3ced068b,0x7d1b8a6c,0x05020083}},	//   _társ, ljev_, lius, _এদের_,
   {{0x2d981e74,0xe9a50036,0xdce102a7,0x63bd0197}},	//   _året_, _тайп, _lulč, _apsn,
   {{0xa3d211b5,0x94260214,0x05240033,0x3ced0693}},	//   विल_, амбе, পত্র_, njev_,
   {{0xf7721c51,0x03a612fb,0x93c800b5,0x53a61682}},	// [9600] _باب_, ризо, دازہ_, разб,
   {{0x7d1b8a6d,0x7cf542ae,0x26c302a7,0x969620a6}},	//   hius, _márq, cejo_, _триш,
   {{0xa2a70d00,0x6d400523,0x7d1b8a6e,0x62878a6f}},	//   _चार्, ylma, kius, _dejo,
   {{0x53a62857,0x3cff006d,0x19b6016b,0x00000000}},	//   _камб, jkuv_, יפער_, --,
   {{0x43750500,0x7d1b8a70,0x7d098a71,0xe3b21dbf}},	//   _густ, dius, dhes, _برج_,
   {{0x63a48a72,0x9ea703fa,0x62878a73,0x7cfc006c}},	//   muin, авља_, _gejo, _térk,
   {{0x63a48a74,0xb23a004f,0x7cfc1f3c,0x7d1b0bf7}},	//   luin, _شكرا_, _héri, fius,
   {{0x6b820c1f,0x92a6004e,0x7d1b72ce,0x6d400260}},	//   _pwog, _wyłą, gius, ulma,
   {{0x7cf5365c,0xa2db00a1,0x6d400093,0x63a48a75}},	//   _párr, नाच्, rlma, nuin,
   {{0x69d82a9f,0x2d9c00b8,0x2fc900a2,0x00000000}},	//   _prve, prve_, çage_, --,
   {{0x63a419fd,0xf2d902b5,0x7d1b0b6d,0x3cff006d}},	//   huin, אַרל, bius, bkuv_,
   {{0x7d1b8a76,0x63a47671,0xfce300af,0xa3e60803}},	//   cius, kuin, _мохо, भमा_,
   {{0x315702b5,0x8c43192f,0xe667853e,0xb4db00f1}},	//   ייטן_, _деце, итво, _mhàt,
   {{0x63a48a77,0x69d80009,0x46de046c,0x7cfc0093}},	//   duin, _trve, मागह, _sérh,
   {{0x26d1006a,0x62878a78,0x26c38a79,0x7cfc0248}},	//   rdzo_, _rejo, rejo_, _aéri,
   {{0x26c38a7a,0x3f8f001e,0x628714e1,0x2ed33979}},	//   sejo_, ysgu_, _sejo, _दफ्त,
   {{0x63a48a7b,0x26c38a7c,0x3ce7046c,0x8387005f}},	// [9610] guin, pejo_, झाते_, рыбе,
   {{0x883c0122,0x7cfc0248,0x6e2d01d6,0x7d1b0409}},	//   _בתחו, _déri, şabi, zius,
   {{0x75d50125,0xb4db00f1,0x00000000,0x00000000}},	//   _ايجا, _bhàt, --, --,
   {{0x7cfc26c0,0x63a48a7d,0x7d1b01dd,0xb4db009e}},	//   _féri, buin, xius, _chàt,
   {{0x7d1b01ef,0x28ac0084,0x63a40043,0x7f192659}},	//   vius, ट्टि, cuin, ліку_,
   {{0x630510ab,0x00000000,0x00000000,0x00000000}},	//   _اوسل, --, --, --,
   {{0x7d098a7e,0x7d1b2803,0xa19455c5,0xb4db0211}},	//   thes, tius, _марч, _fhàt,
   {{0x02c70b57,0x51848a7f,0xd5d800ab,0xb4c5018d}},	//   _रघुन, _фура, डितज, _एसो_,
   {{0x7d1b8a80,0x3ced108a,0x7d0900b5,0xdb090042}},	//   rius, rjev_, rhes, steí,
   {{0xfe700041,0x7d098a81,0x78ad8a82,0x3cff8a83}},	//   _قدم_, shes, _acav, skuv_,
   {{0x657701a9,0x7d098a84,0x63a464af,0x3ced0124}},	//   _ntxh, phes, zuin, pjev_,
   {{0x05090033,0x00000000,0x00000000,0x00000000}},	//   রচুর_, --, --, --,
   {{0xeb9900aa,0xdb0b08c8,0x7bd904fb,0x2d980d51}},	//   _сил_, _opgø, _urwu, _årer_,
   {{0xa3c10ca1,0xda7b2374,0xcc3a016b,0x00000000}},	//   ंबई_, _ряд_, _גענט, --,
   {{0x7cfc8a85,0x7ae38a86,0xe8d90019,0x7afc8a87}},	//   _séri, _innt, _giỏ_, örte,
   {{0x7cfc02e1,0x63a48a88,0xb4668008,0x6efd0392}},	//   _péri, tuin, скал, _dèbi,
   {{0x68e40069,0xa49b0211,0x044a8a89,0x212600f4}},	// [9620] _inid, _glòm, упак_, vnoh_,
   {{0x63a4004a,0x7cfc02e1,0x7c2e033b,0xb4db0284}},	//   ruin, _véri, ßbri, _bhàs,
   {{0x63a48a8a,0xb4db009e,0x386d336f,0x60660312}},	//   suin, _chàs, žere_, مهال,
   {{0xb4db01da,0x29020421,0x00000000,0x00000000}},	//   _dhàs, nkka_, --, --,
   {{0x29020086,0x1fb61f7c,0x24808a8b,0xdb00000d}},	//   ikka_, ссер, mbim_, sumé,
   {{0x4dbe0033,0x2f0b0044,0xb4db0284,0x24801e2c}},	//   ্মসূ, _nøgd_, _fhàs, lbim_,
   {{0x7cf50453,0x2fcd0298,0xb4db009e,0x68e4099e}},	//   _párp, _eseg_, _ghàs, _onid,
   {{0xbb740798,0x7ae300f1,0x644b099d,0x00000000}},	//   огиј, _annt, ügig, --,
   {{0x61fe0044,0xc0061eb9,0x300601e0,0x00000000}},	//   lypl, _упак, _узаг, --,
   {{0x78ad8a8c,0x68e48a8d,0x00000000,0x00000000}},	//   _scav, _anid, --, --,
   {{0xdd9200bf,0x81b60033,0x69cf0035,0x68f6242d}},	//   _روش_, জিক_, łcen, _boyd,
   {{0x68e4248a,0xd8430097,0x7ae305f5,0x00000000}},	//   _cnid, _ničí_, _ennt, --,
   {{0x28aa020c,0x07a4010b,0x613401fb,0x00000000}},	//   _कारि, паўн, _gülş, --,
   {{0x98be0029,0x7cfc1c02,0x290b0160,0xf1c8052f}},	//   ētā_, _cérv, shca_, रबान,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e4029e,0x256e00fe,0x00000000,0x00000000}},	//   _gnid, _dýl_, --, --,
   {{0x29090103,0x36d5095d,0xb4db0284,0x7cfc01ef}},	// [9630] _ilaa_, _допр, _bhàr, _férv,
   {{0x326724b6,0xb4db00f1,0x2f0b08c8,0x44270023}},	//   став, _chàr, _køge_, ăn_,
   {{0x2bcf02e4,0x40950088,0xdb090079,0x24808a8e}},	//   _तैना, قلار, nteá, bbim_,
   {{0xdb09004f,0x00000000,0x00000000,0x00000000}},	//   iteá, --, --, --,
   {{0xcf9b0202,0xff510416,0x60c400ab,0xb4db01da}},	//   ује_, وخت_, õima, _fhàr,
   {{0x13ba0070,0xe81c007c,0xb4db0284,0xd2f6042c}},	//   _דזשע, _पइसा_, _ghàr, _وکلا_,
   {{0x28aa0af9,0x69de00ac,0xace901d3,0x290902d7}},	//   _कालि, _špen, имка_, _olaa_,
   {{0x2fcd01a9,0x28d90f2b,0x8b9584cc,0x26d301ef}},	//   _tseg_, _बोलि, ороч, _laxo_,
   {{0x68e48a8f,0xa49b0107,0x212d0118,0x34da016b}},	//   _rnid, _alòk, _ijeh_, בֿיב,
   {{0x6906002a,0x29098a90,0x0b42002d,0x68f605f9}},	//   _cóen, _alaa_, мнын, _soyd,
   {{0x2dfa0332,0xcebb00a8,0x290914d0,0x00000000}},	//   _پبلک_, şəsi_, _blaa_, --,
   {{0x68f600a8,0x7cfc8a91,0x00000000,0x00000000}},	//   _qoyd, _sérv, --, --,
   {{0x3c470041,0x290200c3,0x4c2500fd,0x6eef008c}},	//   _اضاف, rkka_, _بظاہ, _søby,
   {{0x2bcf1db6,0xa49b0107,0xead40421,0x3ce700ab}},	//   _तैया, _flòk, _ночь, झावे_,
   {{0x96635b60,0x96043d75,0xdb090098,0x9f62013b}},	//   дкре, रनेट_, cteá, şqçi_,
   {{0x68e43207,0xd4670ae6,0x61fe0187,0x212d01f4}},	//   _unid, жите_, vypl, _njeh_,
   {{0x24808a92,0xd7ef0037,0xb4db01a6,0x96ba0009}},	// [9640] rbim_, _لكي_, _phàr, _куну_,
   {{0x681c0080,0xe29a1285,0xc8aa111e,0x6b4f01b4}},	//   rādī, раж_, _काँट, bøge,
   {{0x673c279a,0x5066021d,0x7c2d008a,0xf8bf00b5}},	//   morj, отла, _þarf, knél_,
   {{0x7cfc00f8,0xb9ac016b,0xa9ba016b,0x00000000}},	//   _yéru, רבאָ, יזער, --,
   {{0xa3ce5dc3,0x7cfc00b5,0xb4db0211,0x6f1a18f9}},	//   _शनि_, _mért, _thàr, _pmtc,
   {{0x7c240478,0x3940046a,0xdd9a0923,0x4aae0096}},	//   _žiro, _lkis_, аши_, ज्ञव,
   {{0xa3d20d1f,0x6ce50035,0xd9a80035,0x4c940340}},	//   विक_, कांग_, _कमेट, пийс,
   {{0x61e10332,0x3ea08a93,0x3940006d,0x90c30fdd}},	//   _álla, şit_, _nkis_, _обсе,
   {{0x63b68a94,0xd0070b46,0x46ca22a7,0x2f0b01b4}},	//   ntyn, _дете_, ाजाह, _søge_,
   {{0x29090054,0x8af700a8,0x3940010b,0xed5800ee}},	//   _slaa_, _şəri, _akis_, _esľp_,
   {{0x673c8a95,0x7cfc8a96,0x63b60421,0x394000cc}},	//   dorj, _séru, htyn, _bkis_,
   {{0x26d38a97,0x7cfc4135,0x0aea0118,0x88b100f8}},	//   _saxo_, _cért, ارکي_, ریخچ,
   {{0xdb09004f,0xc86400d4,0xab2a6058,0x673c8a98}},	//   steá, дтри, _кода_, forj,
   {{0x3ce60189,0x673c42c0,0x394022fc,0x24990009}},	//   _hnov_, gorj, _ekis_, _sdsm_,
   {{0x2bd209b1,0x7cfc2587,0x45d4005c,0x69240009}},	//   तिका, _fért, морс, vđev,
   {{0x92a90035,0x33753e71,0x00000000,0x00000000}},	//   kułó, згар, --, --,
   {{0x6b4f054e,0xf8bf8a99,0x38698a9a,0x00000000}},	// [9650] søge, nném_, _igar_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69240254,0x6916008b,0x776d0069,0x98a90207}},	//   rđev, ršev, _huax, _ljač_,
   {{0x3cda1a75,0x55da02b5,0x657a0172,0x2499002f}},	//   _खोले_, _פֿינ, íthe, _udsm_,
   {{0x69de08b7,0x00000000,0x00000000,0x00000000}},	//   _špel, --, --, --,
   {{0x644f8a9b,0xf8bf00b8,0x7af80069,0x3ebe055c}},	//   _izci, dném_, _novt, _cbtt_,
   {{0x3ce7009a,0x7bc2002a,0xf8bf00b5,0x00000000}},	//   झाले_, _apou, tnél_, --,
   {{0x673c0693,0x7d760037,0x69168a9c,0x00000000}},	//   zorj, أمير_, nšet, --,
   {{0x395200e9,0x76450086,0xdb090132,0xe0d20070}},	//   _rhys_, _lyhy, nteç, _אײן_,
   {{0x38694322,0x7cfc68f3,0x05cb03de,0x0eb502b4}},	//   _agar_, _sért, ाबाब, _आउटड,
   {{0x7bc22870,0x673c008b,0x4a451646,0x2fdf0069}},	//   _epou, vorj, янов, _hrug_,
   {{0x2fdf0254,0x63b61667,0x69d004aa,0x00000000}},	//   _krug_, ytyn, धिजी, --,
   {{0x6a850210,0x673c8a9d,0x7cfc8a9e,0xe81c11b5}},	//   _елла, torj, _vért, _पेशा_,
   {{0x4e1f0c3e,0x7bda0122,0xbb78042c,0x2cad00be}},	//   _बधाई_, _לקנו, _بلوچ_, lged_,
   {{0x386d0b79,0x38690069,0x7cfc021d,0x7645016e}},	//   žera_, _fgar_, _gérs, _cyhy,
   {{0x63b603ad,0x2cad8a9f,0x673c8aa0,0x141a0037}},	//   ttyn, nged_, sorj, ميزة_,
   {{0x2fdf0221,0xf42a016f,0x776d0183,0x644f0067}},	// [9660] _nrug_, _opäť_, _guax, _czci,
   {{0x63b68aa1,0x7af8006f,0x00000000,0x00000000}},	//   rtyn, _xovt, --, --,
   {{0x63b68aa2,0xe57700af,0x00000000,0x00000000}},	//   styn, _нзэ_, --, --,
   {{0x2fdf0022,0xa99a0070,0x63b6010b,0x4fea0210}},	//   _brug_, מבער, ptyn, ймен_,
   {{0x09a80567,0x61e100b5,0x2cad024b,0x2fdf0090}},	//   _कम्य, _álln, dged_, _crug_,
   {{0x69c30c7c,0xf67a02b5,0x290b0029,0x63a48aa3}},	//   _opne, זאַמ, ībai_, mrin,
   {{0x7bc28aa4,0x629c8aa5,0xf8bf000d,0x26d800ea}},	//   _spou, _idro, liée_, idro_,
   {{0x27e08aa6,0x2cad8aa7,0xf8bf2e7f,0x628e60cc}},	//   _orin_, gged_, tném_, _hebo,
   {{0x7cfc00fb,0x65668aa8,0x628e1b0f,0x8fa30847}},	//   _sérs, _mikh, _kebo, _пате,
   {{0x628e8aa9,0x63a48aaa,0x99980370,0x65668aab}},	//   _jebo, irin, окот_, _likh,
   {{0x63a48aac,0x6446008a,0x27e08aad,0x26ca008c}},	//   hrin, _lyki, _arin_, debo_,
   {{0x63a48aae,0x628e8aaf,0x27e03b7b,0x7c2d0693}},	//   krin, _lebo, _brin_, _žare,
   {{0xd83b005f,0x7cfc2cad,0x691601ba,0x629c088a}},	//   сэн_, _férr, všet, _odro,
   {{0x628e0252,0x63a40c60,0x27e08ab0,0xa3e0167e}},	//   _nebo, drin, _drin_, थिन_,
   {{0xd49b082e,0x27e08ab1,0x3abb00a5,0x15f60026}},	//   йра_, _erin_, _המונ, ीनगर_,
   {{0xca470082,0x63a48ab2,0x629c0297,0xf8bf0248}},	//   _عليه_, frin, _adro, fiée_,
   {{0x63a48ab3,0x628e8ab4,0x65668ab5,0x6d42000e}},	// [9670] grin, _bebo, _dikh, _mkoa,
   {{0xa3d2170c,0x02c70387,0x64461b84,0xfe1c00ab}},	//   विज_, रजेन, _dyki, _भइंस_,
   {{0x32072d87,0x3f8000af,0xd04700a8,0x63a48ab6}},	//   ány_, ţiul_, ələn, arin,
   {{0xf42a016f,0xdce800ee,0xdb000176,0x2fdf0207}},	//   _späť_, _budč, humà, _prug_,
   {{0xf8bf00f7,0x335900af,0x00000000,0x00000000}},	//   ciée_, _мамэ_, --, --,
   {{0x628e6e48,0x69240c99,0x2fdf053e,0x61e100b5}},	//   _gebo, nđer, _vrug_, _állo,
   {{0x30a78ab7,0x62850db6,0x60dd02d7,0x00000000}},	//   _нрав, mbho, _ósmo, --,
   {{0x629c1298,0x48e80083,0x26ca0036,0x752d773b}},	//   _zdro, _পত্র, zebo_, nnaz,
   {{0x2cad8ab8,0x26d88ab9,0x31340200,0x628e3998}},	//   rged_, ydro_, _четр, _yebo,
   {{0x7c26008a,0x69240124,0x6d4213bf,0x1a0502fb}},	//   úkra, jđer, _ekoa, дпом,
   {{0x25b80036,0x98a618cd,0x00000000,0x00000000}},	//   xtrl_, мине, --, --,
   {{0x27e009eb,0x63a48aba,0xec6e0d6e,0x81df0033}},	//   _prin_, yrin, _јп_, _তথা_,
   {{0xeb8e5c47,0x6d498abb,0xeaae01f5,0x26ca8abc}},	//   _ши_, mlea, _ий_, tebo_,
   {{0x6d498abd,0x65660044,0x752d1200,0x6d5b792f}},	//   llea, _sikh, enaz, lmua,
   {{0x63a44fbb,0xed16006c,0x36670036,0xe64303e6}},	//   wrin, _رہیں_, даро_, верп,
   {{0x628e308b,0x6d498abe,0x752d8abf,0x26ca87c7}},	//   _sebo, nlea, gnaz, sebo_,
   {{0x6d498ac0,0x59d50567,0xc95300a5,0x628e0159}},	// [9680] ilea, धिकर, _במה_, _pebo,
   {{0x03a30009,0x6d5b01f4,0xf8bf00f7,0x6d490719}},	//   тифо, hmua, riée_, hlea,
   {{0x6d498ac1,0x65660069,0xd46a2701,0x63a48ac2}},	//   klea, _tikh, _мине_, srin,
   {{0x6d5b01e8,0x628e8ac3,0x63a48ac4,0x69de13a2}},	//   jmua, _webo, prin, _špek,
   {{0x628e1b0e,0x6d49009e,0x00000000,0x00000000}},	//   _tebo, dlea, --, --,
   {{0xf8bf006c,0x2bd206fe,0x0efa1856,0x672e05ee}},	//   tnék_, तिघा, ्सेस_, nnbj,
   {{0x626318cd,0x672e008d,0xdb00003e,0x00000000}},	//   _авра, inbj, jumá, --,
   {{0x6d5b006d,0xe8e00023,0xed570fb4,0x9cb405f5}},	//   gmua, _trội_, мој_, رمخت,
   {{0xaf2a2e14,0xdb090051,0x00000000,0x00000000}},	//   _джаз_, cueë, --, --,
   {{0xadba004f,0xe4570070,0x6d4901b7,0x6d5b0118}},	//   _وهذا_, ויפט_, alea, amua,
   {{0x6d498ac5,0xf2d30122,0x1bec0084,0x5eeb0099}},	//   blea, דעת_, जमहल_, चार्_,
   {{0xcb6a06c2,0x27e60009,0xf1d10f06,0x6d5b8ac6}},	//   _даде_, _šona_, _सनसन, cmua,
   {{0xac9700bf,0x386d0009,0x752d0207,0x0cbc021a}},	//   _آنها_, žero_, vnaz, ्जीम,
   {{0x6d401ac5,0x28b10825,0xdce200f4,0x2f0b0249}},	//   loma, _झावि, _mioč, _løgn_,
   {{0xdb000020,0x7aea01ef,0x31c801d1,0x00000000}},	//   cumá, _inft, रबोध, --,
   {{0x6d408ac7,0x66f8027d,0x657a00b5,0xa2c10963}},	//   noma, _aşkı, ítha, र्न्,
   {{0x752d8ac8,0xf66b0037,0x69de0207,0x00000000}},	// [9690] rnaz, _وحده_, _špeh, --,
   {{0x6d408ac9,0x6d4901d7,0x00000000,0x00000000}},	//   homa, zlea, --, --,
   {{0x6d408aca,0xda0e0fd0,0x7cf50279,0x60cb0103}},	//   koma, ानित_, _várz, tegm,
   {{0xdce20c99,0xa49b009e,0x5576016b,0x00000000}},	//   _bioč, _clòt, _רערן_, --,
   {{0x6d408acb,0x6d5b01e8,0x2f0b0c71,0x257501ff}},	//   doma, vmua, _døgn_, _hål_,
   {{0x63ad0e89,0x60cb0408,0x25753a29,0x00000000}},	//   muan, segm, _kål_, --,
   {{0x6d408acc,0x63ad8acd,0x20094cd6,0x6d498ace}},	//   foma, luan, šai_, tlea,
   {{0x257504ca,0xdfd50f99,0x7e7a081b,0x28c11140}},	//   _mål_, _побы, _eftp, ष्मि,
   {{0x6d498acf,0x6d5b8ad0,0x00000000,0x00000000}},	//   rlea, rmua, --, --,
   {{0xa3e00162,0x6d498ad1,0xfaf1004f,0x6d5b8ad2}},	//   थित_, slea, اثة_, smua,
   {{0x6d498ad3,0x69265288,0x6d407e79,0xf8bf2939}},	//   plea, емна, boma, ffé_,
   {{0xdb090370,0x6d408117,0x63ad2638,0xe8f705d8}},	//   nteú, coma, kuan, елю_,
   {{0x63ad06b3,0xfaa51517,0x2ba600ab,0x00000000}},	//   juan, _зало, _खिया, --,
   {{0x63ad8ad4,0x7d098ad5,0x257504c1,0xa2c11e18}},	//   duan, lkes, _bål_, र्म्,
   {{0xe73718cd,0x644b018d,0x00000000,0x00000000}},	//   хер_, ügin, --, --,
   {{0x7c240121,0x69a40099,0x63ad08c7,0x1da70067}},	//   _žiri, _किती, fuan, _गिनत,
   {{0x63ad885e,0xa49b0359,0x03a302d5,0x00000000}},	// [96a0] guan, _alòs, лито, --,
   {{0x28c10026,0x068600d8,0xdbc6007c,0x31710eaf}},	//   ष्ठि, _ягон, _tööa, _buzz_,
   {{0x6d400858,0x7d090c61,0xa49b3df6,0x00000000}},	//   yoma, kkes, _clòs, --,
   {{0x26da0657,0x397a0070,0xa2c10808,0x3171008c}},	//   _hapo_, לטענ, र्ब्, _duzz_,
   {{0xe7e30bda,0x43754a7f,0xd12f211f,0x63ad8ad6}},	//   खिया_, _ауст, حمن_, cuan,
   {{0x26da8ad7,0x2d8c08dd,0x8d734574,0x00000000}},	//   _japo_, _pwde_, گاوا, --,
   {{0x2d9a8ad8,0x26da8ad9,0x5d661956,0x00000000}},	//   épe_, _mapo_, нтиз, --,
   {{0xc5f30122,0x91bb0122,0x8d7300b5,0x55db0070}},	//   רדה_, _ממלי, داوا, פֿונ,
   {{0x6d408ada,0xef1a1dd0,0x5ce300c3,0x00000000}},	//   roma, _ема_, ующа, --,
   {{0x2d6e000c,0x6b4f01b4,0xd00f0037,0x00000000}},	//   _před_, søgn, _الك_, --,
   {{0x6d408adb,0xddc80067,0x00000000,0x00000000}},	//   poma, _wzdł, --, --,
   {{0x69b1004e,0x63ad68ad,0x6d40085a,0x0fd4021a}},	//   _अमरी, yuan, qoma, _धनाढ,
   {{0xb8d90cc5,0xa2c10026,0x26da8adc,0xbb2b00b5}},	//   _चा_, र्ड्, _bapo_, _کتنے_,
   {{0x26da8add,0xe6672725,0x25754a11,0x00000000}},	//   _capo_, етбо, _pål_, --,
   {{0x39428ade,0x95c80948,0x63ad012f,0x692b0355}},	//   boks_, нута_, wuan, třed,
   {{0x290b0ae0,0x63ad8adf,0x98b40009,0x799a0067}},	//   ības_, tuan, _ćećo_, mstw,
   {{0x68ed8ae0,0xb4db0176,0x31710298,0x799a0067}},	// [96b0] _inad, _khàz, _suzz_, lstw,
   {{0x26da0160,0x1de0060a,0x59a4021a,0x00000000}},	//   _gapo_, पटात, _खटार, --,
   {{0x799a8ae1,0x692b00b8,0x171c016b,0xdb000553}},	//   nstw, před, _מוזע, mumä,
   {{0x21260526,0xc60d0026,0x672701a8,0xdb00194e}},	//   gioh_, सनीय_, lijj, lumä,
   {{0x63ad8ae2,0x389c02b5,0x68ff0069,0x26da002f}},	//   quan, ליאנ, _moqd, _yapo_,
   {{0x7d093889,0xf3ff0019,0x4439011e,0x6da58ae3}},	//   wkes, _ngãi_, _ixs_, вика,
   {{0x5334107b,0x68ed8ae4,0x7d0903a6,0xa2c10e61}},	//   _серт, _onad, tkes, र्ण्,
   {{0x6297063c,0x68ed030d,0x2efe034d,0x00000000}},	//   laxo, _nnad, _eotf_, --,
   {{0xa2c100a1,0xdb0018af,0x7d093993,0xbbbd021a}},	//   र्थ्, kumä, rkes, ्बेक,
   {{0xf8aa0c67,0x68ed0a97,0x7d098ae5,0x60db8ae6}},	//   कल्प, _anad, skes, _haum,
   {{0x60db8ae7,0x39428ae8,0x68ed007a,0x3d9500af}},	//   _kaum, toks_, _bnad, _риер,
   {{0xa2c10914,0xdb26006c,0x60db12c3,0x26da8ae9}},	//   र्त्, _یونی, _jaum, _sapo_,
   {{0x26da8aea,0x60db8aeb,0x7d060086,0x644b00ab}},	//   _papo_, _maum, ökse, ügil,
   {{0x4ad700f5,0xfaa58aec,0x2ba61edf,0x68ed06e8}},	//   _ساتھ_, _рако, _खिता, _enad,
   {{0xceb25c8e,0x6d598aed,0x6297002a,0x6b9b8aee}},	//   יים_, _khwa, daxo, lsug,
   {{0x26da0054,0x44390176,0x68ed02b1,0xe1f203fc}},	//   _wapo_, _bxs_, _gnad, یسا_,
   {{0x26da010b,0xb4664054,0x6b9b3176,0xe3ba1ac5}},	// [96c0] _tapo_, ткал, nsug, ьба_,
   {{0xdb000095,0x68ed012e,0x290000be,0x7d1e00fd}},	//   rumç, _znad, _hoia_, épsz,
   {{0x60db8aef,0xa2c105f8,0x21260009,0x68ed016e}},	//   _baum, र्ध्, tioh_, _ynad,
   {{0xdcfe0029,0x29008af0,0x443900ee,0x6b9b0839}},	//   īvīb, _joia_, _fxs_, ksug,
   {{0xe0434697,0x087702b5,0x7c2d8af1,0x60db8495}},	//   анци, דענט_, _žarn, _daum,
   {{0xdcbc01d1,0xa2c101c0,0x7f4339c5,0xa3c10f09}},	//   ्ज्ञ, र्द्, gonq, ूबर_,
   {{0x2912073a,0x00000000,0x00000000,0x00000000}},	//   _olya_, --, --, --,
   {{0x6d598af2,0x60db8af3,0x29008af4,0x00000000}},	//   _chwa, _gaum, _noia_, --,
   {{0x6b9b03be,0x5ec70033,0x6d590069,0x50460b00}},	//   gsug, লয়ে, _dhwa, _реаб,
   {{0x7f438af5,0x68ed01c0,0x6d5902c2,0x3f868af6}},	//   conq, _snad, _ehwa, mpou_,
   {{0x7c2d008a,0x29003811,0x3f860952,0x60db25e8}},	//   _þarn, _boia_, lpou_, _yaum,
   {{0x0c265544,0x799a004e,0xe8e001a5,0x60c28af7}},	//   _имен, rstw, _trời_, nfom,
   {{0x692b000c,0xeb970043,0x68ed00ac,0x290001ed}},	//   třeb, _аич_, _vnad, _doia_,
   {{0xf8bf0831,0xe9e63db0,0x644b00be,0x2912030d}},	//   cién_, _ацио, ügim, _elya_,
   {{0xf62800d4,0xdb00013c,0x9f4401f4,0x00000000}},	//   віти_, rumä, _armë_, --,
   {{0x69d88af8,0x68ed002f,0x29008af9,0x00000000}},	//   _isve, _unad, _goia_, --,
   {{0x60db8afa,0x54558afb,0xe8d901a5,0x24898afc}},	// [96d0] _raum, уват, _nhỉ_, rbam_,
   {{0xe3b00037,0x36d50421,0x29000139,0x00000000}},	//   ترف_, _соор, _zoia_, --,
   {{0x26d18afd,0x60db8afe,0x7c360093,0x00000000}},	//   mezo_, _paum, _þyrf, --,
   {{0x3015395b,0x26d10657,0x2600000c,0x2900002a}},	//   лдер, lezo_, रहरी_, _xoia_,
   {{0xe8d900e8,0xd91c00c2,0x251a0122,0x443f01a5}},	//   _chỉ_, וואל, _נושא, _âu_,
   {{0xb87b0a20,0x60db0054,0x7c2d0a66,0x69ca033b}},	//   ndíb, _waum, _žaro, _opfe,
   {{0x60db8aff,0xf8bf0248,0x2d94010b,0x3ea9013b}},	//   _taum, nnés_, арыс, ğat_,
   {{0x26d1000e,0x39490221,0x2bb700a1,0x3ea98b00}},	//   hezo_, _nkas_, _आमदा, şat_,
   {{0x26d130c6,0x0b450279,0x69ca033b,0xdc310225}},	//   kezo_, лнин, _apfe, _düğm,
   {{0x6b9b8b01,0x29008b02,0xcf8e00e0,0x62951bd8}},	//   rsug, _soia_, _رژه_, _jezo,
   {{0xa2ca1e79,0x6d5931dc,0x2bd80324,0x6b9b7fb9}},	//   _सॉफ्, _thwa, _बैठा, ssug,
   {{0x69a4009a,0x6f018b03,0x62953e4e,0x61f80454}},	//   _किरी, _holc, _lezo, ävli,
   {{0x316d078a,0x69d8081d,0x6f016064,0x3cef0036}},	//   _miez_, _esve, _kolc, _ingv_,
   {{0x6295024e,0x26d143d1,0xb8eb0127,0x316d00f6}},	//   _nezo, gezo_, _रॉ_, _liez_,
   {{0x64a62b33,0xf8bf00f7,0x2b4501f7,0x68ef0098}},	//   лава, gnés_, molc_, áidí,
   {{0x31bc00b5,0xf48401df,0xdb090345,0x00000000}},	//   víz_, شاری, kreë, --,
   {{0x629504ce,0xdce100ea,0x78a401e9,0x00000000}},	// [96e0] _bezo, _atlī, _idiv, --,
   {{0xb463135b,0xdb0009af,0xb87b0138,0x31bc02d7}},	//   скул, stmö, rdíe, tíz_,
   {{0x62958b04,0xd24f004f,0x9abc003c,0x9e3c00ee}},	//   _dezo, كنك_, fiċj, _odďa,
   {{0x19b60070,0x2b4502c4,0x2f0b0a8a,0x79830103}},	//   טפער_, holc_, _høgh_, _mtnw,
   {{0x316d8b05,0xdb090298,0x00000000,0x00000000}},	//   _diez_, greë, --, --,
   {{0x62958b06,0x6f0141e1,0xa8570122,0x3f86002a}},	//   _gezo, _colc, ניסה_, rpou_,
   {{0x6b8238c4,0x6f0102fb,0xdb1b00f7,0x2b07000c}},	//   _stog, _dolc, ctué, ाउनु_,
   {{0xd1321d05,0x78a40054,0x386d25e2,0x62950103}},	//   _امر_, _ndiv, žeri_, _zezo,
   {{0x5b144599,0xa2c10e61,0x6f018b07,0x101600d8}},	//   имит, र्व्, _folc, _сьвя,
   {{0x78a41ea3,0x6f018b08,0x00000000,0x00000000}},	//   _adiv, _golc, --, --,
   {{0x02c60266,0x26d1023a,0x00000000,0x00000000}},	//   र्यभ, vezo_, --, --,
   {{0xdd8f00ce,0x26d10195,0x644b00ab,0x69de02c4}},	//   _روه_, wezo_, ügik, _špes,
   {{0xe8d900e8,0x31d17a51,0xed575866,0xdb000037}},	//   _giờ_, _सन्ध, _соц_, armá,
   {{0x8c1b0122,0xdb1e01ff,0x78a40183,0x3dd20067}},	//   _אודי, övän, _ediv, ływu_,
   {{0x62958b09,0x7d021eca,0x26d1070b,0x65951fb1}},	//   _rezo, _koos, rezo_, рабу,
   {{0x99830082,0xf8bf488c,0x7d028b0a,0xa7754a35}},	//   _اليو, rnés_, _joos, _клич,
   {{0x291909c3,0x176b737f,0x62951725,0x26d105c9}},	// [96f0] mhsa_, _проп_, _pezo, pezo_,
   {{0x27e98b0b,0x83050033,0x7d0219a6,0xb87b0176}},	//   _iran_, োচ্চ_, _loos, bdíc,
   {{0xe8d90023,0x629557f9,0xa2c1012f,0x80270594}},	//   _nhị_, _vezo, र्ष्, گرام,
   {{0x6f018b0c,0x32648b0d,0x19b702b5,0xd0110037}},	//   _solc, стув, רפאר_, يلا_,
   {{0x4ac45860,0x35ab0066,0x6f015a62,0x656f009e}},	//   वभाव, _छिड़, _polc, _iich,
   {{0x656f0657,0xa2c10ca1,0xaec400d4,0xde050819}},	//   _hich, र्श्, йбіл, ипли,
   {{0x656f8b0e,0xe8d90028,0x6f010d2e,0x41e40560}},	//   _kich, _chị_, _volc, _літа,
   {{0x27e98b0f,0x63ad8b10,0x656f8b11,0x7d020118}},	//   _oran_, oran, _jich, _coos,
   {{0x656f8b12,0x7d027153,0x9ed901d3,0x60c90371}},	//   _mich, _doos, _имат_, _ibem,
   {{0x656f8b13,0x63ad210b,0x1605112b,0x644f8b14}},	//   _lich, iran, रहार_, _myci,
   {{0x63ad531e,0x69de024e,0x27e98b15,0x656f8b16}},	//   hran, _šper, _aran_, _oich,
   {{0x656f328b,0x7d023eed,0xd9462c0f,0xf8661158}},	//   _nich, _goos, реми, ивно,
   {{0x690601ef,0x63ad011c,0x27e900a2,0x2fcd190f}},	//   _bóer, jran, _cran_, _jpeg_,
   {{0x7d0201e8,0x656f8b17,0x6b898b18,0x657701f4}},	//   _zoos, _aich, mpeg, _buxh,
   {{0x27e98b19,0x656f8b1a,0x63ad8b1b,0x660319b6}},	//   _eran_, _bich, eran, опра,
   {{0x69c18b1c,0x63ad8b1d,0x7de0006c,0x27e906aa}},	//   mtle, fran, lásá, _fran_,
   {{0x27e925ac,0x656f8b1e,0x63ad8b1f,0x03260402}},	// [9700] _gran_, _dich, gran, адан,
   {{0x656f48b0,0x60c9251e,0xa2c137e8,0x69c112ba}},	//   _eich, _abem, र्ल्, otle,
   {{0x656f8b20,0x63ad8b21,0x69c1691f,0xb87b0300}},	//   _fich, aran, ntle, ldía,
   {{0x2ba61033,0x3fe60836,0x759b00a5,0xe1650037}},	//   _खिला, ижев, _ביטח, مدني,
   {{0x7d0231a1,0xb87b2675,0xdb0907a6,0x69c100ab}},	//   _roos, ndía, nteó, htle,
   {{0x656f0a75,0x69c154b2,0x7d0200ab,0x65643f60}},	//   _zich, ktle, _soos, lmih,
   {{0x71a304d9,0xdd97004b,0x7de0006c,0x7d028b22}},	//   _марз, ашы_, dásá, _poos,
   {{0x9cca01c8,0x5bb81a1d,0x61433ad5,0x7bc00938}},	//   тыка_, глия_, _деса, ttmu,
   {{0x69c1004e,0x02c6018d,0xa067027a,0x24800098}},	//   etle, र्थभ, _вата_, icim_,
   {{0xe8d900e8,0x5b1403ad,0x31788b23,0x7bc08b24}},	//   _thị_, смот, _kurz_, rtmu,
   {{0x13cf00c8,0x257c0082,0x7d020103,0xbca600bf}},	//   রিয়, _níl_, _toos, _نماي,
   {{0x27e9142f,0xe7e30e6f,0x6b89009e,0x00000000}},	//   _pran_, खिला_, bpeg, --,
   {{0x656f40ad,0xdc54006c,0xd83b0409,0x69c18b25}},	//   _rich, _اراک, тэн_, atle,
   {{0x656f02bf,0x63ad00a3,0x257c0093,0x98a20228}},	//   _sich, vran, _bíl_, rikā_,
   {{0x656f0657,0x69c102a2,0x257c00b8,0x35e4093e}},	//   _pich, ctle, _cíl_, оцтв,
   {{0x7969004e,0xf9930122,0x257c00b8,0x00000000}},	//   _oświ, _ורק_, _díl_, --,
   {{0x656f8b26,0xd3710ad9,0x98ab0139,0x00000000}},	// [9710] _vich, سها_, ancă_, --,
   {{0x656f02c9,0x59da007c,0x63ad8b27,0x7c2d0bc6}},	//   _wich, _बनार, rran, _žark,
   {{0x656f8410,0x63ad4225,0x644f004e,0x81a7103b}},	//   _tich, sran, _wyci, شحال,
   {{0x63ad8b28,0x7de0006c,0x7a0a00a8,0x386d0506}},	//   pran, zásá, mətd, žeru_,
   {{0x752d8b29,0x6b5d000d,0x00000000,0x00000000}},	//   miaz, lège, --, --,
   {{0x752d8b2a,0x2d952876,0x43942214,0x00000000}},	//   liaz, брис, _фарс, --,
   {{0x51843379,0x692b01c0,0x7de000b5,0x00000000}},	//   _мута, vřen, vásá, --,
   {{0x752d8b2b,0x657a0037,0xdb0900be,0x60c90a8a}},	//   niaz, íthi, steü, _ubem,
   {{0x7de00332,0x3015195a,0x2ca6001e,0x692b01c0}},	//   tásá, _удар, _ddod_, třen,
   {{0x69c18b2c,0x6b892b02,0xe9d92374,0xa2ca0808}},	//   ttle, rpeg, гко_, स्प्,
   {{0x6b8986cf,0x39460ebb,0x7de000b5,0x6e4515f4}},	//   speg, йног, rásá, _انضم,
   {{0x69c18b2d,0x6b890c2c,0x1e56024b,0x00000000}},	//   rtle, ppeg, _השער_, --,
   {{0x69c18b2e,0x7d1b54b4,0x752d8b2f,0x291e010b}},	//   stle, mhus, diaz, ėta_,
   {{0xb87b0473,0x7d1b17ad,0x257c00ee,0xd75a0088}},	//   rdía, lhus, _píl_, الست_,
   {{0xba9a0052,0x1a65103b,0x7d1b08c7,0x00000000}},	//   _עסקי, _دیدی_, ohus, --,
   {{0x752d8b30,0x257c00d5,0x7d1b8b31,0x00000000}},	//   giaz, _víl_, nhus, --,
   {{0xdb090453,0xe45a8b32,0x24808b33,0xe2920037}},	// [9720] lteñ, ужа_, rcim_, كذا_,
   {{0x65646096,0x57fb011d,0xd83f1dab,0xb87b8b34}},	//   smih, _עליו, áček_, ndín,
   {{0xdb090391,0x7d1b8b35,0x8b5602b5,0xd36f0037}},	//   nteñ, khus, ציעס_, رهم_,
   {{0x752d4a10,0xd83f08b7,0x7ae60228,0x00000000}},	//   ciaz, šček_, ēkti, --,
   {{0x7d1b8b36,0x4f96005f,0xd9a4198f,0x2d6e00fe}},	//   dhus, ёрду, _खट्ट, _dřel_,
   {{0xd0070500,0xe4570070,0x6e9344ab,0xdb090176}},	//   сеље_, _ליכט_, пишу, dreï,
   {{0xacf810be,0x44208b37,0x629e8b38,0x0eb90409}},	//   инку_, lzi_, mapo, ручы_,
   {{0x629e3234,0x7d1b8b39,0xa06a0ece,0x44208b3a}},	//   lapo, ghus, _баба_, ozi_,
   {{0x44201ae0,0x660e00ac,0x1eaa2e22,0xfe7202ed}},	//   nzi_, hybk, _ماضي_, _فدا_,
   {{0xbea343f7,0x629e8b3b,0x752d8b3c,0x44207663}},	//   _наук, napo, ziaz, izi_,
   {{0x9cca4fa1,0x7d1b0b3e,0x672e012f,0xaa5829af}},	//   _была_, bhus, dibj, рину_,
   {{0x7d1b8b3d,0xeb9a021d,0x629e8b3e,0xe8d90019}},	//   chus, _бид_, hapo, _thọ_,
   {{0x629e8b3f,0x752d8b40,0x6ebf13a0,0x44201b19}},	//   kapo, viaz, ल्कु, jzi_,
   {{0x44208b41,0xa2ca018d,0xdc3b02b5,0x3bbb00a5}},	//   dzi_, स्म्, _געדר, _עמוד,
   {{0x44208b42,0x752d8b43,0x50c81365,0x2499023a}},	//   ezi_, tiaz, रभाष, _pesm_,
   {{0x7a0a0095,0x2f0b0044,0x00000000,0x00000000}},	//   rətd, _høgt_, --, --,
   {{0x752d8b44,0xc2991eb9,0x7a0a013b,0x00000000}},	// [9730] riaz, иках_, sətd, --,
   {{0x394b8b45,0x6aba0a8a,0x20d300e2,0x752d8b46}},	//   locs_, ngtf, _ải_, siaz,
   {{0xe5c72770,0x442025b4,0x752d8b47,0xd25b002d}},	//   _успо, azi_, piaz, уца_,
   {{0x63b68b48,0x90551f1b,0xb87b0098,0xe1f00037}},	//   buyn, овец, idío, عسل_,
   {{0x692b0355,0x629e8b49,0x44205423,0x00000000}},	//   vřel, bapo, czi_, --,
   {{0xa19501c8,0x645d8b4a,0x3f691b79,0x079c076b}},	//   _магч, _izsi, шило_, נסול,
   {{0xe8d90028,0x7d1b206d,0x6ebf0808,0x00000000}},	//   _nhỏ_, thus, ल्गु, --,
   {{0xe6b606fe,0x3b850c9f,0xdb1b01ef,0x5ba90dec}},	//   _अञ्ज, олиг, rtuí, аким_,
   {{0xfc310514,0x7d1b31cb,0x98a21640,0x02c648cd}},	//   بحث_, rhus, niką_, र्वभ,
   {{0x7d1b8b4b,0x212f8b4c,0x49c98b4d,0xdce800fe}},	//   shus, ligh_, алон_, _kudě,
   {{0x44208b4e,0xb87b8b4f,0x1eea05f5,0x212f0767}},	//   zzi_, rdín, _خولی_, oigh_,
   {{0xc689168d,0x629e0d5c,0x212f004f,0xdb091111}},	//   _יא_, zapo, nigh_, rteñ,
   {{0x81c10083,0xdb090b06,0x2f1000f1,0xfaa500c7}},	//   ্টি_, steñ, _bàgh_, _дало,
   {{0x212f01a6,0x9f440279,0xfa690036,0x00000000}},	//   high_, _irmã_, _калк_, --,
   {{0x366a095d,0x44200107,0xa50a8b50,0xdb090453}},	//   раво_, wzi_, аева_, nreí,
   {{0x7ae38b51,0x44200291,0x81c10083,0x629e6aa9}},	//   _hant, tzi_, ্টা_, wapo,
   {{0x7ae305ca,0x629e03a2,0x44208b52,0x66e66af8}},	// [9740] _kant, tapo, uzi_, _допа,
   {{0x44207a05,0x29020496,0x27e000d1,0x6b840037}},	//   rzi_, ljka_, _isin_, _éige,
   {{0x629e271f,0x44200332,0x68e40fff,0x8c3d0095}},	//   rapo, szi_, _kaid, laşd,
   {{0x26d88b53,0x29020693,0x4fea8b54,0x212f0037}},	//   lero_, njka_, имен_, gigh_,
   {{0x7ae30160,0x68e411be,0x644b00be,0x2fd627f6}},	//   _oant, _maid, ügit, تتاح,
   {{0x26d88b55,0x7ae38b56,0x68e48b57,0xf4130122}},	//   nero_, _nant, _laid, _חפש_,
   {{0x63a48b58,0x629c0029,0x25b88b59,0x29192143}},	//   lsin, _iero, nurl_, ūrai_,
   {{0x7ae306ba,0x68e4004a,0xf1c3033a,0x26d88b5a}},	//   _aant, _naid, žší_, hero_,
   {{0xa2ca1ae9,0x7ae38b5b,0x629c8b5c,0x26d87a4d}},	//   स्थ्, _bant, _kero, kero_,
   {{0x7ae3248a,0x26d80033,0x3d1800d1,0x0a6a0ea0}},	//   _cant, jero_, _déwa_, ирни_,
   {{0x26d88b5d,0x7ae38b5e,0x27e08b5f,0x629c2f91}},	//   dero_, _dant, _asin_, _mero,
   {{0x68e48b60,0x25b80118,0x7c6500d1,0x38c900b5}},	//   _caid, durl_, _کامل, حادی_,
   {{0x26d88b61,0x2fc602b3,0x68e475e8,0x26e40083}},	//   fero_, ntog_, _daid, খানো_,
   {{0x629c1615,0x26d8050f,0x940b00a8,0xe8d90023}},	//   _nero, gero_, _gecə_, _thỏ_,
   {{0xd49b0896,0xc1c9004e,0xfb1b0122,0x68e48b62}},	//   ира_, _रहेग, _דוגמ, _faid,
   {{0x68e48b63,0x7ae38b64,0x63a48b65,0x692b01c0}},	//   _gaid, _zant, fsin, zřej,
   {{0x63a48b66,0x26d88b67,0x7ae38b68,0x61ee009f}},	// [9750] gsin, bero_, _yant, _arbl,
   {{0x68e48b69,0x7ae38b6a,0x26d88b6b,0xa3ac0299}},	//   _zaid, _xant, cero_, _गिर_,
   {{0x212f004f,0xdb1b6144,0x63a48b6c,0xa2c1012f}},	//   tigh_, ntuá, asin, र्ग्,
   {{0x69cd1e79,0x6f1a002d,0xa3b304bc,0x63a48b6d}},	//   _तहसी, _altc, _टिप_, bsin,
   {{0x629c8b6e,0x212f066a,0xdb090279,0x645d00d8}},	//   _fero, righ_, queç, _uzsi,
   {{0x629c8b6f,0x212f0037,0xdb1b1d8a,0x2d950c65}},	//   _gero, sigh_, ktuá, прис,
   {{0x7ae38b70,0x6d441b29,0x61ee0009,0x62853739}},	//   _rant, čian, _grbl, mcho,
   {{0x7ae31d24,0x62858b71,0x26d88b72,0x2fdf006d}},	//   _sant, lcho, zero_, _tsug_,
   {{0x26c10831,0x629c018e,0x26d88b73,0x2b80009e}},	//   _ocho_, _yero, yero_, _còc_,
   {{0x62858b74,0x68e48b75,0x68f68b76,0x7ae36203}},	//   ncho, _said, _snyd, _qant,
   {{0x26d8290a,0x63a48b77,0x68e48b78,0x5e590037}},	//   vero_, zsin, _paid, _الاس_,
   {{0x26c10370,0x9f440391,0x7ae38b79,0x63a48b7a}},	//   _acho_, _irmá_, _want, ysin,
   {{0x68e48b7b,0x29090069,0x2ee52069,0x00000000}},	//   _vaid, _doaa_, _kalf_, --,
   {{0x7ae30221,0x63a4093a,0x6285238b,0x25ac053d}},	//   _uant, vsin, jcho, ádlo_,
   {{0x26d88b7c,0x62858b7d,0x68e40086,0xa96a2d4d}},	//   rero_, dcho, _taid, _лика_,
   {{0x63a48b7e,0x629c8b7f,0xb4e60378,0x62858b80}},	//   tsin, _sero, पये_, echo,
   {{0x629c8ab5,0x26d88b81,0x63a463f6,0xa50701d3}},	// [9760] _pero, pero_, usin, чета_,
   {{0x63a48b82,0x213f0118,0x212d00e0,0xaabd06fe}},	//   rsin, _ajuh_, _ameh_, ्भिक,
   {{0x629c8b83,0x41b6081b,0x63a42212,0xc8b5006c}},	//   _vero, ясат, ssin, _علیک,
   {{0x629c8b84,0x63a41abf,0x39818b85,0x6362021d}},	//   _wero, psin, _mós_, dône,
   {{0x28c10d53,0x4abd164f,0x6285024e,0x6f088b86}},	//   ष्टि, ्भाव, bcho, _podc,
   {{0x628500f1,0xb87b00b5,0xfe700fa2,0x2ca00a69}},	//   ccho, gdíj, نگا_, _žid_,
   {{0x39818b87,0x2fc68b88,0x6f083b6d,0xe2970036}},	//   _nós_, stog_, _vodc, _хас_,
   {{0xc0e311ec,0x3860023a,0xa3b30761,0x00000000}},	//   _поск, _ozir_, _टिम_, --,
   {{0x614322cc,0x2ee50090,0x00000000,0x00000000}},	//   _чета, _falf_, --, --,
   {{0xfbcf0ad9,0xef170086,0x501b00a5,0x395200c7}},	//   اتي_, _ему_, _הומו, _akys_,
   {{0x39810042,0xa2c11ede,0x62830506,0xe8d900e2}},	//   _cós_, र्ट्, žnog, _nhể_,
   {{0x14ce0ac4,0xdb1b040f,0x628537fe,0x26c102b1}},	//   ह्मण, rtuá, zcho, _scho_,
   {{0xc8640a9f,0x6aa1099e,0xdb1b0279,0x48e4010b}},	//   етри, balf, stuá, хоўв,
   {{0x39810082,0x6aa10310,0xd90f0647,0xf53f0044}},	//   _fós_, calf, ئیک_, _sjå_,
   {{0xf98a0286,0x66140355,0xe3b30647,0x00000000}},	//   _اخته_, _čeká, کرز_, --,
   {{0x2a3b0122,0xe9450df3,0x00000000,0x00000000}},	//   _לעומ, _ترتی, --, --,
   {{0x6285139b,0x3375005f,0x93780210,0x00000000}},	// [9770] tcho, дгар, збут_, --,
   {{0x316400d7,0x62851697,0xc3540274,0x212d1b88}},	//   _ahmz_, ucho, екуј, _smeh_,
   {{0x62858b89,0xcb1300c2,0x69c88b8a,0x2ee58b8b}},	//   rcho, עלע_, ntde, _ralf_,
   {{0x62852668,0xf8bf8b8c,0xa2c1022e,0x7e7a008c}},	//   scho, ngé_, र्ज्, _agtp,
   {{0xf8bf00f7,0x62850103,0x9f840185,0xdee50fc5}},	//   liés_, pcho, егід, доли,
   {{0xf8bf006c,0xdb09726f,0x6622027d,0x6440003d}},	//   gnéz_, kreá, _öykü, _žmig,
   {{0x78ad8b8d,0x77770024,0xa2c200dc,0x6aa10523}},	//   _odav, _mixx, _लात्, valf,
   {{0x78ad01d5,0x3981451f,0x3d180118,0x7777009f}},	//   _ndav, _rós_, _déwo_, _lixx,
   {{0x1c4501e0,0x76570282,0xfc310079,0x39818b8e}},	//   ьним, _lyxy, ضحة_, _sós_,
   {{0x398103e6,0xa2c1143a,0xc9a900c3,0x7777007a}},	//   _pós_, र्च्, овое_, _nixx,
   {{0xd9460652,0x6aa13008,0xa96a18b4,0xbbeb01df}},	//   дени, ralf, жина_, _گرام_,
   {{0x77770176,0xf8bf8aaf,0x398132fb,0x657e02ec}},	//   _aixx, ggé_, _vós_, _ruph,
   {{0x200b0310,0x00000000,0x00000000,0x00000000}},	//   _àcid_, --, --, --,
   {{0xdb09004f,0xf8bf00f7,0x7bc98b8f,0xab6400d4}},	//   breá, fiés_, mteu, _звіл,
   {{0xbb52064e,0x69c804f4,0x28c60084,0x7bc98b90}},	//   _جنوب, ctde, _वापि, lteu,
   {{0x2cbf0006,0x291901f4,0x7d0b00b5,0x2d530132}},	//   ngud_, ërat_, _jogs, mães_,
   {{0x7bc98b91,0x3a0500b5,0x7d0600c3,0x644b00be}},	// [9780] nteu, _رکھی_, öksi, ügip,
   {{0xe8d9098b,0xa3cf0f8a,0x446300c9,0x7d0b508f}},	//   _thể_, _शहर_, твув, _logs,
   {{0xaacf00db,0xa50a06c2,0x4acf01d1,0xf8bf64cb}},	//   त्यक, _дена_, त्यव, ciés_,
   {{0x7bc922f7,0x7d0b03bc,0x00000000,0x00000000}},	//   kteu, _nogs, --, --,
   {{0xdfd00c36,0x10a3691a,0xd12f01ca,0x00000000}},	//   ايت_, тичн, جمن_, --,
   {{0xaacf00b4,0x6d4400d8,0x644601ed,0x00000000}},	//   त्मक, čiam, _ixki, --,
   {{0x7d0b8b92,0x69c845bd,0x2d8c0183,0xe8d900e2}},	//   _bogs, xtde, _qtde_, _giỗ_,
   {{0xa2ca00b4,0xfbaa0421,0xb87b00d5,0x00000000}},	//   स्र्, отой_, rdík, --,
   {{0xaec603fa,0x63620183,0x00000000,0x00000000}},	//   _обал, cônc, --, --,
   {{0xf1d2020d,0x98a00035,0x69c81b5f,0x7e610069}},	//   _सहान, _imię_, ttde, _fzlp,
   {{0x19590104,0x02b700a5,0x69351667,0x7bc98b93}},	//   заны_, והים_, енну, ateu,
   {{0x27f200e9,0x00000000,0x00000000,0x00000000}},	//   _bryn_, --, --, --,
   {{0x7bc97a39,0x69c88b94,0xf8bf69eb,0x7777007a}},	//   cteu, stde, rgé_, _pixx,
   {{0xf8bf000d,0x5fb10ed1,0x92c20831,0x00000000}},	//   tiés_, ुंतल, ্যু_, --,
   {{0xcad70122,0x8c3d00a8,0x7aea00ea,0x94d50fb4}},	//   _חוות_, maşa, ļotā, новц,
   {{0xf8bf0248,0x63b6001e,0x78ad00cd,0x8c3d00c1}},	//   riés_, fryn, _udav, laşa,
   {{0x29191772,0x24580086,0x63b68b95,0x27f20090}},	// [9790] ūras_, дать_, gryn, _gryn_,
   {{0xf8bf8b96,0xd25b8b97,0x00000000,0x00000000}},	//   piés_, оце_, --, --,
   {{0x518400d8,0x85750086,0xef19007a,0x2ca40051}},	//   вуча, _плох, _nuża_, kamd_,
   {{0xa5d803fc,0x63b68b98,0x2258008c,0x3395010b}},	//   _کبیر_, bryn, _dyrk_, _памё,
   {{0x24b60100,0xf8bf0248,0xd11000b4,0x656d8b99}},	//   _אהרן_, chée_, _ावरण_, mmah,
   {{0x2489566d,0x2f1800c3,0x80db01c0,0xe7b2046c}},	//   lcam_, мочь_, _नसके, _जिसप,
   {{0x6d420044,0xa3e70835,0x00000000,0x00000000}},	//   _bjoa, भिक_, --, --,
   {{0x656d8b9a,0x7bc98b9b,0xef190067,0xeb998b9c}},	//   nmah, tteu, _duża_, пии_,
   {{0x313424df,0x656d01d7,0x7bc9000d,0x4fc4021d}},	//   _ретр, imah, uteu, _асха,
   {{0x7bc90b8b,0x656d0a4e,0x00000000,0x00000000}},	//   rteu, hmah, --, --,
   {{0xf2d202b5,0x7bc98b9d,0x656d046a,0xa2c20380}},	//   נעט_, steu, kmah, _लास्,
   {{0x7bc90248,0x2d5303e6,0x7a0a0095,0x63b60328}},	//   pteu, rães_, mətl, yryn,
   {{0x395e0029,0x656d010d,0x7a0a00a8,0x24890345}},	//   ēts_, dmah, lətl, dcam_,
   {{0x6d5b01d2,0xdb090392,0x00000000,0x00000000}},	//   llua, dreç, --, --,
   {{0xceb201f3,0xf8bf024e,0x6abd4ae7,0x7a0a00a8}},	//   טים_, riér_, ्भीर, nətl,
   {{0x2edc000c,0x656d0c86,0x63b6297a,0xf8bf00a2}},	//   _यस्त, gmah, tryn, thée_,
   {{0x6d5b1f54,0xc2b60274,0x7a0a013b,0xdb09021d}},	// [97a0] ilua, ељењ, hətl, greç,
   {{0x28c60026,0x7a0a00a8,0x63b68b9e,0x20ec00e2}},	//   _वाडि, kətl, rryn, _ới_,
   {{0xda0f06bc,0x64a68b9f,0xaac231d7,0x569b00a5}},	//   ाहित_, _пана, _शासक, _מייצ,
   {{0x92c20b52,0x4acf0099,0x4fc60e60,0x98ab002d}},	//   ্যে_, त्तव, еска, mică_,
   {{0x6d5b8ba0,0x9f4d01f7,0x98ab002d,0xdb090183}},	//   dlua, _creï_, lică_, creç,
   {{0xde5802a4,0x00000000,0x00000000,0x00000000}},	//   малі_, --, --, --,
   {{0x78a601cc,0x43438ba1,0x98ab0043,0x6d5b8ba2}},	//   kakv, _серв, nică_, flua,
   {{0xafe654e1,0x20110095,0x2f1001f7,0xdb0900c3}},	//   _побл, _əziz_, _pàgs_, hreä,
   {{0xcf4600ef,0x60c2023c,0xefb300fd,0x00000000}},	//   _знай, mgom, _مینگ, --,
   {{0x7a0a0095,0xef19003c,0xb87b0132,0x60c200c7}},	//   bətl, _tuża_, ndív, lgom,
   {{0x673500da,0x6d5b01e8,0x8c3d00a3,0x00000000}},	//   vizj, blua, raşa, --,
   {{0x60c28ba3,0x28c604aa,0xdca60183,0x67350035}},	//   ngom, _वाणि, _чади, wizj,
   {{0xac97004f,0x29198ba4,0xd7fb0200,0xb87b02d7}},	//   _أنها_, rksa_, чун_, veíd,
   {{0x98ab002d,0xd7630416,0x00000000,0x00000000}},	//   fică_, انسی, --, --,
   {{0x248944d1,0x6d4003bc,0x98ab002d,0xaa578ba5}},	//   tcam_, onma, gică_, _كلها_,
   {{0x7aea8ba6,0x92bd0083,0x6d408ba7,0x6b82002f}},	//   _haft, _আসে_, nnma, _kuog,
   {{0x656d026f,0x6d408ba8,0x24898ba9,0x7aea5209}},	// [97b0] rmah, inma, rcam_, _kaft,
   {{0x656d02e2,0xdbc7007c,0xdb090279,0x24894505}},	//   smah, _tööp, rreç, scam_,
   {{0x6b8201d3,0xa2c20026,0xb87b0453,0x975800a5}},	//   _luog, _लार्, seíd, _איזו_,
   {{0x75248baa,0x7aea0381,0x6d408bab,0x4668081b}},	//   chiz, _laft, jnma, _ярым_,
   {{0x3d040378,0x5eaa0083,0x6d5b006d,0xdce20168}},	//   वाने_, চ্ছে, vlua, _choč,
   {{0x4429000e,0x141a0122,0x6d405b80,0x63bf0036}},	//   mza_, _חושב, enma, muqn,
   {{0x1ea80037,0x00000000,0x00000000,0x00000000}},	//   راوي_, --, --, --,
   {{0x44290b23,0x7a0a0095,0x6d408bac,0x5ff510bb}},	//   oza_, rətl, gnma, _избу,
   {{0x44298bad,0x6d5b0f1a,0x7aea8bae,0x98ab002d}},	//   nza_, rlua, _baft, zică_,
   {{0x44298baf,0x7aea2c60,0x6d405d50,0xb87b01ef}},	//   iza_, _caft, anma, ndíu,
   {{0x3ea78bb0,0x7aea072e,0x27260023,0x28c60067}},	//   mant_, _daft, _hông_, _वादि,
   {{0x3ea78bb1,0x27260019,0x61f539a2,0xe8f71303}},	//   lant_, _kông_, _mrzl, влю_,
   {{0x7d09029d,0x44298bb2,0x88e30033,0x3ced0051}},	//   mjes, jza_, যাংক, mdev_,
   {{0x3ea78bb3,0x7d090332,0x44298bb4,0x98ab0043}},	//   nant_, ljes, dza_, tică_,
   {{0x80d25b7f,0x44298bb5,0x64a601c8,0x27260019}},	//   ण्डे, eza_, кава, _lông_,
   {{0x7d098bb6,0x3d0407b5,0x7d1b8bb7,0xd0470095}},	//   njes, वाये_, nkus, şlən,
   {{0x3ea78bb8,0x272601a5,0x03a618d4,0x7d1b048d}},	// [97c0] kant_, _nông_, тизо, ikus,
   {{0x7524659d,0x3ea78bb9,0x7983067f,0x7d1b1b43}},	//   shiz, jant_, _kunw, hkus,
   {{0x3ea78bba,0x44290012,0x7d1b8bbb,0x6d408bbc}},	//   dant_, aza_, kkus, ynma,
   {{0x6ec40e1d,0x27260019,0xb87b0279,0x60c200c7}},	//   _राहु, _bông_, rdív, ugom,
   {{0x2726098b,0x4429006a,0x6283029d,0x7c295d92}},	//   _công_, cza_, žnoa, jzer,
   {{0x7c296659,0x6d4016df,0xef19004e,0x78a418af}},	//   dzer, wnma, _dużo_, _leiv,
   {{0x200009eb,0x52de00b4,0x52d70070,0x7afe0310}},	//   ţii_, नजीस, _שולע_, _òpti,
   {{0xaacf06bb,0x7aea4534,0x7d0901f4,0x7d1b1b82}},	//   त्सक, _saft, gjes, gkus,
   {{0x3ea78bbd,0x6aa38bbe,0xafe31403,0x6d4003c1}},	//   bant_, _benf, _котл, rnma,
   {{0x3ea78bbf,0x2d6e01c0,0xf8eb0461,0x6aa30090}},	//   cant_, _přes_, _जोड़ा_, _cenf,
   {{0xc3335c8e,0x44298bc0,0x3f840054,0xdb00008a}},	//   שות_, zza_, _humu_, gsmá,
   {{0x3f848bc1,0x44298bc2,0x7c2900ee,0x7d1b3ee5}},	//   _kumu_, yza_, bzer, ckus,
   {{0xead48213,0x78a40a09,0x7c290035,0x27260023}},	//   _боль, _deiv, czer, _xông_,
   {{0x7bc08bc3,0x6aa38bc4,0x3f840273,0x7a0a00a8}},	//   mumu, _genf, _mumu_, nətk,
   {{0x4b7b02b5,0x4429009f,0x69d80051,0x3f84018e}},	//   _קאוו, wza_, _upve, _lumu_,
   {{0x44298bc5,0x3ea78bc6,0x628e8bc7,0x3f840103}},	//   tza_, zant_, _afbo, _oumu_,
   {{0x92a70202,0x3ea714e1,0x44298bc8,0xaacf06d9}},	// [97d0] вјел, yant_, uza_, त्वक,
   {{0x8c3d036a,0x68ed8bc9,0x3ea78bca,0x290b264f}},	//   daşl, _haad, xant_, ljca_,
   {{0x3ea78bcb,0x4429213b,0x7c2964a3,0x8af701c2}},	//   vant_, sza_, zzer, _şəki,
   {{0x7bc08bcc,0x290b2676,0x68ed8a5a,0x3ea75640}},	//   kumu, njca_, _jaad, want_,
   {{0x7bc08bcd,0x7d09029d,0x68ed8bce,0x28c60761}},	//   jumu, vjes, _maad, _वासि,
   {{0x68ed8bcf,0x6da52399,0x1dd400a1,0x657d8bd0}},	//   _laad, гика, _दहशत, _hish,
   {{0x3ea76e0d,0x657d8bd1,0xed592cdd,0x41e4010b}},	//   rant_, _kish, нок_, _кіта,
   {{0x3ea78bd2,0x68ed8bd3,0x27260019,0x61fa006c}},	//   sant_, _naad, _tông_, _átla,
   {{0x63ad8034,0x657d8bd4,0x7d098bd5,0xa2ca02e4}},	//   nsan, _mish, rjes, स्क्,
   {{0x645d8bd6,0x63ad8bd7,0x657d57c4,0x7d098bd8}},	//   _mysi, isan, _lish, sjes,
   {{0x68ed19c6,0x7c2900f5,0x645d8bd9,0x63ad8bda}},	//   _baad, szer, _lysi, hsan,
   {{0x63ad03d0,0x68ed0027,0x3ea50bf3,0x8c3d0092}},	//   ksan, _caad, _helt_, laşm,
   {{0xb8ec0c04,0x7bc08bdb,0x68ed50f9,0x78a4022b}},	//   _ला_, cumu, _daad, _veiv,
   {{0x63ad0557,0x70e0004e,0x2d858bdc,0x8afc004e}},	//   dsan, _नस्ल, _kule_, ględ,
   {{0x27e98bdd,0x7ae18bde,0x657d8bdf,0x2d8519b2}},	//   _esan_, melt, _bish, _jule_,
   {{0x68ed018e,0xaacf1d25,0x4acf0af9,0x63ad8be0}},	//   _gaad, त्रक, त्रव, fsan,
   {{0x63ad8be1,0x2fcd006d,0x636b8be2,0x2d858be3}},	// [97e0] gsan, _nqeg_, künd, _lule_,
   {{0x29000221,0xb87b006c,0x7ae18be4,0x68ed8be5}},	//   _hnia_, rdít, nelt, _zaad,
   {{0x2b890028,0x69c18be6,0xe8d90028,0x291200d7}},	//   _lúc_, nule, _nhớ_, _koya_,
   {{0x645d3e48,0x657d65a4,0x0cbe0083,0x291200de}},	//   _fysi, _gish, _আস্ত, _joya_,
   {{0x63ad8be7,0x7ae18be8,0x69c18be9,0x60c98bea}},	//   csan, kelt, hule, _dcem,
   {{0x6d598beb,0x69c1889c,0x2912046a,0x2d850118}},	//   _akwa, kule, _loya_, _bule_,
   {{0x7ae18bec,0x657d0010,0x6da3192f,0xe8d90023}},	//   delt, _yish, бија, _chớ_,
   {{0x69c18bed,0x7bc08bee,0x39ae00d8,0x657d1505}},	//   dule, tumu, vęs_, _xish,
   {{0x68ed17fd,0x7a0a0095,0x7ae151e3,0x6d4e0453}},	//   _raad, məti, felt, _íbam,
   {{0x68ed4d4e,0x7bc08bef,0x29008bf0,0x636b8bf1}},	//   _saad, rumu, _ania_, rüng,
   {{0x69c18bf2,0x7bc08bf3,0x2d858bf4,0x68ed8bf5}},	//   gule, sumu, _gule_, _paad,
   {{0x63ad8bf6,0x7bc02f85,0x39ae010b,0x27e90176}},	//   ysan, pumu, ręs_, _psan_,
   {{0x9cd70052,0x2900006a,0x657d8bf7,0x68ed1c55}},	//   _תודה_, _dnia_, _rish, _vaad,
   {{0x2d852058,0x7ae18a9b,0x6d4400d8,0x68ed2d69}},	//   _yule_, celt, čiau, _waad,
   {{0x69c18bf8,0xfa55006c,0x2912046a,0x657d8bf9}},	//   cule, _پروگ, _foya_, _pish,
   {{0x657d8bfa,0x63ad8bfb,0x636b8bfc,0x29120a95}},	//   _qish, tsan, zünd, _goya_,
   {{0x2b8901a5,0x27e98bfd,0xb97c0070,0x63ad8bfe}},	// [97f0] _xúc_, _usan_, _אנהי, usan,
   {{0x63ad8bff,0x6b5d0443,0x60c907e5,0x645d01ba}},	//   rsan, tègi, _scem, _vysi,
   {{0x94d5534c,0x645d8c00,0x657d8c01,0x7a0a00a8}},	//   _конц, _wysi, _tish, fəti,
   {{0x63ad8c02,0x4174004f,0x645d0035,0x7ae10742}},	//   psan, مانس, _tysi, zelt,
   {{0x69c18c03,0x636b04d4,0x63ad013b,0x3fca0088}},	//   zule, tünd, qsan, ندوی_,
   {{0x4ea700af,0x9f4d0037,0x6d598c04,0x7ae100ee}},	//   урда, _breá_, _skwa, xelt,
   {{0x28c6045c,0x7a0a0095,0x636b8c05,0x2b890023}},	//   _वालि, bəti, ründ, _súc_,
   {{0x3ea502c9,0x7ae101ae,0xa3b90084,0x69c10160}},	//   _welt_, welt, _घटा_, vule,
   {{0x7ae18c06,0xdcfa0029,0x69c1073a,0x3ea58c07}},	//   telt, _attē, wule, _telt_,
   {{0x69c18c08,0x15f70d53,0x2d851c55,0x394900be}},	//   tule, ुमार_, _tule_, _ajas_,
   {{0x8e840082,0xa2ca0ed1,0x7ae18c09,0x394636c3}},	//   _المه, स्ट्, relt, иног,
   {{0x69c18c0a,0x7ae18c0b,0x6d5901d5,0x2b890019}},	//   rule, selt, _ukwa, _túc_,
   {{0x6d44016f,0x69c18c0c,0x7ae18c0d,0x98ab0067}},	//   čiat, sule, pelt, nicę_,
   {{0x69c18c0e,0xf7720c9e,0x386900d7,0x98ab00ea}},	//   pule, تاج_, _dzar_, ējās_,
   {{0xe8d901a5,0x7a0a0095,0x29121d42,0xe5a60227}},	//   _giữ_, yəti, _toya_, риби,
   {{0xe8d900e2,0xb87b02d7,0x29008c0f,0x77868c10}},	//   _khờ_, seía, _unia_, _клиз,

   {{0xdb092587,0xe2ca4237,0x00000000,0x00000000}},	// [9800] queó, клад_, --, --,
   {{0xd9ec06bc,0xdce20023,0x130300d4,0xe29700af}},	//   _जनमत_, _khoă, озум, иау_,
   {{0x673c8c11,0x9c820097,0xb87b01ef,0x97260088}},	//   mirj, áčko, neín, _مفکو,
   {{0x316d1010,0x46d209b4,0xf1d70067,0x661c8c12}},	//   _chez_, द्रह, _ठहरन, myrk,
   {{0xe8d901a5,0x3d04193c,0x7a0a00a8,0xee1e04aa}},	//   _nhờ_, वासे_, rəti, बन्ध_,
   {{0x6b84004f,0x2f560370,0x03a30d9e,0x7a0a00a8}},	//   _éigi, штес, _фиро, səti,
   {{0x32070086,0x98a0023a,0x2ca6018d,0x00000000}},	//   änyt_, _alič_, _peod_, --,
   {{0x636b7b2e,0x387f00cd,0xdb0902d7,0xfa0b0033}},	//   rüne, žuri_, dueñ, শনাল_,
   {{0x673c247d,0xe8d901a5,0xeb06190a,0x386001d5}},	//   kirj, _chờ_, ачно, _nyir_,
   {{0xb87b00ee,0x3d0407b5,0x661c30f6,0x7dfc00af}},	//   feín, वाहे_, kyrk, _păsă,
   {{0xdb090300,0xd5b10023,0x2ca6018d,0x3d1800e0}},	//   gueñ, ới_, _teod_, _séwu_,
   {{0x6d446545,0x00000000,0x00000000,0x00000000}},	//   čias, --, --, --,
   {{0x7d028c13,0xdce800d8,0xab940037,0x6ecd09b4}},	//   _inos, _sudė, _التغ, _सामु,
   {{0x3d042fa9,0xa2c210b7,0x7bdb0070,0xd72401e0}},	//   वावे_, _लाग्, _סקוו, офсп,
   {{0xdb008c14,0x05770286,0xe45f00c3,0x00000000}},	//   gsmå, لارد, _syö_, --,
   {{0x8a7b0122,0xd498178e,0x26da0103,0x386901ed}},	//   _באות, иру_, _ebpo_, _tzar_,
   {{0x39598c15,0x673c01ed,0x628300f4,0x7d027d3f}},	// [9810] moss_, birj, žnom, _mnos,
   {{0x39590b74,0x3dde0176,0xa37b021d,0x00000000}},	//   loss_, _optw_, _opõe, --,
   {{0x6ecd0f39,0x8c1a0083,0x7d02030d,0x940500a8}},	//   _साबु, _তেমন_, _onos, _ələ_,
   {{0xe45f00c3,0xed4600f8,0x39590bf7,0x00000000}},	//   _työ_, _رپ_, noss_, --,
   {{0x8fe72a8a,0x00000000,0x00000000,0x00000000}},	//   рцед, --, --, --,
   {{0xc69502b5,0x7d020160,0xdee5272c,0x39598c16}},	//   זאַ_, _anos, соки, hoss_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4c69027a,0x7d0200ee,0x00000000,0x00000000}},	//   лийн_, _cnos, --, --,
   {{0x60db8c17,0x5f940185,0x7b160395,0x00000000}},	//   _ibum, _митт, _râur, --,
   {{0xb87b043f,0x7d0202c6,0x37bf0033,0x81da0831}},	//   teín, _enos, েবার, ়ির_,
   {{0x5d85004f,0x6d4401ba,0x656f4bca,0x673c08b7}},	//   _الصل, čiar, _ohch, virj,
   {{0xe8d90019,0x673c022e,0x39598c18,0xd94610da}},	//   _thờ_, wirj, goss_, семи,
   {{0x3d040ca1,0x60db8c19,0xdb090453,0x2cad0159}},	//   वारे_, _mbum, sueñ, maed_,
   {{0x63701a17,0xed590097,0x6b9600a5,0x7e6100c3}},	//   mäng, lož_, _הכסף_, _kylp,
   {{0xdb090083,0x63700ed4,0x59db0af9,0xadf9057c}},	//   queñ, läng, _बहिर, ्मिन_,
   {{0x636203e6,0x8a160122,0x6ab7111a,0xc4b80033}},	//   môni, _לחצו_, _आयुर, ুজ্জ,
   {{0xd6c3006c,0x63620279,0x673c008b,0x6b9b011e}},	// [9820] _کمپی, lôni, pirj, npug,
   {{0xadf90bc1,0xed5900b8,0x60db4296,0x00000000}},	//   ्मान_, hož_, _abum, --,
   {{0x63703230,0x644f8c1a,0x63620132,0xed598c1b}},	//   häng, _exci, nôni, kož_,
   {{0xa2d802e4,0x6eda06fe,0xd00f00e0,0x60db0211}},	//   _नॉर्, प्नु, کله_, _cbum,
   {{0x7d0202c4,0x657600d5,0x00000000,0x00000000}},	//   _rnos, mmyh, --, --,
   {{0x26ca8c1c,0x26d8001e,0x7d02011c,0x60db0103}},	//   ngbo_, nfro_, _snos, _ebum,
   {{0x877b0070,0xe8d90023,0x3d040518,0x6da30166}},	//   נאצי, _nhở_, वाले_, пија,
   {{0x5bb80945,0xeb200af6,0x27e08c1d,0x637016ad}},	//   алия_, यस्त_, _opin_, fäng,
   {{0x637015e5,0xa2d801c0,0x6b9b02b3,0xa0678c1e}},	//   gäng, न्थ्, gpug, _гата_,
   {{0x63620279,0x7b390187,0x00000000,0x00000000}},	//   fôni, lňuj, --, --,
   {{0xfbcf0609,0xe8d90019,0x63700282,0x273800a8}},	//   وتی_, _chở_, mänd, _günə_,
   {{0xa2d8000c,0x637015e5,0xd01c0083,0x195900d8}},	//   न्त्, länd, _দেয়_, рамы_,
   {{0x39598c1f,0x65641835,0x7d1d033b,0x26d88c20}},	//   ross_, dlih, össe, ffro_,
   {{0x56940382,0x998304a3,0x395902d7,0x81df0033}},	//   зарт, _کليو, soss_, তিত_,
   {{0xa3cb0378,0x27e00a21,0xa2c706fe,0x6eda143a}},	//   रंभ_, _epin_, ालस्, प्यु,
   {{0x3eae02bf,0x63700ed4,0x6aaa8c21,0x656402b3}},	//   haft_, händ, _heff, glih,
   {{0x7b390187,0x06e40033,0x6370017b,0x61ee0b88}},	// [9830] dňuj, মাজি, känd, _asbl,
   {{0x6b5d6105,0x8c1b00a5,0x6ecd020c,0x7a0a00a8}},	//   lègr, אומי, _साधु, bətt,
   {{0xa3a90084,0x656402b3,0xa2d80096,0x026b195c}},	//   _गौर_, blih, न्ध्, ушай_,
   {{0x6aaa00c3,0x69c002b4,0xa0c50079,0xddd40225}},	//   _leff, _विनी, زيتو, _şaşk,
   {{0xd00904de,0x636203e6,0xf8bf000d,0x6b9b01ef}},	//   реле_, zôni, ckée_, xpug,
   {{0xa2d8051d,0x2d9528fb,0xd00e0088,0xd5dd0066}},	//   न्द्, орис, ئلو_, _पहाड़,
   {{0x171c00c2,0x9f4402d7,0x8d750037,0x271c0070}},	//   רווע, _armó_, يابا, רווײ,
   {{0x60db0232,0xa63c00a5,0x6370017b,0x6ab8021d}},	//   _ubum, טגור, täng, _advf,
   {{0x798a01ae,0x6aaa8c22,0xe8d900e2,0x2cad00e5}},	//   _aufw, _beff, _nhố_, raed_,
   {{0x636203e6,0x637006d2,0xe9d903fa,0x1c4210b0}},	//   tôni, räng, ако_, ьным,
   {{0x7a690eb4,0x6aaa8c23,0x6b9b027a,0x7bc00312}},	//   ринг_, _deff, spug, armu,
   {{0x628301ba,0x63620279,0x63701193,0x2fc00009}},	//   ľnoh, rôni, mäne, šige_,
   {{0xbf8701a5,0x6d498c24,0xeaae1174,0x68e623b5}},	//   _điển_, mnea, _ой_, rekd,
   {{0x1ddd1746,0x6d5b8c25,0xd5b80029,0xe8d90019}},	//   _महात, loua, šām_, _thở_,
   {{0x6b8340ee,0x6b8b8c26,0x6d498c27,0x798a0027}},	//   _iing, _hugg, onea, _gufw,
   {{0x6d4941e3,0x6b838c28,0x39b50029,0x629501e4}},	//   nnea, _hing, mās_, _afzo,
   {{0x6d49006e,0x65644322,0x39b50080,0x6b838c29}},	// [9840] inea, rlih, lās_, _king,
   {{0x6b838c2a,0x6d498c2b,0x6b8b8c2c,0x70b40127}},	//   _jing, hnea, _mugg, ुल्ल,
   {{0x63704b47,0x6b838c2d,0x39b50ae0,0xe297021f}},	//   vänd, _ming, nās_, цах_,
   {{0x6b838c2e,0x69c10094,0x752d8c2f,0x806602fb}},	//   _ling, irle, chaz, овеж,
   {{0x63703230,0x69c101ae,0x7b390187,0x6b830065}},	//   tänd, hrle, rňuj, _oing,
   {{0x6b838c30,0x39b50080,0x44200010,0xa85700a5}},	//   _ning, kās_, myi_, חינה_,
   {{0x637006ea,0x39b50ae0,0x4420006c,0x272f01ae}},	//   ränd, jās_, lyi_, _fünf_,
   {{0x39b50029,0x63703f3b,0x752401d7,0x628701f4}},	//   dās_, sänd, nkiz, _zgjo,
   {{0x44208c31,0x6b8316c8,0x6aaa009e,0x4ae600d8}},	//   nyi_, _bing, _peff, оўна,
   {{0x6b838c32,0x37d00083,0xef190069,0xda7a1172}},	//   _cing, িবার, _bużu_, иян_,
   {{0x39b50029,0x6b5d00f7,0x28f90c00,0x6b830cd5}},	//   gās_, tègr, бень_, _ding,
   {{0x394d051b,0x6b838c33,0xe8d90028,0x6b8b2afb}},	//   ões_, _eing, _phố_, _fugg,
   {{0x44200232,0x6d408c34,0x6b8b8c35,0x58840409}},	//   jyi_, mima, _gugg, дыра,
   {{0x4432004e,0x39b500ea,0xa49b0176,0x6b838c36}},	//   dzy_, bās_, _enòl, _ging,
   {{0x39b50029,0x6ecd1ef5,0xdce20067,0x00000000}},	//   cās_, _सासु, _choć, --,
   {{0x6d408c37,0x6b838c38,0x2d8c60fd,0x81c20033}},	//   nima, _zing, _mude_, ্বা_,
   {{0x69c88c39,0x6b831642,0x2d8c003a,0x4420006c}},	// [9850] lude, _ying, _lude_, gyi_,
   {{0x6d408c3a,0x7415006c,0x2d8c8c3b,0x6b838c3c}},	//   hima, _ہوجا, _oude_, _xing,
   {{0x6d408c3d,0x2d8c8c3e,0x7c200297,0x69c88c3f}},	//   kima, _nude_, hymr, nude,
   {{0x6d4001c8,0xdb090082,0x44200010,0x7c200c61}},	//   jima, iseá, byi_, kymr,
   {{0x6d405306,0x4432006a,0x2d8c8c40,0x8c3d8c41}},	//   dima, czy_, _aude_, naşt,
   {{0x2d8c8c42,0x78ad8c43,0xf3ff0279,0x68fa00ea}},	//   _bude_, _leav, _irã_, ētdi,
   {{0x6b8b0a1f,0x6d490a32,0x69c88c44,0x6d5b8c45}},	//   _sugg, tnea, jude, toua,
   {{0x6d408c46,0x39b50029,0x69c800be,0x63700170}},	//   gima, vās_, dude, räne,
   {{0x6b838c47,0xb4e90803,0x3eac01b4,0x7c20016e}},	//   _ping, _यसै_, _fedt_, gymr,
   {{0x39b50080,0x6b838bfa,0x6d4909bb,0x49c92770}},	//   tās_, _qing, snea, блон_,
   {{0x44327701,0x6b838c48,0x78ad8c49,0x6d408c4a}},	//   zzy_, _ving, _beav, bima,
   {{0x39b50029,0x3f85141d,0x6b8b8c4b,0x4420030d}},	//   rās_, _hilu_, _tugg, yyi_,
   {{0x39b500ea,0x3f8562c2,0x3f8d0392,0x7bf900af}},	//   sās_, _kilu_, _jueu_, _ындр_,
   {{0x6b83000e,0xdb091111,0xed3500b5,0x39b500ea}},	//   _uing, rreó, _بوچھ, pās_,
   {{0xe7370834,0x8c3d0395,0x69c80d2e,0x64a61a0b}},	//   чер_, raşu, cude, заба,
   {{0x4432401f,0x7d19022e,0x78ad0120,0x3f85035f}},	//   tzy_, _jows, _geav, _lilu_,
   {{0x39428c4c,0x75246464,0x1aee0083,0x3cdd25de}},	// [9860] miks_, rkiz, জারে_, क्ये_,
   {{0x443212ad,0x6d403aa0,0x68f68c4d,0x394242c3}},	//   rzy_, zima, _hayd, liks_,
   {{0x44268c4e,0x4432006a,0x68f601d6,0x6d406f6a}},	//   šo_, szy_, _kayd, yima,
   {{0x39428c4f,0x3f8d002a,0x7d190035,0x68f68a00}},	//   niks_, _bueu_, _nows, _jayd,
   {{0x6d4001c8,0x68f6027b,0xa3cb0722,0xf3ff0132}},	//   vima, _mayd, रूद_, _grã_,
   {{0x2d8c8c50,0x6d400027,0x394200ab,0x3f85022f}},	//   _pude_, wima, hiks_, _cilu_,
   {{0x91e3210e,0x10a600c9,0x69c000e7,0x63b62f36}},	//   _поре, _нивн, _विधी, lsyn,
   {{0xdb988c51,0x7d190069,0x69c801bc,0x2cea01e0}},	//   ович_, _cows, vude, сько_,
   {{0x5f76006c,0x7ae80523,0x7bc98c52,0x63b617ad}},	//   _فائر, tedt, gueu, nsyn,
   {{0x6d408c53,0x81df00c8,0xb4e9046c,0xab970037}},	//   sima, তির_, _यस्_, أخير_,
   {{0x6d408c54,0x68f60471,0x78ad007c,0x7ae88c55}},	//   pima, _bayd, _peav, redt,
   {{0x6f1a28c3,0x68f67f92,0xdb1b008d,0x394200ab}},	//   _hotc, _cayd, stuð, giks_,
   {{0x69c88c56,0x6f1a007e,0x00000000,0x00000000}},	//   sude, _kotc, --, --,
   {{0x69c81447,0x63b60044,0x8c3d10b1,0x636b027b}},	//   pude, dsyn, raşt, günl,
   {{0x68f606d3,0x78ad007c,0xa4d52327,0x645800a8}},	//   _fayd, _teav, мові, şvil,
   {{0x04c91ee1,0x5ec50033,0xf3ff021d,0x00000000}},	//   توري_, ল্পে, _prã_, --,
   {{0xdcfa0080,0x88bc00a5,0xe4542408,0xb86700fd}},	// [9870] _attī, _המחז, екты, _ڈاکو,
   {{0x2b5e00e2,0x6f1a0f00,0x00000000,0x00000000}},	//   notc_, _notc, --, --,
   {{0xa3b90785,0x4ad404e9,0x68f62f80,0x00000000}},	//   _घटक_, _दानव, _yayd, --,
   {{0x3f850ba8,0x6f080176,0x68f600cc,0x81df0033}},	//   _silu_, _andc, _xayd, তিল_,
   {{0x7d1901ef,0xe0d00d93,0x6f1a20f8,0xb4c90380}},	//   _rows, ازم_, _botc, ईली_,
   {{0xdb1b8c57,0x05b104ef,0xdce1003c,0x823702fd}},	//   truí, _जबाब, _kulħ, _فرزا,
   {{0x7d19004e,0x3f850d5c,0x6f1a00f6,0x272f0225}},	//   _pows, _vilu_, _dotc, _güne_,
   {{0xe8d901a5,0xa3e100a1,0x2d868c58,0x3b9503e6}},	//   _khổ_, _दहा_, _cioe_, мјот,
   {{0x3f850034,0x39428c59,0x6f1a0fbf,0x00000000}},	//   _tilu_, viks_, _fotc, --,
   {{0x81c200c8,0x290927b8,0x68f60644,0xdb090453}},	//   ্বর_, _anaa_, _sayd, treñ,
   {{0x13e600c8,0x39428c5a,0x7d192b28,0x1dc60066}},	//   নিয়, tiks_, _tows, रूआत,
   {{0x68f60095,0xdb091e6e,0x5fd12450,0x6fc400b4}},	//   _qayd, rreñ, _समाल, _रिमू,
   {{0x636b0644,0x3942007c,0x7bc98c5b,0x8c3d0a21}},	//   tünl, riks_, queu, raşs,
   {{0x59c50e6f,0x39428c5c,0x290908b7,0xdb0901ef}},	//   _विपर, siks_, _enaa_, preñ,
   {{0x212d4150,0x39427bb5,0xa3cb0067,0xd62a0382}},	//   _oleh_, piks_, रूस_, цове_,
   {{0xadf0007c,0x00000000,0x00000000,0x00000000}},	//   _अईसन_, --, --, --,
   {{0xd467014d,0x044319f8,0xc953011d,0x61e9011c}},	// [9880] дите_, ветн, _שמח_, _ćela,
   {{0x3cdd00e7,0x63b60c61,0x212d00d7,0xd77615f8}},	//   क्ते_, rsyn, _aleh_, _تابع,
   {{0x212d582e,0x63b68c5d,0x9e3c00fe,0x09db0831}},	//   _bleh_, ssyn, _jeďt, ধিকা,
   {{0xd04601cb,0x53a900a1,0xa3cb1604,0x63b68c5e}},	//   وپاي, _चौकश, रंश_, psyn,
   {{0x6f1a4723,0x3993021d,0x00000000,0x00000000}},	//   _potc, _lãs_, --, --,
   {{0xdd9a18cd,0x2d8600e9,0x800b00b5,0x00000000}},	//   оши_, _sioe_, ترمہ_, --,
   {{0x39404c7a,0x6d090380,0xac941bda,0x6f1a0160}},	//   _omis_, वांग_, найш, _votc,
   {{0xe73f0132,0x00000000,0x00000000,0x00000000}},	//   mpõe_, --, --, --,
   {{0x61430171,0x81df0033,0x69c0175f,0x6f1a01f7}},	//   _рета, তিঃ_, _विही, _totc,
   {{0x3940507f,0x7f430382,0xb87b02d7,0x00000000}},	//   _amis_, cinq, nfíe, --,
   {{0x28f98c5f,0x8e4a0037,0xbebc0228,0x00000000}},	//   пень_, _بلاك_, _blīv, --,
   {{0x2d9e0328,0x0c26002d,0x25480448,0x9c260279}},	//   _itte_, _омен, oğlu_, _одед,
   {{0x1bf2046c,0x29090051,0xd7f81e47,0x00000000}},	//   _अनिल_, _vnaa_, мур_, --,
   {{0x39930279,0xf53f2172,0x394000af,0xd90f00b5}},	//   _fãs_, _små_, _emis_, ایک_,
   {{0x98a90116,0x6d8700b5,0xdef8009f,0x00000000}},	//   _hlač_, _műan, _maċ_, --,
   {{0xe8d901a5,0x636b04d4,0x2fc680e2,0x765b027d}},	//   _phổ_, rünm, krog_, şuyo,
   {{0x7af8006d,0x69da8c60,0x54553312,0x33754054}},	// [9890] _kavt, ltte, хват, егар,
   {{0x2fc604c5,0x2d9e01b4,0x59c522a3,0x69da8c61}},	//   drog_, _otte_, _विमर, otte,
   {{0x69da0086,0x29d8000d,0x69cf0035,0xb60800ac}},	//   ntte, néa_, ąceg, rkší,
   {{0x69da03ad,0xe8d90019,0x7af88c62,0x30750421}},	//   itte, _thổ_, _lavt, нулс,
   {{0x7feb0642,0x63708c63,0x3d1221b2,0x2d9e8c64}},	//   تراف_, männ, थाने_, _atte_,
   {{0x7af8008b,0x7df30095,0x92eb0580,0x63701ab7}},	//   _navt, _həsə, _برحق_, länn,
   {{0x6283016f,0x7f4300a8,0xa3cb52cf,0x212d08b7}},	//   ľnos, rinq, रूर_, _tleh_,
   {{0x62838c65,0xa2d70083,0x2fc66caa,0x98a0011c}},	//   žnos, _সফটও, brog_, _ilić_,
   {{0x7df301c2,0x2d9e007c,0x69da8c66,0x5e590df3}},	//   _məsə, _ette_, ette, _کلاس_,
   {{0x8c9f0026,0x69da8c67,0x7af80207,0x00000000}},	//   _ग्रो, ftte, _cavt, --,
   {{0xa96a8c68,0x637068c4,0xe9d60043,0x27340ef0}},	//   зина_, känn, нкэ_, _häng_,
   {{0xfe6e00d1,0xf769100a,0x38690044,0x3940009f}},	//   _اگه_, _הק_, _byar_, _qmis_,
   {{0x7d0b00d1,0x69da8c69,0x636b8c6a,0xdb0b01ff}},	//   _ings, atte, günk, _avgå,
   {{0xdb1b18fa,0x3ced0069,0x8c1a011d,0x273400ab}},	//   bruá, leev_, _מוני, _mäng_,
   {{0x7bdb8c6b,0xd9460272,0x69da0051,0x3d0400a1}},	//   ltuu, _пеки, ctte, वाचे_,
   {{0x7df3013b,0x00000000,0x00000000,0x00000000}},	//   _cəsə, --, --, --,
   {{0x7bdb7359,0x68e40010,0xd4090037,0x98a00207}},	// [98a0] ntuu, _ibid, وتكم_, _alić_,
   {{0x3ced01e8,0x00000000,0x00000000,0x00000000}},	//   heev_, --, --, --,
   {{0xe8d901a5,0xf8bf1fe2,0x4256021d,0x7bdb00c3}},	//   _chỗ_, chés_, хтат, htuu,
   {{0x7bdb2ba8,0x8c9f0d00,0xa99a0070,0x2fc600cd}},	//   ktuu, _ग्लो, לבער, trog_,
   {{0x7f468c6c,0xe73f0279,0x68e48c6d,0xe3b206ee}},	//   недж, spõe_, _mbid, _حرج_,
   {{0x7d0b8c6e,0x69da3f62,0x69c0143a,0x00000000}},	//   _angs, ytte, _विली, --,
   {{0x68e400a0,0x628e8c6f,0x63a489fb,0x4ea501e0}},	//   _obid, _igbo, lpin, тріа,
   {{0x2fc68c70,0x98a967f8,0x7ae30371,0x68e4007a}},	//   prog_, _plač_, _abnt, _nbid,
   {{0x63a48c71,0x7bdb8c72,0x27340454,0xcb463534}},	//   npin, gtuu, _känd_, ехни,
   {{0x30750b7d,0x68e48c73,0x7e68053e,0x20190310}},	//   _русс, _abid, _tydp, _àsia_,
   {{0xc3338c74,0x2bc2143a,0x19590104,0x3869022e}},	//   רות_, _शिवा, даны_, _syar_,
   {{0x69da8c75,0x98a9016f,0x20045010,0x636b00b5}},	//   rtte, _tlač_, _krmi_, tünk,
   {{0x629c01f4,0x7bdb0120,0x1bd44e4f,0x637031ea}},	//   _ofro, ctuu, _роля, vänn,
   {{0x63a48c76,0x999e006c,0x68e48c77,0x61330225}},	//   dpin, sztő_, _ebid, _içle,
   {{0x7d0b3bd1,0x63a43754,0xe5c46299,0x63700421}},	//   _yngs, epin, лсто, tänn,
   {{0x59c50567,0x7df300a8,0x68e40069,0x64cb00b4}},	//   _वितर, _qəsə, _gbid, िलेश,
   {{0xf2c70970,0x63708c78,0x63a40f3a,0x64400124}},	// [98b0] есен, ränn, gpin, _žmir,
   {{0x69c80261,0xd0110416,0x68fd3ce9,0x00000000}},	//   orde, یلا_, ldsd, --,
   {{0x200468d5,0x7df30095,0x6d4200af,0x273401ff}},	//   _armi_, _təsə, _omoa, _säng_,
   {{0x629c8c79,0x69c804e6,0x68fd150b,0x3ced0221}},	//   _efro, irde, ndsd, xeev_,
   {{0x656d1512,0x8009006c,0xd250006c,0x7bdb0051}},	//   mlah, براہ_, لنے_, xtuu,
   {{0x66050e46,0x6d420159,0xb87b02d7,0xd006692c}},	//   _krhk, _amoa, leís, теше_,
   {{0x8d552a24,0xed590f23,0xb35410b4,0xbebc013a}},	//   ктич, мок_, _скрш, _alīs,
   {{0x7bdb00c3,0x13d50033,0x656d8c7a,0x00000000}},	//   ttuu, _সৈয়, nlah, --,
   {{0x3cdd0026,0x69c80244,0x656d00d7,0x7f9501d3}},	//   क्षे_, erde, ilah, _разх,
   {{0x7bdb07bd,0x59c500a1,0x656d081b,0x6d42081b}},	//   rtuu, _विदर, hlah, _emoa,
   {{0x7bdb2382,0x81df00c8,0x27e92700,0x656d8c7b}},	//   stuu, তিক_, _apan_, klah,
   {{0x63a4183a,0x27e9009e,0xd94659d4,0xdb090138}},	//   ypin, _bpan_, теми, nseú,
   {{0x69c81928,0x656d024e,0xf8bf00b8,0x2be58c7c}},	//   arde, dlah, ckém_, _कहिं_,
   {{0xa3d40026,0x07a38c7d,0x7bdc00af,0x6605023a}},	//   सूफ_, рарн, ărut, _brhk,
   {{0xa3d402cb,0xb0d10035,0x63bd1d2f,0x16592374}},	//   सून_, _हांग, _avsn, ерть_,
   {{0x2be50299,0x656d8c7e,0x629c8c7f,0x68e401b7}},	//   _कहां_, glah, _sfro, _ubid,
   {{0x3cf408b0,0xb87b24c5,0x63a48c80,0x7bc98c81}},	// [98c0] ्यते_, rfíc, upin, nreu,
   {{0x63a48c82,0x657f006d,0x00000000,0x00000000}},	//   rpin, amqh, --, --,
   {{0x63a48c83,0x656d34d2,0xe5a6021d,0x7bc90051}},	//   spin, blah, _шини, hreu,
   {{0x63a45c74,0xd5b80029,0x656d00ee,0x2bc20266}},	//   ppin, šās_, clah, _शिला,
   {{0xb4ce0591,0xc0570409,0x81e80033,0x62830009}},	//   रली_, кіш_, বিধ_, žnop,
   {{0x6d423562,0xb87b1725,0x7bc9887d,0x65640421}},	//   _smoa, nfía, dreu, loih,
   {{0xe1f700c3,0x41aa0823,0x2eee8c84,0x00000000}},	//   _игр_, _іван_, reff_, --,
   {{0xed570d44,0x7bc901ae,0x2fdd006d,0x7c860e8b}},	//   кој_, freu, btwg_, купе,
   {{0x06b80083,0x5fc90084,0x9f4d00de,0x7bc91d69}},	//   _জানি, _रियल, _creó_, greu,
   {{0x69c88c85,0xfe420594,0x00000000,0x00000000}},	//   trde, _پکتی, --, --,
   {{0x27e98c86,0x656d02b3,0x69c802e6,0xa3c60035}},	//   _span_, ylah, urde, ैंड_,
   {{0xdca62632,0x7bc98c87,0xf8bf006c,0x290d01a3}},	//   _ради, breu, mkék_, ñea_,
   {{0xb8eb0e04,0x7bc92ddc,0xa3d40127,0x3f8c0118}},	//   _लय_, creu, सूम_, _kidu_,
   {{0xcf9302b5,0xbb430009,0x66050124,0x6b8a0211}},	//   יטש_, _кечк, _prhk, _uifg,
   {{0xd5b80994,0xb8d90033,0x80d30461,0x3f8c00e2}},	//   кст_, _চা_, _डाले, _midu_,
   {{0xdb1b0370,0x656d011e,0x6441013b,0x3f8c06fe}},	//   truç, ulah, _əlif, _lidu_,
   {{0x656d005d,0x27e90159,0x43941172,0xcfd70033}},	// [98d0] rlah, _upan_, иатс, _দৈনন,
   {{0x656d8c88,0x2fdd006d,0x764e00b5,0x6fcc0099}},	//   slah, vtwg_, ányá, _समजू,
   {{0x656d00b9,0xb87b002a,0x00000000,0x00000000}},	//   plah, peís, --, --,
   {{0x59c500a1,0x7bc94cdd,0x00000000,0x00000000}},	//   _विसर, yreu, --, --,
   {{0x3f8c003c,0x00000000,0x00000000,0x00000000}},	//   _bidu_, --, --, --,
   {{0x442922e5,0x543a02b5,0x7bc92386,0x00000000}},	//   mya_, _טערא, vreu, --,
   {{0x44298c89,0x3f8c2181,0x02af0035,0x92680d46}},	//   lya_, _didu_, टरीन, _арта_,
   {{0x7bc98c8a,0x16b00084,0x752d8c8b,0x9f4d027a}},	//   treu, _जज्ब, nkaz, _creò_,
   {{0x7bc90248,0xa05501c8,0x59c5022e,0x3f8c0176}},	//   ureu, _сваі, _विहर, _fidu_,
   {{0x89a90f94,0x7bc97847,0x44290ba4,0x3e1900af}},	//   нков_, rreu, iya_, _позэ_,
   {{0x44298c8c,0x798d0ac8,0x5cd500ad,0xf9861d99}},	//   hya_, _biaw, _مقاط, лгоо,
   {{0x44298c8d,0x7bc98c8e,0x798d022e,0x3f8c0bc6}},	//   kya_, preu, _ciaw, _zidu_,
   {{0x59c53054,0x4429070b,0x798d8c8f,0x31560070}},	//   _विवर, jya_, _diaw, רירן_,
   {{0x44293b4b,0x3cfd006d,0x7d1b8c90,0x6d498c91}},	//   dya_, _hawv_, ljus, liea,
   {{0xceb25c8e,0x4429030d,0x3cfd006d,0x62810237}},	//   מים_, eya_, _kawv_, _úloh,
   {{0xb4ce8c92,0xb4c00311,0x44296737,0x798d011e}},	//   रले_, ीले_, fya_, _giaw,
   {{0x7c2918c5,0x6b8d0082,0x7c3b8c93,0x44298c94}},	// [98e0] nyer, _éags, nzur, gya_,
   {{0x3cfd0d4b,0x57fb0052,0x7d1b007c,0x78b600a8}},	//   _lawv_, _טלפו, hjus, _heyv,
   {{0xdce24cc3,0xf772064e,0x4429018e,0x00ca081b}},	//   _skoč, _پاک_, aya_, елек_,
   {{0x44298c95,0x3cfd006f,0x3f8c0009,0x6d950069}},	//   bya_, _nawv_, _sidu_, _eġak,
   {{0x7d1b23a9,0x78b600d0,0xe8070534,0x442901d5}},	//   djus, _meyv, शिया_, cya_,
   {{0x78b60453,0x00000000,0x00000000,0x00000000}},	//   _leyv, --, --, --,
   {{0x7afe04a5,0x3f8c8c96,0x3d8a00c3,0xa49b009e}},	//   _ópti, _vidu_, нщин_, _gnòs,
   {{0x3cfd006f,0x425303c7,0xdb008c97,0x067b016b}},	//   _cawv_, _انفر, nsmö, ענקל,
   {{0x3cfd006d,0xdce2011c,0x7c298c98,0x00000000}},	//   _dawv_, _ukoč, gyer, --,
   {{0xef8328a1,0xe8ad00b4,0xdfcf0037,0x7d1b013a}},	//   _глуп, चर्च, _ريم_, ajus,
   {{0x6e930082,0x5e930082,0x798d8c99,0x6ce64747}},	//   _الما, _المط, _piaw, _біле,
   {{0x3cfd006d,0x7c298c9a,0xe8d90019,0x88b00033}},	//   _gawv_, byer, _khứ_, _কাউক,
   {{0x752d33a5,0x69c00026,0x386d08c8,0xac970037}},	//   vkaz, _विकी, æer_, _إنها_,
   {{0x7dea0095,0x7bfb0122,0x44298c9b,0x3cfd006d}},	//   _təsd, _נפוצ, vya_, _zawv_,
   {{0x44298c9c,0x6aba42e7,0x95c80ef3,0x00000000}},	//   wya_, matf, лута_, --,
   {{0x44298c9d,0x6aba8c9e,0x06c60033,0x752d00a0}},	//   tya_, latf, শ্লি, ukaz,
   {{0x394b8c9f,0x44290107,0x29270067,0x939700bc}},	// [98f0] mics_, uya_, ętać_, اجرا,
   {{0xd25b0500,0x44297ab8,0x394b8ca0,0x752d000e}},	//   нце_, rya_, lics_, skaz,
   {{0x44298ca1,0x3207024e,0x7c3b07e5,0xf12718a4}},	//   sya_, íny_, zzur, льдо,
   {{0x44298ca2,0x394b8ca3,0x7c3b0035,0x68ff007a}},	//   pya_, nics_, yzur, _jaqd,
   {{0xe8d901a5,0x06b80083,0x3cfd0221,0x68ff8ca4}},	//   _chứ_, _জাতি, _rawv_, _maqd,
   {{0x3cfd01a9,0xa3ea0355,0x394b0f00,0x68ff0069}},	//   _sawv_, _महत_, hics_, _laqd,
   {{0x3cfd006d,0x6d493baa,0xf20402fb,0x7d1b584e}},	//   _pawv_, tiea, _лято, tjus,
   {{0x68ff0024,0x7c3b8ca5,0x00000000,0x00000000}},	//   _naqd, tzur, --, --,
   {{0x75ec00f5,0x394b0443,0xa3cb02e4,0x60db0010}},	//   _közö, dics_, रंट_, _icum,
   {{0xff530082,0x81e80083,0x98a702d4,0x7d1b008c}},	//   _اخر_, বির_, _ēnā_, sjus,
   {{0x394b0443,0xb0b9045c,0x3cfd0189,0x7c291fd9}},	//   fics_, _उजाग, _tawv_, syer,
   {{0x394b0443,0x6370022a,0x7c291292,0x657d009e}},	//   gics_, tänk, pyer, _nhsh,
   {{0x6aba08c8,0x6ff00139,0x5ba71000,0x60c40098}},	//   batf, _fπcu, _срез, óimi,
   {{0xfaa514f8,0x2cad6494,0x657d2a8f,0x63708ca6}},	//   _тако, lbed_, _ahsh, ränk,
   {{0x29560133,0x28a71ede,0xf623324a,0x18a6290a}},	//   _въпр, _क्वि, одро, _кайм,
   {{0x637018d6,0x2d8f0260,0xb87b01ef,0x394b0176}},	//   mäni, _jige_, ofíl, cics_,
   {{0x2900334e,0x29120118,0x93468b32,0xe29a06d8}},	// [9900] _iaia_, _inya_, анае, ваз_,
   {{0x2d8f0022,0x2912006d,0xdb00191b,0x00000000}},	//   _lige_, _hnya_, ssmö, --,
   {{0x80a60a72,0x4add0c67,0xaadd017a,0x2912067f}},	//   لمان, _मानव, _मानक, _knya_,
   {{0x290001d7,0x3be50066,0xdfa62123,0x81e80033}},	//   _jaia_, _कहूँ_, ајко, বিল_,
   {{0xdefa03ad,0x29008ca7,0xa3ea0387,0xa49b0176}},	//   вый_, _maia_, _महि_, _inòp,
   {{0xd00f01b2,0x2d8f1093,0x29008ca8,0x26d88ca9}},	//   بله_, _aige_, _laia_, ngro_,
   {{0x636b1a68,0x6aba0a8a,0x60db0211,0x527500af}},	//   rünt, vatf, _fcum, _гуту,
   {{0xa3ea0387,0xe8d90028,0x637002ee,0x394b01f7}},	//   _महा_, _thứ_, däni, xics_,
   {{0x8fa334a2,0x61e90f44,0x28a70e9b,0x2aaa16c0}},	//   _мате, _ćeli, _क्षि, ктно_,
   {{0x290207c0,0x29128caa,0x320a0097,0xdfcf0312}},	//   edka_, _anya_, _krby_, _آيل_,
   {{0x2bc223e3,0x394b8cab,0x29008cac,0x2d8f003d}},	//   _शिका, tics_, _baia_, _fige_,
   {{0xdd8f0fab,0x7c862ad1,0x38c90609,0x29000434}},	//   _قول_, _куле, دادی_, _caia_,
   {{0x20068cad,0x394b0122,0x8b96002d,0x29050355}},	//   nvoi_, rics_, _треч, ěla_,
   {{0x28a70d00,0x394b8cae,0x2902042f,0x61ee8caf}},	//   _क्रि, sics_, adka_, _opbl,
   {{0x68ff5fbe,0x394b8cb0,0xa3d413a0,0x25a50055}},	//   _taqd, pics_, सूस_, ëll_,
   {{0x290006a2,0xef190035,0x63a60345,0x00000000}},	//   _gaia_, _duży_, _btkn, --,
   {{0x3cde0035,0x394927be,0x449800c3,0x78bd0349}},	// [9910] _गाने_, _imas_, рвую_, masv,
   {{0x27340006,0x60db002d,0x3949028b,0x48e30518}},	//   _täna_, _scum, _hmas_, ट्रो_,
   {{0x93888cb1,0xa3cb0174,0xa2dd0efa,0x636b01ae}},	//   рста_, रूज_, _पाठ्, wüns,
   {{0xeaf30026,0x212426c9,0x30150d13,0x78bd8cb2}},	//   _अस्त_, _comh_, йдер, nasv,
   {{0x2d8f8cb3,0x838710b0,0x212426c9,0x320a00d5}},	//   _rige_, _выве, _domh_, _erby_,
   {{0x3949006d,0x2d8f8cb4,0xf1a719b6,0x9f0500b5}},	//   _lmas_, _sige_, _вран, صوبو,
   {{0x2cad0602,0x2d8f01b4,0x78bd127d,0x7bc200f7}},	//   tbed_, _pige_, kasv, _avou,
   {{0x260802cb,0x28a702b4,0x26d8042a,0x067c00a5}},	//   हिती_, _क्लि, zgro_, כנול,
   {{0x2cad8cb5,0x40340e0a,0x2900000e,0x78bd003a}},	//   rbed_, _детс, _raia_, dasv,
   {{0x39498cb6,0x7bc200b8,0x7de700d4,0x29008cb7}},	//   _amas_, _dvou, _відд, _saia_,
   {{0xe8d901a5,0x2d8f3ed8,0x29008cb8,0xaa4921be}},	//   _chữ_, _tige_, _paia_, упна_,
   {{0x3cde0084,0x6d59012f,0x63700301,0x7c950037}},	//   _गाये_, _ujwa, räni, _الإص,
   {{0x6c85004f,0x29008cb9,0x00000000,0x00000000}},	//   _الشم, _vaia_, --, --,
   {{0x39490452,0x6f0100ee,0x6d500067,0xdb090176}},	//   _emas_, _jalc, ądał, nseü,
   {{0xe5a63091,0x6f018cba,0x290006cd,0xf74300c3}},	//   сиби, _malc, _taia_, черо,
   {{0x29120f3a,0x6f010176,0x00000000,0x00000000}},	//   _unya_, _lalc, --, --,
   {{0x69c18cbb,0x7dea013b,0xf48400f8,0x21240211}},	// [9920] lsle, _məsa, زاری, _romh_,
   {{0xa2dd0587,0x7c240014,0x5fd10099,0x00000000}},	//   _पाण्, _àire, _समजल, --,
   {{0x69c18cbc,0xfe65006c,0x2d8430c8,0x00000000}},	//   nsle, _آگ_, ymme_, --,
   {{0x69c18cbd,0xf77f0225,0x6d95023a,0x00000000}},	//   isle, rtçe_, _ošab, --,
   {{0x572504e8,0x6018406b,0x28db06fe,0x00000000}},	//   _طریق, роля_, _भासि, --,
   {{0x6f01225a,0x03a3049f,0x2ca00484,0x69c18cbe}},	//   _calc, _хиро, _żid_, ksle,
   {{0xa3d40026,0x69c14a69,0x1dcf2516,0x61ee0223}},	//   सूर_, jsle, संगत, _upbl,
   {{0xc0e312f8,0x7bc6010b,0x69c177e6,0xdb190107}},	//   _носк, škum, dsle, _avwà,
   {{0x491c05dc,0x2d84028b,0x6f011651,0x78bd65f9}},	//   यानो_, rmme_, _falc, vasv,
   {{0x69c30051,0x6f018cbf,0x69c18cc0,0x60230104}},	//   _bvne, _galc, fsle, _эдуа,
   {{0x69c18cc1,0x995201c0,0x78bd8cc2,0x38600510}},	//   gsle, lář_, tasv, _axir_,
   {{0x7d1d02b1,0x48ab0421,0x00000000,0x00000000}},	//   össt, ытом_, --, --,
   {{0x672503ad,0xc867392c,0x69c3082b,0x78bd68dc}},	//   _pohj, стни, _evne, rasv,
   {{0x69c14182,0x28db0099,0x7d028cc3,0x2bf7016b}},	//   bsle, _भावि, _haos, _למדן_,
   {{0x63a20079,0x78bd005f,0x957700f8,0x69c18cc4}},	//   íonn, pasv, مدرض, csle,
   {{0x394903e6,0xe8d90023,0x7dea00a8,0x7d0202e2}},	//   _umas_, _khử_, _xəsa, _jaos,
   {{0x2418325e,0x2a8e0095,0x7d020088,0x67251510}},	// [9930] боты_, ləb_, _maos, _tohj,
   {{0x70d10299,0x00000000,0x00000000,0x00000000}},	//   हल्ल, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd86414b,0x3f9900e0,0x00000000,0x00000000}},	//   _زو_, _ésuk_, --, --,
   {{0x68ed6289,0x67540e3a,0xe04b01cb,0xa06900ed}},	//   _mbad, _ذخیر, دشاه_, јала_,
   {{0x63ad8cc5,0x7a3f0332,0xf6500332,0x4add1119}},	//   mpan, _játé, _آئی_, _माधव,
   {{0x68ed8cc6,0x6f018cc7,0xb4db009e,0x7d02582f}},	//   _obad, _valc, _amài, _baos,
   {{0x6f010035,0x28db2e64,0xdce000ea,0xa1596e59}},	//   _walc, _भाषि, tomā, _табу_,
   {{0x60c97615,0x63ad8cc8,0x4ad402cb,0x69c12c99}},	//   _idem, npan, _दाखव, wsle,
   {{0x68ed8cc9,0x69c117ad,0x200d60fd,0xb1780093}},	//   _abad, tsle, _irei_, _þórð,
   {{0xf2d202b8,0x61e54645,0x7dea00a8,0x8d740919}},	//   ועי_, nthl, _təsa, _کالا,
   {{0x69c18cca,0xa96a03fa,0x61e5370e,0x63ad4808}},	//   rsle, рима_, ithl, kpan,
   {{0x6d4b0024,0x3cde0026,0x59c523f0,0x28db2874}},	//   _imga, _गाते_, _विकर, _भारि,
   {{0xfbd00d47,0x69c30080,0x2cbf20e5,0x2a8e0095}},	//   _سته_, _tvne, laud_, bəb_,
   {{0x63ad00ee,0x00000000,0x00000000,0x00000000}},	//   epan, --, --, --,
   {{0x95990bfa,0x2cbf8ccb,0xf8bf0132,0x60c98ccc}},	//   стру_, naud_, caé_, _ndem,
   {{0xccf2035e,0x63ad0b04,0x03261c80,0xc32603f5}},	// [9940] וכן_, gpan, одан, омак,
   {{0x60c91166,0x68ed8757,0x00000000,0x00000000}},	//   _adem, _zbad, --, --,
   {{0xe1fa4e8a,0x6d4b8ccd,0x63ad0037,0xdb090300}},	//   рге_, _omga, apan, nseñ,
   {{0xa50a2f4c,0x63ad011e,0x200d8cce,0xbfaa2c72}},	//   _тема_, bpan, _brei_, атке_,
   {{0xf1aa01cb,0x200d8ccf,0x7d0200f8,0x60c98cd0}},	//   _چاره_, _crei_, _raos, _ddem,
   {{0x200d02c9,0x7d020c06,0x60c98cd1,0x73f90070}},	//   _drei_, _saos, _edem, _פּרו,
   {{0x644900fb,0xdd9700d8,0x995200b8,0x200d581e}},	//   _þeir, ошы_, sář_, _erei_,
   {{0x200d8cd2,0xe0d701e0,0x2cbf8cd3,0x00000000}},	//   _frei_, _мвс_, gaud_, --,
   {{0x81bc12eb,0x644005f9,0x200d125e,0x853b0070}},	//   _আমি_, _ümid, _grei_, יגקי,
   {{0x68ed027a,0x6d4b055c,0xf1d10026,0xba0a02fb}},	//   _sbad, _emga, _हिमन, ахме_,
   {{0x13b30083,0x81e80083,0x06e30083,0x7d020341}},	//   টওয়, বিক_, য়মি, _taos,
   {{0xe8d90028,0x63ad1722,0x2cbf8cd4,0x68ed0024}},	//   _thử_, ypan, caud_, _qbad,
   {{0xdd8f0312,0x63700421,0x00000000,0x00000000}},	//   _شوه_, näns, --, --,
   {{0x656f00ee,0x00000000,0x00000000,0x00000000}},	//   _skch, --, --, --,
   {{0x56940439,0xe8d90028,0xbb8301b2,0x46dc0066}},	//   дарт, _chợ_, _تلوي, _बारह,
   {{0x68ed8444,0x00000000,0x00000000,0x00000000}},	//   _ubad, --, --, --,
   {{0x6370013c,0x63ad8cd5,0x6d950069,0xa3b500ab}},	// [9950] jäns, upan, _jġar, छीं_,
   {{0xc7b28cd6,0xd3711e23,0x63ad8cd7,0x28a70066}},	//   _רבי_, رها_, rpan, कुरि,
   {{0x63ad14bc,0x637031ea,0x877c0070,0x200d0118}},	//   span, vänt, _דאזי, _srei_,
   {{0x61e58cd8,0x64400484,0x200d0118,0x00000000}},	//   rthl, _żmie, _prei_, --,
   {{0xd0090043,0x251a02b8,0xb4d70ca1,0x6d4b0069}},	//   селе_, _הורא, सली_, _rmga,
   {{0xd00e0cd1,0x200d0043,0xe3b202b5,0xa85800a5}},	//   الو_, _vrei_, _אױך_, חידה_,
   {{0x09af0083,0x43940d54,0x31c40798,0x63701cb5}},	//   _কিভা, _царс, _оств, ränt,
   {{0x200d0043,0x644100a8,0x0c25083e,0x6b880223}},	//   _trei_, _əlin, змин, emdg,
   {{0xdb1b0132,0x4ea700af,0xaed5002d,0x00000000}},	//   ssuí, _дреа, _ноаш, --,
   {{0x0b4201c8,0xce6b0043,0x656d055c,0x00000000}},	//   еньн, _кред_, hoah, --,
   {{0xc86902b5,0x7a690c5a,0x656d0065,0x00000000}},	//   _ען_, синг_, koah, --,
   {{0x7dea0095,0x6d4b574d,0x00000000,0x00000000}},	//   _məsl, _umga, --, --,
   {{0x4c9a00a5,0x00000000,0x00000000,0x00000000}},	//   _הבנו, --, --, --,
   {{0x3d19022e,0x26080099,0x00000000,0x00000000}},	//   भावे_, हिली_, --, --,
   {{0x7dea013b,0x6d5b4148,0xfbbd0831,0x00000000}},	//   _nəsl, onua, _আমিত, --,
   {{0xe9a82e63,0x6d5b8cd9,0x00000000,0x00000000}},	//   _بدون_, nnua, --, --,
   {{0x798408dd,0xf99300a5,0x42ca081b,0xc9857e94}},	// [9960] _ihiw, _ארה_, йган_, _تشوي,
   {{0x1ddb0026,0xe8d90019,0x6d5b0079,0x661700b5}},	//   _यमंत, _thợ_, hnua, égkö,
   {{0xa2dd04aa,0x2734022a,0xe2978cda,0x569b011d}},	//   _पार्, _länk_, чах_, _לייצ,
   {{0x2367025c,0x46dc0066,0x6d5b0055,0x00000000}},	//   čnja_, _बाँह, jnua, --,
   {{0xe475002d,0x21675a1a,0x00000000,0x00000000}},	//   _журэ, чици_, --, --,
   {{0x439300d8,0x75240207,0x00000000,0x00000000}},	//   _паўс, ljiz, --, --,
   {{0xde9303fa,0xa3c60066,0x44328cdb,0x00000000}},	//   нашњ, ैंक_, lyy_, --,
   {{0x06c60083,0xd6c60033,0x752401d5,0x2734017b}},	//   শ্চি, শ্চয, njiz, _bänk_,
   {{0x44208cdc,0x644401a8,0x4e9600f8,0xe8d900e2}},	//   nxi_, nzii, _فشار, _nhỡ_,
   {{0x3cde2fa9,0x44200443,0xbec20029,0x2fc603be}},	//   _गावे_, ixi_, šība, msog_,
   {{0x58d51bdf,0x75240ac8,0x4add020d,0xaadd1edf}},	//   монт, kjiz, _मारव, _मारक,
   {{0x3ebe01ff,0x60c28cdd,0xdb190107,0x443200c3}},	//   _hett_, naom, _avwä, kyy_,
   {{0xa2dd05b7,0x3ae50260,0x79840118,0xfc2f27f6}},	//   _पाल्, _bňpč_, _dhiw, _محو_,
   {{0x2d9e0019,0x59c5164f,0x4420002a,0xaae600f8}},	//   _kute_, _विचर, dxi_, _رستو,
   {{0x3ebe8cde,0x2d9e04da,0x60c288e9,0x4b7b00a5}},	//   _mett_, _jute_, kaom, _האגו,
   {{0x3ebe8cdf,0x69da2d06,0xb4d71bb5,0xb4c9000c}},	//   _lett_, mute, सले_, ैले_,
   {{0x69da8ce0,0x2d9e8ce1,0x7dea0095,0xb4db0392}},	// [9970] lute, _lute_, _səsl, _llàg,
   {{0x7afa1b0a,0x2bd4017a,0x3ebe8ce2,0xfbd401c0}},	//   nett, _दिना, _nett_, _दिनम,
   {{0x65150332,0x6d408ce3,0x7afa0382,0x6da30009}},	//   _ہوگئ, khma, iett, _ađan,
   {{0x7afa8ce4,0x26c3008b,0x60c20103,0x98a500c7}},	//   hett, lajo_, gaom, ėlė_,
   {{0x2d9e0501,0x3ebe09af,0xaadd72c4,0x4add25d8}},	//   _aute_, _bett_, _मालक, _मालव,
   {{0x69da8ce5,0x7afa8ce6,0x26c30116,0x6441013b}},	//   kute, jett, najo_, _əlil,
   {{0x69da8ce7,0x7afa8ce4,0x41770148,0xb4d70084}},	//   jute, dett, _فارس, _साफ़_,
   {{0x2d9e03cb,0x69da8ce8,0x7afa4a70,0xdcfb0009}},	//   _dute_, dute, eett, imuć,
   {{0x7afa07c9,0x3ebe8ce9,0x6d5b06a2,0xdfd400d8}},	//   fett, _fett_, rnua, _поты,
   {{0x7afa0133,0x3ebe013c,0x26c3108a,0x6fd20035}},	//   gett, _gett_, jajo_, _सितं,
   {{0x2d9e8461,0x69da8cea,0xd6e30083,0x26c302c6}},	//   _gute_, gute, য়ায, dajo_,
   {{0x6d4002c9,0x2734013c,0xf1b20070,0x7e7e0f5e}},	//   chma, _tänk_, כסט_, üppe,
   {{0x44200484,0x7afa8ceb,0x7d0901a0,0xf8bf00b5}},	//   xxi_, bett, mdes, rkép_,
   {{0x7afa8cec,0xdb0b013c,0x2d9e022e,0x26c3008b}},	//   cett, _avgö, _yute_, gajo_,
   {{0x64a6010b,0x69da7b64,0x79843cb7,0xa50a083e}},	//   даба, cute, _thiw, оева_,
   {{0x2bd40fc3,0x442006a2,0xe3ba0dc8,0x44320086}},	//   _दिमा, txi_, жба_, tyy_,
   {{0x26c300c8,0x7dea01c2,0x7306010b,0x7d098ced}},	// [9980] bajo_, _rəsm, мпаз, ides,
   {{0x44208cee,0x7d090086,0x60c20054,0x753d00b5}},	//   rxi_, hdes, waom, _elsz,
   {{0xf1a503d0,0x00e602ce,0x3cde0066,0x7d098cef}},	//   ерін, джен, _गाले_, kdes,
   {{0x2d9e8cf0,0x3ebe03d0,0x7d098cf1,0x3f852206}},	//   _rute_, _sett_, jdes, _ahlu_,
   {{0x7afa8cf2,0x69da01d7,0x2d9e8c27,0x8fa33539}},	//   yett, zute, _sute_, ваче,
   {{0x69da8cf3,0x7afa8cf4,0x437500d4,0x2d9e3d92}},	//   yute, xett, _зуст, _pute_,
   {{0x3ebe8cf5,0x7d0911ad,0x629c05e2,0x68e48cf6}},	//   _vett_, fdes, _igro, _ocid,
   {{0x6440008a,0x1d070274,0x7d098cf7,0x69da8cf8}},	//   _ýmis, дећи_, gdes, vute,
   {{0x7afa8cf9,0x3ebe8cfa,0x7dea00a8,0x63a4013b}},	//   tett, _tett_, _kəsk, nqin,
   {{0x60c08cfb,0x6d408cfc,0x2d9e0358,0x7afa4b2f}},	//   _hemm, shma, _tute_, uett,
   {{0xfe430f36,0x60c076f5,0x7afa8cfd,0x7d096c04}},	//   _инфо, _kemm, rett, bdes,
   {{0x7afa8cfe,0x69da8cff,0x60c0035f,0x7d0900ec}},	//   sett, rute, _jemm, cdes,
   {{0xb90723e3,0x7afa8d00,0x8d7401cb,0x69da8d01}},	//   _पा_, pett, _قاچا, sute,
   {{0x60c00303,0x69da8d02,0x629c6acf,0xb8d6060a}},	//   _lemm, pute, _ngro, _च्_,
   {{0xe5c40272,0x26c302c6,0x2d8601a5,0xf79400d8}},	//   ксто, rajo_, _khoe_, тарэ,
   {{0x60c08d03,0x20040d5c,0xab5d0035,0x69c80cfc}},	//   _nemm, _osmi_, duży, msde,
   {{0xdce9011c,0x491c0963,0x26c308b7,0x6f1a0223}},	// [9990] sleć, यारो_, pajo_, _ontc,
   {{0x3211006a,0xdb0903e6,0xd37b00d8,0x7d098d04}},	//   _przy_, mpeã, іча_, zdes,
   {{0xe8d900e8,0xd25b7bcb,0xd25107f8,0x7d090086}},	//   _chủ_, цца_, دنا_, ydes,
   {{0x290b00af,0x66058d05,0x68fd05f5,0x6b98029e}},	//   ndca_, _ishk, nesd, _livg,
   {{0x6f080118,0x2fc90079,0x7d098d06,0xf4090079}},	//   _badc, éag_, vdes, _عيسى_,
   {{0x26c1086d,0xaadd06bb,0xdc140083,0x670f06bc}},	//   _jeho_, _माइक, িহাস_, ायिक_,
   {{0x60c08d07,0x3d100084,0x7d098d08,0x26c11575}},	//   _femm, _दोहे_, tdes, _meho_,
   {{0x60c08d09,0x69c88d0a,0x629c8d0b,0x28db08b0}},	//   _gemm, dsde, _zgro, _भागि,
   {{0x213f0118,0x69ca8d0c,0x7c24009e,0x00000000}},	//   _iluh_, _avfe, _àirl, --,
   {{0x26c101ba,0x60c00e8c,0x3f8500d5,0x3a254268}},	//   _neho_, _zemm, _uhlu_, емог,
   {{0x9f8a0086,0x69c85cde,0x6b9800ec,0xc7af0c6f}},	//   töön_, gsde, _divg, _atё_,
   {{0x68fd8d0d,0x186a1303,0xdb1b02d7,0x00000000}},	//   gesd, зами_, rruñ, --,
   {{0x2d8d8d0e,0x26c1010d,0xdd9400d8,0x00000000}},	//   mmee_, _beho_, _рацы, --,
   {{0x613a0310,0x25a1008c,0x26c100fe,0xcc56076b}},	//   _aïll, _buhl_, _ceho_, _אבני_,
   {{0xe61718d9,0xa3e208b6,0xf53f0f7f,0x7bc91f23}},	//   ндр_, नून_, _blå_, lseu,
   {{0x68e400af,0x6d950506,0xe807018d,0x629c8d0f}},	//   _ucid, _ošam, शिखा_, _sgro,
   {{0x4ad30302,0x7bc98d10,0x66052074,0x3940043d}},	// [99a0] _दयाव, nseu, _eshk, _ilis_,
   {{0x60c08d11,0xe8d901a5,0x39400189,0xd83f024e}},	//   _semm, _phủ_, _hlis_, íček_,
   {{0x6f085702,0xf7720416,0xf53f008c,0x39400207}},	//   _radc, _لاگ_, _flå_, _klis_,
   {{0x7bd50035,0x7a4652d5,0x7bc98d12,0x06570070}},	//   ązuj, _hété, kseu, _טייך_,
   {{0x7bcf12d1,0x63a4013b,0x26c1010d,0x60c0008c}},	//   ácul, qqin, _yeho_, _vemm,
   {{0xe8d900e8,0x629c8d13,0x9e062491,0x39400176}},	//   _thủ_, _ugro, ечил, _llis_,
   {{0xe3631f27,0x7bcb1dce,0x60c00723,0x7a4602e1}},	//   _скри, _avgu, _temm, _mété,
   {{0xe2978d14,0x213f003d,0x7bc90298,0x00000000}},	//   _час_, _gluh_, fseu, --,
   {{0x69c8099e,0x1be70274,0x6d95023a,0x2167002d}},	//   wsde, едњи_, _kšaj, _чити_,
   {{0x39403ee2,0x69c82357,0x8fa30819,0xa3e800b4}},	//   _alis_, tsde, _сафе, _यमन_,
   {{0x4dd60987,0x68fd03c1,0x394030ce,0xb33b021d}},	//   _ستاس, tesd, _blis_, _juça,
   {{0x69c814e6,0xfc6601d3,0x7dea0095,0x2245027d}},	//   rsde, _пълн, _nəsi, _ülke_,
   {{0x68fd8d15,0x69c80210,0xdc3000fe,0xdceb035f}},	//   resd, ssde, _kýčo, _sigħ,
   {{0xb9c60514,0xf53f04ca,0x8c1b0d85,0x39408d16}},	//   _كتبه, _slå_, _מודי, _elis_,
   {{0xc6680012,0xbb830037,0x7a46000d,0x39402aef}},	//   еште_, _حلوي, _dété, _flis_,
   {{0x28db0084,0x4a7b00a5,0x8a7b00a5,0xb4db009e}},	//   _भाटि, _מרוב, _מאות, _slàb,
   {{0x28b40079,0x26c18d17,0x3495004b,0x00000000}},	// [99b0] _صحيح, _teho_, таар, --,
   {{0x862700d8,0x213f01a0,0x00000000,0x00000000}},	//   _зьме, _sluh_, --, --,
   {{0x212d0051,0xcad700a5,0x213f0168,0x326700c7}},	//   _poeh_, תובת_, _pluh_, хтав,
   {{0x3ce601e8,0x00000000,0x00000000,0x00000000}},	//   _ncov_, --, --, --,
   {{0xb4cd00a1,0xdee50011,0x6568104b,0xe134010b}},	//   रणी_, воли, édhe, ынцы,
   {{0xbec20029,0x3eac000d,0xb33b0183,0x00000000}},	//   šīna, _cfdt_, _fuça, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe700bdf,0x2734013c,0x2d998d18,0xa19400af}},	//   حده_, _hänt_, öse_, _басч,
   {{0x2d8d0903,0x273401ff,0x752f0067,0x28db021a}},	//   rmee_, _känt_, _mocz, _भाजि,
   {{0x7bc98d19,0xc6bc0083,0x78ad0443,0x2d8d8d1a}},	//   rseu, _অঞ্চ, _afav, smee_,
   {{0xa96a0786,0x3940142f,0x7bc902e1,0xd946429c}},	//   дина_, _plis_, sseu, вени,
   {{0x9c390274,0x7bc90298,0x00000000,0x00000000}},	//   _опет_, pseu, --, --,
   {{0xeb8e477c,0x39400051,0x69de0185,0x00000000}},	//   _ви_, _vlis_, _åpen, --,
   {{0x41d10567,0x7d0b008a,0x9a158266,0x78ad0107}},	//   _हिंस, _hags, _афиш, _efav,
   {{0xb87b00de,0x65c38697,0x7d0b011e,0x7a4600f7}},	//   rgía, ибра, _kags, _vété,
   {{0xe8d90028,0x7d0b1b4a,0xb4dc4fa7,0x394000f6}},	//   _phụ_, _jags, ठले_, _ulis_,
   {{0x7d0b8409,0x7dea00a8,0x7a460e8c,0x752f0067}},	// [99c0] _mags, _vəsi, _tété, _docz,
   {{0x2bd42fa9,0x7c26022a,0xfbd408a9,0x7d0b8d1b}},	//   _दिसा, äkri, _दिसम, _lags,
   {{0xb6d900c2,0x7dea0095,0x2fcd0260,0xb87b021d}},	//   _אַרט, _təsi, _aveg_, ngín,
   {{0x7d0b12d7,0xa3e20e04,0x64a605ac,0xe8d90019}},	//   _nags, नंद_, _шама, _thụ_,
   {{0xc0e30352,0x00000000,0x00000000,0x00000000}},	//   рочк, --, --, --,
   {{0xdbdb0093,0x273400ab,0xd336002d,0x4add0099}},	//   _ráðg, _tänu_, _рэмы, _मागव,
   {{0x7d0b8d1c,0x2bc40355,0x68f60c3d,0x00000000}},	//   _bags, लीना, _obyd, --,
   {{0x3d19018d,0x69ce0009,0x6b440107,0x27340282}},	//   भागे_, šbek, _mòge, _käns_,
   {{0x7d0b8d1d,0x8fa61400,0x6aad027d,0xbb740fb4}},	//   _dags, _разе, _şafa, лгиј,
   {{0x78ad1f26,0x201946e4,0x27340523,0x00000000}},	//   _sfav, _ásia_, _mäns_, --,
   {{0x2bd452cf,0x7d0b8d1e,0x2734017b,0x00000000}},	//   _दिवा, _fags, _läns_, --,
   {{0xa9210095,0xdd9603c7,0xe94501df,0x00000000}},	//   _şöbə, _شجاع, اردی, --,
   {{0xf7732292,0xdb090082,0x1bd43997,0x752f0035}},	//   لاس_, speá, _соля, _rocz,
   {{0x7d008d1f,0x752f0067,0xf09332e3,0x00000000}},	//   lems, _socz, ינר_, --,
   {{0x752f006a,0x7e8601c0,0x6d42082b,0xa4d52659}},	//   _pocz, _úspě, _kloa, лові,
   {{0xb4cd00a1,0x354400d4,0x7d008d20,0x386901b7}},	//   रणे_, ахув, nems, _txar_,
   {{0x65948d21,0x24580d36,0x39598d22,0x06d80083}},	// [99d0] рату, вать_, miss_, দ্ধি,
   {{0x69da01e4,0x7d008d23,0x46a707b5,0x6d420392}},	//   orte, hems, _खलिह, _lloa,
   {{0x10d500d8,0xe6590043,0x752f0067,0x7d00023c}},	//   гілё, _чинч_, _tocz, kems,
   {{0x69da009c,0x06d80083,0x7d002187,0x39598d24}},	//   irte, দ্দি, jems, niss_,
   {{0xd2500332,0x69da01ae,0x63a2004f,0x7dea0095}},	//   منے_, hrte, íont, _məsu,
   {{0x7d0b8d25,0xf77f05f9,0xaed20274,0x0f350594}},	//   _sags, ftçi_, бољш, دکرد,
   {{0x7d0b7396,0xb06200c3,0x6d428d26,0x00000000}},	//   _pags, _ääni, _bloa, --,
   {{0x2bd40fbf,0x00000000,0x00000000,0x00000000}},	//   _दिशा, --, --, --,
   {{0xeb9903ad,0x69da8d27,0xa1580274,0x31341d91}},	//   нии_, erte, _рату_, _тетр,
   {{0x4add0f0d,0x9b450a42,0x4b25364f,0x00000000}},	//   _माओव, اندو, умов, --,
   {{0x7d0b8d28,0x52d00083,0x7dea00a8,0x6d428d29}},	//   _tags, স্কৃ, _səsv, _floa,
   {{0x2e3a02b5,0xb87b8d2a,0x6d420139,0x4a4201e0}},	//   _אגענ, rgín, _gloa, снюв,
   {{0x69da8d2b,0x00000000,0x00000000,0x00000000}},	//   arte, --, --, --,
   {{0xcc3a0070,0x07a31a55,0x3959021d,0x65660044}},	//   _רעסט, сарн, aiss_, _sjkh,
   {{0x39598d2c,0x2d9d2d69,0x6b44009e,0xe800007c}},	//   biss_, _kiwe_, _fògb, _लईका_,
   {{0x2cad0122,0xa5075fc0,0xf8a80084,0x2d9d002f}},	//   nced_, леса_, _गलिय, _jiwe_,
   {{0xc9530052,0x29028d2d,0xf2da06ee,0x00000000}},	// [99e0] _למה_, meka_, فظات_, --,
   {{0x29028d2e,0x7d000612,0x2d9d002f,0x37068d2f}},	//   leka_, zems, _liwe_, _спог,
   {{0xe0da8d30,0x248601ba,0x8b560070,0x7d0008c7}},	//   еве_, ťom_, ניעס_, yems,
   {{0x29028d31,0x9fca0086,0x26ca8d32,0x2d9d035a}},	//   neka_, егда_, labo_, _niwe_,
   {{0x43862ac4,0x00000000,0x00000000,0x00000000}},	//   _ملحق, --, --, --,
   {{0x26ca03be,0x643b02b5,0x1eaa0a42,0x29020848}},	//   nabo_, _טעכנ, راتي_, heka_,
   {{0x7d0032dc,0x29022506,0x6d4200af,0x2d9d2973}},	//   tems, keka_, _ploa, _biwe_,
   {{0x26ca8d33,0x29020470,0xae090084,0x69da55ae}},	//   habo_, jeka_, विजन_, vrte,
   {{0x7dea0095,0x7d008d34,0x29024f87,0x26ca8d35}},	//   _rəsu, rems, deka_, kabo_,
   {{0x69da02c6,0x3d1900a1,0x7dea00a8,0x7d008d36}},	//   trte, _मोठे_, _bəst, sems,
   {{0x26ca8d37,0x69da5cd7,0x656442f6,0x037700a5}},	//   dabo_, urte, knih, רתית_,
   {{0x7dea01c2,0x29023004,0x637001ae,0x2367063b}},	//   _dəst, geka_, gänz, čnji_,
   {{0x3f9e8d38,0x63a67ad4,0xb95400c3,0xd7f80036}},	//   _kitu_, _nukn, свящ, лур_,
   {{0x26ca76a4,0x3f9e0e89,0x2d9d5d11,0x69da08b7}},	//   gabo_, _jitu_, _ziwe_, prte,
   {{0x29028d39,0x3f9e007c,0x63a60093,0x2d9d0371}},	//   beka_, _mitu_, _aukn, _yiwe_,
   {{0x99d3006c,0x29028d3a,0x44b50210,0x63a6543f}},	//   _اتوا, ceka_, рбас, _bukn,
   {{0x26ca74c2,0x798d8d3b,0xb3553079,0x549900d8}},	// [99f0] babo_, _ihaw, акаш, тваў_,
   {{0xd498818c,0xb4db01f7,0x63a60523,0x3f9e0395}},	//   урс_, _glàn, _dukn, _nitu_,
   {{0x798d8d3c,0x6564184b,0x7dea0095,0xdb090279}},	//   _khaw, bnih, _xəst, speç,
   {{0x30153d52,0x656400fe,0xddc8007e,0x112802fb}},	//   идер, cnih, _bydž, лючи_,
   {{0xd0090012,0xa49b01f7,0x63a600cd,0x3f9e8d3d}},	//   теле_, _caòt, _gukn, _bitu_,
   {{0x3f9e0029,0x2902000e,0xddc8010b,0x98ab00c7}},	//   _citu_, zeka_, _dydž, ėjęs_,
   {{0x3f9e03cb,0xed59033a,0xddc203fe,0x7bc2021e}},	//   _ditu_, tiž_, общи, _awou,
   {{0xd6580122,0x7bc20260,0x7bdb0dfa,0x3f9e8d3e}},	//   טיות_, _bwou, truu, _eitu_,
   {{0x44298d3f,0x0b45415d,0x29021be6,0x2d530043}},	//   nxa_, инин, veka_, nţei_,
   {{0x29020657,0x44291561,0x7bdb4ab4,0x60cb02b3}},	//   weka_, ixa_, rruu, lagm,
   {{0x29028d40,0x69268d41,0x7a698d42,0x6e671a09}},	//   teka_, амна, тинг_, _стаж,
   {{0x273d00e8,0x798d0189,0x60cb121e,0x5c751578}},	//   _hình_, _chaw, nagm, _клет,
   {{0x798d8d43,0x29028d44,0x6d4909e3,0x7bc20c1f}},	//   _dhaw, reka_, mhea, _gwou,
   {{0x29028d45,0x6d5b002f,0x63a6023a,0x6c840079}},	//   seka_, liua, _rukn, _الهم,
   {{0x273d00e8,0x63a68d46,0x29020523,0xb8ec0083}},	//   _mình_, _sukn, peka_, _লা_,
   {{0x63a68d47,0x26ca018c,0x798d007a,0x59da00ab}},	//   _pukn, sabo_, _ghaw, _भितर,
   {{0x6f038cf1,0x7c3b8d48,0x7c290d99,0x78a91942}},	// [9a00] kenc, nyur, nxer, ževc,
   {{0x6f038d49,0xdcfb011c,0x6d95010b,0x7c290392}},	//   jenc, dluč, _išau, ixer,
   {{0x3f9e081b,0x0219010b,0x02060842,0x6d5b34de}},	//   _ritu_, ліць_, рзен, kiua,
   {{0x3f9e5053,0xfbc71301,0xc05a03d0,0x60cb011e}},	//   _situ_, _وت_, кіл_, gagm,
   {{0x6d49060e,0x273d00e8,0x3f9e8d4a,0xe819111e}},	//   dhea, _bình_, _pitu_, दिया_,
   {{0x69c30122,0x6d4912f7,0x9f5302a4,0x06d80033}},	//   _owne, ehea, овіч, দ্রি,
   {{0x3f9e000e,0xa3e2020d,0x6fd20026,0x61fc02f6}},	//   _vitu_, नूर_, _सिकं, _uprl,
   {{0x6d4909e3,0xc0e31272,0x6aa3008c,0x6f0301ed}},	//   ghea, _моск, _agnf, aenc,
   {{0xdee604bf,0x798d8d4b,0x29d1003c,0x3f9e71e6}},	//   _вози, _rhaw, eġa_, _titu_,
   {{0x6f031269,0x6da30c99,0x752d8d4c,0x63700086}},	//   cenc, _rđav, zjaz, täny,
   {{0x6d4902a8,0x798d016e,0xc9870279,0x00000000}},	//   bhea, _phaw, иуми, --,
   {{0x6d49060e,0x798d01e8,0x7bc202e9,0x6aa303d0}},	//   chea, _qhaw, _twou, _egnf,
   {{0x588700c7,0x44290484,0x386d027d,0x7c3b01d5}},	//   рына, xxa_, çer_, cyur,
   {{0x6b440284,0x78a4001c,0x79a60f8c,0x00000000}},	//   _fòga, _egiv, _крие, --,
   {{0x798d01a9,0x69c302c7,0x7aef0187,0xd90f0416}},	//   _thaw, _gwne, žitý, _قید_,
   {{0x644d03cb,0x442920c9,0x6d406079,0x6f038d4d}},	//   tzai, txa_, nkma, zenc,
   {{0xf8bf8d4e,0x79460035,0x6f0382f9,0xd6db03e6}},	// [9a10] mbé_, _wówc, yenc, _итн_,
   {{0xec7100c2,0x44298d4f,0x6f030391,0x7ae84884}},	//   פֿן_, rxa_, xenc, ngdt,
   {{0x6d498d50,0x443b012f,0x55591d13,0xdce90009}},	//   yhea, syq_, _баня_, zleđ,
   {{0x6d49009e,0x6d404e5f,0x00000000,0x00000000}},	//   xhea, jkma, --, --,
   {{0x6b81001e,0x68ed0312,0xa05401e0,0x00000000}},	//   yllg, _mcad, овці, --,
   {{0x6d400130,0x60cb0159,0x00000000,0x00000000}},	//   ekma, sagm, --, --,
   {{0x6d4930d2,0x6f038d51,0xed598971,0x60cb0dc3}},	//   thea, renc, лок_, pagm,
   {{0x6f038d52,0x1d2502c4,0x7c298d53,0x2367012e}},	//   senc, смим, txer, čnju_,
   {{0x273d00e8,0x6ab80083,0x61e58d54,0x63ad1505}},	//   _tình_, _আয়ো, luhl, nqan,
   {{0x6aa41a68,0x2bdd1649,0x6d498d55,0x60c90223}},	//   _şifr, _मिठा, shea, _heem,
   {{0x60c903d1,0x6d493e5a,0xdce90200,0x7c3b10ce}},	//   _keem, phea, sleđ, syur,
   {{0x60c90d89,0xfc330413,0x00000000,0x00000000}},	//   _jeem, _وحش_, --, --,
   {{0x8d741dbf,0x6d5970f7,0x60c912ef,0x7d740037}},	//   _بالا, _imwa, _meem, _بالط,
   {{0x2cbf8c14,0x60c98d56,0x657d3357,0xf1a70266}},	//   lbud_, _leem, _aksh, गदान,
   {{0x19b5006c,0x78a9108a,0xd90d0088,0xf8bf00b5}},	//   _احتج, ževa, ریی_, bbé_,
   {{0x60c98d57,0x6d95005f,0x00000000,0x00000000}},	//   _neem, _išas, --, --,
   {{0x44260370,0xa3e2046c,0x6d59073a,0x66e62a0b}},	// [9a20] ão_, नूं_, _mmwa, _лопа,
   {{0x29128d58,0xe29a8d59,0xd24f00d1,0xe64630cc}},	//   _haya_, газ_, کنم_, _геоп,
   {{0x29128d5a,0x60c98d5b,0x6d5909d6,0xfde20033}},	//   _kaya_, _beem, _omwa, _মন্ড,
   {{0xc6930052,0x29120452,0xda7a016b,0xf8c8060a}},	//   _מאת_, _jaya_, אנער, लरिय,
   {{0x8ff70082,0x29128d5c,0xdfcf381f,0x69d500b8}},	//   مرور_, _maya_, فين_, ázej,
   {{0x425300f8,0x6d5937e2,0x61e500d7,0x291208dd}},	//   _کنفر, _amwa, buhl, _laya_,
   {{0x60c98d5d,0x200d028b,0x00000000,0x00000000}},	//   _feem, _esei_, --, --,
   {{0x29126d92,0x60c94171,0x49182135,0x06e10831}},	//   _naya_, _geem, _बोलो_, ম্পি,
   {{0x6d408d5e,0x2eec021d,0x00000000,0x00000000}},	//   rkma, _tcdf_, --, --,
   {{0x68ed1d40,0x60c98d5f,0x6d408d60,0x6e9302fd}},	//   _scad, _zeem, skma, _کلما,
   {{0x29128d61,0x8e86004f,0x7c2400d8,0x3f9b00f7}},	//   _baya_, _الاه, _šird, ïque_,
   {{0x60c9006d,0x2912008c,0xdd8f0037,0x00000000}},	//   _xeem, _caya_, _كول_, --,
   {{0x29120452,0xf8bf8d62,0x25e600be,0x00000000}},	//   _daya_, rbé_, जूसी_, --,
   {{0x2bdd0380,0x29120159,0x2d840051,0x83030033}},	//   _मिता, _eaya_, llme_, _উচ্চ_,
   {{0x2c74006c,0x29128d63,0x6d953c73,0x6d5900e9}},	//   _دیکھ_, _faya_, _išar, _ymwa,
   {{0x2912422d,0x39a500ea,0x657d8d64,0x00000000}},	//   _gaya_, _cēsu_, _qksh, --,
   {{0x99480ad9,0x60c92dea,0x83352dbb,0x00000000}},	// [9a30] _دليل_, _reem, онах, --,
   {{0x63ad7838,0x39490187,0x60c98d65,0x21240260}},	//   rqan, _hlas_, _seem, _anmh_,
   {{0x39498d66,0x2912596c,0xe5350086,0x5187010b}},	//   _klas_, _yaya_, _день, буда,
   {{0x61e500ee,0x0ce30033,0x399b7f6e,0x00000000}},	//   ruhl, _মস্ত, _būsi_, --,
   {{0x63ad0510,0xb4e51404,0x9f998d67,0x60c98d68}},	//   qqan, नली_, авду_, _veem,
   {{0x2ca60159,0x60c9018e,0x394901ef,0x8afc0035}},	//   _agod_, _weem, _llas_, nięd,
   {{0x60c94d4e,0x39498d69,0x00000000,0x00000000}},	//   _teem, _olas_, --, --,
   {{0x2bd41db6,0x6d9500c7,0x00000000,0x00000000}},	//   _दिखा, _ašar, --, --,
   {{0x6fe01e79,0x29120f1a,0x2cbf44ed,0x200d0a4a}},	//   _नियं, _raya_, rbud_, _usei_,
   {{0x29120614,0x394905ca,0x6d5e02e1,0x3d190fcd}},	//   _saya_, _alas_, épar, _मोरे_,
   {{0x7cd90332,0x29128d6a,0x2d84009e,0x00000000}},	//   _نواز_, _paya_, blme_, --,
   {{0x6d59070b,0x78a910ec,0x39498d6b,0x7c240a78}},	//   _umwa, ževn, _clas_, _šire,
   {{0x29128d6c,0x224d00b8,0x67370051,0x00000000}},	//   _vaya_, _řekl_, _boxj, --,
   {{0x39498d6d,0x409a00a5,0x29121ebf,0x25a20107}},	//   _elas_, יברס, _waya_, _sikl_,
   {{0x291218e4,0x39498d6e,0xa2d8012f,0x25a2023a}},	//   _taya_, _flas_, मणस्, _pikl_,
   {{0x6725008c,0x785c0228,0x00000000,0x00000000}},	//   _enhj, tāvī, --, --,
   {{0xe577093e,0x42ca081b,0x5eca0033,0x00000000}},	// [9a40] ізу_, иган_, _রাসে, --,
   {{0x7c24004f,0x6fe037e8,0x2124009e,0xf77f021d}},	//   _áire, _निबं, _snmh_, puça_,
   {{0x64a622bb,0xf74a0594,0xa49b021e,0x8afc0067}},	//   _мана, _ملکي_, _abòd, sięg,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee022821,0x34a700d4,0x25e61edf,0x00000000}},	//   लब्ध_, _євро_, जूरी_, --,
   {{0x6fdb0ac4,0xcdda0fb4,0x5eca0831,0x00000000}},	//   _निरू, ањи_, _রাহে, --,
   {{0x7946006a,0x1219010b,0xdd9100b5,0x61466342}},	//   _równ, _люты_, کوٹ_, _дева,
   {{0x910300ed,0x00000000,0x00000000,0x00000000}},	//   _опсе, --, --, --,
   {{0x46bf3100,0xeb062698,0x60c28d6f,0x6b44009e}},	//   ्रमह, очно, mbom, _fògl,
   {{0xba54192f,0x60c28d70,0x25ba0176,0x00000000}},	//   звој, lbom, _otpl_, --,
   {{0x39498d71,0xa2ad0fbf,0x8f9b00a5,0xb87b0183}},	//   _plas_, _जलस्, _כימי, ngív,
   {{0x2ca60159,0x8ba6195c,0x00000000,0x00000000}},	//   _ugod_, _дидж, --, --,
   {{0xcb6a00c9,0x8b6505f5,0x39493c2c,0xc19b0070}},	//   _каде_, _کانم, _vlas_, ישטי,
   {{0x628e0009,0x44250160,0x00000000,0x00000000}},	//   _ozbo, _ăl_, --, --,
   {{0x661e0124,0x26da8d72,0x60c20051,0x00000000}},	//   _crpk, _ddpo_, kbom, --,
   {{0xb4e54fa7,0xa5dc111b,0x00000000,0x00000000}},	//   नले_, _फिरौ, --, --,
   {{0xe8731c0c,0x00000000,0x00000000,0x00000000}},	// [9a50] _زندگ, --, --, --,
   {{0x2bdd08b6,0xdceb0124,0xe8d900e2,0x777c0392}},	//   _मिसा, _čičk, _thỳ_, corx,
   {{0x26d10c22,0x6cea0084,0xdb030345,0x00000000}},	//   mazo_, _टांग_, _binê, --,
   {{0xdd860332,0x26d18d73,0x60c243c9,0x6b44009e}},	//   _سو_, lazo_, gbom, _sògl,
   {{0xf48411eb,0x6fc60d00,0x00000000,0x00000000}},	//   _журн, रीलं, --, --,
   {{0x26d18d74,0xdb0b0132,0x00000000,0x00000000}},	//   nazo_, _eugê, --, --,
   {{0x5eca0083,0xbea27a34,0xc3320317,0xd04900a8}},	//   _রাশে, нашк, _אום_, _ənən,
   {{0x26d102d7,0xb4db01da,0x00000000,0x00000000}},	//   hazo_, _blài, --, --,
   {{0x399b0080,0xdd8e1ee1,0xb4db0284,0x26d18d75}},	//   _jūsu_, دوي_, _clài, kazo_,
   {{0x399b0080,0x26d1002f,0x78a900f4,0x7c240116}},	//   _mūsu_, jazo_, ževl, _širc,
   {{0xd91000f5,0x26d18d76,0x98b0011c,0x6b447034}},	//   ہیں_, dazo_, šača_, _gògm,
   {{0x201f8d77,0xa96a8d78,0xb4db0211,0x60db0024}},	//   _krui_, сима_, _flài, _jdum,
   {{0x6d4b8d79,0x7d098d7a,0xcc0b00f3,0x661e011c}},	//   _ilga, mees, _خزان_, _srpk,
   {{0x26cc0bb0,0x7d098d7b,0x26d10138,0x907a32e3}},	//   údo_, lees, gazo_, מטרי,
   {{0xd9463668,0xba77026e,0x65c601d3,0x39b70139}},	//   _неки, _باشت, ябва, _băse_,
   {{0x2a3a0122,0x7d095acc,0x60db01d5,0xb33b0132}},	//   _לעצמ, nees, _ndum, _muçu,
   {{0x26d13d5d,0xb4be046c,0xda1926d4,0x656f034d}},	// [9a60] bazo_, _ीजी_, धिवत_, _djch,
   {{0xe81902e4,0x7d090086,0x59c200dc,0x629a0187}},	//   दिरा_, hees, वीकर, _útok,
   {{0x7d090119,0x2366011c,0x4256195c,0xf41f0421}},	//   kees, đoj_, чтат, _erä_,
   {{0xfaf800ea,0x201f03d0,0x7d090dfa,0x00000000}},	//   lnīt_, _brui_, jees, --,
   {{0x8afc006a,0x98a70254,0x1b120033,0xc9530d85}},	//   nięc, šića_, ়াতে_, עמד_,
   {{0xa2bb8d7c,0x6d4b19a6,0x60db00b9,0x00000000}},	//   शुद्, _alga, _edum, --,
   {{0x7d098d7d,0x29000051,0xb87b002a,0xb4db01a6}},	//   fees, _obia_, sfíx, _slài,
   {{0x7d091472,0x6da3052c,0x3f87011c,0xe7be035d}},	//   gees, нија, alnu_, ्ठाप,
   {{0x6fb60180,0x00000000,0x00000000,0x00000000}},	//   _رمضا, --, --, --,
   {{0x2900002d,0x6d4b8d7e,0xe6c600dc,0xff2400d1}},	//   _abia_, _elga, वरोज, _تبری,
   {{0xc3330122,0x7d098d7f,0xf8c8007e,0xf1c300e2}},	//   תות_, bees, लरूप, _nhớ_,
   {{0x26d1000e,0xdb03021e,0x7d09013a,0x00000000}},	//   wazo_, _linè, cees, --,
   {{0x26d18d80,0xe8240b29,0x31570317,0x7c831682}},	//   tazo_, нфро, ליטן_, _пуше,
   {{0xd7f83b4d,0x00000000,0x00000000,0x00000000}},	//   чую_, --, --, --,
   {{0x50cc0429,0x8afb0052,0x26d18d81,0xb6040402}},	//   ाराष, _להגי, razo_, нятк,
   {{0xe8d901a5,0x25fe04bc,0x26d18d82,0x69d8009f}},	//   _thự_, _लहरी_, sazo_, _ivve,
   {{0x26d1043f,0xf8c306bc,0xdb030118,0x00000000}},	// [9a70] pazo_, _व्यय, _binè, --,
   {{0xdb0301f7,0xe9ff0023,0x290b4351,0x291900f4}},	//   _cinè, _hoại_, leca_, ldsa_,
   {{0x7d09073a,0xdb0b0533,0x224700b5,0x00000000}},	//   yees, _utgå, ánk_, --,
   {{0x2bdd0fff,0xdb0b2ddc,0xed4600b5,0xe4c5042c}},	//   _मिला, _eugè, _شپ_, _تصدی,
   {{0xdb1b0083,0x29d80028,0xdb0307a7,0xd25000b5}},	//   spué, hĩa_, _finè, ننے_,
   {{0xe9ff00e8,0x35f801cb,0x7d098d83,0x69d802fb}},	//   _loại_, _برید_, wees, _ovve,
   {{0x7d098d84,0x290b8d85,0x8afc0035,0xed59021f}},	//   tees, keca_, zięc, жой_,
   {{0x656d8d86,0x290b025c,0x63af0a16,0x0c254d11}},	//   nnah, jeca_, _kucn, дмин,
   {{0x69d82e31,0x2bdd02cb,0x7d098d87,0x46bf111a}},	//   _avve, _मिळा, rees, ्राह,
   {{0x9906045c,0x7d098d88,0xe9d90e05,0x4a450b00}},	//   षज्ञ_, sees, око_, днов,
   {{0x63a70120,0xdb0300b8,0x6d4b08dd,0x7d09018f}},	//   _mijn, _jiné, _tlga, pees,
   {{0xdb038d89,0xe6c60096,0x63a701e4,0x62870160}},	//   _miné, वर्ज, _lijn, _myjo,
   {{0x7d5602b5,0xdb03000d,0x0c25010b,0x69d88d8a}},	//   _קינד_, _liné, _імкн, _evve,
   {{0x63a78d8b,0x4c9a00a5,0x6fe0060a,0xf4030033}},	//   _nijn, _ובנו, _निसं, উটার_,
   {{0x07a36804,0x8afc004e,0x656d01ae,0x00000000}},	//   тарн, sięc, fnah, --,
   {{0x198701d3,0x8afc0035,0xdb0301f7,0x290008c7}},	//   _общи_, pięc, _sinè, _ubia_,
   {{0x79840657,0x63a70a75,0xdb038d8c,0x63af0207}},	// [9a80] _ikiw, _bijn, _pinè, _cucn,
   {{0xdb090831,0x69c178a3,0x656d08c7,0x00000000}},	//   mpeó, ople, anah, --,
   {{0xdb038d8d,0x69c18d8e,0xc20a0098,0x656d0110}},	//   _ciné, nple, تقان_, bnah,
   {{0x2004012f,0x63a70069,0x6b440284,0x9c82031d}},	//   _ppmi_, _eijn, _eògh, íčko,
   {{0x63a701e4,0xb4db0310,0x6b440284,0x798408c7}},	//   _fijn, _clàu, _fògh, _mkiw,
   {{0xdb03039f,0xb5ab00b5,0x290b00f4,0x69c18d8f}},	//   _finé, _دئیے_, zeca_, kple,
   {{0x44221e85,0x7bcb009f,0x53a702b4,0x7984073a}},	//   _hrk_, _awgu, _कूटश, _okiw,
   {{0x69c18d90,0xfe720088,0x63a701e4,0xa2c60067}},	//   dple, _یدا_, _zijn, िरक्,
   {{0xa2a23779,0x69c18d91,0x44228d92,0x00830043}},	//   _कृत्, eple, _jrk_, _алто,
   {{0x79844267,0x5a34029f,0x65640df0,0x44228d93}},	//   _akiw, енот, hiih, _mrk_,
   {{0x290b8d94,0x656d8d95,0xdb030176,0x44220069}},	//   teca_, ynah, _xiné, _lrk_,
   {{0x7996016e,0x00000000,0x00000000,0x00000000}},	//   _chyw, --, --, --,
   {{0xb8d75a6c,0x290b8d96,0xfc2f017e,0x6b440310}},	//   _जल_, reca_, _نحو_, _lògi,
   {{0x44250a69,0x290b1851,0x63af3c2c,0x79840273}},	//   _čl_, seca_, _rucn, _ekiw,
   {{0xd9f20f3d,0x63a7407c,0x290b021d,0x656d0110}},	//   _अमित_, _rijn, peca_, tnah,
   {{0x99440d6f,0x7d022b28,0x44228d97,0x656d86a7}},	//   mış_, _jbos, _brk_, unah,
   {{0x63a78d98,0x9944045e,0x656d8d99,0x78ad00ab}},	// [9a90] _pijn, lış_, rnah, _igav,
   {{0x656d4cfc,0x4422753b,0xdb0b0176,0x8c1b00a5}},	//   snah, _drk_, _pugé, חומי,
   {{0x7d02811b,0x3992006c,0x99440716,0x63a701f4}},	//   _obos, lása_, nış_, _vijn,
   {{0x63a70120,0x63af1b97,0x442213dc,0x7c228d9a}},	//   _wijn, _tucn, _frk_, _oror,
   {{0x80270082,0x5ed30083,0x44228d9b,0xb82202b4}},	//   برام, _সাবে, _grk_, मियम_,
   {{0x9944027d,0x6fe00cea,0x39b70395,0xdcf90103}},	//   kış_, _निरं, _lăsa_, _okwă,
   {{0x753d1af0,0xc17718dd,0x7c220371,0x78ad0124}},	//   _kosz, _قدرت, _aror, _ogav,
   {{0xa29401c8,0x78ad011e,0x929409f1,0x7c22543e}},	//   _расі, _ngav, _расц, _bror,
   {{0x79960297,0x51841286,0xdcf90103,0x753d8d9c}},	//   _rhyw, _рура, _akwă, _mosz,
   {{0x7d02001e,0x3992006c,0x69c10a81,0x79840479}},	//   _ebos, dása_, tple, _skiw,
   {{0x7c228d9d,0xdcfb00b8,0xc332011d,0x00000000}},	//   _eror, louč, אוי_, --,
   {{0x69c14f47,0x4abf0af9,0x7c2201ef,0x753d3bda}},	//   rple, _श्रव, _fror, _nosz,
   {{0x291e01c0,0xb4db0392,0x00000000,0x00000000}},	//   ěta_, _llàs, --, --,
   {{0xcc3a0779,0x7d1b0006,0x7d1905a4,0x7946004e}},	//   _מענט, ldus, _haws, _mówi,
   {{0x7d190069,0xd04001c2,0xd5b21c51,0xd62700af}},	//   _kaws, _demə, افر_, норе_,
   {{0x7d1b0ccf,0xdb090b4c,0x79840054,0x6fe0083f}},	//   ndus, mpeñ, _ukiw, _निलं,
   {{0x0326095d,0x49000066,0xb4db009e,0x753d0035}},	// [9aa0] ндан, ष्णो_, _alàs, _dosz,
   {{0xb4db009e,0xa2bb09b1,0x6d49005b,0x6b8103d0}},	//   _blàs, शुल्, hkea, nolg,
   {{0x00e68d9e,0xb4db0310,0x6d494192,0x614664e1}},	//   ежен, _clàs, kkea, нежа,
   {{0x61e30332,0x6b818d9f,0xe0d21015,0x0576186e}},	//   ánla, holg, ازا_, _ساجد,
   {{0x14d70122,0x673e8da0,0x7d1b8da1,0x442205d0}},	//   _אוכל_, _kopj, ddus, _urk_,
   {{0x7c240690,0x99440716,0x44200054,0x2f5600af}},	//   _širo, yış_, mvi_, этес,
   {{0x994401c2,0x3992006c,0x6b660248,0x6b818da2}},	//   xış_, zása_, _légè, dolg,
   {{0xdfd2802e,0x78a90254,0x7d1b129d,0x44208da3}},	//   _مير_, ževi, gdus, ovi_,
   {{0x6b8102c9,0x442012c3,0x30762784,0x70cc01c0}},	//   folg, nvi_, _чувс, ारील,
   {{0xf06303fa,0x994406d3,0x44208da4,0x7d1b00ab}},	//   _скуп, tış_, ivi_, adus,
   {{0x44208da5,0x39b70160,0x1b120831,0x00000000}},	//   hvi_, _păsa_, ়ালে_, --,
   {{0x99440ec4,0x44200a78,0x39920332,0x6d491db8}},	//   rış_, kvi_, tása_, ckea,
   {{0x44200009,0xa49b02e9,0x7c228da6,0x2d8601cb}},	//   jvi_, _abòn, _uror, _ikoe_,
   {{0x7d19004e,0x4420093f,0x6b81027a,0xc6a709ce}},	//   _zaws, dvi_, colg, ерби,
   {{0x6f1a8da7,0x753d0c0f,0x44208da8,0xe610006c}},	//   _matc, _posz, evi_, یشہ_,
   {{0x69da4893,0x78ad08c7,0x00000000,0x00000000}},	//   mste, _ugav, --, --,
   {{0x97a705f2,0x4420008d,0xb4db01da,0xdcfb011c}},	// [9ab0] _прол, gvi_, _blàr, sluć,
   {{0x35b50210,0x69da42f9,0xb4db8da9,0xe4a4798e}},	//   _ибор, oste, _clàr, урсо,
   {{0x64410669,0x69da1f8c,0x44208daa,0x20cc1140}},	//   _əliy, nste, avi_, ारूढ,
   {{0x69da7dff,0xf99f02e9,0x6b8100b5,0x291b007a}},	//   iste, nmè_, zolg, _jaqa_,
   {{0x41747cf8,0x69da8dab,0x6f1a8dac,0x00000000}},	//   دالس, hste, _batc, --,
   {{0x69da8dad,0x7d1b5804,0xe822258f,0x7d198dae}},	//   kste, wdus, मिता_, _saws,
   {{0x6b818daf,0x69da8db0,0x5eca0033,0x6d490328}},	//   volg, jste, _রাখে, tkea,
   {{0x26d300da,0x62958db1,0x387e0067,0x291b009f}},	//   _lexo_, _izzo, ętrz_, _naqa_,
   {{0x69da8db2,0x6d4943a3,0x81c30083,0xeb995963}},	//   este, rkea, _এটি_, мии_,
   {{0x69da07b8,0x26d30473,0x6d498db3,0x00000000}},	//   fste, _nexo_, skea, --,
   {{0x2bd1006a,0x28c300a1,0x291b035f,0x628b0035}},	//   _दौरा, _व्हि, _baqa_, ęgow,
   {{0x81c300c8,0x44208db4,0x186a00aa,0x8afc004e}},	//   _এটা_, yvi_, дами_, wnęt,
   {{0x395900da,0x2d8d104e,0xdd9400d8,0x3de30083}},	//   ërsa_, mlee_, _сацы, _মহিল,
   {{0x2d8d8db5,0x4420030d,0xb8e900b4,0x316601a3}},	//   llee_, vvi_, _ल्_, zioz_,
   {{0x291b163e,0x9a241902,0x69da0987,0x00000000}},	//   _faqa_, _معين, cste, --,
   {{0xa2a205f7,0x442003ab,0xa3b602b4,0x00000000}},	//   _कृष्, tvi_, _चंद_, --,
   {{0xd4672e76,0x7bdb1361,0xe5a31347,0x62957b9c}},	// [9ac0] вите_, nsuu, рити, _azzo,
   {{0x7bdb0086,0x212d1034,0x3940009e,0xc7a6001f}},	//   isuu, _aneh_, _hois_, _шипк,
   {{0x26d80010,0x2d8d8db6,0x44202a2d,0x39520523}},	//   maro_, klee_, svi_, _klys_,
   {{0x26d800a7,0x212d0260,0x39405eec,0x7bdb0421}},	//   laro_, _cneh_, _jois_, ksuu,
   {{0x39401010,0x31661043,0x2d8d0024,0x25a08db7}},	//   _mois_, rioz_, dlee_, mmil_,
   {{0x69da03d0,0x26d88db8,0x39408db9,0x9e060044}},	//   yste, naro_, _lois_, вчил,
   {{0x6704142a,0x2dd7004f,0x216a35b2,0x3999006c}},	//   श्यक_, نبية_, _живи_, lése_,
   {{0x6f1a7daa,0x39400443,0x26d801b7,0x69da00d4}},	//   _watc, _nois_, haro_, vste,
   {{0x26d88dba,0x69da8dbb,0x7bdb011e,0x6f1a09ba}},	//   karo_, wste, gsuu, _tatc,
   {{0x69da8dbc,0x3940006e,0x26d80453,0xb4db0176}},	//   tste, _aois_, jaro_, _llàp,
   {{0x39408dbd,0x26d88dbe,0x69da8dbf,0x28f9563e}},	//   _bois_, daro_, uste, нень_,
   {{0x7c2d0280,0x26d31430,0x3940009d,0x2d8d0160}},	//   _šare, _sexo_, _cois_, clee_,
   {{0x39408dc0,0x69da5b88,0xdb030279,0x26d82127}},	//   _dois_, sste, _dinâ, faro_,
   {{0x26d88dc1,0x25ab00d7,0x291b007a,0x399900b5}},	//   garo_, _sicl_, _waqa_, dése_,
   {{0x39401010,0x26d301dd,0x98c70166,0x98a900ee}},	//   _fois_, _vexo_, _испл, _inač_,
   {{0x02cb06fe,0x61fe033b,0x394006e8,0x00000000}},	//   िर्न, dtpl, _gois_, --,
   {{0x26d801d5,0x26d301ef,0x53991667,0x6d5e00a2}},	// [9ad0] baro_, _texo_, евая_, épay,
   {{0x2d843f01,0x9952024e,0xe6672611,0x26d801d5}},	//   home_, máš_, _атмо, caro_,
   {{0x2d841b2a,0x6d5c01c8,0x99520237,0x02a72b34}},	//   kome_, _įran, láš_, трам,
   {{0xe5350086,0x2d84010b,0x9f4f021d,0x00000000}},	//   _семь, jome_, cugê_, --,
   {{0xb4c13914,0x2d842a28,0xdee51c8c,0x995200ac}},	//   ुरी_, dome_, голи, náš_,
   {{0x20d100e8,0x5ed30083,0xd00e026e,0xf41200a5}},	//   ại_, _সাহে, سلى_, _הפך_,
   {{0x7bc247d4,0x80d20083,0xfd110037,0x623401e0}},	//   _atou, _হার্, مجة_, _керу,
   {{0x2d843f8f,0x2ee901c2,0x99520187,0x2fc6006d}},	//   gome_, şaf_, káš_, bpog_,
   {{0x39408dc2,0xfc31004f,0x7c2d1a8a,0x7e7a0176}},	//   _rois_, صحة_, _šarb, _extp,
   {{0x7bdb3527,0x26d8092e,0x39408dc3,0x2fdf0027}},	//   rsuu, xaro_, _sois_, _ivug_,
   {{0x39408dc4,0x7bdb8dc5,0x3999006c,0x98a00009}},	//   _pois_, ssuu, zése_, _knić_,
   {{0x2d840122,0x26d804fb,0x7f41009f,0x7bdb8dc6}},	//   come_, waro_, _holq, psuu,
   {{0xeb8e8dc7,0x26d88dc8,0x39408dc9,0x2bdd0084}},	//   _ги_, taro_, _vois_, _मिटा,
   {{0x59d02160,0x7f41007a,0x00000000,0x00000000}},	//   थीहर, _jolq, --, --,
   {{0x26d88dca,0xa50a0af5,0x6eca2483,0xdb030160}},	//   raro_, нева_, _स्फु, _tinâ,
   {{0x291e0080,0x39990332,0x26d88dcb,0x69c30168}},	//   ētas_, tése_, saro_, _itne,
   {{0x2e1701c2,0x26d88dcc,0x25a08dcd,0xb4e40461}},	// [9ae0] _dəfə_, paro_, rmil_, _नयी_,
   {{0xdcf41269,0x46f603fe,0x4256562d,0x79868dce}},	//   _čačk, _счит, лтет, lokw,
   {{0x29d1008b,0xdb0a0107,0x2fdf0027,0x399900b5}},	//   nša_, _difè, _avug_, sése_,
   {{0x27e00009,0xdb090279,0xa91b0093,0x63140033}},	//   _kvin_, mpeõ, llþr, সাইট_,
   {{0x2d844d96,0xe3b209b9,0x61fe8dcf,0x7f468dd0}},	//   vome_, _درج_, stpl, ледж,
   {{0x29d1176d,0x1f7300d8,0x2bdd0066,0x7f41009e}},	//   kša_, блія, _मिजा, _colq,
   {{0xe2970ea0,0x5fe027bd,0x29d18dd1,0x06d90033}},	//   _бар_, _निकल, jša_, _তামি,
   {{0xe6d101d1,0x68e4759b,0x27e00207,0x00000000}},	//   _तज्ज, _ndid, _ovin_, --,
   {{0xdb030176,0x2d848dd2,0x9b6a1ca9,0x69c38dd3}},	//   _binà, rome_, ешна_, _atne,
   {{0x93fb0100,0x2d848dd4,0xdd04027d,0x9e5a00af}},	//   עליי, some_, ırıy, _преф_,
   {{0xaa942c61,0x195945d7,0x49751470,0x6eca012f}},	//   ринч, ваны_, илос, _स्यु,
   {{0x63ae5da2,0x69c300e2,0x00000000,0x00000000}},	//   _libn, _dtne, --, --,
   {{0x68e4001e,0x69c3027a,0xf773017e,0xc867272c}},	//   _ddid, _etne, ماس_, утни,
   {{0x6d4200ab,0x68e40103,0x63ae009f,0x995200ac}},	//   _hooa, _edid, _nibn, ráš_,
   {{0x628e8dd5,0x27e000c1,0x6b440211,0xe5c402fb}},	//   _nybo, _evin_, _fògr, йсто,
   {{0xb4c12203,0x69c801f7,0x68e4007a,0x00000000}},	//   ुरे_, mpde, _gdid, --,
   {{0x69c88dd6,0x245800c3,0x7afd0200,0x628e0168}},	// [9af0] lpde, гать_, đstv, _aybo,
   {{0x78a902c4,0x2b9900f7,0x6e288dd7,0x628e198d}},	//   ževs, pèce_, _ordb, _bybo,
   {{0x5ed30083,0x6db10029,0xdb0b02d7,0xdb0300fe}},	//   _সালে, _jāat, _jugá, _jiná,
   {{0xf8bf02e1,0x7ff51015,0xdb031534,0xdd860037}},	//   ncé_, لستا, _miná, _ذو_,
   {{0x6e280341,0x00000000,0x00000000,0x00000000}},	//   _ardb, --, --, --,
   {{0x798608c7,0x00000000,0x00000000,0x00000000}},	//   zokw, --, --, --,
   {{0x8d551c1b,0x7986699a,0xed590f08,0x00000000}},	//   итич, yokw, кок_, --,
   {{0x29d10bc6,0xf1a40810,0x69c30159,0xdce00228}},	//   vša_, _грун, _rtne, timā,
   {{0xa15802c4,0x6e28033b,0x320100a5,0x1c42037c}},	//   _сату_, _erdb, lthy_, жным,
   {{0xdce0013a,0x2909030d,0x3b090200,0x00000000}},	//   rimā, _abaa_, њено_, --,
   {{0x4a75004b,0x29d1022f,0x3f873068,0x27e07704}},	//   рыпт, uša_, monu_, _svin_,
   {{0xb4e422d4,0xdb030b4c,0xa96a6151,0xfe700957}},	//   _नये_, _diná, тима_, _عدل_,
   {{0x2f2400b5,0x61e300b5,0xd7d00099,0x00000000}},	//   ségű_, ánlj, तींच, --,
   {{0x29d10293,0xfaa51fda,0xdb03024e,0x7bc98dd8}},	//   pša_, _кало, _finá, mpeu,
   {{0x59760733,0x63ae04c3,0xdb030279,0xe7370c95}},	//   _выпу, _ribn, _giná, шер_,
   {{0x7c240888,0x2c090f09,0x3f870252,0x63ae8dd9}},	//   _širi, _वहां_, honu_, _sibn,
   {{0x5ee000c8,0x66e621b7,0x628e1c9b,0x3366010b}},	// [9b00] প্টে, _копа, _sybo, аваг,
   {{0x3f872b44,0xa2e60421,0x00000000,0x00000000}},	//   jonu_, рожд, --, --,
   {{0x8afc004e,0x63ae006d,0x200d002d,0xa3b61ca8}},	//   więk, _vibn, _apei_, _चूर_,
   {{0xb4db0028,0x27ed05e2,0x65660345,0x628e0187}},	//   _hoàn, šene_, _umkh, _vybo,
   {{0x628e8dda,0x63ae8ddb,0x96da04aa,0x23780183}},	//   _wybo, _tibn, _बजाउ, _tjrj_,
   {{0x7c24004f,0x00000000,0x00000000,0x00000000}},	//   _áiri, --, --, --,
   {{0x91e31a1c,0xdbcf00ac,0x399900e0,0x00000000}},	//   _море, _džín, hésa_, --,
   {{0x7c2d00cd,0x2d9d00e9,0x2247033b,0x6576007e}},	//   _šara, _chwe_, änke_, nnyh,
   {{0xef1a0b46,0xf8bf0248,0x60cd1d94,0xdb030042}},	//   _има_, ndée_, ñame, _siná,
   {{0xd00f004f,0x3b5421e2,0xf2d30070,0xda2600d4}},	//   _تلك_, скор, ֿער_, аємо,
   {{0xcd36026b,0x00000000,0x00000000,0x00000000}},	//   _پراب, --, --, --,
   {{0x6eca0fff,0xed5900b8,0x2d580176,0xbc670416}},	//   _स्तु, chž_, _béee_, امین_,
   {{0xf8bf8ddc,0xdca60166,0xdcfb05f9,0x00000000}},	//   rcé_, _тади, lluğ, --,
   {{0xe7878ddd,0xb4c1112b,0x291f0009,0x6a4a013b}},	//   румо, ुर्_, žua_, vəff,
   {{0xdcfb037a,0xf9c402fd,0xdb030b41,0xbb2b00fd}},	//   nluğ, _احتی, _binæ, _جتنے_,
   {{0x486702fb,0x00000000,0x00000000,0x00000000}},	//   _въоб, --, --, --,
   {{0x798d16fe,0xe7ee0722,0x9fe10083,0x3f8704d4}},	// [9b10] _ikaw, _जिया_, _মঙ্গ, yonu_,
   {{0xf2c71853,0xdcfb027d,0x96270228,0x00000000}},	//   рсан, kluğ, _paņē, --,
   {{0xd1b804e8,0x877c0070,0x798d007a,0x00000000}},	//   لانا_, _באזי, _kkaw, --,
   {{0xc105004f,0xe6100df3,0x32018dde,0xdcfb013b}},	//   صوتي, _کشی_, rthy_, dluğ,
   {{0x656d8ddf,0x2cbf0095,0x798d0f25,0x80c6046c}},	//   miah, vcud_, _mkaw, ाड़े,
   {{0x20e70023,0x6b8800cd,0x00000000,0x00000000}},	//   ối_, jodg, --, --,
   {{0xdce200ac,0xb87b01ef,0xdef81023,0x798d030d}},	//   _emoč, laíd, рыч_, _okaw,
   {{0x798d0189,0xe6780122,0x656d0fc2,0x5fe00084}},	//   _nkaw, יתוח_, niah, _निचल,
   {{0x644d8de0,0x442b184b,0x63a511d9,0x6018002d}},	//   nyai, _jrc_, omhn, _котя_,
   {{0x798d46a4,0xdb0301ed,0x656d00cc,0x00000000}},	//   _akaw, _minç, hiah, --,
   {{0x63a5066a,0x3992006c,0x5e95004f,0x89aa1d30}},	//   imhn, lási_, _الاط, лков_,
   {{0x7bc90248,0xe8f71a6d,0x6b4d0176,0x644d0421}},	//   ppeu, блю_, _múgi, kyai,
   {{0x4ca500c8,0xe81b0c57,0x7c2400c7,0x3b092d7a}},	//   _গ্রু, _पैदा_, _širv, _бело_,
   {{0x644d0159,0x6d5b02d7,0x798d4734,0x28ac0af6}},	//   dyai, lhua, _ekaw, _घृणि,
   {{0xceb25019,0xa6e3008a,0x656d3492,0x442b1691}},	//   לים_, íðar, fiah, _arc_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a3010b,0xaadb0324,0x65760542,0x7c3b0042}},	// [9b20] зата, _मजाक, rnyh, nxur,
   {{0x3992006c,0x442b1766,0xf8bf00f7,0x00000000}},	//   dási_, _drc_, rdée_, --,
   {{0x442b12c3,0x644d00d7,0x6d5b0a4e,0xd12f00e0}},	//   _erc_, ayai, khua, کمن_,
   {{0x00da028c,0x63a50037,0x6d5b0221,0x10a68de1}},	//   ابات_, amhn, jhua, биен,
   {{0x5ec900c8,0xfecf0083,0xdcfb012e,0xb87b1bea}},	//   _রয়ে, _রাজধ, jluđ, caíd,
   {{0x21200bc6,0x934600af,0x75248de2,0xe81b00ab}},	//   žih_, _унге, ldiz, _पईसा_,
   {{0x7c2b001e,0x0ef900d8,0xdb0300c3,0x442b0116}},	//   _argr, рэчы_, _minä, _zrc_,
   {{0x75248de3,0x2fda01ca,0x6fb600bf,0x629c0693}},	//   ndiz, _مورد_, _همرا, _izro,
   {{0x75240054,0xfbaa02ee,0xdce20124,0xe04332a6}},	//   idiz, лтой_, _umoč, _енти,
   {{0x60c20122,0x26da0009,0x20570070,0x6d5b0390}},	//   lcom, _nepo_, _הימל_, ahua,
   {{0xd915342d,0x6d5b0719,0x7c2b02b1,0x00000000}},	//   одны, bhua, _ergr, --,
   {{0x6d5b8de4,0xf53f022a,0xb4c700a1,0xd7fb0352}},	//   chua, _ihåg_, _उभे_, луг_,
   {{0xbfb600e8,0x58870409,0x75243707,0x286b031a}},	//   _điểm_, сына, ddiz, урно_,
   {{0x442b0ac8,0xac9700ad,0x25ba0b3e,0x629c0298}},	//   _rrc_, _انها_, _bupl_, _ozro,
   {{0x26da8de5,0x3992006c,0x656d01ba,0x20dd010b}},	//   _depo_, zási_, tiah, lšių_,
   {{0x6d400c1f,0x6a4a0095,0x798d829c,0xdb031e60}},	//   njma, rəfd, _ukaw, _pinç,
   {{0xb4b91163,0x6d400223,0x00000000,0x00000000}},	// [9b30] _चली_, ijma, --, --,
   {{0xb87b1fca,0x656d016f,0x6d5b163e,0x764e0051}},	//   raíd, siah, zhua, byby,
   {{0x644d1ea7,0xfbda1f34,0x50b5172a,0x82150037}},	//   syai, _मौसम, ослу, تواص,
   {{0x39920332,0xdb0b01ae,0x442b8de6,0x6d5b8de7}},	//   tási_, _zugä, _trc_, xhua,
   {{0x6d402fb1,0x442b47dc,0x00000000,0x00000000}},	//   djma, _urc_, --, --,
   {{0x4429070b,0xf41f00c3,0x60c20036,0x7c2d00cd}},	//   mva_, _isä_, acom, _šaro,
   {{0xe81b06bc,0x60c24827,0x2efe021d,0xbea21c4d}},	//   _पैसा_, bcom, _dctf_, машк,
   {{0x60c202fb,0xdd91004f,0xd6580d85,0x7c3b01a3}},	//   ccom, بوع_, מיות_, txur,
   {{0x44298de8,0x764e0035,0x00000000,0x00000000}},	//   nva_, zyby, --, --,
   {{0x44298de9,0x6d5b8dea,0x60db623c,0x7c3b013b}},	//   iva_, shua, _heum, rxur,
   {{0x60db046a,0x44293115,0xdce96545,0xdb1b000d}},	//   _keum, hva_, lieč, nqué,
   {{0x442901cc,0x6d5b006d,0xdb0300c3,0x6369013b}},	//   kva_, qhua, _sinä, _dönə,
   {{0x26da8deb,0xdce98dec,0x764e00e9,0x60c40453}},	//   _pepo_, nieč, wyby, ñimi,
   {{0x44298ded,0x60db0284,0x60c20069,0x7d098dee}},	//   dva_, _leum, zcom, lfes,
   {{0x44298def,0x2b4737a5,0x80d90387,0x00000000}},	//   eva_, _ionc_, _ढ़ूं, --,
   {{0x27ed05e2,0x7c2938b9,0xdce9010b,0x9f4601ef}},	//   šena_, over, kieč, iroá_,
   {{0x06d900c8,0x44292916,0x7c298df0,0x2b4703c9}},	// [9b40] _তারি, gva_, nver, _konc_,
   {{0x75247e14,0x63690095,0x2b478df1,0xb2960274}},	//   sdiz, _yönə, _jonc_, ојећ,
   {{0x7c298df2,0xe8220ac4,0x8afc004e,0x7c2d1e80}},	//   hver, मिका_, mięt, _šarl,
   {{0xf1a90833,0x7c2973a0,0x60c28df3,0x44290987}},	//   مانه_, kver, ucom, bva_,
   {{0x7c298df4,0xb4d68df5,0x629c004e,0x60db8df6}},	//   jver, हरी_, _wzro, _deum,
   {{0x7c298df7,0x6d598df8,0x8afc004e,0x7d09001c}},	//   dver, _alwa, nięt, efes,
   {{0x629c0a78,0x7c2954f1,0x7d094763,0x60db0014}},	//   _uzro, ever, ffes, _feum,
   {{0x29008df9,0x201f012f,0x7d092f21,0x7c298dfa}},	//   _ncia_, _fsui_, gfes, fver,
   {{0x7c298dfb,0x8b660037,0x00000000,0x00000000}},	//   gver, قادم, --, --,
   {{0xb4d6000c,0x3f76004e,0x6d590107,0xa3dc0c67}},	//   हरु_, dług_, _elwa, णीय_,
   {{0x2b471010,0x06d90083,0x44291055,0x79951dd0}},	//   _donc_, _তালি, zva_, зинф,
   {{0xb4b91163,0x44295a84,0xa9c300d4,0x6f180009}},	//   _चले_, yva_, ьськ, levc,
   {{0x20068dfc,0x6ec10a64,0x7d7b016b,0x8b660079}},	//   ntoi_, रुकु, _דראג, _واتم,
   {{0x34d300b4,0x21240284,0x2b47023a,0x44298dfd}},	//   तर्द, _lamh_, _gonc_, vva_,
   {{0xb4d621b2,0xe81b0324,0xf41f00c3,0x356b124a}},	//   हरू_, _पैरा_, _ssä_, аран_,
   {{0xb87b03e6,0x20060031,0x2124009e,0xe534010b}},	//   raíb, ktoi_, _namh_, месь,
   {{0x29198dfe,0x44298dff,0x20060031,0xd7fb07e5}},	// [9b50] mesa_, uva_, jtoi_, _туй_,
   {{0x44290e96,0x29198e00,0x60db8e01,0x6f180a23}},	//   rva_, lesa_, _seum, jevc,
   {{0x55950370,0xf77001b2,0x7c29434b,0xdb1901cb}},	//   _наоѓ, _جاي_, zver, _duwè,
   {{0x29198e02,0x68fd1949,0x7c2919b2,0xdb1b8e03}},	//   nesa_, ngsd, yver, rqué,
   {{0x6725007c,0x25a98e04,0x2124006b,0xdb1b6346}},	//   _kahj, mmal_, _damh_, squé,
   {{0x7c298e05,0x39498e06,0x3992006c,0x29198e07}},	//   vver, _loas_, lást_, hesa_,
   {{0x7c2901e4,0x29198e08,0x2006027a,0x2124009e}},	//   wver, kesa_, atoi_, _famh_,
   {{0x25a902c9,0x63bd1047,0x29198e09,0x672528e5}},	//   nmal_, _kusn, jesa_, _lahj,
   {{0x29198e0a,0xc104004f,0x7c290248,0x25a9033b}},	//   desa_, _توقي, uver, imal_,
   {{0x7d0909e1,0x63bd8e0b,0x25a901ae,0x317f0009}},	//   sfes, _musn, hmal_, _hjuz_,
   {{0x29198e0c,0x39498e0d,0x25a98e0e,0xce6b0ff6}},	//   fesa_, _boas_, kmal_, _трад_,
   {{0x3949043f,0x7c2952e4,0x29198e0f,0x63b50207}},	//   _coas_, pver, gesa_, _lizn,
   {{0xdb0301ba,0x63bd8e10,0xab29150d,0x394901ef}},	//   _minú, _nusn, _гола_, _doas_,
   {{0x63b500ee,0x00000000,0x00000000,0x00000000}},	//   _nizn, --, --, --,
   {{0x7ae18e11,0x29195b67,0x63bd01ae,0x3949008c}},	//   malt, besa_, _ausn, _foas_,
   {{0x7ae18e12,0x63bd0297,0xf99200bf,0x29198e13}},	//   lalt, _busn, _ثبت_, cesa_,
   {{0x63b58e14,0x29c10028,0xb4660c06,0x212401da}},	// [9b60] _bizn, _hóa_, чкал, _ramh_,
   {{0x62951c1c,0x63bd00d5,0x394901ef,0x7ae123e8}},	//   _byzo, _dusn, _zoas_, nalt,
   {{0xb6bb00a5,0x63600093,0x29e70124,0xdb190118}},	//   _לציי, _löng, nđa_, _cuwé,
   {{0x7ae18e15,0x63bd001e,0x2d8001ba,0x80d20083}},	//   halt, _fusn, čiek_, _হাঙ্,
   {{0x7ae13821,0xdb190118,0x3992008e,0xf53f0185}},	//   kalt, _tuwè, láss_, _tiår_,
   {{0x29190273,0x20063ab2,0x7ae100c3,0x3ce08e16}},	//   zesa_, rtoi_, jalt, _živ_,
   {{0x7ae18e17,0x29198e18,0x6f18011c,0x20068e19}},	//   dalt, yesa_, revc, stoi_,
   {{0x7ae18e1a,0x7cf604d4,0x636000b5,0x20060031}},	//   ealt, dürü, _böng, ptoi_,
   {{0x29198e1b,0x06e20033,0x442200f6,0x1b200831}},	//   vesa_, _বানি, _jsk_, বাসে_,
   {{0x7ae18e1c,0x39498e1d,0x3992006c,0x44228e1e}},	//   galt, _soas_, zást_, _msk_,
   {{0xc333035e,0x29198e1f,0x44270023,0x29c100e2}},	//   גות_, tesa_, ̉n_, _cóa_,
   {{0x63600093,0x7ae10303,0xb4d60387,0xa49b009e}},	//   _hönd, aalt, हरो_, _mbòr,
   {{0x7ae18e20,0x63608e21,0x44220168,0x7d022658}},	//   balt, _göng, _nsk_, _icos,
   {{0x27ed05e2,0x7ae18e22,0x7c228e23,0x29198e24}},	//   šeno_, calt, _isor, sesa_,
   {{0x3992006c,0x5ee10083,0x44228e25,0x63bd89c8}},	//   tást_, _নামে, _ask_, _susn,
   {{0x44228e26,0x63b50a21,0x9cfa0033,0x63600093}},	//   _bsk_, _sizn, _আসুন_, _lönd,
   {{0x68ed5c71,0x3f8e870f,0x2eec0176,0x18680274}},	// [9b70] _idad, kofu_, _oddf_, _наћи_,
   {{0x02a709d0,0x25a98e27,0x7c2d093f,0x3f8e02c4}},	//   прем, smal_, _šark, jofu_,
   {{0x2b0e04aa,0x29c101a5,0x44228e28,0xfe1b0722}},	//   त्यु_, _xóa_, _esk_, _भैंस_,
   {{0x63bd8e29,0x7c228e2a,0x27e90009,0x7ae18e2b}},	//   _tusn, _osor, _kvan_, zalt,
   {{0xe13400d8,0x63601aee,0x68ed08c7,0x7ae109e8}},	//   энцы, _bönd, _mdad, yalt,
   {{0xa2a500b4,0x3f8e023c,0x00000000,0x00000000}},	//   _करप्, gofu_, --, --,
   {{0x7ae18e2c,0x636055f6,0x68ed8e2d,0x00000000}},	//   valt, _dönd, _odad, --,
   {{0xe7ee07ba,0x30150798,0x27e9013c,0x7ae101ae}},	//   _जिला_, _одбр, _ovan_, walt,
   {{0x7ae13f58,0x60c902d7,0x00000000,0x00000000}},	//   talt, _ifem, --, --,
   {{0x636008ca,0x7cf60716,0x68ed8e2e,0x224d0355}},	//   _gönd, türü, _adad, _řeky_,
   {{0x27e902e9,0x7c220382,0x987000a0,0x09bd0033}},	//   _avan_, _esor, rúča_, _আবহা,
   {{0x7ae18e2f,0xa2cd0066,0x29e7011c,0x7d020079}},	//   salt, दुत्, rđa_, _gcos,
   {{0x7ae18e30,0xeb8e002d,0xb8d600a1,0x7d1b2c3d}},	//   palt, _аи_, _जण_, meus,
   {{0x6d4b0033,0x6360017b,0x7d1b8e31,0x68ed60d6}},	//   _hoga, _köne, leus, _edad,
   {{0xab280642,0xdb1b5988,0x6d4b1377,0xd6270200}},	//   _رسول_, nquí, _koga, море_,
   {{0x6d4b8e32,0xe5a32294,0x7d1b8e33,0x99f6011d}},	//   _joga, виси, neus, _חזקה_,
   {{0x6d4b2ecd,0x9f5f8e34,0x2fcd01e8,0x6360013c}},	// [9b80] _moga, _aquí_, _nteg_, _löne,
   {{0xdcda1856,0x7d1b8e35,0x44228e36,0x98a90207}},	//   _यज्ञ, heus, _vsk_, _snać_,
   {{0x75261b66,0xc87f02c9,0x6d4b213d,0x7d1b8c61}},	//   _takz, raße_, _ooga, keus,
   {{0x44228e37,0x63608e38,0xa49b0176,0x27e900a2}},	//   _tsk_, _sönd, _icòn, _yvan_,
   {{0xd01003c7,0x3f8e7b04,0x801a0172,0x7d1b8e39}},	//   الت_, tofu_, تزاز_, deus,
   {{0x4420000e,0x7d0232b0,0x6d4b01da,0x9cfa0033}},	//   mwi_, _scos, _aoga, _আসেন_,
   {{0x656f0297,0xe2970f88,0x4420016e,0x60c98e3a}},	//   _ymch, _жар_, lwi_, _ffem,
   {{0x6d4b8e3b,0x63600723,0x7d1b3533,0xf2a300af}},	//   _coga, _döne, geus, _рисп,
   {{0x6d4b0bc6,0x4420001e,0x3f8e002f,0xaf068e3c}},	//   _doga, nwi_, pofu_, _опал,
   {{0x29120260,0x6b4d0079,0x00000000,0x00000000}},	//   _abya_, _súgr, --, --,
   {{0x6d4b8e3d,0xdd8f002d,0xad620019,0x7d27013c}},	//   _foga, _аш_, _đươn, örsä,
   {{0x7d1b3686,0x7c220312,0x44208e3e,0x6d4b36e9}},	//   ceus, _tsor, kwi_, _goga,
   {{0xf77307f6,0xab2a28a1,0x442001d5,0xed580168}},	//   ناس_, _мода_, jwi_, _guľa_,
   {{0x63600723,0x44208e3f,0xc0530070,0x29120273}},	//   _yöne, dwi_, דזש_, _ebya_,
   {{0xb87b21a4,0x7dc7027d,0xe7eb00fa,0x2bdf00a1}},	//   caín, _kısa, _झटका_, पीठा,
   {{0x6d4b1a71,0x7c2d8e40,0x68ed8e41,0x06e20083}},	//   _xoga, _šari, _udad, _বাণি,
   {{0xb87b004f,0x2d580248,0x659435b8,0x97a7081b}},	// [9b90] maío, _réel_, тату, _орол,
   {{0xb87b0082,0x5f0002e4,0x25090a86,0x399900b5}},	//   laío, _राष्_, _کردی_, dési_,
   {{0x2fcd0307,0x7d1b8e42,0x00000000,0x00000000}},	//   _steg_, yeus, --, --,
   {{0xb87b004f,0x2b0e018d,0x44208e43,0x7d1b01ef}},	//   naío, त्तु_, bwi_, xeus,
   {{0x06e20033,0x7d1b8ddc,0x00000000,0x00000000}},	//   _বাতি, veus, --, --,
   {{0x6d4b02c9,0xb87b0037,0xeaa600b5,0x00000000}},	//   _soga, haío, _مٹ_, --,
   {{0x6d4b1cb0,0x7d1b8e44,0x80d0021a,0x00000000}},	//   _poga, teus, _ड्वे, --,
   {{0xdb1b0caa,0x0c250b46,0x80d90033,0xa3dc0099}},	//   rquí, емин, _ডাক্, णीव_,
   {{0x6d4b8e45,0x7d1b02e1,0xb87b004f,0x6eca0ca4}},	//   _voga, reus, daío, _स्कु,
   {{0x4a450525,0x7d1b8e46,0xfbc80033,0xf1b908b7}},	//   енов, seus, _শিখত, _hiš_,
   {{0xa3e606bb,0x6d4b0014,0x44208e47,0x99520187}},	//   _यौन_, _toga, zwi_, ráž_,
   {{0x25b90065,0xb87b8b4f,0x99520187,0x290400be}},	//   _nisl_, raín, sáž_, üma_,
   {{0xf1b90280,0x3156016b,0xb87b002a,0x973401cb}},	//   _miš_, גירן_, saín, نکدا,
   {{0x4420021e,0x6360033b,0xa92400c7,0xa803002a}},	//   vwi_, _mönc, _ąžuo, áñas,
   {{0x59b90302,0x69962876,0xba520037,0x59c60026}},	//   _ईंटर, _прих, _منوع, _रूपर,
   {{0xb87b0082,0xa2cd0299,0x44202fe7,0xf1b90a78}},	//   caío, दुस्, twi_, _niš_,
   {{0x4420067f,0x68e60a21,0x00000000,0x00000000}},	// [9ba0] uwi_, makd, --, --,
   {{0x44208e48,0x78a40475,0x1423010b,0x00000000}},	//   rwi_, _iziv, ыдум, --,
   {{0x26d80f84,0xa2a50429,0x44208e49,0x25b90183}},	//   mbro_, _करण्, swi_, _fisl_,
   {{0x2902703e,0x3999006c,0x44208e4a,0xb4db0176}},	//   ngka_, tési_, pwi_, _anàf,
   {{0x25dc0380,0x6287017b,0xf1b90207,0xc0e70079}},	//   गीरी_, _exjo, _diš_, رفون_,
   {{0x80d0017a,0x26d802d7,0x6720060a,0x00000000}},	//   _ड्रे, nbro_, मजिक_, --,
   {{0x638301d3,0x644403d0,0xdb030037,0x6e93290e}},	//   _сгра, lxii, _ghné, лишу,
   {{0x798452f0,0x78a40207,0x7dc7013b,0x1e208833}},	//   _njiw, _oziv, _qısa, _मनीष_,
   {{0xfbcf0df3,0x9f860402,0x78a41857,0xfd6600cc}},	//   یتی_, _згад, _nziv, _khuế,
   {{0x5a340dc8,0x7984034d,0x00000000,0x00000000}},	//   внот, _ajiw, --, --,
   {{0x28f98e4b,0xb87b004f,0xa49b0176,0x61fe563f}},	//   мень_, taío, _acòl, nupl,
   {{0xfaa30409,0xa3c0000c,0x00000000,0x00000000}},	//   ышын, ँदा_, --, --,
   {{0xb87b004f,0xd8380d8a,0xdd8f10ee,0x7984012f}},	//   raío, нэр_, _اون_, _djiw,
   {{0x61fe326f,0xb87b004f,0x48ed000c,0x78a40228}},	//   kupl, saío, _आएको_, _dziv,
   {{0xdb0301c0,0xb9070033,0x249f0c6e,0x78a4001c}},	//   _jiný, _পা_, _šum_, _eziv,
   {{0xba9b0122,0x656400a7,0x1a9b00a5,0x00000000}},	//   _מסוי, ghih, _מיוע, --,
   {{0x26d81005,0x94770d4f,0x24f800d8,0x61fe0345}},	// [9bb0] bbro_, ردرا, энты_, eupl,
   {{0xd6db0086,0x799d64d3,0x47353379,0xb87b17b6}},	//   _эти_, llsw, _рнос, naím,
   {{0xa4d92374,0x61fe35df,0x81c90033,0xf1b91575}},	//   _одну_, gupl, লীন_, _piš_,
   {{0x60b5036b,0x00000000,0x00000000,0x00000000}},	//   نمائ, --, --, --,
   {{0xdb180132,0xf1b9873b,0x753d8e4c,0x2ca000f1}},	//   _vivê, _viš_, _insz, _ùidh_,
   {{0x0eac0067,0x8f6a00fd,0x00000000,0x00000000}},	//   टइंड, ولنے_, --, --,
   {{0x61fe0160,0x00000000,0x00000000,0x00000000}},	//   cupl, --, --, --,
   {{0x69c71840,0xa2cd035d,0x6a4a0095,0x2b0e022e}},	//   íjem, दुर्, rəfl, त्सु_,
   {{0x51840f27,0xdb18021e,0x63600282,0x752d01b7}},	//   _сура, _kivè, _höna, idaz,
   {{0x799d01ae,0x162101c0,0xf412024b,0x00000000}},	//   elsw, मबार_, ספי_, --,
   {{0x68e6121e,0x78a400b5,0x753d02a2,0xb87b0098}},	//   takd, _sziv, _onsz, saíl,
   {{0x4ad102e4,0x999f00c7,0x00000000,0x00000000}},	//   _द्रव, dytų_, --, --,
   {{0xf1b2168d,0xdce20207,0x8b250bbc,0x68e6048f}},	//   יסט_, _smoć, _адле, rakd,
   {{0x06e20083,0x290500b5,0x6d5b1c9a,0x6d492981}},	//   _বাহি, őlap_, lkua, ljea,
   {{0x26d81058,0x66e320c3,0x06b50033,0xa5963367}},	//   rbro_, роса, _জ্বি, вращ,
   {{0x7ae33d64,0x26d88e4d,0x6d5b8e4e,0x6d498e4f}},	//   _hent, sbro_, nkua, njea,
   {{0xc9530052,0x78a408c2,0x69c3002d,0x332a0279}},	// [9bc0] _כמה_, _uziv, _hune, _pabx_,
   {{0x61fe029d,0x7ae38e50,0x69c38e51,0x65648e52}},	//   tupl, _jent, _kune, shih,
   {{0xdb1802e9,0x1db30096,0x6d5b0a13,0x2cb10355}},	//   _divè, ुदात, kkua, ězdy_,
   {{0x7ae30c28,0x69c38e53,0x61fe8e54,0xb29503fa}},	//   _lent, _mune, rupl, ујућ,
   {{0x69c3423b,0xdb0b8e55,0x68e48e56,0x7ae3022e}},	//   _lune, _bugü, _meid, _oent,
   {{0x68e41025,0x7ae38e57,0x27e002d0,0x399900b5}},	//   _leid, _nent, _mwin_, lést_,
   {{0x44328e58,0x69c321c3,0x91e338df,0x35a70066}},	//   lvy_, _nune, _восе, _कीड़,
   {{0x68e48e59,0x27ed0496,0xdce9027d,0x399940b6}},	//   _neid, šeni_, rneğ, nést_,
   {{0x7ae33829,0x63bc450c,0xe7bd0033,0xd84300ac}},	//   _bent, _kirn, _অব্য, _mlčí_,
   {{0x63bc007a,0x69c38e5a,0xdb1800b5,0xda7a0352}},	//   _jirn, _bune, _kivé, дям_,
   {{0x68e48e5b,0x63bc753e,0x69c3137d,0x7ae32e65}},	//   _beid, _mirn, _cune, _dent,
   {{0x7ae37057,0x2fc4010d,0x629c03c1,0x68e400e9}},	//   _eent, _kumg_, _myro, _ceid,
   {{0x5887004b,0x7ae38e5c,0x68e401a6,0x60cd00de}},	//   тына, _fent, _deid, ñami,
   {{0x7ae38e5d,0x63bc8e5e,0x629c0159,0xac170043}},	//   _gent, _nirn, _oyro, _рошу_,
   {{0xe5c47b96,0x68e40082,0x69c38e5f,0x3166006c}},	//   исто, _feid, _gune, khoz_,
   {{0x7ae38e60,0xd9440202,0x8ab70122,0x60c00159}},	//   _zent, _већи, _בלוג_, _ngmm,
   {{0xe45400d8,0x63bc8e61,0x629c0008,0x7ae38e62}},	// [9bd0] акты, _birn, _ayro, _yent,
   {{0x7ae3043f,0x629c8e63,0x7ae8299a,0x68e46b02}},	//   _xent, _byro, nadt, _zeid,
   {{0x63bc1394,0xf2c416b6,0x6d5b0031,0xdb180392}},	//   _dirn, рсун, ykua, _vivè,
   {{0x61ee0176,0xdb180118,0xf8e3021a,0xf8c1073f}},	//   _dvbl, _divé, परिय, _एलोप,
   {{0x629c043d,0x7ae88e64,0xdb0a00ac,0xe0d800d4}},	//   _eyro, kadt, _difú, тві_,
   {{0x6360008a,0xdb0301f7,0x63bc8e65,0xada700ee}},	//   _hönn, _linò, _girn, _obĺú,
   {{0x63608e66,0x60c4010b,0xa3c90035,0x6d5b8e67}},	//   _könn, žima, _लंड_, tkua,
   {{0x69c38e68,0x636000b5,0x63bc8e69,0x29092e65}},	//   _rune, _jönn, _zirn, _ncaa_,
   {{0x7ae38e6a,0x6d5b0c6d,0x69c38e6b,0x2d86012f}},	//   _pent, rkua, _sune, _djoe_,
   {{0xe9d92cdd,0x69c38e6c,0x69c4016f,0x6d5b8e6d}},	//   нко_, _pune, _čier, skua,
   {{0xc33200c2,0x68e44578,0x44320187,0xdb030b4c}},	//   זוי_, _peid, zvy_, _sinó,
   {{0xf99f02e9,0x7ae38e6e,0x29090176,0x69c38e6f}},	//   glè_, _went, _ccaa_, _vune,
   {{0x68e48e70,0xe9e901ba,0x399900b8,0x3a270223}},	//   _veid, dnúť_, vést_, _wsnp_,
   {{0x68e406e1,0xa87500c3,0x3dc5001c,0x2d9f8e71}},	//   _weid, рующ, _kulw_, llue_,
   {{0x68e48e72,0x2bdf2188,0x3999006c,0x00000000}},	//   _teid, पीरा, tést_, --,
   {{0x63bc8e73,0x96d40026,0x0906036c,0x27e00f00}},	//   _sirn, _ब्रॉ, _спин, _twin_,
   {{0x629c0865,0x39408e74,0xd4672aac,0x15b9010b}},	// [9be0] _syro, _inis_, гите_, тыры_,
   {{0x44328e75,0x872600c3,0xdb0300d5,0xe3cd0033}},	//   rvy_, _смож, _ohní, _লিখব,
   {{0x64402b6c,0x63bc8e76,0x39401901,0x316600fd}},	//   _šmid, _virn, _knis_, thoz_,
   {{0x629c05d3,0xf1a90a42,0x636002b1,0x98a50067}},	//   _vyro, نانه_, _gönn, ślą_,
   {{0x63bc8e77,0x629c0035,0xdfcf0037,0x25b28e78}},	//   _tirn, _wyro, كين_, mmyl_,
   {{0x629c8e79,0x3166006c,0x96a8000c,0x8f3407c3}},	//   _tyro, shoz_, _गराउ, рекц,
   {{0x2d9f8e7a,0x2ee50298,0x6eca0067,0x63600282}},	//   flue_, _delf_, सुगु, _höno,
   {{0x5d543cc0,0x212d009e,0xf1aa00f8,0x00000000}},	//   ркит, _gaeh_, _سازه_, --,
   {{0x21670011,0x7ae88e7b,0x5477016b,0x00000000}},	//   _сити_, tadt, ָגיע_, --,
   {{0x96d40378,0x2d9f0328,0x25a03833,0x9b580370}},	//   _ब्लॉ, alue_, hlil_, тиот_,
   {{0xdb03004f,0x7ae87efd,0x2d86012f,0x39528e7c}},	//   _ghní, radt, _tjoe_, _boys_,
   {{0x2ee504ce,0x02b70070,0x2d9f512a,0x39520027}},	//   _zelf_, טליך_, clue_, _coys_,
   {{0x8d930082,0xec3402fd,0x9c5700f8,0x00000000}},	//   _النش, _خوشگ, _مجوز_, --,
   {{0x6360008d,0x00000000,0x00000000,0x00000000}},	//   _sönn, --, --, --,
   {{0x58d50133,0x3940008c,0x2909023c,0x00000000}},	//   _койт, _fnis_, _tcaa_, --,
   {{0x58391172,0x2363012f,0xb4d5218b,0x6360017b}},	//   _азия_, _sljj_, ржащ, _böno,
   {{0x33750677,0x80cd0033,0xa9bc00a5,0xe8d800a5}},	// [9bf0] агар, ারম্, _אזהר, _עוזר_,
   {{0x5f09021a,0x00000000,0x00000000,0x00000000}},	//   _साध्_, --, --, --,
   {{0x77ba00a5,0xb4db009e,0x02a74fc7,0x93881474}},	//   _שמתח, _cnàc, урам, уста_,
   {{0x2ee50122,0x27ed011c,0xa49b009e,0x90e71026}},	//   _self_, šenu_, _lcòi, اسان,
   {{0x6360013b,0x00000000,0x00000000,0x00000000}},	//   _könl, --, --, --,
   {{0x80d50035,0x442b8e7d,0x212d0118,0x44390f00}},	//   _ड्रइ, _isc_, _waeh_, _irs_,
   {{0x44398e7e,0xf1a705c2,0x752f0035,0x6b5f0b88}},	//   _hrs_, _бран, _kacz, _sêgo,
   {{0x5284004f,0x443973c9,0x442b8e7f,0x63600282}},	//   _الفك, _krs_, _ksc_, _lönl,
   {{0x50678e80,0xab658e81,0x2ee58e82,0x44398e83}},	//   _ства, ивил, _telf_, _jrs_,
   {{0xce6b0f8c,0xd7a41163,0xb87b0279,0x39520625}},	//   _пред_, _खींच, ibíd, _soys_,
   {{0xa96a0525,0xfaa55095,0x44398e84,0x442b013a}},	//   вина_, рано, _lrs_, _lsc_,
   {{0x752f0035,0x00000000,0x00000000,0x00000000}},	//   _nacz, --, --, --,
   {{0x7db403c5,0x442b002a,0x4439250e,0xebe53c3b}},	//   _اصلا, _nsc_, _nrs_, _толп,
   {{0x7c2b5a84,0x66e34054,0x00000000,0x00000000}},	//   _isgr, жора, --, --,
   {{0x39528e85,0x00000000,0x00000000,0x00000000}},	//   _toys_, --, --, --,
   {{0x39400248,0x442b64d3,0xbdfa0033,0x00000000}},	//   _unis_, _bsc_, _আহমদ_, --,

   {{0x25b20298,0x25a08e86,0x00000000,0x00000000}},	// [9c00] rmyl_, rlil_, --, --,
   {{0x44390099,0x25a08e87,0x63600225,0x00000000}},	//   _drs_, slil_, _gönl, --,
   {{0x4439430c,0xb2260043,0xe5a67f42,0x366a059b}},	//   _ers_, рмел, _вини, _рано_,
   {{0x44394d0b,0x00000000,0x00000000,0x00000000}},	//   _frs_, --, --, --,
   {{0x33d501c8,0x6a4a01c2,0x44398e88,0x60c40168}},	//   _гіст, rəfi, _grs_, žimo,
   {{0x752f004e,0x25e30084,0x00000000,0x00000000}},	//   _zacz, टीवी_, --, --,
   {{0x7c2d093f,0x22473308,0x69c10325,0xb87b02d7}},	//   _šarp, änkt_, _रंगी, mbíe,
   {{0x23720067,0x44393080,0x00000000,0x00000000}},	//   żają_, _yrs_, --, --,
   {{0x765c099e,0x8c435604,0x00000000,0x00000000}},	//   hyry, жење, --, --,
   {{0x61fe271e,0x7c39011e,0x7524033b,0xdb030211}},	//   orpl, _drwr, heiz, _chnà,
   {{0x19590f99,0x7c2b0890,0x00000000,0x00000000}},	//   ганы_, _esgr, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8cf66c3,0x68f60297,0x752f004e,0x6d42581e}},	//   _कर_, _ddyd, _racz, _inoa,
   {{0x0b930bdf,0x656603d5,0xdb030284,0x628e00f6}},	//   _وجود, _alkh, _ghnà, _oxbo,
   {{0x752f0035,0x6d420051,0x99420067,0x00000000}},	//   _pacz, _knoa, _dół_, --,
   {{0x81c40b52,0x442b12c3,0x7c2b0297,0x99d345fd}},	//   _এবং_, _psc_, _ysgr, _بتوا,
   {{0x61fe3777,0xf2c70e05,0x69da8e89,0x291b009f}},	// [9c10] erpl, асен, lpte, _ibqa_,
   {{0x34a713a0,0xdb0a004f,0x69da0e97,0x442b8a3c}},	//   _खरीद, _bhfé, opte, _vsc_,
   {{0x6d4200af,0x443900ee,0x5f0025d8,0x00000000}},	//   _onoa, _wrs_, _राज्_, --,
   {{0xdd8601ca,0x442b0ae5,0x7afd010b,0x51840274}},	//   _رو_, _tsc_, ėsti, оуча,
   {{0x44398e8a,0xf77000d1,0xf484149e,0x442b0147}},	//   _urs_, _رای_, _дурн, _usc_,
   {{0x44291d6a,0xa2d604bc,0x6d420159,0xf8bf00b5}},	//   mwa_, मुद्, _anoa, ldés_,
   {{0x44296210,0xdb180391,0x61fe0254,0x628e1491}},	//   lwa_, _civí, crpl, _gxbo,
   {{0xf8bf8e8b,0xdb188e8c,0x98a50035,0x44298e8d}},	//   ndés_, _diví, ślę_, owa_,
   {{0x44298e8e,0xeb99265e,0xdd2f00b8,0x1c42037c}},	//   nwa_, лии_, _těžk, зным,
   {{0x44290054,0x201f0065,0x00000000,0x00000000}},	//   iwa_, _ipui_, --, --,
   {{0x44290429,0xed3500af,0x81c90033,0xdb030098}},	//   hwa_, _гэлэ, লীর_, _chná,
   {{0x4429801c,0xce680b32,0xf41f07c0,0x00000000}},	//   kwa_, _труд_, _opä_, --,
   {{0xa2e800c8,0xa2be046c,0x7d098e8f,0x44298e90}},	//   _পাসও, _वृन्, mges, jwa_,
   {{0x59cf0821,0x44298e91,0x7d098e92,0x7c298e93}},	//   _संपर, dwa_, lges, mwer,
   {{0x7c290b3c,0xdb03004f,0x75240c6f,0x19f900af}},	//   lwer, _ghná, teiz, _сэль_,
   {{0x16a80fc3,0x44290e94,0x00000000,0x00000000}},	//   _गरीब, fwa_, --, --,
   {{0x442925b0,0x7c292668,0x752421d5,0x48de0084}},	// [9c20] gwa_, nwer, reiz, _क्यो_,
   {{0x06e200c8,0x61fe0169,0x7d09033b,0x7c291b4a}},	//   _বাকি, trpl, hges, iwer,
   {{0xe1fa5c36,0x7c2902c9,0x44292eb8,0xb9c104d4}},	//   уге_, hwer, awa_, _üçün,
   {{0x4429462e,0x7c292a6a,0x26380187,0x106a004c}},	//   bwa_, kwer, _ičo_, лией_,
   {{0x7bcf478a,0x6360013c,0x7c290120,0x44290010}},	//   ícul, _jönk, jwer, cwa_,
   {{0x69da038d,0x0ce000b4,0x7c298e94,0x7d09000b}},	//   ypte, नर्म, dwer, eges,
   {{0xdef901c8,0x7c290d35,0x7d093481,0x201f0107}},	//   рыі_, ewer, fges, _epui_,
   {{0xdb182675,0x7c298e95,0x7d098e96,0xdd901d05}},	//   _viví, fwer, gges, بوب_,
   {{0x7c298e97,0x80660994,0xb87b0079,0xa6c00033}},	//   gwer, _уваж, naít, ্রিয়,
   {{0x2619004e,0x6e3c2017,0x7d090088,0xdce20207}},	//   _पहली_, _árbo, ages, _iloč,
   {{0x44298e98,0xdc5501df,0xdb01000d,0x6e960037}},	//   zwa_, مریک, illè, _الضا,
   {{0xd90f1c0c,0x7c290173,0x44298e99,0x99671607}},	//   ریخ_, bwer, ywa_, стол,
   {{0x34a700a1,0x7c290223,0x00000000,0x00000000}},	//   _खरेद, cwer, --, --,
   {{0x4429142f,0x69da8e9a,0xd7f800c3,0xb87b0079}},	//   vwa_, ppte, щую_, daít,
   {{0x44290484,0x7aea002d,0x4b7b1804,0xdb0300ee}},	//   wwa_, _ieft, _תאוו, _uhná,
   {{0x44298e9b,0x46d9073f,0x7aea8e9c,0x6b9a32e0}},	//   twa_, _ब्रह, _heft, lotg,
   {{0xf8bf8e9d,0x44290195,0x3f8700e9,0x69ca6b35}},	// [9c30] rdés_, uwa_, ynnu_, _hufe,
   {{0x442936e4,0x7aea0ce9,0x69ca8e9e,0xe2f901e0}},	//   rwa_, _jeft, _kufe, режі_,
   {{0x44291903,0x7d09053e,0x201f002d,0xa3c900be}},	//   swa_, yges, _spui_, _लूर_,
   {{0x44298e9f,0x3f9e8ea0,0x7c298ea1,0xdce200ac}},	//   pwa_, _aktu_, ywer, _bloč,
   {{0x442909e7,0x7af800a0,0x00000000,0x00000000}},	//   qwa_, _odvt, --, --,
   {{0x7aea0095,0x555200b5,0x69d80282,0x00000000}},	//   _neft, _ٹھہر, _otve, --,
   {{0x7d0902c0,0x7c2919c1,0x69ca0160,0x661501ed}},	//   tges, wwer, _nufe, ntzk,
   {{0xed5900f0,0x7c298ea2,0x798d6e77,0x78ad0116}},	//   рои_, twer, _njaw, _ozav,
   {{0x7d098ea3,0x7c298ea4,0x69d84cd6,0x69ca8ea5}},	//   rges, uwer, _atve, _aufe,
   {{0x7c298ea6,0x7d093388,0x656d8ea7,0xdd9900d5}},	//   rwer, sges, hhah, soň_,
   {{0xdce205e2,0x7c298ea8,0x7aea027d,0xdd990334}},	//   _zloč, swer, _deft, poň_,
   {{0x7bdb8ea9,0xdb01178d,0xac1956e8,0xd01000fd}},	//   ppuu, illé, _воду_, _تلے_,
   {{0x656d00f8,0xb87b2cad,0x6b9a4190,0x798d1b18}},	//   dhah, daís, botg, _djaw,
   {{0x7bcb002a,0xdb0a0176,0xe73a0274,0x2d8a0176}},	//   _iugu, _difó, шег_, _íber_,
   {{0x7bcb8eaa,0x857a19b3,0x7bc31fac,0x69ca00d5}},	//   _hugu, асат_, _iinu, _gufe,
   {{0x7bc30b04,0x7bcb1d6a,0x656d0269,0xf99237a4}},	//   _hinu, _kugu, ghah, _تبت_,
   {{0x64a36130,0x7bcb8eab,0x7bc38eac,0xe7320833}},	// [9c40] дата, _jugu, _kinu, _قصد_,
   {{0xaac90d53,0x7bcb8ead,0xdb18006c,0x636001ae}},	//   रशिक, _mugu, _kivá, _köni,
   {{0x7bcb7b7c,0xb87b0079,0x69c4018d,0x656d009e}},	//   _lugu, saít, _kiie, bhah,
   {{0xdce205e2,0x02aa2b6d,0x5a0c0070,0x04460043}},	//   _ploč, _करीन, רלאַ, _демн,
   {{0x2eee8eae,0x644b00ab,0x7bcb04e1,0xdb0a01ef}},	//   taff_, ägit, _nugu, _xifó,
   {{0x7bc308dd,0x44223ad3,0xdce200ac,0x78a47d08}},	//   _ninu, _ipk_, _vloč, _myiv,
   {{0x2eee8eaf,0xdbd103e6,0x7bd90027,0x44222119}},	//   raff_, qüên, _atwu, _hpk_,
   {{0x7bc30006,0x7bcb8eb0,0x44228eb1,0xa2d6060a}},	//   _ainu, _bugu, _kpk_, मुर्,
   {{0xa2be02cb,0xa06700a4,0x69ca0043,0x7bc38eb2}},	//   _वृत्, _дата_, _sufe, _binu,
   {{0x7bcb06a2,0xb4db0443,0x44228eb3,0x00000000}},	//   _dugu, _anàl, _mpk_, --,
   {{0x78ad0332,0x7bc38eb4,0x6b9a01f7,0x7aea008a}},	//   _szav, _dinu, rotg, _veft,
   {{0x7bc3008a,0xdb18024e,0xdb030132,0x7bcb428c}},	//   _einu, _divá, _sinô, _fugu,
   {{0x64402a9f,0x7bc38eb5,0x69c4009e,0x78a40371}},	//   _šmin, _finu, _diie, _cyiv,
   {{0x3f9c0b16,0x7bc38eb6,0x7c22021d,0x00000000}},	//   novu_, _ginu, _ipor, --,
   {{0x69d86efe,0x95cb1f6a,0x44226b02,0x656d00f8}},	//   _utve, руга_, _apk_, thah,
   {{0x3f9c8eb7,0x44228eb8,0x3201024e,0x656d01a2}},	//   hovu_, _bpk_, vrhy_, uhah,
   {{0xb87b36b0,0x78ad053d,0xa49b0176,0x2d510300}},	// [9c50] raís, _uzav, _acòr, _páez_,
   {{0x656d3d6d,0x68ed8eb9,0x27e98eba,0x4422667d}},	//   shah, _head, _iwan_, _dpk_,
   {{0xa2be09b4,0x68ed0f1a,0x3f9c429e,0x69ce01ba}},	//   _वृद्, _kead, dovu_, íbeh,
   {{0x27e914cc,0x61e7006d,0x44220345,0x417400f8}},	//   _kwan_, _vwjl, _fpk_, وانس,
   {{0xd6bd0083,0x4422046a,0xb97c0070,0x657d7272}},	//   _অভিয, _gpk_, סנדי, _imsh,
   {{0xdfce317b,0x3f9c0a78,0x68ed8ebb,0xdb0a0037}},	//   ديو_, govu_, _lead, _bhfí,
   {{0x7c228ebc,0x7bc38ebd,0x7bcb8ebe,0x59c60b57}},	//   _apor, _rinu, _sugu, _रंगर,
   {{0x7bcb12c3,0x7bc38ebf,0x6aa30345,0x7c2211cf}},	//   _pugu, _sinu, _rynf, _bpor,
   {{0x3f9c8ec0,0x7bc37db7,0x9c2200c3,0x6ed806d9}},	//   bovu_, _pinu, едыд, नुहु,
   {{0x3b090202,0x59cf2c29,0xa3ab018d,0x3cdb0026}},	//   љено_, _संदर, खति_, _ग्रे_,
   {{0x7bc38ec1,0x27e98ec2,0x7c228ec3,0x31ae0187}},	//   _vinu, _awan_, _epor, lýza_,
   {{0xbea800bf,0x68ed0a32,0x7bcb8ec4,0x27e910d6}},	//   _بهمن_, _cead, _tugu, _bwan_,
   {{0x7bc37161,0x8d7400d1,0x69c400ab,0xa3ab3138}},	//   _tinu, _تالا, _viie, खता_,
   {{0x81e100c8,0xc6150033,0x657d8ec5,0x27e90107}},	//   _দিন_, াবনা_, _amsh, _dwan_,
   {{0x68ed1093,0x27e90dc3,0x6d598ec6,0xdcfb0254}},	//   _fead, _ewan_, _kowa, gnuć,
   {{0x60c900d1,0x3f9c8ec7,0x68ed443e,0x44220ccc}},	//   _ngem, zovu_, _gead, _ppk_,
   {{0xa2be0266,0x291201d5,0x6d59018e,0x27e98ec8}},	// [9c60] वेन्, _icya_, _mowa, _gwan_,
   {{0x083b0122,0x6d590054,0x60c98ec9,0x44228eca}},	//   _פעיל, _lowa, _agem, _vpk_,
   {{0xb6a30248,0xa75b00a5,0x3f9c00f4,0x00000000}},	//   éâtr, _הדיר, vovu_, --,
   {{0x6d598ecb,0x6b818ecc,0x4fc60370,0x68ed0042}},	//   _nowa, hilg, пска, _xead,
   {{0xdbd10443,0x8fa61c6b,0xea000023,0x9f340210}},	//   qüèn, паде, _trầy_, делі,
   {{0x60c98ecd,0x00000000,0x00000000,0x00000000}},	//   _egem, --, --, --,
   {{0x7d1b8ece,0x2cc101c2,0x3f9c19bf,0x6b8101ef}},	//   ffus, ərdə_, rovu_, dilg,
   {{0x6b81004f,0x6d598ecf,0x3f9c01a0,0x7d780037}},	//   eilg, _cowa, sovu_, تمبر_,
   {{0x68ed0122,0x6d598ed0,0x69d50355,0x205503e6}},	//   _read, _dowa, ízen, _отфр,
   {{0x68ed8ed1,0x27e98ed2,0x9f8300af,0x3ea50185}},	//   _sead, _rwan_, _згуд, _fylt_,
   {{0x68ed8ed3,0x799d74b6,0xb4db01da,0x27e90147}},	//   _pead, tosw, _snàm, _swan_,
   {{0x27e902d0,0x7c22022f,0x00000000,0x00000000}},	//   _pwan_, _tpor, --, --,
   {{0x7c2239ea,0x6b818ed4,0x799d0453,0x68ed5856}},	//   _upor, bilg, rosw, _vead,
   {{0xc7c40086,0x68e00457,0x6b810042,0xb90423e3}},	//   есси, ımda, cilg, _प्_,
   {{0x68ed0006,0x356b0eee,0x3a3a00b5,0x6d59018e}},	//   _tead, бран_, _épp_, _yowa,
   {{0xc87f02b1,0x27e9616d,0xdcfb00f4,0x00000000}},	//   faßt_, _twan_, rnuć, --,
   {{0xdcfb3485,0x97320594,0x27e90118,0x00000000}},	// [9c70] snuć, رکیا, _uwan_, --,
   {{0x81e10033,0x00000000,0x00000000,0x00000000}},	//   _দিব_, --, --, --,
   {{0x35b5668a,0xe69500af,0x394902fc,0x00000000}},	//   _обор, _цины, _knas_, --,
   {{0x6b818ed5,0x657d8ed6,0x59cf05f8,0x2ca60118}},	//   zilg, _umsh, _संसर, _oyod_,
   {{0x6d5960cc,0x25a900d5,0x3ea540d1,0x26170183}},	//   _rowa, mlal_, _sylt_, lço_,
   {{0x6d598ed7,0x9618006c,0x25a98ed8,0xbea503e6}},	//   _sowa, _بغیر_, llal_, малк,
   {{0x26178ed9,0x6d590035,0x6b818eda,0x394900ee}},	//   nço_, _powa, vilg, _onas_,
   {{0x61fa008a,0x5f770332,0x60c93de0,0x1c450352}},	//   _ætla, _کارر, _ugem, дним,
   {{0x6b818edb,0xd6c50083,0x2fc50211,0x00000000}},	//   tilg, ্রিয, _tilg_, --,
   {{0x7c3b082b,0x2ca60359,0x7f5a0118,0x7d1b8edc}},	//   rvur, _dyod_, _gotq, sfus,
   {{0x6d590f6e,0x7d1b04fb,0x25a901fb,0x6e670421}},	//   _towa, pfus, klal_, _этаж,
   {{0x37e20033,0xb87b83fc,0x6b818edd,0x39490160}},	//   _বিবর, rbín, silg, _cnas_,
   {{0x02aa0ac4,0x59cf37e8,0x2ca608dd,0x6b817bb5}},	//   _कर्न, _संवर, _gyod_, pilg,
   {{0x6b81007a,0xae21073f,0x39494f93,0x2d8d0051}},	//   qilg, _महान_, _enas_, lnee_,
   {{0xe5a60142,0x637201b4,0x2d8d023c,0x31660225}},	//   диви, _hæng, onee_, ykoz_,
   {{0xdb1803ad,0x2d8d8ede,0x699500d8,0xa2be012f}},	//   _eivä, nnee_, _прых, _वृष्,
   {{0xe73a408d,0xfc4a0093,0xd6cf006c,0x00000000}},	// [9c80] _деп_, mtíð_, اقہ_, --,
   {{0x39490c21,0x637201b4,0x316d021e,0x2d9f19d2}},	//   _znas_, _mæng, _alez_, houe_,
   {{0xa2b30380,0x63720022,0xa2be1404,0x316d0009}},	//   _अरण्, _læng, _वृश्, _blez_,
   {{0xa3c9009a,0x6e3c3207,0x00000000,0x00000000}},	//   _लूक_, _árbi, --, --,
   {{0xdfcf21a0,0x25a00036,0x92c00033,0x3166361c}},	//   لين_, moil_, ীরে_, rkoz_,
   {{0x26d88edf,0x6d5d01ff,0x00000000,0x00000000}},	//   ncro_, ösan, --, --,
   {{0x6360006c,0x03a30421,0x00000000,0x00000000}},	//   _dönt, _риро, --, --,
   {{0x60260274,0x316d02d7,0x00000000,0x00000000}},	//   _одба, _glez_, --, --,
   {{0x657a00a2,0x00000000,0x00000000,0x00000000}},	//   éthy, --, --, --,
   {{0xdb0a0079,0x6eb60037,0x33380069,0x39490767}},	//   _bhfá, _قصائ, _jarx_, _snas_,
   {{0xc3335c8e,0x2d9f03bc,0x2d8d8ee0,0xdb181281}},	//   דות_, boue_, bnee_, _nivå,
   {{0x59ac0084,0x6372035b,0x636001ff,0x8f0e1f57}},	//   _टीआर, _hænd, _köns, _साँझ_,
   {{0xd83801f1,0x63602d49,0x290500d0,0x2006002a}},	//   мэр_, _yönt, ğla_, nroi_,
   {{0x2d848ee1,0x6360013c,0x290500c1,0x00000000}},	//   lime_, _möns, şla_, --,
   {{0x636001ff,0x63720b3e,0x00000000,0x00000000}},	//   _löns, _mænd, --, --,
   {{0x261700c9,0x2d848ee2,0x39490083,0x26d801ef}},	//   rço_, nime_, _unas_, acro_,
   {{0x36d56229,0x34950036,0x25a9012f,0x425500ff}},	// [9c90] _попр, хаар, rlal_, کنار,
   {{0x25a90e6a,0x2d848ee3,0x316d0009,0x00000000}},	//   slal_, hime_, _slez_, --,
   {{0x2d848ee4,0x2d8d0328,0x15e800b4,0x00000000}},	//   kime_, ynee_, टीआर_, --,
   {{0x2d84550e,0x37e20083,0x63600282,0x25a91767}},	//   jime_, _বিতর, _böns, qlal_,
   {{0x752d0043,0x2d848ee5,0x63720093,0x656f0079}},	//   meaz, dime_, _bænd, _ilch,
   {{0x752d0043,0x63608ee6,0x00000000,0x00000000}},	//   leaz, _döns, --, --,
   {{0x6da5439f,0x69ca0f8a,0xada50409,0xa2be05f8}},	//   ника, _संगी, накл, वेद्,
   {{0x752d0043,0x6360013c,0x3dde011e,0x69d50187}},	//   neaz, _föns, _dttw_, ízem,
   {{0xa2d60d91,0x2d9f053e,0x7e9900d1,0xb4db01da}},	//   मुक्, roue_, _کنار_, _cnài,
   {{0xdbdc008a,0x33380176,0x908a00fd,0xb4cc018d}},	//   ráðh, _xarx_, _عملے_, _लल्_,
   {{0xdea1006c,0x2d848ee7,0xd91002fd,0x656f8ee8}},	//   _حیثی, bime_, لیغ_, _olch,
   {{0x752d002d,0x5c753537,0xbf1b00b4,0xceb2016b}},	//   jeaz, _плет, प्रभ_, _גיב_,
   {{0xeb8e04b2,0x6d4b8ee9,0xec6e8eea,0x60db000e}},	//   _би_, _inga, _сп_, _mfum,
   {{0x3f790070,0x75dc0107,0xfc4a05ee,0x00000000}},	//   לאָס, _lčze, stíð_, --,
   {{0x69ce00de,0x25a08eeb,0x656f0168,0x60db073a}},	//   íbet, toil_, _blch, _ofum,
   {{0x7dc7006c,0x60db001c,0x33380069,0x00000000}},	//   _műso, _nfum, _sarx_, --,
   {{0x2fdf006f,0x09031a0e,0x656f009e,0x79868eec}},	// [9ca0] _ntug_, _спын, _dlch, mikw,
   {{0x25a08eed,0x79868eee,0x138a0037,0x27e08eef}},	//   soil_, likw, أخرى_, _itin_,
   {{0x6d4b8ef0,0x752d0139,0x0cac0b35,0x00000000}},	//   _onga, beaz, _चर्म, --,
   {{0x2d848ef1,0x7986087c,0x20068ef2,0x59b20a44}},	//   xime_, nikw, troi_, ीगिर,
   {{0x403407c1,0x2d848ef3,0xa3c900b4,0xa0670274}},	//   телс, vime_, _लंच_, наца_,
   {{0x6d4b8ef4,0xa2d60253,0x20066022,0x4432016e}},	//   _anga, मुख्, rroi_, mwy_,
   {{0xe2971a55,0xa3c90534,0x6d4b6410,0x29008ef5}},	//   _зар_, _लूट_, _bnga, _odia_,
   {{0x6da304bf,0x5bc80266,0x44320035,0x7986002f}},	//   лија, रद्व, owy_, jikw,
   {{0x79860054,0x4432001e,0x6d4b00d7,0x637201b4}},	//   dikw, nwy_, _dnga, _tænd,
   {{0x5c732246,0x2d848ef6,0x752d0043,0x60c4042a}},	//   ульт, sime_, zeaz, žims,
   {{0x27e000a7,0x2a6a00b5,0x337700a5,0x7e9a083a}},	//   _atin_, ább_, געים_, _عنصر_,
   {{0x67d5176c,0xdb01021d,0x00000000,0x00000000}},	//   кому, nolê, --, --,
   {{0x752d002d,0x38c90ef2,0x00000000,0x00000000}},	//   veaz, بادی_, --, --,
   {{0x44320297,0x6601006c,0x2900007e,0x69ce0042}},	//   dwy_, álko, _edia_, íbes,
   {{0x79a70002,0x752d09f3,0x79868ef7,0xb8d70033}},	//   _прие, teaz, bikw, _জল_,
   {{0x7bca007b,0x555802fb,0xa3c900b4,0x79860371}},	//   _hifu, нася_, _लूज_, cikw,
   {{0x7bca8ef8,0x752d0043,0x6aaa0297,0xa2be0026}},	// [9cb0] _kifu, reaz, _hyff, वेस्,
   {{0x752d0043,0x60db1f26,0x7bca0054,0x00000000}},	//   seaz, _sfum, _jifu, --,
   {{0x7bca000e,0x71f800b5,0x61ee00e9,0x2fdf43c1}},	//   _mifu, فرنس_, _cwbl, _stug_,
   {{0x7ff50ef5,0x02a40036,0xb4db0392,0x7bca8ef9}},	//   نستا, урум, _anàv, _lifu,
   {{0xd5640c8a,0xfbe700cc,0x78fc016b,0xc4282bfc}},	//   _стэп, _chế_, לפאו, _пюре_,
   {{0x798605ba,0x7bca0848,0x63720b3e,0x00000000}},	//   zikw, _nifu, _pæne, --,
   {{0xed5981b6,0x61ee00e9,0x00000000,0x00000000}},	//   дой_, _gwbl, --, --,
   {{0x92e90083,0x60db0054,0x6e2800fe,0x7bca034d}},	//   _যায়_, _ufum, _dpdb, _aifu,
   {{0x6ac90026,0x7bca0b69,0x5bb506cd,0x69cb1db9}},	//   रश्र, _bifu, ксоф, _संजी,
   {{0x0b420a93,0x4a45172a,0x200f8efa,0xdcf134c3}},	//   аньн, внов, mugi_, ıgın,
   {{0x6aaa0297,0x3f878efb,0x200f8efc,0xf2d20d85}},	//   _cyff, minu_, lugi_, יעי_,
   {{0x3f870ad7,0x6d4b16f4,0x69dc0079,0x6aaa00e9}},	//   linu_, _unga, írea, _dyff,
   {{0x8d741062,0xd910006c,0xdb010079,0x79868efd}},	//   _حالا, لیں_, allá, rikw,
   {{0x3f878efe,0x6aaa01da,0x7bca024c,0x660e0553}},	//   ninu_, _fyff, _gifu, tubk,
   {{0x6aaa001e,0xb6a603d0,0x200f2c81,0x798608c7}},	//   _gyff, тивл, hugi_, pikw,
   {{0x7bca43dd,0x3f870024,0x16140035,0x44320035}},	//   _zifu, hinu_, तंबर_, twy_,
   {{0xf77300d1,0xccf20100,0x3f872e3d,0x7bca01d5}},	// [9cc0] _چاپ_, יכן_, kinu_, _yifu,
   {{0x31ca1fc3,0x44328eff,0x200f007c,0xc88701ae}},	//   िद्ध, rwy_, dugi_, ößer_,
   {{0xf5060500,0x3f87011c,0x7ae5007c,0x00000000}},	//   _изно, dinu_, _õhtu, --,
   {{0x4a5a0052,0xcfe600c8,0xafe601c8,0x200f8f00}},	//   ודעו, _নিবন, водл, fugi_,
   {{0x3f870093,0x69cb0761,0x200f00be,0x00000000}},	//   finu_, _संघी, gugi_, --,
   {{0x3f878f01,0x64463f3a,0xa0670274,0x6e943b3c}},	//   ginu_, _irki, ђаја_, лилу,
   {{0x6e2800e5,0xa2be021a,0x7bca87d9,0x00000000}},	//   _qpdb, वेश्, _rifu, --,
   {{0xc5f300a5,0xfbe70023,0x6446023a,0x7bca1ebf}},	//   בדה_, _thế_, _krki, _sifu,
   {{0x3f876192,0xbfc65f4e,0x711b00a5,0x00000000}},	//   binu_, _абак, _קומפ, --,
   {{0x3f8725d2,0x3ce20026,0x1eaa663e,0x798402d7}},	//   cinu_, _ट्रे_, _قاضي_, _amiw,
   {{0x2b130a44,0x7bca0054,0xe9f8010b,0x25750282}},	//   _दारु_, _vifu, энні_, _håle_,
   {{0x394d0138,0x64468f02,0x7bca04fb,0xdb010176}},	//   ñes_, _orki, _wifu, holè,
   {{0x7d028f03,0xb4db0211,0x00000000,0x00000000}},	//   _idos, _mnàt, --, --,
   {{0x7984001c,0xc3080033,0x2575082b,0xe78710b4}},	//   _emiw, র্তি_, _måle_, тумо,
   {{0x64468f04,0x386d2f70,0xfbb700a5,0x6ac00831}},	//   _arki, šer_, _שפות_, _শ্রো,
   {{0x3f8725e5,0x6b88012f,0x69cb0808,0x81e10033}},	//   zinu_, lidg, _सूची, _দিল_,
   {{0x95c88d21,0xf8bf00a2,0x16140067,0x3eac008c}},	// [9cd0] тура_, ffée_, तूबर_, _lydt_,
   {{0xdb018f05,0x64460207,0x78ad0371,0x12d10033}},	//   golè, _drki, _iyav, ির্দ,
   {{0x3f87011c,0x644606a2,0x7d02016f,0xa2be0127}},	//   vinu_, _erki, _odos, वेल्,
   {{0x7d0200da,0x200f8f06,0x657600d5,0x78ad018e}},	//   _ndos, tugi_, chyh, _kyav,
   {{0x3f878f07,0x2bce0785,0xdce200cb,0x257501ff}},	//   tinu_, _हंगा, _zloć, _våld_,
   {{0x753d00f5,0xa2be0ed1,0x7d028f08,0x44398f09}},	//   _hasz, _वृक्, _ados, _iss_,
   {{0x3f878f0a,0x13e80083,0x44398f0b,0x753d2130}},	//   rinu_, _পিয়, _hss_, _kasz,
   {{0x3f878f0c,0x644605ee,0x656d0a5b,0xdb01001b}},	//   sinu_, _yrki, nkah, molé,
   {{0x51848f0d,0xcfab0332,0x3f877fec,0x69dc016f}},	//   _тура, _قائم_, pinu_, íren,
   {{0x44390223,0x753d340b,0x7d0201ed,0x75dc0107}},	//   _mss_, _lasz, _edos, _lčza,
   {{0x44391570,0xdb01002a,0x198a150d,0x78ad0371}},	//   _lss_, nolé, ебни_, _ayav,
   {{0x753d006a,0x44390533,0x78ad010a,0x8d7400fd}},	//   _nasz, _oss_, _byav, _پاما,
   {{0x443987c7,0x291e0035,0x63a51c26,0x69cd264c}},	//   _nss_, ęta_, kohn, _diae,
   {{0xdce20207,0x00000000,0x00000000,0x00000000}},	//   _ploć, --, --, --,
   {{0x44398f0e,0x7bc101ae,0x46a40243,0x656d1ea7}},	//   _ass_, mmlu, _खुशह, fkah,
   {{0x6d5b0f1a,0x656d2700,0x442b0260,0x79848f0f}},	//   njua, gkah, _bpc_, _umiw,
   {{0x4439239a,0x032600af,0xe3ba31d3,0x9f4f008a}},	// [9ce0] _css_, лдан, еба_, yrgð_,
   {{0x68f601c2,0xb4db01da,0xc29a00af,0x64460207}},	//   _heyd, _snàt, нтец_, _vrki,
   {{0x471b02b5,0x753d8f10,0x61460889,0x171b0070}},	//   _אויג, _fasz, лежа, _אויע,
   {{0x673e8f11,0x7c2b8f12,0xdb011a98,0x64460009}},	//   _hapj, _opgr, solè, _trki,
   {{0x68f60092,0x6d5b207a,0x644601a3,0x673e8f13}},	//   _meyd, djua, _urki, _kapj,
   {{0x27f20297,0x8fa302bb,0x753d0067,0x7d1900e5}},	//   _mwyn_, баче, _zasz, _acws,
   {{0x09cf4f02,0x6b888f14,0x7c2b00ea,0x673e3958}},	//   _संगठ, vidg, _apgr, _mapj,
   {{0x44208f15,0x61fe8f16,0x6d5b00da,0x6b880312}},	//   oti_, mspl, gjua, widg,
   {{0x44208f17,0xdee60009,0x25db0066,0x61fe8f18}},	//   nti_, _бози, _खूनी_, lspl,
   {{0x44208f19,0x673e006c,0xf06303fa,0xa49b0260}},	//   iti_, _napj, _укуп, _odòn,
   {{0x4420087a,0xdd8f006c,0x28c70567,0x6b888f1a}},	//   hti_, _کون_, रेनि, ridg,
   {{0x61fe476c,0x7d020035,0xddb6250f,0x673e0223}},	//   ispl, _udos, _صحاب, _aapj,
   {{0x44208f1b,0x68f60471,0x6d400159,0x27f2016e}},	//   jti_, _deyd, mdma, _cwyn_,
   {{0x44398f1c,0x61fe4856,0x27f200e9,0xdceb00ea}},	//   _rss_, kspl, _dwyn_, _ilgā,
   {{0x7afa03ad,0x44208f1d,0xd5bb0423,0x7524033b}},	//   matt, eti_, еса_, ffiz,
   {{0x44208f1e,0x63a501ae,0x61fe1e54,0xb4db0176}},	//   fti_, wohn, dspl, _anàr,
   {{0x44208f1f,0x656d8f20,0xdb030037,0x27f200e9}},	// [9cf0] gti_, rkah, _ghnó, _gwyn_,
   {{0x753d004e,0x2d81006c,0x7bdf000d,0xdb0126e8}},	//   _wasz, éhez_, _éque, tolé,
   {{0x64440dfa,0x44208f21,0x7afa8f22,0xf8b100b5}},	//   avii, ati_, iatt, _دکھ_,
   {{0x673e003a,0x44200e95,0xdb0100d5,0x63bc081b}},	//   _zapj, bti_, rolé, _ehrn,
   {{0x44208f23,0xb97c00c2,0x442b8f24,0xdb01000d}},	//   cti_, ענדי, _upc_, solé,
   {{0xa06633ed,0x6d470080,0x61fe0477,0xdb01399b}},	//   раша_, ējam, bspl, polé,
   {{0x7afa8f25,0x539a011d,0xff040de9,0xa24600b5}},	//   datt, _יישו, сячн, _پینل_,
   {{0x5187021d,0x00000000,0x00000000,0x00000000}},	//   _суга, --, --, --,
   {{0x7afa64e2,0x28c70084,0x6d5b124f,0x2363006d}},	//   fatt, रेमि, rjua, _kojj_,
   {{0x7afa8f26,0x2d860afc,0x68f61183,0x6d5b02d7}},	//   gatt, _emoe_, _seyd, sjua,
   {{0x44208f27,0x491a00ab,0x68f6013b,0x5fba016b}},	//   zti_, _भादो_, _peyd, _סצענ,
   {{0x68f60669,0x44208f28,0x213f0f1a,0x68461fae}},	//   _qeyd, yti_, _jauh_, анма,
   {{0x7c2b8f29,0x44208f2a,0x290c0644,0x25db07b5}},	//   _upgr, xti_, ğda_, _खूबी_,
   {{0xcf9202b5,0x7afa8f2b,0x1ae58f2c,0xcb6656e8}},	//   ַטן_, catt, _токм, _ваше_,
   {{0x24f6562d,0x96638f2d,0x28c700b4,0x25aa0aaa}},	//   ичар, окре, रेबि, ندري_,
   {{0x44208f2e,0x63bc0355,0xdb03009e,0x00000000}},	//   tti_, _shrn, _ghnò, --,
   {{0x44208f2f,0x75240009,0x63860132,0x31bc01c0}},	// [9d00] uti_, rfiz, агаа, níze_,
   {{0x44208f30,0x39400d4b,0x61fe1193,0x64441d10}},	//   rti_, _hais_, tspl, rvii,
   {{0x201f8f31,0x42561156,0x64442933,0xd8430097}},	//   _aqui_, штат, svii, _točí_,
   {{0x44208f32,0x61fe8f33,0x50660009,0x39408f34}},	//   pti_, rspl, итла, _jais_,
   {{0x3940143b,0x44200024,0x61fe8f35,0x7afa027d}},	//   _mais_, qti_, sspl, yatt,
   {{0x3940006f,0x42e70370,0x9e068f36,0x61fe8f37}},	//   _lais_, _вмро_, ачил, pspl,
   {{0x7afa8f38,0x7f83026e,0xdd9a01f2,0x25750282}},	//   vatt, تلون, кши_, _håla_,
   {{0x5d540cac,0x39408f39,0x28c70d00,0x64430035}},	//   скит, _nais_, रेडि, łnie,
   {{0x7afa8f3a,0xafe30210,0x1be70200,0x00000000}},	//   tatt, _мотл, адњи_, --,
   {{0x3952162d,0x257501bc,0x7ac65425,0xeb4a3367}},	//   _anys_, _måla_, исне, тчик_,
   {{0x7afa8f3b,0x28f98f3c,0x39400211,0xfe720079}},	//   ratt, лень_, _bais_, _بدء_,
   {{0xac0a0009,0x7afa2172,0x39408f3d,0x644901c8}},	//   _анда_, satt, _cais_, _šeim,
   {{0x39408f3e,0x7afa8f3f,0xc8648f40,0x00000000}},	//   _dais_, patt, отри, --,
   {{0x7afa009f,0xd7f810b0,0x8a1812a2,0x00000000}},	//   qatt, шую_, _бокс_, --,
   {{0x394002e1,0xc668002d,0x59d01140,0x31ae0097}},	//   _fais_, аште_, _संचर, lýzu_,
   {{0xda5b0052,0x39408f41,0x224d0612,0xb87b002a}},	//   _יכול, _gais_, _ček_, rcíb,
   {{0x68fd8f42,0x7af8006d,0x69d88f43,0xd83b61ad}},	// [9d10] masd, _kevt, _huve, _рэй_,
   {{0x69d800da,0x7af85dd8,0x3940006f,0x213f028b}},	//   _kuve, _jevt, _zais_, _sauh_,
   {{0x3952001e,0x3940006d,0x213f8f44,0xc0d50594}},	//   _ynys_, _yais_, _pauh_, مياب,
   {{0x29191034,0x3940006f,0x68fd8f45,0x69d88f46}},	//   ngsa_, _xais_, nasd, _muve,
   {{0xdee536ed,0x504503e6,0xdb1800ee,0x66150065}},	//   боли, селб, _sivý, luzk,
   {{0x69d802e1,0x63050088,0x543a02b5,0x7af83f01}},	//   _ouve, _دوسل, _געשא, _nevt,
   {{0x69d88f47,0x81e10033,0x92582ad7,0xc29303fc}},	//   _nuve, _দিক_, _карт_, _بیاب,
   {{0x069800a5,0x25a9021d,0x00000000,0x00000000}},	//   ידום_, noal_, --, --,
   {{0x394019c6,0x68fd8f48,0x69d800f7,0x5ba902ee}},	//   _rais_, dasd, _auve, лким_,
   {{0x4ea709d0,0x39408f49,0x69d88f4a,0xa2be0f17}},	//   _креа, _sais_, _buve, वेक्,
   {{0x39400aca,0x69d88f4b,0xa96a0665,0xd9468f4c}},	//   _pais_, _cuve, гина_, бени,
   {{0x69d88f4d,0x200f0036,0xdd8f042c,0x7f411787}},	//   _duve, orgi_, _کوچ_, _halq,
   {{0x39408f4e,0xab2901f2,0x9cda02b5,0xb9000803}},	//   _vais_, _бола_, _עקספ, _तल_,
   {{0x66e31ad4,0x39400159,0xdb180a4a,0x3a3c0176}},	//   зора, _wais_, _divó, _fsvp_,
   {{0x394001a9,0x26181e79,0x69d88f4f,0xa50a2031}},	//   _tais_, बंधी_, _guve, лева_,
   {{0x7bd98f50,0x25a90036,0x257503d0,0x394001da}},	//   _kuwu, goal_, _påla_, _uais_,
   {{0xb87b8f51,0x69d801ae,0x973600af,0x00000000}},	// [9d20] rcíc, _zuve, _лэнч, --,
   {{0x261802e4,0x46f6257f,0x69c6183a,0x69d801b5}},	//   बंदी_, _учит, lmke, _yuve,
   {{0x69d80391,0x35a60ddc,0x3e4700e2,0x7bd9759b}},	//   _xuve, _ганг, _nđt_, _luwu,
   {{0xdb018f52,0x25a90183,0xb87b01ef,0x00000000}},	//   dolí, coal_, lcía, --,
   {{0x7f418f53,0x68e4002f,0x7bd900d1,0x2d8d03bc}},	//   _balq, _mfid, _nuwu, diee_,
   {{0x7f41043f,0xb87b1111,0x637b0160,0xb7db016b}},	//   _calq, ncía, _cînd, אקסי,
   {{0x6566012f,0x2d8d00d7,0x24808f54,0x61468f55}},	//   _kokh, fiee_, lzim_, _лева,
   {{0x3a3c6706,0x7bd9018e,0x7cd80fc5,0x256e008e}},	//   _rsvp_, _buwu, шмир_, _býli_,
   {{0x69d88f56,0x26180084,0x6566028b,0x20560798}},	//   _suve, बूती_, _mokh, _утвр,
   {{0x4f650082,0x65664808,0xc43b00a5,0x7bd901cb}},	//   _والف, _lokh, נתיי, _duwu,
   {{0x999900c9,0x68e90300,0xdb01002a,0x68fd00ec}},	//   икот_, ñedo, colí, tasd,
   {{0x3f8e000e,0x61fa008a,0x2480028b,0x5e570070}},	//   lifu_, _ætlu, kzim_, _ליבע_,
   {{0x68fd00f1,0xdb180359,0xa2aa0067,0x7bd9073a}},	//   rasd, _divò, _जुस्, _guwu,
   {{0x7f4101c2,0x3f8e000e,0x68e400d7,0x661501d7}},	//   _xalq, nifu_, _efid, tuzk,
   {{0x656615ed,0xa5f90274,0x68e400e5,0x00000000}},	//   _bokh, ребу_, _ffid, --,
   {{0x66150291,0xdb0801f4,0x56942447,0xdb010183}},	//   ruzk, kodë, част, colâ,
   {{0xdd1c0187,0x798f66cd,0x6d4201ef,0x98170833}},	// [9d30] kážk, micw, _maoa, _ابعا,
   {{0x63600332,0x66150291,0x27e90a2d,0x6d426001}},	//   _köny, puzk, _itan_, _laoa,
   {{0xd2510c74,0xa4d51645,0x2004005f,0x637b0395}},	//   بنا_, _моні, _avmi_, _rînd,
   {{0x3d1402e4,0x798f0027,0xdb017b10,0x00000000}},	//   _धागे_, nicw, volí, --,
   {{0x3e470023,0x3f8e08c7,0x2378023a,0x1ee7042c}},	//   _sđt_, fifu_, _flrj_, موشی_,
   {{0x7f4100d7,0x2d9a006c,0xdb010334,0x27e901ed}},	//   _qalq, épen_, tolí, _mtan_,
   {{0xdb18024e,0x7bd900f8,0x6d428f57,0x656601cb}},	//   _chví, _suwu, _baoa, _yokh,
   {{0xdb012141,0x27e98f58,0x637b00f7,0x5bd113de}},	//   rolí, _otan_, _dîne, सद्व,
   {{0x0b590104,0x3f8e0054,0x2d8d2de3,0x1c42037c}},	//   арны_, bifu_, riee_, дным,
   {{0x68e48f59,0xdb012127,0xae1900b4,0x3b090200}},	//   _sfid, polí, नंदन_, јено_,
   {{0xeab1004f,0x28c70af9,0x27e98f5a,0x7bd98f5b}},	//   بعة_, रेसि, _atan_, _wuwu,
   {{0x3a980086,0x7bd98f5c,0x626e00f4,0x00000000}},	//   стью_, _tuwu, _uđoš, --,
   {{0xeb8e09ce,0x913a0070,0x7d1b08c7,0x2d9d0027}},	//   _жи_, בערק, mgus, _ijwe_,
   {{0x7d1b007c,0x257c0037,0x7c3b0027,0x27e90107}},	//   lgus, _míle_, mwur, _dtan_,
   {{0x27e98f5d,0x212d8f5e,0xb87b07a6,0x52b8021a}},	//   _etan_, _obeh_, rcía, _अरेस,
   {{0x7c240139,0x00000000,0x00000000,0x00000000}},	//   _ţiri, --, --, --,
   {{0xf74688ae,0x61e971c6,0x336612ea,0x7c3b0110}},	// [9d40] _депо, _čela, оваг, nwur,
   {{0x2575013c,0x3cff0221,0x212d0118,0x2480307e}},	//   _håll_, hauv_, _abeh_, rzim_,
   {{0xe0da1279,0x052a002d,0x65666ad1,0x00000000}},	//   аве_, _конк_, _tokh, --,
   {{0x01aa0204,0x64430035,0x7c3b0298,0x27e901ff}},	//   шкек_, łnia, kwur, _ytan_,
   {{0xa2aa0299,0x3f8e8f5f,0x44240c6f,0xaaab0324}},	//   _जुर्, tifu_, _ëm_, _घुसक,
   {{0x7d1b8f60,0x7c3b0298,0xdb088df1,0x257c06fe}},	//   egus, dwur, codè, _díle_,
   {{0xe2978f61,0xdd1c0187,0x3f8e8f62,0x63721f8b}},	//   _дар_, rážk, rifu_, _lænk,
   {{0x3f8e8f63,0x717600f8,0x6b8a0176,0xa06a021d}},	//   sifu_, _بهرا, _smfg, _каба_,
   {{0xe8160775,0x00000000,0x00000000,0x00000000}},	//   _तमगा_, --, --, --,
   {{0xe45700c2,0xee0a00af,0x8afc0067,0x00000000}},	//   קייט_, _вежл_, djęc, --,
   {{0x798f0027,0xa2be48cd,0x637b0160,0x1f59002d}},	//   ticw, वेच्, _hînc, _ушть_,
   {{0x63720b3e,0xed570f16,0x7c3b0027,0x256e00fe}},	//   _bænk, _мох_, bwur, _kýlu_,
   {{0x7dd500d8,0x798f2635,0x00000000,0x00000000}},	//   _išsa, ricw, --, --,
   {{0x7d005c4d,0x28c702b4,0xb7bb0183,0x2904008d}},	//   lams, रेषि, rtão, ómar_,
   {{0xa2aa0084,0xb7bb0132,0xb87b01ef,0x5bc30037}},	//   _जुल्, stão, ccín, _تقول,
   {{0x7d008f64,0xdb0801ef,0x27e90065,0x1dca012f}},	//   nams, dodé, _ttan_, ागित,
   {{0x27e90343,0x00000000,0x00000000,0x00000000}},	// [9d50] _utan_, --, --, --,
   {{0x97151ac5,0xa49b0211,0x6b9a02b1,0x00000000}},	//   _эмоц, _leòg, nntg, --,
   {{0x7d008f65,0x7d1b027d,0x28c70d4e,0x257c8f66}},	//   kams, ygus, रेरि, _síle_,
   {{0xf5590082,0x7d003c54,0x257c00d5,0x36340919}},	//   _الحب_, jams, _píle_, _کریس,
   {{0xdee5386a,0xdb010079,0x00000000,0x00000000}},	//   поли, holá, --, --,
   {{0xdb012d87,0x3fab0274,0xd7ab073f,0x644f081b}},	//   kolá, шњем_, चकिच, _irci,
   {{0x7d00016e,0x798d0067,0x00000000,0x00000000}},	//   fams, _omaw, --, --,
   {{0x7c3b3ac5,0x7d1b8f67,0x7d00474b,0x00000000}},	//   twur, ugus, gams, --,
   {{0x7d1b8f68,0xdbd600ab,0xd0118f69,0xa49b009e}},	//   rgus, jään, _سلا_, _deòg,
   {{0x547c0122,0x798d0273,0x3cff006d,0x7c3b7031}},	//   יטחו, _amaw, sauv_, rwur,
   {{0x2b1c009a,0xd9466771,0x89aa411e,0xdb0100b5}},	//   _मारु_, пени, йков_, golá,
   {{0xac19342d,0xdb0a004f,0xa49b01f7,0x00000000}},	//   _году_, _bhfó, _geòg, --,
   {{0x23bd0e6f,0x5ed00033,0xf2b800b8,0x02b801c0}},	//   ्गाद, _স্পে, _अर्घ, _अर्न,
   {{0xc3110033,0x752f008c,0x798d0103,0x00000000}},	//   স্তি_, _abcz, _emaw, --,
   {{0xfbd00118,0xdb012b82,0xa49b01a6,0x2d7f0067}},	//   _شته_, colá, _leòd, ałeś_,
   {{0x06ab00c8,0x6372054e,0x18a60823,0xa2cc012f}},	//   _গৃহি, _tænk, _найм, _थृष्,
   {{0xd5af21a0,0x29028f6a,0x9f5f0176,0xb87b0015}},	// [9d60] افق_, maka_, _avuí_, ncíl,
   {{0x29028f6b,0x04fc0033,0x6e2d0035,0x00000000}},	//   laka_, ইলের_, łaby, --,
   {{0x7dc505c9,0x11d600d1,0x69d68f6c,0x7d0001a2}},	//   mósf, ستاد, _kiye, yams,
   {{0x29028f6d,0xe5a607b0,0xa3e402e4,0x6a9a0070}},	//   naka_, _хими, _पंप_, זשענ,
   {{0x69d60d0d,0x26180243,0x7bc300ac,0xdb0100b5}},	//   _miye, बूरी_, _ohnu, zolá,
   {{0x29023069,0x69d60afe,0x00000000,0x00000000}},	//   haka_, _liye, --, --,
   {{0x290224a8,0x7d001eb0,0x6fb600b5,0x69c401b7}},	//   kaka_, tams, _ہمرا, _ohie,
   {{0x29028f6e,0xdb01024e,0x69c40019,0x7bc35ee7}},	//   jaka_, volá, _nhie, _ahnu,
   {{0x290255a0,0x321a053d,0xa49b009e,0xd6c40033}},	//   daka_, lupy_, _geòd, ্ডিয,
   {{0xd9b73779,0xfc2f0bdf,0x7d008f6f,0x7bc31a07}},	//   ृष्ट, احي_, sams, _chnu,
   {{0x34b900b4,0x29020054,0x69d604a9,0xdb180187}},	//   _आर्द, faka_, _biye, _chvá,
   {{0x644a0029,0x69c40e12,0xe7e10066,0x0dca002d}},	//   āfij, _chie, _गंदा_, _улей_,
   {{0x69d68f70,0x69c40034,0x6c3403c5,0xdb0100b5}},	//   _diye, _dhie, _آفتا, solá,
   {{0x321a12ad,0x69d60159,0xdb018f71,0x7bc30211}},	//   kupy_, _eiye, polá, _ghnu,
   {{0x29028f72,0x644f1942,0xb8d40387,0x69c40069}},	//   baka_, _srci, _जु_, _fhie,
   {{0x29028f73,0xdbd60086,0x20068f74,0x79a400d8}},	//   caka_, sään, ksoi_, _прые,
   {{0x245800c3,0x24f8010b,0x00000000,0x00000000}},	// [9d70] пать_, янты_, --, --,
   {{0xa87c0122,0xd25b01c8,0x64430067,0xf2c703e6}},	//   _לאחר, йце_, łnio, псен,
   {{0x32070332,0x69d68f75,0x799d0110,0x00000000}},	//   ény_, _yiye, onsw, --,
   {{0x63730723,0x65767380,0x644f0305,0x637b00f6}},	//   _sını, ckyh, _trci, _dîna,
   {{0xb4d90378,0x644f0334,0x3dde009e,0xd009002d}},	//   ाशी_, _urci, _autw_, целе_,
   {{0x29021aa5,0x00000000,0x00000000,0x00000000}},	//   zaka_, --, --, --,
   {{0x290219c7,0xc33202b5,0x6da52c86,0x644d8f76}},	//   yaka_, _שול_, мика, lvai,
   {{0x44298f77,0xd6580122,0x290201ed,0x7bc30211}},	//   ota_, ליות_, xaka_, _shnu,
   {{0x29024553,0x60db8f78,0x644d1b49,0x69c4001e}},	//   vaka_, _igum, nvai, _rhie,
   {{0x4429052a,0x29021548,0x69d68f79,0x69c43080}},	//   ita_, waka_, _siye, _shie,
   {{0x290228f7,0x44298f7a,0x628554fd,0x69d68f7b}},	//   taka_, hta_, nzho, _piye,
   {{0x442903c1,0x00000000,0x00000000,0x00000000}},	//   kta_, --, --, --,
   {{0x290204be,0x44298f7c,0x3b09189d,0x60db002f}},	//   raka_, jta_, _дело_, _mgum,
   {{0x6f038b12,0x6d490291,0x44298f7d,0x7c298f7e}},	//   nanc, ldea, dta_, mter,
   {{0x29028f7f,0x7c298f80,0x69d6010d,0x2fdf011e}},	//   paka_, lter, _tiye, _luug_,
   {{0x6f038f81,0x60db8f82,0x6d498f83,0x442908d7}},	//   hanc, _ngum, ndea, fta_,
   {{0x6d49003b,0x6f038f84,0x65640034,0xdce90009}},	// [9d80] idea, kanc, rjih, nheđ,
   {{0x7c293523,0x6d498f85,0x321a0097,0x60db5a13}},	//   iter, hdea, tupy_, _agum,
   {{0x7c293342,0x44298f86,0x673c17fb,0xa6ca03c5}},	//   hter, ata_, merj, _گوگل_,
   {{0x44295a49,0x27e00d36,0x661c0a0f,0x673c8f87}},	//   bta_, _kuin_, murk, lerj,
   {{0x442925ac,0x27e01010,0x661c20fb,0xc48301c8}},	//   cta_, _juin_, lurk, _аляк,
   {{0x29008f88,0x673c8f89,0x7c2903e4,0x25ad15d7}},	//   _leia_, nerj, dter, čele_,
   {{0x7c296822,0xda0906d9,0x661c8ec3,0x20060036}},	//   eter, _विगत_, nurk, ssoi_,
   {{0x7c298f8a,0x27ed00af,0x2fc501ed,0x673c8f8b}},	//   fter, ţeni_, _ehlg_, herj,
   {{0x6f036c64,0x673c8f8c,0x7c298f8d,0x2b478f8e}},	//   banc, kerj, gter, _banc_,
   {{0x6f0315f9,0x2d98006c,0x661c8f8f,0x2b470036}},	//   canc, őre_, kurk, _canc_,
   {{0x44298f90,0x673c8f91,0x6d49008c,0xaa5811c3}},	//   zta_, derj, bdea, чину_,
   {{0x44298f92,0x661c7a42,0x6d60024e,0x27e08f93}},	//   yta_, durk, ávač, _buin_,
   {{0x442920fd,0xdb080b4c,0x29008f94,0x27e00284}},	//   xta_, lodí, _deia_, _cuin_,
   {{0x27e08f95,0x673c8f96,0xe8e00023,0x44291757}},	//   _duin_, gerj, _muội_, vta_,
   {{0x67d41663,0x79a712b3,0x661c8f97,0x29008f98}},	//   тору, _орие, gurk, _feia_,
   {{0xb4d95756,0x644d8a5a,0xb55800af,0x257c2d09}},	//   ाशे_, tvai, мисф_, _píla_,
   {{0x44298f99,0x7bd88f9a,0x6f038f9b,0x644d00f7}},	// [9d90] uta_, _kivu, yanc, uvai,
   {{0x752d8f9c,0x661c7c3c,0x644d8f9d,0x394964d3}},	//   sfaz, burk, rvai, _haas_,
   {{0x394942f9,0x6f038f9e,0x7c298f9f,0x6d4901a2}},	//   _kaas_, vanc, zter, ydea,
   {{0x6f038fa0,0x76450232,0x7c298fa1,0xf9d90070}},	//   wanc, _ishy, yter, פֿעל,
   {{0x39498fa2,0x4429007a,0x7c294f93,0xd47902b5}},	//   _maas_, qta_, xter, _זאָל,
   {{0x3949053e,0x7052250f,0xa3e40026,0x63720093}},	//   _laas_, انوا, _पंत_, _bænu,
   {{0x6d49002d,0xa49b0211,0x2b47009e,0x59af00be}},	//   tdea, _feòc, _ranc_, घवार,
   {{0x7c290a1f,0x6f0302e1,0x1c458fa3,0x39495b6a}},	//   tter, sanc, еним, _naas_,
   {{0x6d498fa4,0x7c298fa5,0xfc4801a5,0x7bd80010}},	//   rdea, uter, _cử_, _bivu,
   {{0x7c298fa6,0x6d4900f1,0x61e90121,0x29000044}},	//   rter, sdea, _čelj, _seia_,
   {{0x7bd88fa7,0x673c8fa8,0x39498fa9,0xc33202b5}},	//   _divu, verj, _baas_, נוט_,
   {{0x6d59001e,0x39490069,0x127a0070,0x27e00afc}},	//   _unwa, _caas_, פארע, _puin_,
   {{0x673c8faa,0x27e012c3,0xa3db0299,0x2900377e}},	//   terj, _quin_, _ढंग_, _veia_,
   {{0xfaa53b4d,0x7bd8030d,0xfbc52dbe,0x00000000}},	//   _пало, _givu, _ябло, --,
   {{0x29000279,0x6f018fab,0xcb1200a5,0x8f9a00a5}},	//   _teia_, _melc, _עלה_, לישי,
   {{0x673c8fac,0x27e002e6,0x2d9f00f7,0x3d0d0035}},	//   serj, _tuin_, nnue_, _ियों_,
   {{0x673c0484,0xfc480028,0x66e6263b,0x661c8fad}},	// [9da0] perj, _xử_, _попа, surk,
   {{0x201d00d7,0x317f0118,0xe3b703e5,0x74130037}},	//   duwi_, _aluz_, ебу_, اولا,
   {{0x317f8fae,0x00000000,0x00000000,0x00000000}},	//   _bluz_, --, --, --,
   {{0x10a60036,0x28c70eff,0xa87a016b,0x072000ab}},	//   ниен, रेकि, ּאַר, _बाँव_,
   {{0x26c700b8,0x26180026,0x201d010d,0x00000000}},	//   _únor_, बंकी_, guwi_, --,
   {{0xdfcf22c4,0x6f01046a,0x64468faf,0x25a02018}},	//   مين_, _celc, _iski, lnil_,
   {{0xfc4800e8,0x53a34bba,0x03a32846,0x7bd801d5}},	//   _sử_, _сарб, _сиро, _rivu,
   {{0x7bd803ad,0x25a08fb0,0x6f010051,0x5d542503}},	//   _sivu, nnil_, _eelc, ткит,
   {{0x64460009,0x39498fb1,0x10a322e3,0x6f018fb2}},	//   _jski, _raas_, _битн, _felc,
   {{0xf8bf00f7,0x3dc60345,0x6f010a21,0x00000000}},	//   ngée_, _whow_, _gelc, --,
   {{0xc3335c8e,0x7bd88fb3,0x394900b9,0x3dc60118}},	//   אות_, _vivu, _paas_, _thow_,
   {{0xfc4800e8,0x4c863f27,0xbfa50023,0x25a08fb4}},	//   _tử_, _плев, hiệ, jnil_,
   {{0xec1300bc,0xb90900b1,0xdb080279,0x64460009}},	//   _موند, _बल_, godã, _nski,
   {{0x39490d35,0x257c00fe,0x00000000,0x00000000}},	//   _waas_, _bílo_, --, --,
   {{0x39498fb5,0xb4d9021a,0x64462199,0x63720a8a}},	//   _taas_, ाश्_, _aski, _læns,
   {{0xd5b88fb6,0x257c0355,0x25a008b7,0x95d85084}},	//   есу_, _dílo_, gnil_, едст_,
   {{0x68ed06d0,0x63720a8a,0x00000000,0x00000000}},	// [9db0] _ifad, _næns, --, --,
   {{0x889c0122,0x2c18018d,0x317f03c9,0x316d02d7}},	//   _מבחי, _दिनं_, _sluz_, _soez_,
   {{0x64468fb7,0x02a70036,0x22590037,0x764501d5}},	//   _eski, храм, بلاد_, _ushy,
   {{0x68ed0069,0x00000000,0x00000000,0x00000000}},	//   _jfad, --, --, --,
   {{0x2d848fb8,0x656f00f1,0x201d0159,0x68ed08c7}},	//   dhme_, _ioch, uuwi_, _mfad,
   {{0x7bdf1010,0x656f02bf,0x3b0501c2,0x248910b9}},	//   _équi, _hoch, xalq_, mzam_,
   {{0x63720093,0x24897371,0xb87b00b5,0x61dc0067}},	//   _vænt, lzam_, gbíz, यदृष,
   {{0x6f018fb9,0x7dd500d8,0x656f3c5f,0x2d8402d7}},	//   _welc, _išsk, _joch, ghme_,
   {{0x656f7ac2,0x7d020043,0x70dd021a,0x00000000}},	//   _moch, _deos, यशील, --,
   {{0x656f0094,0x69cf01e8,0x672008b6,0x2489011c}},	//   _loch, emce, _बाइक_, izam_,
   {{0xfaa52fb8,0x6a8602e1,0x7d0257f4,0x371b00ab}},	//   тано, _réfé, _feos, _बाड़ी_,
   {{0x656f3875,0x2d9f8fba,0xc7a900a5,0xdc530647}},	//   _noch, qnue_, _וב_, _مرتک,
   {{0x8ccd0035,0xa9a30036,0x6d4b009e,0xec6e1346}},	//   देशो, рияд, _iaga, _тп_,
   {{0x6d4b570b,0x24891486,0x1ae21d30,0x7dc501ef}},	//   _haga, dzam_, _кошм, bósc,
   {{0x6d4b8fbb,0x656f8fbc,0xa2d301c0,0x7d020345}},	//   _kaga, _boch, भेम्, _yeos,
   {{0x656f8fbd,0x6d4b8fbe,0x44391510,0x64460009}},	//   _coch, _jaga, _bps_, _pski,
   {{0x6d4b8fbf,0x442b0183,0x291208c7,0x25a502d7}},	// [9dc0] _maga, _cqc_, _idya_, élla_,
   {{0x6d4b8fc0,0x25ad1851,0x656f004f,0x25a05584}},	//   _laga, čela_, _eoch, snil_,
   {{0xf8bf00f7,0x656f8fc1,0x6372008d,0x00000000}},	//   rgée_, _foch, _sæns, --,
   {{0x6d4b2326,0x44396be1,0x656f8fc2,0x64460009}},	//   _naga, _fps_, _goch, _tski,
   {{0x644600cd,0x7d0200be,0x29120118,0x24890067}},	//   _uski, _reos, _mdya_, czam_,
   {{0x44201972,0x7d021c12,0x6d4b8fc3,0x38bd0037}},	//   mui_, _seos, _aaga, lárú_,
   {{0x44208e6a,0x6d4b8fc4,0x26dc0076,0x9e03010b}},	//   lui_, _baga, _úvod_, ачыл,
   {{0x75241d6a,0xdd97005f,0x44208fc5,0x656f554b}},	//   ngiz, кшы_, oui_, _xoch,
   {{0x44208fc6,0x61e9003a,0x98be00b8,0xa49b01da}},	//   nui_, _čeli, ětě_, _leòn,
   {{0x2d84071f,0x6d4b009c,0x4420009e,0x29120103}},	//   shme_, _eaga, iui_, _adya_,
   {{0x44200f1a,0x3f9b0248,0x33770122,0x6d4b8fc7}},	//   hui_, èque_, דעים_, _faga,
   {{0x6d4b8fc8,0x44204e64,0x7dc525ec,0x00000000}},	//   _gaga, kui_, rósc, --,
   {{0x656f7d45,0x442045b2,0xdd8f2a2f,0x6d408fc9}},	//   _roch, jui_, _بون_, mema,
   {{0x6d405546,0x44208fca,0x656f6d9b,0x6d4b1c90}},	//   lema, dui_, _soch, _zaga,
   {{0x35e402ce,0x6d4b0198,0xda6f0133,0x7c2051e7}},	//   ицтв, _yaga, _тя_, lumr,
   {{0x6d4019a6,0x44200409,0x68ed002f,0xa49b00f1}},	//   nema, fui_, _ufad, _deòn,
   {{0x44208fcb,0x5455342d,0x656f8fcc,0xb87b0132}},	// [9dd0] gui_, ыват, _voch, ecív,
   {{0x6d408fcd,0x656f02bf,0x1b1400c8,0x24898fce}},	//   hema, _woch, ত্রে_, rzam_,
   {{0x6d4003c8,0x656f8fcf,0x2489004e,0xb887008d}},	//   kema, _toch, szam_, _fríð,
   {{0x44200043,0x6d408fd0,0x44398fd1,0xf67a02b5}},	//   bui_, jema, _tps_, _נארמ,
   {{0x6d4b8fd2,0x94870043,0x44208fd3,0x6d408fd4}},	//   _raga, _рынд, cui_, dema,
   {{0x7dd501c8,0xdb0100a0,0x00000000,0x00000000}},	//   _išsi, solú, --, --,
   {{0x6d4b8fd5,0x4394027a,0x00000000,0x00000000}},	//   _paga, _тарс, --, --,
   {{0x2ca000d5,0x00000000,0x00000000,0x00000000}},	//   _žida_, --, --, --,
   {{0x7bca02aa,0x6d4b8fd6,0xc6bf00c8,0x00000000}},	//   _bhfu, _vaga, _আলোচ, --,
   {{0x9ee9004f,0x6d4b2144,0x20090029,0x3c2b0a8a}},	//   _أفضل_, _waga, šais_, røv_,
   {{0x6d4b8fd7,0x6d408fd8,0x7dc7006c,0xadf50945}},	//   _taga, bema, _műsz, _спеш,
   {{0xdb085b59,0x29047846,0x6d4b0409,0x31ae00d5}},	//   rodá, úma_, _uaga, fýzy_,
   {{0xd910006c,0xdd99007e,0x7c643cf2,0xdb0800b5}},	//   میں_, miň_, _ناول, sodá,
   {{0x3ced02c6,0x44208fd9,0x7d098fda,0xf1c70097}},	//   lcev_, vui_, laes, _šály_,
   {{0x69c4004e,0x98a4037a,0xdbd100ab,0xf8bf00a2}},	//   रतदी, ımı_, _müüj, ffés_,
   {{0x44208fdb,0x7d090a78,0x3ced02c6,0x00000000}},	//   tui_, naes, ncev_, --,
   {{0x2618007c,0x79840054,0x39428fdc,0x00000000}},	// [9de0] बूजी_, _iliw, meks_, --,
   {{0x39428fdd,0x44208fde,0x6d408fdf,0x7d090160}},	//   leks_, rui_, zema, haes,
   {{0xeb960779,0x44208fe0,0x6b7a0070,0x6d400b65}},	//   נדער_, sui_, ערענ, yema,
   {{0x673b0254,0x39421b43,0x0f1c0026,0x6d400065}},	//   đuje, neks_, नल्स_, xema,
   {{0x44208fe1,0xe3b100b5,0x98b200d5,0x7984034d}},	//   qui_, صرے_, _obyč_, _mliw,
   {{0x3942007c,0xa2e30e05,0x6d408fe2,0x798400e9}},	//   heks_, _горд, wema, _lliw,
   {{0x79848fe3,0x63830274,0x39421cc6,0x63ab00fd}},	//   _oliw, _угра, keks_, égne,
   {{0xdd901ef9,0x644d00ab,0x6b830118,0x7bca0031}},	//   توب_, _üliõ, _alng, _shfu,
   {{0x6d408fe4,0xd1b300bf,0x51b900af,0xa49b009e}},	//   rema, _اینک, _рыря_, _neòl,
   {{0x6d870083,0x6d408fe5,0xff240332,0x79848fe6}},	//   _añad, sema, _خبری, _aliw,
   {{0xee290037,0xa49b009e,0x6d40018d,0xfca900f8}},	//   _لأنه_, _aeòl, pema, _یاهو_,
   {{0x78a20009,0x394200be,0x984b010b,0x99670369}},	//   _žova, geks_, няга_, утол,
   {{0xe81c0084,0xa49b00f1,0xa3d70066,0xa3e44d99}},	//   भंगा_, _ceòl, ागम_, _पूल_,
   {{0xead41853,0x394d0409,0x60dd00a0,0xdceb0069}},	//   _коль, žes_, _úsme, _imgġ,
   {{0x5b7b02b5,0x6b9a8fe7,0x387f0207,0x00000000}},	//   _ארגא, mitg, šur_, --,
   {{0x25ad0496,0x79840035,0xa49b0284,0x6b9a0176}},	//   čelo_, _gliw, _feòl, litg,
   {{0x290b4bf4,0x33f4004f,0xa49b8fe8,0x68fd0c6f}},	// [9df0] maca_, مسلس, _geòl, mbsd,
   {{0x290b8fe9,0x69df0031,0x98b900ea,0x79960067}},	//   laca_, _hiqe, cesā_, _zmyw,
   {{0x3ebe0d0f,0xdb080093,0xd6db01e0,0x7dd50409}},	//   _nytt_, lldó, _яти_, _išsv,
   {{0x290b8fea,0x313501e0,0x637b0160,0x2b4e00ee}},	//   naca_, редр, _mîni, _lafc_,
   {{0x3ced008b,0x69df0031,0x7d091eb8,0x00000000}},	//   vcev_, _miqe, vaes, --,
   {{0x290b14ae,0x88c70083,0x69df0031,0x656d12ca}},	//   haca_, _এলাক, _liqe, ljah,
   {{0xd5ae00f5,0x27780122,0x290b103c,0xa49b01da}},	//   _رہے_, רגון_, kaca_, _meòm,
   {{0x3f870069,0x290b1278,0xed5912a2,0x463c0070}},	//   shnu_, jaca_, тои_, געהע,
   {{0xe7e10953,0x0d8200ef,0x290b435f,0xdd8e0037}},	//   _गंगा_, ільн, daca_, بوي_,
   {{0x30840037,0x60c90371,0x79843c83,0x2d9a75e3}},	//   _الكف, _izem, _sliw, éper_,
   {{0x39420006,0xa49b01a6,0x69cd009e,0x290b8feb}},	//   teks_, _seòl, _bhae, faca_,
   {{0x290b47ed,0x69cd001e,0xac9601cb,0x7f4301f7}},	//   gaca_, _chae, انیا_, lenq,
   {{0x7dc50a20,0x6b6500aa,0x6d7a00a5,0x656d6fe7}},	//   lóso, _вкла, _שאנח, djah,
   {{0x87b96b07,0x39420ccf,0x7f430392,0x60c9034d}},	//   густ_, seks_, nenq, _mzem,
   {{0x290b2ed3,0x63b70097,0x7f430176,0x00000000}},	//   baca_, doxn, ienq, --,
   {{0x290b25bf,0x69cd004f,0x79840054,0xdb180107}},	//   caca_, _ghae, _uliw, _akvè,
   {{0xb46618e2,0x3f8500c3,0x19bb00a5,0xe3ba0210}},	// [9e00] шкал, _ollu_, _במקב, вба_,
   {{0x7bc102c7,0x425603f5,0x69df00a2,0x6e230065}},	//   nllu, итет, _éper, kunb,
   {{0x00e60b00,0x171b02b5,0x7bc18fec,0x60c98fed}},	//   ажен, _בויע, illu, _azem,
   {{0x31600300,0x3f8500e9,0x7ae30065,0x00000000}},	//   ñiz_, _allu_, _lgnt, --,
   {{0xb4e20026,0x224a012f,0x60c90035,0x2f1851fe}},	//   दशी_, _wsbk_, _czem, голь_,
   {{0x60c900ea,0x290b273b,0x6e23055c,0x8fa3002d}},	//   _dzem, zaca_, funb, оаче,
   {{0x1c180006,0x44328fee,0xe8e00019,0x60c98fef}},	//   _दिहल_, lty_, _muối_, _ezem,
   {{0xe81700a1,0x290b0020,0xad66004f,0x68e400f8}},	//   _तिला_, xaca_, شابه, _ngid,
   {{0x290b0a78,0x4432107d,0x61e0009e,0x69cd05a4}},	//   vaca_, nty_, _iiml, _rhae,
   {{0x44328ff0,0x61e08ff1,0x69cd0069,0xe8e000e2}},	//   ity_, _himl, _shae, _nuối_,
   {{0x3f9c6289,0x61e006d3,0xa3d70567,0x44328ff2}},	//   mivu_, _kiml, ागत_, hty_,
   {{0x443215b3,0x7bc10090,0x3f9c8ff3,0x61e08ff4}},	//   kty_, allu, livu_, _jiml,
   {{0x290b2524,0xdbdc00b8,0x63bc03c9,0x63a58ff5}},	//   raca_, lšíh, _okrn, ynhn,
   {{0xe8e00028,0x61e08ff6,0x290b8d04,0x68e48ff7}},	//   _cuối_, _liml, saca_, _egid,
   {{0x44328ff8,0x290b5f44,0xada501ba,0x656d0e0e}},	//   ety_, paca_, skúš, tjah,
   {{0x3f9c18b0,0x4432109e,0x61e00069,0x6f0800fe}},	//   hivu_, fty_, _niml, _ledc,
   {{0x44320298,0x799d8ff9,0x656d8ffa,0x3f9c1c00}},	// [9e10] gty_, misw, rjah, kivu_,
   {{0x799d7b65,0x3f9c1ce9,0x656d48b0,0x9f44000d}},	//   lisw, jivu_, sjah, _fumé_,
   {{0x60c900f5,0x27e98ffb,0x44328ffc,0x61e902c4}},	//   _szem, _huan_, aty_, _čels,
   {{0x799d0260,0x27e910cd,0xdceb035f,0x61ec00d5}},	//   nisw, _kuan_, _imgħ, _žolí,
   {{0x27e90083,0x7bc18ffd,0x7f4301ae,0x3e47006c}},	//   _juan_, yllu, tenq, _sőt_,
   {{0x2d868ffe,0x799d0afe,0x60c908b7,0x00000000}},	//   _aloe_, hisw, _vzem, --,
   {{0x27e98fff,0x6fcd016f,0x61e0008d,0xceb400a8}},	//   _luan_, júce, _fiml, şən_,
   {{0x5187005f,0x6fcd9000,0x6e2306a2,0x7f439001}},	//   _туга, dúce, runb, senq,
   {{0x60c09002,0x60c99003,0x6e2301a3,0xec790421}},	//   _gymm, _uzem, sunb, упп_,
   {{0x5f740082,0xdce90207,0x3f9c0207,0x00000000}},	//   _والر, mječ, civu_, --,
   {{0xe9da0021,0x26c1006d,0xdce919cd,0xe7e10035}},	//   лко_, _nyho_, lječ, _गंजा_,
   {{0x44329004,0x27e96e4f,0xe8e00023,0x186a2374}},	//   yty_, _buan_, _suối_, гами_,
   {{0x44329005,0x27e99006,0xa3d70380,0xdce90506}},	//   xty_, _cuan_, ागा_, nječ,
   {{0x27e99007,0x291e027d,0xcc5600a5,0xa803002a}},	//   _duan_, şta_, _לבני_, íñas,
   {{0xc9f5036b,0xfaa29008,0x6456006f,0x27e9009e}},	//   _استع, _нашо, wvyi, _euan_,
   {{0x3f9c0528,0x44329009,0xb6a309c2,0x63bc900a}},	//   zivu_, tty_, числ, _skrn,
   {{0x61e08953,0xe8f7005f,0x27e91e77,0xd4674ae8}},	// [9e20] _riml, _улы_, _guan_, бите_,
   {{0x4432900b,0x212d005d,0xdb011e15,0xaace00dc}},	//   rty_, _aceh_, moló, हेकक,
   {{0x4432107d,0x06d60083,0x61e000e7,0xdb9a0070}},	//   sty_, _ত্রি, _piml, נסער,
   {{0x443210a3,0x3aba0070,0x64a6900c,0x463b016b}},	//   pty_, אמענ, _гама, _געטע,
   {{0xdb01900d,0xb87b900e,0x3a250c7c,0x61e0900f}},	//   noló, ncíp, hulp_, _viml,
   {{0xe8202088,0x44209010,0x00000000,0x00000000}},	//   _बिना_, mri_, --, --,
   {{0xa2480164,0x5286004f,0x3f9c0273,0x61e09011}},	//   _خیال_, _الأك, rivu_, _timl,
   {{0x44209012,0x3f9c03ad,0xdb019013,0xafe600af}},	//   ori_, sivu_, koló, _гоал,
   {{0x40960079,0x00000000,0x00000000,0x00000000}},	//   _الذر, --, --, --,
   {{0x44209014,0x09b300e7,0x27e99015,0x799d00e9}},	//   iri_, ीत्य, _ruan_, wisw,
   {{0x44202a48,0x7dea0035,0xed0600d1,0x25ed0067}},	//   hri_, _męsk, _هواپ, _आंधी_,
   {{0x27e99016,0x2d86012f,0x8afc0035,0x00000000}},	//   _puan_, _uloe_, ejęt, --,
   {{0x27e99017,0x39520122,0x8c430112,0x00000000}},	//   _quan_, _days_, _неце, --,
   {{0x799d272d,0x27e90031,0x00000000,0x00000000}},	//   sisw, _vuan_, --, --,
   {{0x44209018,0x7d25008d,0x637b0160,0xaa9400af}},	//   eri_, _útsý, _mînt, _фийч,
   {{0x27e99019,0x3952901a,0xe9a411b9,0xa3e40907}},	//   _tuan_, _gays_, _најп, _पंख_,
   {{0x4420901b,0xdb01901c,0xe8200006,0x5399021f}},	// [9e30] gri_, coló, _बिया_, авая_,
   {{0xdce90c0a,0xdceb0139,0xdb0172c2,0x00000000}},	//   vječ, _kogă, lolò, --,
   {{0x26c7016f,0xa49b01da,0x073600a5,0x00000000}},	//   _áno_, _meòi, _ואתם_, --,
   {{0x4420901d,0x59c90d1f,0xdce90c21,0xa49b00f1}},	//   bri_, रतिर, tječ, _leòi,
   {{0xa0694bba,0xa3d51159,0x25a97e24,0x77770024}},	//   рала_, _момч, mnal_, _koxx,
   {{0x66fb0d53,0xdce9003a,0x644f003d,0xfe7000d1}},	//   ्रिक_, rječ, _isci, کده_,
   {{0xdce910d1,0x3cdb0302,0x7df10211,0x877c0070}},	//   sječ, खेने_, _bāsa, ראוי,
   {{0x25a9901e,0x4c8502ce,0x5bb3143a,0xee3601c8}},	//   nnal_, жлив, ुत्व, іны_,
   {{0xa49b01da,0xdb010392,0x3952901f,0x00000000}},	//   _beòi, dolò, _rays_, --,
   {{0x39529020,0xeb99210e,0x25a90097,0xdceb0395}},	//   _says_, рио_, hnal_, _bogă,
   {{0x39521010,0x89aa0086,0x442001ba,0x753d0035}},	//   _pays_, иков_, zri_, _obsz,
   {{0x44209021,0xdb019022,0x645d17a4,0x68e900ac}},	//   yri_, toló, _orsi, žedn,
   {{0xcb69021d,0x7777007a,0xe8e00023,0x442000a8}},	//   _вале_, _boxx, _ruồi_, xri_,
   {{0x44209023,0xdb019024,0xc31f0083,0x5ed00033}},	//   vri_, roló, ন্তি_, _স্টে,
   {{0x645d9025,0xb87b3207,0x644f9026,0xdb019027}},	//   _arsi, scíp, _asci, soló,
   {{0x44209028,0x25a9593a,0x18a65e0c,0xdb019029}},	//   tri_, gnal_, _майм, poló,
   {{0x4420902a,0x7d0b0332,0x3776002d,0x00000000}},	// [9e40] uri_, _megs, _дынс, --,
   {{0x4420902b,0x2bcf0c67,0x7d0b3daf,0x645d023a}},	//   rri_, _सीमा, _legs, _drsi,
   {{0x644f8405,0x4420902c,0x645d190c,0x2b80009e}},	//   _esci, sri_, _ersi, _dòch_,
   {{0x4420902d,0x637b00af,0x257c00ee,0xdceb0409}},	//   pri_, _sînt, _pílu_, _ilgė,
   {{0x69c60065,0x637b0160,0x00000000,0x00000000}},	//   ilke, _pînt, --, --,
   {{0xdfcf004f,0xceb40095,0x2b800359,0x637b0160}},	//   نين_, şəm_, _gòch_, _dîns,
   {{0xed5000b5,0xa3d70d1f,0xa49b0211,0x637b0139}},	//   ٹھا_, ागर_, _reòi, _vînt,
   {{0x25a0902e,0xa49b01da,0xc31f0033,0x00000000}},	//   niil_, _seòi, ন্দি_, --,
   {{0x7d0b902f,0x8c4303e6,0x9b6a1a1c,0xb143093e}},	//   _degs, дење, ашна_, _інфл,
   {{0x25ad1851,0x25a9571a,0x23781505,0x69c60088}},	//   čeli_, znal_, _jorj_, elke,
   {{0x19590bbc,0xa2a005e7,0x4ad502b4,0x00000000}},	//   баны_, _गेम्, डेलव, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8f302cb,0x2480006f,0xd8cb002d,0xf99f0358}},	//   _वर_, jyim_, рынд_, riè_,
   {{0x68f600e9,0x7d0b0051,0x6566055c,0x5fca01c0}},	//   _efyd, _zegs, _ankh, ितिल,
   {{0x693301c0,0xdb23008a,0x68f600e9,0x25a000ab}},	//   _přeč, _þrát, _ffyd, fiil_,
   {{0x645d9030,0x48150923,0x00000000,0x00000000}},	//   _prsi, _емис, --, --,
   {{0x25a93322,0xe8e001a5,0x6fca0099,0x777702d7}},	// [9e50] rnal_, _buổi_, ितां, _toxx,
   {{0xd25b2171,0xed59391a,0x65660223,0x645d9031}},	//   ице_, može_, _enkh, _vrsi,
   {{0x25a000ab,0x765e0118,0xed5900f4,0x6fc40392}},	//   biil_, _grpy, lože_, còci,
   {{0x2b8002e9,0x6d870065,0x00000000,0x00000000}},	//   _wòch_, _añan, --, --,
   {{0x644f9032,0x7d0b0173,0x24920035,0x61fe1ead}},	//   _usci, _regs, czym_, appl,
   {{0x4429303d,0x752d9033,0xd3430a86,0x644d001e}},	//   mua_, lgaz, _تفسی, mwai,
   {{0x44299034,0x29020035,0x69c60044,0x644d016e}},	//   lua_, ybka_, ylke, lwai,
   {{0x752d77e5,0x3cf7004e,0xed599035,0x44299036}},	//   ngaz, ीरें_, kože_, oua_,
   {{0x644d016e,0x7dc501ef,0x7d0b4b19,0x8c4500af}},	//   nwai, nósi, _vegs, чепе,
   {{0x2d8d32c6,0x5f9500f8,0x7d0b1090,0x291b0176}},	//   shee_, _علائ, _wegs, _adqa_,
   {{0x44290d4b,0x644d4c7c,0x00000000,0x00000000}},	//   hua_, hwai, --, --,
   {{0x44299037,0x24801719,0x66150035,0x2d84008c}},	//   kua_, yyim_, dszk, ckme_,
   {{0x44299038,0xeb8e0043,0x2d9d0010,0x213f00f8}},	//   jua_, _зи_, _imwe_, _mbuh_,
   {{0x44299039,0x752d0382,0x7c29112c,0x644d001e}},	//   dua_, egaz, muer, dwai,
   {{0x7c298a22,0xdb1a0031,0x1c21021a,0x00000000}},	//   luer, zotë, _मिडल_, --,
   {{0x44290054,0x2bcf0cea,0xe5a600af,0xed591321}},	//   fua_, _सीता, чиби, bože_,
   {{0x4429903a,0x7c29903b,0x25a00fff,0x2d9d0273}},	// [9e60] gua_, nuer, riil_, _mmwe_,
   {{0x25a04a1c,0x213f01cb,0x00000000,0x00000000}},	//   siil_, _abuh_, --, --,
   {{0x24860928,0xb77b0122,0x2492004e,0x4429002d}},	//   šom_, _האיש, szym_, aua_,
   {{0x7c29903c,0x4429903d,0x7dc5002a,0x3cf70067}},	//   kuer, bua_, bósi, ीरों_,
   {{0xe8e00028,0x213f0159,0xf9930070,0x7dc50042}},	//   _tuổi_, _dbuh_, ערד_, cósi,
   {{0xfbc705bc,0x7c293b74,0x9e06021d,0x2d9d01d5}},	//   _ست_, duer, пчил, _amwe_,
   {{0x28de0026,0x2d9d008c,0x67eb035f,0x00000000}},	//   _नृसि, _bmwe_, _iżje, --,
   {{0x63be042a,0x7c290033,0xdb1a300b,0x321800a2}},	//   lopn, fuer, moté, _ivry_,
   {{0x7c298ebc,0x2c1c0099,0x8e2001e0,0x00000000}},	//   guer, _मिळू_, рiв_, --,
   {{0x5ede00c8,0x61ee903e,0x15ec0084,0x39400088}},	//   নুষে, _kubl, झदार_, _abis_,
   {{0x4429903f,0xa3e40992,0x61ee9040,0x3940009e}},	//   zua_, _पूछ_, _jubl, _bbis_,
   {{0xed590076,0x7c290532,0x63be05d3,0xa3d31ea9}},	//   tože_, buer, hopn, _हीन_,
   {{0x7c290083,0x23be00b4,0xc86408ae,0x61ee8519}},	//   cuer, ्ताद, нтри, _lubl,
   {{0x61ee02e1,0x44299041,0x38660009,0x39400069}},	//   _oubl, vua_, _šorc_, _ebis_,
   {{0x7bda008a,0x61ee9042,0x8b3b00a5,0xc6680274}},	//   mmtu, _nubl, _התוצ, пште_,
   {{0x44295e43,0x67eb0069,0xdb1a01ef,0x7bc87983}},	//   tua_, _ażje, doté, lldu,
   {{0x3f8c06d0,0x09c90325,0x798d02b3,0x752d9043}},	// [9e70] _oldu_, रतीय, _ilaw, rgaz,
   {{0x44299044,0x798d0221,0x61ee0187,0xe973006c}},	//   rua_, _hlaw, _bubl, _آنکھ,
   {{0x44290068,0x213f0159,0x7c292543,0x798d9045}},	//   sua_, _pbuh_, zuer, _klaw,
   {{0xdd860642,0x61ee9046,0x44299047,0x7dc50aca}},	//   _شو_, _dubl, pua_, pósi,
   {{0x442901d3,0x321800a2,0xe8e000e2,0x798d034d}},	//   qua_, _evry_, _duỗi_, _mlaw,
   {{0x798d0297,0x6f03006d,0x25ad05e2,0x394b000d}},	//   _llaw, ubnc, čelu_, hecs_,
   {{0x7c290bf7,0x61ee9048,0x6442000d,0x61fc008c}},	//   wuer, _gubl, çoiv, _gtrl,
   {{0x7c299049,0x3f8c0065,0x3f9e021d,0xe46a0225}},	//   tuer, _eldu_, _emtu_, ıköğ,
   {{0x3201010d,0x5ede0033,0x61ee0207,0x00000000}},	//   lphy_, নুলে, _zubl, --,
   {{0x7c29904a,0x798d904b,0x00000000,0x00000000}},	//   ruer, _alaw, --, --,
   {{0x3201006d,0x394a09b5,0x798d904c,0xddc800b5}},	//   nphy_, озно_, _blaw, _erdő,
   {{0x7c29112c,0xa96a0202,0x2d9d0232,0x798d904d}},	//   puer, цима_, _umwe_, _claw,
   {{0x798d904e,0xd91000b5,0x00000000,0x00000000}},	//   _dlaw, نیں_, --, --,
   {{0x8c4217c2,0x61fb042a,0xa49b0211,0xdd1c00ac}},	//   _реше, _čuln, _leòs, mášk,
   {{0xe7370421,0xb17d00ee,0x798d10a7,0xdd1c00ac}},	//   ьер_, _niťo, _flaw, lášk,
   {{0x995201c8,0x61ee904f,0x386001f2,0xe8170099}},	//   ršų_, _rubl, _trir_, _तिचा_,
   {{0x63be02c6,0x61fc02a7,0x64a35ba8,0x6fcd01ba}},	// [9e80] topn, _strl, вата, júco,
   {{0x387f033b,0x7dea00c7,0xa49b01da,0xaad10067}},	//   äure_, _kęst, _reòt, _हराक,
   {{0xa49b0211,0x63be9050,0x7dc500fd,0x00000000}},	//   _beòs, ropn, lósu, --,
   {{0xed59042a,0x2f0a0035,0x80a6730b,0x00000000}},	//   jdž_, _mógł_, ومان, --,
   {{0x7bc8008a,0x7bc31af8,0x63be0009,0x9f4502d0}},	//   yldu, _oknu, popn, _kilè_,
   {{0xdb1a4029,0x61ee00ab,0xdfd000bc,0x9f450107}},	//   poté, _tubl, ديت_, _jilè_,
   {{0x69c41cca,0x61fc00cd,0x00000000,0x00000000}},	//   _okie, _utrl, --, --,
   {{0xdb01008d,0x6e2a02b1,0x2dd70037,0x00000000}},	//   nnlæ, rufb, وبية_, --,
   {{0x7e87010b,0x21a31e31,0xa49b009e,0xdb183441}},	//   _įspū, _ритм, _heòr, _akvá,
   {{0x798d9051,0x69c45e20,0x6fcd002a,0x00000000}},	//   _slaw, _akie, núcl, --,
   {{0xd0130b52,0x798d01a9,0x6446046a,0x394b3469}},	//   _সময়_, _plaw, _lpki, tecs_,
   {{0x286b0210,0x1ea901b2,0x69d60359,0xdce20069}},	//   орго_, _عالي_, _chye, _eloġ,
   {{0xdb1800ac,0xd7f8034b,0xa2a0258f,0x394b01f7}},	//   _ekvá, дус_, _गेस्, recs_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f45021e,0x6446005f,0x7dea0067,0x5b330cd1}},	//   _dilè_, _apki, _gęst, _شعور,
   {{0x58d50421,0x236a0282,0x798d034d,0x99990067}},	//   _пойт, _anbj_, _ulaw, żyła_,
   {{0x660202c4,0x68ed01ef,0x9f45021e,0xdb019052}},	// [9e90] _čoke, _igad, _filè_, rolö,
   {{0x6d97002d,0x58d8010b,0x00000000,0x00000000}},	//   nţar, _ідэя_, --, --,
   {{0x644601f7,0xb8670088,0xe7e80067,0xe1f03e7c}},	//   _epki, _راکو, _टूटा_, لسن_,
   {{0xe5070d93,0x7dc517bf,0xa49b01da,0x59df021a}},	//   _تبدي, nóst, _deòr, नगिर,
   {{0xd00908f1,0x3f690431,0x04c90d47,0x69dd0719}},	//   челе_, зило_, _روسي_, imse,
   {{0x657d0027,0xa49b0284,0x7e610176,0x9f450392}},	//   _hosh, _feòr, _prlp, _xilè_,
   {{0xee390a55,0x657d9053,0x23be0d91,0x44390132}},	//   їни_, _kosh, ्तरद, _hqs_,
   {{0x68ed9054,0x63a576c6,0x6d8701d7,0x7dc50093}},	//   _ngad, lihn, _iñak, jóst,
   {{0x657d9055,0xed590200,0xdb011f55,0x00000000}},	//   _mosh, rdž_, lilé, --,
   {{0x69c49056,0x61e99057,0x68ed9058,0xa3bf210a}},	//   _skie, _hiel, _agad, ँकि_,
   {{0x61e99059,0xa2d31e82,0x62856bb4,0x7a6912a2}},	//   _kiel, भेच्, nyho, чинг_,
   {{0x657d0c6f,0x60c9001c,0x61e9023c,0x63a5357b}},	//   _nosh, _kyem, _jiel, hihn,
   {{0x61e9905a,0x8c45002d,0x443901f4,0xdb08905b}},	//   _miel, _челе, _nqs_, godó,
   {{0x61e90ae0,0x6d59905c,0x7c3b905d,0x60c97e30}},	//   _liel, _hawa, mtur, _myem,
   {{0x6d59905e,0x657d905f,0x69d601f4,0xdb011f10}},	//   _kawa, _bosh, _thye, vilè,
   {{0x6d590452,0x6d5b6cd1,0x61e99060,0x657d009e}},	//   _jawa, ndua, _niel, _cosh,
   {{0x6d599061,0x60c968c1,0xa49b0014,0x809f0803}},	// [9ea0] _mawa, _nyem, _seòr, _खेले,
   {{0x6d599062,0x68ed0035,0x7c3b4d89,0x61e9325f}},	//   _lawa, _zgad, itur, _aiel,
   {{0x61e99063,0x6ebf018d,0x657d0031,0xdcdd0023}},	//   _biel, _लुलु, _fosh, _sỉlẻ_,
   {{0x6d598eac,0x5efd0302,0x61e99064,0x7bc16438}},	//   _nawa, रुस्_, _ciel, holu,
   {{0x61e99065,0x4fc69066,0x63a50ec0,0x7bc19067}},	//   _diel, нска, bihn, kolu,
   {{0x6d59067f,0x2d8f9068,0x7c3b0a8a,0x60c90260}},	//   _aawa, _alge_, dtur, _dyem,
   {{0x6d599069,0x61e90122,0xd04e0095,0x7c3b0139}},	//   _bawa, _fiel, _ədəb, etur,
   {{0x6d59906a,0xdd9768be,0x7c3b906b,0x2912030d}},	//   _cawa, ешь_, ftur, _neya_,
   {{0x6d59906c,0x7c3b11e9,0x60c94ae1,0x00000000}},	//   _dawa, gtur, _gyem, --,
   {{0x09c920ab,0x61e9906d,0xa0a30ded,0x1e960923}},	//   रत्य, _ziel, _сауд, _прер,
   {{0x200d02c9,0x0c730416,0x29120118,0xdb080035}},	//   _zwei_, ندید, _beya_, wodó,
   {{0x6d59906e,0x67eb009f,0x13be06fe,0x7c3b7970}},	//   _gawa, _ażja, ्तुभ, btur,
   {{0x7c3b56f0,0x7bc1906f,0x69dd1d22,0xdb1a00d5}},	//   ctur, bolu, rmse, lotí,
   {{0x6d599070,0x7bc10043,0xef0e010b,0x7dc5171c}},	//   _zawa, colu, амi_, sóst,
   {{0x6d5974b7,0x657d5f34,0xa2a002cb,0x862410be}},	//   _yawa, _posh, _गेल्, льте,
   {{0xdb019071,0x657d1280,0x68ed009e,0x62850187}},	//   vilé, _qosh, _ugad, vyho,
   {{0x932700f8,0x61e91ab8,0x63a522be,0xf9940070}},	// [9eb0] فران, _riel, tihn, _תרפ_,
   {{0x61e99072,0x628500d5,0x60c904fb,0x657d0027}},	//   _siel, tyho, _ryem, _wosh,
   {{0x61e99073,0x60c9121e,0x06df0083,0x7c3b4d98}},	//   _piel, _syem, _ব্রি, ztur,
   {{0x7bc19074,0xf2c40210,0x1c210006,0x63a506b3}},	//   zolu, усун, _मिलल_, sihn,
   {{0x61e99075,0x6d59906a,0x29d9004f,0xdce9003a}},	//   _viel, _rawa, méad_, mjeć,
   {{0x61e90755,0x6d5909df,0xdce9029d,0xa06622e3}},	//   _wiel, _sawa, ljeć, таша_,
   {{0x44299076,0x61e99077,0x6d400408,0x6d599078}},	//   lra_, _tiel, ffma, _pawa,
   {{0x7c3b3c1d,0x44299079,0x8d6507b0,0xf8bf907a}},	//   ttur, ora_, твие, ngés_,
   {{0x4429907b,0x7bc1907c,0x29120159,0x6d5b907d}},	//   nra_, tolu, _reya_, rdua,
   {{0x4429907e,0x6d5987ab,0x61fb022f,0x6d400223}},	//   ira_, _wawa, _čulj, afma,
   {{0x4429009f,0x6d59907f,0x316d6395,0x09d600c8}},	//   hra_, _tawa, _knez_, _সংবা,
   {{0x44299080,0x7c3b6b97,0x00000000,0x00000000}},	//   kra_, ptur, --, --,
   {{0x29120723,0x44299081,0x7bc19082,0x25a2028b}},	//   _veya_, jra_, polu, _rmkl_,
   {{0x442986a9,0x70130033,0x3dcd007a,0x321a0159}},	//   dra_, _সমাজ_, llew_, yspy_,
   {{0x65b3048c,0x316d01b7,0xdb1a021d,0x29120103}},	//   għho, _onez_, botâ, _teya_,
   {{0xf8661a31,0x7d099083,0x89361b15,0x7c291fad}},	//   _авио, nbes, _شعبا, orer,
   {{0xd70601d3,0x5fc10de8,0x28de05e7,0xdb1a01ef}},	// [9ec0] _изпи, शकाल, नेशि, zotí,
   {{0x06863d4d,0x7c290d92,0x13be021a,0x78ad0355}},	//   _агон, irer, ्तेभ, šová,
   {{0x44299084,0x7c2902c9,0xdce9025c,0x7d090173}},	//   ara_, hrer, bjeć, kbes,
   {{0x29d9004f,0x6fcd9085,0x7d090051,0x7f5a013b}},	//   céad_, lúch, jbes, _satq,
   {{0x317f02d0,0x7d092aab,0x00000000,0x00000000}},	//   _douz_, dbes, --, --,
   {{0x7c296025,0x7d0929a4,0xce6a5759,0xe814020c}},	//   drer, ebes, дрид_, तीया_,
   {{0x7c299086,0xf3f40033,0x7d091b4a,0x59b40569}},	//   erer, _ছবির_, fbes, ीवार,
   {{0x7d099087,0x7c290132,0x6ce6093e,0x6fcd0079}},	//   gbes, frer, кіпе, húch,
   {{0x7c299088,0xc0452087,0x00000000,0x00000000}},	//   grer, _مخلو, --, --,
   {{0xf4130052,0x20060897,0xd00700af,0x7d090345}},	//   ספת_, mpoi_, _рефе_, abes,
   {{0xc3335c8e,0x44299089,0x6fcd178f,0x00000000}},	//   בות_, zra_, dúch, --,
   {{0x7c29908a,0x44292e40,0x6f1802c6,0x760902d0}},	//   brer, yra_, lavc, _lèzò,
   {{0xdce9012e,0x28de00b4,0x7c294090,0x00000000}},	//   vjeć, नेलि, crer, --,
   {{0x4429908b,0x6f18082d,0x0eb60066,0x60180079}},	//   vra_, navc, _अखाड, _zúmá,
   {{0x4429035f,0xb8ca0e04,0xdce90207,0xdb1a021d}},	//   wra_, _गे_, tjeć, potâ,
   {{0xdcfb0506,0x00000000,0x00000000,0x00000000}},	//   rkuć, --, --, --,
   {{0x29192a37,0xf8bf908c,0x317f908d,0xdcfb00cb}},	// [9ed0] masa_, rgés_, _rouz_, skuć,
   {{0xc6a71c1b,0xdce90c21,0x6f1802a7,0x6fcd0453}},	//   _арми, sjeć, javc, cúch,
   {{0x4429908e,0x29d90079,0x317f00ee,0x00000000}},	//   sra_, péad_, _pouz_, --,
   {{0x4429908f,0x29199090,0x673b0254,0x326434db}},	//   pra_, nasa_, đuju, штув,
   {{0x3a3e0024,0x4429003c,0x6fcd9091,0x656f9092}},	//   http_, qra_, lúci, _inch,
   {{0x2919120d,0x24890221,0x7c299093,0x2d829094}},	//   hasa_, myam_, vrer, öken_,
   {{0x6da509d0,0x29199095,0xd1bb0312,0x24899096}},	//   лика, kasa_, _قارا_, lyam_,
   {{0x7c299097,0xa2820118,0xf8d3018d,0x291907e0}},	//   trer, _دیمو, _सरूप, jasa_,
   {{0x29199098,0x7c29362b,0x6d9500b5,0x6f1800f4}},	//   dasa_, urer, _ráad, bavc,
   {{0x7c299099,0x2b5c0176,0x61f503e0,0xd01000fd}},	//   rrer, _cavc_, _kuzl, _گلے_,
   {{0x656f34d2,0x6fcd016f,0x25a900a0,0x7d091472}},	//   _onch, júci, kial_, pbes,
   {{0x2919429b,0x7c29909a,0x24890103,0x7c260156}},	//   gasa_, prer, kyam_, škra,
   {{0x24890221,0x31560070,0x9b4527f6,0xdb1a0176}},	//   jyam_, נישן_, _منشو, botà,
   {{0x656f0dbb,0x2d8d00c3,0xa3d300b4,0x00000000}},	//   _anch, lkee_, _हील_, --,
   {{0x2919909b,0x6fcd909c,0xe8200380,0x00000000}},	//   basa_, rúch, _बिका_, --,
   {{0x291903d0,0x6fc50099,0x6f1800cd,0x6fcd0079}},	//   casa_, ाकडू, zavc, súch,
   {{0x2bf602b5,0x69c62d1b,0x9f450312,0x00000000}},	// [9ee0] ָמען_, moke, _ailí_, --,
   {{0x25bf909d,0x69c6909e,0x6fcd909f,0x656f05f0}},	//   čula_, loke, búci, _ench,
   {{0x201f0955,0x35a62214,0x6f180a66,0xb22600d8}},	//   _avui_, _банг, vavc, умел,
   {{0x25a9734c,0x05560a71,0x24890221,0xf67b0070}},	//   cial_, _стоя, byam_, _נאכמ,
   {{0xdefa0d36,0x6f1800ac,0xe47501f1,0x80cc0033}},	//   ный_, tavc, _курэ, ়েন্,
   {{0x443201a2,0xa3cf00b4,0x69c690a0,0xdb1a00fd}},	//   muy_, शतः_, hoke, kotá,
   {{0x4432026f,0x291990a1,0x6f1805ed,0x69c690a2}},	//   luy_, yasa_, ravc, koke,
   {{0x69c690a3,0xdb080279,0x6f180506,0x99420067}},	//   joke, cidê, savc, _cóż_,
   {{0x61e21622,0x44320159,0x69c690a4,0x50b8021a}},	//   mmol, nuy_, doke, _अशिष,
   {{0x40930082,0x25a990a5,0xdb0190a6,0xc43b00a5}},	//   _الكر, zial_, bilí, עתיי,
   {{0x29191153,0xdb0190a7,0x443290a8,0xc33300a5}},	//   tasa_, cilí, huy_, זות_,
   {{0xdb010279,0x2d8d0069,0x61e2016e,0x69c690a9}},	//   gilâ, ckee_, nmol, goke,
   {{0x291937db,0x4432112c,0x61e290aa,0xdb080098}},	//   rasa_, juy_, imol, andá,
   {{0x443290ab,0x291990ac,0x6fcd01ba,0xa3d30324}},	//   duy_, sasa_, túci, _हीं_,
   {{0x291990ad,0x69c690ae,0x25a990af,0x61e290b0}},	//   pasa_, boke, tial_, kmol,
   {{0x55581728,0xdb030176,0x248990b1,0xdb01021d}},	//   лася_, _amnè, tyam_, cilâ,
   {{0xdb0803e6,0xe3150431,0x394902d7,0x00000000}},	// [9ef0] vidê, имањ, _ibas_, --,
   {{0x25a91c3d,0x248909e7,0x4ad80066,0x05150033}},	//   sial_, ryam_, _डराव, িলের_,
   {{0xd25107f6,0x7ceb006c,0x24895635,0x32558207}},	//   تنا_, _körü, syam_, рвер,
   {{0x3d0e0461,0xdb010453,0xf435002d,0x656f172e}},	//   सरों_, vilí, _кемэ, _unch,
   {{0x653600c2,0x9487005f,0x394901f4,0xf3ff0279}},	//   _דארף_, _сынд, _mbas_, _irão_,
   {{0xdb0803e6,0x61f50ad0,0xdb01002a,0x61e201af}},	//   sidê, _tuzl, tilí, amol,
   {{0xed5990b2,0x6d8790b3,0x69c601a8,0x09d60033}},	//   вой_, _oñat, yoke, _সংসা,
   {{0x0c253471,0x3869279b,0x9f4c02d0,0x0d8515ae}},	//   амин, _orar_, _lidè_, рлин,
   {{0x69c690b4,0x2d8d02ee,0x257c00fe,0xff2500f8}},	//   voke, rkee_, _cíly_, _نبای,
   {{0x4a4590b5,0x257c00b8,0x394990b6,0x2d8d90b7}},	//   анов, _díly_, _abas_, skee_,
   {{0xa2cb0712,0x69c60657,0x66022190,0x2fc790b8}},	//   _तुम्, toke, _čoko, mong_,
   {{0x3949009e,0x2fc790b9,0x4e940037,0x00000000}},	//   _cbas_, long_, _اشكر, --,
   {{0xeb8e1334,0x69c690ba,0xa2a70f8a,0x7d1b90bb}},	//   _ди_, roke, _टेस्, maus,
   {{0x7d1b1a9a,0x2fc78650,0x69c690bc,0x38693789}},	//   laus, nong_, soke, _drar_,
   {{0x66e67d5c,0x69c6000e,0x6b8349fb,0x61e23096}},	//   рова, poke, _iong, ymol,
   {{0x7ceb08d2,0x6b8390bd,0x2fc75b97,0x7d1b90be}},	//   _görü, _hong, hong_, naus,
   {{0x6b8390bf,0x2fc790c0,0x753690c1,0xd6d90035}},	// [9f00] _kong, kong_, rgyz, ęła_,
   {{0x6b8390c2,0xb6a609d0,0xf1b902c4,0x7d1b02d8}},	//   _jong, _виол, _ajš_, haus,
   {{0x6b8390c3,0x2fc790c4,0x7d1b90c5,0x28aa018d}},	//   _mong, dong_, kaus, _चेति,
   {{0x7d1b45d7,0x614601f6,0x6b831f73,0x443290c6}},	//   jaus, реда, _long, puy_,
   {{0x61e290c7,0x2056199d,0xdce202c4,0x6b830159}},	//   rmol, ртер, _inoć, _oong,
   {{0x2fc790c8,0x79960297,0x44201af8,0x6b8390c9}},	//   gong_, _llyw, msi_, _nong,
   {{0xf8d36ecd,0x91e603e6,0x257c0355,0x79960298}},	//   _सर्प, _вове, _síly_, _olyw,
   {{0x44200bbc,0x6b8349fb,0x442290ca,0x7d1b90cb}},	//   osi_, _aong, _kvk_, gaus,
   {{0x442090cc,0x6b8342cb,0x2fc75b97,0x9f4c01c0}},	//   nsi_, _bong, bong_, _lidé_,
   {{0x4420253c,0x23c600b1,0x7c260a66,0x2fc790cd}},	//   isi_, वविद, škro, cong_,
   {{0x6b8390ce,0x7d1b4594,0x79960b88,0x442090cf}},	//   _dong, baus, _blyw, hsi_,
   {{0x442090d0,0x8c463c49,0x7d1b0052,0x442290d1}},	//   ksi_, _веде, caus, _ovk_,
   {{0xfce60b46,0x6b830815,0x44200a69,0x9f4c000d}},	//   _тодо, _fong, jsi_, _aidé_,
   {{0x6b830044,0x8c1b0317,0x395f23c6,0x9f450168}},	//   _gong, _יודי, žus_, _kilá_,
   {{0x7c223fee,0x7bc890d2,0x61410332,0x442090d3}},	//   _hvor, modu, náló, esi_,
   {{0x44f52360,0x44200657,0x8cdd193c,0x39150073}},	//   спас, fsi_, _परमो, _умир,
   {{0x2fc732e1,0xe4e702ce,0x6b830010,0x98b900ea}},	// [9f10] yong_, рівн, _yong, resē_,
   {{0x7d1b3c73,0x44220345,0xdb0800a2,0x473590d4}},	//   zaus, _dvk_, fidé, _унос,
   {{0x442090d5,0x59bb09a0,0xdb1a2e22,0x2fc700cc}},	//   asi_, _उदार, lltó, vong_,
   {{0x442090d6,0xf6500332,0x2fc790d7,0xdb080443}},	//   bsi_, _کئی_, wong_, sidè,
   {{0x4420006c,0x557602b5,0x2fc77ffe,0x7bc80306}},	//   csi_, _הערן_, tong_, kodu,
   {{0x645d90d8,0x7d021315,0xef1800ec,0x00000000}},	//   _issi, _afos, _ceļ_, --,
   {{0x2fc711e9,0x22950082,0x7c224963,0xce1801c8}},	//   rong_, _الأس, _avor, ацыі_,
   {{0x6b8390d9,0x2fc790da,0x56b800a5,0x6d8701ed}},	//   _song, song_, יפון_, _añar,
   {{0x7d1b0408,0x6b8390db,0x2fc790dc,0x09d60083}},	//   raus, _pong, pong_, _সংলা,
   {{0x7c2202b2,0x6b9a02d0,0x7d1b90dd,0x60db15d7}},	//   _dvor, ghtg, saus, _izum,
   {{0x6b8352b4,0x7c22081b,0x442090de,0x7d02016e}},	//   _vong, _evor, zsi_, _ffos,
   {{0x442090df,0x645d68d5,0x6b831e20,0x2cbd006d}},	//   ysi_, _ossi, _wong, _txwd_,
   {{0x3f8590e0,0x44200095,0x8d5a0122,0x31560070}},	//   _kolu_, xsi_, _תכני, זירן_,
   {{0x6b83000e,0x6b9a5745,0x442090e1,0x60db08c7}},	//   _uong, chtg, vsi_, _mzum,
   {{0x645d90e2,0x7c22042a,0xdb1a0037,0x4422148a}},	//   _assi, _zvor, altó, _svk_,
   {{0x44204fe1,0x95990664,0xe5a374db,0x7d190107}},	//   tsi_, атуу_, писи, _jews,
   {{0x442090e3,0x7b060332,0x03262780,0x60db0371}},	// [9f20] usi_, _érté, йдан, _nzum,
   {{0x442090e4,0x442229ca,0xdb08000d,0x3f850225}},	//   rsi_, _vvk_, tidé, _nolu_,
   {{0x645d90e5,0x44220298,0x00000000,0x00000000}},	//   _essi, _wvk_, --, --,
   {{0x7d1990e6,0xf1a502ce,0x290290e7,0x765e4597}},	//   _news, орін, ncka_, _ispy,
   {{0x442090e8,0x3f8531b0,0x629e5a40,0x6d9c0098}},	//   qsi_, _bolu_, szpo, _héag,
   {{0xd8d702b5,0x6d4b01ae,0xdb080037,0x3f8524e4}},	//   זונט_, _abga, pidé, _colu_,
   {{0x7c2290e9,0x6d4b0159,0x3f8500a3,0x644400c3}},	//   _svor, _bbga, _dolu_, ltii,
   {{0x656490ea,0x7bc80035,0xdb0100b5,0xdd97010b}},	//   ndih, wodu, vilá, йшы_,
   {{0x91e31099,0x644490eb,0x55770070,0x7bc890ec}},	//   _хоте, ntii, מעקן_, todu,
   {{0xa3d81af6,0x69df00da,0x2902004e,0x3f850506}},	//   ाति_, _shqe, ecka_, _golu_,
   {{0x34d505dc,0x1e96002d,0x644400c3,0x765e0345}},	//   _दर्द, _урар, htii, _nspy,
   {{0x7c220097,0x64441c55,0x7bc890ed,0x00000000}},	//   _tvor, ktii, sodu, --,
   {{0x399b01d2,0xa3d82135,0x3f850463,0xe81400a1}},	//   _nëse_, ाता_, _yolu_, तीला_,
   {{0x0a940402,0x68f60103,0x6f1a00f6,0xdb0100ac}},	//   _малю, _egyd, _jetc, pilá,
   {{0x56948788,0xa1430029,0xd6d90067,0x7d0d0160}},	//   парт, šķir, ęło_, _însâ,
   {{0x6f1a00fe,0x69cd90ee,0x6d9c0079,0x29d901ef}},	//   _letc, _ukae, _déag, méao_,
   {{0x5fba030f,0x644408dd,0x765e021e,0x49b811c0}},	// [9f30] ेवाल, gtii, _espy, _داود_,
   {{0xed5902a7,0x2d86009e,0x6d9c0098,0x2bab021a}},	//   roži_, _looe_, _héad, टोपा,
   {{0x72b9004f,0xa5f903fa,0x644490ef,0x925900c3}},	//   جهاز_, _њему_, atii, рает_,
   {{0x644400b9,0x8f6a00b5,0x40950312,0x3f850a21}},	//   btii, یلنے_, يلار, _solu_,
   {{0x6d9c004f,0x4acf00b1,0x3f8590f0,0x6444002d}},	//   _méad, _सुनव, _polu_, ctii,
   {{0x3f693de2,0x00000000,0x00000000,0x00000000}},	//   рико_, --, --, --,
   {{0x62342659,0xfebb03c5,0x2902013c,0xdee200af}},	//   _неру, داشت_, ycka_, моши,
   {{0x7dc5006c,0x29d900e0,0x6f1a0223,0x2363023c}},	//   lósz, wéan_, _eetc, _hajj_,
   {{0x3f850118,0x60db0371,0xa2b91ab2,0xf4020160}},	//   _tolu_, _uzum, ्थव्, _guţă_,
   {{0x09d201d1,0xb4db009e,0x5ba98d30,0x3a2530cc}},	//   सत्य, _gcàe, рком_, омог,
   {{0xdcfb0888,0x2fc00079,0x00000000,0x00000000}},	//   ljuč, éige_, --, --,
   {{0x6d9c32d6,0x64440421,0xdb010510,0xbc7500f3}},	//   _réag, ytii, kilç, _وهاب,
   {{0xe45f0d36,0xa3e9021a,0x00000000,0x00000000}},	//   _myös_, मगा_, --, --,
   {{0x1af30033,0x6d4990f1,0x2d8601f7,0x6d9c00a2}},	//   _আজকে_, lfea, _zooe_, _péag,
   {{0xba7701ca,0x6d9c004f,0xf1c904e9,0x41c9142a}},	//   _داشت, _féad, िकान, िकास,
   {{0x644403ad,0x29d90037,0xf50a8207,0x6d494dbb}},	//   ttii, néal_, рнал_, nfea,
   {{0x92d600c8,0x044312e3,0xd46701b8,0x6d49184f}},	// [9f40] _হলে_, метн, оите_, ifea,
   {{0x32d62cdd,0x644490f2,0x213f0034,0x3860003c}},	//   оцес, rtii, _acuh_, _isir_,
   {{0x644490f3,0xdb010328,0x5a16016b,0x00000000}},	//   stii, milä, ַקסן_, --,
   {{0x6f1a3ec4,0x644490f4,0xdb01145d,0x59ca1579}},	//   _setc, ptii, lilä, रविर,
   {{0xe05603c7,0x6f1a20f8,0x29d90037,0x25a524dc}},	//   تخاب, _petc, déal_, ëlle_,
   {{0x44323f14,0x3940009e,0x9e0690f5,0xdb010dfa}},	//   mry_, _lcis_, очил, nilä,
   {{0xdd9a3ad5,0x59ca1e82,0x443290f6,0xa3d300b4}},	//   иши_, रवार, lry_, _हीट_,
   {{0x443290f7,0x127b0070,0xed590009,0x6d490098}},	//   ory_, _דאלע, kožu_, gfea,
   {{0x61fc90f8,0x6d9c0037,0x38600024,0x459b016b}},	//   _hurl, _réad, _nsir_, יסקע,
   {{0x44320a4e,0x0b8a0c46,0x394000ea,0x6d9c0079}},	//   iry_, рсии_, _acis_, _séad,
   {{0x9d468967,0x44320237,0xed5a002d,0x8aa3051a}},	//   _межд, hry_, _вое_, дряд,
   {{0x44320173,0x29d90079,0x61fc1016,0x316400ee}},	//   kry_, céal_, _murl, _jamz_,
   {{0x92d600c8,0x9f4c01c0,0xdce9025c,0x61fc0051}},	//   _হলো_, _lidí_, bjeđ, _lurl,
   {{0x443205d1,0xdceb00ea,0xb4db0211,0x61fc00f6}},	//   dry_, _ungā, _mbàt, _ourl,
   {{0x38660009,0x61fc242d,0x99d702e7,0x386090f9}},	//   _šort_, _nurl, _وتعا, _esir_,
   {{0xa2cb0096,0x6283463e,0xe7db00b4,0x443205d1}},	//   _तुष्, änom, _मीरप, fry_,
   {{0xb9c40082,0x6fca02e4,0x443290fa,0x395990fb}},	// [9f50] _تقيي, ाकां, gry_, mess_,
   {{0x39596eb6,0x26c1006d,0xb4db0176,0xef1f0035}},	//   less_, _txho_, _acàc, ążka_,
   {{0xe7f902cb,0x443290fc,0x46d200ab,0x00000000}},	//   ंदवा_, ary_, _दुपह, --,
   {{0x395911b6,0xe1f800d8,0x44320f86,0x61fc0210}},	//   ness_, ігі_, bry_, _durl,
   {{0xa2cb1fe0,0xf9940397,0xd4790070,0xd0ab03e6}},	//   _तुर्, ורף_, _האָל, јтед_,
   {{0xf8380d85,0x77650069,0x23fa00a5,0xa3d30099}},	//   קנות_, _jahx, _להשא, _हीच_,
   {{0xa3d80026,0xc7b400a5,0xfe5700b5,0x6d49026e}},	//   ातर_, ובס_, تیاب_, tfea,
   {{0xac85081b,0x673c0124,0x4c852b32,0xc17701df}},	//   згил, zgrj, злив, _بدست,
   {{0x29d90248,0x6d490037,0x61fc0036,0x9f89008d}},	//   réal_, rfea, _zurl, búð_,
   {{0xeb990274,0x290d01a3,0x61fc0223,0x6d4990fd}},	//   сио_, ñean_, _yurl, sfea,
   {{0x05bd009a,0xdb0807a6,0xa96a22a9,0x8a051482}},	//   ्काब, cidí, бина_, язне,
   {{0x764701b4,0x443202ee,0xc7a900a5,0x499a195c}},	//   dtjy, yry_, _גב_, стоя_,
   {{0x3d110099,0xdb010421,0x00000000,0x00000000}},	//   _ध्ये_, tilä, --, --,
   {{0xed59068b,0xfaa50426,0x443290fe,0x38660009}},	//   lež_, _нало, vry_, _šors_,
   {{0x70b80066,0xa2cb02d1,0xa59602fb,0x395990ff}},	//   _अश्ल, _तुल्, пращ, bess_,
   {{0xf99f9100,0x39599101,0x443206a0,0x394000af}},	//   chè_, cess_, try_, _ucis_,
   {{0x5fcb3100,0x44329102,0x77650069,0x2d9f02d7}},	// [9f60] िवाल, ury_, _fahx, ihue_,
   {{0x44329103,0x61fc0a8a,0xe7f90387,0xb7f9021a}},	//   rry_, _purl, ंदरा_, ंदरम_,
   {{0xe7170052,0x44327908,0xdb080132,0xf8a900f8}},	//   _מחיר_, sry_, lidã, _هدیه_,
   {{0xc6930779,0x7c26201d,0x9f4c0187,0x0f1405e7}},	//   _נאר_, škri, _vidí_, डर्स_,
   {{0xed59765d,0x6d9c0079,0x65660107,0x00000000}},	//   dež_, _léac, _iakh, --,
   {{0x61fc9104,0xa2a71bc6,0xdfcf11c0,0x8fa327b9}},	//   _turl, _टेक्, هين_, наче,
   {{0x65660044,0x9f44299f,0x6d9c0079,0xaff600b5}},	//   _kakh, _sumó_, _réab, _کہتا_,
   {{0xfe6f0427,0x2d9f9105,0x65660298,0x7a0100ea}},	//   ادو_, ghue_, _jakh, _pētn,
   {{0x656606b3,0xdb089106,0x39599107,0x2bdd021a}},	//   _makh, sidí, vess_, _नीहा,
   {{0x65669108,0x25bf5abf,0x0ea7046c,0x00000000}},	//   _lakh, čuli_, _केकड, --,
   {{0x39590484,0x25a000e0,0xed59080a,0xa93531fe}},	//   tess_, khil_, bež_, менш,
   {{0x65668a0d,0x2d9f67ff,0x00000000,0x00000000}},	//   _nakh, chue_, --, --,
   {{0x39599109,0xf3ff0023,0x25a0910a,0x26150066}},	//   ress_, _trãi_, dhil_, _फौजी_,
   {{0x6d9c0082,0x3959910b,0x6566910c,0xe784584e}},	//   _féac, sess_, _aakh, нусо,
   {{0x656683a0,0x1db00099,0xf674010b,0x00000000}},	//   _bakh, _जगात, нгрэ, --,
   {{0x6566012f,0x1dcc01d1,0x98b900ea,0x25a00098}},	//   _cakh, ावित, nesī_, ghil_,
   {{0x69cf73cb,0xa3d8022e,0x7a080355,0x764708c8}},	// [9f70] moce, ातं_, _děte, stjy,
   {{0x69cf910d,0x889c00a5,0x64a40200,0x00000000}},	//   loce, _לבחי, хађа, --,
   {{0x65665efb,0x1dcc01d1,0x6b8a009e,0xdb1a0055}},	//   _fakh, ावात, _mofg, entë,
   {{0x25a00a75,0x69cf910e,0x6d420160,0x6f0800f6}},	//   chil_, noce, _ncoa, _afdc,
   {{0x1b220083,0x2378042a,0xed590693,0x00000000}},	//   _মানে_, _fnrj_, vež_, --,
   {{0x6566910f,0xa3d8012f,0x69cf00fe,0x00000000}},	//   _zakh, ातः_, hoce, --,
   {{0x443b9110,0x6566023c,0xed5901a0,0xf1a700af}},	//   luq_, _yakh, tež_, _еран,
   {{0x6d9c0248,0xaad00066,0x962700ea,0x6d420371}},	//   _réac, _हड़क, _ieņē, _ccoa,
   {{0xed59023a,0xcc8900d1,0x9f459111,0x1c420421}},	//   rež_, زنده_, _milú_, вным,
   {{0x23bf012f,0x7d0300b5,0xdb080132,0x200d009e}},	//   ्विद, _bíró, vidã, _itei_,
   {{0x52db13a0,0x69cf0184,0xed592018,0x7e7e01ff}},	//   _भरोस, foce, pež_, äppt,
   {{0x69cf37cb,0xdb080279,0x443b01e9,0x2d829112}},	//   goce, tidã, kuq_, öket_,
   {{0x23bf31d7,0x6566578f,0xa3bf7f73,0x6d5b002f}},	//   ्वाद, _rakh, ुका_, meua,
   {{0x6d9c004f,0x65666dd0,0x2480006d,0x7c3b9113}},	//   _téac, _sakh, vxim_, muur,
   {{0xd5b20037,0x6566541f,0x25a0195f,0x290902d7}},	//   نفس_, _pakh, thil_, _ffaa_,
   {{0x69cf1c02,0xdb1a00f7,0xdb08094c,0x6936007e}},	//   coce, entè, midá, _břež,
   {{0xdb089114,0xb9b30037,0x656601a2,0x7c3b9115}},	// [9f80] lidá, _جميع, _vakh, nuur,
   {{0x61b820ab,0x6566034d,0x25a001e9,0x6d5b016e}},	//   ेक्ष, _wakh, shil_, heua,
   {{0x65669116,0x7c3b331d,0x200d1315,0x57da0099}},	//   _takh, huur, _atei_, णतीह,
   {{0xe0da9117,0x7c3b02e2,0x00000000,0x00000000}},	//   ове_, kuur, --, --,
   {{0x9fca0086,0x75249118,0x7c3b0303,0x4fc63b41}},	//   огда_, maiz, juur, мска,
   {{0x09bb0d53,0x6d420043,0x2bdd0067,0xfbdd00b4}},	//   _उद्य, _scoa, _नीला, _नीलम,
   {{0x2247002d,0xa3da073f,0x00000000,0x00000000}},	//   _опри_, _डीए_, --, --,
   {{0x717601ca,0x75243f83,0xdb080952,0x6b8a0107}},	//   _تهرا, naiz, didá, _sofg,
   {{0xe0431d30,0x69cf9119,0x7c3b911a,0x00000000}},	//   _инти, voce, guur, --,
   {{0x75247ed2,0x547b0070,0x2d9d0345,0x39520edf}},	//   haiz, קטיו, _elwe_, _abys_,
   {{0x69cf911b,0xd3370122,0xa3e60066,0x3f9b000d}},	//   toce, וריה_, _पठन_, êque_,
   {{0x7c3b0051,0x443b013b,0x3f8c00f4,0x38720e6c}},	//   buur, yuq_, _hodu_, _bryr_,
   {{0x3f8c38b0,0xc3240083,0x7dde01f4,0x1b220033}},	//   _kodu_, _পানি_, lëso, _মাঠে_,
   {{0xeaaf0357,0xac9700bf,0xd90f03c5,0x36d517d0}},	//   اعی_, _تنها_, دیک_, еогр,
   {{0x3f8c06a2,0x69cf00cd,0xdb0801ef,0x7dde0055}},	//   _modu_, poce, cidá, nëso,
   {{0x7bda911c,0x69360355,0x28aa0e6f,0x75240065}},	//   lltu, _přež, _चेकि, gaiz,
   {{0x337569e1,0xdb1a000d,0x7dde0031,0x38720282}},	// [9f90] нгар, enté, hëso, _gryr_,
   {{0xdce20a16,0x7dde01f4,0x443b911d,0x68e00225}},	//   _naoč, këso, ruq_, ümde,
   {{0x443b009f,0xe3c30033,0x6d5b911e,0x7d1d003e}},	//   suq_, ্গলব, yeua, ðssk,
   {{0x59f90779,0x3f9e911f,0x3d0d00ab,0x00000000}},	//   פּעד, _altu_, _सभें_, --,
   {{0x443b0095,0x3f8c0187,0x00000000,0x00000000}},	//   quq_, _bodu_, --, --,
   {{0x44299120,0xfe452495,0x141a00a5,0x63b10355}},	//   msa_, енко, _מושב, édně,
   {{0x3f8c73c0,0x53340274,0xdb0851ac,0x6d8701ed}},	//   _dodu_, _јест, xidá, _iñaz,
   {{0x7c3b9121,0x6d40026a,0x7bda02a2,0x442b0371}},	//   tuur, ggma, eltu, _kvc_,
   {{0x44299122,0x6d5b016e,0x00000000,0x00000000}},	//   nsa_, reua, --, --,
   {{0x44299123,0x7c3b14e7,0x2d82013c,0xdaa90374}},	//   isa_, ruur, öker_, звод_,
   {{0xd946263b,0x44299124,0x752f0035,0x7c3b9125}},	//   нени, hsa_, _odcz, suur,
   {{0x3f870254,0xa96a0274,0x98a61641,0x7bda009e}},	//   ljnu_, чима_, еиме, altu,
   {{0xb908017a,0xaacf131c,0x752400d8,0x9d1a0070}},	//   _भर_, _सुरक, vaiz, _זונט,
   {{0x44299126,0x7d0907f2,0x00000000,0x00000000}},	//   dsa_, lces, --, --,
   {{0x7c299127,0x959a00af,0x7c260097,0x7524034d}},	//   lser, птау_, škrt, taiz,
   {{0x7d0909e8,0x6d9c0079,0x442b9128,0xe7e0007c}},	//   nces, _léan, _bvc_, _खीरा_,
   {{0x7c293789,0x44297698,0x64a39129,0x69c4035f}},	// [9fa0] nser, gsa_, гата, _ijie,
   {{0x68e4912a,0x6d9c00f7,0x69c40069,0xf4870088}},	//   _izid, _néan, _hjie, راقی,
   {{0x7d090035,0x442b0223,0x7c290bf7,0x00000000}},	//   kces, _evc_, hser, --,
   {{0xf1a901b2,0x44294498,0x7c29912b,0x7d093cfe}},	//   وانه_, bsa_, kser, jces,
   {{0x4429912c,0x3f8c912d,0x3f9e012f,0x7c2908c8}},	//   csa_, _podu_, _pltu_, jser,
   {{0x6d9c004f,0x7c29912e,0x7dde00da,0x7d090168}},	//   _céan, dser, tëso, eces,
   {{0x6d9c0514,0x3f8c022f,0xa3b5020c,0xa2e3167d}},	//   _déan, _vodu_, _जगत_, _борд,
   {{0x7dde00da,0x68e402c4,0x7bc30024,0x7c2b00ee}},	//   rëso, _ozid, _ajnu, _bvgr,
   {{0x7c29912f,0x68e40e0b,0xbebc00ec,0xdb030523}},	//   gser, _nzid, _adīt, _omnä,
   {{0x6d9c178d,0x8c531902,0x1fb50bfe,0x69c70009}},	//   _géan, ائيا, _исхр, čkem,
   {{0x7c290103,0x533702b5,0x44299130,0x7dde01f4}},	//   aser, ענטן_, zsa_, qëso,
   {{0x44299131,0x7d099132,0x7c299133,0x23a4013c}},	//   ysa_, cces, bser, _höjd_,
   {{0x44290095,0xc17300a5,0x7c2900b5,0xa3d000ab}},	//   xsa_, אחר_, cser, शवा_,
   {{0x5c970a93,0x69d601a8,0x442b0051,0xd7f8034b}},	//   _якія_, _ekye, _rvc_, еус_,
   {{0x36d50431,0x68e405a0,0x6be30037,0x44299134}},	//   товр, _ezid, _حكوم, wsa_,
   {{0xd0080033,0xa2d40ec5,0x00000000,0x00000000}},	//   রীয়_, _बुध्, --, --,
   {{0x44299135,0x24580086,0xf3f90370,0x98b9010b}},	// [9fb0] usa_, нать_, днаш_, mesį_,
   {{0x61c91856,0x69dd9136,0x7d099137,0x23a4013c}},	//   िक्ष, llse, zces, _nöjd_,
   {{0x44299138,0xa2d40e6f,0x290b0036,0x6d9c00a2}},	//   ssa_, _बुद्, occa_, _réan,
   {{0x44299139,0x51842490,0x7c29913a,0x6d9c32d6}},	//   psa_, луча, yser, _séan,
   {{0x657d0232,0x44297838,0x3494004b,0x3f694670}},	//   _insh, qsa_, _баяр, дило_,
   {{0x6727001c,0x656d0702,0x7c29913b,0x101413cf}},	//   najj, ldah, vser, ابند,
   {{0x644d913c,0x92588a7f,0x8fa200c3,0x29190159}},	//   ltai, _парт_, раще, kbsa_,
   {{0x644d913d,0xdb010079,0xdb1a0d7f,0xf67c00a5}},	//   otai, mhlé, kotó, לאומ,
   {{0x644d1762,0xdd8e004f,0x6d9c0037,0xa3b5030f}},	//   ntai, توي_, _téan, _जगा_,
   {{0x09ca063f,0x7d09913e,0x67274380,0x644d913f}},	//   रव्य, sces, jajj, itai,
   {{0x644d9140,0x34de145a,0x7c2906c6,0x657d82dc}},	//   htai, _मर्द, sser, _onsh,
   {{0x644d9141,0x61fb9142,0xf2d20070,0x61e90069}},	//   ktai, _jiul, שעט_, _jhel,
   {{0x656d9143,0x8c4503f5,0xa3e100dc,0x201f0107}},	//   ddah, _реле, दता_, _jwui_,
   {{0x2d8f0120,0x69dd007c,0x644d9144,0x656d00d7}},	//   _hoge_, alse, dtai, edah,
   {{0x644d9145,0x9f450079,0xfaf800ea,0x2d8f0b3e}},	//   etai, _chlé_, udīt_, _koge_,
   {{0x656d9146,0x2d8f02f6,0x61fb3b0a,0x69c4034d}},	//   gdah, _joge_, _niul, _ujie,
   {{0x60db9147,0x644d9148,0x2d8f9149,0x27210033}},	// [9fc0] _nyum, gtai, _moge_, _বারো_,
   {{0x2258022e,0x657d018e,0xe29a6299,0x61e95384}},	//   _pprk_, _ensh, маз_, _ahel,
   {{0x644d02a8,0x23a4022a,0x60db914a,0x179b0122}},	//   atai, _nöje_, _ayum, _חייב,
   {{0xc05a0210,0x644d914b,0x60db041b,0x2d8f5620}},	//   дік_, btai, _byum, _noge_,
   {{0xd0070133,0x644d914c,0x60db0010,0x61e906dd}},	//   вече_, ctai, _cyum, _dhel,
   {{0xdefa1a72,0x61e92d20,0xdb010079,0x00000000}},	//   мый_, _ehel, bhlé, --,
   {{0x60c9914d,0xdb01914e,0x290001a3,0x61fb0395}},	//   _exem, chlé, _ogia_, _fiul,
   {{0x61fb914f,0x91e61bfd,0x2d8f00de,0xa2bf021a}},	//   _giul, _робе, _coge_, वपर्,
   {{0x9f4c00c3,0x00000000,0x00000000,0x00000000}},	//   _pidä_, --, --, --,
   {{0x5fb6007c,0x61e91a7f,0x8a1803d0,0x290003d0}},	//   _अगिल, _zhel, ноос_, _agia_,
   {{0x6b9a2668,0x2d8f0132,0x644d9150,0x46d2007c}},	//   rktg, _foge_, ztai, _दुलह,
   {{0x20040a15,0x61e901f4,0xf2d3011d,0x9f450097}},	//   _kumi_, _xhel, יעת_, _milý_,
   {{0x8c430bd7,0x69dd2aab,0x1d073668,0xdca305a1}},	//   _вече, rlse, _речи_, _каци,
   {{0xc7c400c3,0xa2cb00a1,0x290006a2,0x9f450037}},	//   асси, _तुझ्, _egia_, _phlé_,
   {{0x6d9c004f,0x20049151,0xb9090033,0xdb1a0098}},	//   _léam, _lumi_, _বল_, nntí,
   {{0xa2b809b1,0xa3b50b4a,0x644d03ad,0x56940b5e}},	//   ्पन्, _जगह_, ttai, шаст,
   {{0x6d9c9152,0x656d9153,0x644d00f1,0x657d0023}},	// [9fd0] _réal, rdah, utai, _vnsh,
   {{0x61fb010b,0x644d2968,0x61e96161,0x38699154}},	//   _siul, rtai, _shel, _isar_,
   {{0x7205006c,0x644d9155,0x61fb4a49,0xe9df0079}},	//   اہرہ_, stai, _piul, olú_,
   {{0x20040452,0x657d72fc,0xdb01007e,0x62850031}},	//   _bumi_, _unsh, dilý, rxho,
   {{0x9484081b,0x394910c3,0x20040010,0x7dde0031}},	//   _кырд, _mcas_, _cumi_, mësh,
   {{0x200408dd,0x60db002f,0x889c00a5,0x720506ee}},	//   _dumi_, _vyum, ובדי, _موسم,
   {{0x61e99156,0x28da1d25,0x6d9c0037,0x29d90079}},	//   _thel, _युनि, _téal, néas_,
   {{0x61e99157,0x394901e8,0x2004027a,0xdcfb00cd}},	//   _uhel, _ncas_, _fumi_, njuć,
   {{0x60db9158,0xa3d800a1,0xb0b70127,0x20045167}},	//   _uyum, ातच_, _अधिग, _gumi_,
   {{0xceeb03c7,0x39497f85,0xdb0100d5,0x799d0051}},	//   _قران_, _acas_, bilý, eksw,
   {{0x38699159,0x7dde01f4,0xa2e108a9,0x317f0a8a}},	//   _asar_, kësh, _करोड़_, _knuz_,
   {{0x98b201c2,0xcd2b0609,0xdb0a0176,0xa3b300b4}},	//   _sayı_, _آسان_, _emfà, जोत_,
   {{0x386900d7,0x672504c1,0x8d742fad,0x98b2045e}},	//   _csar_, _behj, _خالا, _payı_,
   {{0x6c32006c,0x366a00d8,0x3949915a,0xe9df0079}},	//   _افوا, наго_, _ecas_, alú_,
   {{0xf1d300e7,0x7d1b915b,0x857a002d,0x00000000}},	//   तवान, obus, нсат_, --,
   {{0xceb20319,0x764e6ba8,0x7dde0055,0x799d0bf7}},	//   צין_, rtby, gësh, cksw,
   {{0x69db00c2,0x5fc322a3,0x29d9000d,0x764e0557}},	// [9fe0] _אַזו, वचाल, réat_, stby,
   {{0x6d9c004f,0x1c1b10a6,0x7d1b00a8,0x00000000}},	//   _réam, पीएल_, hbus, --,
   {{0x77f70122,0xdb9a02b5,0x200400e0,0x6d9c0079}},	//   _תמיד_, עסער, _sumi_, _séam,
   {{0x7d1b915c,0x29d90098,0x20040024,0x00000000}},	//   jbus, léar_, _pumi_, --,
   {{0x25d7035e,0xa2d40084,0x9f4501f7,0xdfda02fb}},	//   _תוכן_, _बुर्, _niló_, нък_,
   {{0x7dde0031,0x7e680160,0x7c3b4d05,0xdb0100ac}},	//   mësi, _psdp, drur, tilý,
   {{0x7dde01f4,0x75260107,0x2ff700af,0x00000000}},	//   lësi, _kekz, ыншь_, --,
   {{0x6d9c004f,0x7d1b784c,0xcbc00033,0x62810124}},	//   _téam, gbus, _উঠেছ, _šlog,
   {{0x5b26086c,0x7dde01f4,0x39490051,0xafe600af}},	//   льна, nësi, _rcas_, _боал,
   {{0x7d1b0159,0x39490345,0x75268e28,0x4a543a49}},	//   abus, _scas_, _lekz, акос,
   {{0x7d1b008e,0x7dde01f4,0x8f9b024b,0x00000000}},	//   bbus, hësi, _ריבי, --,
   {{0x7dde01f4,0x7d1d008d,0x29040121,0x9f45021d}},	//   kësi, ðsst, žman_, _filó_,
   {{0xec1311cf,0xedd32149,0x7c3b0043,0xe9df0037}},	//   _هوند, _ايند, crur, rlú_,
   {{0x66053115,0xb8fd007c,0xa49b00e2,0xb8dd0387}},	//   _puhk, _तँ_, _ngòa, _आध_,
   {{0x4422415b,0x8af600a8,0x7dde0031,0xb4db009e}},	//   _awk_, şəbb, tësh, _icài,
   {{0x3869915d,0x39494c1e,0x7c220b13,0x00000000}},	//   _tsar_, _ucas_, _kwor, --,
   {{0x38690aca,0x7dde0031,0x75260051,0x7d0208c7}},	// [9ff0] _usar_, rësh, _dekz, _mgos,
   {{0x316d00f6,0x175502fb,0x7c22007b,0x66056f5e}},	//   _saez_, _твоя, _mwor, _tuhk,
   {{0x316d02d7,0x7c220103,0x00000000,0x00000000}},	//   _paez_, _lwor, --, --,
   {{0xd5674ae8,0x7d028396,0x7dde0055,0x00000000}},	//   _стоп, _ngos, bësi, --,
   {{0xc3240083,0xa06960f8,0x4422012f,0xf1a60c57}},	//   _পারি_, тала_, _gwk_, _खतरन,
   {{0x656f915e,0x645d4287,0xad9c00a0,0xb81d00b4}},	//   _hach, _ipsi, _stĺp, बीएम_,
   {{0x656f02e9,0x244f01d6,0xdce9497c,0x9f962123}},	//   _kach, lüm_, rdeč, рвју_,
   {{0x25a9101d,0x7c2204fb,0x7d1b08dd,0x00000000}},	//   nhal_, _bwor, ubus, --,
   {{0x656f915f,0x244f027d,0x7a0800b8,0xdb1a0183}},	//   _mach, nüm_, _dětm, mitê,
   {{0x656f9160,0x7d1b9161,0x7c3b9162,0x543c0070}},	//   _lach, sbus, rrur, געזא,
   {{0xf986107b,0x244f0095,0x26e4000c,0x4acf9163}},	//   агно, hüm_, _गरेर_, _सुखव,
   {{0x656f4fec,0xa2b8051d,0x645d9164,0xdb01004f}},	//   _nach, ्पत्, _opsi, mhlí,
   {{0x25a99165,0x6d5904fb,0x2d8d023c,0x29d90098}},	//   dhal_, _ibwa, mjee_, téar_,
   {{0x656f9166,0xdca215df,0x2bdd00ab,0x2d8d9167}},	//   _aach, _фаши, _नीचा, ljee_,
   {{0xb8fd21fe,0xaa450423,0x645d00d8,0xa3d90174}},	//   _तु_, _тейл, _apsi, ावन_,
   {{0x7dde01d2,0x25a901a6,0x6d9c0118,0x3e4e013b}},	//   tësi, ghal_, _réak, _qəti_,

   {{0x656f9168,0x03261c84,0x6fdf0248,0xf5071bdc}},	// [a000] _dach, идан, pêch, рнул_,
   {{0x656f1093,0x7dde01d2,0xd7640e3a,0xdb1a0037}},	//   _each, rësi, _اندی, ontá,
   {{0x656f9169,0x25a909bb,0x7afc18b0,0x6d590273}},	//   _fach, bhal_, žrtv, _obwa,
   {{0x25a915bd,0xd2e60a5e,0x7dde01f4,0x244f027d}},	//   chal_, _करीब_, pësi, büm_,
   {{0x7dde00da,0x69c6916a,0xf1aa0088,0x44220345}},	//   qësi, inke, _یاره_, _uwk_,
   {{0x656f0c3d,0x087702b5,0x6d59916b,0x65645d91}},	//   _zach, יענט_, _abwa, leih,
   {{0x656f916c,0x7c223cc2,0x00000000,0x00000000}},	//   _yach, _swor, --, --,
   {{0x25a0916d,0x69c66666,0xdceb027d,0x65a300be}},	//   nkil_, jnke, _algı, _lõhn,
   {{0x7f860416,0xdb1a05f6,0xa067145c,0xef8670a5}},	//   _پلان, entá, _ката_, _клап,
   {{0x61e2916e,0x2912000e,0x28da170c,0xbbd0000c}},	//   llol, _afya_, _युधि, सकेक,
   {{0xc3331759,0xa4e30e96,0x7ac61018,0x244f00d0}},	//   חות_, _खर्च_, рспе, züm_,
   {{0x7c22004e,0x7d020254,0x61e2067f,0x00000000}},	//   _twor, _ugos, nlol, --,
   {{0xdd8f11c0,0xa49b01f7,0xf99f027a,0xd8cb002d}},	//   _تون_, _agòn, rkè_, тынд_,
   {{0x656f916f,0x69c60cfd,0x00000000,0x00000000}},	//   _sach, anke, --, --,
   {{0x25f300a1,0x61e208dd,0x8b6501cb,0x00000000}},	//   ंगली_, klol, _دانم, --,
   {{0x656f1505,0xf53f017b,0xaacf0099,0x244f9170}},	//   _qach, _blåa_, _सुटक, tüm_,
   {{0x656f9171,0x61e235f3,0x25a95acd,0x9f450079}},	// [a010] _vach, dlol, rhal_, _shlí_,
   {{0x656f9172,0x9f5e00da,0x0a51006c,0xdb1a01f4}},	//   _wach, _ditë_, _بھیج, ditë,
   {{0x656f9173,0xed590956,0x7dde0031,0x25a964d3}},	//   _tach, liže_, lësu, phal_,
   {{0x656f148b,0x61e2010d,0x835500fd,0xeaa600b5}},	//   _uach, glol, _گھرا, _ہٹ_,
   {{0xed590c99,0x7dde0031,0x20670274,0xd12e0bf5}},	//   niže_, nësu, рђев, رمو_,
   {{0xeaa600b5,0x28c801c0,0x94f600a5,0x00000000}},	//   _فٹ_, रपति, _לצרף_, --,
   {{0xed591667,0x69c6008c,0x61e201fb,0xdb1a01f7}},	//   гой_, ynke, blol, mitè,
   {{0xa3b30bc1,0x7e7a00d7,0x752d018e,0xf1a703e6}},	//   जोर_, _drtp, naaz, _тргн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed590254,0xdb1a01f7,0x2cad0067,0x00000000}},	//   diže_, nitè, rzed_, --,
   {{0x7bca01f7,0x752d4179,0xc869011d,0x2cad00fd}},	//   _djfu, kaaz, _רן_, szed_,
   {{0x6d590232,0x69c60065,0x00000000,0x00000000}},	//   _ubwa, unke, --, --,
   {{0xf1b20070,0x69c69174,0xb88600a0,0xeb8e1126}},	//   לסט_, rnke, _opíš, _еи_,
   {{0x6d499175,0x656402b1,0x00000000,0x00000000}},	//   lgea, weih, --, --,
   {{0x78c10669,0x66e61ce8,0xdb1a01f4,0x6b831a9e}},	//   _əvvə, сова, zitë, _inng,
   {{0x6d499176,0x7a130160,0x00000000,0x00000000}},	//   ngea, _căte, --, --,
   {{0x6d4902a8,0x16046a9c,0x65644acc,0x79840dc3}},	// [a020] igea, _शंकर_, reih, _iniw,
   {{0x7dde0055,0x00000000,0x00000000,0x00000000}},	//   qësv, --, --, --,
   {{0x61e202a7,0xb5ca0833,0x00000000,0x00000000}},	//   tlol, _مودم_, --, --,
   {{0x6146692c,0xd76403c5,0x7a130395,0x00000000}},	//   седа, _انگی, _găte, --,
   {{0x20569177,0xe3b10332,0x61e2010d,0xb03301e0}},	//   стер, سرے_, rlol, зніш,
   {{0xfbc729fe,0xdb1a01f4,0x5f930043,0x9f5e0107}},	//   _رت_, ritë, зишт, _kité_,
   {{0x91e60dfc,0x00000000,0x00000000,0x00000000}},	//   _гове, --, --, --,
   {{0x15fa0f39,0xdb1a9178,0xb8000083,0x7d9884f9}},	//   ्दिर_, mité, ্ঠিত_, рвис_,
   {{0xdb1a1010,0xfd0f0bdf,0x443256dd,0x02b80d1f}},	//   lité, رجي_, nsy_, _आधुन,
   {{0x6d490211,0x79842d0d,0x752d9179,0x320a917a}},	//   agea, _aniw, zaaz, _kuby_,
   {{0xa3d91782,0xdd8f917b,0x15f80e04,0x3860010d}},	//   ावत_, _еш_, ंगार_, _apir_,
   {{0x394d917c,0x7dde01f4,0xc27b0070,0x4432917d}},	//   ües_, tësu, ארטי, ksy_,
   {{0x320a00d5,0x80da0033,0x661701ed,0xac940382}},	//   _luby_, _বৃত্, _stxk, _фалш,
   {{0x7dde00da,0x44320173,0x81c00033,0x8cc5018d}},	//   rësu, dsy_, ুতি_, ापरो,
   {{0x7bda917e,0x9f5e0248,0x7a020228,0x386001e9}},	//   motu, _cité_, _vētr, _epir_,
   {{0x7bda917f,0xb88600b8,0x2b4e0176,0xdb1a00a2}},	//   lotu, _spíš, _hcfc_, dité,
   {{0x7dde00da,0xe4502ac4,0xdb010037,0xddda6ce6}},	// [a030] qësu, فضل_, mhlá, _artū,
   {{0x7bda9180,0xa3b30035,0x68ed9181,0x47351303}},	//   notu, जों_, _izad, _ьнос,
   {{0x7bc89182,0x69cd093a,0x752d2206,0x3e4e013b}},	//   indu, _kjae, paaz, _xətt_,
   {{0xa1599183,0x764701d5,0xfc4600ac,0x7bda0328}},	//   раду_, mujy, _čínu_, hotu,
   {{0x7bda1667,0x7a08007e,0x1958016b,0x00000000}},	//   kotu, _děti, מבאל_, --,
   {{0x8cdc0299,0x65aa0187,0x63a70124,0xdb1a534f}},	//   _पड़ो, _výhe, _uljn, bité,
   {{0x35f80148,0xdb1a0248,0x80da0083,0x7bda9184}},	//   _خرید_, cité, _বৃদ্, dotu,
   {{0xa2b8164f,0x7bc884a3,0xd0d501d3,0x8db500d8}},	//   ्पर्, endu, _добъ, ўскі,
   {{0x6d49006e,0x320a0187,0x212f03d0,0x77ab00a8}},	//   rgea, _zuby_, magh_, _müxb,
   {{0x212f0284,0x6d4901a6,0xdfdb02fb,0xa49b0103}},	//   lagh_, sgea, _съб_, _ngòm,
   {{0x68ed01c2,0x00000000,0x00000000,0x00000000}},	//   _azad, --, --, --,
   {{0x44322075,0x7bc80d18,0x00000000,0x00000000}},	//   ysy_, andu, --, --,
   {{0xa3d90ca1,0x69cd012f,0x629e004e,0xa2e64532}},	//   ावा_, _djae, zypo, _कर्ज_,
   {{0x212f009e,0x7c249185,0x68ed005f,0x6b8300d4}},	//   hagh_, _çira, _dzad, _unng,
   {{0x672e9186,0xa50a1d6b,0x44320035,0x68ed018e}},	//   rabj, иева_, wsy_, _ezad,
   {{0x44329187,0xdb1a02e1,0x38600010,0xdb010037}},	//   tsy_, vité, _tpir_, chlá,
   {{0x212f9188,0xe3ba5811,0x290500b8,0x321803bc}},	// [a040] dagh_, аба_, ělat_, _stry_,
   {{0x4432004e,0x21220726,0xdb1a0e8c,0x629e088a}},	//   rsy_, मर्श_, tité, typo,
   {{0x63be046a,0x7a080355,0x82660079,0x00000000}},	//   ripn, _pěti, تهان, --,
   {{0x00e60002,0xdb1a9189,0x212f0211,0x7bda002f}},	//   ожен, rité, gagh_, zotu,
   {{0x7bc80093,0x7bda0054,0xdb1a918a,0x7ae31c9b}},	//   yndu, yotu, sité, _lynt,
   {{0x2d99918b,0x63be0031,0x27170355,0x8fa30d15}},	//   ösen_, qipn, mění_, маче,
   {{0x59ca112b,0xf8bf000d,0x7bda918c,0xe1661c64}},	//   ाचार, mbée_, votu, _ودري,
   {{0x6ebe00b4,0x5f76006c,0xdc1e0033,0xb4db01f7}},	//   _वेणु, _ڈائر, _দিবস_, _icàr,
   {{0xc5f31759,0x6eda06bc,0x7bda918d,0x271701c0}},	//   ודה_, _पुरु, totu, nění_,
   {{0xa3ea051d,0x6d9c076c,0x68ed0035,0xdfa60079}},	//   मति_, _réau, _rzad, _بحري,
   {{0x7ae30297,0x7bda918e,0x68e4918f,0x6d9c000d}},	//   _cynt, rotu, _ayid, _béat,
   {{0x6d9c0079,0x7ae300fe,0x7bda9190,0x00000000}},	//   _céat, _dynt, sotu, --,
   {{0x7bda9191,0xddc80009,0xa3ea074f,0x32040176}},	//   potu, _krdž, मता_, _mimy_,
   {{0x271700b8,0xdb010037,0xc6a754d3,0x7ae31808}},	//   dění_, shlá, орби, _fynt,
   {{0x7ae3001e,0x387e00ea,0xa3d900ab,0xed5901a0}},	//   _gynt, ātra_, ावस_, liža_,
   {{0xdb0100be,0x00000000,0x00000000,0x00000000}},	//   gilõ, --, --, --,
   {{0x5fbc000c,0x6d9c0037,0x68ed22ca,0xcd9700a5}},	// [a050] ्चाल, _héas, _uzad, קדמת_,
   {{0x69dd9192,0xd37100ad,0xdb0802d7,0x28c831d7}},	//   lose, عها_, midó, रपरि,
   {{0x212f00d7,0xdb010196,0xc3240033,0x65a300be}},	//   tagh_, silö, _পাখি_, _jõhk,
   {{0xe0d301ca,0xa3d93272,0x6b980c71,0xc6920070}},	//   وزش_, ावह_, _lovg, _נאכ_,
   {{0x2909011e,0x212f9193,0x65a300ab,0x6d9c0079}},	//   _mgaa_, ragh_, _lõhk, _léas,
   {{0x1b2200c8,0xd00e11cf,0x69dd9194,0x62350c9f}},	//   _মাঝে_, دلو_, hose, _негу,
   {{0x69dd61f8,0xc22500b5,0x00000000,0x00000000}},	//   kose, _رکاو, --, --,
   {{0xdceb0484,0x29095589,0x9f4c0176,0x7f9d0176}},	//   _jogħ, _ngaa_, _bidó_, _rèqu,
   {{0x65a30006,0x7ae3342a,0xcc350037,0xdceb9195}},	//   _põhj, _synt, أربع, _bagā,
   {{0x5ba93e25,0xdceb048c,0x7ae30d51,0x26d302d7}},	//   ском_, _logħ, _pynt, _oxxo_,
   {{0x539c0070,0xe9da2a66,0x7a1300af,0x6b98023a}},	//   ייזו, йко_, _băta, _dovg,
   {{0x20050657,0x69dd0c6f,0x186a10be,0x200d0118}},	//   _hili_, gose, бами_, _kuei_,
   {{0xda0b0f8a,0x6d5b002f,0x20059196,0x7ae33c30}},	//   _सूरत_, mfua, _kili_, _wynt,
   {{0x8c1a011d,0x2005002f,0xa2d401c0,0x212d009e}},	//   _הוסי, _jili_, _बुझ्, _leeh_,
   {{0x20057b0b,0xcb120122,0xf1db00b4,0x69dd3599}},	//   _mili_, _אלו_, यकान, bose,
   {{0xf9920642,0x20059197,0x7bc19198,0x25f50084}},	//   _سبب_, _lili_, lilu, ्दगी_,
   {{0x02c410aa,0x68e40027,0xddc100ea,0xb4db009e}},	// [a060] वप्न, _uyid, _aplū, _scàr,
   {{0x645635a1,0x61d407df,0x287b00a5,0x7bc1145d}},	//   rtyi, धक्ष, _פנימ, nilu,
   {{0x479b00c2,0x179b02b5,0x51860336,0x6d9c0079}},	//   _הייס, _הייב, зула, _méar,
   {{0x6d9c004f,0x7bc19199,0x80da0083,0xddc80506}},	//   _léar, hilu, _বৃষ্, _srdž,
   {{0xd12f0a9b,0x20053f4c,0x752440e9,0x7bc1919a}},	//   امه_, _bili_, mbiz, kilu,
   {{0x200501d2,0x46db0722,0xb60200b8,0x6d9c0098}},	//   _cili_, _मुँह, žáda, _néar,
   {{0xa3d90429,0x20052922,0x69dd306e,0x752401ed}},	//   ावर_, _dili_, yose, obiz,
   {{0x66060484,0x77ab0095,0xdceb919b,0x6d9c0037}},	//   _jikk, _müxa, _xogħ, _réas,
   {{0x200515a1,0x6d9c0037,0x6606919c,0x44200359}},	//   _fili_, _béar, _mikk, npi_,
   {{0x0b8a03ad,0x6d9c0037,0x6606919d,0x7bc124ff}},	//   ссии_, _céar, _likk, gilu,
   {{0x6d9c0037,0x46db0324,0x200d01a3,0x68e800a8}},	//   _déar, _मुंह, _zuei_, əddi,
   {{0xdb1a6e8d,0x7524007a,0x6d9c05c9,0x4420919e}},	//   mití, jbiz, _véas, kpi_,
   {{0x7bc133d1,0x20051008,0x588700d8,0xdb1a27d0}},	//   bilu, _yili_, чына, lití,
   {{0x2005919f,0x6d9c0079,0x64448a5a,0xdb0801ef}},	//   _xili_, _géar, drii, ridó,
   {{0x6a13004f,0x69dd91a0,0xe3c40033,0x660691a1}},	//   _كبير, pose, ্তাব, _bikk,
   {{0x66060332,0x644472fe,0x00000000,0x00000000}},	//   _cikk, frii, --, --,
   {{0x660691a2,0xa3d90006,0x53991397,0x4420067f}},	// [a070] _dikk, ावल_, овая_, gpi_,
   {{0x33740043,0x660652ff,0x9f5e00fe,0x8c1b00a5}},	//   нгур, _eikk, _bití_, צובי,
   {{0xdb0101ae,0x442091a3,0x6444081b,0x35f51c80}},	//   chlä, api_, arii, _опор,
   {{0x6444007c,0x200591a4,0x7bc191a5,0x77770024}},	//   brii, _sili_, zilu, _haxx,
   {{0x200d02fb,0x20050657,0x3ce6006d,0x7777003c}},	//   _quei_, _pili_, _nyov_, _kaxx,
   {{0xdee5191f,0xedf705f7,0xdb1a0037,0x1fa900af}},	//   моли, ुद्ध_, antú, юкли_,
   {{0x7bc1003c,0x44390118,0xdb0300ac,0x3cff0099}},	//   vilu, _hvs_, _plní, शेने_,
   {{0x4c853869,0x2005010d,0x6d9c0079,0x7db4010b}},	//   длив, _wili_, _séar, есьц,
   {{0x200591a6,0x7bc191a7,0x752f0035,0xd6d90067}},	//   _tili_, tilu, _mecz, ęły_,
   {{0x752f004e,0x7777009f,0x44390510,0xdb1a00d5}},	//   _lecz, _naxx, _mvs_, bití,
   {{0xd9462a25,0x7bc191a8,0x442006a2,0x69030095}},	//   мени, rilu, zpi_, ətdə,
   {{0x442091a9,0x442b0118,0xc7a900a5,0x00000000}},	//   ypi_, _owc_, _דב_, --,
   {{0x6d9c004f,0x7bc10043,0x660691aa,0x7777035f}},	//   _téar, pilu, _rikk, _baxx,
   {{0x66060568,0x7777027a,0x75246581,0x80da0033}},	//   _sikk, _caxx, wbiz, বেক্,
   {{0x66061246,0x66e391ab,0x7a0801c0,0x442b5a1b}},	//   _pikk, вора, _děts, _awc_,
   {{0x3dcd035f,0x64442933,0x443925d7,0x442b91ac}},	//   nnew_, trii, _bvs_, _bwc_,
   {{0xdb1a6764,0x3ce6006f,0xa3d90099,0x752491ad}},	// [a080] zití, _xyov_, ावं_, rbiz,
   {{0x443991ae,0x644491af,0xf7720647,0x6606718e}},	//   _dvs_, rrii, _شاخ_, _wikk,
   {{0x660691b0,0x6444007c,0xdce900f4,0x4256022b}},	//   _tikk, srii, bdeć, ьтат,
   {{0x442091b1,0x644491b2,0x6d9c0118,0x00000000}},	//   ppi_, prii, _néap, --,
   {{0xd7d20569,0x44390160,0x2f180bfc,0xd4361301}},	//   _सदाच, _gvs_, поль_, _تعجب,
   {{0x43751ce8,0x7d0b03d0,0x68eb03d0,0x00000000}},	//   _пуст, _aggs, _øgde, --,
   {{0x7c2b001e,0xa3db0785,0x63a391b3,0x00000000}},	//   _awgr, डकर_, önne, --,
   {{0x65a30006,0x5c74144b,0xdb1a3e90,0xdd900037}},	//   _põhi, елит, rití, اوة_,
   {{0xfc3f0187,0x2126325b,0x673e0207,0x00000000}},	//   šín_, mboh_, _odpj, --,
   {{0x7d0b03d0,0x7ac60c06,0x00000000,0x00000000}},	//   _eggs, дсме, --, --,
   {{0xa3b62fa9,0x3ddf0120,0x2d9a000d,0x2482008c}},	//   _जतन_, bouw_, êpes_, _lrkm_,
   {{0x9e650332,0x23780260,0x00000000,0x00000000}},	//   _سامن, _larj_, --, --,
   {{0xdb1a021d,0x00000000,0x00000000,0x00000000}},	//   ritâ, --, --, --,
   {{0xead413ad,0x2cb0037a,0x65a300be,0x77770024}},	//   _поль, ıldı_, _jõhv, _qaxx,
   {{0xbd050248,0xf8ae0416,0x442b00fe,0x9419013b}},	//   _théâ, لکی_, _swc_, əyəm_,
   {{0xfaa700d1,0x65aa007e,0xdb1a0392,0x96f805a1}},	//   _تجهی, _dýho, lità, фест_,
   {{0x94ab0560,0xdb0a0176,0x245800c3,0x63ae00ac}},	// [a090] цтва_, _alfé, мать_, _blbn,
   {{0x443991b4,0x08f807f6,0xdb1a0443,0x7c2d0448}},	//   _vvs_, _غريب_, nità, _çare,
   {{0x69cf0036,0x98a00207,0x00000000,0x00000000}},	//   once, _peić_, --, --,
   {{0x77b0013c,0x442b4c9d,0x34951888,0xd1b8186e}},	//   _växe, _twc_, _замр, وانا_,
   {{0x6d9c000d,0x656d08c7,0x251a1804,0x00000000}},	//   _réap, meah, _מורא, --,
   {{0xf41f00c3,0xa3ea022e,0x25a97805,0x00000000}},	//   _itä_, मतः_, lkal_, --,
   {{0x644d913c,0x9ea90b3a,0x5214010b,0xc2930987}},	//   luai, явка_, _адст, _جیاب,
   {{0x25a9053e,0x69cf91b5,0xf41f01ff,0x2ba7007e}},	//   nkal_, jnce, _träd_, गस्थ,
   {{0x644d91b6,0x3ddf01e4,0x25a901ed,0x00000000}},	//   nuai, rouw_, ikal_, --,
   {{0x69cf20ac,0x3dcd03da,0x00000000,0x00000000}},	//   ence, snew_, --, --,
   {{0x25a90332,0xf8c802e4,0xfaa55159,0x644d0037}},	//   kkal_, रप्प, хано, huai,
   {{0x9f470187,0x65a300ab,0xf2d20070,0x9f5e021d}},	//   dlné_, _kõhu, רעט_, _titã_,
   {{0x2904312a,0x00000000,0x00000000,0x00000000}},	//   äma_, --, --, --,
   {{0x644d91b7,0x2d9d91b8,0xdb1a0310,0x69cf91b9}},	//   duai, _howe_, cità, ance,
   {{0x2d9d00bf,0x7a0900b8,0x8b56016b,0x25b2024b}},	//   _kowe_, _větr, _ניקס_, thyl_,
   {{0x65aa0076,0xdb1a0784,0x644d0037,0x2d9d0118}},	//   _výho, pitã, fuai, _jowe_,
   {{0xd4675051,0x04431c1b,0xdb1a7af3,0x644d91ba}},	// [a0a0] ните_, летн, litá, guai,
   {{0x69c691bb,0x213f09df,0x32d61e5b,0xdb010079}},	//   like, _aduh_, нцес, dhlú,
   {{0xdb1a4743,0x8146004f,0xb1463a52,0xcb12016b}},	//   nitá, فنان, енел, אלב_,
   {{0x2d9d004e,0x65b10044,0x9f5e0069,0x644d91bc}},	//   _nowe_, _påhe, _sità_, buai,
   {{0x644d0a4e,0x237802d7,0x00000000,0x00000000}},	//   cuai, _tarj_, --, --,
   {{0x69c691bd,0x7bcf000d,0x753622ca,0x7a130160}},	//   hike, écul, layz, _pătl,
   {{0x765c2286,0x412a0b46,0x614603fa,0x9e066a18}},	//   ntry, _ново_, _пева, нчил,
   {{0xc6930052,0x7c240644,0x2c2600d4,0xdb1a91be}},	//   ראה_, _çirk, ньог, ditá,
   {{0x61e291bf,0x69c691c0,0x764e011e,0x2d9d0b88}},	//   mool, dike, huby, _dowe_,
   {{0x61e26e4d,0x765c004e,0x764e1815,0x3e7100ee}},	//   lool, ktry, kuby, _fšt_,
   {{0x69c691c1,0xdb1a91c2,0x3f8c91c3,0x25a991c4}},	//   fike, gitá, _indu_, ykal_,
   {{0x248091c5,0x69c691c6,0x765c91c7,0xed5a91c8}},	//   kvim_, gike, dtry, _ход_,
   {{0xfbcf00d1,0x644d0f84,0xe78500b5,0x3f9e7c45}},	//   شتی_, xuai, پلزپ, _kotu_,
   {{0x8c1b0779,0x61e291c9,0x764e01d5,0x36d56cab}},	//   _צווי, hool, fuby, вогр,
   {{0x61e291ca,0x61eb0602,0x69c691cb,0xdb1a7af3}},	//   kool, ylgl, bike, citá,
   {{0x644d91cc,0x3f9e91cd,0xf0a60019,0x1dd006bc}},	//   tuai, _lotu_, _đành_, तचित,
   {{0x798d0657,0x656d6242,0x261119b7,0x61e291ce}},	// [a0b0] _inaw, reah, _दूरी_, dool,
   {{0x25a94634,0x644d02a8,0x386991cf,0x65a300ab}},	//   skal_, ruai, _ipar_, _rõhu,
   {{0x644d20fb,0x325508a6,0x27e301e9,0x9f45009e}},	//   suai, твер, mojn_, _ghlù_,
   {{0x27e391d0,0x3f8c91d1,0x61e2030d,0x24720260}},	//   lojn_, _andu_, gool, _fņm_,
   {{0x7aea91d2,0x2ec901d1,0x798d91d3,0x3f9e361c}},	//   _lyft, िप्त, _mnaw, _botu_,
   {{0x27e37d81,0x69c691d4,0x10a20274,0xdb1a03db}},	//   nojn_, zike, ришн, litæ,
   {{0x61e2001c,0x69c691d5,0x6115010b,0x2d9d0069}},	//   bool, yike, _адбу, _powe_,
   {{0xfc3f024e,0x61e291d6,0xdb1a7b10,0x65a300ab}},	//   ším_, cool, vitá, _tõhu,
   {{0x69c691d7,0x2a6700d7,0x27e30031,0x3f9e0176}},	//   vike, _spnb_, kojn_, _fotu_,
   {{0x09ca0429,0x798d91d8,0x2d9d0010,0x69c6007b}},	//   ाच्य, _anaw, _wowe_, wike,
   {{0x2fc791d9,0x3869002d,0x27e301e9,0x798d0090}},	//   ming_, _apar_, dojn_, _bnaw,
   {{0xdb1a6016,0xf8bf081d,0x23a40523,0x798d00e5}},	//   ritá, rbén_, _höjt_, _cnaw,
   {{0x2fc71c91,0x69c614bc,0x00000000,0x00000000}},	//   oing_, rike, --, --,
   {{0x69c615d6,0x7c3b91da,0x27e30055,0x764e04fb}},	//   sike, msur, gojn_, tuby,
   {{0x66e6280a,0x480791db,0x3ea7001e,0x2c190083}},	//   това, терн_, nynt_, _দিয়ে_,
   {{0x2fc791dc,0x7d1b35b9,0xceb202b8,0x765c1e54}},	//   hing_, ncus, ביל_, rtry,
   {{0x2fc791dd,0xe8fa0133,0x69c40035,0x7c3b11f0}},	// [a0c0] king_, _юли_, _imie, nsur,
   {{0x7c3b348b,0x69c40024,0xf83700a5,0xdceb013a}},	//   isur, _hmie, _שנית_, _angī,
   {{0x2fc791de,0x61e291df,0x24800a78,0x7c3b0a4e}},	//   ding_, tool, svim_, hsur,
   {{0x3ea7001e,0x248d0c99,0x7c3b00b9,0x2fc7633a}},	//   dynt_, _šeme_, ksur, eing_,
   {{0x2056036c,0x61e2007c,0x7d1b02d7,0x248000a8}},	//   ттер, rool, dcus, qvim_,
   {{0x2fc791e0,0x61e291e1,0x35c8046c,0xa3b601c0}},	//   ging_, sool, _रगड़, _जति_,
   {{0x61e21ad8,0x8fa30274,0x69c491e2,0x44220a8a}},	//   pool, раје, _omie, _htk_,
   {{0x44220054,0x21a3021d,0x69d601d5,0x27e30055}},	//   _ktk_, _кисм, _njye, zojn_,
   {{0x2fc76c97,0xe8170953,0x7aea013c,0xa3b6045c}},	//   bing_, _धंधा_, _syft, _जता_,
   {{0x2fc77daa,0x69c46a8d,0x7d1b0036,0xef830166}},	//   cing_, _amie, acus, _клуп,
   {{0x38698999,0x19591482,0x7c3b91e3,0x23a4017b}},	//   _spar_, наны_, asur, _höjs_,
   {{0x7c3b1a48,0x79a709c0,0x200c0054,0x9f450359}},	//   bsur, трое, _hidi_, _aklè_,
   {{0x27e391e4,0xa3e200ab,0x7bc30176,0x6d4201ed}},	//   tojn_, दवा_, _fmnu, _idoa,
   {{0x656691e5,0x7c220010,0x69c40223,0x00000000}},	//   _abkh, _itor, _emie, --,
   {{0xf8bf00c9,0x200c91e6,0x442240c5,0x27e30031}},	//   mbém_, _midi_, _atk_, rojn_,
   {{0x7c2266fb,0x798d91e7,0x2fc791e8,0x200c00b8}},	//   _ktor, _unaw, zing_, _lidi_,
   {{0x2fc70052,0x26da91e9,0x386991ea,0x44f500af}},	// [a0d0] ying_, _expo_, _upar_, упас,
   {{0x68ed0371,0x69c491eb,0x61db2177,0x02a700d4}},	//   _iyad, _zmie, यक्ष, крем,
   {{0x2fc791ec,0x9f5e03ad,0x75d52604,0xf53f0b3e}},	//   ving_, _mitä_, _ميدا, _blåt_,
   {{0xc692012b,0x7c2291ed,0x2fc791ee,0xdb1a91ef}},	//   _האט_, _otor, wing_, litä,
   {{0x2fc791f0,0x7bc891f1,0x3ea700e9,0x7c2291f2}},	//   ting_, kidu, wynt_, _ntor,
   {{0x657d2f89,0xfc3f024e,0x200c0051,0xdb1a91f3}},	//   _hash, šík_, _cidi_, nitä,
   {{0x7c2291f4,0x657d91f5,0x200c0118,0x6e950ad9}},	//   _ator, _kash, _didi_, العا,
   {{0x657d01d2,0x7c3b22fb,0xc1050934,0xf2d2011d}},	//   _jash, tsur, _موزي, _העל_,
   {{0x2fc791f6,0x657d5f09,0x7c3b137d,0x68ed91f7}},	//   ping_, _mash, usur, _nyad,
   {{0xa3d91e79,0x7d1b844e,0x7c3b91f8,0x657d91f9}},	//   ावट_, scus, rsur, _lash,
   {{0x68ed009e,0x7c220291,0x61fb91fa,0x7c3b1c86}},	//   _ayad, _etor, _khul, ssur,
   {{0x657d91fb,0xdea30332,0x7c3b0395,0x68ed4296}},	//   _nash, _میڈی, psur, _byad,
   {{0x8c4505c2,0x7bc891fc,0x2d8f0d51,0x61fb0874}},	//   _селе, bidu, _inge_, _mhul,
   {{0x44220031,0x628703d0,0x7bc30bf7,0x00000000}},	//   _rtk_, _orjo, _umnu, --,
   {{0x657d91fd,0x442291fe,0x61e991ff,0x68ed073a}},	//   _bash, _stk_, _okel, _eyad,
   {{0x69c49200,0x60db0095,0x44229201,0x61e90069}},	//   _umie, _oxum, _ptk_, _nkel,
   {{0x62879202,0x81cc0083,0x657d1b00,0xa49b01da}},	// [a0e0] _arjo, রকম_, _dash, _sgòr,
   {{0x550307f5,0x61fb01a3,0xf53f0523,0x28970277}},	//   спуб, _ahul, _blås_, _עדין_,
   {{0x200c027a,0x61e90069,0x61fb0767,0x2d8f9203}},	//   _ridi_, _bkel, _bhul, _onge_,
   {{0x657d9204,0x61fb9205,0x22470187,0x200c00a2}},	//   _gash, _chul, ánka_, _sidi_,
   {{0x261a0992,0x61fb08c7,0x4422128f,0x8fa63de2}},	//   _मंडी_, _dhul, _utk_, ладе,
   {{0x2d8f9206,0xa2e608bb,0x657d04fb,0xf41f0107}},	//   _ange_, _богд, _zash, _krän_,
   {{0x200c0500,0x657d0232,0x61fb04e6,0x1eaa0413}},	//   _vidi_, _yash, _fhul, عاتي_,
   {{0x9f5e03ad,0x7bc80035,0xdb1a033b,0x91e62c3c}},	//   _sitä_, widu, zitä, _собе,
   {{0xf53f9207,0x00000000,0x00000000,0x00000000}},	//   _klår_, --, --, --,
   {{0x9986010b,0x29129208,0x2d8f9209,0x9f5e0282}},	//   kslų_, _agya_, _enge_, _bitå_,
   {{0x7bc83f04,0xdb1a01ae,0x68ed012f,0x7c220035}},	//   ridu, vitä, _syad, _wtor,
   {{0x7bc8920a,0x2eb000c0,0x00000000,0x00000000}},	//   sidu, जनीत, --, --,
   {{0x7c22920b,0x7bc8920c,0x00000000,0x00000000}},	//   _utor, pidu, --, --,
   {{0x2912018e,0x00000000,0x00000000,0x00000000}},	//   _egya_, --, --, --,
   {{0x657d920d,0xdb1a920e,0x8b6500f8,0x9f8b00be}},	//   _pash, ritä, _خانم, _töös_,
   {{0x657d01e9,0xca47004f,0xdb1a233b,0x29120103}},	//   _qash, _إليه_, sitä, _ggya_,
   {{0x657d920f,0xdb1a112d,0xdce200ac,0xf53f7808}},	// [a0f0] _vash, pitä, _oboč, _slås_,
   {{0x61fb0657,0x657d5eee,0x61e989fb,0x7e7a9210}},	//   _shul, _wash, _skel, _ostp,
   {{0x657d9211,0x56950814,0x92590086,0x61fb5794}},	//   _tash, _тант, тает_, _phul,
   {{0x657d1eec,0x2a57016b,0x77b00282,0x00000000}},	//   _uash, רבאן_, _läxl, --,
   {{0x752d289f,0xf53f0a8a,0x799d0051,0x9f4700ac}},	//   mbaz, _flår_, ijsw, slní_,
   {{0x3f699212,0x644d01a6,0x9f470187,0x661701a3}},	//   тико_, mrai, plní_, _kuxk,
   {{0xfd11004f,0x644d26c9,0x660f3f36,0x67370024}},	//   يجة_, lrai, _kick, _mexj,
   {{0x1c4507c7,0xada500c3,0x644d009d,0x61fb021d}},	//   аним, раил, orai, _uhul,
   {{0x644d006e,0x442950e0,0xdb0a0176,0xdb1801ff}},	//   nrai, npa_, _alfà, _omvä,
   {{0x44299213,0x5ba9748e,0x7ff70037,0x644d00a2}},	//   ipa_, тком_, _إسرا, irai,
   {{0x644d7cf9,0x44290381,0x317f007e,0x00000000}},	//   hrai, hpa_, _kauz_, --,
   {{0x2d8f0d48,0x09e61108,0x660f9214,0x644d16de}},	//   _unge_, ромн, _nick, krai,
   {{0xac2700af,0x00000000,0x00000000,0x00000000}},	//   _сфек, --, --, --,
   {{0x644d174e,0x7c291425,0x261a0141,0xdcfb00cd}},	//   drai, mper, _मंदी_, nduč,
   {{0xe73717c2,0x45369215,0x44292b26,0x644d405f}},	//   рес_, ихат, epa_, erai,
   {{0x644d9216,0xf53f0b87,0xa5260714,0x6d9c0118}},	//   frai, _slår_, рмад, _béay,
   {{0x660f9217,0x644d9218,0xb4252e36,0x7c299219}},	// [a100] _dick, grai, معلو, nper,
   {{0xcb1202b5,0xdb010c71,0xdcfb011c,0xe3b72449}},	//   ַלד_, rklæ, jduč, абу_,
   {{0x673c921a,0x644d09c3,0x4429921b,0x660f921c}},	//   marj, arai, apa_, _fick,
   {{0x644d921d,0x442900d7,0x644b1c98,0x673c921e}},	//   brai, bpa_, ágic, larj,
   {{0x66040d4c,0x644d8888,0x261c002a,0xc05a00af}},	//   mmik, crai, _hío_, трец_,
   {{0x673c921f,0x66049220,0x7c299221,0xa3ca22a7}},	//   narj, lmik, dper, _ऋषि_,
   {{0x2eb00387,0x7c292b09,0xe2979222,0x00000000}},	//   जनेत, eper, _кар_, --,
   {{0x91e30610,0x673c693b,0x261c0831,0xef180029}},	//   _досе, harj, _mío_, _daļa_,
   {{0x673c9223,0x261c0300,0x7c29108c,0x7a130139}},	//   karj, _lío_, gper, _mătu,
   {{0xeb069224,0x673c7982,0xdb0a4e1c,0xed59011c}},	//   ично, jarj, _alfá, dižu_,
   {{0x673c9225,0xdb0101ae,0xdee6081b,0x77b001ff}},	//   darj, chlü, _тожи, _växl,
   {{0x44299226,0x7c290069,0x644d00e9,0x67370051}},	//   ypa_, bper, yrai, _sexj,
   {{0xf7730c74,0xa3b6022e,0x98b20107,0x05770088}},	//   ياس_, जसा_, _feyč_, یارد,
   {{0x644d1010,0x261c9227,0x673c9228,0xdb01033b}},	//   vrai, _bío_, garj, fklä,
   {{0x660f9229,0x644d3f14,0x6b9c0093,0x7a1300af}},	//   _pick, wrai, örgu, _bătu,
   {{0x644d922a,0x48ab034b,0xd5b809a7,0x3860035f}},	//   trai, _атом_, асу_, _fqir_,
   {{0x752d922b,0x644d1b57,0x673c8d08,0xdb010037}},	// [a110] rbaz, urai, barj, bhló,
   {{0x644d922c,0x4429922d,0x261c0042,0x660f06c6}},	//   rrai, rpa_, _fío_, _wick,
   {{0x644d5c8f,0x660f922e,0x7c29922f,0x660435df}},	//   srai, _tick, zper, bmik,
   {{0xf595004f,0x2eb03100,0x48fe000c,0x32180051}},	//   _الحج, जनैत, रेको_, _dury_,
   {{0x70220033,0xe0d00413,0xf41f017b,0xf8bf00f6}},	//   _নিউজ_, وزه_, _kräm_, nzé_,
   {{0x9f4700da,0x7c290207,0x32180147,0x00000000}},	//   monë_, vper, _fury_, --,
   {{0x7c290223,0x87b8016b,0x98ab0067,0x00000000}},	//   wper, שלוס_, racę_, --,
   {{0x7c299230,0x98b202d0,0x673c279c,0x9f4500f1}},	//   tper, _seyč_, zarj, _chlò_,
   {{0xb4f50d00,0x7c290176,0xf99f02d0,0x00000000}},	//   _आरोप_, uper, djè_, --,
   {{0x7c2945ad,0xe4fa045c,0x2b5c0176,0x6604629a}},	//   rper, ्धति_, _ccvc_, zmik,
   {{0x673c9231,0x23b6008a,0x6604081b,0x00000000}},	//   varj, _jæja_, ymik, --,
   {{0x261c9232,0x7c299233,0x3e610093,0x00000000}},	//   _río_, pper, mót_, --,
   {{0x673c9234,0xa2f400a1,0x3e6100b5,0xd2f401c0}},	//   tarj, _अर्ज_, lót_, _अर्ब_,
   {{0x261c0300,0xeb96021d,0xab261e46,0xdca21682}},	//   _pío_, _гиш_, _лоша_, _хаши,
   {{0x66049235,0x673c9236,0x7a130139,0x00000000}},	//   tmik, rarj, _pătu, --,
   {{0xd01f0083,0x673c9237,0xdb0115e8,0x9663010b}},	//   নীয়_, sarj, rklä, яксе,
   {{0x66048c0d,0xdb011193,0x6d9c01ef,0xc9b700a5}},	// [a120] rmik, sklä, _véax, _להקת_,
   {{0x66049238,0x261c0b4c,0x2a6e02d7,0xe29a11ab}},	//   smik, _tío_, _ypfb_, лаз_,
   {{0x9f4c0028,0xdb1a043f,0x5b3a0070,0xdd110024}},	//   _đoàn_, titú, רגעק, _ażżm,
   {{0x9f4702d0,0x3e6100e4,0x00000000,0x00000000}},	//   lonè_, dót_, --, --,
   {{0x2eb007df,0x00000000,0x00000000,0x00000000}},	//   जन्त, --, --, --,
   {{0xc05902ce,0xdefa0086,0x25b29239,0xd9a50253}},	//   рії_, лый_, lkyl_, _ऑक्ट,
   {{0x877b0070,0xf77300a5,0x00000000,0x00000000}},	//   ראצי, פקה_, --, --,
   {{0x25a0923a,0x6576923b,0x00000000,0x00000000}},	//   njil_, neyh, --, --,
   {{0x5bb80945,0x77b0013c,0xe0da0274,0xdb030107}},	//   илия_, _växj, _сва_, _honè,
   {{0xf8bf02e1,0xdb030107,0x547b076b,0x7f430421}},	//   ncée_, _konè, נטיו, _неуж,
   {{0x77ab0095,0xc33302b8,0x8d860009,0x65760421}},	//   _müxt, הות_, _гулд, keyh,
   {{0xdb0301f4,0x6456923c,0xada3083e,0x00000000}},	//   _zonë, kuyi, _нахл, --,
   {{0xacf60609,0xdb030107,0x99920107,0x25a000e0}},	//   _اسات, _lonè, _miyň_, djil_,
   {{0x7bcf0248,0xda340043,0x6fd8046c,0x00000000}},	//   écut, _декы, भचिं, --,
   {{0x7bca01d5,0x28c5007c,0xf21d00ab,0x00000000}},	//   _imfu, _लइकि, _बूढ़_, --,
   {{0x2d84923d,0x77b00282,0xf9930698,0x00000000}},	//   ndme_, _läxh, _ربع_, --,
   {{0x69cf923e,0x64a403e6,0x3494923f,0x3e6100b5}},	// [a130] mice, паѓа, патр, zót_,
   {{0x261a0035,0xdb030260,0x00000000,0x00000000}},	//   _मूवी_, _bonè, --, --,
   {{0xdb0312c3,0x6275183b,0x02d92402,0x00000000}},	//   _conè, تهائ, جواب_, --,
   {{0x9f4c01a5,0x64569240,0x2cad00d7,0x00000000}},	//   _đoán_, buyi, yyed_, --,
   {{0x3dcd9241,0x8fa51583,0x00000000,0x00000000}},	//   view_, жале, --, --,
   {{0x62350183,0xb4b50387,0x3e6100b5,0x69cf0afb}},	//   _мегу, जनी_, tót_, hice,
   {{0x9989004e,0x2489350b,0x69cf0c6f,0x7a130139}},	//   _miał_, lvam_, kice, _lătr,
   {{0x69cf153b,0x63a70d14,0xec491b81,0x3e619242}},	//   jice, _hojn, азил_, rót_,
   {{0x61eb05e2,0x9f4710af,0xdb0a0282,0x00000000}},	//   mogl, yonè_, _llfä, --,
   {{0x4a45384b,0x61eb9243,0xfbc501e0,0x00000000}},	//   онов, logl, ібно, --,
   {{0xe9da0d54,0x69cf9244,0x63a700ee,0x7a690714}},	//   ико_, fice, _mojn, шинг_,
   {{0x61eb9245,0x69cf9246,0x7a1300af,0x3e4500ea}},	//   nogl, gice, _bătr, mēt_,
   {{0x7a130043,0x30790070,0x3e4500ea,0xdb03000d}},	//   _cătr, באָנ, lēt_, _moné,
   {{0xe73719fa,0xb90200b8,0x63a79247,0x25b9011e}},	//   жер_, _दश_, _nojn, _alsl_,
   {{0x3e4500ea,0x6b832d5f,0xe9a60279,0x9f4700f8}},	//   nēt_, _iang, _макп, goné_,
   {{0x28c53717,0x6d5b1425,0x452a095d,0x6b839248}},	//   _लेकि, ngua, ржан_, _hang,
   {{0x6b831c04,0x61eb9249,0x63a733ee,0x79960371}},	// [a140] _kang, dogl, _bojn, _inyw,
   {{0x6b836072,0x7984924a,0x7c24004f,0xdb030392}},	//   _jang, _haiw, _éire, _ponè,
   {{0x6b83924b,0x79840159,0xdb1a008c,0xe5a610da}},	//   _mang, _kaiw, ritø, _дини,
   {{0x216a2d5a,0x61eb0382,0xdb03924c,0x3e450029}},	//   риди_, gogl, _coné, dēt_,
   {{0x79840dc3,0x6d5b011e,0x92aa0083,0xdb031564}},	//   _maiw, dgua, গছে_, _doné,
   {{0x6b837e2a,0x5f93192f,0x63a70009,0x69cf924d}},	//   _nang, дишт, _gojn, zice,
   {{0xdb1a00da,0x179b0122,0xdb03540c,0x4420924e}},	//   shtë, ייסב, _foné, lqi_,
   {{0x6b83019c,0x61eb02fb,0x79844b6a,0x7524924f}},	//   _aang, cogl, _naiw, nciz,
   {{0x64449250,0x69cf9251,0x628e00d5,0x4420013b}},	//   nsii, vice, _hrbo, nqi_,
   {{0x6b8309df,0x64440086,0x705300bf,0x79969252}},	//   _cang, isii, _آنلا, _anyw,
   {{0x39491bae,0x6b839253,0x3e4500ea,0x261a00ab}},	//   _pdas_, _dang, cēt_, _मूली_,
   {{0x64440086,0x79840051,0x628e9254,0x6b839255}},	//   ksii, _caiw, _mrbo, _eang,
   {{0xdd8f03c7,0x6d409256,0x6b833cdc,0xcdd90070}},	//   _جون_, mama, _fang, _פֿער,
   {{0x6d409257,0xcb6703fa,0x69cf9258,0x6444081b}},	//   lama, _даље_, sice, dsii,
   {{0x69cf9259,0xb5a70dba,0x63a7023a,0x00000000}},	//   pice, орай, _rojn, --,
   {{0x6d40925a,0x6b83925b,0x6444073a,0x24890116}},	//   nama, _zang, fsii, tvam_,
   {{0x6b8305ba,0xb4b505e7,0x61eb925c,0x63a7006f}},	// [a150] _yang, जने_, vogl, _pojn,
   {{0x6d40925d,0xc2e90083,0x2489925e,0x6b83925f}},	//   hama, _কৃষি_, rvam_, _xang,
   {{0x63a70759,0x6d409260,0x2509006c,0x6444001c}},	//   _vojn, kama, _گردی_, asii,
   {{0xf67a00c2,0x1a9b00c2,0x05b9006c,0x63a70035}},	//   _פארמ, ייבע, _اگست_, _wojn,
   {{0x6d409261,0x61eb9262,0x859a0122,0x628e027a}},	//   dama, rogl, _השרו, _erbo,
   {{0x3e450029,0x61eb02a7,0xf8bf01ef,0x00000000}},	//   tēt_, sogl, lbés_, --,
   {{0x442b31b7,0x44399263,0x31352ab4,0x628e011c}},	//   _htc_, _hws_, _невр, _grbo,
   {{0x753d006a,0x44390189,0x7bda9264,0x3e450029}},	//   _jesz, _kws_, entu, rēt_,
   {{0x6b839265,0x6d5b9266,0x00000000,0x00000000}},	//   _pang, rgua, --, --,
   {{0x69dd1010,0x753d1f11,0x442b0176,0x6d5b50a1}},	//   éren, _lesz, _mtc_, sgua,
   {{0x656f114d,0x6b839267,0x44399268,0x6d409269}},	//   _obch, _vang, _lws_, bama,
   {{0x6b83926a,0x6d400e98,0x644402ee,0x7bda0086}},	//   _wang, cama, ysii, antu,
   {{0x44391020,0x7bda01e8,0x3f85926b,0x442b4605}},	//   _nws_, bntu, _kalu_, _ntc_,
   {{0x61a80567,0x6b83926c,0x3f850088,0x78a900ab}},	//   _कक्ष, _uang, _jalu_, äeva,
   {{0x4439926d,0x753d0332,0xcf9202b5,0x7aee0097}},	//   _aws_, _besz, עטל_, čité,
   {{0x3f850224,0x64443115,0x442b926e,0xe5a37e81}},	//   _lalu_, tsii, _btc_, ниси,
   {{0x39420006,0x628e39bb,0x7524926f,0xa5072b34}},	// [a160] maks_, _srbo, rciz, зета_,
   {{0x6d409270,0x64449271,0xb9039272,0x44209273}},	//   zama, rsii, _язык, rqi_,
   {{0x6444073c,0x442b8d52,0x6d4b1b86,0x753d006c}},	//   ssii, _etc_, _odga, _fesz,
   {{0x6d40002a,0x80cd018d,0x44399274,0xe1f20372}},	//   xama, _देहे, _fws_, رسا_,
   {{0x6d409275,0x3f859276,0x442086c4,0x661e00ee}},	//   vama, _balu_, qqi_, _hupk,
   {{0x6d4b054e,0x6d400ce7,0x3942007c,0x68f60086}},	//   _adga, wama, haks_, _myyd,
   {{0x59dc060a,0x628e004b,0x7c2b0029,0x3f8509ac}},	//   मचार, _urbo, _atgr, _dalu_,
   {{0xdef90a93,0x3942007c,0x44390221,0x3c2002d0}},	//   цыі_, jaks_, _yws_, _pòv_,
   {{0x6d409277,0x44390189,0x442b5aa5,0x394200ab}},	//   rama, _xws_, _xtc_, daks_,
   {{0x6d409278,0x24820159,0x7bda738a,0x3f854886}},	//   sama, _mskm_, untu, _galu_,
   {{0x21fc01c0,0xb8260083,0x290001e9,0x39429279}},	//   ního_, _বিগত_, _azia_, faks_,
   {{0x6d40927a,0xdb1a018d,0x39421ea6,0x00000000}},	//   qama, litü, gaks_, --,
   {{0x2ac202e1,0x753d2130,0xd5b100e2,0xed5701e0}},	//   _bébé_, _resz, ếm_, _хоч_,
   {{0x44390051,0xf41f0523,0x00000000,0x00000000}},	//   _rws_, _kräv_, --, --,
   {{0xb4b507df,0x661e1a7f,0x5694021d,0x3942927b}},	//   जन्_, _cupk, нарт, baks_,
   {{0x4439099e,0x661e41d8,0x00000000,0x00000000}},	//   _pws_, _dupk, --, --,
   {{0x753d0332,0x443926af,0xdb183113,0x2d861872}},	// [a170] _vesz, _qws_, _alvé, _maoe_,
   {{0x6ad00083,0x442b0019,0x443949ea,0x051d0033}},	//   _সুযো, _vtc_, _vws_, তরের_,
   {{0x753d0332,0x224700b5,0x3f850139,0x00000000}},	//   _tesz, énk_, _ralu_, --,
   {{0x3f85927c,0x443901e8,0x3135311c,0x69dd927d}},	//   _salu_, _tws_, федр, nnse,
   {{0xc5fb0567,0x3f858d92,0x69dd927e,0xc5f904bc}},	//   ्षीय_, _palu_, inse, ंतीय_,
   {{0x69dd3d98,0xdfd10037,0x14080099,0x656d02b1}},	//   hnse, ضيع_, वगृह_, lfah,
   {{0x3f870c99,0x21fc01c0,0x63a3008a,0x3f85927f}},	//   rdnu_, cího_, önnu, _valu_,
   {{0x629a022f,0x69dd01e4,0x656d033b,0xa4c010b1}},	//   _štog, jnse, nfah, nüşü_,
   {{0xfc054697,0x3f854578,0x3942007c,0xf09f00f7}},	//   мпио, _talu_, vaks_, _çà_,
   {{0xdb1a0279,0x76550035,0x656d9280,0x00000000}},	//   ditó, krzy, hfah, --,
   {{0x3942007c,0x2900006c,0x7afd0035,0x8eb50df3}},	//   taks_, _szia_, ęsto, _تماش,
   {{0x7f439281,0x6d4b054e,0x9f5e0176,0xbcb51583}},	//   lanq, _udga, _fitó_, _обещ,
   {{0xe87c036a,0x39424f04,0x656d033b,0x21fc00b8}},	//   _düşü, raks_, dfah, zího_,
   {{0x3942007c,0x661e1e85,0xdb080098,0x00000000}},	//   saks_, _pupk, ghdó, --,
   {{0xdb030187,0xe9d20037,0x7bc122b8,0x7ae3009e}},	//   _koní, _لغة_, mhlu, _uxnt,
   {{0x213f0051,0x9f470176,0x290001b7,0x656d02b1}},	//   _neuh_, doní_, _tzia_, gfah,
   {{0xd4678526,0x04430272,0x39400211,0x261a046c}},	// [a180] мите_, кетн, _ieis_, _मंकी_,
   {{0x672202e4,0x76550067,0x7bc19282,0xdb1a01f7}},	//   _मलिक_, brzy, nhlu, litò,
   {{0xa3af0ccf,0x38cb00bf,0xf8bf13cf,0x5186448c}},	//   _ओकर_, _هایی_, ncén_, дула,
   {{0xbbaa0066,0x20052bab,0x02de0141,0x765c0010}},	//   _चक्क, _ahli_, _मशीन, mury,
   {{0x7bc10464,0x39409283,0x65b10a8a,0x00000000}},	//   khlu, _meis_, _påhv, --,
   {{0x39409284,0x443205d1,0x7bc19285,0xdce000ea}},	//   _leis_, mpy_, jhlu, zemē,
   {{0x443200ee,0x9e06210e,0xdb030392,0x2e4a02fb}},	//   lpy_, мчил, _boní, цяло_,
   {{0xdb031c02,0x248d02c4,0x39409286,0x9f5e0176}},	//   _coní, _šemi_, _neis_, _pitó_,
   {{0x7f430371,0xa06a0272,0xdb0301ef,0x69dd0e8c}},	//   banq, _фаза_, _doní, érem,
   {{0x7bc19287,0x765c9288,0x0a6a7044,0x5a340382}},	//   ghlu, kury, орми_, ннот,
   {{0x59f900d8,0x765c005f,0x3a2052c2,0x68fa00a8}},	//   зеня_, jury, _čips_, ətdi,
   {{0x8d93004f,0x24800a4e,0x69dd0036,0x3940021d}},	//   _للمش, kwim_, unse, _ceis_,
   {{0x69dd9289,0x3940004f,0x7bc101e8,0xc8645f77}},	//   rnse, _deis_, bhlu, ктри,
   {{0x7bc1928a,0x7655004e,0x7d020bc6,0x60040392}},	//   chlu, trzy, _izos, lòmb,
   {{0xdb1a6493,0x394001da,0x656d8c16,0xcc8800e2}},	//   sitó, _feis_, tfah, _hớ_,
   {{0x69d600b5,0x00000000,0x00000000,0x00000000}},	//   ézet, --, --, --,
   {{0x656d02c9,0xe9df01ba,0xa4c005f9,0x64560118}},	// [a190] rfah, mnú_, rüşü_, gryi,
   {{0x765c0010,0x63a5006d,0x76550035,0x656d033b}},	//   bury, ujhn, przy, sfah,
   {{0x77b0013c,0x33f401ff,0xe9df0079,0x7536928b}},	//   _växt, växt_, onú_, bbyz,
   {{0x397c0070,0xe9df342f,0x9f470392,0x00000000}},	//   ַטונ, nnú_, roní_, --,
   {{0x7f43928c,0x660d43ba,0xe4e700d4,0xd46b0037}},	//   tanq, mmak, _цінн, _بحجم_,
   {{0x01c90332,0xe9df004f,0x660d928d,0x3869009f}},	//   _کورٹ_, hnú_, lmak, _mqar_,
   {{0xfe7100d2,0x7f431bea,0xdb034b04,0x7bc10221}},	//   ادت_, ranq, _poní, vhlu,
   {{0x660d928e,0x224705d3,0x4c8505ac,0xcc8800cc}},	//   nmak, ánku_, елив, _bớ_,
   {{0x3940928f,0xe9df016f,0x765c012f,0xcc880023}},	//   _reis_, dnú_, zury, _cớ_,
   {{0x39401fca,0x660d9290,0xdd1d0160,0x00000000}},	//   _seis_, hmak, _fâşi, --,
   {{0xa3b70ccf,0x777c0042,0x660d9291,0x765c0160}},	//   _जवन_, verx, kmak, xury,
   {{0x3ce00a78,0x660d398d,0x7bc19292,0x29d200f4}},	//   _žive_, jmak, shlu, ršao_,
   {{0x39409293,0x777c002a,0x00000000,0x00000000}},	//   _veis_, terx, --, --,
   {{0x3940033b,0x660d9294,0x765c9295,0x7f410069}},	//   _weis_, emak, tury, _jelq,
   {{0x39409296,0xe9df01ba,0x66e39297,0x6e21017b}},	//   _teis_, bnú_, гора, _julb,
   {{0x660d9298,0x3869009f,0x64a6004b,0x00000000}},	//   gmak, _fqar_, наба, --,
   {{0x672102f6,0x765c9299,0x777c2984,0xe406218b}},	// [a1a0] žlja, sury, perx, езап,
   {{0x26cc8c57,0x43860037,0xb4e00099,0x64568962}},	//   údos_, علاق, _तशी_, rryi,
   {{0xdb030176,0xdbc61e7b,0x00000000,0x00000000}},	//   _jonà, _töön, --, --,
   {{0x64a67275,0xe0462701,0x4432929a,0xa06a0036}},	//   _зама, енди, ppy_, зада_,
   {{0x2480046a,0x351b00a5,0x44240160,0x00000000}},	//   qwim_, _מוכנ, _îm_, --,
   {{0x442201ed,0x8fa31956,0xf41f0421,0x6e21929b}},	//   _iuk_, лаче, _eräs_, _bulb,
   {{0x539b0052,0x6e210db4,0xf41f0523,0x00000000}},	//   _צילו, _culb, _fräs_, --,
   {{0x44223bc7,0x6e218c80,0xa7fb02d7,0xf41f017b}},	//   _kuk_, _dulb, muñe, _gräs_,
   {{0x29d26395,0x442200d8,0x63ae00cb,0xe9df01ba}},	//   ršal_, _juk_, _kobn, vnú_,
   {{0x660d0029,0x4f84006c,0x7ac621e2,0x63ae0a8a}},	//   zmak, _جارہ, есме, _jobn,
   {{0x19590104,0x4422929c,0x6e21929d,0x2ec63345}},	//   маны_, _luk_, _gulb, _ثقاف,
   {{0xcc8801a5,0x3ce601e8,0x4422929e,0xdb030176}},	//   _tớ_, _txov_, _ouk_, _donà,
   {{0x442208e3,0xe9df01ba,0x98b802fb,0x00000000}},	//   _nuk_, rnú_, елят_, --,
   {{0xc5fb0bdd,0xe9df3651,0xaa58002d,0x8c1b00a5}},	//   ्ष्य_, snú_, _жику_, _זוגי,
   {{0x4422008a,0x660d929f,0xd5bb32b0,0xf8ae00b5}},	//   _auk_, tmak, пса_, مکی_,
   {{0x7c2200c3,0x00000000,0x00000000,0x00000000}},	//   _kuor, --, --, --,
   {{0x660d92a0,0x4422095f,0x6d4f0079,0x63ae08b7}},	// [a1b0] rmak, _cuk_, ócai, _bobn,
   {{0x442292a1,0x7c220382,0x660d92a2,0x6b8a0069}},	//   _duk_, _muor, smak, _jafg,
   {{0x63ae7e52,0xd1310b82,0xd25000b5,0xd25b002d}},	//   _dobn, لما_, ینے_, яца_,
   {{0xa2d502cb,0x3e4c000c,0x248d02c4,0xdb03163f}},	//   _येण्, dět_, _šemu_, _joná,
   {{0x7c2247ec,0x7f4100da,0xf8b30907,0xdb030042}},	//   _nuor, _pelq, ुनिय, _moná,
   {{0x25a992a3,0x7f410055,0xdb0a0260,0x00000000}},	//   ljal_, _qelq, _tofè, --,
   {{0x442206a2,0xdfce1c64,0x00000000,0x00000000}},	//   _zuk_, تيو_, --, --,
   {{0x25a992a4,0xb0d20907,0x442201cb,0xbbb900dc}},	//   njal_, _देवग, _yuk_, इस्क,
   {{0x7c2201d3,0x1c42010b,0x6d420043,0x70582585}},	//   _cuor, аным, _deoa, _патр_,
   {{0x7c220103,0x2cc70019,0x6e2192a5,0x25a900ab}},	//   _duor, _đtdđ_, _tulb, hjal_,
   {{0x25a92c81,0x6b8a0282,0x00000000,0x00000000}},	//   kjal_, _dafg, --, --,
   {{0x7c2201d3,0x6d42002d,0x62950124,0x645f01e9}},	//   _fuor, _geoa, _mrzo, kuqi,
   {{0xef180029,0xbb850037,0x09e30036,0xdb0392a6}},	//   _daļu_, _للشي, роян, _doná,
   {{0x4422053e,0x5a95846a,0x00000000,0x00000000}},	//   _ruk_, _ариф, --, --,
   {{0x442292a7,0xf7436660,0x63ae01a0,0x7c2202b1}},	//   _suk_, ресо, _robn, _zuor,
   {{0x63ae33c7,0x645f0031,0xdb0300fe,0x00000000}},	//   _sobn, fuqi, _goná, --,
   {{0x62950453,0x63ae006d,0xa8060036,0xa5230384}},	// [a1c0] _arzo, _pobn, _изил, рмуд,
   {{0x44220254,0x600402d0,0x25a900be,0xdb0300d5}},	//   _vuk_, kòma, ajal_, _zoná,
   {{0x200200d8,0xdb03006c,0x6287017b,0xb9930ef2}},	//   _ūkio_, _elnö, _csjo, _صلیب,
   {{0x44221f8a,0x629500d5,0xdb0301ef,0x2c6b08c8}},	//   _tuk_, _drzo, _xoná, kød_,
   {{0x64430c0a,0x69a300a1,0xf1a90037,0x4153093e}},	//   ćnic, गाती, عامه_, рвіс,
   {{0x60040c1f,0x6d42002a,0x2d8d00d7,0x9f8a00be}},	//   fòma, _seoa, edee_, _lööb_,
   {{0x7c2203ad,0x6e940642,0x22164ca7,0x82a3005f}},	//   _suor, البا, _афар, _карж,
   {{0x65640430,0xd657076b,0x00000000,0x00000000}},	//   ngih, דיקת_, --, --,
   {{0x6d4200be,0xdb1a92a8,0x00000000,0x00000000}},	//   _veoa, nitö, --, --,
   {{0x7c220086,0x00000000,0x00000000,0x00000000}},	//   _vuor, --, --, --,
   {{0xdee31d99,0xdea30416,0x5ea61b20,0xa5b30066}},	//   _кофи, _نیوی, _جمال, _इकलौ,
   {{0x61e292a9,0x7c220086,0x3f8c0024,0x6bd7042c}},	//   nnol, _tuor, _hadu_, _یونس_,
   {{0x3f8c92aa,0x7c2d00d0,0x6c545fa1,0x61e2081b}},	//   _kadu_, _çarp, _склу, inol,
   {{0x61e292ab,0x7dde00ea,0xb8cb2907,0x3f8c92ac}},	//   hnol, dīsi, _गप_, _jadu_,
   {{0x8c1b1899,0x3f8c04f6,0xf1b902c6,0xda0700af}},	//   _קווי, _madu_, _hiše_, _ичип,
   {{0x69c602bf,0xf1b90c0a,0xdb1a004f,0xf1bd0033}},	//   chke, _kiše_, chtá, _অদ্ভ,
   {{0x33750021,0x25a992ad,0xa5f81f7e,0x00000000}},	// [a1d0] лгар, rjal_, тету_, --,
   {{0x6564011e,0x798d0103,0xf1b9264f,0x62950035}},	//   agih, _haaw, _miše_, _przo,
   {{0x798d92ae,0x2d8d1413,0x3f8e92af,0x00000000}},	//   _kaaw, ydee_, ddfu_, --,
   {{0x61e292b0,0xfb1502b5,0x3f9e43f3,0x00000000}},	//   gnol, אַנט_, _antu_, --,
   {{0x80cd006a,0x798d08dd,0x3f8c06a2,0x7fd500d8}},	//   _देखे, _maaw, _badu_, лікі,
   {{0xae1b0907,0x62870223,0x644d92b1,0xa5bb002a}},	//   _पूजन_, _tsjo, msai, _bióg,
   {{0x661d92b2,0x3f8c022e,0x44294498,0x2f5400d4}},	//   _kisk, _dadu_, lqa_, ртіс,
   {{0x661d92b3,0x3ce015d7,0x644d92b4,0x752d92b5}},	//   _jisk, _živa_, osai, ncaz,
   {{0x661d92b6,0x644d74e7,0x53b705f7,0x4429542a}},	//   _misk, nsai, _आकाश, nqa_,
   {{0x3f8c92b7,0x09dc00a1,0x2c6b0c71,0xf1b900cb}},	//   _gadu_, मच्य, rød_, _diše_,
   {{0xd9460afd,0xa96a00ca,0x644d006b,0x06d80033}},	//   лени, нина_, hsai, _দুনি,
   {{0x644d92b8,0x7c950957,0x644f201d,0xdcfb022f}},	//   ksai, _مشتا, _ovci, leuč,
   {{0xeb8e92b9,0x798d0054,0x256d00b5,0xb4db009e}},	//   _ли_, _daaw, zóló_, _seàn,
   {{0x69c600da,0x6c5203fa,0x6d490176,0x61e20121}},	//   shke, _укљу, laea, znol,
   {{0x6b8101dd,0x959a00af,0xfbd000f8,0xe9da92ba}},	//   melg, нтау_, _بتن_, _пкк_,
   {{0x61e20095,0x888685ad,0x798d073a,0x80b8021a}},	//   xnol, _ближ, _gaaw, ्नमे,
   {{0x69c492bb,0xb0d2004e,0x7c2901f4,0x69d601d5}},	// [a1e0] _ilie, _देंग, nqer, _imye,
   {{0xb6a60073,0x798d92bc,0xdb030248,0x6d4900e5}},	//   _биол, _zaaw, _conç, haea,
   {{0x661d6df8,0x3f8c3a52,0x644d0874,0x50d600d1}},	//   _fisk, _radu_, asai, گزار,
   {{0x3f8c92bd,0x249f0254,0x14d500a1,0xa7fb01dd}},	//   _sadu_, _šume_, _ठेवण, muña,
   {{0x7bc30006,0x3f8c92be,0x644d92bf,0x69c401ba}},	//   _olnu, _padu_, csai, _mlie,
   {{0x661d024e,0xdb0303e6,0xbe8a3db0,0x5f9448b9}},	//   _zisk, _gonç, есие_, рикт,
   {{0x69c45a34,0xa5bb0176,0xf1b90207,0xdb030282}},	//   _olie, _fiód, _siše_, _jonä,
   {{0xf1b902f0,0xf99f02d0,0x00000000,0x00000000}},	//   _piše_, nmèt_, --, --,
   {{0x7bc623c6,0x6b8192c0,0x00000000,0x00000000}},	//   ūkum, felg, --, --,
   {{0xf1b91254,0x6b81106d,0xe804073f,0xef9100d1}},	//   _više_, gelg, _शीला_, _ویند,
   {{0x8cd41649,0x69c492c1,0x798d010d,0xe7f80066}},	//   _बेरो, _blie, _paaw, ंकना_,
   {{0x8c460f08,0x316692c2,0x201e92c3,0x7bc300a8}},	//   _беде, ngoz_, _hiti_, _elnu,
   {{0x201e92c4,0x69c401da,0x798d030d,0x00000000}},	//   _kiti_, _dlie, _vaaw, --,
   {{0x798d00fe,0x661d92c5,0xdb1800b5,0xb4db009e}},	//   _waaw, _sisk, _elvá, _deàl,
   {{0x7bda0086,0x201e1ce2,0xdb0301f7,0x69c41f8c}},	//   mitu, _miti_, _ronç, _flie,
   {{0xb0c40e04,0x644d92c6,0x201e270c,0x44290107}},	//   वनाग, tsai, _liti_, tqa_,
   {{0x661d92c7,0x24580086,0x752d0cc9,0x03d592c8}},	// [a1f0] _visk, лать_, rcaz, ажаю,
   {{0x644d92c9,0x4429035f,0x201e92ca,0x661d03c4}},	//   rsai, rqa_, _niti_, _wisk,
   {{0x661d16dc,0x644d92cb,0x4429542a,0x57fc02b5}},	//   _tisk, ssai, sqa_, _אלזו,
   {{0x7bda92cc,0xa119004f,0x394b0d99,0x50b57439}},	//   hitu, نقاط_, nacs_, ислу,
   {{0xa0a52d4d,0x201e4d49,0x4429003c,0x7bda92cd}},	//   ралд, _biti_, qqa_, kitu,
   {{0x201e92ce,0x7bda92cf,0x902800d8,0x29d2010b}},	//   _citi_, jitu, уцца_, ršai_,
   {{0x7bda92d0,0x74d90567,0x6b814f8a,0xda0500a1}},	//   ditu, _नेतृ, velg, रतात_,
   {{0xf2d202b8,0x201e92d1,0x394b92d2,0x200c0328}},	//   _ועל_, _eiti_, jacs_, _ehdi_,
   {{0xe1340043,0xfce51858,0x201e92d3,0x61fb0054}},	//   _ынты, ропо, _fiti_, _ikul,
   {{0x7bda92d4,0x69c492d5,0x249902c2,0x201e0010}},	//   gitu, _slie, _mrsm_, _giti_,
   {{0x69c492d6,0x6b8105f5,0x8d77211f,0x61e948d9}},	//   _plie, relg, _ماشا, _kjel,
   {{0x6b81470d,0x7cd600b5,0x201e92d7,0x69c4007a}},	//   selg, اویز_, _ziti_, _qlie,
   {{0x69c40903,0x61fb0054,0x3d110096,0x7c290be2}},	//   _vlie, _mkul, देशे_, qqer,
   {{0x7bda92d8,0x7bc85794,0x2d8f92d9,0x61e90207}},	//   citu, chdu, _hage_, _ljel,
   {{0x61fb85f6,0x69c4003c,0x2d8f082b,0x7e63010d}},	//   _okul, _tlie, _kage_, nunp,
   {{0xceb20122,0x69c468a5,0x393600d8,0x61fb25b6}},	//   חיל_, _ulie, _тэкс, _nkul,
   {{0x6fc500a1,0x2d8f1c9e,0x9f5e0086,0x934692da}},	// [a200] वसां, _mage_, _yhtä_, инае,
   {{0x2d8f92db,0xe29a2691,0x61fb92dc,0xa7fb0b06}},	//   _lage_, каз_, _akul, puña,
   {{0x61e992dd,0x201e92de,0x27f84884,0xa75b00a5}},	//   _bjel, _riti_, morn_, _בדיר,
   {{0x201e92df,0xea7600c2,0x61e90c0a,0x7bda92e0}},	//   _siti_, יגער_, _cjel, zitu,
   {{0x61e9039a,0x201e92e1,0x25a292e2,0x2499011e}},	//   _djel, _piti_, _inkl_, _grsm_,
   {{0xdefa00af,0x3ce0068b,0x7c24004f,0xdfcf0ad9}},	//   кый_, _živo_, _éiri, وين_,
   {{0x201e92e3,0x7bda92e4,0x2d8f13b3,0x61e902ce}},	//   _viti_, vitu, _bage_, _fjel,
   {{0x2d8f34f3,0x61e9814d,0xdd900754,0xdd97002d}},	//   _cage_, _gjel, سوخ_, ашь_,
   {{0x201e92e5,0x2d8f054e,0xbc67004f,0x2900006d}},	//   _titi_, _dage_, لمين_, _nyia_,
   {{0x90e500bf,0xc5e30026,0x201e6aca,0x2fc5099e}},	//   _اسفن, _गद्य_, _uiti_, _gllg_,
   {{0xbeaa00bf,0xf1b9008b,0xdfcf3e7c,0x3a200051}},	//   _جهان_, _hiša_, _تيل_, _biip_,
   {{0x7bda1d0c,0xf1b90c0a,0xdebb0100,0xdd8f0312}},	//   situ, _kiša_, _שמאל, _يول_,
   {{0x6e2805d3,0x2d8492e6,0x6c3400d1,0x629a00fe}},	//   _hudb, meme_, _افتا, _štol,
   {{0xf1b9029d,0x2d8492e7,0x7bda01f4,0xdcfb00d0}},	//   _miša_, leme_, qitu, lduğ,
   {{0x7bd80010,0x69dd92e8,0x2d8f0027,0x00000000}},	//   _imvu, éres, _yage_, --,
   {{0xdcfb06d3,0x59d4004f,0xf99f8b45,0x2d844643}},	//   nduğ, _وغير, rmès_, neme_,
   {{0xf1b97375,0x69dd92e9,0x600d283e,0x6e28012e}},	// [a210] _niša_, mise, lúme, _ludb,
   {{0x61fb071b,0x61e94c46,0x69dd0d19,0xa3b700a1}},	//   _skul, _sjel, lise, _जवळ_,
   {{0xe6950082,0x2d8492ea,0xdb0301ff,0x69dd47a4}},	//   _الجد, keme_, _tonå, oise,
   {{0x2d8435a2,0x69dd92eb,0xa5bb1725,0xddc8005f}},	//   jeme_, nise, _dióc, _apdž,
   {{0x2d84024e,0x34940409,0x3949009d,0xd4790070}},	//   deme_, _даяр, _meas_, _גאָל,
   {{0x69dd92ec,0x3949066a,0x7dde0029,0x6e28038d}},	//   hise, _leas_, zīst, _budb,
   {{0x320d01f3,0x69dd92ed,0x61e90c21,0x3dc692ee}},	//   _they_, kise, _tjel, _blow_,
   {{0x61fb92ef,0x0eb8005f,0x3dc6012f,0x69dd92f0}},	//   _ukul, рушы_, _clow_, jise,
   {{0x69dd0ccf,0x2d8f92f1,0x63b503c9,0x61f90067}},	//   dise, _vage_, _kozn, mowl,
   {{0x6e282c3f,0x78bd00c3,0x5ba910e3,0x69dd864a}},	//   _fudb, dysv, уком_, eise,
   {{0x2d8f92f2,0x63b54456,0x6e2892f3,0x7dde0080}},	//   _tage_, _mozn, _gudb, tīst,
   {{0x2d8492f4,0x63b50c99,0x69dd92f5,0x394900af}},	//   ceme_, _lozn, gise, _ceas_,
   {{0x39490094,0x27f892f6,0xec3502b5,0x2b470392}},	//   _deas_, torn_, _פאַר_, _tenc_,
   {{0x7c3b1581,0xdc3602b5,0x69dd92f7,0x30da0070}},	//   mpur, _האסט_, aise, אַלע,
   {{0x7c3b0093,0x39490453,0x00000000,0x00000000}},	//   lpur, _feas_, --, --,
   {{0x249f0254,0x7bc1198d,0xd5b100e2,0x2a360037}},	//   _šuma_, lklu, ếp_, _اكيد_,
   {{0x61f9004e,0x5ede00dc,0x79860054,0xe3bf01ef}},	// [a220] dowl, _केन्_, mekw, _cuño_,
   {{0x7bc1739d,0xd7640ef2,0xd8d702b5,0x798605db}},	//   nklu, _بندی, _לופט_, lekw,
   {{0x63b592f8,0xce950029,0xdceb00ea,0xdcfb00d0}},	//   _dozn, šējā_, _angļ, yduğ,
   {{0x629a1821,0xf1b90124,0x6e2892f9,0x7f480024}},	//   _átom, _piša_, _rudb, _sedq,
   {{0x6e280a78,0x660492fa,0x905300d8,0x7bc192fb}},	//   _sudb, mlik, звіц, kklu,
   {{0x824a3655,0x66041213,0xdfd000ad,0x087702b5}},	//   _مشرف_, llik, بيت_, מענט_,
   {{0x69dd92fc,0x6f01001e,0x2d8492fd,0x660492fe}},	//   yise, _cylc, teme_, olik,
   {{0x660492ff,0x63b50038,0x628e099e,0x629c9300}},	//   nlik, _zozn, _isbo, _irro,
   {{0xe3bf043f,0x6604053e,0x394900b9,0xdcfb00d0}},	//   _xuño_, ilik, _reas_, rduğ,
   {{0xdee69301,0x39499302,0x67211851,0x7bc19303}},	//   _лози, _seas_, žlji, gklu,
   {{0x69dd35e8,0x39499304,0x93fb02b5,0x2904027d}},	//   tise, _peas_, רליי, üman_,
   {{0x79869305,0x66040282,0x24890067,0xecd90354}},	//   gekw, jlik, ywam_, _बेवफ,
   {{0x66049306,0x39491111,0x600d1111,0x00000000}},	//   dlik, _veas_, súme, --,
   {{0x7bc102c9,0x69dd9307,0xd7e70409,0x629c3ec9}},	//   cklu, sise, сімо, _orro,
   {{0x98a50dac,0x66049308,0x7d020a8a,0x79869309}},	//   ğlı_, flik, _hyos, bekw,
   {{0x6604930a,0x98a50463,0x7d02030d,0xe3bf0300}},	//   glik, şlı_, _kyos, _puño_,
   {{0x9327006c,0xe9df0037,0x545500d4,0x73d92b4d}},	// [a230] مران, miú_, юват, адар_,
   {{0xe9df0037,0x66045d47,0x3359002d,0x6e2211d9}},	//   liú_, alik, ражэ_, _liob,
   {{0x63b548cf,0x7c3b930b,0xb4db009e,0x1dc8022e}},	//   _vozn, zpur, _meài, िघात,
   {{0xe9df004f,0x225c024e,0xdb030038,0x63b5930c}},	//   niú_, ávka_, _ponú, _wozn,
   {{0x629c930d,0x628e141e,0x7bc153a2,0x7ff511cf}},	//   _erro, _esbo, yklu, يستا,
   {{0x44390052,0xee39930e,0xe9df0098,0x8fa20a19}},	//   _its_, анк_, hiú_, даше,
   {{0x7d026242,0x79860b65,0xb4db009e,0x00000000}},	//   _ayos, yekw, _seàh, --,
   {{0x442325cb,0xf8bf930f,0x7d020232,0x44399310}},	//   _hij_, ncés_, _byos, _kts_,
   {{0xdb1a004f,0x6e229311,0xe9df0037,0x7d020010}},	//   chtú, _diob, diú_, _cyos,
   {{0x44239312,0x44391f83,0x79863eb0,0x442b9313}},	//   _jij_, _mts_, wekw, _muc_,
   {{0x442304ce,0x656f01d3,0xf9860b12,0x66049314}},	//   _mij_, _occh, огно, ylik,
   {{0x4423006f,0x7c3b4a76,0x64430254,0xf1b9003d}},	//   _lij_, ppur, ćnij, _mišo_,
   {{0x79869315,0x442b0139,0xb4db0211,0xa17a0070}},	//   rekw, _nuc_, _feài, סטשט,
   {{0x442301e8,0x657d022e,0x6d4b06a2,0x656f1005}},	//   _nij_, _absh, _hega, _acch,
   {{0x6d4b06b3,0x66049316,0x44399317,0xdb1102b1}},	//   _kega, tlik, _ats_, ßgän,
   {{0xe5a30896,0x442b9318,0x66049319,0x4439931a}},	//   миси, _buc_, ulik, _bts_,
   {{0x44234cca,0x6604931b,0x26d1027a,0x442b6997}},	// [a240] _bij_, rlik, azzo_, _cuc_,
   {{0x6604931c,0x3f87931d,0x442b931e,0x644000da}},	//   slik, jenu_, _duc_, _çmim,
   {{0x6604931f,0x443912c3,0xe2977d8b,0x3f8700cd}},	//   plik, _ets_, жах_, denu_,
   {{0x6d4b4037,0x44390069,0xf6530122,0x6d590b69}},	//   _nega, _fts_, _קצר_, _ndwa,
   {{0x442326af,0x7c2b9320,0xbfaa3ad5,0x104702fb}},	//   _fij_, _nugr, итке_, оящи_,
   {{0x6e221861,0xc05900d4,0x442301e4,0x6d4b00ab}},	//   _siob, сії_, _gij_, _aega,
   {{0x60040955,0x628e067f,0x6e221a07,0x7c2b0298}},	//   nòmi, _usbo, _piob, _augr,
   {{0x442304ce,0x5d542351,0x6d4b9321,0x7c230341}},	//   _zij_, чкит, _cega, _ainr,
   {{0x6d4b9322,0x3f879323,0x442301e8,0x7c230159}},	//   _dega, benu_, _yij_, _binr,
   {{0x4423006f,0x32060312,0xd00a0e9f,0x1f630036}},	//   _xij_, lloy_, _тезе_, _окум,
   {{0xc3330bed,0xe9df004f,0x6d4b9324,0xa3dc00a1}},	//   וות_, tiú_, _fega, तोय_,
   {{0x9e651a95,0x7c237282,0x3dcd00d7,0x78a20228}},	//   _رامن, _einr, chew_, _šova,
   {{0xe9df0082,0x64430254,0x7c235cde,0xec7703e6}},	//   riú_, ćnik, _finr, _мпц_,
   {{0xd7fb1906,0x29050080,0xe9df004f,0x442b01b4}},	//   рум_, āla_, siú_, _ruc_,
   {{0xf8ae02fd,0xa3ae020c,0x442b9325,0x7c2b9326}},	//   نکی_, कान_, _suc_, _zugr,
   {{0x44230189,0x442b4a7b,0x3f870293,0x44399327}},	//   _sij_, _puc_, zenu_, _pts_,
   {{0x44230221,0x92e700c8,0xf8bf00a2,0x4439021d}},	// [a250] _pij_, _পরে_, rcés_, _qts_,
   {{0x4423006d,0x6b887c49,0x442b9328,0x29150067}},	//   _qij_, nedg, _vuc_, ądać_,
   {{0x44239329,0x1b1c0033,0xaaca0808,0x00000000}},	//   _vij_, পুরে_, ानिक, --,
   {{0x442325cb,0x442b57d5,0xd1b80079,0x657d0027}},	//   _wij_, _tuc_, يانا_, _ubsh,
   {{0x4423932a,0x8fa51112,0x3f87932b,0x44395d48}},	//   _tij_, зале, tenu_, _uts_,
   {{0x94ba0122,0x9f470248,0xce3400b5,0xaaca1cce}},	//   _המשת, onné_, ڈووک, ानाक,
   {{0x92580de3,0x6d4b3c5d,0x3f8735b9,0xed59247f}},	//   _март_, _pega, renu_, бой_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4b932c,0x205427f7,0x3f8702c4,0x7c23932d}},	//   _vega, _октя, penu_, _pinr,
   {{0xa3ae0edf,0x7c2b19cd,0x6d4b289d,0x00000000}},	//   काय_, _vugr, _wega, --,
   {{0xf1b9932e,0x76550035,0x61eb932f,0x7c232e08}},	//   _koš_, jszy, ongl, _vinr,
   {{0xf1b91254,0x22472ab5,0x9f5e02d0,0x7c2b73ca}},	//   _još_, ánky_, _aktè_, _tugr,
   {{0xa3dc009a,0xdca505a1,0xa3ae0591,0xf1b99330}},	//   तोड_, _хали, काम_, _moš_,
   {{0xe7371d91,0x4c9a02b8,0xf1b90254,0x61eb0008}},	//   зер_, _לבנו, _loš_, hngl,
   {{0xf60a0088,0x00000000,0x00000000,0x00000000}},	//   متره_, --, --, --,
   {{0x25a609ab,0x3ce00e3d,0x69cf2c70,0x656d9331}},	//   ñol_, _živi_, chce, ggah,
   {{0x2ea80d55,0x00000000,0x00000000,0x00000000}},	// [a260] _कप्त, --, --, --,
   {{0xdb031010,0x389b0319,0x317f002d,0x187700a5}},	//   _anné, _פיינ, _abuz_, _צעיר_,
   {{0xd36f0125,0xf1b902c6,0x67bb076b,0x00000000}},	//   اهم_, _boš_, _המיק, --,
   {{0x69c61131,0x59af0084,0x00000000,0x00000000}},	//   nkke, टायर, --, --,
   {{0xd00a178e,0x92bc0033,0xe0431309,0x69c60421}},	//   беде_, ইছে_, енчи, ikke,
   {{0xdb0300b5,0x61eb09c1,0x987b016b,0x00000000}},	//   _enné, angl, מאנט, --,
   {{0x09cc0429,0x59cc00a1,0x2002010b,0x7bca0118}},	//   ासाठ, ासार, _ūkis_, _rlfu,
   {{0x200702f6,0x79960345,0x00000000,0x00000000}},	//   alni_, _nayw, --, --,
   {{0x69dd02e1,0x6b880a8a,0x7e630051,0x7dce009e}},	//   èrem, tedg, arnp, _rùsd,
   {{0x61e29332,0x5a340445,0x6f6603e6,0x79960103}},	//   liol, мнот, _ѕвез, _aayw,
   {{0x7f3b0122,0xe7b00026,0x799608dd,0x645600d7}},	//   _העבו, ञानप, _bayw, hsyi,
   {{0x61e29333,0x394d0300,0x9f5c0031,0x6b880207}},	//   niol, úes_, kovë_, sedg,
   {{0x60c29334,0x2bd90084,0x1da9074f,0x76550067}},	//   nyom, योहा, कारत, wszy,
   {{0x6fbe02e4,0x61e29335,0xa6d80033,0xfbcf0037}},	//   ्सिं, hiol, _দুইট, _متى_,
   {{0x4b7b0d85,0xdb7b00a5,0x61e29336,0x61eb016e}},	//   _האוו, _הנוכ, kiol, yngl,
   {{0xb8e312eb,0x76550035,0x69c6033b,0x60c20b23}},	//   _এই_, rszy, ckke, kyom,
   {{0x57f53936,0x656d9337,0x69df0024,0xb0db00b4}},	// [a270] _опит, rgah, _imqe, _मेंग,
   {{0xa3d70f09,0x76550035,0x656d1292,0xf1b905ed}},	//   ़ों_, pszy, sgah, _soš_,
   {{0x27e324dc,0x69cd0298,0xdb180298,0xf1b9023a}},	//   mijn_, _klae, _sovê, _poš_,
   {{0x61e2027a,0x27e301e4,0x68e2010b,0x9f5c01f7}},	//   giol, lijn_, _žodi, lovè_,
   {{0x60c200b5,0x69cd00e9,0x2258005f,0x00000000}},	//   gyom, _mlae, _evrk_, --,
   {{0xa3ae0099,0x69cd00e9,0x8b070355,0x10a23efc}},	//   काण_, _llae, _jiří, тишн,
   {{0xdd9100f5,0x629a025c,0x4ea700c7,0x69c60909}},	//   ہوں_, _štov, ярда, ykke,
   {{0xf194093c,0xf1b9023a,0x27e302a2,0x60c24296}},	//   _пись, _mišk_, hijn_, byom,
   {{0x22580124,0x3a3c02a7,0x52dd0ed1,0xdd9100fd}},	//   _zvrk_, _atvp_, _मधुस, فوں_,
   {{0x69cd00be,0x0ae900c3,0x00000000,0x00000000}},	//   _alae, ждой_, --, --,
   {{0x69cd0297,0xa3ae0325,0x198a1e9f,0x00000000}},	//   _blae, कात_, обни_, --,
   {{0x69cd33c2,0x88e624ee,0xdb18021e,0x00000000}},	//   _clae, джме, _movè, --,
   {{0x315602b5,0x69c600c3,0x00000000,0x00000000}},	//   וירן_, rkke, --, --,
   {{0x81e30033,0x799651c7,0x69cd9338,0x8b030355}},	//   নকি_, _wayw, _elae, ářsk,
   {{0xf7720ef5,0x2bda00bf,0x69cd001e,0x2bca00a1}},	//   _یاد_, _بانک_, _flae, िसरा,
   {{0x64a60183,0x9f5c0031,0x2bd9021a,0x69cd0090}},	//   маба, tovë_, योरा, _glae,
   {{0xe3ba18d4,0x27e30051,0xe45a005f,0x142632dd}},	// [a280] оба_, bijn_, южа_, ддам,
   {{0x64560034,0x27e30120,0x60c2002f,0x00000000}},	//   rsyi, cijn_, vyom, --,
   {{0x9f5c00da,0x61e29339,0x754900b5,0x00000000}},	//   sovë_, tiol, észü, --,
   {{0x9f5c0314,0xdb03933a,0x491500b8,0x00000000}},	//   mové_, _honó, नेको_, --,
   {{0x9f5c0076,0x61e2933b,0x20560036,0xc448132d}},	//   lové_, riol, фтер, _ریان_,
   {{0xfbc77407,0x8fa3386a,0x2f14010b,0xd8d7016b}},	//   _شت_, каче, ндлё, וונט_,
   {{0x9f5c033a,0xdb032587,0x0cb8012f,0x2f1700af}},	//   nové_, _monó, ेन्म, мошь_,
   {{0x27e301e4,0x68f600a2,0x00000000,0x00000000}},	//   zijn_, _oxyd, --, --,
   {{0x63bc7eca,0x9f5c024e,0x91030142,0xf41f017b}},	//   _korn, hové_, _апте, _isär_,
   {{0x63bc933c,0xdfa6211b,0x9f5c05d3,0x00000000}},	//   _jorn, _تحري, kové_, --,
   {{0x9f5c024e,0x69cd933d,0x63bc933e,0x2fd700d1}},	//   jové_, _plae, _morn, _تولد_,
   {{0x9f5c053d,0x8c460183,0xceb30317,0x3ce0011c}},	//   dové_, _жеде, _שיף_, _živu_,
   {{0xae1b0070,0xdb180042,0x63bc03bc,0x69cd0051}},	//   _וואכ, _mové, _oorn, _vlae,
   {{0xdb0300de,0x63bc736a,0xe7848816,0x00000000}},	//   _conó, _norn, кусо, --,
   {{0xd5bb933f,0xdb0301ef,0x52dd06d9,0x9f5c0314}},	//   оса_, _donó, _मधेस, gové_,
   {{0xdb18033a,0xca290070,0x6b981b99,0x00000000}},	//   _nové, _צופֿ, _havg, --,
   {{0xdb039340,0x27e301e4,0x6b98027d,0x841502fb}},	// [a290] _fonó, pijn_, _kavg, емах,
   {{0x9f5c024e,0x3a29012f,0x63bc9341,0xb4db00f1}},	//   bové_, _hiap_, _corn, _beàr,
   {{0x63bc9342,0x3d050311,0xddc3002d,0x9f5c0187}},	//   _dorn, _हुने_, nunţ, cové_,
   {{0xf1b9012e,0xb4db01da,0x6b98008c,0x00000000}},	//   _kiši_, _deàr, _lavg, --,
   {{0x63bc03b1,0x25ab9343,0x653a016b,0xdb18007e}},	//   _forn, _incl_, _מערד, _dové,
   {{0x63bc05e2,0xdb030310,0x1e950e05,0xb4db01da}},	//   _gorn, _monò, ерир, _feàr,
   {{0xf1b90009,0xb4db00f1,0xed594b2a,0xa28204cd}},	//   _liši_, _geàr, пой_, _میلو,
   {{0xdceb048c,0x63bc9344,0x2c1400ab,0x63b1008b}},	//   _jagħ, _zorn, _नीबू_, šenč,
   {{0x9c2505d2,0xdceb048c,0x9f5c024e,0xa2cb00e7}},	//   ндид, _magħ, zové_, थैर्,
   {{0x63bc043f,0x3ec70009,0x9f4702d7,0xdceb007a}},	//   _xorn, _осеб, ronó_, _lagħ,
   {{0x5fac04eb,0x2005010d,0x9b450987,0x63b801ff}},	//   चारल, _ikli_, ونکو, övni,
   {{0xf99f0c1f,0x9f470037,0x9f5c0187,0xdceb003c}},	//   blèm_, inní_, vové_, _nagħ,
   {{0x3a29021d,0x48ce0033,0x00000000,0x00000000}},	//   _diap_, রপ্র, --, --,
   {{0x9f5c0076,0x6aae0037,0x3d050035,0xf1b90116}},	//   tové_, óifí, _हुये_, _diši_,
   {{0xb9070f8a,0xa3ae04aa,0x28e0045c,0xdceb007a}},	//   _ये_, कास_, _पेरि, _bagħ,
   {{0x9f5c0076,0x98ac00a8,0x212d0118,0x3a299345}},	//   rové_, şdı_, _ngeh_, _giap_,
   {{0x9f5c024e,0x7de801c0,0x62870029,0xdceb0024}},	// [a2a0] sové_, měst, _apjo, _dagħ,
   {{0x9f5c0187,0xdb1a0037,0xdcea011c,0x00000000}},	//   pové_, chtó, šiće, --,
   {{0xa3dc017a,0x63bc01ae,0x39529346,0x78a40168}},	//   तोष_, _vorn, _keys_, _hriv,
   {{0x2ba6009a,0x78a40121,0xfb160070,0x629a003d}},	//   _कोना, _kriv, ײַבט_, _štos,
   {{0x63bc9347,0xd00a291e,0xf8d00066,0x67310355}},	//   _torn, педе_, हनिय, řejň,
   {{0x80a3183b,0xdb030176,0x64449348,0x74160413}},	//   امون, _anní, mpii, _سوزا,
   {{0xaade0299,0x442a9349,0x8e268790,0x7984001c}},	//   _फेंक, _iib_, нфид, _obiw,
   {{0xa3ae0b57,0x249f0254,0x442a0312,0x6b980b88}},	//   काव_, _šumi_, _hib_, _savg,
   {{0x442a934a,0x6aa334b7,0xef86002d,0x2c7900e0}},	//   _kib_, _arnf, _плап, gèd_,
   {{0x442a934b,0x3a291b0f,0x79847238,0xcbce0033}},	//   _jib_, _siap_, _abiw, িচ্ছ,
   {{0x78a444fe,0x442a4831,0xdb030176,0x00000000}},	//   _ariv, _mib_, _sonò, --,
   {{0x442a934c,0x78a4934d,0x3e7a01f4,0x395200ee}},	//   _lib_, _briv, mët_, _ceys_,
   {{0x442a934e,0x3e7a01d2,0xdd8f004f,0x78a4934f}},	//   _oib_, lët_, _دون_, _criv,
   {{0x442a9350,0xf1b90254,0x7aeb00b5,0x79840273}},	//   _nib_, _viši_, áltá, _ebiw,
   {{0x3e7a00da,0x3a290614,0x78a47244,0xdb9b00a5}},	//   nët_, _tiap_, _eriv, _מסגר,
   {{0x78a40f7f,0x65949351,0x442a9352,0xf1b90207}},	//   _friv, ласу, _aib_, _tiši_,
   {{0x24f83122,0xf3671bdf,0x442a02d0,0x3e7a01f4}},	// [a2b0] енты_, етен, _bib_, hët_,
   {{0x442a9353,0x3e7a00da,0x7c2a009f,0x629535e2}},	//   _cib_, kët_, _jifr, _pszo,
   {{0x442a5d2b,0xdceb2251,0x3e7a01f4,0x1705006c}},	//   _dib_, _tagħ, jët_, _شہری_,
   {{0x799d84eb,0x7de70118,0x3e7a0055,0x20050044}},	//   ndsw, _mèsè, dët_, _skli_,
   {{0x660d000e,0x442a2fdc,0xa3ae06bc,0x3e7a0345}},	//   mlak, _fib_, काश_, eët_,
   {{0x660d9354,0xdee50202,0x442a5cf7,0x7c2a00a8}},	//   llak, коли, _gib_, _nifr,
   {{0x3e7a01f4,0x660d01a3,0xd00e0098,0xddd400f4}},	//   gët_, olak, غلى_, _šaši,
   {{0x4ce200c8,0x442a0221,0x660d9355,0x4c8500c3}},	//   _পড়ু, _zib_, nlak, влив,
   {{0x442a01e8,0xc8e002e4,0x7c2a0093,0x7de80355}},	//   _yib_, _पेंट, _bifr, věst,
   {{0x442a0189,0x660d9356,0x3e7a01f4,0x7de70118}},	//   _xib_, hlak, bët_, _bèsè,
   {{0x7c2a230d,0x78a4104e,0xa96a73a8,0xd9460009}},	//   _difr, _sriv, мина_, кени,
   {{0x660d011c,0x60160279,0x2ba6366c,0x645d0168}},	//   jlak, râme, _कोठा, _ovsi,
   {{0xeb8e08ce,0x660d9357,0x1a650332,0x6d499358}},	//   _ки_, dlak, ریکی_, mbea,
   {{0x6a859359,0xdcfb02c4,0x290c00ea,0x660d01b7}},	//   _алка, nfuč, āda_, elak,
   {{0x07a304bf,0x6e2b011e,0xe73718cd,0x645d3ee4}},	//   јасн, _kigb, тес_, _avsi,
   {{0x442a935a,0x660d18ad,0xf1b900cb,0x798f012f}},	//   _sib_, glak, _kišu_, cecw,
   {{0xa3ae0e1d,0x442a0189,0x3e7a01f4,0xdb0a0359}},	// [a2c0] काल_, _pib_, zët_, _anfè,
   {{0xa3dc006a,0x442a006f,0x7c2a0443,0x6d490211}},	//   तों_, _qib_, _xifr, hbea,
   {{0x442a0221,0x64442933,0xa683002d,0x00000000}},	//   _vib_, spii, _клэд, --,
   {{0x6e2b009f,0x442a16ab,0x3aba0070,0x64440421}},	//   _nigb, _wib_, ומענ, ppii,
   {{0x442a01a9,0xf1b90200,0xdb0a0260,0x00000000}},	//   _tib_, _nišu_, _enfè, --,
   {{0x3e7a00da,0x6e2b0211,0x6604935b,0x14d700a5}},	//   tët_, _aigb, loik, _יוכל_,
   {{0x3f8e935c,0x63ae0024,0x7c2a935d,0x539b024b}},	//   refu_, _inbn, _rifr, _קילו,
   {{0x3e7a071f,0x2bca05f7,0x7c2a935e,0x3f8e0054}},	//   rët_, िस्थ, _sifr, sefu_,
   {{0xdb0a00f7,0x6e2b03bc,0x3e7a0031,0x9f5c0097}},	//   _infé, _digb, sët_, loví_,
   {{0xf1b900cd,0x3e7a0055,0x7d0b0409,0x00000000}},	//   _dišu_, pët_, _dygs, --,
   {{0x6d49935f,0x2ba600a1,0x9e6503c5,0x6fd40176}},	//   bbea, _कोणा, _مانن, _càce,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799d081f,0x09e400d8,0x2d860118,0x00000000}},	//   rdsw, роўн, _iboe_, --,
   {{0x5ba30133,0x660d41ca,0x00000000,0x00000000}},	//   _връз, wlak, --, --,
   {{0x27ed01cc,0x660d9360,0x45d503e6,0x7bdd0055}},	//   đen_, tlak, говс, ësue,
   {{0xa2a6012f,0x27ed00b5,0x9f5c00ac,0x596702fb}},	//   छिन्, ően_, doví_, _ръка,
   {{0x660d431f,0xa3ae0026,0x24580086,0x629a0169}},	// [a2d0] rlak, कां_, кать_, _štop,
   {{0x39599361,0xf2c702c4,0x660d9362,0x3d0500ab}},	//   lass_, ксен, slak, _हँसे_,
   {{0xd1310312,0x00000000,0x00000000,0x00000000}},	//   مما_, --, --, --,
   {{0xf99f02e9,0xf1b9025c,0x249f8543,0xdb1800a0}},	//   ndè_, _ništ_, _šumu_, _noví,
   {{0xe0d0017e,0x7a260211,0x07f800d1,0xa0691c4d}},	//   يزه_, _dųth, _سریع_, хала_,
   {{0xa3ae0af9,0x248400b9,0x9f4701f4,0x6e2b9363}},	//   काः_, _ämma_, minë_, _sigb,
   {{0x7dd51111,0x2ca60176,0x9f470031,0xc29300d1}},	//   _láse, _arod_, linë_, _خیاب,
   {{0x2ca60b79,0xf1b90254,0xf1a41d2d,0x00000000}},	//   _brod_, _pišu_, _крун, --,
   {{0x6d499364,0x9f4701f4,0x442101a6,0x39595f18}},	//   rbea, ninë_, omh_, dass_,
   {{0x09cc00e7,0x6d4901a6,0xd9cc02e4,0xf1b9011c}},	//   ास्य, sbea, ास्ट, _višu_,
   {{0x39ea0896,0x4421148b,0x2bd91662,0x6e2b043d}},	//   едно_, imh_, योगा, _tigb,
   {{0x186a08a6,0xceb202b5,0x7dd50097,0x9f470031}},	//   нами_, _ליב_, _báse, kinë_,
   {{0xed5947f2,0x8d5a00a5,0xdb180139,0x2ca60341}},	//   maž_, _נכסי, _covâ, _grod_,
   {{0x66e61208,0x5a95263c,0x7dd50824,0xed592cf6}},	//   гога, _бриф, _dáse, laž_,
   {{0x2d9d9365,0x395903d0,0x66049366,0xf74302fb}},	//   _kawe_, bass_, toik, сесо,
   {{0x2d9f9367,0x9f470031,0x295602fb,0x2bb1178c}},	//   ndue_, finë_, _съкр, जावा,
   {{0xd467519d,0x08e20083,0x2d9d0054,0x66049368}},	// [a2e0] лите_, _গুরু_, _mawe_, roik,
   {{0x3ce60006,0x248b0036,0x2d9d9369,0x66043474}},	//   _जइसे_, _dpcm_, _lawe_, soik,
   {{0x8b5602b5,0xa90500b5,0x7dd500d5,0x66040421}},	//   ריעס_, _مبین, _záse, poik,
   {{0xc6930779,0x442104d6,0x2d9d1cf5,0x2e3800f7}},	//   _פאר_, amh_, _nawe_, _réf_,
   {{0x18360070,0x9f470031,0x44210211,0x00000000}},	//   נאַל_, cinë_, bmh_, --,
   {{0x25a000ab,0xa5bb34b8,0x00000000,0x00000000}},	//   ldil_, _chóf, --, --,
   {{0x2480936a,0x74130416,0x3940936b,0xdb1800b8}},	//   ltim_, _طوفا, _ofis_, _poví,
   {{0x25a0936c,0x225c024e,0x2d9d01cb,0x38600116}},	//   ndil_, ávku_, _cawe_, _ovir_,
   {{0xa3ae0026,0x25a0936d,0x7f46167d,0x2d9d0027}},	//   काऊ_, idil_, _безж, _dawe_,
   {{0x3b5402ee,0x32060008,0x39400160,0x212000b4}},	//   шкор, looy_, _afis_, यधीश_,
   {{0x8d8618b9,0x3f9e028b,0x2480936e,0x7ac6117a}},	//   _булд, _iatu_, htim_, успе,
   {{0x2480936f,0x2d9d9370,0x2e160037,0x3d050722}},	//   ktim_, _gawe_, _صباح, _हुवे_,
   {{0x24805a02,0x3f9e9371,0x2ca60207,0x39597c81}},	//   jtim_, _katu_, _urod_, rass_,
   {{0x3f9e0691,0x7d0600be,0x2d9d04fb,0x9f470031}},	//   _jatu_, üksu, _zawe_, vinë_,
   {{0xb4ad021a,0xa3ae0f39,0x395903c1,0x2d9d3069}},	//   कम्_, काई_, pass_, _yawe_,
   {{0x9f4700da,0x3f9e0029,0xf9931015,0x24809372}},	//   tinë_, _latu_, _طبع_, ftim_,
   {{0x248082b2,0x00000000,0x00000000,0x00000000}},	// [a2f0] gtim_, --, --, --,
   {{0x9f4701d2,0x3f9e9373,0x6fa40099,0x00000000}},	//   rinë_, _natu_, _गोलं, --,
   {{0x06bf00c8,0x9f4700da,0x25a0035f,0x9388010b}},	//   _উইকি, sinë_, bdil_, ыста_,
   {{0x7dd521a4,0x9f4707c8,0xe45f008a,0x24800159}},	//   _másc, pinë_, _tvö_, btim_,
   {{0x3f9e43a2,0xe4c700d8,0x2d9d00e0,0x9f470031}},	//   _batu_, _сённ, _rawe_, qinë_,
   {{0x764500da,0x3f9e012f,0xfe450c4c,0x8fa50390}},	//   _kthy, _catu_, анко, раке,
   {{0x3f9e9374,0xe7f8198f,0x2d9d0283,0xa5bb0098}},	//   _datu_, ूकता_, _pawe_, _chóg,
   {{0x3d190067,0x69cf0223,0x00000000,0x00000000}},	//   _परदे_, jkce, --, --,
   {{0x61eb01d3,0xed590c99,0x2d9f9375,0x3f9e0124}},	//   migl, raž_, rdue_, _fatu_,
   {{0x2d9d3069,0xa5bb004f,0x25a00252,0x61eb9376}},	//   _wawe_, _fhóg, zdil_, ligl,
   {{0x7dd59377,0xa3ad046c,0x00000000,0x00000000}},	//   _cásc, _कफन_, --, --,
   {{0x61eb9378,0x9f5c0187,0x9f4785a6,0x82760070}},	//   nigl, mová_, diné_, סערע_,
   {{0x9f5c0076,0xc2ec0083,0x20070006,0x7645008a}},	//   lová_, _করছি_, ooni_, _athy,
   {{0x6d5b9379,0x200770f4,0xfaa58223,0x61eb07e5}},	//   laua, noni_, _вако, higl,
   {{0x9f5c0076,0x9f473710,0x7bc33c41,0x61eb0008}},	//   nová_, giné_, _ionu, kigl,
   {{0x7bc300fb,0x2480027d,0x2007937a,0x69cf0051}},	//   _honu, ttim_, honi_, ckce,
   {{0x7bc3937b,0x2007937c,0x69d60332,0x9f5c245a}},	// [a300] _konu, koni_, _ilye, hová_,
   {{0x2007602f,0x2480937d,0x9f5c05d3,0xf7460274}},	//   joni_, rtim_, ková_, _њено,
   {{0x2480022e,0x20075aa7,0x3f9e937e,0x6d5b0034}},	//   stim_, doni_, _ratu_, kaua,
   {{0x3f9e203f,0x6d5b0ac8,0x69c4937f,0x248001f4}},	//   _satu_, jaua, _joie, ptim_,
   {{0x60260409,0x81cd0033,0x6d5b01ed,0x69c40147}},	//   адда, ষোভ_, daua, _moie,
   {{0x20079380,0xdfd00d4f,0x33d500d8,0x261700f7}},	//   goni_, ثيت_, _ліст, nçon_,
   {{0x61eb9381,0xd17600c3,0x69c432c5,0x2ba60761}},	//   bigl, _вызы, _ooie, _कोषा,
   {{0x3f9e19c6,0x69c49382,0xdb187797,0x6d5b0159}},	//   _watu_, _noie, _nová, gaua,
   {{0x3f9e9383,0x20079384,0xdb0a02b1,0xf53f017b}},	//   _tatu_, boni_, _wofü, _inåt_,
   {{0xa5bb004f,0x9f5c024e,0x2007027a,0x7dd50279}},	//   _thóg, bová_, coni_, _pásc,
   {{0x1fb5263e,0x98a20095,0x19591385,0x7bdd01f4}},	//   _устр, dakı_, ланы_, ësua,
   {{0x6d5b9385,0xecea021d,0x69c40176,0x6446011c}},	//   caua, _идел_, _coie, _otki,
   {{0xa3e70243,0x2b063efe,0x7bc39386,0x69cf027d}},	//   _बगल_, _सुरु_, _fonu, rkce,
   {{0x628e09a6,0x7dd50037,0x9f4700f8,0x69d66251}},	//   _opbo, _tásc, tiné_, _elye,
   {{0xc6a41129,0xd7f81bdc,0x35e700d8,0x799f09df}},	//   орти, руя_, ацав, _taqw,
   {{0x69c406a2,0x9f4700e0,0x7bc301ef,0x69d60345}},	//   _goie, riné_, _zonu, _glye,
   {{0xf94a00c2,0x20073069,0x61eb02fb,0xe7870043}},	// [a310] _געפֿ, yoni_, vigl, _куно,
   {{0xd795004f,0xdb0a0279,0x69c40120,0x200701f4}},	//   _الدخ, _infâ, _zoie, xoni_,
   {{0x64460723,0x6d5b046a,0x764501ff,0x20079387}},	//   _etki, yaua, _uthy, voni_,
   {{0x9f5c0187,0x69c4002a,0x628e03d0,0x6fd4009e}},	//   vová_, _xoie, _dpbo, _ràca,
   {{0xf99f12c3,0x61eb31a6,0xd00e1328,0x10a59388}},	//   llès_, rigl, کلو_, силн,
   {{0x443920d7,0x61eb9389,0x9f5c0237,0x6aaa00e9}},	//   _ius_, sigl, tová_, _orff,
   {{0x2007938a,0x44394409,0xe61f0019,0x24950644}},	//   roni_, _hus_, _khô_, şamı_,
   {{0x7bc3938b,0x4439938c,0x2007938d,0x9f5c033a}},	//   _sonu, _kus_, soni_, rová_,
   {{0x7bc3308a,0x4439938e,0x61e9938f,0x9f5c024e}},	//   _ponu, _jus_, _imel, sová_,
   {{0x44391020,0x7bc39390,0x69c40248,0x61fb0f7f}},	//   _mus_, _qonu, _soie, _hjul,
   {{0x44390d4b,0x44319391,0x7bc39392,0x69c40139}},	//   _lus_, _miz_, _vonu, _poie,
   {{0x3cfd0189,0x44398b45,0x61fb030d,0xe61f00e2}},	//   _txwv_, _ous_, _jjul, _nhô_,
   {{0x4439006f,0x69c401d4,0x6d590345,0x7dd567f9}},	//   _nus_, _voie, _iewa, _gása,
   {{0x7bda2a29,0x44319393,0x61c406fe,0x6d5900a1}},	//   chtu, _niz_, _वक्ष, _hewa,
   {{0x44399394,0xdb1800f5,0x7dd5024e,0x6d59072e}},	//   _aus_, _tová, _zása, _kewa,
   {{0x443100ea,0x44399395,0x6d590088,0x61fb759b}},	//   _aiz_, _bus_, _jewa, _njul,
   {{0x4431242d,0x6d59124f,0x44399396,0x3a2008dd}},	// [a320] _biz_, _mewa, _cus_, _ihip_,
   {{0x61e99397,0x44399398,0x6d5906b3,0xf1a900d1}},	//   _amel, _dus_, _lewa, یانه_,
   {{0x44310370,0x44399399,0x479b0317,0x00000000}},	//   _diz_, _eus_, _גייס, --,
   {{0x4439939a,0x121900d8,0x443100d5,0x321f939b}},	//   _fus_, аючы_, _eiz_, _chuy_,
   {{0x44397969,0x4fc60bba,0x4431939c,0x61fb0088}},	//   _gus_, йска, _fiz_, _djul,
   {{0x161c3e72,0x43750272,0x61e907ed,0x7dd50079}},	//   _भीतर_, _муст, _emel, _rása,
   {{0x6d59939d,0x4439939e,0x7dd50079,0x2fc508b7}},	//   _bewa, _zus_, _sása, _dolg_,
   {{0x443901a9,0xfe6f026e,0x7dd50300,0x7e9600b5}},	//   _yus_, ردى_, _pása, لنڈر_,
   {{0x443901a9,0x6d594367,0xbda600b5,0xea010023}},	//   _xus_, _dewa, لحکو, _quậy_,
   {{0x9b5800c9,0x4431939f,0x61e9023a,0x00000000}},	//   шиот_, _xiz_, _zmel, --,
   {{0xfba70421,0xc6010831,0x00000000,0x00000000}},	//   стый_, ্ষতা_, --, --,
   {{0x6d593d7d,0x7bda5f34,0xf2d302b5,0x2e3700a5}},	//   _gewa, shtu, פער_, _הראש_,
   {{0xb87b00a0,0xae1b00a5,0x657d93a0,0x00000000}},	//   dzíc, _עודכ, _rcsh, --,
   {{0xa3a80e1d,0x6d590103,0x00000000,0x00000000}},	//   _खोल_, _zewa, --, --,
   {{0x443993a1,0x443193a2,0xe61f00e2,0xa5bb021d}},	//   _sus_, _riz_, _phô_, _bióp,
   {{0x44310092,0x443993a3,0xdb0a0310,0xca470037}},	//   _siz_, _pus_, _infà, _اليه_,
   {{0x44310024,0x4439006f,0x798d011e,0x69dd009d}},	// [a330] _piz_, _qus_, _ibaw, mhse,
   {{0x443993a4,0x4431013b,0x61e993a5,0x78ad04fb}},	//   _vus_, _qiz_, _smel, _irav,
   {{0x443100b8,0xe5353122,0x78ad0097,0xe61f0019}},	//   _viz_, _мень, _hrav, _thô_,
   {{0x44391020,0x3f8c3998,0x00000000,0x00000000}},	//   _tus_, _abdu_, --, --,
   {{0x44390006,0x2ed101c0,0x7dd50187,0x798d276d}},	//   _uus_, तन्त, _básn, _mbaw,
   {{0x6d591221,0x185c02b5,0x6e3a011e,0xdb1a2e2f}},	//   _sewa, רכגע, _butb, nktó,
   {{0x2fc50136,0x644d93a6,0x6d591034,0x321f0023}},	//   _volg_, lpai, _pewa, _thuy_,
   {{0x61e9016f,0x78ad93a7,0x1c451169,0x2d8a006c}},	//   _umel, _orav, оним, őben_,
   {{0x644d49b4,0x6d590345,0x2fc50098,0xc3250033}},	//   npai, _vewa, _tolg_, মুখি_,
   {{0x7ff703c7,0x798d0273,0x6d597f0c,0xdb03213c}},	//   _اسرا, _abaw, _wewa, _innú,
   {{0x628593a8,0x6d5919ba,0x78ad93a9,0x63a500f1}},	//   ntho, _tewa, _arav, idhn,
   {{0xee2e00d4,0x628500e9,0x7dd500ac,0xdb1a0067}},	//   _ін_, itho, _zásn, ektó,
   {{0x6285462c,0x394d20d9,0x00000000,0x00000000}},	//   htho, ñesa_, --, --,
   {{0x78ad0b67,0xdbf10095,0xab2993aa,0x798d073a}},	//   _drav, dəçi, _кола_, _ebaw,
   {{0x78ad93ab,0x628593ac,0xb6a31783,0x69dd4dbb}},	//   _erav, jtho, мирл, bhse,
   {{0x69dd02bf,0x7dd50332,0xe81f11b5,0x628593ad}},	//   chse, _máso, _मीठा_, dtho,
   {{0x62850297,0x13ea004b,0x644d1296,0xa3ea0279}},	// [a340] etho, амай_, gpai, адаа_,
   {{0xe3b709a7,0xa5bb0079,0x317f0160,0xa3e5052f}},	//   обу_, _phóc, _acuz_, बोल_,
   {{0xe29a4ee3,0x78ad008b,0x7dd50097,0x00000000}},	//   рае_, _zrav, _náso, --,
   {{0x63a50014,0x00000000,0x00000000,0x00000000}},	//   adhn, --, --, --,
   {{0x92bc0b52,0x6285026e,0x2bdc0355,0x224d023a}},	//   েছে_, atho, यसमा, _čeke_,
   {{0x661693ae,0x628593af,0x6e3a4164,0x7a3e00ec}},	//   llyk, btho, _putb, _bītl,
   {{0x62854564,0x6e4300e0,0x61460009,0x7d1500a8}},	//   ctho, ونوم, _мева, əzsi,
   {{0x8548010b,0x00000000,0x00000000,0x00000000}},	//   brėž, --, --, --,
   {{0x6ea800b5,0x00000000,0x00000000,0x00000000}},	//   _گناہ_, --, --, --,
   {{0x8bd803fa,0x3dc60160,0x00000000,0x00000000}},	//   смос_, _woow_, --, --,
   {{0x1fb55533,0x69dd01f4,0x661693b0,0x2905037a}},	//   _эстр, thse, klyk, ğlam_,
   {{0x78ad53eb,0x00000000,0x00000000,0x00000000}},	//   _prav, --, --, --,
   {{0x7dd5024e,0x6e2293b1,0x764e0345,0x00000000}},	//   _záso, _ihob, epby, --,
   {{0x7ddc0248,0x78ad93b2,0x62851904,0xdb0a1dad}},	//   _dése, _vrav, ytho, _enfá,
   {{0x06e10033,0x6e2235df,0x66163ee4,0x00000000}},	//   _মুজি, _khob, flyk, --,
   {{0x78ad4305,0x2b490129,0x7dd505d3,0xd5b82674}},	//   _trav, _đaci_, _násl, осу_,
   {{0x78ad93b3,0xe9df0037,0x0459004f,0x7ddc0345}},	// [a350] _urav, mhú_, صلاة_, _gése,
   {{0x644d93b4,0x57f400c3,0xa3e50035,0x628593b5}},	//   rpai, _опыт, बों_, ttho,
   {{0x644d93b6,0x66160b88,0x6440000d,0x63a501e9}},	//   spai, blyk, _émin, rdhn,
   {{0x6285001e,0x7ddc08cb,0x7df300af,0x644d0421}},	//   rtho, _lésb, năst, ppai,
   {{0x628593b7,0x644b014c,0x224a0065,0x55ba00a5}},	//   stho, ígid, _etbk_, _המרו,
   {{0x62850069,0x660d0069,0x1da32f78,0x7dd50097}},	//   ptho, loak, _खोजत, _páso,
   {{0x6e2293b8,0x44230523,0xc695016b,0x00000000}},	//   _bhob, _ihj_, לאַ_, --,
   {{0xbca5004f,0x317f037a,0xb2220093,0x660d02ee}},	//   كمبي, _ucuz_, áætl, noak,
   {{0x2bb90037,0x6e221ef2,0x2b5c023a,0x00000000}},	//   مادة_, _dhob, _bevc_, --,
   {{0x7ddc1010,0x9c2200d8,0x1eab0987,0x7dd50097}},	//   _rése, ндыд, _پائي_, _zásl,
   {{0xe8e10028,0x7f1905f5,0x660d93b9,0x44230088}},	//   _đều_, _اياز_, koak, _mhj_,
   {{0x6e220874,0x3ce60066,0xf2d2016b,0x7c280345}},	//   _ghob, _जेके_, געט_, amdr,
   {{0x2d8f0279,0x6e29082b,0xdd990501,0x3935010b}},	//   _ibge_, mmeb, meň_, дэрс,
   {{0x2bbb0514,0x59c800a1,0xdd990097,0xda7800d5}},	//   _خاصة_, _लवकर, leň_, buď_,
   {{0xe9df0037,0x290c0035,0xa3b52869,0xdb0a0a8a}},	//   bhú_, łda_, झाई_, _anfæ,
   {{0xb9020033,0x660d01ed,0xa44662a6,0x00000000}},	//   _দশ_, goak, знад, --,
   {{0x66160349,0x75d30037,0xa3e800b4,0xdceb0381}},	// [a360] rlyk, ريكا, यफल_, _kagı,
   {{0x442300e2,0x6e2902b1,0x00000000,0x00000000}},	//   _chj_, hmeb, --, --,
   {{0x8c1a0122,0xe2970423,0xb87b0187,0x2bc300e7}},	//   צועי, зах_, nzín, _वचना,
   {{0xd24f04a3,0x236a011e,0x21670431,0x68e2010b}},	//   انن_, _wdbj_, зици_, _žody,
   {{0xf5370122,0x6e2900ab,0x60160183,0xdd9915d8}},	//   _מרכז_, dmeb, lâmi, deň_,
   {{0x6e946a63,0x6e2293ba,0x9f5c00a0,0x9f470176}},	//   дику, _shob, lovú_, ginà_,
   {{0x6e2293bb,0xcf26004f,0x60160279,0xc7b300a5}},	//   _phob, أرشي, nâmi, תבו_,
   {{0x21a31714,0xade300d4,0x00000000,0x00000000}},	//   _писм, ецьк, --, --,
   {{0xdceb0471,0xbf360ae7,0x00000000,0x00000000}},	//   _bagı, _فراغ, --, --,
   {{0x660d01ed,0x09d50edf,0xdb030260,0x00000000}},	//   zoak, दस्य, _kanè, --,
   {{0xe9df0082,0x6e2290fd,0xfe723cf2,0xdb030260}},	//   thú_, _thob, _سدا_, _janè,
   {{0x7d0206a2,0x261701d6,0xdb0300d1,0x3ddf02a2}},	//   _txos, rçok_, _manè, chuw_,
   {{0x660d081b,0x9ac4003c,0x7de50037,0x05000033}},	//   voak, _suċċ, _تسلم, ্ধুর_,
   {{0xdc3700c2,0xa5bb93bc,0x7d1d93bd,0x4c9b00a5}},	//   _זאגט_, _chón, üsse, _לבדו,
   {{0x660d93be,0x356b0ffd,0xeaaf0037,0x9ac4035f}},	//   toak, йран_, _معي_, _quċċ,
   {{0x442300d7,0x6b9a2845,0xe1ab0a44,0x41ab0066}},	//   _shj_, letg, _घोंघ, _घोंस,
   {{0x7bca012f,0x660d3375,0x200e08c7,0x644000a2}},	// [a370] _kofu, roak, kofi_, _émil,
   {{0xdd9901c0,0x660d01a3,0x386993bf,0xd3710037}},	//   zeň_, soak, _ivar_, ئها_,
   {{0x3869008a,0x754800b5,0x200e0124,0xaadc00be}},	//   _hvar_, észí, dofi_, मनिक,
   {{0xd1315002,0x386901bc,0x41e400d8,0x7dd50187}},	//   نما_, _kvar_, ніча, _pásm,
   {{0xdd990076,0x92bd0083,0x8fa593c0,0xc0c803fa}},	//   veň_, ইনে_, дале, зује_,
   {{0x25a9006c,0xb4d90324,0xf78a016b,0x7bca01e9}},	//   ldal_, ़नी_, ַנפֿ, _nofu,
   {{0x24890332,0x9294224a,0x6fd4009e,0x00000000}},	//   ltam_, _парц, _màch, --,
   {{0x96270080,0x53342235,0x25a993c1,0x56b800a5}},	//   _uzņē, _чест, ndal_, לפון_,
   {{0x248993c2,0x7dd5008a,0xea000019,0xdd9901ba}},	//   ntam_, _hásk, _ngại_, reň_,
   {{0x320f0052,0xdd990187,0x63a70a05,0x7bca1c02}},	//   logy_, seň_, _jajn, _cofu,
   {{0x63a72e94,0x7bca93c3,0xdd990187,0x25a900d1}},	//   _majn, _dofu, peň_, kdal_,
   {{0x248993c4,0x7dd500b5,0x00000000,0x00000000}},	//   ktam_, _másk, --, --,
   {{0x7dd50076,0xcb691fae,0xdb035069,0xa5bb01a5}},	//   _lásk, _дале_, _mané, _phón,
   {{0x63a777cb,0x0c2402ce,0x2489006c,0x629501e4}},	//   _najn, _змін, dtam_, _opzo,
   {{0xe73700ca,0x16a707c1,0x38690553,0x2cad93c5}},	//   дер_, мври_, _evar_, lved_,
   {{0xcb120122,0x60160279,0x200e93c6,0x6fd4009e}},	//   _שלה_, râmi, zofi_, _eàch,
   {{0x224d93c7,0x63a700b5,0x79840027,0xdb0a0523}},	// [a380] _čeka_, _bajn, _iciw, _enfä,
   {{0x66093479,0x78a458ee,0x25a60a66,0x69c60009}},	//   čeka, _isiv, žol_, ljke,
   {{0xe72a0d1b,0x63a70009,0xea010023,0x7ddc0118}},	//   _фонд_, _dajn, _quầy_, _lésa,
   {{0x320f4827,0xe3b100fd,0x00000000,0x00000000}},	//   gogy_, پرے_, --, --,
   {{0x248993c8,0x63a7004e,0xa06729d6,0xdb0393c9}},	//   ctam_, _fajn, дача_, _dané,
   {{0x5f930fb4,0x2cad93ca,0xb03300d4,0x63a70506}},	//   вишт, dved_, вніш, _gajn,
   {{0x2d8d93cb,0x2cad7179,0xc243167d,0x443893cc}},	//   ffee_, eved_, _анск, _iir_,
   {{0x443893cd,0x200e93ce,0x7ddc02d7,0x78a400ac}},	//   _hir_, sofi_, _bésa, _osiv,
   {{0x61e293cf,0x6fd401f7,0x7bca0207,0x2383008d}},	//   mhol, _làci, _pofu, _þrjá_,
   {{0x61e2555b,0x7ddc0248,0x6f0d04d4,0x79840090}},	//   lhol, _désa, şaca, _aciw,
   {{0x443893d0,0x38692bf2,0x337700a5,0x037700a5}},	//   _mir_, _svar_, ועים_, ותית_,
   {{0xc3331759,0xdd8f0037,0x61e202ce,0x443893d1}},	//   כות_, _نوم_, nhol, _lir_,
   {{0x443801a6,0xdd8f064e,0x7bca030d,0x290c00a8}},	//   _oir_, _خون_, _tofu, şdan_,
   {{0x3f9c93d2,0x61e20a63,0x7984099e,0x00000000}},	//   nevu_, hhol, _eciw, --,
   {{0x38c501d2,0x63a793d3,0xe613004f,0x61e293d4}},	//   _bërë_, _rajn, نشر_, khol,
   {{0x2489006c,0x386933c1,0xe81f0299,0x44383594}},	//   ttam_, _tvar_, _मीरा_, _air_,
   {{0x443850eb,0x61e2054e,0xb4d9004e,0x63a793d5}},	// [a390] _bir_, dhol, ़ने_, _pajn,
   {{0x248993d6,0x25a9765b,0x3f9c0b79,0x6fd412c3}},	//   rtam_, sdal_, jevu_, _fàci,
   {{0x443893d7,0x248993d8,0x65640dc3,0x63a793d9}},	//   _dir_, stam_, baih, _vajn,
   {{0x7c3893da,0x443893db,0x248993dc,0xc6920070}},	//   _livr, _eir_, ptam_, _גאט_,
   {{0x63a7011c,0x4438355f,0x244401ff,0x60c20118}},	//   _tajn, _fir_, _göm_, gxom,
   {{0x443802ce,0x187c0d85,0xe43300b5,0x3f9c1855}},	//   _gir_, קטוב, _شہاد, gevu_,
   {{0xa3a800be,0x7ddc00f6,0x15f500b4,0x61e293dd}},	//   _खोट_, _sésa, _ेदार_, bhol,
   {{0x61e293de,0x6fdd0310,0x6e920037,0xdb180107}},	//   chol, _dèca, اليا, _invè,
   {{0x51840009,0x799d099e,0x60390359,0x00000000}},	//   _шура, desw, _fňma, --,
   {{0x2cad93df,0x7dd5006c,0xddc800ea,0x7ddc01ef}},	//   rved_, _mási, ļoša, _vésa,
   {{0x656f93e0,0x7c3802d4,0x91f30066,0x291e0035}},	//   _odch, _divr, _आगाज_, ętam_,
   {{0x799d93e1,0x69c601e8,0xc33200a5,0x7dd50183}},	//   gesw, ujke, טוי_, _oási,
   {{0x7dd50187,0x26170279,0x9f4701d6,0x65640086}},	//   _nási, nçou_, ginç_, vaih,
   {{0x6d495b1a,0x38c50031,0x7c3800a2,0x60c402e2}},	//   lcea, _sërë_, _givr, äimi,
   {{0x66e6263d,0x61e2008c,0x4438804b,0x6d490036}},	//   хова, yhol, _rir_, ocea,
   {{0x7dd50aca,0xa3a8488d,0x61e26248,0x799d0051}},	//   _bási, _खोज_, xhol, cesw,
   {{0x4438010b,0x656493e2,0x6d49009d,0x61e22a86}},	// [a3a0] _pir_, raih, icea, vhol,
   {{0x085702b8,0x7dd501ef,0x6fd40176,0x645d00e5}},	//   _רבים_, _wásh, _tàci, _dwsi,
   {{0x44381e4f,0x38c501f4,0x61e293e3,0x00000000}},	//   _vir_, _tërë_, thol, --,
   {{0x443893e4,0x3f8593e5,0x04ca3fec,0x2a6a00b5}},	//   _wir_, _aclu_, _فوجي_, ábbi_,
   {{0x44387f85,0x61e20b41,0x3f9c57bd,0xdb18021e}},	//   _tir_, rhol, tevu_, _envè,
   {{0x442c02e9,0x44380284,0x61e2863f,0x4ea60109}},	//   _òd_, _uir_, shol, ериа,
   {{0x61e293e6,0xfe6f11c0,0x3f9c93e7,0xe2976c06}},	//   phol, مدي_, revu_, _пар_,
   {{0x291e004e,0x7dce0211,0x7c380225,0x6e390090}},	//   ętaj_, _cùsp, _sivr, _ciwb,
   {{0xdb180279,0x98ab00d0,0x320700b5,0x6e39099e}},	//   _invé, yacı_, énye_, _diwb,
   {{0xdb570f99,0x3ea90067,0x26170176,0x00000000}},	//   нюю_, łata_, lçot_, --,
   {{0x7c380248,0x799d93e8,0xa3e502b4,0x00000000}},	//   _vivr, tesw, बोट_, --,
   {{0x225c024e,0x6136037a,0x6e390090,0x00000000}},	//   ávky_, _gülü, _giwb, --,
   {{0x799d1dfb,0x44100066,0x00000000,0x00000000}},	//   resw, ़काऊ_, --, --,
   {{0xb8c90755,0x799d93e9,0x2ca6001e,0x645d016e}},	//   _गई_, sesw, _isod_, _rwsi,
   {{0x3ea50210,0x7a3e010b,0xab270274,0x9c1700a5}},	//   _xslt_, _būte, _поља_, _רחוק_,
   {{0x349544d3,0x7ddc2ddc,0x7dd507c0,0xb87b00d5}},	//   кабр, _méso, _pási, nzík,
   {{0x3a2902b3,0x00000000,0x00000000,0x00000000}},	// [a3b0] _ihap_, --, --, --,
   {{0xdce02190,0xdb030176,0x61e003d0,0x00000000}},	//   jamč, _innò, _alml, --,
   {{0xae1004bc,0xc87f033b,0x79ea00b5,0x6d494415}},	//   ावान_, luß_, _رویہ_, ycea,
   {{0xcb1302b5,0x7ae500ab,0x2ca600e9,0x1af7016b}},	//   אלע_, _ühte, _osod_, עמאל_,
   {{0xf9940122,0xa0a5027a,0x6f1a0107,0x10a54717}},	//   טרף_, талд, _aytc, тилн,
   {{0x61e000a8,0x26170183,0xdb182d56,0x6f1a00ee}},	//   _elml, rçou_, _envé, _bytc,
   {{0x9f470421,0x5f050382,0x31660027,0x00000000}},	//   vinä_, ъзка, baoz_, --,
   {{0x7ddc0248,0x7767006d,0x9f5c0187,0x3a2900e2}},	//   _déso, hajx, mový_, _nhap_,
   {{0x6d4993ea,0x9f5c024e,0xa5bb2cad,0xf20400d8}},	//   rcea, lový_, _dióx, _сяро,
   {{0x6d49004f,0xe50200dc,0x1a650e3a,0x386b0312}},	//   scea, लपति_, نیتی_, dscr_,
   {{0x26174db0,0x9f5c024e,0xdb030107,0x3ed90079}},	//   nços_, nový_, _annò, _تواج_,
   {{0x3a2993eb,0x186a1129,0xf53f03d0,0x9f470421}},	//   _chap_, мами_, _ngå_, sinä_,
   {{0x9f5c0187,0x3a2901ef,0xd84300ee,0x69a10067}},	//   hový_, _dhap_, _rečí_, गज़ी,
   {{0x9f5c033a,0xbb42021d,0x00000000,0x00000000}},	//   kový_, _кешк, --, --,
   {{0xfaa55187,0x9f5c0187,0x25ab008c,0x966318ea}},	//   _райо, jový_, _bacl_, икре,
   {{0x98be01d6,0x9f5c024e,0x63bc0e8f,0xdb0300ac}},	//   ştı_, dový_, _snrn, _janí,
   {{0xdb031dad,0xd46793ec,0x3940005f,0x25ab099e}},	// [a3c0] _maní, ките_, _igis_, _dacl_,
   {{0x2d9f03bc,0xf53f0a8a,0x00000000,0x00000000}},	//   heue_, _egå_, --, --,
   {{0x66e62e34,0x277700a5,0x78b617c3,0x9f5c0097}},	//   _рона, _בגין_, _hryv, gový_,
   {{0xdb180076,0x7ddc0248,0xd24f0413,0x6fd401f7}},	//   _nový, _réso, زنه_, _làct,
   {{0xe0e00083,0x7bda008d,0xf8c2021a,0x00000000}},	//   বপ্ন, yktu, शमिय, --,
   {{0xdfcf317b,0x25a093ed,0x9f5c290b,0xb4de0035}},	//   يين_, leil_, bový_, तनी_,
   {{0x6fdd12c3,0x248000f1,0x79960035,0xdb030097}},	//   _tècn, luim_, _obyw, _baní,
   {{0x7526006d,0x25a000f1,0xdb030138,0x27f802b1}},	//   _kzkz, neil_, _caní, hirn_,
   {{0xc5f30052,0xdb010ffb,0xdb0393ee,0x00000000}},	//   ידה_, ndlæ, _daní, --,
   {{0x25a093ef,0x442a0b88,0x9f5e0107,0xdd0c0067}},	//   heil_, _jhb_, _ektò_, _półk,
   {{0xe9f91728,0x5a354db5,0x37ba0033,0x0d861c62}},	//   енні_, лнот, ুসার, _ален,
   {{0xdb0301ef,0x394093f0,0x5a34002d,0x24800345}},	//   _ganí, _cgis_, инэт, kuim_,
   {{0x386d02e1,0xc8641218,0x9f5c0187,0x6fd401f7}},	//   éer_, итри, zový_, _fàct,
   {{0x6eb800b4,0x442a5339,0xd7c900f8,0x248093f1}},	//   ्मपु, _nhb_, روزه_, duim_,
   {{0x1af00083,0x88cb0033,0x25a00185,0x3a29184a}},	//   _ঘুরে_, _লেখক, feil_, _thap_,
   {{0x25a001a6,0x9f5c0187,0x2d8493f2,0x1dc50266}},	//   geil_, vový_, ngme_, वायत,
   {{0x80be006a,0x386000e9,0x442a15ff,0xdb0a0249}},	// [a3d0] ्हों, _gwir_, _bhb_, _anfø,
   {{0x9f5c0076,0x442a0088,0xa5bb0079,0xc3540274}},	//   tový_, _chb_, _mhói, икуј,
   {{0x7dd50187,0x59d70387,0x69dd56ea,0x96f900af}},	//   _zásu, _डकार, okse, _чент_,
   {{0x261724c5,0x9f5c024e,0x69dd72d0,0xdd0100cd}},	//   rços_, rový_, nkse, _žučn,
   {{0x9f5c0187,0x7dd5365a,0xdfd51667,0x00000000}},	//   sový_, _mást, лоды, --,
   {{0x7dd500de,0x224302a7,0x9f5c0097,0x00000000}},	//   _lást, _tujk_, pový_, --,
   {{0xf1a7135b,0x4e95004f,0x00000000,0x00000000}},	//   _иран, اشتر, --, --,
   {{0x7dd50076,0x7db40a93,0x7645028b,0xa5bb0098}},	//   _nást, асьц, _muhy, _bhói,
   {{0xa5bb0082,0x7c2a0037,0x612c000d,0x313493f3}},	//   _chói, _bhfr, rôlé, _ветр,
   {{0xa5bb0079,0x7aa51053,0x5ac99224,0x00000000}},	//   _dhói, гиоз, елом_, --,
   {{0xdb0300b5,0x764501ed,0x00000000,0x00000000}},	//   _taní, _nuhy, --, --,
   {{0x7dd501ef,0x61f90159,0x60160183,0xa5bb0079}},	//   _cást, niwl, lâmp, _fhói,
   {{0x6d5b3635,0xfd4400d8,0x25a093f4,0x6fd40310}},	//   mbua, _тэхн, veil_, _tàct,
   {{0xaae51d05,0x291e0029,0x69dd00c3,0x25a05baa}},	//   _مسعو, āta_, akse, weil_,
   {{0x66e313f8,0x25a05e21,0x7dd50037,0x65ba0274}},	//   бора, teil_, _fást, нуар_,
   {{0x64a6082a,0x7dd52cad,0x290500d0,0x248093f5}},	//   лаба, _gást, ğlar_, tuim_,
   {{0x26de042d,0x290506a8,0xb4de20d8,0x25a093f6}},	// [a3e0] što_, şlar_, तने_, reil_,
   {{0x7dd5053d,0x25a001a6,0x248093f7,0xf99f0036}},	//   _zást, seil_, ruim_, rnèe_,
   {{0x1bf60070,0xdb0a01f7,0x764500e0,0x574300af}},	//   נצער_, _cafè, _guhy, _ынэб,
   {{0x00e6144b,0x79860430,0x067b0070,0x7a3e00ea}},	//   лжен, ngkw, _אנטל, _jūta,
   {{0xdce00228,0x66044962,0x248064df,0x8a170122}},	//   kamā, mnik, quim_, נחנו_,
   {{0x660467b3,0xeeaa5fc0,0x6566010d,0xdce000ea}},	//   lnik, етик_, _hekh, jamā,
   {{0x23272ee2,0x69dd03ad,0xdb01013c,0x65665112}},	//   _бори_, ykse, ndlä, _kekh,
   {{0x5c742f82,0x644605ba,0x660493f8,0x7c2a00da}},	//   алит, _kuki, nnik, _shfr,
   {{0xa3e80953,0x600a1159,0x63ae006d,0x660400ab}},	//   _बता_, _знам_, _kabn, inik,
   {{0x660493f9,0xda7a93fa,0x644693fb,0x7dd5004f}},	//   hnik, ням_, _muki, _sást,
   {{0xd00f0642,0x6604393b,0x644693fc,0x19591385}},	//   _علم_, knik, _luki, каны_,
   {{0x69dd03ad,0x63ae0159,0x7c86110d,0x656629c5}},	//   ukse, _labn, _буке, _nekh,
   {{0x644693fd,0x69dd00d4,0x5c56010e,0xdb18002a}},	//   _nuki, rkse, _стеф, _inví,
   {{0xdb0301f7,0x6fc705e7,0x69dd00be,0xdce00228}},	//   _fanà, लायं, skse, camā,
   {{0xd5bb0272,0x7dd5004f,0xaab70c26,0x64464a30}},	//   нса_, _tást, _مدير_, _auki,
   {{0x644650a2,0x66042308,0x63ae0a8c,0x00000000}},	//   _buki, gnik, _aabn, --,
   {{0xd37b20a6,0xf9900037,0x65660051,0x63ae02a7}},	// [a3f0] ече_, _ربي_, _dekh, _babn,
   {{0x6446435f,0x5eea0033,0xdb030097,0x656632c5}},	//   _duki, _কখনও_, _haná, _eekh,
   {{0xdb03024e,0x63ae0221,0x6604108a,0x7ff501cb}},	//   _kaná, _dabn, bnik, یستا,
   {{0x6d420019,0x629c00ce,0xdb0a29e0,0x660493fe}},	//   _ngoa, _dpro, _café, cnik,
   {{0x629c93ff,0x601f0279,0xdceb0484,0x6016002d}},	//   _epro, lêmi, _ibgħ, tâmp,
   {{0x3d180299,0xd47a0070,0x09e21cce,0x6d4201ed}},	//   _पड़े_, _באשל, _पत्य, _agoa,
   {{0x6d5b01c2,0xd344006c,0xdce0013a,0xd00e06ca}},	//   tbua, _اہمی, vamā, بلو_,
   {{0xdb030097,0x8db5010b,0x60390260,0x00000000}},	//   _naná, рскі, _kňmk, --,
   {{0x6d5b5443,0xdce002d4,0xdb010279,0x629c00b8}},	//   rbua, tamā, celê, _zpro,
   {{0xdb183318,0x66041cb0,0xabd504bf,0x7dd50279}},	//   _enví, znik, рциј, _páss,
   {{0x4fc42876,0xdce000ec,0xdb031d8a,0x3b090610}},	//   _уста, ramā, _baná, тено_,
   {{0x1d190eb1,0x66040095,0x601f03e6,0xcda80698}},	//   _июль_, xnik, dêmi, _مهمه_,
   {{0x660439bb,0xdce000ec,0x9a15002d,0x00000000}},	//   vnik, pamā, сфэш, --,
   {{0x6604006a,0x6446401e,0xdb03004f,0xdb010055}},	//   wnik, _ruki, _eaná, nelë,
   {{0x09e67fdb,0xdb031ea3,0x6446297a,0xa92800fe}},	//   _войн, _faná, _suki, _buží,
   {{0xe9df016f,0x060706cd,0x395f0093,0xdb0302d7}},	//   ckú_, анск_, ðust_, _ganá,

   {{0x7ddc9400,0xddd8011c,0x629c9401,0x00000000}},	// [a400] _désh, nuvš, _spro, --,
   {{0x66040121,0x63ae006d,0x629c003c,0x682000b5}},	//   snik, _qabn, _ppro, ködi,
   {{0x66049402,0xb1461edd,0x6566022e,0x63060037}},	//   pnik, анел, _tekh, جوال,
   {{0x644656a8,0xfc4801a5,0xe0da03fa,0xb87b00ac}},	//   _tuki, _lửa_, кве_, rzív,
   {{0x629c004e,0x4fc64697,0x4dce0831,0x00000000}},	//   _wpro, иска, ়সমূ, --,
   {{0xfc4801a5,0x00000000,0x00000000,0x00000000}},	//   _nửa_, --, --, --,
   {{0x7ddc0248,0x539b00a5,0x5ed90033,0x6fdd00a2}},	//   _hési, _שילו, _ভেবে, _mèch,
   {{0x9fa30093,0x7dd50453,0x6fdd000d,0x00000000}},	//   síðu_, _básq, _lèch, --,
   {{0x64400248,0x5f1601c0,0xdb010055,0x7a3f02d4}},	//   _émis, _पुर्_, belë, _būtn,
   {{0xfc480028,0x66090254,0x53c900b4,0x60e80644}},	//   _cửa_, čeki, रायश, ırmı,
   {{0xb4db0028,0x6253003c,0x7ddc000d,0xdb0300ac}},	//   _ngàn, _għod, _lési, _paná,
   {{0xed5a586d,0x99670279,0x00000000,0x00000000}},	//   _род_, штол, --, --,
   {{0xfbcf0357,0x6fdd021e,0xa9280168,0x00000000}},	//   ستی_, _bèch, _ruží, --,
   {{0xd7fb04bf,0x00000000,0x00000000,0x00000000}},	//   тум_, --, --, --,
   {{0xdb030332,0x3952099e,0x00000000,0x00000000}},	//   _taná, _ffys_, --, --,
   {{0xdb1801f7,0x26cd0207,0x8b3b024b,0x00000000}},	//   _invà, ćeo_, _בתוצ, --,
   {{0x22a801d6,0x44210065,0xb87b00b5,0x337503d0}},	// [a410] _aşk_, tlh_, gzít, йгар,
   {{0x7ddc02e1,0x78ad3dc8,0xd687002d,0x69cf0a66}},	//   _dési, _isav, _кумп, ljce,
   {{0xdb0a76f0,0xa5bb0079,0xa27900af,0x00000000}},	//   _infó, _bhót, убеу_, --,
   {{0x69cf0a66,0xe1f003ec,0xc2440746,0xa5bb026e}},	//   njce, وسن_, інік, _chót,
   {{0xdce202c4,0xc1040037,0xdb0302b1,0xe80e07b5}},	//   _beoč, يومي, _unnö, _सदमा_,
   {{0x656d9403,0x335800af,0x2397007e,0x00000000}},	//   laah, _варэ_, _dějí_, --,
   {{0x63a502c4,0xfc480019,0x212901ba,0xa49b0392}},	//   mehn, _rửa_, ťah_, _exòt,
   {{0xfc480028,0x798d006f,0x656d0fc2,0x63a59404}},	//   _sửa_, _ncaw, naah, lehn,
   {{0x62859405,0xdb0100fd,0x00000000,0x00000000}},	//   luho, melé, --, --,
   {{0x656d82b2,0x63a508b7,0x7dd51725,0x6253007a}},	//   haah, nehn, _vásq, _iħob,
   {{0xa96a0de3,0x656d9406,0xae7800d4,0xaa5600b5}},	//   лина_, kaah, _всіх_, یلیا_,
   {{0xdb030370,0x6fdd00f7,0x00000000,0x00000000}},	//   _lanç, _sèch, --, --,
   {{0xeb990cac,0x91ba00a5,0x991600d8,0x6253007a}},	//   _бил_, אמרי, сьні, _jħob,
   {{0x7ddc02e1,0xdb030176,0x661d0298,0x628532c6}},	//   _rési, _nanç, _aksk, kuho,
   {{0x320648be,0x6729000c,0xdb01006c,0x66e37024}},	//   ynoy_, řejn, kelé, пора,
   {{0xbb3a02b5,0x7ddc1111,0x6fdd0392,0x656d1187}},	//   _געצי, _pési, _dèci, gaah,
   {{0xdb189407,0x78ad023a,0x452a0200,0x62530024}},	// [a420] _invá, _gsav, ужан_, _nħob,
   {{0xdb038037,0x60390260,0xdb0a0260,0x69c407c0}},	//   _canç, _fňmi, _infò, _hnie,
   {{0xb87b0332,0xe5a69408,0xdb0303e6,0x69c40b3c}},	//   szít, _лини, _danç, _knie,
   {{0xc8b50332,0x69d69409,0x387f0169,0x765c011e}},	//   _الیک, _joye, šure_, mpry,
   {{0x69d675ab,0x7bc3030d,0x69c4004e,0xa5bb0093}},	//   _moye, _onnu, _mnie, _skóg,
   {{0x6285940a,0x69d600f7,0xdb0302b1,0x22a80225}},	//   buho, _loye, _kanä, _tşk_,
   {{0x7ddc0310,0x61eb009e,0x00000000,0x00000000}},	//   _mésv, bhgl, --, --,
   {{0x7bc3940b,0x20075c1d,0x69d6940c,0x61eb940d}},	//   _annu, anni_, _noye, chgl,
   {{0xf1c300b8,0x61e2940e,0xdce20009,0x8afc0035}},	//   šší_, mkol, _teoč, zbęd,
   {{0x61e2940f,0x3a740f88,0x24800037,0x69c49410}},	//   lkol, олор, irim_, _anie,
   {{0x441b02b5,0x69d69411,0x61e20b23,0x69c4003c}},	//   רויס, _boye, okol, _bnie,
   {{0x14c81bb5,0x61e29412,0x7bc39413,0xf4000083}},	//   रमाण, nkol, _ennu, ্তির_,
   {{0xdca30525,0x1dc500b4,0x69d64090,0x69c49414}},	//   _наци, वारत, _doye, _dnie,
   {{0xdb01006c,0xd7f89415,0xb8d11d25,0x656d08c7}},	//   zelé, бус_, _ऐन_, waah,
   {{0xdb0a9416,0x61e29417,0x69d69418,0xf4000033}},	//   _enfò, kkol, _foye, ্তার_,
   {{0x78ad9419,0x9f470187,0xdb030132,0x69c4941a}},	//   _tsav, diný_, _sanç, _gnie,
   {{0x63a5941b,0x02e11bc6,0x61e20d14,0xdb01006c}},	// [a430] tehn, पन्न, dkol, velé,
   {{0xa5bb0037,0x7d1d01ae,0x656d012f,0x6285941c}},	//   _chór, üssi, saah, tuho,
   {{0xa6ab1d05,0xdb01006c,0x45d53c45,0x3255010b}},	//   _صادق_, telé, _донс, цвер,
   {{0x201e941d,0x61e2941e,0xdb0a01ef,0x63a5729a}},	//   _akti_, gkol, _nafí, sehn,
   {{0xa5bb0037,0x7ddc93a4,0xdb01006c,0x62852a07}},	//   _fhór, _jésu, relé, suho,
   {{0xf2e76297,0x6609011c,0x7e550c94,0x00000000}},	//   _любо, čeku, отиц, --,
   {{0xb7dc02b5,0xdb013f18,0x7ddc0118,0x00000000}},	//   רקוי, pelé, _lésu, --,
   {{0xec796e70,0xa19400c3,0x5fc7057c,0x00000000}},	//   апи_, _насч, लाहल, --,
   {{0x61fb2af6,0x69d600f6,0x261a021a,0x1be9195c}},	//   _imul, _roye, पवती_, идии_,
   {{0x69c41669,0x69d60248,0x9f4557f4,0x95f60808}},	//   _snie, _soye, _ollé_, _इष्ट_,
   {{0x61e9941f,0xab295f4e,0x4fc40bbc,0x69c49420}},	//   _klel, рона_, _эста, _pnie,
   {{0x5ed20083,0x27fa022e,0x7ddc00e0,0x9d190036}},	//   _থেকে, _smpn_, _bésu, _коет_,
   {{0x69d69421,0x9f4500f7,0x776e00a8,0xdd8e0312}},	//   _voye, _allé_, tabx, _شوو_,
   {{0x7bc30093,0x9f472a04,0x61e29422,0x61e901ef}},	//   _unnu, minó_, zkol, _llel,
   {{0x61e29423,0x61fb09d6,0xf74334fe,0xe73a2b4b}},	//   ykol, _omul, деро, рев_,
   {{0x69c49424,0x24809425,0x9f5c0031,0xa5bb0079}},	//   _unie, trim_, tivë_, _shór,
   {{0x3a2001d1,0x22583270,0x7ddc00e0,0x4431021d}},	// [a440] _ikip_, _strk_, _gésu, _bhz_,
   {{0xf7720594,0x61fb018e,0x248001f4,0x99860580}},	//   _کاک_, _amul, rrim_, _الکو,
   {{0x1dbf009a,0x61e29426,0x44315d50,0x75ea0097}},	//   _शोभत, tkol, _dhz_, _výzb,
   {{0x24809427,0xea8c0070,0x61fb00ee,0x44310065}},	//   prim_, רנאָ, _cmul, _ehz_,
   {{0x61e29428,0x7ddc2278,0x9f5c00ac,0x00000000}},	//   rkol, _mést, livé_, --,
   {{0x88bb0070,0x2d9d030d,0xd3720a42,0x61fb0147}},	//   יזני, _abwe_, _زهر_, _emul,
   {{0xfe6f11c0,0x2176021d,0x9f5c0097,0xc30701e0}},	//   ندي_, _муар, nivé_, _держ_,
   {{0x934302ce,0x61fb2a07,0x7ddc21db,0x61e90118}},	//   _інте, _gmul, _nést, _glel,
   {{0x9f4700de,0x00000000,0x00000000,0x00000000}},	//   ginó_, --, --, --,
   {{0x7ddc1010,0xbea62f44,0x00000000,0x00000000}},	//   _résu, _мазк, --, --,
   {{0x201c030a,0x7ddc0981,0x3eb800b5,0x9f5c00ac}},	//   movi_, _bést, _ért_, jivé_,
   {{0x201c0ce9,0xfcaa01cb,0xec3500b5,0x6da605c7}},	//   lovi_, _ناتو_, _ہونگ, _фида,
   {{0xa92b0210,0xc17300a5,0x9f473965,0x7ddc000d}},	//   ріне_, וחר_, minò_, _dést,
   {{0xbebc0ae0,0x201c05e2,0x3a209429,0x36d51956}},	//   _dzīv, novi_, _ekip_, погр,
   {{0x3dc6942a,0x356b0896,0x3a2000e7,0xc5fb0370}},	//   _know_, иран_, _fkip_, аѓа_,
   {{0x201c0888,0x7a120080,0x54551b0a,0x6fdd0176}},	//   hovi_, tāte, зват, _hèct,
   {{0x94ab0500,0x201c011c,0x3494942b,0x394900be}},	// [a450] штва_, kovi_, матр, _igas_,
   {{0x61fb942c,0x7bd80024,0x9f5c00ac,0x61e90118}},	//   _smul, _jovu, bivé_, _slel,
   {{0x201c01cc,0x7afc004f,0x7ddc0183,0x61e90124}},	//   dovi_, úrth, _jéss, _plel,
   {{0x7bd8942d,0xdb1801ff,0xbbd723f0,0x00000000}},	//   _lovu, _invä, _ढक्क, --,
   {{0xf7f400d1,0x3ebe0382,0x9f47027a,0xa6e20093}},	//   _رسید, _artt_, dinò_, öðva,
   {{0x201c0496,0xa2a60035,0x44253503,0x3f9e021d}},	//   govi_, _टैक्, _ól_, _cbtu_,
   {{0x248940a3,0x61e9942e,0x00000000,0x00000000}},	//   luam_, _tlel, --, --,
   {{0x25a901a6,0x3949942f,0x629701e8,0x61fb9430}},	//   neal_, _ngas_, mtxo, _umul,
   {{0x63b50888,0x201c0a78,0x24899431,0x7ddc01ef}},	//   _kazn, bovi_, nuam_, _rést,
   {{0x25a99432,0x201c110e,0x321d0035,0x290602c4}},	//   heal_, covi_, lowy_, _žoao_,
   {{0x7bd89433,0x63b59434,0x24890189,0x62979435}},	//   _dovu, _mazn, huam_, ntxo,
   {{0x316d0069,0x63b59436,0x321d0035,0x3d954e5d}},	//   _jeez_, _lazn, nowy_, _хидр,
   {{0xdb184b47,0xdb0300fb,0x25a90727,0x00000000}},	//   _anvä, _janú, deal_, --,
   {{0x3869048c,0x9f5c9437,0x7ddc01f7,0x2a6724f7}},	//   _dwar_, tivé_, _féss, _twnb_,
   {{0xfaa20133,0x321d0035,0x6297006d,0xdb0317d9}},	//   _защо, kowy_, jtxo, _lanú,
   {{0x25a99438,0xceb20bed,0x201c0ce9,0x9f5c9439}},	//   geal_, עין_, zovi_, rivé_,
   {{0x321d004e,0x64a35432,0x63b5943a,0x2489104e}},	// [a460] dowy_, ната, _bazn, guam_,
   {{0x59c40096,0x9f5c00ac,0x00000000,0x00000000}},	//   षाकर, pivé_, --, --,
   {{0x386902c9,0xe7db00a5,0x25a9943b,0x201c00cd}},	//   _zwar_, _הקיש, beal_, vovi_,
   {{0x04460086,0xdb0301f7,0x25a9943c,0x321d0067}},	//   _немн, _banú, ceal_, gowy_,
   {{0x25d700c2,0x201c05e2,0x63b55ed9,0x55bb0122}},	//   _זוכן_, tovi_, _fazn, _המכו,
   {{0xdb0a022a,0x741603c5,0x6297006d,0x65641292}},	//   _infö, _روزا, btxo, lbih,
   {{0x7646018e,0x316d01ed,0x321d0067,0x2cad0f00}},	//   _kiky, _feez_, bowy_, ewed_,
   {{0x201c02f6,0x2d8d0b88,0x316d0088,0xdb0301ba}},	//   sovi_, ggee_, _geez_, _fanú,
   {{0x7bd80a78,0x201c05e2,0xa3e055f5,0xdb080279}},	//   _povu, povi_, _तवा_, cedê,
   {{0x25a90139,0x9f4707e5,0x7ddc0132,0x3c2b0a8a}},	//   zeal_, sinò_, _péss, søvn_,
   {{0xc4c809b1,0x6135006c,0xdb0100d5,0x34c8012f}},	//   रमुख, pülé, belí, रमुद,
   {{0x80b30035,0x2489006d,0xee3a002d,0x7646073a}},	//   _इनमे, yuam_, _уне_, _niky,
   {{0x7bd8943d,0x6e220371,0x25a9024b,0x00000000}},	//   _tovu, _ikob, veal_, --,
   {{0x61d90a44,0xd7f8002d,0x8c431676,0x3f8e943e}},	//   _भक्ष, пус_, _зече, ngfu_,
   {{0x63b50888,0x752f006a,0x6bd31c2d,0x25a909c3}},	//   _razn, _szcz, _ستور, teal_,
   {{0x63b501cc,0x24898ae9,0x656411e9,0x7c3a03d0}},	//   _sazn, tuam_, gbih, lmtr,
   {{0x73d93539,0x63b5943f,0x76462717,0x7c285c2e}},	// [a470] одар_, _pazn, _diky, oldr,
   {{0x25a99440,0x7a1202d4,0x67250086,0x68ef033e}},	//   seal_, māta, _tyhj, ındı,
   {{0x98b9036a,0x25a99441,0x2489006f,0x321d004e}},	//   ması_, peal_, suam_, towy_,
   {{0x629706a2,0x7a3f4cd6,0x98b90644,0x2cad001e}},	//   rtxo, _būti, lası_, ywed_,
   {{0x656f0297,0x321d6640,0x7a1200ea,0x6253007a}},	//   _iech, rowy_, nāta, _għon,
   {{0x656f0083,0x98b904d4,0x443a0176,0x645d01d5}},	//   _hech, nası_, cmp_, _itsi,
   {{0x4423022e,0xd5e10066,0x660d9442,0xee39021d}},	//   _ikj_, _नवाज, onak, онк_,
   {{0x660d5837,0x64472cbe,0x644f1034,0xb4db009e}},	//   nnak, _hiji, _kuci, _agài,
   {{0x98b90dac,0x6447000e,0x660d9443,0x2d8d03bc}},	//   kası_, _kiji, inak, rgee_,
   {{0x656f9444,0x6447000e,0x644f31b0,0xdb0a1945}},	//   _lech, _jiji, _muci, _safá,
   {{0x644742a7,0x26c10189,0xdb080443,0x799d033b}},	//   _miji, _nrho_, nedè, ffsw,
   {{0x645d2efa,0x656f086d,0xf2d202b5,0x7dd5006c}},	//   _otsi, _nech, דעט_, _lász,
   {{0xcd2b13cf,0x645d0d4b,0x660d2523,0x6d4b9445}},	//   _اسان_, _ntsi, dnak, _igga,
   {{0x6e2902fc,0xdca20c98,0xa3ac07b5,0x64479446}},	//   lleb, _раши, कड़ा_, _niji,
   {{0x645d0a93,0x656f1264,0x6ec00355,0x00000000}},	//   _atsi, _bech, वियु, --,
   {{0x660d9447,0x644f9448,0x656f088a,0xdb0a0037}},	//   gnak, _buci, _cech, _uafá,
   {{0x644f01d3,0x656f9449,0x6447944a,0x25fd0275}},	// [a480] _cuci, _dech, _biji, रोधी_,
   {{0x644f944b,0x9f45944c,0x660d0103,0x98b901fb}},	//   _duci, _allí_, anak, cası_,
   {{0x6d59099e,0x656f08df,0xe2971897,0x645d944d}},	//   _ofwa, _fech, дах_, _etsi,
   {{0x6d4b0703,0x656f5cd7,0x644f0382,0xf1a30431}},	//   _ngga, _gech, _fuci, вршн,
   {{0x64472d3c,0x644f01d5,0x6604944e,0x6e2918de}},	//   _fiji, _guci, miik, dleb,
   {{0x6604944f,0x6d4b9450,0x25a200d7,0x6d5909a6}},	//   liik, _agga, _hbkl_, _afwa,
   {{0x656f0107,0xf1aa00ce,0xdb080310,0x81b60831}},	//   _yech, _واره_, cedè, জাব_,
   {{0x6e299451,0x98b90463,0x1dc56882,0x7ddc1111}},	//   gleb, zası_, वागत, _césp,
   {{0x98b901c2,0x7ddc07a6,0x3166023c,0x9f4c008c}},	//   yası_, _désp, mboz_, _omdø_,
   {{0x7a120228,0x6d4b001c,0xc0a90773,0x1aff0831}},	//   vāta, _egga, _عاقل_, _উড়ে_,
   {{0xddcb3479,0x660d01d6,0x7c3a029e,0x66040273}},	//   žišt, ynak, rmtr, kiik,
   {{0x7c661015,0x2be007b5,0x7a1202d4,0x799d02b1}},	//   _قاتل, _पकवा, tāta, ufsw,
   {{0x656f9452,0x98b906d3,0x660d016f,0x200e9453}},	//   _rech, tası_, vnak, onfi_,
   {{0x6e209454,0x656f9455,0x644f0371,0x78bd0b3e}},	//   lomb, _sech, _ruci, rvsv,
   {{0x656f9456,0x98b90092,0xa3d21af6,0x644f9457}},	//   _pech, rası_, वान_, _suci,
   {{0x4423055f,0x6447411b,0x660d01a2,0x62850187}},	//   _skj_, _siji, unak, vrho,
   {{0x656f9458,0x660d4507,0x6447046a,0x25a2028b}},	// [a490] _vech, rnak, _piji, _dbkl_,
   {{0x656f02c9,0x6e2001d5,0xd3710ad9,0x7a120029}},	//   _wech, homb, اها_, nātn,
   {{0x6e205f0c,0x64479459,0x62530484,0xe0d000f8}},	//   komb, _viji, _għol, یزه_,
   {{0x3e7a0080,0xd131004f,0xdb08006c,0x3ea5012f}},	//   dīt_, هما_, gedé, _rplt_,
   {{0xa06913ad,0x645d945a,0x6e2901ff,0xe00100d8}},	//   чала_, _utsi, vleb, лькi_,
   {{0x7bca0069,0xdb080176,0x00000000,0x00000000}},	//   _nnfu, pedè, --, --,
   {{0xfc4800e8,0x2bd200a1,0x6e200020,0x2ca600b8}},	//   _gửi_, ताना, fomb, _apod_,
   {{0x6e201548,0x4421945b,0x53345451,0x2ca6012f}},	//   gomb, loh_, _рест, _bpod_,
   {{0x6e290eda,0xdb01290b,0x442139c5,0x301501c8}},	//   rleb, delá, ooh_, _здар,
   {{0xa3d272c4,0x35d10324,0xeb990274,0x6e29945c}},	//   वाय_, हाड़, чио_, sleb,
   {{0x6e200b13,0xf99f0382,0x6e294d89,0xdd0000ea}},	//   bomb, ffè_, pleb, ātāj,
   {{0x61f92024,0x44214f63,0x7bca01a8,0x6d4b945d}},	//   _çalı, hoh_, _enfu, _ugga,
   {{0x44210406,0xc3260083,0x66040086,0xf1b908b7}},	//   koh_, _বলছি_, viik, _maš_,
   {{0xcc760319,0xfbd013cf,0x2cbf0009,0x7bca030d}},	//   _טענה_, _پته_, mvud_, _gnfu,
   {{0x6604945e,0x2cbf0009,0xdb01945f,0xe7373c3b}},	//   tiik, lvud_, belá, еер_,
   {{0xf1b923d8,0x7a3f004b,0x00000000,0x00000000}},	//   _naš_, _būtu, --, --,
   {{0x66041d2a,0x225f0009,0x2cbf0009,0x3e7a00ea}},	// [a4a0] riik, _čuka_, nvud_, zīt_,
   {{0x2bd206d9,0x44210118,0x6604707e,0x26170484}},	//   ताया, goh_, siik, għob_,
   {{0xf1b90759,0xa3d20299,0x68e60159,0x6e2025b6}},	//   _baš_, वाब_, lykd, yomb,
   {{0x2cbf0009,0x6253007a,0x00000000,0x00000000}},	//   kvud_, _għom, --, --,
   {{0xf123093c,0x44210ce8,0xf1b92518,0x9f450443}},	//   льшо, boh_, _daš_, _allà_,
   {{0x3e7a0ae0,0x6576081b,0x25b90009,0x6e20001c}},	//   tīt_, layh, _zasl_, womb,
   {{0x443802bf,0x6e209460,0x25a0012f,0x180e074f}},	//   _ihr_, tomb, ofil_, _सदैव_,
   {{0x3e7a0029,0x65769461,0xe2a60093,0x320700b5}},	//   rīt_, nayh, öðum_, ényt_,
   {{0x3e7a0080,0xdb0101ef,0x00000000,0x00000000}},	//   sīt_, velá, --, --,
   {{0xf1b9003d,0x96e000b4,0x00000000,0x00000000}},	//   _zaš_, नहाउ, --, --,
   {{0x2ebd00b4,0x44381ef2,0xda771397,0x5ba30409}},	//   ्मृत, _mhr_, няя_, урыз,
   {{0xf8bf0187,0xdd8f1c2d,0xddea00d1,0x00000000}},	//   tvé_, _هوم_, _عرضه_, --,
   {{0xf8bf02e1,0xebe69462,0x4421435d,0x2ca602b3}},	//   uvé_, _подп, yoh_, _upod_,
   {{0xf8bf0248,0xdb1801f4,0xf99f02d0,0xdb0101ef}},	//   rvé_, _javë, sfè_, selá,
   {{0xdce20009,0x25a000e9,0xdb0140e7,0x00000000}},	//   _beoć, ffil_, pelá, --,
   {{0xd5b89463,0x48fc0099,0xdb0300fe,0x00000000}},	//   нсу_, _लेको_, _janý, --,
   {{0x44219464,0x69cd0054,0x44380069,0xf1b90009}},	// [a4b0] toh_, _inae, _bhr_, _raš_,
   {{0x44389465,0x7a369466,0x160200a1,0x25b90176}},	//   _chr_, ráte, रोबर_, _wasl_,
   {{0x4421195f,0x44389467,0x8c1b0122,0xa5f99468}},	//   roh_, _dhr_, לומי, _жену_,
   {{0x4421195f,0x225c0355,0x69df0055,0xdb070fce}},	//   soh_, ívka_, _joqe, élém,
   {{0xf1b922b2,0x44210a1e,0x7c3800ab,0xed5900cd}},	//   _vaš_, poh_, _ohvr, ndže_,
   {{0x9f450033,0x4421022e,0xc0e2182f,0x24899469}},	//   _allá_, qoh_, рошк, mram_,
   {{0xf1b90009,0x5334946a,0x2bb7073f,0xf1a7946b}},	//   _taš_, _берт, _असबा, _пран,
   {{0x2cbf0009,0x69df0c6f,0x69cd0103,0x00000000}},	//   tvud_, _noqe, _nnae, --,
   {{0xdb030097,0x00db0754,0x00000000,0x00000000}},	//   _daný, _عبرت_, --, --,
   {{0xa5bb00fb,0x69cd946c,0x24892cd9,0x00000000}},	//   _skól, _anae, iram_, --,
   {{0x20075ba0,0xa3d202cb,0x05e10035,0x0dcb0166}},	//   mini_, वात_, _नवंब, _нуди_,
   {{0x200733cd,0x24890c53,0xdd1d00af,0x00000000}},	//   lini_, kram_, _câţi, --,
   {{0x7c2100e7,0xeb992b60,0x2489946d,0xdb18021e}},	//   polr, _жил_, jram_, _lavè,
   {{0x2007946e,0x2489946f,0xfc4800e2,0x69cd0103}},	//   nini_, dram_, _bửu_, _enae,
   {{0xd62a9470,0xfc480019,0xa5961109,0xdb1868fd}},	//   дове_, _cửu_, кращ, _navè,
   {{0x200719c6,0x44380159,0x6d5b9471,0x2489008d}},	//   hini_, _shr_, ncua, fram_,
   {{0x200719c6,0xb9070b52,0x25a09472,0xe3ba9473}},	// [a4c0] kini_, _যে_, rfil_, мба_,
   {{0x20079474,0x7ae500be,0x64a311c5,0x00000000}},	//   jini_, _ühts, рафа, --,
   {{0x24890279,0xd25912ea,0xb4db00f1,0x00000000}},	//   aram_, еці_, _sgàt, --,
   {{0x24895afd,0x6d5b006d,0x9f5c00ac,0x00000000}},	//   bram_, jcua, divá_, --,
   {{0xa3d20d55,0x20079475,0xf9930122,0x409600c3}},	//   वाद_, fini_, שרד_, трет,
   {{0x443802bf,0x20079476,0x78fb00a5,0x00000000}},	//   _uhr_, gini_, ופנו, --,
   {{0x0eec0299,0x63bc9477,0xe7a40d41,0x00000000}},	//   जनेस_, _iarn, ख्यप, --,
   {{0x531b00a5,0x6e39016e,0x229c00ac,0x00000000}},	//   _חולצ, _chwb, mík_, --,
   {{0x61e0006e,0x229c024e,0x629e9478,0xa3d60099}},	//   _ioml, lík_, ltpo, _ाचा_,
   {{0x2bb700a1,0xdb030138,0x9f5c00d5,0xdb010328}},	//   _असणा, _nanó, bivá_, kelä,
   {{0x63bc9479,0x229c05d3,0xd00f0a72,0x7ec800f7}},	//   _marn, ník_, _ظلم_, _dépô,
   {{0x24890644,0x8b0700b8,0x6d5b3ee6,0xdb010282}},	//   yram_, _skří, ccua, delä,
   {{0xcdf700a5,0x6ba701ff,0x2cb800ea,0xfc4800e2}},	//   _במאי_, ärgå, ārds_, _sửu_,
   {{0x63bc947a,0xdb036625,0x69cd001e,0x61e005e2}},	//   _narn, _canó, _wnae, _loml,
   {{0x2bb702cb,0xdb0100a6,0xdceb0029,0x5c371198}},	//   _असता, gelä, _iegā, _שרון_,
   {{0x248911c6,0x2007947b,0x61e00118,0xfde00083}},	//   tram_, zini_, _noml, _বগুড,
   {{0x2007947c,0x63bc63b7,0x7bda01e8,0x049508cf}},	// [a4d0] yini_, _barn, ojtu, طلاح,
   {{0x2489947d,0x44270019,0x7a36213c,0xdb01947e}},	//   rram_, ôn_, máta, belä,
   {{0x63bc947f,0x00000000,0x00000000,0x00000000}},	//   _darn, --, --, --,
   {{0xf65000f5,0x20079480,0x61e05d98,0xa5f92f2c}},	//   _گئی_, wini_, _coml, _чему_,
   {{0x20079481,0x61e00355,0x3c3900f7,0x248900a8}},	//   tini_, _doml, lève_, qram_,
   {{0x27e1666e,0xb4df00a1,0x1e950fe7,0x7a120228}},	//   _john_, तही_, грир, vātm,
   {{0x20079482,0xed599483,0x3a299484,0x3c3900f7}},	//   rini_, ной_, _okap_, nève_,
   {{0x20079485,0x61e00a21,0x5187027f,0x63bc9486}},	//   sini_, _goml, _шуга, _zarn,
   {{0xdd910332,0xdd110092,0x20075082,0x6f1a01f7}},	//   لوں_, _düşm, pini_, _extc,
   {{0x6d5b08bf,0x63bc1d75,0x3a296b80,0x20079487}},	//   scua, _xarn, _akap_, qini_,
   {{0x81b600c8,0x224d01c8,0x7d040009,0xdb0801ef}},	//   জার_, _kiek_, _žist, bedí,
   {{0xdb089488,0x75ea00b8,0x7bda01f4,0x6ec03010}},	//   cedí, _výzk, ajtu, विरु,
   {{0x224701c0,0xdb0301f7,0x229c0097,0x00000000}},	//   ínky_, _canò, zík_, --,
   {{0x224d9489,0xdb0102ee,0x00000000,0x00000000}},	//   _liek_, telä, --, --,
   {{0x98a50080,0xd7570416,0xfb240416,0x224d0065}},	//   ālā_, الفت_, _پروپ, _oiek_,
   {{0x229c00fb,0x63bc948a,0xdb0101ff,0x224d948b}},	//   vík_, _sarn, relä, _niek_,
   {{0x61e0948c,0x20ce05ee,0x27e10051,0xdb010421}},	// [a4e0] _roml, iðið_, _fohn_, selä,
   {{0x69a08d7c,0x63bc3886,0x61e0948d,0x229c948e}},	//   ग्री, _qarn, _soml, tík_,
   {{0x518609d0,0x66e612f3,0x63bc4978,0x179b02b5}},	//   гула, _сона, _varn, _אייב,
   {{0xbbe00fbf,0x63bc1425,0x5be0022e,0x80ad0831}},	//   _पक्क, _warn, _पक्व, চিন্,
   {{0x63bc948f,0x79840051,0x224d0345,0x81b60831}},	//   _tarn, _mdiw, _diek_, জাল_,
   {{0xb4c21bc6,0x60c29490,0xb4c00d2a,0xc4480088}},	//   ्मी_, rvom, ंटी_, _شیان_,
   {{0x61e04c2e,0x644e0dc3,0x4ea60036,0x2bd221b2}},	//   _toml, _iibi, урла, तासा,
   {{0x7984876b,0xa3d200be,0x5d540dee,0x61460009}},	//   _ndiw, वाव_, шкит, _беба,
   {{0x644e9491,0x7ddc0332,0x25d702b5,0x442a102f}},	//   _kibi, _kész, רופן_, _kkb_,
   {{0x644e3af3,0x79841ea7,0x224d01e4,0x3a292129}},	//   _jibi, _adiw, _ziek_, _skap_,
   {{0xc3fb02b5,0xdb089492,0x442a9493,0x3872001e}},	//   גליש, pedí, _mkb_, _awyr_,
   {{0xf2d300c2,0x644e9494,0x75f801c0,0x27e101ae}},	//   צער_, _libi, _jízd, _sohn_,
   {{0x79840297,0x442a2267,0x7d7b0070,0x3872099e}},	//   _ddiw, _okb_, _טראג, _cwyr_,
   {{0x644e041b,0xf41f013c,0x7a369495,0x59c30963}},	//   _nibi, _iväg_, ráta, षयहर,
   {{0xd90f00d1,0x00000000,0x00000000,0x00000000}},	//   تیک_, --, --, --,
   {{0xb4c21e79,0xb4c00e04,0x644e00f1,0x2bd2112b}},	//   ्मू_, ंटू_, _aibi, तावा,
   {{0x644e9496,0xed590d77,0x7b0400c7,0x224d07c0}},	// [a4f0] _bibi, ndža_, žutė, _riek_,
   {{0x224d9497,0x644e9498,0x442a0211,0x78ad023a}},	//   _siek_, _cibi, _ckb_, _ipav,
   {{0x644e9499,0xe45f1cb5,0x41e712ea,0x41557275}},	//   _dibi, _grön_, ліда, авес,
   {{0x69d8018d,0x00000000,0x00000000,0x00000000}},	//   यायी, --, --, --,
   {{0x656d253e,0xa3d222a7,0x7a360314,0x644e949a}},	//   mbah, वाश_, kátn, _fibi,
   {{0x224d004e,0x9f510095,0xdceb002d,0x644e949b}},	//   _wiek_, _özü_, _legă, _gibi,
   {{0x224d3bc2,0xb3d200a1,0x3e55013a,0x7777003c}},	//   _tiek_, सारख, _kāti_, _mexx,
   {{0x656d949c,0x644e949d,0x2bb7020d,0x78ad00b8}},	//   nbah, _zibi, _असहा, _opav,
   {{0x20ce008a,0x82340365,0x644e04fb,0x3e5502d4}},	//   rðið_, _طرفا, _yibi, _māti_,
   {{0xa3ab0e04,0x656d0034,0x7a120029,0x60c9949e}},	//   _कॉम_, hbah, māti, _irem,
   {{0x34d10569,0xa3bd22a7,0x78ad00ea,0xa96a579f}},	//   समुद, _आसन_, _apav, кина_,
   {{0xd946949f,0xcfaa0033,0x656d02c4,0x764f01d5}},	//   иени, _গোপন, jbah, _nicy,
   {{0x69d81782,0x7a120029,0xed4e002d,0x2bd2021a}},	//   याबी, nāti, _фо_, ताशा,
   {{0x60c90054,0x660600d7,0x9f470037,0x18671682}},	//   _mrem, _smkk, dhnú_, рари_,
   {{0x7ddc00f5,0x644e94a0,0xf7461470,0x2bd20d91}},	//   _rész, _ribi, рево, तारा,
   {{0x644e94a1,0x05661fd7,0x7a36024e,0x656d300c}},	//   _sibi, рван, máto, gbah,
   {{0xb4c20825,0x9f47004f,0x7a36503b,0x644e94a2}},	// [a500] ्मे_, ghnú_, láto, _pibi,
   {{0x7bc194a3,0x7a1200ea,0x187b0070,0x63800355}},	//   ndlu, dāti, _שטיב, dání,
   {{0x656d94a4,0x7a361d85,0xe29a00d8,0x644e0858}},	//   bbah, náto, тае_, _vibi,
   {{0x60c994a5,0x71a601c8,0x506693c0,0x644e94a6}},	//   _brem, радз, атка, _wibi,
   {{0xe046059b,0x9f470037,0xf8b80066,0x76440381}},	//   анди, chnú_, ेटिय, mmiy,
   {{0x764401d6,0x248094a7,0x7a361d85,0x7a3d006c}},	//   lmiy, msim_, káto, méte,
   {{0x444494a8,0xd3350a93,0x60c994a9,0x248094aa}},	//   mm_, _гэты, _erem, lsim_,
   {{0x60c93d9d,0x806600d4,0x7a360187,0x661600c3}},	//   _frem, _вваж, dáto, nnyk,
   {{0x444494ab,0x2bd201c0,0x2617003c,0x2480550e}},	//   om_, ताला, dħol_, nsim_,
   {{0x444494ac,0xed5902c4,0x8bd8002d,0x00000000}},	//   nm_, rdža_, умос_, --,
   {{0x444494ad,0x78ad94ae,0x656d010d,0x7a3656fe}},	//   im_, _spav, ybah, gáto,
   {{0xdca62495,0x248094af,0xa3d20006,0x26170484}},	//   _вади, ksim_, वाँ_, għol_,
   {{0xb4c2030f,0xfd120647,0x248000d5,0x764f0027}},	//   ्मो_, _بجا_, jsim_, _ricy,
   {{0x444494b0,0xb4c20355,0xdb1894b1,0x8c430043}},	//   jm_, ्मै_, _haví, _дече,
   {{0x0cb61ae9,0xc98707bc,0x656d08dd,0x7c28856b}},	//   _अनुम, _купи, tbah, modr,
   {{0x444494b2,0x81ab0b52,0x80ad0083,0xb99903fa}},	//   em_, _কোন_, চিত্, _свих_,
   {{0xa3d20992,0x656d34dc,0x444494b3,0xf1da018d}},	// [a510] वां_, rbah, fm_, णानन,
   {{0xf36794b4,0x7644073a,0x638001c0,0x7c280228}},	//   ртан, amiy, vání, nodr,
   {{0x60c9764e,0x752f0035,0x24800159,0x00000000}},	//   _srem, _wycz, asim_, --,
   {{0x444494b5,0xdb1801c0,0xb5a7467f,0x5187847e}},	//   am_, _naví, _трой, ружа,
   {{0x69d802cb,0x7c2800da,0x7a362eef,0x660d94b6}},	//   याती, kodr, záto, miak,
   {{0xa3d20b35,0xafe200c3,0x7a120228,0xb17d00ee}},	//   वाः_, зошл, rāti, _doťa,
   {{0x75ea0187,0xdb1864ec,0xe7ff0354,0x00000000}},	//   _výzv, _baví, _उतना_, --,
   {{0x660d84e5,0xa1941783,0x7a1202d4,0xd0870421}},	//   niak, _масч, pāti, _выжи,
   {{0xd0e9006c,0x60c95ba0,0xdb180093,0x2d86016e}},	//   _حکام_, _urem, _daví, _ddoe_,
   {{0x660d06a2,0x6445184f,0x7c280088,0xdb0394b7}},	//   hiak, nmhi, godr, _manö,
   {{0x644594b8,0x660d94b9,0x7bc194ba,0x764494bb}},	//   imhi, kiak, rdlu, ymiy,
   {{0x7a36122d,0x69d80567,0x186a00aa,0x444494bc}},	//   ráto, याधी, лами_, zm_,
   {{0x660d94bd,0xfd560122,0xdb0800a0,0x6e29248a}},	//   diak, _השני_, redá, moeb,
   {{0x7a3d006c,0x7c281c5b,0xdb180097,0x6253035f}},	//   véte, codr, _zaví, _jħos,
   {{0xb4c00066,0x76440225,0x44440c8c,0xe45f01ff}},	//   ंट्_, tmiy, vm_, _dröm_,
   {{0x44441020,0x660d94be,0x6a640037,0x7a3d00b5}},	//   wm_, giak, _بطول, téte,
   {{0x7644027d,0x66160409,0x00000000,0x00000000}},	// [a520] rmiy, rnyk, --, --,
   {{0x44440d4b,0x3ea90035,0x44330036,0x7a3d94bf}},	//   um_, łaty_, glx_, réte,
   {{0x248094c0,0x86c6026b,0x833a0445,0x966300af}},	//   ssim_, _ايجن, учат_, _нкэе,
   {{0x444494c1,0x7a3d8a21,0x64a694c2,0x63550355}},	//   sm_, péte, _лама, třní,
   {{0x2378012f,0x00000000,0x00000000,0x00000000}},	//   _terj_, --, --, --,
   {{0x225894c3,0x7a1202d4,0x23780132,0xf3e628fa}},	//   _turk_, mātu, _uerj_, _ужго,
   {{0xdb18002a,0x7c280009,0x00000000,0x00000000}},	//   _paví, vodr, --, --,
   {{0x5275141d,0x7c28001e,0x21a30200,0x00000000}},	//   _фуру, wodr, _нисм, --,
   {{0xb87b006c,0x225f02a7,0x00000000,0x00000000}},	//   nyít, _čuki_, --, --,
   {{0x660d06a2,0x2cbd08dd,0x00000000,0x00000000}},	//   ziak, _dswd_, --, --,
   {{0x7c2894c4,0x3f9e94c5,0xfe720405,0xdb180160}},	//   rodr, _ictu_, _ردا_, _savâ,
   {{0x7f3b00c2,0x200e00a8,0x1e5700a5,0x81b60033}},	//   _געבו, lifi_, _השאר_, জাক_,
   {{0x25ab01ef,0x660d94c6,0x81ab0033,0xe9df00b5}},	//   _rbcl_, viak, _কোড_, rjú_,
   {{0x200e94c7,0x00000000,0x00000000,0x00000000}},	//   nifi_, --, --, --,
   {{0xb4d11140,0xa3d211b5,0xa3cc0ca1,0x660d94c8}},	//   वम्_, वाई_, _शोध_, tiak,
   {{0xa3ab01c0,0x200e94c9,0x00000000,0x00000000}},	//   क्न_, hifi_, --, --,
   {{0x660d393b,0x045b00f8,0x2eee0345,0x00000000}},	// [a530] riak, اجرت_, hyff_, --,
   {{0x660d94ca,0x443300a2,0x274301cb,0x00000000}},	//   siak, ulx_, géné_, --,
   {{0x660d94cb,0x31690138,0x59dd01d1,0x3d0f018d}},	//   piak, ñazo_, यापर, _तेने_,
   {{0x3f9e02e1,0x22461fd9,0xdb0110db,0x38690024}},	//   _actu_, gmok_, relø, _ktar_,
   {{0x661d94cc,0xf8c900ab,0x00000000,0x00000000}},	//   _ijsk, िटिय, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x51870804,0x6ec0022e,0xdb1801f7,0xfe45051a}},	//   _гуза, विगु, _navà, онко,
   {{0xdb0a02c9,0x25a994cd,0x63b7024e,0xee39052c}},	//   _dafü, nfal_, lexn, јни_,
   {{0xa3bd193c,0x38691872,0x6a530160,0x1fa7066d}},	//   _आसा_, _ntar_, _năfr, _грег,
   {{0x661d0009,0x25a9012f,0x320f00ac,0xd0110079}},	//   _ljsk, hfal_, ligy_, _غلا_,
   {{0xa3ab09a8,0xbf15004f,0x62976c04,0x661d0009}},	//   क्य_, _بواب, nuxo, _ojsk,
   {{0x7a3600b8,0x98a606cd,0x661d023a,0xf769024b}},	//   mátk, оиме, _njsk, _יק_,
   {{0x7a36024e,0x89361b15,0xfce50043,0x91bf0023}},	//   látk, تعدا, _фоло, _chủ_,
   {{0xdb180176,0xcb6900d4,0xb9020099,0x7a1200ea}},	//   _favà, _таке_, _नऊ_, vātu,
   {{0x26cc1423,0x7bc30043,0x38690009,0x65c602fb}},	//   ído_, _ianu, _etar_, обва,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc33bc5,0x69d694ce,0x7a360187,0x999200d5}},	// [a540] _kanu, _inye, hátk, _chyť_,
   {{0x69c406a2,0xdb1894cf,0x661d0009,0x38a494d0}},	//   _haie, _havá, _ejsk, mör_,
   {{0x7bc332ca,0x05760ad9,0x7a3d94d1,0xf7461de4}},	//   _manu, _واحد, léta, _фено,
   {{0x7bc394d2,0x69c694d3,0x69c401d7,0xdb0a0176}},	//   _lanu, ndke, _jaie, _zafó,
   {{0x7a3d94d4,0x38a42fa8,0x386900a8,0x200e1870}},	//   néta, nör_, _xtar_, tifi_,
   {{0x7bc394d5,0x69c494d6,0x629701dd,0xbe8a1172}},	//   _nanu, _laie, buxo, асие_,
   {{0x38a406ea,0x81e600c8,0x59ca00c0,0x200e94d7}},	//   hör_, যোগ_, ियार, rifi_,
   {{0x85f702b5,0x7bc308dd,0x38a416f1,0x69c494d8}},	//   ַציע_, _aanu, kör_, _naie,
   {{0x1da60567,0x6283024e,0x7bc394d9,0xa0672e3e}},	//   क्षत, ánov, _banu, _мата_,
   {{0x7a360082,0x69d60c1f,0x69c40223,0x290294da}},	//   láth, _anye, _aaie, dzka_,
   {{0x69c409d1,0x386994db,0x201e00e7,0x80c200a1}},	//   _baie, _star_, _ijti_, लिके,
   {{0x38a494dc,0x61e294dd,0x69c494de,0x7a360037}},	//   för_, njol, _caie, náth,
   {{0x7bc394df,0x7a3d00f7,0x38a4013c,0x99a500b5}},	//   _fanu, géta, gör_, ítők_,
   {{0xf8ae00e0,0x7bc300a7,0x69d60088,0x3f9c94e0}},	//   اکي_, _ganu, _enye, ngvu_,
   {{0xadee046c,0xba730312,0x61e294e1,0x45d57a6e}},	//   _जवान_, _قايت, kjol, повс,
   {{0x2c6002d0,0x69c401d7,0x2bd20266,0x69d60107}},	//   _kòd_, _gaie, ताका, _gnye,
   {{0x80ba1649,0x2902004e,0x8ccd004e,0x2eb701c0}},	// [a550] _शैले, czka_, तियो, _आन्त,
   {{0x69a794e2,0x7bc30510,0xdb180187,0x2c6094e3}},	//   ट्री, _xanu, _zavá, _mòd_,
   {{0x2c600c1f,0x77ba00a5,0x67ba00a5,0x00000000}},	//   _lòd_, _המתח, _המתק, --,
   {{0x5bb71bb5,0x799d8764,0x245f001e,0x2bb708b6}},	//   _अस्व, ngsw, _tîm_, _अस्थ,
   {{0x3f6954b8,0xdd0f0168,0x657d005f,0x00000000}},	//   било_, _oľša, _iesh, --,
   {{0x657d94e4,0x645d011e,0x629701ef,0x9f450791}},	//   _hesh, _iusi, puxo, _holé_,
   {{0x657d16b3,0xfd4c0028,0x645d94e5,0x6e95004f}},	//   _kesh, _triể, _husi, ألعا,
   {{0x645d94e6,0x657d52d6,0xf0760332,0x7bc394e7}},	//   _kusi, _jesh, _کیوں_, _sanu,
   {{0x7bc394e8,0x6455462e,0x657d00da,0x2c600284}},	//   _panu, _kizi, _mesh, _còd_,
   {{0x7a3694e9,0x7bc301c2,0x657d01f4,0x6285008c}},	//   máti, _qanu, _lesh, osho,
   {{0x69c494ea,0x645594eb,0x645d94ec,0x7bc317fd}},	//   _paie, _mizi, _lusi, _vanu,
   {{0xa3ab0d00,0x61e9261f,0x38a494ed,0x657d94ee}},	//   क्त_, _joel, tör_, _nesh,
   {{0x7bc394ef,0x645d01c8,0xeb8e24df,0xc95501c8}},	//   _tanu, _nusi, _пи_, дтры,
   {{0xa3ab02e4,0x7a3d94f0,0x61fb01f7,0x657d0107}},	//   _कॉल_, réta, _llul, _aesh,
   {{0x61fb94f1,0x645d8439,0x29022510,0x657d94f2}},	//   _olul, _ausi, szka_, _besh,
   {{0xd90d01ca,0x645d94f3,0xe88654d4,0x657d01f4}},	//   ایی_, _busi, _егип, _cesh,
   {{0x645594f4,0x657d94f5,0xdb0a00fb,0x645d3304}},	// [a560] _bizi, _desh, _hafð, _cusi,
   {{0xf7465a4f,0x6b811cb6,0x7a360279,0xb4bc04bc}},	//   _непо, nalg, dáti, _आनी_,
   {{0x1dbd143a,0x645594f6,0x628594f7,0x61e90a81}},	//   ्यात, _dizi, gsho, _boel,
   {{0x61e994f8,0xa3cc0299,0x44310260,0x6d5994f9}},	//   _coel, _शोर_, _ekz_, _ngwa,
   {{0x59dd009a,0x61e90a45,0x645d018c,0x2fc5009e}},	//   यातर, _doel, _gusi, _balg_,
   {{0x628594fa,0x9f340804,0x2fc50211,0x6d5994fb}},	//   bsho, мелі, _calg_, _agwa,
   {{0x044394fc,0xe2972b79,0x6b8194fd,0x628556e5}},	//   _черн, _нар_, dalg, csho,
   {{0x64553136,0x61e936a6,0x645d00a8,0x6b8a0345}},	//   _zizi, _goel, _yusi, _sdfg,
   {{0x6455007b,0x6b8a0107,0x00000000,0x00000000}},	//   _yizi, _pdfg, --, --,
   {{0x3a20012f,0xe7d70083,0xcfaa00bf,0x61e994fe}},	//   _ajip_, _হত্য, _دارم_, _zoel,
   {{0xdfa50c26,0x39402074,0x0dca021d,0x5b1300af}},	//   _تحقي, _azis_, _гули_, емэт,
   {{0x6d5901a8,0xcefe0471,0x00000000,0x00000000}},	//   _ggwa, ışın_, --, --,
   {{0xa92b005f,0x657d0ca0,0x6b810065,0xc8670423}},	//   сіне_, _resh, balg, ятни,
   {{0x645d94ff,0x657d01e9,0x1dda022e,0x3a200359}},	//   _rusi, _sesh, भावत, _ejip_,
   {{0x645d9500,0xa3e00d55,0x657d00da,0x7bd89501}},	//   _susi, थान_, _pesh, _invu,
   {{0x64550dac,0x645d9502,0x657d01f4,0x070801b2}},	//   _sizi, _pusi, _qesh, سيقي_,
   {{0x657d00da,0x62859503,0x61e90b0d,0xc8c40354}},	// [a570] _vesh, wsho, _roel, _लैपट,
   {{0x64550be2,0x78fc0122,0x26c1006f,0x61e9027c}},	//   _qizi, _לפחו, _tsho_, _soel,
   {{0x64559504,0x2bae02cb,0xfbae0d91,0x61e99505}},	//   _vizi, ज्या, ज्यम, _poel,
   {{0x62859506,0x64552a13,0x7a361fca,0x2fc52b6f}},	//   rsho, _wizi, táti, _salg_,
   {{0x64554c55,0x645d03ad,0xd0ab0009,0x61e93440}},	//   _tizi, _uusi, стед_, _voel,
   {{0x7a364e39,0x61e9864a,0x80c20066,0x628300b5}},	//   ráti, _woel, लिजे, ános,
   {{0x61e9152b,0x6b819507,0x798d012f,0x3e7a00ea}},	//   _toel, valg, _odaw, gūt_,
   {{0x7a364e1c,0x798d1857,0xf1a400af,0x61fb9508}},	//   páti, _ndaw, _прун, _ulul,
   {{0x6b815fd5,0xa3d201d1,0xed5902c4,0xe0df0176}},	//   talg, वाच_, ndži_, _çò_,
   {{0xa3c202e4,0x3e7a0029,0x9f630086,0x798d9509}},	//   ्यय_, būt_, ävät_, _adaw,
   {{0x7a3d024e,0xad27132d,0xfc4600b8,0xdb1800ee}},	//   rétn, _کراو, _říct_, _navä,
   {{0x7bd8950a,0x6b81950b,0x7bc8009e,0x00000000}},	//   _envu, salg, addu, --,
   {{0xb4bc004e,0xa3c21451,0x850c02e4,0x1dda0026}},	//   _आने_, ्यम_, _सेंट_, भारत,
   {{0xfd1005bc,0x2d9f03e6,0x1dbd00b4,0x1c4401e0}},	//   _حجم_, lgue_, ्यवत, _знім,
   {{0xe7ff0084,0xa3d106d9,0x798d0024,0x9f5c00ac}},	//   _उतरा_, वयन_, _fdaw, jivý_,
   {{0xa3ab1edf,0x2d9f05f0,0xceb2011d,0x75f81534}},	//   क्स_, ngue_, כיל_, _vízo,
   {{0xd0400669,0x39400069,0x69c0000d,0x7a0b0067}},	// [a580] _ermə, _uzis_, ômeu, jęty,
   {{0x798d0067,0x00000000,0x00000000,0x00000000}},	//   _zdaw, --, --, --,
   {{0x03a31574,0x91e60d9c,0x386000de,0xf1cf0066}},	//   тихо, може, _huir_, _सोहन,
   {{0xe80a007c,0x00000000,0x00000000,0x00000000}},	//   होरा_, --, --, --,
   {{0x7bc8659a,0x00000000,0x00000000,0x00000000}},	//   yddu, --, --, --,
   {{0x38600874,0x2d9f0138,0xb87b01ef,0x9f5c00d5}},	//   _muir_, egue_, nxía, bivý_,
   {{0x03a338d0,0x4ea60279,0x53a30009,0x00000000}},	//   _широ, фрла, _шарб, --,
   {{0x25a04abf,0xd6c00083,0x9f4501f7,0xef1800ea}},	//   ngil_, _উপায, _alló_, _ceļa_,
   {{0x80a60e0c,0x06370070,0x69a51604,0x7a1200ea}},	//   _زمان, ונקט_, _काबी, vātp,
   {{0x2d9f0147,0x00000000,0x00000000,0x00000000}},	//   ague_, --, --, --,
   {{0x59d00006,0x78b6010b,0x7bc8950c,0xdb1a0055}},	//   _तोहर, _apyv, rddu, metë,
   {{0xe81102e4,0xf1e100b4,0x00000000,0x00000000}},	//   डोना_, फायन, --, --,
   {{0x386041e3,0x2d84950d,0xd90f0148,0x6e220027}},	//   _cuir_, mame_, شید_, _ijob,
   {{0x2d84950e,0x59dd2c2b,0x00000000,0x00000000}},	//   lame_, याहर, --, --,
   {{0xdcc800e2,0x00000000,0x00000000,0x00000000}},	//   _hỉ_, --, --, --,
   {{0x7c3a950f,0xdcc80019,0x4d7b0070,0x69c00132}},	//   lltr, _kỉ_, ַרבע, ômet,
   {{0x3860009e,0xdb1a0055,0xd3a7002d,0xb95501e0}},	// [a590] _guir_, ketë, дреп, _явищ,
   {{0xeddb00b4,0x59dd00a1,0x2d849510,0x4394002d}},	//   _मच्छ, यावर, hame_, каус,
   {{0xa3ab142a,0x6fdd02cb,0xed592d17,0x870701c8}},	//   क्ष_, पासू, leže_, _цяпе,
   {{0x2d8400d8,0x6e229511,0x0b150070,0x7a364a12}},	//   jame_, _njob, ײַער_, bátu,
   {{0xb0680037,0xdcc800e2,0x2d849512,0xdb1a0055}},	//   وصول_, _nỉ_, dame_, fetë,
   {{0x764d06d3,0x248952fe,0x8fa22ce2,0x6e22030d}},	//   lmay, msam_, гаше, _ajob,
   {{0x82a4021d,0xf1a74ae6,0x9f4512c3,0x2d849513}},	//   _иште, _оран, _allò_, fame_,
   {{0x2d84070b,0x764d06d3,0xa3ab0fd1,0xada535ec}},	//   game_, nmay, क्र_, хаил,
   {{0x2d9f2b9f,0xed59025c,0x24899514,0xe13400d8}},	//   rgue_, ježe_, nsam_, _анты,
   {{0x3ec403ad,0x5ba9621f,0x7a360093,0xed590116}},	//   ästä_, чком_, hátt, deže_,
   {{0xa3c21e18,0x3d0f0035,0x764d027d,0x2d8400ee}},	//   ्यत_, _तेरे_, kmay, bame_,
   {{0xc7a902da,0x24899515,0x2d849516,0x6e220031}},	//   _לב_, ksam_, came_, _gjob,
   {{0x7e610244,0x2489006d,0x764d9517,0x39350c8a}},	//   _hulp, jsam_, dmay, вэрс,
   {{0x7e619518,0xb6c800b5,0x00000000,0x00000000}},	//   _kulp, وازے_, --, --,
   {{0xf626052c,0x1da60066,0xb87b0042,0x7e610523}},	//   едво, क्कत, rxía, _julp,
   {{0x764d596c,0xa2c3051d,0xdb1a01f4,0x7a366493}},	//   gmay, रबन्, zetë, tátu,
   {{0x25a09519,0x2489951a,0x7986951b,0xed590009}},	// [a5a0] rgil_, gsam_, makw, beže_,
   {{0x2d84951c,0x7a36951d,0xa3ab198f,0x36c610b4}},	//   zame_, rátu, क्ल_, _због,
   {{0x2bf600c2,0x6e3b951e,0x248908dd,0x1bf60070}},	//   עמען_, klub, asam_, עצער_,
   {{0xeac90028,0x7986951f,0x2d840015,0xa5bb0093}},	//   _mẹ_, nakw, xame_, _hjón,
   {{0xdb1a00da,0x2d8401ba,0x2489001e,0xdb01191b}},	//   tetë, vame_, csam_, lflä,
   {{0xe7e30035,0x6e9403e6,0xdcc80023,0x66040159}},	//   खाया_, вику, _rỉ_, lhik,
   {{0x75f8024e,0x2d849520,0x81b50083,0xdb1a01f4}},	//   _nízk, tame_, জয়_, retë,
   {{0x63be9521,0x433b00c2,0xb14804e8,0x9f5c0453}},	//   lepn, _זעלב, _قیام_, tivó_,
   {{0x2d849522,0xe7e306bb,0x7986925d,0x1aed0083}},	//   rame_, खामा_, dakw, _ছেলে_,
   {{0xdee61878,0x2d849523,0xdb1a7974,0x6adb0026}},	//   _пози, same_, leté, यमूर,
   {{0x629e9524,0x7986073a,0xed590169,0x7a3600b5}},	//   nupo, fakw, veže_, játs,
   {{0xdcc801a5,0xdb1a006c,0x6e3b9525,0x1da70e62}},	//   _tỉ_, neté, club, _गायत,
   {{0xa3c29526,0x66049527,0xed59116d,0x629e029c}},	//   ्या_, dhik, teže_, hupo,
   {{0x629e2018,0x2bd72188,0xdb1a52d5,0x7793042c}},	//   kupo, _भोपा, heté, دیدا,
   {{0x764d037a,0x798625b0,0xf64778bd,0xed590a66}},	//   tmay, bakw, ехан, reže_,
   {{0x66041fd9,0xed5903ab,0x7bca9528,0xdb1a000d}},	//   ghik, seže_, _hafu, jeté,
   {{0xdbf9006a,0x764d06d3,0x7bca25b4,0x7a36008a}},	// [a5b0] _głów, rmay, _kafu, rátt,
   {{0xdd86006c,0x24899529,0x764d952a,0x7a36003e}},	//   _ھو_, rsam_, smay, sátt,
   {{0x7bca0657,0x2489952b,0xdd8601df,0x764d033e}},	//   _mafu, ssam_, _پو_, pmay,
   {{0xf77000f8,0x6604952c,0x7bca00e9,0xdb1a00b5}},	//   _پای_, chik, _lafu, geté,
   {{0x8fa55a00,0xa3cc1119,0x9f4500ac,0x91bf00cc}},	//   вале, _शोक_, _volí_, _chú_,
   {{0x7bca0f25,0x244600a2,0xe8d900e2,0x7e61952d}},	//   _nafu, tôme_, _ngọ_, _pulp,
   {{0xd00e600c,0x79860428,0x00000000,0x00000000}},	//   تلو_, yakw, --, --,
   {{0x7e61486c,0xed59325e,0x53340819,0x24461f3c}},	//   _vulp, мой_, _сест, rôme_,
   {{0x7bca2107,0x6e3b0034,0x9f5c07e5,0x9f4c0107}},	//   _bafu, rlub, rivò_, _lodè_,
   {{0x6e3b8f06,0x798608a0,0x7a3d952e,0x00000000}},	//   slub, wakw, léth, --,
   {{0x91f5009a,0xcd2b01df,0xda7801c8,0x798605ba}},	//   _आवाज_, _کسان_, няў_, takw,
   {{0xa5bb008a,0x3f87030a,0x7bca0103,0x09b50831}},	//   _sjón, lanu_, _eafu, _জোবা,
   {{0xa3d105f8,0x798601d5,0x63b500cd,0x6d5c0355}},	//   वया_, rakw, _obzn, ěrat,
   {{0xdb1a0332,0x3dcd952f,0x7bca9530,0x3f876893}},	//   zeté, ldew_, _gafu, nanu_,
   {{0x44339531,0xe7379532,0x6604027c,0x26160026}},	//   dox_, вер_, thik, _नगदी_,
   {{0x6b839533,0x3f879534,0xdb0101ae,0x7a362d95}},	//   _heng, hanu_, rflä, ráts,
   {{0x2cad49bf,0x6b839535,0x7bca462e,0x2bae018d}},	// [a5c0] nted_, _keng, _yafu, ज्वा,
   {{0x389b00c2,0x66049536,0x629e9537,0x6b839538}},	//   _קיינ, shik, tupo, _jeng,
   {{0x6b831760,0x3f87029d,0xf62601c8,0x8c3d0095}},	//   _meng, danu_, _адно, muşd,
   {{0x629e9539,0x63be953a,0x44210023,0x9f470031}},	//   rupo, sepn, anh_, ajnë_,
   {{0x629e190b,0xdb1a00b5,0xa5bb0093,0xa067953b}},	//   supo, reté, _mjól, вача_,
   {{0x3f87953c,0x93463ac3,0x6b83953d,0x44330815}},	//   ganu_, _анге, _neng, cox_,
   {{0xa2e3953e,0x9f450036,0xb5fb0138,0x529902fb}},	//   _корд, _colà_, _diáf, _пътя_,
   {{0x645c0291,0x9f450107,0x2cad11b6,0xe45f0523}},	//   _hiri, _dolà_, fted_, _kröp_,
   {{0x6b836467,0x645c44da,0x23670888,0x3f87273a}},	//   _beng, _kiri, žnje_, banu_,
   {{0x645c953f,0x69a502cb,0x3f879540,0x443805eb}},	//   _jiri, _काही, canu_, _jkr_,
   {{0x6b834150,0x2cad0122,0xcfa91dbf,0x44389541}},	//   _deng, ated_, _سالم_, _mkr_,
   {{0xc33335d9,0x645c8a5f,0x7bca3eb0,0x6b839542}},	//   יות_, _liri, _wafu, _eeng,
   {{0x2cad0052,0x7a3d76b5,0x6b83200b,0x7bca3eb0}},	//   cted_, néti, _feng, _tafu,
   {{0x6b839543,0x645c9544,0x44330069,0x9f4500d5}},	//   _geng, _niri, xox_, _holá_,
   {{0x65959545,0x7a3d000d,0x9f450168,0xb595126e}},	//   лаву, héti, _kolá_, ливш,
   {{0x645c9546,0xed5904c3,0x6b839547,0x3f875f44}},	//   _airi, leža_, _zeng, zanu_,
   {{0x645c817c,0x73d90760,0x44384863,0x6b839548}},	// [a5d0] _biri, ндар_, _bkr_, _yeng,
   {{0x337421df,0x46ac0084,0x3f8700d5,0x93940037}},	//   игур, _चहचह, xanu_, لجما,
   {{0x3f87180c,0xf3640043,0x1dd2045c,0x7d090382}},	//   vanu_, ртун, थयात, zzes,
   {{0x645c9549,0xa2941958,0xdb08954a,0x69cf5bd8}},	//   _eiri, раці, ledó, ndce,
   {{0x3f87954b,0x2cad2ea2,0x765d0159,0xe13400d8}},	//   tanu_, xted_, _iisy, анцы,
   {{0x645c954c,0x765d0034,0x13a703c5,0xed59012e}},	//   _giri, _hisy, _جنسی_, ježa_,
   {{0x6b83954d,0xed5903ab,0x765d0103,0xa3c21365}},	//   _reng, deža_, _kisy, ्यर_,
   {{0x6b831034,0x656d62dd,0x2cad954e,0x645c954f}},	//   _seng, ncah, tted_, _ziri,
   {{0x6b830464,0x3f879550,0x765d2230,0x645c04fb}},	//   _peng, panu_, _misy, _yiri,
   {{0x645c9551,0x2cad9552,0x60c99553,0x7d099554}},	//   _xiri, rted_, _isem, rzes,
   {{0x2cad172d,0x6b839555,0x7d093a5f,0x387291c7}},	//   sted_, _veng, szes, _styr_,
   {{0x6b839556,0x2cad00a5,0x765d010d,0xdb019557}},	//   _weng, pted_, _nisy, nglé,
   {{0x6b880486,0x3f850088,0xdb01002a,0x60c99558}},	//   badg, _kelu_, nflú, _jsem,
   {{0x9d1a0779,0x7c92004f,0x765d6307,0x60c99559}},	//   _אונט, _الوص, _aisy, _msem,
   {{0x3f85955a,0x645c64cd,0x7bc1955b,0x765d955c}},	//   _melu_, _riri, melu, _bisy,
   {{0x645c955d,0x7bc12930,0x4438955e,0x60c9955f}},	//   _siri, lelu, _skr_, _osem,
   {{0x645c6eed,0x765d9560,0x44380a4e,0x7a3d002a}},	// [a5e0] _piri, _disy, _pkr_, xéti,
   {{0x7bc19561,0xdb0800b5,0x645c1280,0x1bfc00b4}},	//   nelu, yedü, _qiri, एसएल_,
   {{0x645c9562,0x60c97564,0x20070031,0x6aa10138}},	//   _viri, _asem, dhni_, nulf,
   {{0x645c9563,0x7a3d2140,0x216a0036,0x7bc19564}},	//   _wiri, téti, хиди_, helu,
   {{0x645c9565,0x7bc13a87,0x3f8539e7,0x320600de}},	//   _tiri, kelu, _belu_, rhoy_,
   {{0x3f859566,0x645c00f1,0x7a3d259e,0xccf90035}},	//   _celu_, _uiri, réti, dyś_,
   {{0x3f851dce,0x60c99567,0x7bc19568,0x69a5360b}},	//   _delu_, _esem, delu, _काली,
   {{0x7a3d00f7,0x7c380355,0x6b88012f,0x3df4002d}},	//   péti, _skvr, wadg, рзис,
   {{0xed590c0a,0xa0c90037,0x9f450097,0x2dd70037}},	//   teža_, _لذلك_, _volá_, طبية_,
   {{0x7bc13569,0x200706d9,0xd7040d00,0x67040c57}},	//   gelu, chni_, रनाथ_, रनाक_,
   {{0xd43702b5,0xa5bb0093,0x6b88081c,0x705301cb}},	//   רטיי_, _sjóm, radg, _انلا,
   {{0x80bb007c,0xccf90067,0x00000000,0x00000000}},	//   _एहमे, byś_, --, --,
   {{0x7bc19569,0xdb1a956a,0x69cf01ff,0x00000000}},	//   belu, metí, rdce, --,
   {{0xb8ed3054,0xdb1a956b,0x765d0185,0x753d0067}},	//   _रन_, letí, _sisy, _rysz,
   {{0x765d0cca,0xf3f9002d,0x656d00d7,0xdb081725}},	//   _pisy, _îţi_, tcah, redó,
   {{0xe6644076,0xe4e70823,0xd4e71eb9,0x9980027b}},	//   стро, лізн, люзи, _imiş_,
   {{0xa3c200e7,0x261600c0,0xf79501f1,0xf9940d85}},	// [a5f0] ्यं_, _नगरी_, _капэ, _פרץ_,
   {{0x59dd05f8,0x32040088,0x00000000,0x00000000}},	//   याकर, _almy_, --, --,
   {{0x753d006a,0x63a50037,0x7afa8dd7,0xdb1a747a}},	//   _wysz, rghn, nytt, letâ,
   {{0x3f853b12,0x4a7b016b,0x956402fb,0x63a514a0}},	//   _selu_, גראב, _гърд, sghn,
   {{0x3f850118,0x00000000,0x00000000,0x00000000}},	//   _pelu_, --, --, --,
   {{0xa3c21371,0xa3ac0e04,0x60c9008b,0x1e95167d}},	//   ्यः_, _गाय_, _vsem, арир,
   {{0x7bc10043,0x2c6901ba,0x00000000,0x00000000}},	//   velu, _súd_, --, --,
   {{0x2007751f,0x60c9956c,0x8cb51566,0xb5fb00b5}},	//   shni_, _tsem, асоч, _hiáb,
   {{0xdd910332,0xfde6081b,0xb882000c,0x7bc1956d}},	//   موں_, рдык_, říze, telu,
   {{0x5e870a93,0x00000000,0x00000000,0x00000000}},	//   _будз, --, --, --,
   {{0x2005035f,0xa7200083,0xab291fff,0x394905ca}},	//   _illi_, _ধর্ম_, тона_, _azas_,
   {{0x186a10a9,0x7bc10f1a,0x224d0118,0xaa850168}},	//   ками_, selu, _jhek_, _niýš,
   {{0x3949006a,0x2b150006,0xdb0a02b1,0x00000000}},	//   _czas_, _फेरु_, _abfä, --,
   {{0xbd440098,0x68e20484,0x7afa279f,0x67230124}},	//   _انهي, _ġodd, bytt, _žnja,
   {{0x9f450392,0xe73a0be8,0x8ccd057c,0xf41b0831}},	//   _dolç_, тев_, तिको, তকার_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d10d55,0xd4670cac,0x2005956e,0x64a60aef}},	// [a600] वयं_, иите_, _olli_, раза,
   {{0x779405f5,0x00000000,0x00000000,0x00000000}},	//   _دیسا, --, --, --,
   {{0x213f028b,0x66e6956f,0x179b076b,0x00000000}},	//   _ayuh_, _тона, _בייב, --,
   {{0x64a6231c,0x20059570,0x224d9571,0x213f00e0}},	//   _кама, _alli_, _chek_, _byuh_,
   {{0x23670496,0xb5fb1e15,0x5fe2000c,0x224d00f8}},	//   žnja_, _fiáb, पालल, _dhek_,
   {{0xd00f03fb,0x224d9572,0x26da02a7,0x7afa00c3}},	//   ولن_, _ehek_, _krpo_, yytt,
   {{0x225f9573,0x9e0610d7,0xf65f03d0,0x00000000}},	//   _fiuk_, ичил, _yiæ_, --,
   {{0xdef7057a,0x291e0225,0x7afa0421,0x9757024b}},	//   рыш_, ştay_, vytt, סיקו_,
   {{0xafe63e4b,0xa06a1f1e,0x00000000,0x00000000}},	//   _коал, _раза_, --, --,
   {{0x34b70052,0x9f4c0187,0x7afa00c3,0x26da01ed}},	//   ספים_, _hodí_, tytt, _orpo_,
   {{0x8aa30ebb,0xa3ab0d00,0xdb1a0300,0x03d70317}},	//   оряд, क्ट_, petí, בוים_,
   {{0xf2d300c2,0x13cf0083,0x4efb0070,0x201c9574}},	//   קער_, রায়, _שלאג, livi_,
   {{0xe7e3009a,0xc31a00c8,0x1bd40133,0x7996001e}},	//   खाला_, _তুমি_, _голя, _ddyw,
   {{0x9f4c0097,0x26090066,0x25ab01f7,0x201c00f6}},	//   _lodí_, _सतही_, _sccl_, nivi_,
   {{0xc6681a31,0xa3e00084,0xf8ae0647,0x25ab028b}},	//   иште_, थाई_, وکی_, _pccl_,
   {{0x7a2801d6,0x9f4c0036,0x442a9575,0x8c3d00c1}},	//   nıtl, _rodì_, _ajb_, muşa,
   {{0xf3670cac,0x201c9576,0x24f81ac5,0x629e0345}},	// [a610] атен, kivi_, анты_, erpo,
   {{0x201c0888,0x442a0009,0x224d01f4,0x644e009e}},	//   jivi_, _cjb_, _shek_, _chbi,
   {{0x9f4c0176,0x93190037,0x201c00f4,0xb5fb01ef}},	//   _bodí_, دقاء_, divi_, _viáb,
   {{0xf1e14092,0x386900d7,0xb5fb1d2b,0x00000000}},	//   फाइन, _kuar_, _diác, --,
   {{0xe9df0391,0x629e0051,0x3ebe01ef,0x83871ac5}},	//   clúe_, arpo, _aptt_, _выбе,
   {{0x38699577,0x25a99578,0x7e6801cf,0x00000000}},	//   _muar_, lgal_, _budp, --,
   {{0x38695a95,0x92944738,0x22945866,0xa29401e0}},	//   _luar_, _марц, _миря, _марі,
   {{0x25a99579,0xf1cf0299,0xf2d20070,0x7d1d0093}},	//   ngal_, _सोचन, _צען_, ússo,
   {{0x20240093,0x814500b5,0x201c00cd,0x00000000}},	//   ðrið_, _اچان, bivi_, --,
   {{0x2005957a,0x201c0036,0x5fae0067,0x60db0371}},	//   _ulli_, civi_, _घायल, _irum,
   {{0x3946957b,0x27e6957c,0x7c2a005f,0x00000000}},	//   _šos_, _đon_, _djfr, --,
   {{0xa3de0429,0xf76900a5,0x00000000,0x00000000}},	//   _दोन_, _טק_, --, --,
   {{0xed4e0ff6,0xeaae006c,0xa3e80722,0x2a6000ab}},	//   _хо_, وٹی_, _मचल_, _viib_,
   {{0x186703f5,0x6d4b957d,0x38690031,0x59b804aa}},	//   сари_, _izga, _duar_, ेजहर,
   {{0xa3ab06bb,0x00000000,0x00000000,0x00000000}},	//   क्छ_, --, --, --,
   {{0x25a90148,0x3869957e,0x60db004b,0x056602fb}},	//   ggal_, _fuar_, _orum, сван,
   {{0x7a3d008a,0x69c61197,0xe3ba957f,0x3861012f}},	// [a620] rétt, meke, лба_, _fihr_,
   {{0x69c63223,0x25a9004f,0x657f006d,0x201c00a8}},	//   leke, agal_, abqh, xivi_,
   {{0x7a3d8ddc,0xa3b90006,0x7a2801d6,0x59dd00ab}},	//   métr, _अउर_, yıtl, याचर,
   {{0xdb1a4a22,0x7a3d9580,0x38610116,0x71a6010b}},	//   netá, létr, _zihr_, садз,
   {{0x201c9581,0x10a33d51,0x7644027b,0x69c601ed}},	//   tivi_, зичн, mliy, ieke,
   {{0x60db9582,0x76440092,0x69c69583,0x7a3d1f96}},	//   _drum, lliy, heke, nétr,
   {{0x201c0fed,0x69c69584,0x443a0486,0x60db073a}},	//   rivi_, keke, mop_, _erum,
   {{0x44449585,0x60db9586,0x201c9587,0x5c743f6c}},	//   ll_, _frum, sivi_, олит,
   {{0x69c60332,0x60db69f6,0x44449588,0x201c07e7}},	//   deke, _grum, ol_, pivi_,
   {{0xda7a4a2f,0x44449589,0x443a0278,0x764401fb}},	//   лям_, nl_, nop_, hliy,
   {{0x4444958a,0x7644958b,0x6d4b01a3,0x63ae0118}},	//   il_, kliy, _ezga, _mcbn,
   {{0x44443f58,0x69c6958c,0x3f8e000e,0x386901ef}},	//   hl_, geke, lafu_, _puar_,
   {{0x443a958d,0x63bc0169,0x4444958e,0xdb180138}},	//   kop_, _obrn, kl_, _pavó,
   {{0x4444958f,0x06c00033,0x3f8e8cd0,0x321d0067}},	//   jl_, _উপজি, nafu_, ziwy_,
   {{0xd5bb9590,0x69c69591,0x44449592,0x2bb70122}},	//   лса_, beke, dl_, _הפוך_,
   {{0x7c3a50c3,0x44443d29,0x69c69593,0x7644596c}},	//   lotr, el_, ceke, gliy,
   {{0x3f8e276d,0x44449594,0x60c400d0,0x6fa900a1}},	// [a630] kafu_, fl_, çiml, _घालू,
   {{0xf3679595,0x4444888b,0x76440103,0x7c281506}},	//   стан, gl_, aliy, nndr,
   {{0x764470aa,0x7c289596,0x60db012f,0x236708b7}},	//   bliy, indr, _srum, žnjo_,
   {{0xddc10043,0x7a2800a8,0x76441684,0x60db9597}},	//   _mulţ, yıtm, cliy, _prum,
   {{0x44440297,0x660d1b68,0x00000000,0x00000000}},	//   bl_, mhak, --, --,
   {{0x7c3a9598,0x69c69599,0x4444959a,0xd0060dee}},	//   jotr, zeke, cl_, жеше_,
   {{0x1dda0324,0x69c6959b,0x6d420103,0x59c900ab}},	//   _मोहत, yeke, _ayoa, िजार,
   {{0x644517f0,0x7c28959c,0x171c0070,0xa3d10026}},	//   llhi, endr, טווע, वयक_,
   {{0x7e62959d,0x7c3a959e,0x69c600b5,0x60db5c03}},	//   _diop, fotr, veke, _urum,
   {{0x69c6959f,0x7c3a95a0,0x76440095,0x660d3ed9}},	//   weke, gotr, zliy, hhak,
   {{0x69c695a1,0x2fc795a2,0x26c1006d,0x660d0051}},	//   teke, meng_, _npho_, khak,
   {{0x2fc795a3,0x3ea70443,0xef1800ea,0x7e620036}},	//   leng_, munt_, _ceļu_, _giop,
   {{0x6d4b180c,0x29040841,0x443a383a,0x660d00f8}},	//   _uzga, áma_, yop_, dhak,
   {{0x69c695a4,0x2fc701ca,0x78a600cb,0x290c0035}},	//   seke, neng_, rukv, ąda_,
   {{0x69c695a5,0x444401b4,0xdb1a95a6,0x3ea70395}},	//   peke, vl_, petá, nunt_,
   {{0x2fc795a7,0xe57a150d,0x18a602c4,0x660d0c47}},	//   heng_, рза_, _даим, ghak,
   {{0x764401c2,0x2fc795a8,0x4444001e,0x3ea795a9}},	// [a640] rliy, keng_, tl_, hunt_,
   {{0x444495aa,0x2fc700bf,0xa3e70ec5,0x9f88008d}},	//   ul_, jeng_, भाष_, jóði_,
   {{0x443a3d7c,0x42ca09cc,0x2fc795ab,0xdc3900a8}},	//   rop_, рген_, deng_, nçıl,
   {{0xa3ac2fa9,0xe0da4a4e,0x660d95ac,0x3ea700b9}},	//   _गाव_, иве_, chak, dunt_,
   {{0x2fc795ad,0x444495ae,0x6e2903e0,0x998900d5}},	//   feng_, pl_, dneb, _dlaň_,
   {{0x2bae0d00,0x7e6295af,0x2fc700d1,0xdc390716}},	//   ज्ञा, _siop, geng_, kçıl,
   {{0x3ea701f7,0xa3e70246,0xe2973bd5,0x7c3a063c}},	//   gunt_, भार_, _мар_, votr,
   {{0x660495b0,0xdcba02fb,0x6b8a0055,0x69bc022e}},	//   nkik, ащо_, _sefg, ष्मी,
   {{0xf6530052,0x2fc795b1,0x9f4c0097,0x660401a3}},	//   וצה_, beng_, _dodá_, ikik,
   {{0x3ea70107,0x60cd2e00,0x22460484,0x2fc746d4}},	//   bunt_, çame, llok_, ceng_,
   {{0xdd8f0200,0x66045ab3,0x7c2895b2,0xa5bb00d5}},	//   _ош_, kkik, rndr, _kjót,
   {{0x7c3a0083,0x8c3d033e,0x5ce60037,0x6e3b00a2}},	//   sotr, luşl, _وكال, coub,
   {{0x7c3a95b3,0xfbcf09b9,0x7e7a95b4,0x6d42010d}},	//   potr, رتی_, _http, _uyoa,
   {{0x660d01ef,0x6e2095b5,0xd83b61ad,0x39450080}},	//   whak, limb, рэм_, āls_,
   {{0x660d00d1,0x3f8c0520,0x224695b6,0x4b7b0070}},	//   thak, _medu_, klok_, _דאוו,
   {{0x6e201034,0x1dbc057c,0xa5bb0093,0x80bc00dc}},	//   nimb, ्जित, _njót, ोबाइ,
   {{0x660d6bd8,0x224602b3,0x2fc795b7,0xe9df002a}},	// [a650] rhak, dlok_, yeng_, clúa_,
   {{0x660d070b,0x6e2095b8,0xd37b2c61,0xb5fb0019}},	//   shak, himb, рча_, _gián,
   {{0x660d0282,0x6e2030c6,0xc7b202b8,0x798d012f}},	//   phak, kimb, _אבי_, _keaw,
   {{0xdce90274,0x7bc888cc,0x6e200054,0x56da0070}},	//   zbeđ, hedu, jimb, _פֿיד,
   {{0x2fc701ca,0x3f8c17d1,0x7e7a03d0,0x00000000}},	//   teng_, _bedu_, _attp, --,
   {{0x3ea70051,0x7bc83731,0x3f8c0036,0x224683c1}},	//   tunt_, jedu, _cedu_, alok_,
   {{0x2fc700bf,0x44210693,0x6e3b0009,0x7bc83f9b}},	//   reng_, mih_, toub, dedu,
   {{0x44212b63,0x3ea795b9,0x2fc795ba,0xf1a40036}},	//   lih_, runt_, seng_, _орун,
   {{0x6e290c61,0x2fc708eb,0x6e3b95bb,0x3f8c00d5}},	//   rneb, peng_, roub, _fedu_,
   {{0x44210888,0x3ea795bc,0xdc390463,0x46cb1e82}},	//   nih_, punt_, tçıl, ाबाह,
   {{0x6e2095bd,0x661d428f,0x66040159,0x442102ec}},	//   bimb, _omsk, ykik, iih_,
   {{0xdeba0122,0x91c90066,0xdc39013b,0xdb1a00c3}},	//   _למעל, _रसोइ, rçıl, detä,
   {{0x44216edc,0xfce595be,0x3e7195bf,0xa5bb00fb}},	//   kih_, _холо, _hát_, _ljós,
   {{0x442155bc,0x913a02b5,0xed59022f,0x7bc895c0}},	//   jih_, מערק, ježi_, cedu,
   {{0x44210169,0xa3c10e6f,0x26de0391,0xed592163}},	//   dih_, ्जन_, íto_, deži_,
   {{0x3e710019,0x8afa0122,0x966395c1,0x7afc95c2}},	//   _mát_, _להצי, ексе, ärte,
   {{0x66044020,0x3e7195c3,0x98ac00ea,0x00000000}},	// [a660] rkik, _lát_, ādē_, --,
   {{0x660495c4,0x442195c5,0x6e2033af,0xe8d90019}},	//   skik, gih_, zimb, _ngộ_,
   {{0x3f8c1848,0xdb1a01d6,0x69d695c6,0xa1c604bf}},	//   _redu_, retç, _kaye, збед,
   {{0x23720080,0x7bc806a2,0x69d63ad3,0x3f8c95c7}},	//   _šajā_, zedu, _jaye, _sedu_,
   {{0x4421203f,0x6e20023c,0x38b67752,0x200e012f}},	//   bih_, vimb, nær_, thfi_,
   {{0x442133c7,0x3e7195c8,0x69d62715,0x6e2095c9}},	//   cih_, _bát_, _laye, wimb,
   {{0xc0590a55,0x3e710019,0x7bc83b9b,0x22461b18}},	//   ції_, _cát_, vedu, plok_,
   {{0x3e71024e,0x23ac00c0,0x69d695ca,0x646700b5}},	//   _dát_, _चाँद, _naye, _óriá,
   {{0x6e200a74,0x7bc801ed,0x798d0069,0x00000000}},	//   rimb, tedu, _reaw, --,
   {{0x6e200198,0x798d95cb,0x307b024b,0x00000000}},	//   simb, _seaw, _לאמנ, --,
   {{0x69d695cc,0x600f0185,0xcd3605f5,0x9f7b00a5}},	//   _baye, _dømd, _کراب, _הנבח,
   {{0x69d67285,0x00000000,0x00000000,0x00000000}},	//   _caye, --, --, --,
   {{0x69d695cd,0xb5fb08c0,0x7bc895ce,0x5c0601d3}},	//   _daye, _diál, pedu, _няка,
   {{0xc60500e7,0xdb1a0086,0x96050af9,0x661d1dab}},	//   रस्य_, tetä, रस्ट_, _smsk,
   {{0x44210888,0x3bbb02b8,0x98be0029,0xed590116}},	//   vih_, _המוד, ātā_, veži_,
   {{0x442101ca,0x38b603d8,0x69d695cf,0x00000000}},	//   wih_, bær_, _gaye, --,
   {{0x200c00b9,0xed59011c,0xa5bb003e,0x00000000}},	// [a670] _oldi_, teži_, _sjós, --,
   {{0x7d1d95d0,0x69d603d0,0xb8830355,0x1be20f06}},	//   ússi, _zaye, říst, _कोमल_,
   {{0x442195d1,0x8c4101ae,0x999001ba,0x569400d8}},	//   rih_, äßig, ťaťa_, _паэт,
   {{0x44211512,0x200c95d2,0xf8b10026,0x661d78d7}},	//   sih_, _aldi_, _जमाय, _umsk,
   {{0x3e710028,0x92ad0083,0xa5bb008a,0xa2cd0d2a}},	//   _sát_, কবে_, _fjór, _धैर्,
   {{0x442139fd,0xc4d20122,0x3e710355,0x28de0355}},	//   qih_, _שגם_, _pát_, मिति,
   {{0x290212ad,0x74db0f17,0x69ce0066,0x4431023a}},	//   zyka_, निवृ, _तसली, _ijz_,
   {{0xcfcd0083,0xec793425,0x8c3d027b,0x3e7100cc}},	//   লাইন, опи_, ruşm, _vát_,
   {{0x61e995d3,0x4c35010b,0xb87b01ef,0x3e710298}},	//   _inel, дэнт, nvíd, _wát_,
   {{0x69d695d4,0x3e710023,0xb5fb002a,0x38b684fd}},	//   _saye, _tát_, _siál, vær_,
   {{0x61fb95d5,0x69d695d6,0xf98a0088,0x61e90d35}},	//   _koul, _paye, يندي_, _knel,
   {{0xa3c1009a,0x2902004e,0x61fb0086,0x38b60c61}},	//   ्जड_, tyka_, _joul, tær_,
   {{0x9f5800b5,0xeb990819,0x61fb1fd3,0x00000000}},	//   özök_, _дил_, _moul, --,
   {{0xb8f60006,0xb5fb2675,0x61fb95d7,0x290295d8}},	//   _सन_, _diám, _loul, ryka_,
   {{0xa3de0302,0xb4e6021a,0xf74305f2,0x61e995d9}},	//   _दोष_, भम्_, веро, _onel,
   {{0x23780121,0x61fb95da,0xa5bb008d,0x00000000}},	//   _sfrj_, _noul, _sjór, --,
   {{0x44310051,0x3a20021d,0x2d8f0024,0x00000000}},	// [a680] _bjz_, _imip_, _mege_, --,
   {{0x2d8f95db,0x61e995dc,0xe4570746,0x4ad104aa}},	//   _lege_, _anel, джу_, _तनाव,
   {{0x61fb95dd,0x44310a8a,0x320d0103,0x316a3fcb}},	//   _boul, _djz_, _bley_, ошло_,
   {{0x61fb95de,0xed5903c9,0x2d8f95df,0x6f030067}},	//   _coul, ležu_, _nege_, dync,
   {{0x61fb95e0,0xe7e344d2,0x00000000,0x00000000}},	//   _doul, खाचा_, --, --,
   {{0xd12f16e6,0x23780132,0xdbcc0093,0x60cd95e1}},	//   جمه_, _ufrj_, jóðu, çama,
   {{0x61fb95e2,0x2d8f95e3,0xdb01191b,0xe7c0012f}},	//   _foul, _bege_, nglä, श्यप,
   {{0x3ea001c0,0x600f0a8c,0x00000000,0x00000000}},	//   čit_, _røme, --, --,
   {{0x2d8f34e8,0x00000000,0x00000000,0x00000000}},	//   _dege_, --, --, --,
   {{0x61fb2c60,0xed59264f,0x9f4500ac,0x2b47099e}},	//   _zoul, ježu_, _holý_, _bync_,
   {{0xa3c11b8f,0xa3ac366c,0xfff50919,0x00000000}},	//   ्जत_, _गाई_, _سکوت_, --,
   {{0x2d8f95e4,0x00000000,0x00000000,0x00000000}},	//   _gege_, --, --, --,
   {{0xb4bd9526,0x9cb30037,0xf99f00e0,0x00000000}},	//   _आहे_, _لمنت, dhèt_, --,
   {{0x236702dd,0x36d52c0f,0x2d8f8fcc,0x00000000}},	//   žnji_, ногр, _zege_, --,
   {{0x80d50084,0x683f00b8,0xc5fb0370,0x501b024b}},	//   _मैने, vádě, оѓа_, קולו,
   {{0x7bd895e5,0x7bda95e6,0x99670374,0xf1b907c0}},	//   _havu, ldtu, _отпл, _omša_,
   {{0x61fb95e7,0x7bd895e8,0x54550e60,0xed590228}},	// [a690] _roul, _kavu, еват, bežu_,
   {{0x61fb95e9,0x61e90a75,0x2a6901e8,0x7bda4f5d}},	//   _soul, _snel, _hiab_, ndtu,
   {{0x61fb95ea,0x2a69006f,0x7bd83776,0x65950746}},	//   _poul, _kiab_, _mavu, _пану,
   {{0x7bd895eb,0xe4a7002d,0x50b595ec,0x00000000}},	//   _lavu, _орго, еску, --,
   {{0x61fb02e1,0x2d8f95ed,0xd4790070,0xa5bb00a0}},	//   _voul, _rege_, _מאָל, _emóc,
   {{0x61fb6c8b,0x7bd86718,0x2a690189,0xa3ac22a7}},	//   _woul, _navu, _liab_, _गाए_,
   {{0x61fb95ee,0x200795ef,0x2d8f95f0,0x00000000}},	//   _toul, rkni_, _pege_, --,
   {{0x61e995f1,0x2a6901e8,0xa2cc0026,0x63ad00af}},	//   _unel, _niab_, सबर्, şină,
   {{0xdd9100f5,0x7bd80a74,0x6f030051,0x394901e8}},	//   نوں_, _bavu, sync, _nyas_,
   {{0xaf0704bf,0x2d8f033b,0xceeb0fda,0x00000000}},	//   _очек, _wege_, _وران_, --,
   {{0xdbcc05ee,0x7bd895f2,0x7a280381,0xed5900f4}},	//   róðu, _davu, kıtt, vežu_,
   {{0x2a6901e8,0x7afc013c,0x13d80033,0xd9aa0380}},	//   _ciab_, ärta, সায়, कलेट,
   {{0xa3c106bc,0x7bd8035f,0xed59011c,0x2a690107}},	//   ्जा_, _favu, težu_, _diab_,
   {{0x7bd84ea7,0x3949011e,0x3d180035,0x660f0132}},	//   _gavu, _dyas_, _बेटे_, _alck,
   {{0x2a690036,0x7bc395f3,0xed590207,0x96560274}},	//   _fiab_, _ibnu, režu_, еђај,
   {{0x7bd895f4,0xdb0194b7,0xed5900cd,0x00000000}},	//   _zavu, rglä, sežu_, --,
   {{0x64a318d3,0x7bd80232,0x2cad00a5,0x69c4007a}},	// [a6a0] лата, _yavu, nued_, _ibie,
   {{0xa3e795f5,0x68e495f6,0x93c8006c,0x2a6901e8}},	//   भाग_, _irid, بارہ_, _ziab_,
   {{0xf99f02d0,0x68e40506,0x786b009f,0xa3c10067}},	//   chès_, _hrid, _iżva, ्ज़_,
   {{0xa2d504aa,0x2a690221,0x68e495f7,0x69c4035f}},	//   णिज्, _xiab_, _krid, _jbie,
   {{0x3949006d,0x69c495f8,0x68e4035f,0x40b400af}},	//   _xyas_, _mbie, _jrid, треӂ,
   {{0x2ab80332,0xe8d901a5,0x27170033,0x69c4007a}},	//   yéb_, _ngờ_, _দুটো_, _lbie,
   {{0x69c495f9,0xdc1200a8,0xa2e302fb,0x7bd840c5}},	//   _obie, xşıl, _йорд, _ravu,
   {{0x6ed30669,0x7bd895fa,0x387f00af,0x68e495fb}},	//   _xəbə, _savu, ţuri_, _orid,
   {{0x628e1491,0x7ae303d0,0x2cad0147,0x00000000}},	//   _hwbo, _arnt, gued_, --,
   {{0x2a690d4b,0x69c495fc,0x9f4502d7,0x00000000}},	//   _siab_, _abie, _coló_, --,
   {{0x2a69006d,0x62580037,0x7ae3009e,0x645e95fd}},	//   _piab_, ríof, _crnt, impi,
   {{0xdc1206d0,0x7bd816fe,0xc3330122,0x68e495fe}},	//   rşıl, _wavu, טות_, _brid,
   {{0x6e2295ff,0x68e472e2,0x3d180324,0x69c40024}},	//   _imob, _crid, _बेचे_, _dbie,
   {{0x6ed301c2,0x69c40034,0x68e44fd0,0xd7f8386a}},	//   _səbə, _ebie, _drid, нус_,
   {{0x2a690221,0x68e42387,0x00000000,0x00000000}},	//   _tiab_, _erid, --, --,
   {{0x68e49600,0x6ed300a8,0x62580079,0x44d20260}},	//   _frid, _qəbə, níod, _bņ_,
   {{0x629c01c2,0x68e49601,0x69cf06a3,0x1dc201d1}},	// [a6b0] _avro, _grid, mece, व्यत,
   {{0x69cf9602,0x69dd9603,0x69c43d3f,0xdb019604}},	//   lece, ldse, _zbie, rflö,
   {{0x81da0083,0xdb1a01b4,0x78bd033b,0x6ed300a8}},	//   ়ান_, getø, ltsv, _təbə,
   {{0x69cf9605,0x645e9606,0x60cd0132,0x44d20260}},	//   nece, ampi, çamo, _fņ_,
   {{0x629c9607,0x764d00d0,0xd3a703e6,0x00000000}},	//   _evro, mlay, _првп, --,
   {{0x764d0644,0x63b50035,0x44259608,0x6e2200de}},	//   llay, _uczn, _öl_, _amob,
   {{0x764d0103,0x69cf1d52,0x6e220312,0x00000000}},	//   olay, kece, _bmob, --,
   {{0x4423022e,0x69cf6f45,0x764d00c1,0x62859609}},	//   _hmj_, jece, nlay, mpho,
   {{0x4ec30083,0x764d0103,0x78bd0051,0x00000000}},	//   ্মেল, ilay, jtsv, --,
   {{0x6285960a,0x23670a78,0x68e4960b,0x09aa1e82}},	//   opho, žnju_, _rrid, कल्य,
   {{0x764d0723,0x69cf0069,0x6285960c,0x68e40207}},	//   klay, fece, npho, _srid,
   {{0x68e4960d,0xf2d200c2,0xa2c40518,0x78bd960e}},	//   _prid, בעט_, _रहस्, ftsv,
   {{0x764d960f,0x6aa81c1c,0xe8f7051a,0xc19a011d}},	//   dlay, ardf, вля_, ושרי,
   {{0x68e49610,0x3d0d018d,0x7e6b08dd,0x69dd0051}},	//   _vrid, िनीं_, _higp, adse,
   {{0x69cf1bea,0x186718cd,0x78bd8ea4,0xf746218b}},	//   bece, тари_, atsv, тево,
   {{0x940c01c2,0x764d9611,0x442300d7,0x69cf9612}},	//   ələr_, glay, _amj_, cece,
   {{0x6fe100a1,0x05665a1a,0x44230147,0x00000000}},	// [a6c0] पयां, тван, _bmj_, --,
   {{0x764d073a,0x6d4b00f1,0x7e6b1192,0x645e0159}},	//   alay, _myga, _ligp, umpi,
   {{0xe2974237,0x764d0510,0x62850159,0x6d4b9613}},	//   вах_, blay, gpho, _lyga,
   {{0x764d0138,0xb87b0b06,0x78a9030a,0xd7b204aa}},	//   clay, lvía, ševe, _जाँच,
   {{0x44230069,0x6d4b362b,0x2167150d,0x8c3d9614}},	//   _fmj_, _nyga, вици_, luşu,
   {{0x9f6501ba,0x63830be8,0x629c00d5,0xb87b07a6}},	//   _štát_, _вгра, _tvro, nvía,
   {{0x444409e8,0x69cf0723,0xf77300a5,0x8c3d027d}},	//   mo_, yece, סקה_, nuşu,
   {{0x44440d6e,0xe6bb013b,0x6d4b0a8c,0xade301e0}},	//   lo_, şaçı, _byga, ацьк,
   {{0x44449615,0x625832fb,0x69cf9616,0x7ceb008a}},	//   oo_, ríod, vece, vörð,
   {{0x44449617,0x7afc01ff,0x62580079,0x8af804b2}},	//   no_, ärto, síod, енос_,
   {{0x44449618,0x6e2201a2,0x60140443,0x6d4f00b8}},	//   io_, _tmob, _càme, ýcar,
   {{0x44449619,0x7e6b011e,0x764d0095,0xa5bb081d}},	//   ho_, _gigp, xlay, _amón,
   {{0x4444726e,0x69dd961a,0x3e78961b,0xa3b30066}},	//   ko_, rdse, _hét_, _टाल_,
   {{0x4444961c,0x3e780332,0x69cf02c6,0x78bd4534}},	//   jo_, _két_, sece, rtsv,
   {{0x44440168,0x764d01fb,0x78bd1b4b,0x290d00f4}},	//   do_, tlay, stsv, šea_,
   {{0x44443aa7,0x3ce62df4,0x3e78961d,0x6447013a}},	//   eo_, _krov_, _mét_, _skji,
   {{0x44440103,0x764d0457,0x9f5e00da,0x3e78961e}},	// [a6d0] fo_, rlay, _botë_, _lét_,
   {{0x4ab604bc,0xf8bf00f7,0x7c280118,0x764d4a93}},	//   _अमाव, mté_, nidr, slay,
   {{0xf8bf0248,0x3e7801a5,0x8c3d027d,0x60c9023a}},	//   lté_, _nét_, muşt, _spem,
   {{0x68e20080,0x4444961f,0x764d013b,0xe9df6551}},	//   _šodi, ao_, qlay, ndú_,
   {{0x44449620,0xf8bf04b9,0x3ce6006f,0xa0c5026e}},	//   bo_, nté_, _nrov_, ايتو,
   {{0xf8bf0248,0x8c3d027d,0x3e789621,0x00000000}},	//   ité_, nuşt, _bét_, --,
   {{0xa29400d8,0x997600a8,0x64459622,0x22941346}},	//   _васі, _nəşr_, mohi, _вися,
   {{0x6445149b,0x53340109,0xa3c10084,0x660d9089}},	//   lohi, _тест, ंभव_, nkak,
   {{0xc10404cd,0x626c00af,0x660d9623,0x60c908c7}},	//   _پولي, _uşoa, ikak, _upem,
   {{0x4ea70009,0xabd50431,0xe8d900e2,0x3e780107}},	//   _арда, уциј, _ngố_, _fét_,
   {{0x660d9624,0xdd9145fd,0x7e6b02b3,0x8b252626}},	//   kkak, _هوا_, _tigp, удне,
   {{0x444415be,0x62580037,0x7bc17c78,0x60140176}},	//   zo_, míoc, sflu, _gàmb,
   {{0x44449625,0xdca50f08,0x64459626,0x6258004f}},	//   yo_, _сали, kohi, líoc,
   {{0x44444e41,0x315600c2,0x3e710038,0x6e299627}},	//   xo_, טירן_, _ešte_, lieb,
   {{0x44441530,0x7d099628,0x8c1a0122,0x3e7801a5}},	//   vo_, lyes, _רוצי, _xét_,
   {{0x44449629,0x660d8650,0x6e292e13,0x9f5e0260}},	//   wo_, gkak, nieb, _dotè_,
   {{0x44440be8,0x7d09962a,0xf8bf0248,0x2cbf962b}},	// [a6e0] to_, nyes, cté_, ntud_,
   {{0x64450159,0x6e29033b,0x799651c7,0x78a905e2}},	//   gohi, hieb, _heyw, ševc,
   {{0x91e60cf9,0x2cbf007c,0x7996962c,0x41aa075c}},	//   ложе, htud_, _keyw, евен_,
   {{0x2cbf011e,0x3e78962d,0x80c80033,0x26da210c}},	//   ktud_, _rét_, লিস্, _ispo_,
   {{0x4444007e,0x859b0bed,0x644500d7,0x6e297857}},	//   po_, _אשכו, bohi, dieb,
   {{0x44443687,0xa0671126,0xddcb6ce6,0x00000000}},	//   qo_, гача_, _figū, --,
   {{0x62580082,0x7c281186,0x2cbf1d47,0x645c00a0}},	//   ríob, vidr, etud_, _ihri,
   {{0x3ce6270d,0x3e7800e2,0x7c2802b1,0x7d1b02b1}},	//   _prov_, _vét_, widr, fzus,
   {{0x7c28962e,0x645c00d7,0x7d09962f,0x24720260}},	//   tidr, _khri, gyes, _fņme_,
   {{0xd12f028c,0x22469630,0xddc20009,0xa5bb01ef}},	//   _عمل_, look_, _dioš, _amól,
   {{0x23c600a9,0x53c6111a,0x5a3503e6,0x79969631}},	//   र्यद, र्यश, инот, _beyw,
   {{0xe80d473a,0xf8bf0640,0x9f5e3645,0x7c280804}},	//   हस्थ_, tté_, _noté_, sidr,
   {{0xf8bf02e1,0x02d1020c,0x645c9632,0xe9df3094}},	//   uté_, _सन्न, _ohri, rdú_,
   {{0xf8bf02e1,0x9f5e0036,0x628100a2,0x1cb7011d}},	//   rté_, _potè_, _élog, _עלול_,
   {{0xf8bf9633,0x2fde011e,0x6b7b0100,0xdce006d3}},	//   sté_, _matg_, _ארונ, mamı,
   {{0x629e1f79,0xdce006d3,0x6b9a9634,0xf8bf0248}},	//   dspo, lamı, latg, pté_,
   {{0x645c0094,0x58d52f44,0x660d9635,0x64459636}},	// [a6f0] _bhri, _топт, rkak, tohi,
   {{0x660d9637,0x645c9638,0x6b9a12c3,0xdce000c1}},	//   skak, _chri, natg, namı,
   {{0x64459639,0x629e963a,0x645c963b,0xdb1a002a}},	//   rohi, gspo, _dhri, metó,
   {{0x645c963c,0x6445010d,0xa29401e0,0xdb1a963d}},	//   _ehri, sohi, саці, letó,
   {{0x69df01d2,0x6b9a008c,0x645c04e6,0xdce00644}},	//   _maqe, katg, _fhri, kamı,
   {{0x645c02a8,0x6258004f,0x287c02b5,0x7d1b0095}},	//   _ghri, tíoc, ענומ, vzus,
   {{0x6e29963e,0x290b001e,0x80c80033,0xf2e401e0}},	//   tieb, hyca_, লিষ্, _люто,
   {{0x82370514,0x62580082,0x69df0055,0x7d1b02b1}},	//   _إرسا, ríoc, _naqe, tzus,
   {{0x6e29963f,0xdd990187,0x62580079,0xc21200a5}},	//   rieb, raň_, síoc, _והן_,
   {{0x60db1c5c,0x0c250142,0x6e299640,0x2cbf9641}},	//   _isum, рмон, sieb, rtud_,
   {{0x6e296cc0,0x69df0069,0x7d1b9642,0x2cbf9643}},	//   pieb, _baqe, szus, stud_,
   {{0xaa461f7c,0x00000000,0x00000000,0x00000000}},	//   ремл, --, --, --,
   {{0x6b9a0345,0x2d8d002f,0xc9561ac5,0x600f008c}},	//   batg, mbee_, ртны, _lømm,
   {{0x6b9a01f7,0xb8ee0953,0x2cad592a,0x60db002f}},	//   catg, _रह_, mred_, _msum,
   {{0x69df00da,0x9f5e00b8,0x2cad02d7,0xa59602fb}},	//   _faqe, _poté_, lred_, иращ,
   {{0x78a9108a,0x629e9644,0x645c5294,0x45869645}},	//   ševa, vspo, _shri, ргав,
   {{0x645c3b56,0xa3e7135e,0x629e01a2,0x3ce80035}},	// [a700] _phri, _मोह_, wspo, जिये_,
   {{0x389b134d,0x03a6002d,0x6d590345,0x00000000}},	//   _שיינ, рижо, _mzwa, --,
   {{0x60db1ec8,0x81df0083,0x81da0033,0x2cad016e}},	//   _asum, তান_, ়াস_, hred_,
   {{0x00e60cf9,0xb5fb171c,0x6b9a0987,0x55e609ce}},	//   ижен, _diás, zatg, _томб,
   {{0x22469646,0x228c021e,0x645c9647,0xdce0045e}},	//   rook_, _bòkò_, _thri, yamı,
   {{0xa2e603ad,0x2cad02c4,0x6eca00a8,0x645c0421}},	//   _когд, dred_, _rəbb, _uhri,
   {{0xe2972dc5,0x6d59046a,0x82a3002d,0x999901ba}},	//   _вас_, _azwa, _марж, losť_,
   {{0x2d8d0088,0x60143376,0xadf40279,0x00000000}},	//   gbee_, _dàma, спиш, --,
   {{0x6b9a12c3,0x9999016f,0x6d590035,0xeb0e4ae7}},	//   tatg, nosť_, _czwa, ान्त_,
   {{0x60c29648,0x61e200b5,0x46c70084,0xbea61645}},	//   mtom, ldol, _लहलह, _важк,
   {{0x6b9a0443,0x33770122,0x61e00118,0x69df01f4}},	//   ratg, יעים_, _kaml, _paqe,
   {{0x61e2775a,0x2cad9649,0x6b9a0443,0x61e0964a}},	//   ndol, bred_, satg, _jaml,
   {{0x61e0000e,0x3e71044d,0x61e27899,0x63bc00cd}},	//   _maml, _išta_, idol, _ocrn,
   {{0x61e203ad,0x6b9a0069,0x1dc20d34,0x3f9c361b}},	//   hdol, qatg, व्रत, navu_,
   {{0x07080036,0xdb1a964b,0xd5bb0426,0x298b0421}},	//   ахти_, retó, кса_, _испо_,
   {{0xdb01003e,0xdb1a002a,0x600f1b99,0x3f9c007b}},	//   nglý, setó, _rømm, havu_,
   {{0x3f9c964c,0x81df0083,0x61e2001e,0x2ed30355}},	// [a710] kavu_, তাম_, ddol, _दन्त,
   {{0x3f9c0936,0x4ada964d,0xaada0299,0x6b98964e}},	//   javu_, _बनाव, _बनाक, _jevg,
   {{0xb5fb964f,0x2cad1635,0xdce200ee,0xd37832dd}},	//   _diár, zred_, _neoľ, рчу_,
   {{0xa3e7238a,0xaaa90461,0x799d3ebc,0x61e29650}},	//   _मोर_, _किसक, nasw, gdol,
   {{0x95080332,0x32041b66,0x69bc00a1,0xddc2004e}},	//   _پہلے_, _domy_, ष्टी, _okoł,
   {{0x3f9c9651,0x2cad0282,0x6ab60067,0x27e19652}},	//   gavu_, vred_, _अमूर, _jahn_,
   {{0x61e09653,0xe2f80044,0x61e2027a,0x6d590067}},	//   _faml, _кері_, bdol, _szwa,
   {{0x61e003d0,0x6258004f,0x3ea94693,0x60db1a89}},	//   _gaml, líon, čat_, _tsum,
   {{0xa3ab0755,0x3f9c0475,0x2cad2ea2,0x2d8d51c0}},	//   _गया_, bavu_, ured_, rbee_,
   {{0x2cad0122,0x40590180,0x62580037,0x61e083b2}},	//   rred_, _صلاح_, níon, _zaml,
   {{0x9cf912eb,0x81da00c8,0x26c1006d,0x2cad012e}},	//   েছেন_, ়ার_, _nqho_, sred_,
   {{0x2cad0af1,0x3a29046a,0xc3320d85,0x200500e9}},	//   pred_, _cmap_, לוי_, _holi_,
   {{0x78a90a4c,0x6c85004f,0x27e101ae,0x20059654}},	//   ševn, _التم, _bahn_, _koli_,
   {{0xa3e70e04,0x9999016f,0x20059655,0x61e29656}},	//   _मोल_, vosť_, _joli_, zdol,
   {{0x61e27b25,0xdceb0069,0x62580079,0xb60800ee}},	//   ydol, _begħ, díon, _lašš,
   {{0x999901ba,0x20050510,0x60c29657,0x3f9c5785}},	//   tosť_, _loli_, ytom, zavu_,
   {{0x2aa301c2,0x61e09658,0x320486ac,0x2bbd0026}},	// [a720] lıb_, _raml, _romy_, ्भपा,
   {{0x61e00bf3,0x25e808b6,0x68fb0122,0x200562bd}},	//   _saml, _चोरी_, _עליה, _noli_,
   {{0xe80d006a,0x2aa301c2,0x2a600221,0x518605a1}},	//   _सकता_, nıb_, _khib_, була,
   {{0x60c29659,0xe2970274,0x7afc19ee,0x27e17031}},	//   ttom, сац_, ärti, _zahn_,
   {{0x2005016f,0xd24f0934,0x81da0083,0x6287965a}},	//   _boli_, رنه_, ়াল_, _etjo,
   {{0x60c2965b,0xdb010079,0xdbf00355,0x225f01b7}},	//   rtom, ngló, _příd, _ehuk_,
   {{0x6ab6114e,0x660654e5,0x60c2965c,0x2005965d}},	//   _अमेर, _kokk, stom, _doli_,
   {{0x6b980d6f,0x60c2965e,0x53370070,0x3f9c018e}},	//   _sevg, ptom, _האלב_, savu_,
   {{0x8fa60810,0x200572bc,0x442a012f,0x6606965f}},	//   _газе, _foli_, _kmb_, _mokk,
   {{0xb5fb00e8,0x660617ad,0xdbf001c0,0x442a008c}},	//   _khác, _lokk, _tříd, _jmb_,
   {{0xe9f91112,0x0dca00d4,0x442a00d5,0x3940024b}},	//   анні_, _були_, _mmb_, _axis_,
   {{0x660600fb,0x2a60006d,0xaaa96017,0xc984002d}},	//   _nokk, _chib_, _किरक, зури,
   {{0xa3b81163,0x442a0602,0x799d9660,0x9f5e0176}},	//   छला_, _omb_, rasw, _motí_,
   {{0xa3e70066,0x3d2b00b5,0x78a400c7,0x442a002f}},	//   _मों_, _حتمی_, _dviv, _nmb_,
   {{0x799d000e,0x66069661,0x41c8021a,0xab68003c}},	//   pasw, _bokk, रभास, _biżż,
   {{0x442a4045,0xb5fb0037,0x80b90033,0xe6670390}},	//   _amb_, _sháb, _ইনস্, стго,
   {{0x628705ee,0xb87b0187,0x26c302c6,0x66064a8e}},	// [a730] _stjo, zvíj, stjo_, _dokk,
   {{0x68ed525e,0xb36700c3,0x36d50036,0x7e7a962c}},	//   _irad, бъек, _доор, _outp,
   {{0x6258004f,0x68ed033a,0x20059662,0x66069663}},	//   ríon, _hrad, _roli_, _fokk,
   {{0x09ab00c8,0x20059664,0x3abb02b5,0x41552ad7}},	//   গ্রা, _soli_, רמאנ, овес,
   {{0xed4600f5,0x09e300c8,0x2aa301c2,0xb5fb0079}},	//   _آپ_, যাপা, zıb_, _tháb,
   {{0x2aa301c2,0x68ed000e,0xa2950eb9,0xaaa900b4}},	//   yıb_, _mrad, _магі, _किलक,
   {{0x20059665,0x66069666,0x2aa300a8,0x9f5e00ac}},	//   _voli_, _yokk, xıb_, _fotí_,
   {{0xf2d20779,0x68ed9667,0x66066476,0x7c2a0009}},	//   _קען_, _orad, _xokk, _amfr,
   {{0xee3601c8,0x2a60006d,0x20059668,0x2ce300b4}},	//   ўны_, _rhib_, _toli_, कटेल_,
   {{0x2aa30095,0x5ac91c80,0xeb9903fa,0x62580037}},	//   tıb_, алом_, шио_, híol,
   {{0x68ed06d0,0x78a90254,0x78609669,0xdddb0067}},	//   _arad, ševl, növe, rmuł,
   {{0x2a600189,0x2aa30095,0xdd1e0355,0x00000000}},	//   _qhib_, rıb_, _síťo, --,
   {{0x786006d7,0x7e7a44c2,0xed4e0210,0x68ed23e8}},	//   höve, _zutp, _цо_, _crad,
   {{0x6606966a,0x68ed966b,0x786000b5,0xcb69966c}},	//   _sokk, _drad, köve, _кале_,
   {{0x66e3316d,0x442a009f,0x2a60006f,0xba3d00c7}},	//   мора, _rmb_, _thib_, grįs,
   {{0x68ed966d,0x78a40ab8,0x39408583,0x2d9f033b}},	//   _frad, _tviv, _txis_, naue_,
   {{0x6443108a,0xddd4003c,0xe4061b96,0x78a408c7}},	// [a740] čnin, _ħażi, озап, _uviv,
   {{0xb5fb00e2,0x2d9f02b1,0x66065b18,0x00000000}},	//   _phác, haue_, _wokk, --,
   {{0x59c1112b,0x6606966e,0x23c600dc,0x86460109}},	//   ष्कर, _tokk, र्षद, _множ,
   {{0x3f8500af,0x625801ef,0x4b4c0070,0xf1b907c0}},	//   _aflu_, cíol, נגאַ, _omšu_,
   {{0x25a0966f,0x442a9670,0x10a31f7e,0x7641006c}},	//   mail_, _tmb_, дичн, élye,
   {{0x4aa902cb,0xeeaa9671,0x28b20006,0xb5fb0019}},	//   _किंव, атик_, _जिनि, _thác,
   {{0xdefa0104,0x09b20033,0x24809672,0x00000000}},	//   рыл_, ট্যা, lqim_, --,
   {{0x25a001a6,0x61461682,0x6ca60352,0x80d50067}},	//   nail_, _деба, орож, _मैके,
   {{0x6258004f,0xb87b0093,0x09e30831,0x00000000}},	//   níom, rvík, যামা, --,
   {{0x25a003c0,0x68ed01f4,0x9b6a547d,0x8c430274}},	//   hail_, _rrad, ишна_, мење,
   {{0xa5bb0370,0x1ee80118,0xce350987,0x68ed9673}},	//   _imóv, _دوای_, _کونک, _srad,
   {{0x68ed0a93,0xa2cd0ec5,0xba2b00d4,0x6d5c00a8}},	//   _prad, _सहस्, ріод_, əran,
   {{0xcd3618dd,0x25a0111c,0x0e6900d1,0x786000b5}},	//   _براب, dail_, _اصلي_, zöve,
   {{0x7c2a9674,0x68ed00f4,0xb17d00ee,0x00000000}},	//   _umfr, _vrad, _maťa, --,
   {{0x09d000c8,0x25a09675,0xdb4f00d4,0x68ed0118}},	//   িয়া, fail_, _цю_, _wrad,
   {{0x25a00014,0x7afc007c,0xddc20035,0x00000000}},	//   gail_, ärtu, _ukoń, --,
   {{0x68ed02dd,0xd37b0cda,0x7c3a053f,0x62589676}},	// [a750] _urad, аче_, ontr, ríol,
   {{0x7c3a9677,0x00000000,0x00000000,0x00000000}},	//   nntr, --, --, --,
   {{0x926b6a6d,0x25a00082,0x4cd30083,0x7c3a9678}},	//   арда_, bail_, তিযু, intr,
   {{0x25a0009c,0x925900c3,0x2ca69679,0x3ea5008c}},	//   cail_, щает_, _ovod_, _rvlt_,
   {{0xc5fa0122,0xf07500b5,0x00000000,0x00000000}},	//   _הפרט, سیاں_, --, --,
   {{0x7a3604d9,0x7e6201ed,0xdb1a00be,0x22460207}},	//   mšte, _ahop, letõ, čoka_,
   {{0xa19502ce,0x2ca6012f,0x160f19b7,0x82a4052c}},	//   _навч, _avod_, _सवार_, _оште,
   {{0x7c3a967a,0x09e30831,0x00000000,0x00000000}},	//   entr, যাডা, --, --,
   {{0x811905ac,0x7a36967b,0x00000000,0x00000000}},	//   _ужас_, nšte, --, --,
   {{0x4b250402,0x00000000,0x00000000,0x00000000}},	//   змов, --, --, --,
   {{0xc94900a5,0x7a3602c4,0x00000000,0x00000000}},	//   _עמ_, hšte, --, --,
   {{0x7a3600d8,0x6eca00a8,0x25a0013b,0x2d840118}},	//   kšte, _məbl, xail_, ccme_,
   {{0x25a002e1,0x5975005f,0x7e69967c,0x2d9d0345}},	//   vail_, дыру, mmep, _iewe_,
   {{0x601d02e9,0x7c9400d1,0x25a01d38,0x7e620051}},	//   _fème, _آشنا, wail_, _zhop,
   {{0x4e1f0243,0x81b30083,0x25a006a0,0x64430097}},	//   _बताई_, জ্য_, tail_, čnil,
   {{0x6e3b967d,0xe73700af,0x2d9d0371,0xdb1a967e}},	//   nnub, чес_, _jewe_, tetö,
   {{0x25a0967f,0x74130118,0x00000000,0x00000000}},	// [a760] rail_, کولا, --, --,
   {{0x2d9d250a,0x25a09680,0x62580037,0x067600af}},	//   _lewe_, sail_, ríom, _нумя,
   {{0x51863b0c,0x443a0e8f,0xdb030097,0x877b00a5}},	//   пула, rnp_, _odní, _לאיי,
   {{0xa5bb01ef,0xa2cd060a,0x2d9d0298,0xdb1a00be}},	//   _alóf, _सहर्, _newe_, petö,
   {{0x3dc30083,0xb5fb01a5,0xf772132d,0x7e620207}},	//   ্যাল, _khán, _تاک_, _rhop,
   {{0x66042163,0x93260e3a,0xd12f0c26,0x9f4c02d7}},	//   ljik, _فرزن, دمه_, _andá_,
   {{0xeab60083,0x877b02b5,0x2bc204bc,0x2d9d03bc}},	//   _জন্ম, זאצי, _शाबा, _bewe_,
   {{0x91e31a55,0xb226527b,0x66049681,0x333b011d}},	//   _посе, _эмбл, njik, _התלמ,
   {{0x2ba6000c,0x75241939,0x2d9d00d1,0x78a600d5}},	//   jící_, nziz, _dewe_, jskv,
   {{0xb5fb0019,0x7c3a9682,0x2ba60355,0x601d021e}},	//   _nhán, untr, dící_, _pème,
   {{0x81df00c8,0xfbcf006c,0x7c3a9683,0xb87b0132}},	//   তার_, ھتی_, rntr, nvív,
   {{0xdde90118,0x601d0951,0xa5bb014c,0x2d9d0371}},	//   _ورنه_, _gèmb, _ilóg, _gewe_,
   {{0x3f9e00da,0x5e25006c,0x2ca615d7,0x78a69684}},	//   _ketu_, _تعلق, _uvod_, gskv,
   {{0x36d50202,0x7a36290b,0x7afc9685,0xb5fb1617}},	//   могр, všte, ärts, _chán,
   {{0x3f9e9686,0x7bda9687,0x764d9688,0x2d9d01d5}},	//   _metu_, metu, toay, _yewe_,
   {{0x3f9e9689,0x660400da,0x7bda968a,0x6443968b}},	//   _letu_, gjik, letu, čnim,
   {{0xd8bb01cb,0x70bb0253,0xd9440200,0x656001da}},	// [a770] _ادعا_, _ईमेल, _пећи, _ùmhl,
   {{0x7bda968c,0x2bcf05f8,0x3f9e968d,0x7a361ada}},	//   netu, त्पा, _netu_, ršte,
   {{0x61c80066,0x00000000,0x00000000,0x00000000}},	//   रभूष, --, --, --,
   {{0x7bda968e,0x7a360274,0xdcfb0207,0xe8d900e2}},	//   hetu, pšte, zbuđ, _ngừ_,
   {{0xddc8968f,0x7bda9690,0x661d017b,0xd00903e6}},	//   _budž, ketu, _ilsk, желе_,
   {{0x2d9d053e,0x7bda9691,0x6eca00a8,0x00000000}},	//   _sewe_, jetu, _təbl, --,
   {{0x7bda9692,0x6e3b0dc3,0x00000000,0x00000000}},	//   detu, tnub, --, --,
   {{0x44339693,0x7bda00d7,0x2bcf0099,0x601400f1}},	//   lix_, eetu, त्ना, _làmh,
   {{0x7e6909e1,0xddc801f2,0x3f9e0069,0x7bda8b47}},	//   rmep, _fudž, _fetu_, fetu,
   {{0x2d9d0657,0x7bda9694,0x60140284,0x539a016b}},	//   _wewe_, getu, _nàmh, ֿירו,
   {{0x6e3b010d,0x600f0a8c,0x2d9d0345,0x661d3073}},	//   pnub, _dømt, _tewe_, _olsk,
   {{0x3f9e000e,0xdcf9042c,0x4433007a,0x270c0033}},	//   _zetu_, _وفات_, hix_, _হইলো_,
   {{0x3f9e0657,0x64430a78,0x3ea00506,0xb608063c}},	//   _yetu_, čnij, ćite_, _lašá,
   {{0xdb1a0132,0x60140211,0x78a60c68,0xec6b00af}},	//   tetô, _càmh, rskv, _урек_,
   {{0x59c602cb,0x8c420c9f,0x92c10083,0x601400f1}},	//   _वापर, _шеше, ্টু_, _dàmh,
   {{0x44330310,0x752401d7,0x2bbd00e7,0x96550274}},	//   eix_, tziz, ्भवा, еђуј,
   {{0xb5fb00e8,0xc79602ee,0xa5bb0042,0x64a305d8}},	// [a780] _thán, _орны, _amós, ката,
   {{0x661d9695,0xb17d00ac,0xdb010132,0xe1f90409}},	//   _elsk, _baťo, valê, _anų_,
   {{0x2bcf02cb,0xfbcf00b8,0x9f4501f4,0xf746386a}},	//   त्या, त्यम, _dalë_, _цено,
   {{0x3f9e9696,0x224000ab,0xc69300a5,0xa5bb0098}},	//   _setu_, õik_, _שאר_, _clód,
   {{0x59c6009a,0x7bda0054,0x9f450031,0x3f9e9697}},	//   _वानर, yetu, _falë_, _petu_,
   {{0x2bcf0808,0x68e407e3,0xd0100037,0x44210118}},	//   त्मा, _msid, طلب_, chh_,
   {{0xc3340070,0xb87b0093,0xa2e302ee,0x69c40067}},	//   _װוּ_, lvít, _иорд, _ocie,
   {{0x3f9e0657,0x78a90a78,0x9f4502d0,0x3c200107}},	//   _wetu_, ševi, _malè_, _mòve_,
   {{0x7bda9698,0xed5703fa,0x7bc39699,0x3f9e0124}},	//   tetu, моћ_, _bcnu, _tetu_,
   {{0x69c4969a,0x81da0033,0xf063010b,0xa4fb00a5}},	//   _acie, ়াও_, _акуп, קליט,
   {{0x83b700a5,0x68e4969b,0xaa59785b,0x201e0207}},	//   ופיע_, _asid, зину_, _ilti_,
   {{0x7bda023f,0xdd900ad9,0x200c969c,0x9f4c0183}},	//   setu, _صوت_, _hodi_, _dodô_,
   {{0x200c969d,0xa3de0324,0xdb0a021d,0x600f0a8a}},	//   _kodi_, ढ़ा_, _pcfó, _tømt,
   {{0xb8f7114e,0x644302dd,0x200c02e9,0x4433969e}},	//   _सह_, čnik, _jodi_, xix_,
   {{0x200c969f,0x45d58816,0xf65300b5,0x68e40065}},	//   _modi_, новс, نئر_, _esid,
   {{0x200c96a0,0x59c651ba,0x68e403d0,0x27ea009e}},	//   _lodi_, _वायर, _fsid, adbn_,
   {{0x69dd96a1,0x443396a2,0x201e058c,0x9f450031}},	// [a790] mese, tix_, _olti_, _palë_,
   {{0x200c001e,0xc8670c74,0x78bd96a3,0x00000000}},	//   _nodi_, _تطبي, musv, --,
   {{0x44330095,0x7a3696a4,0x81e80083,0xddc80035}},	//   rix_, lšta, বান_, _budż,
   {{0x201e96a5,0xa29400d4,0x442196a6,0x00000000}},	//   _alti_, таці, shh_, --,
   {{0x629c96a7,0x78bd0176,0x7a3678a9,0x200c96a8}},	//   _ewro, nusv, nšta, _bodi_,
   {{0x649a0122,0x85740131,0x200c96a9,0x69dd96aa}},	//   _מישה, _шлях, _codi_, hese,
   {{0x63a596ab,0x69dd96ac,0x7a360c99,0xdb0300ac}},	//   mahn, kese, hšta, _odná,
   {{0x63a50ce8,0x261c004f,0x69dd96ad,0x7a3600d8}},	//   lahn, _líon_, jese, kšta,
   {{0x69dd05e2,0x9f45024e,0x3dcd96ae,0x61fb96af}},	//   dese, _malé_, rfew_, _inul,
   {{0x69c496b0,0x63a596b1,0x320d012f,0x200c001e}},	//   _scie, nahn, _hoey_, _godi_,
   {{0x61e996b2,0x61fb96b3,0x69dd658e,0x7a3600c7}},	//   _kael, _knul, fese, ešta,
   {{0x69dd96b4,0x20071851,0x60140176,0x61e94897}},	//   gese, ljni_, _ràmi, _jael,
   {{0x61e90657,0x63a50034,0xb5fb0391,0xdb0102e9}},	//   _mael, kahn, _chám, zalè,
   {{0xfaa596b5,0x63a50ac8,0x9f4502d0,0xe61f96b6}},	//   _зако, jahn, _palè_, _alô_,
   {{0x8c1a0122,0x9f450015,0x6eca00a8,0x261c0079}},	//   _מוסי, _balé_, _cəbh, _díon_,
   {{0x69dd96b7,0x61e996b8,0x9f4596b9,0x85b503fa}},	//   cese, _nael, _valè_, кључ,
   {{0x2edc000c,0xd54700af,0xb4661d13,0x2bcf0b35}},	// [a7a0] _मन्त, епте_, екал, त्था,
   {{0x61fb1149,0x6fd30723,0x63a5253b,0x443100ee}},	//   _anul, nıcı, gahn, _cmz_,
   {{0x23c60967,0x61e901f7,0x200c01a0,0x35a60043}},	//   र्गद, _bael, _rodi_, _панг,
   {{0xfbcf0af9,0x2bcf05fc,0x645596ba,0xdb0196bb}},	//   त्तम, त्ता, _ekzi, galé,
   {{0x601d02d0,0x63a596bc,0x6d592884,0x387a013b}},	//   _sèma, bahn, _nywa, _kipr_,
   {{0x69dd96bd,0xa5bb7d36,0x63a52090,0x7bc100cd}},	//   zese, _glób, cahn, jglu,
   {{0x2482028b,0x200c02f0,0x69dd96be,0x6fd30095}},	//   _hukm_, _vodi_, yese, dıcı,
   {{0x61e9003b,0xadf40370,0x11f800e0,0x6d590067}},	//   _gael, тпиш, _تورک_, _bywa,
   {{0x59a7004e,0x69dd96bf,0x200c0036,0x61431126}},	//   _ख़बर, vese, _todi_, _бета,
   {{0x69dd96c0,0x7bc11ba3,0x09a90099,0x6d5996c1}},	//   wese, gglu, कण्य, _dywa,
   {{0x69dd96c2,0x61e908c7,0x600f08c8,0x00000000}},	//   tese, _yael, _tømr, --,
   {{0x3a2096c3,0xf2d300c2,0x63a50eda,0x7bc1006d}},	//   _clip_, נער_, zahn, aglu,
   {{0x63a50257,0x09e30033,0x48bf0831,0x69a20067}},	//   yahn, যালা, ইব্র, _ख़री,
   {{0x69dd96c4,0x7a3696c5,0x9f45000d,0x9989045e}},	//   sese, ršta, _salé_, _flaş_,
   {{0xc2210953,0x63a518b0,0x69dd96c6,0x6d590051}},	//   _मतलब_, vahn, pese, _zywa,
   {{0x63a50ec0,0x7a363148,0x4431002f,0x3a2096c7}},	//   wahn, pšta, _smz_, _glip_,
   {{0xb87b003e,0x64554884,0xa5bb01ef,0xdb01031d}},	// [a7b0] rvís, _pkzi, _alóc, valé,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8580052,0x63a55f08,0x61e996c8,0x08f8006c}},	//   _איזה_, rahn, _pael, _قریب_,
   {{0x63a5046a,0x92b40037,0x6fd30225,0x00000000}},	//   sahn, احلا, zıcı, --,
   {{0x63a500d7,0xf8bf0fcb,0x6fd300d0,0x61e90421}},	//   pahn, nué_, yıcı, _vael,
   {{0xdb011fca,0x61e996c9,0xe0570609,0xa5bb01ef}},	//   salé, _wael, ریات_, _flóc,
   {{0x660f96ca,0x6d590298,0x61fb0103,0x00000000}},	//   _kock, _sywa, _tnul, --,
   {{0xe8d901a5,0x7bc1006d,0x92580f24,0xb17d0168}},	//   _ngữ_, wglu, _заст_, _maťk,
   {{0x6fd3027d,0xb17d007e,0x00000000,0x00000000}},	//   tıcı, _laťk, --, --,
   {{0x660f96cb,0xea890fb4,0x00000000,0x00000000}},	//   _lock, мбол_, --, --,
   {{0x7bc11b4b,0xab2907b2,0x78ad96cc,0x2bc200b4}},	//   rglu, фона_, _avav, _शारा,
   {{0xdd9501c8,0x8d8701d3,0x2a69009e,0x660f96cd}},	//   _рады, _чужд, _chab_, _nock,
   {{0xf8bf96ce,0x2a69195f,0x261c0037,0x00000000}},	//   gué_, _dhab_, _díol_, --,
   {{0x2bcb1d29,0x00000000,0x00000000,0x00000000}},	//   _худо_, --, --, --,
   {{0x660f96cf,0xc7a3015a,0x317f90f9,0xa3e50127}},	//   _bock, риск, _oguz_, भजन_,
   {{0xceb25be5,0xf8bf00f7,0x660f96d0,0x6eca00a8}},	//   ייל_, bué_, _cock, _qəbi,
   {{0x2cbf03be,0x69d696d1,0x387a0027,0x45830faf}},	// [a7c0] nuud_, _ibye, _tipr_, ргув,
   {{0xb3760118,0xe29a3079,0x998902c6,0x3e7100f4}},	//   نداش, даж_, _imaš_, _ištu_,
   {{0x6eca0095,0xa7660823,0x4376002d,0x3e450228}},	//   _təbi, _шкод, туат, zēta_,
   {{0x68f604c1,0x6fc40099,0x00000000,0x00000000}},	//   _kryd, _राहू, --, --,
   {{0x0cbc00c8,0x2bc200b4,0x2cbf00ab,0x69d62574}},	//   _অন্ত, _शाला, juud_, _mbye,
   {{0x09d600c8,0xd00f1c2d,0x905300d8,0x7a36010b}},	//   _তোমা, يلن_, авіц, kšto,
   {{0x69d6790b,0x9e340382,0x00000000,0x00000000}},	//   _obye, лекч, --, --,
   {{0x2bcf06bc,0xdef7061c,0xf1aa00ce,0x3ce6308a}},	//   त्सा, тыш_, _زاره_, _psov_,
   {{0x81e80b52,0x24860514,0x62830187,0xc0e30bff}},	//   বাদ_, íomh_, ínov, _котк,
   {{0x3e4500ea,0x261c0079,0x2a69033b,0x2bc20099}},	//   rēta_, _síol_, _shab_, _शाळा,
   {{0x6d440038,0x0c73004f,0x2a690221,0x78ad51de}},	//   _žiad, جديد, _phab_, _svav,
   {{0xf8bf0248,0x68f696d2,0x2a6901e8,0x3ce6006f}},	//   tué_, _bryd, _qhab_, _tsov_,
   {{0xac0a0274,0x5fc90e04,0x660f96d3,0x1bd4536e}},	//   _онда_, _रामल, _rock, _боля,
   {{0x660f96d4,0x6e2296d5,0xd9180086,0x68f600e9}},	//   _sock, _hlob, тью_, _dryd,
   {{0x2a690221,0xf1b4021a,0x660f5f54,0xf8ae00ff}},	//   _thab_, ुलान, _pock, يکی_,
   {{0xd5b896d6,0x628100f7,0x23c6018d,0x68f696d7}},	//   ксу_, _éloi, र्घद, _fryd,
   {{0x2bcf02cb,0xfbcf01c0,0xf8bf96d8,0x26da0051}},	// [a7d0] त्वा, त्वम, qué_, _eppo_,
   {{0x78a92b6c,0x6e2212c3,0xb5fb0037,0x00000000}},	//   ševs, _llob, _mhái, --,
   {{0xe7ec4e29,0x660f19cd,0xe29800d4,0x9f4c01f7}},	//   _छोटा_, _tock, ває_, _endú_,
   {{0x9f450036,0x00000000,0x00000000,0x00000000}},	//   _dalì_, --, --, --,
   {{0x25a996d9,0x6d4e01ae,0x2919011e,0x00000000}},	//   maal_, ßbal, nysa_, --,
   {{0x25a90027,0x1ec95568,0x3f690165,0xe2934cbc}},	//   laal_, елки_, нило_, _نذر_,
   {{0x44230009,0x7a260093,0x1ea800f8,0x2cbf023c}},	//   _ilj_, _hóte, نايي_, wuud_,
   {{0x25a9388d,0xdb030248,0xa3cf0aad,0x6e22009e}},	//   naal_, _fenê, व्र_, _clob,
   {{0xb5fb0037,0xf53f00d4,0xdb0300f6,0x4fc70183}},	//   _chái, _idås_, _genê, _асеа,
   {{0x25a91516,0xdab900d8,0xb5fb0037,0x00000000}},	//   haal_, нымі_, _dhái, --,
   {{0xa9a60073,0xc4d001c0,0xe8070067,0x00000000}},	//   линд, _सङ्ख, शाना_, --,
   {{0xb5fb0082,0x6e2205d6,0x68f60297,0xa2c40785}},	//   _fhái, _glob, _pryd, ांत्,
   {{0x25a996da,0x7a2620d9,0xdcf90069,0x9f45654d}},	//   daal_, _nóte, _fewġ, _malí_,
   {{0x013602b5,0x60db96db,0x68f60173,0x395e0029}},	//   אָלט_, _mpum, _vryd, āts_,
   {{0xa3aa0299,0x186717e3,0x2cad00ab,0x25a92ddb}},	//   _गजब_, уари_, lsed_, faal_,
   {{0x2bcf09b8,0x25a92193,0xfbcf000c,0xdb0196dc}},	//   त्रा, gaal_, त्रम, nalí,
   {{0x056696dd,0x9f4c0132,0x9f450036,0x2cad96de}},	// [a7e0] уван, _cadê_, _salì_, nsed_,
   {{0x389b0317,0x44230176,0xb97b0070,0x232a0faf}},	//   _ריינ, _clj_, _אנפי, нози_,
   {{0x3ce51db6,0x81e800c8,0x25a93e6e,0xe29713ad}},	//   _जैसे_, বাস_, baal_, гах_,
   {{0x69c606d4,0x31260009,0x2cad00ab,0x25a902a2}},	//   ngke, лдег, ksed_, caal_,
   {{0xc05a01c8,0x9f4596df,0x69c6033b,0x3e4c00b8}},	//   нік_, _dalí_, igke, něte_,
   {{0x6e220912,0x2d8f0345,0xd0072503,0x7d040284}},	//   _slob, _afge_, лече_, _àisi,
   {{0x44447868,0x644310a5,0x6e220069,0x201c2744}},	//   mn_, čnit, _plob, rkvi_,
   {{0x444496e0,0xb5fb004f,0xdb01213c,0x62580037}},	//   ln_, _phái, galí, ríos,
   {{0x444496e1,0x3d0e007c,0xa5bb0176,0xdb080183}},	//   on_, िहें_, _olón, cadê,
   {{0x444496e2,0x443a96e3,0x60c266e5,0x76446de5}},	//   nn_, nip_, muom, hniy,
   {{0x444496e4,0x25a90223,0xe45702b5,0x2cad0122}},	//   in_, yaal_, רייט_, ased_,
   {{0xc3335c8e,0x6eca01c2,0xb5fb0082,0x443a96e5}},	//   מות_, _qəbu, _thái, hip_,
   {{0x443a96e6,0x25a9394d,0xdddb04d4,0xddc9027d}},	//   kip_, vaal_, lmuş, lleş,
   {{0x444496e7,0x443a02e9,0x8c435a7e,0x25a91e7e}},	//   jn_, jip_, _лече, waal_,
   {{0x7c3a96e8,0x25a90d26,0x61e24c46,0xdddb0716}},	//   mitr, taal_, keol, nmuş,
   {{0x5eb90083,0x6eca0095,0x60c296e9,0x00000000}},	//   _আহমে, _həbs, kuom, --,
   {{0x61e20723,0x25a9152b,0x7a260093,0x444496ea}},	// [a7f0] deol, raal_, _fótb, fn_,
   {{0x444403ce,0x7c3a96eb,0x25a996ec,0xddc901d6}},	//   gn_, nitr, saal_, kleş,
   {{0x45d596ed,0x25a911ad,0x60db145f,0x7e9100ec}},	//   _конс, paal_, _spum, _kāpe,
   {{0x444496ee,0x7c3a0693,0x2c6b08c8,0x09e30033}},	//   an_, hitr, møde_, যাকা,
   {{0x4444022e,0x9f4700b8,0x26d101a3,0x443a0381}},	//   bn_, rdní_, ltzo_, bip_,
   {{0x660d96ef,0xb5fb4469,0x443a96f0,0x62830097}},	//   ljak, _cháv, cip_, ínos,
   {{0xdb0334fc,0x7c3a96f1,0x26d101a3,0x9294010b}},	//   _genè, ditr, ntzo_, _гасц,
   {{0xed596dc0,0x645701dd,0x61e20037,0x2cad00ab}},	//   кой_, loxi, ceol, tsed_,
   {{0x0c2537e1,0xac850370,0x63a70009,0x10d805bc}},	//   имин, јгол, _kejn, _مبلغ_,
   {{0x2cad96f2,0xdb0107a6,0x7c3a0409,0x660d18af}},	//   rsed_, salí, gitr, hjak,
   {{0x7f8402aa,0x81e80b52,0x2cad0122,0x764496f3}},	//   _المن, বার_, ssed_, yniy,
   {{0x26c30831,0xc8690d85,0x443a96f4,0x62870031}},	//   dujo_, _חן_, zip_, _mujo,
   {{0x444496f5,0xeb8e0faf,0xdca5039e,0xdb0396f6}},	//   yn_, _ми_, _тали, _mené,
   {{0x7c280014,0x7c3a96f7,0x63a701c0,0x07a33d53}},	//   chdr, citr, _nejn, жарн,
   {{0x44440909,0x81ab0083,0xcc3a02b5,0x443a96f8}},	//   vn_, _খান_, _בעסט, vip_,
   {{0xe8fa0500,0x444496f9,0x660d96fa,0x644596fb}},	//   _али_, wn_, gjak, enhi,

   {{0x628702e1,0x443a486e,0x7d1b3439,0xddc901d6}},	// [a800] _aujo, tip_, nyus, zleş,
   {{0x444496fc,0x645701ef,0x26c30831,0x62874835}},	//   un_, goxi, bujo_, _bujo,
   {{0x444496fd,0x63a796fe,0x61e200c3,0x62870132}},	//   rn_, _dejn, teol, _cujo,
   {{0x443a96ff,0x7d1b01a8,0x44449700,0xe7d205f7}},	//   sip_, kyus, sn_, द्रप,
   {{0x81e80033,0x44449701,0x9f5e021d,0x8547051a}},	//   বাল_, pn_, _inté_, _взяв_,
   {{0x20560c01,0x443a00da,0x64a30ddc,0x61e20037}},	//   штер, qip_, _фара, seol,
   {{0x212017ee,0x6e299702,0x60c21db7,0xdb080392}},	//   ših_, fheb, suom, cadè,
   {{0xfe6f07f6,0xddc901d6,0xdb0325ec,0xdddb045e}},	//   ودي_, rleş, _gené, rmuş,
   {{0x7c28499b,0x394d006a,0x9c460439,0x4fea021d}},	//   thdr, żesz_, ихол, _иман_,
   {{0x62809703,0xddc90139,0xdb03006c,0xe8d90023}},	//   _himo, pleş, _zené, _ngỡ_,
   {{0x752d07c9,0x62809704,0x9f450036,0x645c002f}},	//   zzaz, _kimo, _galà_, _mkri,
   {{0xdd8f0332,0x7c3a8dba,0x6cd6006c,0xdb030391}},	//   _قوم_, sitr, _نقصا, _xené,
   {{0x62807478,0x7c940082,0x8c460132,0x3ea9044d}},	//   _mimo, _التص, _кеде, ćate_,
   {{0xd83b002d,0xe8240328,0x7984001c,0x44389705}},	//   тэм_, офсо, _egiw, _nmr_,
   {{0x63a79706,0x41d71579,0xb5a7643e,0x00000000}},	//   _rejn, ण्डस, ирай, --,
   {{0x4b7b1899,0x628003be,0x6d5c008f,0x660d00d7}},	//   _באוו, _nimo, ğraf, ujak,
   {{0x9f45024e,0x63a7082d,0x69cd0176,0xdb039707}},	// [a810] _malá_, _pejn, _icae, _rené,
   {{0x62879708,0x660d9709,0x62804db8,0x224601ba}},	//   _pujo, sjak, _aimo, enok_,
   {{0x6457970a,0xdb03970b,0x2d8201ba,0x2bd800a1}},	//   roxi, _pené, ľkej_, ब्या,
   {{0x645c02d0,0x64572c36,0xb5fb00ac,0xf8bf000d}},	//   _ekri, soxi, _chát, oré_,
   {{0x6280970c,0xb5fb0037,0x14f400d8,0x60140176}},	//   _dimo, _dhát, _дзяў, _pàmp,
   {{0x09e30033,0x7a265bdd,0x9f450176,0x3e61003e}},	//   যাটা, _móta, _palà_, móti_,
   {{0x6e29970d,0xdb030831,0xdb011d8a,0x00000000}},	//   theb, _tené, kalá, --,
   {{0xf2d202b8,0x6280970e,0xf8bf0097,0x7d1b970f}},	//   _מעל_, _gimo, kré_, tyus,
   {{0x6e299710,0x7a260037,0x2bc200a9,0x26080864}},	//   rheb, _nóta, _शाखा, हाती_,
   {{0xf8bf1dfd,0x69cd07a6,0x0c253cef,0x62808013}},	//   dré_, _acae, смон, _zimo,
   {{0x442137db,0xdce706d0,0x682b01c2,0x68ed9711}},	//   ikh_, ımız, _müdd, _asad,
   {{0x6eca0095,0xdb01006c,0xa5bb0093,0x2bd82f41}},	//   _təbr, galá, _blóm, ब्बा,
   {{0xc9560086,0xf8bf0248,0x7a360791,0x2d9f002f}},	//   стны, gré_, nšti, mbue_,
   {{0x765d7ee5,0x2cbf1051,0x00000000,0x00000000}},	//   _aksy, mrud_, --, --,
   {{0xd62a0c0e,0x6eca007e,0xf99f07e5,0xf8bf0d9a}},	//   гове_, संयु, bbè_, aré_,
   {{0x44210103,0xf8bf0076,0xbbb70967,0x7a36010b}},	//   ekh_, bré_, _आयुक, kšti,
   {{0xcc880028,0x62809712,0x44389713,0xf8bf0248}},	// [a820] _lớn_, _rimo, _pmr_, cré_,
   {{0x601d72c2,0xb5fb0098,0x765d0421,0x00000000}},	//   _fèmi, _bhás, _eksy, --,
   {{0x26080026,0xddc99714,0x644b0e8c,0xb5fb0098}},	//   हादी_, zmeš, égia, _chás,
   {{0xd2592659,0x443802a2,0x00000000,0x00000000}},	//   аці_, _wmr_, --, --,
   {{0x25a01201,0x62801ea3,0x44389715,0xf1a900f3}},	//   mbil_, _vimo, _tmr_, شانه_,
   {{0x20b963fa,0x645c9716,0x443844c8,0x25a09717}},	//   рыць_, _ukri, _umr_, lbil_,
   {{0x62800c1f,0xe2970d6e,0x3ea5099e,0xdb0100fd}},	//   _timo, _гас_, _cwlt_, yalá,
   {{0x25a0198d,0x00000000,0x00000000,0x00000000}},	//   nbil_, --, --, --,
   {{0xc5f300a5,0xeb200d1f,0x53cf00b4,0xb53b016b}},	//   לדה_, मन्त_, स्कश, ָגיש,
   {{0xf8bf00f7,0x68ed00d7,0x09d60831,0x00000000}},	//   vré_, _rsad, _তোলা, --,
   {{0xdb019718,0x7a262a04,0x68ed01a8,0x1ee800e0}},	//   talá, _sóta, _ssad, _خوای_,
   {{0x5d86004f,0xf8bf5b69,0x00000000,0x00000000}},	//   _الإل, tré_, --, --,
   {{0xfdf700a5,0x4421002f,0xf8bf15f9,0xdb0100fd}},	//   _לצאת_, ykh_, uré_, ralá,
   {{0xf8bf9719,0x7a260037,0x68ed0252,0xdb0100fd}},	//   rré_, _vóta, _vsad, salá,
   {{0xdc3b02b5,0x6fda08b6,0x501b0122,0x7e9100ec}},	//   _געגר, प्यू, נולו, _kāpa,
   {{0xe8d901a5,0x7e9100ea,0x682b971a,0x68ed971b}},	//   _ngủ_, _jāpa, _südd, _tsad,
   {{0x68ed0aca,0x841501af,0x3a290159,0xb5fb0098}},	// [a830] _usad, омах, _ilap_, _shás,
   {{0x4427971c,0x3ce03e72,0x7a36971d,0xb4e90907}},	//   ón_, _कहने_, všti, _मनी_,
   {{0xfa890019,0x3a29718e,0xb8670088,0x6489023a}},	//   _lẫn_, _klap_, _پاکو, _ožig,
   {{0xa5f901f6,0x925900c3,0x00000000,0x00000000}},	//   _тему_, шает_, --, --,
   {{0x7a36003a,0x99800160,0x00000000,0x00000000}},	//   ušti, _moiş_, --, --,
   {{0xd5bf00ea,0x1e9532a6,0x9f5e0453,0x7a36971e}},	//   žādu_, орир, _notó_, ršti,
   {{0xa49b01da,0xb4e91edf,0x00000000,0x00000000}},	//   _bròg, _मनु_, --, --,
   {{0x7a363b12,0x850d0026,0xfe6e1328,0x00000000}},	//   pšti, _सपाट_, نگن_, --,
   {{0x9f5e0310,0x814500b5,0x224d442d,0x7ae40124}},	//   _botó_, _بچان, _ijek_, _ćita,
   {{0xfa8900e8,0x3f85971f,0x2ca9003c,0x9f5e0392}},	//   _dẫn_, _uglu_, _ħadd_, _cotó_,
   {{0xcb699720,0x00000000,0x00000000,0x00000000}},	//   ране_, --, --, --,
   {{0x6b9c0225,0x24830223,0x2ca6021e,0x9f450a8a}},	//   ırga, _lijm_, _fwod_, _palæ_,
   {{0xa3aa007c,0x9f450176,0x9f5e00b5,0x224d0055}},	//   _गजल_, _balç_, _fotó_, _mjek_,
   {{0xeb9910da,0x30790070,0x9f4501f7,0x2bd8022e}},	//   _тик_, יאָנ, _calç_, ब्दा,
   {{0x224d0feb,0x4b790070,0x98ab0228,0x00000000}},	//   _ojek_, _דאַו, ājās_, --,
   {{0xb5fb0037,0x6d4a0207,0xdb0306fe,0x682b02b1}},	//   _shár, šmaš, _jení, _rüde,
   {{0xa70a0083,0x3ea00a78,0x25a09721,0x9f4501f7}},	// [a840] রনেম_, ćiti_, rbil_, _falç_,
   {{0x25a09721,0x7d040037,0x224d0118,0x7a2600d5}},	//   sbil_, _áise, _ajek_, _kóto,
   {{0x248b0176,0x25ab055c,0x00000000,0x00000000}},	//   _eucm_, _fecl_, --, --,
   {{0x2005011e,0x20d200af,0x25ab009e,0x7a26008d}},	//   _anli_, tâi_, _gecl_, _móto,
   {{0x9f5e0036,0xa49b0211,0x00000000,0x00000000}},	//   _notò_, _cròd, --, --,
   {{0x443e00b5,0x2fc0033b,0x09b7198f,0x33d51645}},	//   _öt_, ßig_, _अय्य, _ніст,
   {{0xa49b0014,0x9f4c7bb8,0x73f90070,0x09b00033}},	//   _pròg, _andò_, _פּשו, _কানা,
   {{0xdb0300b8,0x00000000,0x00000000,0x00000000}},	//   _cení, --, --, --,
   {{0xdb0301c0,0xecfa0033,0x629e00c3,0x9f5e0098}},	//   _dení, েন্স_, lppo, _intí_,
   {{0xfa890028,0x2a60046a,0xa06a1402,0xbfc30166}},	//   _vẫn_, _akib_, _таза_, _обук,
   {{0x7e910029,0x60c20f0a,0x9f5e0453,0x442a9722}},	//   _tāpa, lrom, _votó_, _mlb_,
   {{0x2d9208a1,0xed5a4d11,0x0dc72dbb,0x261c0453}},	//   _üye_, _кое_, _души_, _míos_,
   {{0xe8070967,0xb4e90456,0xc984875c,0x9f4c0176}},	//   शाला_, _मने_, дури, _madí_,
   {{0xe8d90019,0x442a008b,0x9f4c00ac,0xdb0806fe}},	//   _ngụ_, _nlb_, _ladí_, ladí,
   {{0x261c0514,0x5694818c,0x60c29723,0x00000000}},	//   _níos_, даст, hrom, --,
   {{0x60c20076,0x442a9724,0xb5fb0187,0x682b0095}},	//   krom, _alb_, _cháp, _büdc,
   {{0x98be002d,0x6b8d00a8,0x05770118,0x00000000}},	// [a850] ătă_, _şagi, زارد, --,
   {{0x60c28ada,0x442a01a5,0xf3672351,0x93270a42}},	//   drom, _clb_, отен, يران,
   {{0x261c0037,0x629e0159,0x00000000,0x00000000}},	//   _cíos_, gppo, --, --,
   {{0x9f4c11fa,0x442a56df,0xa49b0176,0xcb13025a}},	//   _cadí_, _elb_, _pròd, ולע_,
   {{0x260822a7,0x09b00033,0xae090026,0x24830051}},	//   हारी_, _কামা, वासन_, _tijm_,
   {{0xd3e30a86,0x261c0042,0xdb0301ef,0x64580124}},	//   _تقسی, _fíos_, _sení, čvic,
   {{0xd00e004f,0xdb039725,0x224d054e,0x60c20036}},	//   الى_, _pení, _tjek_, arom,
   {{0x92580421,0x3e610093,0xdb089726,0x7bda0051}},	//   _даст_, jótt_, gadí, eftu,
   {{0xdb030831,0xb4e9170c,0xa5bb0079,0x44ed023a}},	//   _vení, _मनो_, _clói, _jž_,
   {{0x6fd20099,0x20050159,0x1fa720cc,0x98a20035}},	//   _सायं, _unli_, _фраг, czkę_,
   {{0xa3dd1ae9,0xdb039727,0x98b00254,0x23dd022e}},	//   थ्य_, _tení, đača_, न्यद,
   {{0x9f5e07e5,0x00000000,0x00000000,0x00000000}},	//   _totò_, --, --, --,
   {{0xed4e1f39,0x601d021e,0xdb0a139b,0x6fd2074f}},	//   _чо_, _fèmt, _lefè, _सामं,
   {{0x3ce0004e,0x261c004f,0xe7f30035,0xfe7900b8}},	//   _कहते_, _níor_, इएगा_, lmů_,
   {{0x44ed114d,0xe5a620a6,0x91cc22a7,0x09b00033}},	//   _až_, зиби, _हालै, _কাঠা,
   {{0x261c0f56,0x00000000,0x00000000,0x00000000}},	//   _ríos_, --, --, --,
   {{0x261c0082,0x6adb135e,0xdb18021e,0x9f4c0097}},	// [a860] _síos_, _बहुर, _advè, _radí_,
   {{0x44ed1e80,0xb4630854,0x2900478a,0x7a260093}},	//   _dž_, екул, _iria_, _mótm,
   {{0xa49b009e,0xf8bf00b5,0x629e0328,0x38c20093}},	//   _cròb, szét_, uppo, _færð_,
   {{0x7aba0122,0xcc8801a5,0x26ca0c47,0xdb0a02d0}},	//   מצעו, _sớm_, mubo_, _defè,
   {{0x26d89728,0x261c004f,0xdb030176,0xdb0801ef}},	//   ltro_, _fíor_, _lenà, vadí,
   {{0x60c280f4,0x261c2b82,0xd7dc0096,0x6e2b2670}},	//   rrom, _tíos_, यभिच, _algb,
   {{0xdb089729,0x645e972a,0x60c23dd1,0xa5bb0079}},	//   tadí, mopi, srom, _slói,
   {{0x682b0ec4,0x26c50254,0x11da0037,0x2900972b}},	//   _müda, šlog_, _دورة_, _oria_,
   {{0xdb08972c,0x80a60934,0x26ca010d,0x628e972d}},	//   radí, _رمان, hubo_, _hubo,
   {{0x628e972e,0x26d80252,0x26ca0273,0x8cbd0d2b}},	//   _kubo, ktro_, kubo_, _शिरो,
   {{0x2900972f,0xdb0803e6,0x0d8663f5,0x628e023a}},	//   _aria_, dadã, _елен, _jubo,
   {{0x645e00ac,0x628e9730,0xdb030279,0x29000107}},	//   hopi, _mubo, _senã, _bria_,
   {{0x628e9731,0x29009732,0x7e62007a,0x26d8027a}},	//   _lubo, _cria_, _ikop, etro_,
   {{0xb8f59733,0x629c9734,0x645e025c,0x7d1d2185}},	//   _हम_, _otro, jopi, ässe,
   {{0x629c17f0,0x628e9735,0x45d52d64,0x26ca9736}},	//   _ntro, _nubo, мовс, gubo_,
   {{0x29009737,0xdb0a9738,0x2bd80275,0x3e4500ea}},	//   _fria_, _nefé, ब्रा, bētu_,
   {{0x629c26e3,0x7e62002f,0x26d8027f,0x683001ff}},	// [a870] _atro, _mkop, atro_, _bädd,
   {{0x628e9739,0x44ed77ec,0x26ca010d,0xdb18021d}},	//   _bubo, _vž_, bubo_, _advé,
   {{0x41d10f09,0x26ca973a,0x2bd40808,0x63ae973b}},	//   _हादस, cubo_, _दाना, _debn,
   {{0x628e0a78,0x237400b5,0x656f034d,0x00000000}},	//   _dubo, رالح, _tzch, --,
   {{0x44ed973c,0x99890009,0xdb0a1c02,0xdb030c43}},	//   _už_, _omaž_, _defé, _mená,
   {{0x442502c7,0x23c302e1,0x645e83a6,0x9f470237}},	//   _ôl_, _déjà_, copi, lené_,
   {{0x764d25e8,0x81e80033,0x628e2716,0x00000000}},	//   onay, বাজ_, _gubo, --,
   {{0xdb03024e,0x764d018e,0x9f47016f,0x6b8a008c}},	//   _nená, nnay, nené_, _agfg,
   {{0xdb01973d,0x9f5e0392,0x61eb973e,0x629200ea}},	//   mblé, _entà_, megl, ējoš,
   {{0x09c600a1,0x61eb8013,0x4b2500d4,0x683000c3}},	//   वल्य, legl, дмов, _käde,
   {{0x39ea2770,0x69dd038e,0x26d801ef,0xdb030187}},	//   одно_, ffse, xtro_, _bená,
   {{0x20d11856,0x257400fb,0x2900973f,0x9f47024e}},	//   _समाध, _júlí_, _pria_, jené_,
   {{0x9f4770cf,0x645e000e,0x682b4ec3,0x68301173}},	//   dené_, yopi, _süda, _läde,
   {{0xaac506bb,0x26d801d3,0x3e450080,0x26ca9740}},	//   _विपक, ttro_, rētu_, tubo_,
   {{0x18670714,0x6830022a,0x27e101ed,0x26d801ef}},	//   фари_, _rädd, _dbhn_, utro_,
   {{0x29009741,0x764d00a7,0x628e6491,0x26ca2d58}},	//   _tria_, gnay, _rubo, rubo_,
   {{0x629c451b,0x628e2288,0x2bd400ab,0x29009742}},	// [a880] _stro, _subo, _दामा, _uria_,
   {{0x764d0103,0xd7ca00bf,0x7e699743,0x60cb011e}},	//   anay, _بوده_, hlep, dugm,
   {{0x645e9744,0x9f470076,0x7e690a0b,0x3e450228}},	//   ropi, bené_, klep, nēts_,
   {{0x7e692d88,0x63ae9745,0x63a901f2,0x61eb9746}},	//   jlep, _webn, _đene, gegl,
   {{0x5fc9065a,0x63ae0582,0x60cb02b3,0x645e93d2}},	//   _राखल, _tebn, gugm, popi,
   {{0x7e62009f,0x628e9747,0x6830191b,0x00000000}},	//   _skop, _tubo, _fäde, --,
   {{0x629c1f8b,0xe7e00f17,0x61eb9748,0x638380e3}},	//   _utro, ख्या_, begl, _агра,
   {{0x64891269,0x7e6996c2,0xcc8800e2,0x4e770037}},	//   _užic, glep, _hới_, وحيد_,
   {{0xdb080391,0x75240273,0x1b1b0083,0x01d7250f}},	//   dadá, nyiz, _ফেলে_, _توقع_,
   {{0x4444734b,0x9f47024e,0xdb03031d,0x5b140390}},	//   ni_, zené_, _sená, емот,
   {{0xcc88098b,0x44449749,0x764d2f80,0x59f900d8}},	//   _mới_, ii_, ynay, пеня_,
   {{0x4444974a,0x27e1010d,0x7e6200cd,0xdb0800b5}},	//   hi_, _sbhn_, _ukop, gadá,
   {{0x9f47290b,0x69dd008a,0x7e601b1e,0x76441505}},	//   vené_, rfse, momp, diiy,
   {{0x7e60974b,0x61eb004e,0x68fd08c8,0x7d02974c}},	//   lomp, zegl, rvsd, _iros,
   {{0x9f4772d3,0x3e450029,0x2bf300a1,0x290d00af}},	//   tené_, cēts_, _असतं_, ţea_,
   {{0x4444974d,0x7e60974e,0x661601f4,0xf1b90097}},	//   ei_, nomp, gjyk, _koše_,
   {{0x9f4701ba,0x61eb027a,0x764d0a21,0x96010033}},	// [a890] rené_, vegl, rnay, _একদম_,
   {{0x7e690097,0x683000ab,0xcc8800e2,0x61eb02b1}},	//   zlep, _päde, _bới_, wegl,
   {{0xf1b9039a,0xf367004b,0x7a260037,0x648900d8}},	//   _loše_, фтан, _bóth, _džia,
   {{0x4444974f,0x7d029750,0x6830022a,0x60cb9751}},	//   ai_, _oros, _väde, tugm,
   {{0x44449752,0x0ef70026,0xd0099753,0xaac505f8}},	//   bi_, ंट्स_, зеле_, _विभक,
   {{0x61eb9754,0x78ad0428,0xdb089755,0x9f450b3e}},	//   segl, _mwav, zadá, _kalø_,
   {{0x64453044,0x661d03ad,0x61eb9756,0x21290693}},	//   mihi, _kosk, pegl, šah_,
   {{0x64455b97,0x7d029757,0x798d9758,0x661d0086}},	//   lihi, _bros, _ngaw, _josk,
   {{0x661d9759,0x7e69975a,0x7d020f41,0xdfdb01d3}},	//   _mosk, rlep, _cros, _мъж_,
   {{0xa2c40429,0x64450269,0x7d02975b,0x683001ae}},	//   ांच्, nihi, _dros, _mädc,
   {{0x7d0206a2,0x7e69975c,0x7a6a3296,0xdb0316f6}},	//   _eros, plep, зинг_, _menç,
   {{0x44444052,0xb87b0876,0x6445975d,0xc8690122}},	//   zi_, ntíf, hihi, _הן_,
   {{0x4444975e,0x64450468,0xad270ae7,0xdb08975f}},	//   yi_, kihi, _تراو, radá,
   {{0x6e2901b4,0x644508a0,0x7a26008d,0x4444409c}},	//   lkeb, jihi, _móti, xi_,
   {{0x44449760,0x644505ca,0x66e323fe,0x2edd1cce}},	//   vi_, dihi, лора, _महोत,
   {{0x44440a1e,0x62890035,0x13a80b35,0x6e299761}},	//   wi_, _nieo, गर्भ, nkeb,
   {{0x661d17a1,0x69d60010,0xdb030132,0x78ad073a}},	// [a8a0] _dosk, _icye, _benç, _gwav,
   {{0x44449762,0x7644073a,0x64450afe,0x394d0042}},	//   ui_, siiy, gihi, úese_,
   {{0xa6861fff,0x6e2913dc,0xf2a6278d,0x7e609763}},	//   _плод, kkeb, хиеп, yomp,
   {{0x44449764,0xcc88098b,0x3ce00006,0x63a31505}},	//   si_, _với_, _कहले_, ınna,
   {{0x44442dfb,0x64450269,0x47b300c8,0xa06a9765}},	//   pi_, bihi, _জাতী, пада_,
   {{0xcc8800e8,0x44449766,0xdb0301d6,0x3e4c00b8}},	//   _tới_, qi_, _genç, měti_,
   {{0x7e6000d1,0xdb0a054e,0x27fa0395,0x7a26605e}},	//   tomp, _udfø, _mapn_, _tóth,
   {{0xe7e00084,0xb87b0138,0x6e290345,0x6fd20ec5}},	//   ख्ता_, ctíf, gkeb, _सावं,
   {{0x7a261d2b,0x2bd40ca1,0xed5000b5,0x02e001c0}},	//   _góti, _दादा, جھا_, _नहुन,
   {{0x22469767,0x69d60371,0x78ad007b,0x00000000}},	//   liok_, _acye, _rwav, --,
   {{0x200c9768,0xaa59748e,0x7c28476c,0x3a756cef}},	//   _indi_, дину_, rkdr, клор,
   {{0x7d029769,0xf1b90c21,0x200c067f,0x644501d5}},	//   _tros, _toše_, _hndi_, zihi,
   {{0x64454e51,0x661d976a,0x201e0086,0xdca300d4}},	//   yihi, _rosk, _koti_, _бачи,
   {{0xa49b01da,0x201e976b,0xdb0301ff,0x00000000}},	//   _bròn, _joti_, _benä, --,
   {{0x661d7478,0xadf40299,0x201e976c,0x09b00033}},	//   _posk, _आसान_, _moti_, _কারা,
   {{0x201e941d,0x78ad010a,0x798d08c7,0x00000000}},	//   _loti_, _twav, _ugaw, --,
   {{0x648933ad,0x644549e2,0x78ad04fb,0x200c023a}},	// [a8b0] _džin, tihi, _uwav, _ondi_,
   {{0x201e498b,0xb4e10775,0xd37b3cc0,0xa5bb0312}},	//   _noti_, _दही_, пче_, _clór,
   {{0x6445976d,0x661d976e,0xdb0361b1,0xdb180097}},	//   rihi, _tosk, _venç, _odví,
   {{0x200c043c,0x6445976f,0x787201b4,0x224601b7}},	//   _andi_, sihi, nævn, giok_,
   {{0x25a99770,0x683000ab,0xa5bb72c5,0x64454733}},	//   mbal_, _häda, _flór, pihi,
   {{0xa5bb9771,0x289800a5,0xdb18002a,0x628901e4}},	//   _glór, עדון_, _adví, _wieo,
   {{0x4ac500c4,0xe45481b6,0x201e1141,0xf4560317}},	//   _विधव, _скры, _doti_, _יישר_,
   {{0x60c401c8,0x200c00d1,0x25a99772,0xf1d80026}},	//   šima, _endi_, nbal_, _डायन,
   {{0x69a225d8,0x6e299773,0x9f477692,0xdb0a01dd}},	//   _क्षी, rkeb, mení_, _defí,
   {{0xb5fb9774,0x9f47000c,0x61fb9775,0x443102c4}},	//   _skál, lení_, _haul, _jlz_,
   {{0x68300006,0xbf150a86,0x61fb9776,0xa9a63b3c}},	//   _näda, _جواب, _kaul, кинд,
   {{0x201e00da,0x61fb60d6,0x25a90187,0x9f4701ba}},	//   _zoti_, _jaul, jbal_, není_,
   {{0x25a99777,0x91ba00a5,0x290432af,0x443101f7}},	//   dbal_, ומרי, íma_, _olz_,
   {{0x69a20378,0x61fb9778,0x80c40026,0xb8ea021a}},	//   _क्री, _laul, _रिसे, _लट_,
   {{0xf1b304bc,0x25a93170,0xdb03029e,0x52d000be}},	//   ुणान, fbal_, _benå, _हमेस,
   {{0x9f4701c0,0xdb030086,0xcfca0083,0x61fb9779}},	//   jení_, _venä, ল্পন, _naul,
   {{0x9f470076,0x4431977a,0xf8bf00b5,0x60db0069}},	// [a8c0] dení_, _blz_, lyén_, _nqum,
   {{0xa49b977b,0x232a02c4,0x648900c7,0x25a90341}},	//   _tròn, мози_, _džio, abal_,
   {{0x61fb977c,0x2bd408b0,0x645502a7,0x25a9026b}},	//   _baul, _दासा, _djzi, bbal_,
   {{0x201e0c1f,0x28af0026,0xfb1a02b5,0x10a60192}},	//   _soti_, जीवि, וועמ, видн,
   {{0x201e977d,0xdb0a0391,0x260f3272,0x61fb31ed}},	//   _poti_, _refí, डारी_, _daul,
   {{0x03a302ce,0x2d8f448b,0x61fb01ed,0x6aba977e}},	//   _виро, _agge_, _eaul, ystf,
   {{0x201e046f,0x04431a76,0xe297021d,0x9f470314}},	//   _voti_, _терн, _аас_, bení_,
   {{0x69a202e4,0x9f47000c,0x26080084,0x61fb977f}},	//   _क्ली, cení_, हाटी_, _gaul,
   {{0x201e0043,0x64890121,0x9cb401df,0x71660037}},	//   _toti_, _ožil, دمخت, _شارك,
   {{0xfa8a0028,0x200c222c,0xe9df0037,0x61e21fbb}},	//   _mẫu_, _undi_, giún_, lfol,
   {{0xa3e4052f,0x61fb023c,0x3a32008c,0xb87b0176}},	//   भ्य_, _yaul, _blyp_, ntíe,
   {{0xf2d300c2,0x61e29780,0x6cc61f39,0x2bd400b4}},	//   סער_, nfol, _айда, _दावा,
   {{0x2ba30299,0x9f45024e,0x2e37011d,0xcc880019}},	//   _ख्वा, _malý_, _בראש_, _bớt_,
   {{0x9f47000c,0x36d53422,0x68309781,0x8c430009}},	//   zení_, логр, _päda, _кече,
   {{0x368b0409,0xf1b90254,0x80cc0461,0xdb250987}},	//   дсан_, _loša_, _समझे, _مووی,
   {{0xdb01143e,0xe65401e0,0x61e22775,0x00000000}},	//   nalý, авсь, jfol, --,
   {{0x25a60f56,0x3ea903fd,0x9f47000c,0x44317df6}},	// [a8d0] ñola_, ćati_, vení_, _plz_,
   {{0x61fb26e3,0x25a99782,0xfa8a0023,0x57f50c65}},	//   _saul, sbal_, _dẫu_, _спот,
   {{0x61fb9783,0x61e29784,0xa3c422a3,0x9f470334}},	//   _paul, ffol, _एयर_, tení_,
   {{0x25a900d7,0xf1b90009,0x26d1034d,0x61e211cb}},	//   qbal_, _boša_, muzo_, gfol,
   {{0xdca6004f,0xb87b0042,0xfa8a0023,0x9f4700a0}},	//   _دى_, ptíd, _gẫu_, rení_,
   {{0xf1b9022f,0x9f470314,0x61fb0f25,0x2a690282}},	//   _doša_, sení_, _waul, _lkab_,
   {{0x61fb9785,0x9f470314,0x229701f4,0x2bb60067}},	//   _taul, pení_, _uçk_, _आज़ा,
   {{0xc69402b5,0xdb0705ee,0x00000000,0x00000000}},	//   סאפ_, ðlík, --, --,
   {{0x4bd901c8,0x7a26008d,0x315500d8,0x7aea0211}},	//   ньня_, _mótt, _сваё, _apft,
   {{0x6295087c,0x2a690359,0x26d1010a,0x63b50116}},	//   _kuzo, _akab_, kuzo_, _jezn,
   {{0xcc880023,0xab29005f,0x63b506fe,0x2bd40099}},	//   _rớt_, хона_, _mezn, _दारा,
   {{0xe9df004f,0x62950027,0x98a69786,0xa49b0392}},	//   siún_, _muzo, лиме, _pròl,
   {{0x3a209787,0xfd100c26,0xaac5022e,0xec6e2d7a}},	//   _voip_, _وجه_, _विवक, _гп_,
   {{0x63b508c2,0xdb039788,0x7a263ea9,0x26d101d5}},	//   _nezn, _menú, _rótu, fuzo_,
   {{0xae1776c5,0xe9df0093,0xcc8800e2,0x389d0160}},	//   थापन_, gnús_, _vớt_, _fπrπ_,
   {{0x64899789,0x80c40026,0x6721330b,0x9f4500ac}},	//   _džim, _रिले, älja, _haló_,
   {{0x629506a2,0x7a260093,0xa49b0176,0x69c4978a}},	// [a8e0] _auzo, _dótt, _uròl, _idie,
   {{0x26d12967,0x660f02c4,0x63b5022f,0x41d109b1}},	//   buzo_, _enck, _cezn, _हाउस,
   {{0x61e2108c,0x2c79000d,0x316d000d,0xd62a978b}},	//   tfol, cède_, _ayez_, _зоне_,
   {{0x316d0036,0xb87b38bc,0x78a403d0,0xf1b90207}},	//   _byez_, ctíb, _ktiv, _poša_,
   {{0xdb010187,0xf48400e0,0x2bd407b5,0x7d1d02b1}},	//   valý, _ناسی, _दाला, ässl,
   {{0xdb0364df,0x60c4005f,0x00000000,0x00000000}},	//   _denú, šimo, --, --,
   {{0x69c4978c,0xdb180187,0x6295978d,0x648900ac}},	//   _odie, _odvá, _guzo, _ožij,
   {{0x69c401f4,0x7a26008d,0x63b5978e,0x7bc305f5}},	//   _ndie, _móts, _zezn, _adnu,
   {{0x2fd60514,0x8fa628a4,0xb87b978f,0x62950009}},	//   _متاح, _базе, ntíc, _zuzo,
   {{0x69c40291,0x62829790,0x09ad0bdd,0x09bf3779}},	//   _adie, lmoo, चर्य, ्ल्य,
   {{0x78a400c9,0x6f930037,0x69c4035f,0x28b7007c}},	//   _ativ, _المض, _bdie, _अबहि,
   {{0xa2cc1ee0,0xdb0a01ef,0x26d1007b,0xaac50ed1}},	//   _हिन्, _cefá, vuzo_, _विरक,
   {{0x9f47024e,0x648902c4,0xd90f02fd,0xdb019791}},	//   mená_, _džij, سید_, faló,
   {{0x6e220639,0x62820221,0x9f470076,0xd7f80de2}},	//   _hoob, hmoo, lená_, лус_,
   {{0x6e229792,0xae090632,0xf60b0949,0x63b59793}},	//   _koob, वाचन_, нхай_, _rezn,
   {{0x63b59794,0xadf90240,0x69c02eae,0x682b00a8}},	//   _sezn, ्ययन_, ómet, _müdi,
   {{0x6e221333,0xd3a70fc5,0x62950506,0x62820553}},	// [a8f0] _moob, греп, _suzo, dmoo,
   {{0x68ed18ad,0xb87b1d58,0xdb037347,0x69c4016f}},	//   _ipad, stíb, _renú, _zdie,
   {{0x63b500c5,0xe29800d4,0xf8bf00f7,0x6489010b}},	//   _vezn, гає_, lsé_, _užim,
   {{0x6e229795,0xa4d502ce,0x68ed00d7,0x9f470187}},	//   _noob, _комі, _kpad, jená_,
   {{0xf8bf9796,0x9f470237,0x629a00f7,0x6f080037}},	//   nsé_, dená_, _éton, _ardc,
   {{0x41260086,0x1aeb0083,0x4394695e,0xe3cc0033}},	//   рошо_, টিতে_, _гарс, র্বব,
   {{0x6e229797,0x59c50099,0x9028010b,0x00000000}},	//   _boob, वणार, ыцца_, --,
   {{0x68ed9798,0x6e2233b0,0x442376e4,0x9f450310}},	//   _opad, _coob, _hoj_, _saló_,
   {{0x44231020,0x6e226cc4,0x61e90069,0x6d4401ba}},	//   _koj_, _doob, _ibel, _žiar,
   {{0x3ce527bd,0x44233257,0x1c452a66,0xa0c40037}},	//   _कहीं_, _joj_, рном, _ديكو,
   {{0x4423125d,0x9f459799,0x9f470187,0x68ed3636}},	//   _moj_, _való_, bená_, _apad,
   {{0x442301a9,0xa2d60cf1,0x9f45027a,0x61e90024}},	//   _loj_, मंत्, _falò_, _jbel,
   {{0x61e95dda,0xdb01979a,0x6721022a,0xe8f700a4}},	//   _mbel, taló, äljn, аля_,
   {{0x80cd0324,0x442301a9,0xc0520070,0x5d3a32e3}},	//   _सिने, _noj_, ַזן_, _בתנא,
   {{0x61e9979b,0xbb426266,0x7c2311d9,0x2cbf0176}},	//   _obel, _мешк, _ionr, lsud_,
   {{0x7c23659c,0x656f9592,0x69c4979c,0x6a762dea}},	//   _honr, _bych, _udie, máfo,
   {{0xa4463945,0x656f001e,0x44230a3c,0x2909008c}},	// [a900] анад, _cych, _boj_, _graa_,
   {{0x442301a9,0xb87b0042,0x61e9979d,0x656f47a1}},	//   _coj_, rtíc, _abel, _dych,
   {{0xb87b979e,0xfbdd1b8f,0x44230ca0,0x2bdd04cc}},	//   stíc, _मानम, _doj_, _माना,
   {{0x2cbf9379,0xcc880028,0x27ed01cc,0x91e64697}},	//   ksud_, _lớp_, đene_, роде,
   {{0x6e228e06,0x6282979f,0x6f080237,0x9f47024e}},	//   _roob, rmoo, _srdc, vená_,
   {{0x6e2297a0,0x3ec603ad,0x7c2397a1,0x628297a2}},	//   _soob, асиб, _nonr, smoo,
   {{0xb87b0b4c,0x6e2297a3,0x9f45027a,0x9f470501}},	//   ntía, _poob, _salò_, tená_,
   {{0x81e400c8,0x44230221,0x25a097a4,0x7d0d0009}},	//   _ভোর_, _zoj_, ncil_, _šasa,
   {{0x28d80355,0x442301e8,0x80a603c7,0x10a397a5}},	//   भूमि, _yoj_, _ضمان, _митн,
   {{0x7c2397a6,0x9f4700ac,0x2eec034d,0x00000000}},	//   _conr, sená_, _tpdf_, --,
   {{0x5bb611b5,0x648924b7,0xdfcf0037,0xdb1a0031}},	//   _आजीव, _džih, _زين_, matë,
   {{0xfce62674,0xade204cc,0x26c52669,0x60cd0207}},	//   _водо, क्शन_, álom_, šame,
   {{0x25a000d5,0xf8bf00a2,0x984b02fb,0xa2d60b35}},	//   dcil_, usé_, вява_, मूत्,
   {{0x656f000c,0x2bdd4f52,0x69c001dd,0x26c52df4}},	//   _rych, _माया, ómer, šlom_,
   {{0xf8bf8456,0x44230189,0x87041583,0x68ed0035}},	//   ssé_, _roj_, ояте, _wpad,
   {{0x44230221,0x7a36010b,0xbbb600ab,0x5bb600ab}},	//   _soj_, kšty, _आजुक, _आजुव,
   {{0x44230189,0x68ed7d3f,0xdb1a01f4,0xd498066d}},	// [a910] _poj_, _upad, katë, арх_,
   {{0x656f05d3,0x442397a7,0x7c3a0023,0x601d0260}},	//   _vych, _qoj_, nhtr, _fèmy,
   {{0xd7dc0953,0x442397a8,0x656f004e,0xed590254}},	//   _बातच, _voj_, _wych, maže_,
   {{0xed590a23,0x44230035,0xb1150328,0x656f088a}},	//   laže_, _woj_, ймеш, _tych,
   {{0x442397a9,0x3ce50299,0x764d6a87,0x181a04e8}},	//   _toj_, _कहें_, miay, _شریک_,
   {{0xed595ed9,0x764d01ef,0x3dc6008c,0x73c50037}},	//   naže_, liay, _adow_, _ديسم,
   {{0xf8380d85,0xbf01252c,0x752d97aa,0x7c2300f6}},	//   שנות_, लटेन_, lyaz, _ronr,
   {{0x7c2397ab,0x61e9002f,0xa3b8006c,0x764d10cd}},	//   _sonr, _ubel, _ماہر_, niay,
   {{0xdd9100f5,0xeb990011,0xed590528,0x9f5e02e9}},	//   _ہوا_, лип_, kaže_, _latè_,
   {{0x6a762cad,0xf1b90009,0x4ee700d4,0xa49b0211}},	//   táfo, _heš_, _відз, _cròi,
   {{0x26c500cd,0xf1b91bd8,0x764d034d,0x00000000}},	//   šloj_, _keš_, kiay, --,
   {{0x8d95004f,0xf1b90116,0x00000000,0x00000000}},	//   _الإش, _ješ_, --, --,
   {{0xf1b90009,0xbca506ca,0x764d97ac,0x00000000}},	//   _meš_, _امتي, diay, --,
   {{0x7c3a97ad,0xdb0a00a6,0x7d1b01e8,0x07a397ae}},	//   chtr, _befä, mxus, зарн,
   {{0xe737116b,0x2ca6011e,0xfb8700d8,0xf1d80354}},	//   бер_, _ztod_, _тыдн, _डालन,
   {{0xf1b997af,0xb87b27c2,0xe9da17df,0x9f5e0107}},	//   _neš_, rtía, _ски_, _datè_,
   {{0xe57a277d,0xb87b2675,0x15b900c7,0x25a00260}},	// [a920] уза_, stía, рысы_, rcil_,
   {{0x8ccf006a,0x09b00033,0x3e610035,0x25a097b0}},	//   _दिनो, _কাটা, róty_, scil_,
   {{0xdb0a02c9,0xfdf9143a,0x764d97b1,0xadf909a8}},	//   _gefä, ्यास_, biay, ्यान_,
   {{0xd5b903ad,0x3e7a0031,0xf1b90124,0x752d01d5}},	//   _всё_, këta_, _ceš_, byaz,
   {{0x69db02b5,0xf1b9082d,0x511892c8,0x7e69012f}},	//   אַוו, _deš_, ролю_, doep,
   {{0x64a30f23,0xdfcf00ad,0x33d502ce,0x6604525e}},	//   _хара, فيه_, _міст, ldik,
   {{0x81c20083,0x2ca604ca,0xe819084b,0xdb1a01f4}},	//   ্ভব_, _stod_, दाता_, ratë,
   {{0x660497b2,0x6e3b7e30,0xdddb1505,0x91e3150d}},	//   ndik, ghub, rluş, _носе,
   {{0x615400fd,0x09df0033,0xdb1a97b3,0x6da30fb4}},	//   _بچائ, _বোঝা, maté, чиња,
   {{0xdb1a97b4,0x26c582f5,0x63a900f4,0x00000000}},	//   laté, álok_, _đenk, --,
   {{0x6e96004f,0x60c217ad,0xed590a18,0x7d0b0b0d}},	//   _الصا, lsom, važe_, _ergs,
   {{0xc33302da,0x7c3a00da,0x6e3b97b5,0x9f5e97b6}},	//   פור_, shtr, chub, _naté_,
   {{0x60c297b7,0x9e65004f,0x63be7c3c,0x2ca6011e}},	//   nsom, _بالن, kapn, _utod_,
   {{0x60c297b8,0xdb1a00ac,0x6d5c02b1,0x00000000}},	//   isom, haté, ßrau, --,
   {{0x63be0ac8,0x9f4797b9,0xed590a18,0xcb070312}},	//   dapn, renç_, raže_, _هيون_,
   {{0x5b571899,0x645c5d54,0xed590620,0x4438009e}},	//   _לשון_, _ajri, saže_, _alr_,
   {{0xe819009a,0x5fc80433,0x6d400110,0x6fc80099}},	// [a930] दादा_, रणाल, nzma, रणां,
   {{0x7bda90b8,0x63be0ec0,0x60c2555b,0x7d1d15e8}},	//   ngtu, gapn, dsom, ässi,
   {{0x659597ba,0x660497bb,0xd37b1837,0x2bea022e}},	//   _ману, bdik, уча_, ज्यं_,
   {{0x6aa402c4,0x9f5e0107,0xddc997bc,0x44380523}},	//   _čifl, _gaté_, kleš, _elr_,
   {{0x60c297bd,0xf1b9008b,0xb87b0098,0x21690200}},	//   gsom, _veš_, ntío, јили_,
   {{0xc6010b52,0x9ea91346,0xd00916b8,0x63be00d7}},	//   _একটা_, авка_, реке_, capn,
   {{0x62350086,0x6e3b002f,0xd24e00b5,0xf1b902a7}},	//   _деву, thub, رچہ_, _jošk_,
   {{0x82371144,0x4e290390,0x7bda11cc,0x787205ee}},	//   _ارسا, роин_, egtu, rævi,
   {{0x6e3b0f1a,0x7e690244,0xed59126e,0x3c1900d8}},	//   rhub, roep, роп_, аўня_,
   {{0x6e3b01d5,0x9f470421,0x00000000,0x00000000}},	//   shub, tenä_, --, --,
   {{0x7e6912ba,0x00000000,0x00000000,0x00000000}},	//   poep, --, --, --,
   {{0x3cfd0d4b,0xa2cc13ab,0x7bda0221,0x00000000}},	//   _tswv_, _हिस्, agtu, --,
   {{0xb87b0890,0x9f470086,0x63be0ac8,0xdb03027d}},	//   rtín, senä_, yapn, _henü,
   {{0x6e39006d,0xb87b97be,0xdb1a00b5,0x9f5e0051}},	//   _hlwb, stín, zaté, _saté_,
   {{0x660400a8,0x2cad024b,0x9695274a,0xb6a397bf}},	//   tdik, lped_, зруш, дисл,
   {{0x27ed01cc,0x85054532,0x60c4003a,0x682b02b1}},	//   đena_, रिंट_, šimi, _südt,
   {{0x66044f53,0x63be97c0,0x142618c3,0x443817b6}},	// [a940] rdik, tapn, одам, _plr_,
   {{0xf7720df3,0x2aed0b4a,0xf2020084,0xb4ea018d}},	//   _ياد_, _जहाँ_, _रोज़_, _मही_,
   {{0x27f897c1,0x6d400260,0xdb1a52d5,0xf1b90124}},	//   mern_, zzma, taté, _gošk_,
   {{0xe4da0e3a,0x27f80f8e,0x60c236f7,0x26d8259c}},	//   _پوست_, lern_, tsom, muro_,
   {{0x208a03d0,0xdb1a97c2,0x60c200d8,0x26d800e9}},	//   айди_, raté, usom, luro_,
   {{0x60c20c7d,0x629801dd,0x27f816ad,0x4433822c}},	//   rsom, ívos, nern_, ckx_,
   {{0xdb1a132d,0x26d83295,0x63bc0395,0x00000000}},	//   paté, nuro_, _iern, --,
   {{0x27f897c3,0x69d60f3d,0x629c0159,0x63a902c4}},	//   hern_, _भागी, _iuro, _đeni,
   {{0x27f80ed4,0xa2d62218,0x629c5434,0x80c40026}},	//   kern_, मूर्, _huro, _रिटे,
   {{0x1ddc007e,0x320400d7,0x26d8737c,0x63bc0d51}},	//   _यावत, _hamy_, kuro_, _jern,
   {{0x629c26cf,0x68e406b3,0xa3e297c4,0x27f897c5}},	//   _juro, _aqid, _धान_, dern_,
   {{0x64891a60,0x629c97c6,0x63bc02c9,0x32060cca}},	//   _uživ, _muro, _lern, ndoy_,
   {{0x3204324f,0x27f897c7,0x8b0700b8,0x26d80036}},	//   _mamy_, fern_, _poří, euro_,
   {{0xdb1897c8,0xb87b0037,0x27f8306a,0x629c0015}},	//   _levé, rtío, gern_, _ouro,
   {{0x26d897c9,0x629c00d8,0xb87b004f,0xd5bb55a1}},	//   guro_, _nuro, stío, иса_,
   {{0x26cd01cc,0xed593b64,0xdb1897ca,0x8b3b00a5}},	//   čeo_, laža_, _nevé, _כתוצ,
   {{0x63bc6a9e,0xdb030caa,0x27f810c0,0x6a7d1d2b}},	// [a950] _bern, _fenó, bern_, céfa,
   {{0xf1d897cb,0x26d897cc,0xed590169,0x80c40066}},	//   _डाउन, buro_, naža_, _रिजे,
   {{0x63bc97cd,0x26d81d99,0x7d093269,0x629c97ce}},	//   _dern, curo_, zves, _curo,
   {{0x629c97cf,0x3206043d,0x7d0997d0,0xdb032f55}},	//   _duro, gdoy_, yves, _zenó,
   {{0x361a02da,0xddc8004e,0x62981d2b,0x7bca97d1}},	//   _הורד, łośc, ívor, _odfu,
   {{0x63bc97d2,0x629c2d1e,0xdb0397d3,0x7bce0a20}},	//   _gern, _furo, _xenó, óbul,
   {{0x629c0159,0xf1b9011c,0xa49b0392,0x6489005f}},	//   _guro, _loši_, _eròt, _džit,
   {{0xf1bf064b,0x2bdd021a,0x63bc1297,0x27f80110}},	//   _þá_, _माहा, _zern, zern_,
   {{0x27f895cc,0xa3e20084,0x63bc02d7,0x26d81ea0}},	//   yern_, _धाम_, _yern, zuro_,
   {{0x69dd97d4,0x63a52e42,0x9f4500e2,0x7d0997d5}},	//   egse, nchn, _balô_, rves,
   {{0x63a502c9,0xdb0301ef,0x629c002a,0xcb6997d6}},	//   ichn, _renó, _xuro, сане_,
   {{0x200597d7,0xdb03043f,0x2cad97d8,0xb87b4a12}},	//   _hali_, _senó, pped_, stíl,
   {{0x20051221,0x27f897d9,0xdb080037,0xdb0301f7}},	//   _kali_, tern_, fadó, _penó,
   {{0x27f801ae,0xdb0897da,0xfbd303c5,0x200797db}},	//   uern_, gadó, _آتش_, ndni_,
   {{0xe73797dc,0x7bc10006,0x4e1f0066,0x63bc00f4}},	//   пер_, malu, _मचाई_, _rern,
   {{0x7bc13635,0x629a0248,0x200500d1,0x26d80010}},	//   lalu, _étoi, _lali_, ruro_,
   {{0x63bc97dd,0x29000f1a,0xdb1823d4,0x27f897de}},	// [a960] _pern, _usia_, _revé, pern_,
   {{0x320400ac,0x7bc197df,0x629c97e0,0x26d818bb}},	//   _samy_, nalu, _puro, puro_,
   {{0x682b007c,0xe7b70122,0xa79b00a5,0x979b00a5}},	//   _tüdr, _מהיר_, _לשיח, _לשיק,
   {{0x63bc97e1,0x7bc14733,0xd36f0ad9,0x28d30835}},	//   _wern, halu, دهم_, _तिमि,
   {{0x20052536,0x63bc97e2,0xe5720e0c,0x26c501ba}},	//   _bali_, _tern, _سطح_, álov_,
   {{0x660697e3,0x200597e4,0x7bc197e5,0x753200ea}},	//   _hakk, _cali_, jalu, īdzī,
   {{0x200597e6,0x5f9397e7,0x644e5e66,0x09c70083}},	//   _dali_, ништ, _imbi, ষ্টা,
   {{0x442a97e8,0x225a0082,0x6aaa0033,0x7a3f0055}},	//   _hob_, _الرد_, _কিলো, _këte,
   {{0x660697e9,0x200597ea,0x442a97eb,0xf8bf00b5}},	//   _makk, _fali_, _kob_, nyét_,
   {{0x20050a93,0x7bc197ec,0x648997ed,0x09c502cb}},	//   _gali_, galu, _užit, वण्य,
   {{0x442a97ee,0xed594693,0x2bdd0b7a,0x3b53002d}},	//   _mob_, raža_, _मारा, екэр,
   {{0x442a97ef,0x1e861397,0x0e9b0122,0xed590b67}},	//   _lob_, _элем, _השאל, saža_,
   {{0x5887247f,0x7bc197f0,0x442a97f1,0x200509d6}},	//   зыва, balu, _oob_, _yali_,
   {{0x442a97f2,0x27ed01cc,0x7bc10395,0x7d0297f3}},	//   _nob_, đeno_, calu, _isos,
   {{0x3ce6006d,0x660697f4,0x12d70083,0xdb0897f5}},	//   _hqov_, _bakk, _সন্দ, radó,
   {{0xa2d30243,0x6606012f,0xf1b9022f,0xf4a80033}},	//   _डिब्, _cakk, _toši_, _ওয়েব,
   {{0x81c20b52,0x6a7d3318,0x660697f6,0xdb0897f7}},	// [a970] ংলা_, léfo, _dakk, padó,
   {{0x442a006f,0x78ad97f8,0x225f3ee4,0xdb0a0a8a}},	//   _cob_, _itav, _sjuk_, _befø,
   {{0x63a5001e,0x660697f9,0x442a97fa,0x200527c5}},	//   rchn, _fakk, _dob_, _rali_,
   {{0x63a597fb,0xe9df97fc,0x200597fd,0x644e0273}},	//   schn, ngú_, _sali_, _embi,
   {{0x3ce601e8,0x7bc102ea,0x2bdd48cd,0x44e606f2}},	//   _nqov_, yalu, _माला, cô_,
   {{0x8cbf0084,0x7c2a0a8b,0x660697fe,0xfc070033}},	//   लीफो, _nofr, _zakk, _লক্ষ_,
   {{0x7d0297ff,0x20079800,0x20059801,0x66069802}},	//   _asos, rdni_, _vali_, _yakk,
   {{0x20059803,0x2d990c61,0x442a9804,0xdb1a1d37}},	//   _wali_, øse_, _zob_, gatí,
   {{0x7bc19805,0x442a0221,0x51872f6b,0x4c850370}},	//   talu, _yob_, _хува, млив,
   {{0x7c2a0297,0x442a006f,0x69cd00e9,0xcac900c3}},	//   _cofr, _xob_, _adae, огое_,
   {{0x37e30b52,0x7bc19806,0x78ad037b,0x60c4010b}},	//   য়ার, ralu, _atav, šimt,
   {{0x7bc122a8,0xdb1a0183,0x00000000,0x00000000}},	//   salu, catí, --, --,
   {{0xed4e5866,0x7bc19807,0x66065a21,0x69cd001e}},	//   _ро_, palu, _rakk, _ddae,
   {{0xb8f60026,0x66069808,0x7c2a001e,0x7bc7008a}},	//   _हि_, _sakk, _gofr, ðjud,
   {{0x66e38c68,0xe73a5963,0x3d0305e7,0xc7a3876f}},	//   кора, цев_, _वनडे_, тиск,
   {{0x442a9809,0xb9040033,0x78ad03d0,0x98a20067}},	//   _sob_, _নন_, _ftav, zykę_,
   {{0x442a980a,0xa49b0176,0x6606980b,0x15fd0067}},	// [a980] _pob_, _bròq, _vakk, उज़र_,
   {{0x6e2b980c,0x6606980d,0x7c2a0042,0xa49b0392}},	//   _logb, _wakk, _xofr, _pròr,
   {{0xf1b900cd,0x60c9030d,0x1aeb0033,0x9f5e11fa}},	//   _lošu_, _avem, টিকে_, _patí_,
   {{0x7df9164f,0x442a1167,0xda210066,0x47d30033}},	//   ्योग_, _wob_, यायत_, দ্দী,
   {{0x442a0221,0x10a3578a,0x762300af,0x98a20067}},	//   _tob_, вичн, _рмяз, tykę_,
   {{0x644e980e,0xeeaa1285,0x60c924d4,0x63bb0207}},	//   _umbi, отик_, _dvem, _đung,
   {{0xda0e065a,0xd3722e63,0xe80f0c57,0xdb1a980f}},	//   ियात_, _شهر_, ायता_, tatí,
   {{0x7c2a9810,0x249800be,0x00000000,0x00000000}},	//   _sofr, _hirm_, --, --,
   {{0xdb1a63af,0xab5c0029,0xed5000b5,0x29120103}},	//   ratí, daļa, دھا_, _nrya_,
   {{0xb87b00ac,0xddc90067,0xf1b9013a,0x00000000}},	//   rtík, gieł, _došu_, --,
   {{0xe8220299,0x29129811,0xda1a0026,0xdb1a1111}},	//   माना_, _arya_, धांत_, patí,
   {{0x629a000d,0x7d020312,0x00000000,0x00000000}},	//   _étou, _tsos, --, --,
   {{0xf8ae0e3a,0x3e6b006c,0x6da30aec,0x999200d5}},	//   یکی_, _بجلی_, _рича, _plyš_,
   {{0xe9df0079,0xdc5600b5,0x00000000,0x00000000}},	//   giúr_, _کرچک, --, --,
   {{0x764100d8,0xfa8a0023,0x2912018e,0xf1b900fe}},	//   ūlym, _lẫy_, _erya_, _košt_,
   {{0x249802a8,0x7d0d545d,0x6a840370,0x9f5e0211}},	//   _airm_, _šasi, _илја, _matà_,
   {{0xdb1a0132,0x78ad9812,0x6a760093,0x290500ea}},	// [a990] batã, _utav, gáfu, ālas_,
   {{0xc6a700af,0xdb1800ee,0xd37b1368,0x00000000}},	//   _орми, _leví, оче_, --,
   {{0x60c9326f,0x926b1b79,0x7d0001e8,0xdb1a01f7}},	//   _svem, орда_, hwms, natà,
   {{0xdb1801c0,0xdb0111cb,0xfa8a0023,0x8ccf0067}},	//   _neví, rblø, _bẫy_, _दिलो,
   {{0x249800a5,0x25d600a5,0xe4a43aee,0x00000000}},	//   _firm_, _אורן_, _арсо, --,
   {{0x751600c2,0x9f05004f,0xf1b90009,0xf07500b5}},	//   _אַלע_, فوتو, _rošu_, ریاں_,
   {{0x20d5008a,0x9f5e0176,0x6fe002b4,0x00000000}},	//   _búið_, _catà_, _नारं, --,
   {{0xb87b9813,0x9f5e021d,0x68300523,0xfde60382}},	//   luíd, _satã_, _jädr, едък_,
   {{0xdb180bca,0xe82200b8,0x00000000,0x00000000}},	//   _deví, मामा_, --, --,
   {{0x99890620,0x51849814,0x4b250dfc,0xb87b0015}},	//   _blaž_, _руса, емов, nuíd,
   {{0xeaae006c,0xab5c0228,0x6e2b9815,0x00000000}},	//   یٹی_, taļa, _togb, --,
   {{0xf1b9022f,0xa96a0274,0x00000000,0x00000000}},	//   _tošu_, зима_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3d50083,0x7e7b486d,0x683001ff,0xdb1a0176}},	//   স্তব, llup, _räds, batà,
   {{0xb87b01ef,0xfbd2011d,0x96660dec,0xcc3a016b}},	//   duíd, _עתה_, екве, _מעסט,
   {{0xdb0301ae,0xa49b12c3,0x7e7b010d,0xd6270274}},	//   _benö, _pròp, nlup, носе_,
   {{0x6fe00437,0x966300af,0x9f5e0183,0xdb1a10ab}},	// [a9a0] _नालं, укте, _matá_, matá,
   {{0x69c621f3,0xdb1a006c,0xfa8a00e2,0x6b830298}},	//   lake, latá, _rẫy_, _kzng,
   {{0x645e9816,0xe1fa0d46,0x6735004e,0xe29a00d8}},	//   rnpi, зге_, cyzj, чае_,
   {{0x69c69817,0xe64600aa,0x25a99818,0xdb1a9573}},	//   nake, _чемп, ccal_, natá,
   {{0x765601c2,0xb87b8c57,0xdb181534,0xe61f0023}},	//   miyy, buíd, _reví, _khôn_,
   {{0x76560669,0x69c69819,0x38a6001e,0xdb1a0172}},	//   liyy, hake, _môr_, hatá,
   {{0x44449284,0x69c601ca,0xf1b90009,0x00000000}},	//   mh_, kake, _pošt_, --,
   {{0x7e7b981a,0x4444981b,0x7656981c,0x69c6981d}},	//   glup, lh_, niyy, jake,
   {{0x40a80332,0x4444981e,0x69c606a2,0xd2570319}},	//   _آخری_, oh_, dake, _נשמה_,
   {{0x4444098b,0x9f47024e,0x76560095,0x61e2981f}},	//   nh_, lený_, hiyy, lgol,
   {{0x3fc900bf,0x69c601cb,0x44449820,0x7644582e}},	//   _آگهی_, fake, ih_, khiy,
   {{0x61e29821,0xb5fb0332,0xdb1a9822,0x44449823}},	//   ngol, _aján, gatá, hh_,
   {{0x764400d1,0x765601c2,0x443a00d7,0x26d85891}},	//   dhiy, diyy, kkp_, erro_,
   {{0x2c16004e,0x44446b3e,0x7984004e,0xe61f0023}},	//   ताओं_, jh_, _dziw, _chôn_,
   {{0x44449824,0x78ad5b2d,0xb87b4681,0x7984001c}},	//   dh_, _živč, ktív, _eziw,
   {{0x44449825,0xd0090083,0xb8f70083,0xdb1a0181}},	//   eh_, লায়_, _সহ_, catá,
   {{0xb87b335b,0x25a96fca,0x9f47024e,0x6830013c}},	// [a9b0] tuíd, rcal_, dený_, _vädr,
   {{0x444459d2,0x7c3a0f0a,0xf3670377,0x00000000}},	//   gh_, nktr, нтен, --,
   {{0xb87b34bb,0x23e21119,0xf3679826,0xb3e22893}},	//   ruíd, _पारद, хтан, _पारख,
   {{0x444406b3,0xd6d801e0,0xb87b0042,0x3135002d}},	//   ah_, _ять_, suíd, кеер,
   {{0x444441f0,0x661d9827,0x660d037a,0xd0099828}},	//   bh_, _insk, mdak, деле_,
   {{0x44442f3c,0x69c69829,0x660d982a,0xb87b2cad}},	//   ch_, zake, ldak, quíd,
   {{0xd9d900c8,0xe82213ab,0x69c63740,0x9f470187}},	//   ধ্যম, माता_, yake, bený_,
   {{0x660d982b,0x6457043f,0x9f47982c,0x29020035}},	//   ndak, lixi, menü_, ywka_,
   {{0x7e7b0034,0x2024003e,0x69c6982d,0x660d5aa9}},	//   rlup, ýrið_, vake, idak,
   {{0x765601c2,0x69c6982e,0x24440523,0x7e7b982f}},	//   ziyy, wake, _gömd_, slup,
   {{0x69c69830,0xdb1a0332,0x2fc79831,0x6a764e5c}},	//   take, tatá, mang_, dáfr,
   {{0x2fc70dc3,0x444401f4,0x3eaa0076,0x98a61676}},	//   lang_, zh_, žité_, киме,
   {{0x69c69832,0x765601c2,0x1d09798c,0x660d9833}},	//   rake, viyy, _цели_, ddak,
   {{0x2fc79834,0x6d450095,0x9f47024e,0x76560034}},	//   nang_, _əhal, zený_, wiyy,
   {{0x6457002a,0x61e20282,0x6e3b2cee,0x7bc30160}},	//   dixi, ygol, okub, _ienu,
   {{0x2fc79835,0xadf90567,0x6e3b0186,0x05ac00a1}},	//   hang_, ्यटन_, nkub, टुंब,
   {{0x44449836,0x9f47024e,0x03a60e0a,0x76560095}},	// [a9c0] th_, vený_, визо, riyy,
   {{0xb5fb00fb,0x76449837,0x661d9838,0x2fc77c03}},	//   _hjál, shiy, _ensk, jang_,
   {{0x7bc3120d,0x2fc70464,0x3ced9839,0x62890874}},	//   _menu, dang_, htev_, _bheo,
   {{0x4444983a,0x78a40f67,0x62890286,0xb87b0183}},	//   sh_, _kuiv, _cheo, cuíb,
   {{0x61e2983b,0x2fc71949,0x6e29983c,0x69c4983d}},	//   rgol, fang_, djeb, _meie,
   {{0x69c4983e,0x7bc3983f,0xb87b03e6,0x9f5c0248}},	//   _leie, _nenu, stív, levé_,
   {{0x661d0044,0x2d8023c6,0x9f474b04,0x6289006b}},	//   _ynsk, _šie_, denó_, _fheo,
   {{0x69c40029,0x27ed01cc,0xfe6f0c26,0x62899840}},	//   _neie, đeni_, يدي_, _gheo,
   {{0x2fc72326,0x7bc39841,0xa0a66297,0xf65302b8}},	//   bang_, _benu, _разд, יצה_,
   {{0x2fc70614,0xdb1a027d,0x7bc39842,0x8af600a8}},	//   cang_, natç, _cenu, _çəkd,
   {{0x7bc39843,0x201e048c,0x7d0d0009,0xe7dc0066}},	//   _denu, _inti_, _šast, _बाजप,
   {{0x200c9844,0x05e100dc,0xdb1a0457,0x7bc30345}},	//   _hadi_, _फाइब, hatç, _eenu,
   {{0xe80f02cb,0x6a7d0248,0x69c49845,0x78a48c40}},	//   ायला_, néfi, _deie, _cuiv,
   {{0x200c303d,0xd7f8129e,0x78a401e4,0xb8eb0026}},	//   _jadi_, кус_, _duiv, _लब_,
   {{0x45d51f6a,0x7bc89846,0x69c49847,0x200c02d0}},	//   ловс, madu, _feie, _madi_,
   {{0x200c0090,0x7bc89848,0xb0d20fff,0xb7e30083}},	//   _ladi_, ladu, _सिंग, য়েট,
   {{0x2fc79849,0x628902c7,0x5694081b,0xe4a40a80}},	// [a9d0] yang_, _rheo, ратт, архо,
   {{0x6289984a,0x7bc8984b,0xda210581,0x2e3800f7}},	//   _sheo, nadu, यावत_, _défi_,
   {{0x6457984c,0x2fc7718e,0x628900f1,0xd3a40421}},	//   rixi, vang_, _pheo, рруп,
   {{0x201e984d,0x2fc7984e,0x7bc8984f,0xddc207c0}},	//   _anti_, wang_, hadu, _akož,
   {{0x2fc70c47,0x7bc89850,0xb87b0d2e,0x85470c8a}},	//   tang_, kadu, btít, _рэне,
   {{0xa2cc065a,0x7bc89851,0x2fc7006d,0x200c099e}},	//   _हिच्, jadu, uang_, _cadi_,
   {{0x2fc77c03,0x7bc368fb,0x200c01ca,0xdfce0118}},	//   rang_, _renu, _dadi_, سيي_,
   {{0xc33214b0,0x2fc79852,0x6d490291,0x201e9853}},	//   _פון_, sang_, tzea, _enti_,
   {{0x7bc3124f,0x2fc79854,0x6e3b9855,0x6e290ac8}},	//   _penu, pang_, rkub, rjeb,
   {{0xb5fb064b,0x7bc89856,0x69c49857,0x200c0029}},	//   _sjál, gadu, _seie, _gadi_,
   {{0x78a41010,0x68ed028b,0x3ced9858,0x29099859}},	//   _suiv, _aqad, stev_, _asaa_,
   {{0x2fc5985a,0xcf5632e3,0x8c43013b,0x00000000}},	//   _helg_, _גבעת_, _əşya, --,
   {{0x7bc3985b,0xfe70036b,0x7bc8985c,0xed5922b2}},	//   _tenu, _بدل_, badu, kaži_,
   {{0x6cd22499,0x66e65fc0,0x7bc8985d,0x69c403bc}},	//   _اقوا, лога, cadu, _weie,
   {{0x61e9985e,0x69c473a3,0x461a010b,0x657d73ca}},	//   _ocel, _teie, нцаў_, _aysh,
   {{0x3ea509eb,0xdb1801b4,0x28dc007c,0x645500c7}},	//   _mult_, _bevæ, _बिपि, _amzi,
   {{0xdb0a00fb,0x3a20985f,0x44319860,0x3ea50051}},	// [a9e0] _hefð, _inip_, _boz_, _lult_,
   {{0x61e99861,0x657d00da,0xa3e907b5,0x48060208}},	//   _acel, _dysh, _याण_, _спов,
   {{0x200c05e2,0x7ae19862,0xddc90bc6,0xb0c622d4}},	//   _radi_, nult, dlež, रीनग,
   {{0x7bc89863,0xb87b0187,0x2fc52803,0x61e90069}},	//   zadu, stít, _aelg_, _ccel,
   {{0x200c005d,0x7ae19864,0x44310f84,0x2fc59865}},	//   _padi_, hult, _foz_, _belg_,
   {{0x3ea540cf,0x53a3010b,0x648b2314,0x2fc5021d}},	//   _bult_, _гарб, güid, _celg_,
   {{0xa3e902cb,0x7bc89866,0x2fc50345,0x3ea59867}},	//   _यात_, vadu, _delg_, _cult_,
   {{0xe2976726,0x200c47e7,0x7ae19868,0x7bc89869}},	//   _бас_, _wadi_, dult, wadu,
   {{0x7bc8986a,0x200c0ec0,0x21670202,0x516601c8}},	//   tadu, _tadi_, _бити_, _сваб,
   {{0x3ea54cfa,0x61e901c0,0x201e0dc3,0x629801c0}},	//   _fult_, _zcel, _unti_, ůvod,
   {{0x7bc8986b,0x450a0033,0x6d4f014c,0x3ea50cfc}},	//   radu, রমিক_, úcar, _gult_,
   {{0x80db007e,0x6da60183,0x00000000,0x00000000}},	//   _निमे, _сида, --, --,
   {{0x7bc86437,0x3ea50120,0xd7fb10be,0xdb01026e}},	//   padu, _zult_, нув_, rclá,
   {{0xe7e30083,0xb5fb033a,0x7ae1986c,0xb8fd1856}},	//   য়্য, _ukáz, bult, _डि_,
   {{0x81dc0083,0x4431986d,0xb87b1111,0xed5900f4}},	//   ত্য_, _roz_, guía, važi_,
   {{0x29090c47,0x4431986e,0x00000000,0x00000000}},	//   _tsaa_, _soz_, --, --,
   {{0x54552f4c,0xa3e90b4a,0x3dc6010d,0x290901a2}},	// [a9f0] ават, _याद_, _meow_, _usaa_,
   {{0x61e901d3,0xb87b986f,0xb4d50387,0x00000000}},	//   _scel, dríg, _सटी_, --,
   {{0x44311423,0xed592676,0x657d053e,0x61e90124}},	//   _voz_, raži_, _wysh, _pcel,
   {{0xd3780d46,0x27ed0254,0xb6ba0122,0x44319870}},	//   учу_, đenu_, _שצרי, _woz_,
   {{0x25ea0387,0x3ea59871,0x61e90097,0x44319872}},	//   _छाती_, _sult_, _vcel, _toz_,
   {{0xdb180086,0xc4f60070,0x64550110,0x443100ee}},	//   _kevä, _דזשי_, _umzi, _uoz_,
   {{0x28dc01c0,0x2fc502ce,0x44ef0225,0x660f9873}},	//   _बिभि, _velg_, lü_, _kack,
   {{0x3ea502a2,0x81dc0083,0xa2a20967,0x975802b5}},	//   _vult_, ত্ব_, गदर्, טיוו_,
   {{0x2d995f31,0x1c45942b,0x44ef9874,0x9fe70037}},	//   äse_, иним, nü_, _مساه,
   {{0x1c1f0d55,0x7ae19875,0x2a6900ab,0x3a200312}},	//   बाइल_, tult, _ajab_, _snip_,
   {{0x3f6710ac,0xcb694ae8,0xff5305bc,0xda210099}},	//   _стаб, тане_, _اخذ_, यांत_,
   {{0x660f315b,0x7ae11446,0x00000000,0x00000000}},	//   _nack, rult, --, --,
   {{0x7ae17bf9,0xfe700206,0xe8222207,0x2a69021e}},	//   sult, _عدم_, माला_, _djab_,
   {{0x7ae19876,0x5d84004f,0xb87b0a20,0xdb18017b}},	//   pult, _الهل, tuía, _bevä,
   {{0x660f7c5d,0x4b7902b5,0x00000000,0x00000000}},	//   _back, _באַו, --, --,
   {{0x7aee0187,0xdb1800a0,0xe5a35189,0xb87b01ef}},	//   žití, _devä, жити, ruía,
   {{0x69d60008,0xb87b1e15,0x13ea002d,0x290c00ea}},	// [aa00] _idye, rtír, кмай_, ādas_,
   {{0x7d0b01ca,0x29370070,0xb87b0042,0x61fd0225}},	//   _msgs, _כאפן_, luín, _ısla,
   {{0xed592bbb,0x660f9877,0xb87b0453,0x0ef40099}},	//   mažu_, _fack, quía, _आहेस_,
   {{0xb87b0519,0xed598c85,0x660f00cd,0x2444017b}},	//   nuín, lažu_, _gack, _döma_,
   {{0x03a69878,0x059400f8,0x55bb00a5,0x3eb900af}},	//   _виго, _دادگ, _במכו, _ăsta_,
   {{0x66049879,0xc07603fa,0x7641010b,0xc48302fb}},	//   leik, шћењ, ūlyt, _мляк,
   {{0xe7ee0953,0x23274cf3,0x7e4600af,0x1c1f0325}},	//   _जाना_, _кори_, ихие, बाईल_,
   {{0x2ca6012f,0x7d0b0107,0xddc90035,0x7d1900e5}},	//   _puod_, _bsgs, mieś, _brws,
   {{0x61437b96,0x628236bd,0xed59011c,0x673c0031}},	//   _дета, mloo, kažu_, hyrj,
   {{0x69d6987a,0x80db00b4,0x7d1900e5,0x66042931}},	//   _adye, _निते, _drws, heik,
   {{0x80ca0066,0xddc90035,0x6282987b,0x6604987c}},	//   _सौते, nieś, oloo, keik,
   {{0x6282987d,0x6251016f,0x2ca61fd9,0xb87b002a}},	//   nloo, sťov, _tuod_, guín,
   {{0x29870677,0x6e222df0,0xa49b0176,0xdb1801ff}},	//   рынг, _inob, _isòv, _sevä,
   {{0x660f987e,0x6282081b,0x7646987f,0x44ef05f5}},	//   _sack, hloo, _alky, vü_,
   {{0x660f9880,0xb87b01dd,0x628239e1,0x6e226a39}},	//   _pack, buín, kloo, _knob,
   {{0xe61f0019,0x932703fc,0x9f5c00b8,0xd5b88f36}},	//   _khôi_, یران, jeví_, ису_,
   {{0x660f022a,0x62829881,0x95c85f4e,0xb87b01ef}},	// [aa10] _vack, dloo, руса_, tríd,
   {{0x44ef0987,0x660f9882,0xd7fb0036,0x673c2129}},	//   rü_, _wack, _руи_, byrj,
   {{0x66049883,0xa2f59884,0x660f9885,0xfdf8046c}},	//   beik, спеч, _tack, ्जास_,
   {{0x80db0f06,0x9e3c00d5,0x62824b11,0x00000000}},	//   _निदे, _buďm, gloo, --,
   {{0xe3e90df3,0xe7ee0380,0xd14b01cb,0xa2d30026}},	//   _مکان_, _जामा_, خشان_, _डिक्,
   {{0x6e229886,0x859600a5,0x3f6910e3,0x00000000}},	//   _anob, _לדרג_, лило_, --,
   {{0x62821e7e,0x64470024,0x72d41956,0x291b0069}},	//   bloo, _ilji, _морф, _lrqa_,
   {{0x7d0b011e,0x11d40037,0xf99f9887,0x00000000}},	//   _psgs, _وتقد, ndès_, --,
   {{0x44230200,0x61fb01a8,0x00000000,0x00000000}},	//   _knj_, _ibul, --, --,
   {{0x3085004f,0x1c4528fa,0x61fb0024,0x66040409}},	//   _الطف, сном, _hbul, zeik,
   {{0xb87b0391,0x64470009,0xed590506,0x00000000}},	//   tuín, _mlji, važu_, --,
   {{0xd35600a5,0x61fb0118,0x00000000,0x00000000}},	//   מיתי_, _jbul, --, --,
   {{0x66049888,0x61fb9889,0x8e74004f,0xed5900cd}},	//   veik, _mbul, _بالض, tažu_,
   {{0x673c8cc2,0xb87b002a,0xfbde0831,0x00000000}},	//   tyrj, suín, ব্বত, --,
   {{0x6604988a,0x61fb09d6,0x7c23988b,0x6282988c}},	//   teik, _obul, _innr, yloo,
   {{0xed590124,0x44237516,0xb87b0183,0x99870b43}},	//   sažu_, _anj_, quín, šiša_,
   {{0x6604988d,0x7d09988e,0xddc90035,0xab5c00ea}},	// [aa20] reik, nwes, wieś, vaļi,
   {{0x6282916c,0x4423988f,0x61fb9890,0x67230009}},	//   wloo, _cnj_, _abul, _šnje,
   {{0x7d099891,0xe73a4268,0x64470009,0x656f9892}},	//   hwes, _сен_, _dlji, _exch,
   {{0xb87b9893,0x6b7a02b5,0x64470009,0x7d099894}},	//   críb, ארענ, _elji, kwes,
   {{0xc05a1958,0xe77900b5,0x62820191,0x6e22009e}},	//   лік_, _ملیں_, rloo, _rnob,
   {{0x64472802,0xdb1a016f,0x74dd0f17,0x61fb9895}},	//   _glji, ratú, _पितृ, _ebul,
   {{0x62829896,0x645e4030,0x7ff30037,0x2718021e}},	//   ploo, mipi, سسوا, _jčn_,
   {{0x7c2366fa,0x645e470b,0x0cd80274,0xe61f0023}},	//   _annr, lipi, адић_, _phôi_,
   {{0xa49b0443,0x611e0395,0x7d091805,0x21760279}},	//   _pròx, _bălţ, gwes, _ѓубр,
   {{0x645e9897,0x61fb00da,0x94110095,0x00000000}},	//   nipi, _zbul, _bizə_, --,
   {{0x7f860514,0x29000139,0xa49b01f7,0x547b00a5}},	//   _الان, _apia_, _isòt, רטיו,
   {{0xc3335c8e,0x7a3f01d2,0xe61f0028,0xa5bb18a1}},	//   לות_, _këti, _thôi_, _anón,
   {{0x6da300b2,0x645e9898,0xb87b01ef,0x9e3c007e}},	//   _عموم, kipi, buíl, _luďk,
   {{0x69c005ee,0x4d7b02b5,0x645e002f,0xb87b07a6}},	//   ðmer, _ערגע, jipi, dríc,
   {{0x466b1334,0x2bf702b8,0x644b01f4,0x41a800b4}},	//   грам_, _המון_, ëgim, गशास,
   {{0x7bca064b,0x64470124,0x3f8c0097,0x645e0051}},	//   _hefu, _slji, _mzdu_, eipi,
   {{0x69cf9899,0x7bca028b,0xdb0315f9,0x44235438}},	// [aa30] mace, _kefu, _agnè, _pnj_,
   {{0x69cf989a,0x645e989b,0x6aaa989c,0x734b0be8}},	//   lace, gipi, _kuff, лчев_,
   {{0xe7ee20d8,0xe9f90028,0x64470009,0x6aaa1e7e}},	//   _जाता_, _giả_, _vlji, _juff,
   {{0x04060033,0xa49b0107,0xb87b2314,0x7d093998}},	//   রাগী_, _asòt, bríc, ywes,
   {{0x64470009,0x7bd8011c,0x5f010d1f,0x25e60d1f}},	//   _tlji, _odvu, _वैज्_, टलरी_,
   {{0x645e3d46,0x02a70a93,0x7bca024e,0x69cf989d}},	//   cipi, _грам, _nefu, hace,
   {{0x80db04cc,0x69cf989e,0xd1bb004f,0x6aaa081b}},	//   _निवे, kace, _ماذا_, _nuff,
   {{0xee390b46,0x764d1fd9,0x7d09989f,0x61fb007b}},	//   рни_, nhay, twes, _ubul,
   {{0x6aaa01ae,0x82342087,0x94110095,0xae1e1119}},	//   _auff, _عرفا, _sizə_, भाजन_,
   {{0xdfd102fd,0x7d0998a0,0x6aaa98a1,0x7bca023a}},	//   _آيا_, rwes, _buff, _cefu,
   {{0x200798a2,0x69cf98a3,0x6aaa98a4,0x764d09e7}},	//   meni_, face, _cuff, khay,
   {{0xda21009a,0x6aaa09b3,0x13d20083,0x645e780f}},	//   यागत_, _duff, ালয়, zipi,
   {{0x764d0118,0x7e7b3957,0xe7ee0302,0x38af0095}},	//   dhay, moup, _जादा_, _cür_,
   {{0xbd880312,0x7bca2e06,0x7e7b98a5,0x7e6998a6}},	//   _انهن_, _gefu, loup, lnep,
   {{0x69cf98a7,0x3d1129ad,0x2bbf08b6,0x7bc198a8}},	//   bace, तिके_, _श्या, mblu,
   {{0x38af328b,0x764d0008,0x200798a9,0xb81a3123}},	//   _für_, ghay, heni_, _फोरम_,
   {{0x645e98aa,0x80db10aa,0xe45a0e60,0x200798ab}},	// [aa40] tipi, _निषे, ажа_, keni_,
   {{0x200704c3,0xb87b933c,0x6aaa012f,0xe45f0093}},	//   jeni_, rríc, _yuff, _svör_,
   {{0xe5a604b2,0x200798ac,0x645e2930,0x764d022e}},	//   _мини, deni_, ripi, bhay,
   {{0x764d089d,0x645e98ad,0xb5fb0093,0x7e6900f4}},	//   chay, sipi, _sjáv, jnep,
   {{0x6b834088,0x645e0dc3,0xe80f00a1,0x7e7b002a}},	//   _lyng, pipi, ायचा_, doup,
   {{0x200798ae,0xdfd000ad,0x76440644,0x6d4500a8}},	//   geni_, ريب_, lkiy, _əhat,
   {{0x44f403ad,0x444498af,0x7bc1010d,0x69cf7664}},	//   lä_, mk_, dblu, yace,
   {{0x443898b0,0x661698b1,0x7bca98b2,0x69cf01dd}},	//   _hor_, ndyk, _sefu, xace,
   {{0x44f403ad,0xc69302da,0x44381fbb,0x69cf98b3}},	//   nä_, ואה_, _kor_, vace,
   {{0x200798b4,0x44380088,0x7bc1009e,0x7159002d}},	//   ceni_, _jor_, gblu, _урсс_,
   {{0x444409a6,0x6b8302c7,0x443898b5,0xdd8f00b5}},	//   ik_, _cyng, _mor_, _یوم_,
   {{0x81dc0b52,0xb5fb0083,0x443898b6,0xb87b0033}},	//   ত্র_, _imág, _lor_, dría,
   {{0x4438250a,0x69cf98b7,0x44f403ad,0x7e602bab}},	//   _oor_, race, jä_, mimp,
   {{0x444425cb,0x6aaa98b8,0x44f40086,0x290b0035}},	//   jk_, _tuff, dä_, rwca_,
   {{0xb87b0473,0x69cf84cd,0x6d400bbc,0x6b83001e}},	//   quím, pace, lyma, _gyng,
   {{0x645c98b9,0x38af0ab6,0x44380159,0x444498ba}},	//   _amri, _tür_, _aor_, ek_,
   {{0x4438543e,0x7c380506,0x6d4098bb,0xd7fb3832}},	// [aa50] _bor_, _kovr, nyma, _кун_,
   {{0x443832fb,0x764d972e,0xf8bf37d6,0xb87b1111}},	//   _cor_, shay, mpé_, bría,
   {{0x443898bc,0x6d4098bd,0x764d010d,0x7e6098be}},	//   _dor_, hyma, phay, kimp,
   {{0x200798bf,0x444498c0,0x645c8cf1,0x6d4000d8}},	//   weni_, ak_, _emri, kyma,
   {{0x443835d9,0x200798c1,0x444498c2,0xd49b03e6}},	//   _for_, teni_, bk_, _врв_,
   {{0x6d4098c3,0x443898c4,0xf8bf00f7,0x7c3800a8}},	//   dyma, _gor_, ipé_, _novr,
   {{0x2007011c,0x7e7b98c5,0x7d021adb,0x00000000}},	//   reni_, toup, _apos, --,
   {{0x20076f38,0x443898c6,0x7d020037,0xe68e0095}},	//   seni_, _zor_, _bpos, _məşğ,
   {{0x200717c3,0x7bc10282,0x7e690249,0x6b83779d}},	//   peni_, tblu, rnep, _syng,
   {{0xbebc0029,0x44380510,0x69cd009e,0x20070031}},	//   _brīd, _xor_, _aeae, qeni_,
   {{0x7c38425a,0x7bc198c7,0x7d0210f0,0x6445012f}},	//   _dovr, rblu, _epos, ikhi,
   {{0x60c90010,0x7e600ac8,0x6d4098c8,0x9f5e021d}},	//   _kwem, cimp, byma, _obtê_,
   {{0x644500d7,0x7bc103d0,0x6b8398c9,0xe89b28ae}},	//   kkhi, pblu, _wyng, çağı,
   {{0x60c943d1,0x6aa401a2,0x44f40086,0x6b8398ca}},	//   _mwem, _wiif, vä_, _tyng,
   {{0x60c9073a,0x44380f0a,0xaa4600af,0xb8f36540}},	//   _lwem, _ror_, _некл, _हौ_,
   {{0x44f40d36,0x443898cb,0xb87b1111,0xe7ee37e8}},	//   tä_, _sor_, rría, _जावा_,
   {{0x764408ca,0x6e3998cc,0x66163d48,0x00000000}},	// [aa60] rkiy, _mowb, rdyk, --,
   {{0x29120034,0xd91b02b5,0x44f40421,0x44380051}},	//   _isya_, _פויל, rä_, _qor_,
   {{0x443898cd,0x6d40004e,0x7d1b007c,0xf62601b8}},	//   _vor_, zyma, hvus, _едно,
   {{0x44440075,0x64a6010c,0x44380088,0x78ad0221}},	//   sk_, _нама, _wor_, _yuav,
   {{0x443898ce,0xf1a900d1,0x444498cf,0x64a60009}},	//   _tor_, زانه_, pk_, _хага,
   {{0x645c98d0,0x29120159,0x64450282,0x93460f08}},	//   _umri, _msya_, ckhi, _енге,
   {{0x7d0298d1,0x425609ce,0x60c9030d,0x765500fd}},	//   _spos, _етат, _ewem, _ügyé,
   {{0x6d401648,0x7c3898d2,0x7ae80df7,0xdcf902b4}},	//   tyma, _sovr, vudt, ्बंध_,
   {{0x7c3898d3,0x7e6098d4,0xe2970804,0xdd90103b}},	//   _povr, rimp, _хат_, کوک_,
   {{0x7e604fa0,0x6d405a3f,0x5fd02160,0xd64a0279}},	//   simp, ryma, _सजिल, jнов,
   {{0xdddb02dd,0x7e60005d,0x291298d5,0x78ad98d6}},	//   sluš, pimp, _asya_, _suav,
   {{0x78ad006d,0x224600fd,0xdb0300e5,0x00000000}},	//   _puav, nkok_, _egnï, --,
   {{0xdcf700bf,0x2e370122,0x7d0207e7,0x7c3808b7}},	//   _فروش_, _מראש_, _upos, _tovr,
   {{0xa8a400ca,0xb9050534,0xac9800fd,0xdca398d7}},	//   ерск, _पट_, _بنتا_, _зачи,
   {{0xf6470210,0xf1cc10aa,0xabfb0122,0xb8d40066}},	//   пхан, ारान, _ההור, _जू_,
   {{0x80d20083,0xf8bf00f7,0x78ad0453,0x26df00cd}},	//   _সমন্, ppé_, _tuav, čuo_,
   {{0x59c30e04,0x3a29046a,0x18750714,0x3ea65e33}},	// [aa70] _व्यर, _inap_, _огия, _miot_,
   {{0x60c904fb,0xdb1a027d,0xb5fb003e,0xb4cd0066}},	//   _rwem, katü, _smád, _रबी_,
   {{0x64452a37,0xdb1a98d8,0x3a295f6d,0x9f5e98d9}},	//   rkhi, mató, _knap_, _mató_,
   {{0xdb1a03e6,0x3cdd0299,0x60c90359,0x22460118}},	//   lató, _खिले_, _pwem, gkok_,
   {{0xb5fb00fb,0xe1f017bd,0x62994e8b,0xb87b0079}},	//   _fjár, اسم_, rmwo, nrío,
   {{0xadea045c,0xdb1a98da,0x417400f8,0xe7bf00a9}},	//   _टाउन_, nató, رانس, ्रिप,
   {{0xae1e0f9c,0x3a290027,0xb87b0098,0x00000000}},	//   _मोहन_, _onap_, hrío, --,
   {{0x7d1b007c,0x60c998db,0xdb1a07cf,0xda1d25fe}},	//   tvus, _twem, ható, _बोलत_,
   {{0xe7bf1662,0xe7ee0ccf,0xd7bf2095,0x3ea601d7}},	//   ्राप, _जाला_, ्राच, _diot_,
   {{0x5ee50035,0xbb450994,0x9e6700b5,0x394200c7}},	//   _टिप्_, деок, _کائن, vyks_,
   {{0x6e390107,0x7d1b03a6,0x224d00c5,0xdb1a0183}},	//   _towb, svus, _klek_, dató,
   {{0xb87b0037,0x3a290284,0x19b9002d,0x00000000}},	//   frío, _cnap_, зурь_, --,
   {{0xdb0a022a,0xee784cbc,0x993a0144,0x80cf0033}},	//   _affä, _عصمت_, цяну_, হূর্,
   {{0xdb1a98dc,0x3a2998dd,0x6b65182f,0xf1b9007e}},	//   gató, _enap_, _окла, _lfš_,
   {{0x81e50b52,0x98a310da,0x18a3005f,0x224d98de}},	//   ব্য_, тире, тарм, _olek_,
   {{0x2ca7007c,0xb87b004f,0xb5fb002a,0x9f5e0107}},	//   _hind_, brío, _amáb, _katò_,
   {{0x2ca706b5,0x1be10722,0xdb1a98df,0xb87b0079}},	// [aa80] _kind_, _खयाल_, bató, crío,
   {{0x225f46d4,0xdb1a98e0,0x9f5e01f7,0x22a801fb}},	//   _amuk_, cató, _xató_, _aşka_,
   {{0x38b44b47,0x224d5ba5,0x2ca798e1,0x65c698e2}},	//   _här_, _blek_, _mind_, _обна,
   {{0x2ca798e3,0xdb180187,0xdb030037,0x38b401ff}},	//   _lind_, _nevý, _ngní, _kär_,
   {{0xa2aa0f8a,0xdb1a01f7,0x00000000,0x00000000}},	//   _जंक्, natò, --, --,
   {{0x224d02fd,0x46d20084,0x38b43f67,0xceba0274}},	//   _elek_, _तबाह, _mär_, ољи_,
   {{0x38b4013c,0x644e98e4,0x3ea60027,0x00000000}},	//   _lär_, _ilbi, _piot_, --,
   {{0x5fd0009a,0x442a0124,0x224d00e0,0xdb1a4a22}},	//   _सजवल, _hnb_, _glek_, zató,
   {{0x38b44b47,0x2ca700d4,0x53b2157d,0x442a496f}},	//   _när_, _bind_, _जलाश, _knb_,
   {{0x2ca7002d,0x3a2940bb,0x00000000,0x00000000}},	//   _cind_, _snap_, --, --,
   {{0x9e3c0187,0x60c298e5,0x9f5e0310,0x00000000}},	//   _buďt, lpom, _obté_, --,
   {{0x38b406d2,0x2ca70120,0xb87b0037,0x60c20035}},	//   _bär_, _eind_, trío, opom,
   {{0x2ca798e6,0x2bbf1e79,0xdb1a34b3,0x644e0382}},	//   _find_, _श्वा, tató, _olbi,
   {{0x38b44b47,0x9c570037,0x2ca70160,0xb87b01ef}},	//   _där_, _يجوز_, _gind_, rrío,
   {{0xdb1a98e7,0x442d98e8,0x00000000,0x00000000}},	//   rató, _đe_, --, --,
   {{0x644e0291,0x569498e9,0xb5fb008d,0x38b40523}},	//   _albi, васт, _smáb, _fär_,
   {{0xdb1a98ea,0xc7c703fa,0x442a3204,0x60c24034}},	// [aa90] catò, _осни, _bnb_, jpom,
   {{0xe8d800a5,0x225f01b4,0x2ca70223,0x4cc30033}},	//   _חוזר_, _smuk_, _xind_, _শিমু,
   {{0x224d12b0,0x00000000,0x00000000,0x00000000}},	//   _plek_, --, --, --,
   {{0x644e98eb,0x442a6ad8,0x81cf0033,0xa5bb0079}},	//   _elbi, _enb_, _শাহ_, _onói,
   {{0x3858042c,0x442a0345,0x224d01bf,0x7c2a98ec}},	//   _رشید_, _fnb_, _vlek_, _onfr,
   {{0x442a98ed,0x3af800b5,0x64900196,0xa3e900b4}},	//   _gnb_, kép_, läin, _याट_,
   {{0x2ca798ee,0x9f50003e,0x00000000,0x00000000}},	//   _rind_, ðaðu_, --, --,
   {{0x2ca798ef,0x4394247f,0x7c2a01ae,0xdb1801ef}},	//   _sind_, _расс, _anfr, _levó,
   {{0x116700b5,0x2ca798f0,0xb87b01ef,0x00000000}},	//   _غلطی_, _pind_, luíu, --,
   {{0x660d4280,0xfc310514,0x2ca701f4,0x628b98f1}},	//   heak, احة_, _qind_, llgo,
   {{0x2ca71928,0xda6612fa,0x65690187,0x3af800b5}},	//   _vind_, евни, _žehl, gép_,
   {{0xee2e0a93,0x2bbf0d53,0xfbbf0808,0x2ca784c4}},	//   _ён_, _श्रा, _श्रम, _wind_,
   {{0xed4e98f2,0x660d98f3,0x6e2b102f,0x2ca798f4}},	//   _со_, deak, _ingb, _tind_,
   {{0x26de011c,0x60db1766,0xccf2011d,0xb87b0098}},	//   štom_, _mvum, _עכו_, brím,
   {{0x38b4033b,0xe73a224a,0x442a1c9e,0xdb18002a}},	//   _wär_, чев_, _rnb_, _devó,
   {{0x442a00d5,0x60db073a,0x00000000,0x00000000}},	//   _snb_, _ovum, --, --,
   {{0x142610d4,0x66030409,0x442a98f5,0xa507135b}},	// [aaa0] ндам, ыпта, _pnb_, нета_,
   {{0x78fb0122,0x395702b8,0x628b09a6,0x4ad30456}},	//   _צפיו, _נשים_, elgo, _दबाव,
   {{0x60db2973,0xb87b002a,0x442a17d8,0x660d01ed}},	//   _avum, guíu, _vnb_, beak,
   {{0xdb01061b,0x60c298f6,0x116800e0,0x23770919}},	//   lcló, tpom, ولای_, رمند_,
   {{0xa3e900a1,0x51831aab,0x3af800b5,0x00000000}},	//   _याच_, луша, zép_, --,
   {{0x6e2b0159,0x10a3135b,0x442a1438,0x60c298f7}},	//   _angb, гичн, _unb_, rpom,
   {{0x91e61e46,0x60c21ac4,0xc6130033,0x60db030d}},	//   _пове, spom, হারা_, _evum,
   {{0x60c25eec,0x00000000,0x00000000,0x00000000}},	//   ppom, --, --, --,
   {{0x6ecc0084,0x28d004aa,0x00000000,0x00000000}},	//   _सबकु, _तौलि, --, --,
   {{0x46e10461,0x6e2b04c1,0x8fa63c45,0x00000000}},	//   _फिलह, _engb, _зазе, --,
   {{0xdb182dd3,0x26de01f2,0x1c0f0387,0x00000000}},	//   _revó, štoj_, ़ज़ल_, --,
   {{0xdc3c00cd,0x200e01e9,0x00000000,0x00000000}},	//   _išču, lefi_, --, --,
   {{0x8c461847,0x2eee0523,0x7e620160,0x00000000}},	//   _педе, luff_, _imop, --,
   {{0xdd8f00f3,0x7c2a98f8,0xb87b0138,0x00000000}},	//   _اوه_, _unfr, prím, --,
   {{0x45d58816,0x660d98f9,0x61e000ac,0x00000000}},	//   ковс, teak, _odml, --,
   {{0xe9df008d,0x1db206fe,0xe3cd0831,0x00000000}},	//   rhús_, ीडित, _লাইব, --,
   {{0xa8a70439,0xb87b0093,0xdb031534,0x649000c3}},	// [aab0] _прок, nrík, _igná, räin,
   {{0xd13102fd,0x14190037,0xb87b0042,0x64900421}},	//   یما_, بيئة_, tuíu, säin,
   {{0x28b70821,0xf6991c56,0x57bf00b8,0xd3710037}},	//   _इंडि, _овој_, ्रीह, جها_,
   {{0x26c10051,0xb87b01ef,0x00000000,0x00000000}},	//   _itho_, ruíu, --, --,
   {{0x68fd98fa,0x5274004f,0x6f080176,0x6b8a0345}},	//   ntsd, دالز, _apdc, _lyfg,
   {{0x7e620107,0xd0061783,0x68fd02b1,0x9208013a}},	//   _amop, веше_, itsd, _atāķ,
   {{0x43942a50,0x6e2b022e,0x00000000,0x00000000}},	//   _барс, _pngb, --, --,
   {{0xa29500d8,0x57bf018d,0xdb030079,0x00000000}},	//   _рабі, ्रुह, _ngná, --,
   {{0x60db0054,0xb87b01ef,0x320f00fd,0x6ba6013b}},	//   _uvum, nuís, megy_, əsgə,
   {{0x1c451303,0x26de00b5,0x51840036,0xdb180359}},	//   тном, átok_, _суса, _revò,
   {{0x9f040041,0x26c1006d,0xb87b00a0,0x00000000}},	//   _مولو, _ntho_, príj, --,
   {{0xa96a2c49,0xb6c800b5,0x68fd4617,0x3f640200}},	//   дима_, ہارے_, ftsd, _стуб,
   {{0xf4cc0033,0x2d8200fd,0x00000000,0x00000000}},	//   _লম্ব, üket_, --, --,
   {{0xed5602cc,0x66e600c9,0x1d06150d,0xfd5600a5}},	//   _још_, кога, _реши_, _בשני_,
   {{0xb5fb0093,0x68fd000b,0x177900c3,0x00000000}},	//   _smáa, atsd, есть_, --,
   {{0x80d200c8,0xe5f3002d,0xa9261ec2,0xa89800ea}},	//   _সমস্, văţă, _адил, _šķēr,
   {{0x28dc0243,0xb87b98fb,0x20050159,0x46a3010b}},	// [aac0] _बिटि, tuít, _obli_, ратв,
   {{0xd7ca01cb,0x00000000,0x00000000,0x00000000}},	//   _توده_, --, --, --,
   {{0x3e7a00ea,0x00000000,0x00000000,0x00000000}},	//   līte_, --, --, --,
   {{0x2005043d,0x91e617d0,0xbebc00ea,0xb87b5856}},	//   _abli_, тоде, _brīn, suít,
   {{0x2444008a,0x20050159,0x200e98fc,0x00000000}},	//   _sömu_, _bbli_, tefi_, --,
   {{0x753600e5,0xdcf500b8,0xb87b2314,0x7e620176}},	//   mxyz, ůběh, luír, _smop,
   {{0xe8e001a5,0x200e001e,0x24440523,0xe8040e9b}},	//   _ước_, refi_, _dömt_, श्या_,
   {{0x1e140036,0xf77300a5,0x527600af,0xb87b98fd}},	//   умия, יקו_, _ругу, nuír,
   {{0x52750009,0x5ea30037,0xdb1a98fe,0x00000000}},	//   _суру, جميل, natö, --,
   {{0x2eee31b4,0xe7ee00a1,0xb87b0093,0x515b0317}},	//   puff_, _जागा_, rrík, _חכמו,
   {{0x8fa61283,0x3d170035,0xb87b008d,0xdc3c0207}},	//   _раже, _बैठे_, srík, _ušču,
   {{0x28b702e4,0xb87b016f,0x68fd98ff,0x81c20033}},	//   _इंदि, prík, ttsd, ূলক_,
   {{0xb87b0138,0x00000000,0x00000000,0x00000000}},	//   nsíg, --, --, --,
   {{0x68fd4c99,0x98a000fe,0x00000000,0x00000000}},	//   rtsd, _frič_, --, --,
   {{0x44d0006a,0x386d029d,0x98a003c9,0x649000c3}},	//   eń_, đer_, _grič_, räil,
   {{0x13cb05f8,0xf1b900d5,0xb87b002a,0x64900421}},	//   िर्भ, _kaše_, guír, säil,
   {{0x35b46a23,0x9a680037,0xdb0a0b3e,0xf1b900cd}},	// [aad0] рбур, _جميل_, _affø, _jaše_,
   {{0x7bc5007c,0xa5bb28ab,0xf1b90881,0x798d007b}},	//   _õhut, _anót, _maše_, _iyaw,
   {{0xb87b9900,0x6aad0054,0xd3a79222,0x320f9901}},	//   buír, _kiaf, трап, tegy_,
   {{0xe45f022a,0x798d01a8,0x1fcf0033,0x00000000}},	//   _stöd_, _kyaw, _রাইস, --,
   {{0xf1b9308b,0x91051397,0xc7b8011c,0x6aad023c}},	//   _naše_, упле, žđe_, _miaf,
   {{0x764d90f9,0x244401ff,0x6aad0103,0x00000000}},	//   lkay, _döms_, _liaf, --,
   {{0x661d9902,0x53340f08,0x93880043,0x44fd0036}},	//   _kask, _керт, _аста_, lì_,
   {{0x661d9903,0x765800d8,0x80d20083,0xa5bb0037}},	//   _jask, _įvyk, _সমর্, _gnót,
   {{0x661d9904,0x798d61f5,0x44fd0036,0xdbcd02d7}},	//   _mask, _nyaw, nì_, _añád,
   {{0x661d9905,0xec760f8f,0x9098002d,0x57bf20af}},	//   _lask, лпы_, _авут_, ्रोह,
   {{0xeaf200c4,0x6aad9906,0xd5d3021a,0x15e30099}},	//   _अमृत_, _biaf, तराज, गणार_,
   {{0xceb201f3,0x661d3344,0x1cb9004f,0x798d2506}},	//   _היא_, _nask, _كاتب_, _byaw,
   {{0xfce54a35,0x798d0010,0x82760070,0x764d0be2}},	//   _соло, _cyaw, רערע_, dkay,
   {{0x6e3b02dd,0x44fd02fb,0x7e6900d8,0x764d0103}},	//   ljub, dì_, liep, ekay,
   {{0xcfd80083,0xb87b0b9f,0x661d9907,0x6aad0098}},	//   _সামন, tuír, _bask, _fiaf,
   {{0x661d6120,0xe3cd0083,0x764d0c47,0x6e3b01a8}},	//   _cask, _লাগব, gkay, njub,
   {{0x661d011c,0x6d5b9908,0x6d49022e,0xe3b2186e}},	// [aae0] _dask, nzua, nyea, مرا_,
   {{0x7e699909,0xc1cc0931,0xf8bf0248,0xdb1a990a}},	//   hiep, ार्ग, uvée_, ratö,
   {{0x91d00084,0x6e3b5f08,0xf8bf00f7,0x661d251a}},	//   दरलै, kjub, rvée_, _fask,
   {{0x629b990b,0x764d01ef,0x7e69990c,0xb87b0042}},	//   _chuo, ckay, jiep, quír,
   {{0xa06a0ece,0x798d0221,0xf77203c5,0x7e6917ad}},	//   нада_, _xyaw, _خاک_, diep,
   {{0x69d6990d,0x661d843d,0x6d5b1051,0x61430274}},	//   _leye, _zask, dzua, сеља,
   {{0xf1b902f6,0xa5bb0d9b,0x09da0033,0xe29603e6}},	//   _saše_, _gnós, _থানা, _браќ,
   {{0xe8040299,0xf1b904c3,0x69d6001c,0x629b009e}},	//   श्ता_, _paše_, _neye, _ghuo,
   {{0xacb403fa,0x6aad990e,0x7524990f,0xa49b009e}},	//   јбољ, _riaf, nviz, _spòi,
   {{0xf1b94caa,0x4cc30083,0x798d04fb,0x6aad9910}},	//   _vaše_, _শিশু, _ryaw, _siaf,
   {{0x9b940043,0x69d69911,0xaa5965c9,0x3f8c027d}},	//   ринц, _beye, вину_, _uydu_,
   {{0x201e5fe5,0xc3330122,0x00000000,0x00000000}},	//   _hati_, צור_, --, --,
   {{0x201e9912,0x661d9913,0x69d69914,0x3cee00b4}},	//   _kati_, _rask, _deye, _आमटे_,
   {{0x661d9915,0x75240c99,0x201e1034,0x3cf10187}},	//   _sask, dviz, _jati_, ňový_,
   {{0x7bda9916,0x661d9917,0x201e10cd,0x66049918}},	//   matu, _pask, _mati_, ffik,
   {{0x7bda9919,0x201e991a,0xdb18033b,0x69d62efd}},	//   latu, _lati_, _bevö, _geye,
   {{0x764d991b,0xdddb00b8,0xb17d07c0,0x00000000}},	// [aaf0] rkay, nouš, _odťa, --,
   {{0xd37b08ce,0x201e991c,0x36d521b7,0x7d1d054e}},	//   нче_, _nati_, _коор, æssi,
   {{0x44fd0382,0x629b0019,0xd5b10172,0x69d63998}},	//   sì_, _phuo, _وفد_, _yeye,
   {{0x7bda991d,0x44fd0036,0x1af70070,0x661d034d}},	//   hatu, pì_, רמאל_, _uask,
   {{0x7bda991e,0x201e991f,0x26de01ba,0xe7b9021a}},	//   katu, _bati_, átov_, _आलाप,
   {{0xd2d70e6b,0x201e9920,0xd00940f3,0x6d5b027d}},	//   _مغرب, _cati_, теке_, vzua,
   {{0x7bda9921,0x201e9922,0x7e699923,0x629b0019}},	//   datu, _dati_, tiep, _thuo,
   {{0xddc2004e,0x6d5b0291,0xb87b68ff,0xa26701d3}},	//   _iloś, tzua, crív, _съгл,
   {{0xee361db7,0x69d69924,0x44210014,0x7e694534}},	//   рны_, _reye, odh_, riep,
   {{0x7bda9925,0x201e00da,0x44210699,0x6e3b9926}},	//   gatu, _gati_, ndh_, sjub,
   {{0x44219824,0x66040035,0x69d60107,0xbf1502fd}},	//   idh_, yfik, _peye, _خواب,
   {{0x201e3d04,0x69260421,0x3cee0099,0x2cae009e}},	//   _zati_, амма, _आमचे_, _eifd_,
   {{0x7bda1235,0x8e84004f,0xed16006c,0x44319927}},	//   batu, _النه, _نہيں_, _onz_,
   {{0x7bda9928,0x6c7902b5,0x69d69929,0x8d5a00a5}},	//   catu, _שאַפ, _weye, _בכני,
   {{0x07a634d4,0x45d601b8,0x69d6018e,0x00000000}},	//   равн, ицат, _teye, --,
   {{0x6455992a,0x443188e2,0xc87f02b1,0x00000000}},	//   _alzi, _anz_, wußt_, --,
   {{0x6604992b,0xb4665f4e,0x4466010b,0xd547002d}},	// [ab00] rfik, акал, авав, апте_,
   {{0x7524992c,0xe4571018,0x3eaf0a75,0x61fb992d}},	//   rviz, ажу_, _ligt_, _acul,
   {{0x3a200a93,0x201e992e,0xe28600af,0xdddb0355}},	//   _kaip_, _rati_, алжи, dluž,
   {{0x442130d2,0x201e326f,0x7bda992f,0x44310120}},	//   adh_, _sati_, zatu, _enz_,
   {{0x201e9930,0x7bda2973,0xb87b0279,0x99890448}},	//   _pati_, yatu, rrív, _maaş_,
   {{0x7ee69931,0x3ced029e,0x26de0187,0x3e7a00ea}},	//   ацие, drev_, štou_, dīta_,
   {{0x7bda0873,0xa2e36299,0x00000000,0x00000000}},	//   vatu, _морд, --, --,
   {{0x7bda2f76,0xf53f624c,0x201e179a,0x2d8f008c}},	//   watu, _igår_, _wati_, _byge_,
   {{0x7bda9932,0xdd971663,0x6fca00b4,0x201e9933}},	//   tatu, ишь_, _स्थू, _tati_,
   {{0x32060034,0x00000000,0x00000000,0x00000000}},	//   lfoy_, --, --, --,
   {{0xfee90037,0xa3d726c6,0xdb1800ee,0x00000000}},	//   _معنى_, सरत_, _nevô, --,
   {{0x7bda6284,0x3ced0c66,0xaa67527e,0x6fca00b4}},	//   satu, brev_, рток, _स्तू,
   {{0x7bda7a53,0xf1b90478,0x44210c6f,0x00000000}},	//   patu, _jaša_, ydh_, --,
   {{0x27ed02bf,0x588701c8,0xf1b90116,0x7bc500be}},	//   ßen_, рыма, _maša_, _õhup,
   {{0x27ed0225,0x7bd804ff,0x00000000,0x00000000}},	//   ğen_, _ievu, --, --,
   {{0x27ed01d6,0xe65400d4,0xb87b01ef,0x64550168}},	//   şen_, овсь, usíb, _slzi,
   {{0x69dd9934,0xf1b99935,0x26c500d8,0xa49b02d0}},	// [ab10] mase, _naša_, ūlo_, _opòt,
   {{0x69dd9936,0x57f548b9,0x2a690221,0x03c7022b}},	//   lase, _упот, _hmab_, рсам,
   {{0x94a803e6,0x442115f2,0xbebc00ea,0xa6ab06ee}},	//   ртта_, rdh_, _drīk, _لاحق_,
   {{0x69dd9937,0x7bd800a2,0x00000000,0x00000000}},	//   nase, _levu, --, --,
   {{0xe804021a,0xe4a703e6,0x69dd4d05,0x3eaf0b3e}},	//   श्वा_, _врво, iase, _rigt_,
   {{0x69dd9938,0xe2d9006c,0xb87b1f51,0x94d40043}},	//   hase, _مارچ_, crít, _форц,
   {{0x69dd9939,0x2a6900be,0x2f1800e2,0x2d8f08c8}},	//   kase, _omab_, _cũg_, _syge_,
   {{0xdddb1851,0x3e7a00ea,0xa49b0107,0x61fb0118}},	//   služ, tīta_, _epòt, _ucul,
   {{0x69dd993a,0x7bd8993b,0x4bd912ea,0x625a099e}},	//   dase, _bevu, льня_, _dïod,
   {{0xa3d7018d,0x00000000,0x00000000,0x00000000}},	//   सरि_, --, --, --,
   {{0x7bd8993c,0x3a20104e,0x5f95186e,0x20071bd8}},	//   _devu, _paip_, _الائ, mfni_,
   {{0x69dd00fb,0x7a3f00da,0x3ced0183,0x7bce008a}},	//   gase, _këty, prev_, ðbur,
   {{0xa3d73556,0x2f01016f,0x7e7e00b5,0x31790070}},	//   सरा_, lóg_, éppe, ראָד,
   {{0x7bd811cc,0x290292f8,0x2a690107,0x7eb50168}},	//   _gevu, rtka_, _emab_, _ešpe,
   {{0x3a200a93,0x69dd23f4,0x290205d1,0xdddb003c}},	//   _taip_, base, stka_, kluż,
   {{0x69dd095e,0x7bc15aa5,0x69c100b8,0x00000000}},	//   case, lclu, ělec, --,
   {{0xe5a31b09,0x3ae3027d,0xb87b01ba,0x291e00ea}},	// [ab20] зити, lıp_, trít, ātas_,
   {{0xf1b90c99,0xb87b2dd3,0x68e4013a,0x69c40069}},	//   _raša_, rsíc, _ivid, _hfie,
   {{0x68e4054e,0xf1b915d7,0xe29a1566,0x3ae3027d}},	//   _hvid, _saša_, гаж_, nıp_,
   {{0x68e41107,0xe8040a40,0xf1b9993d,0xb80400b4}},	//   _kvid, श्रा_, _paša_, श्रम_,
   {{0xcfcf00c8,0x7bc11f2c,0x00000000,0x00000000}},	//   _রাজন, kclu, --, --,
   {{0x69dd993e,0xf1b9338b,0xfc220033,0x68e40023}},	//   zase, _vaša_, _পক্ষ_, _mvid,
   {{0x7bd827ef,0x69dd993f,0x764600d8,0xe457016b}},	//   _revu, yase, _koky, _פילט_,
   {{0x68e49940,0xf1b90a66,0x76460103,0x6a6f0260}},	//   _ovid, _taša_, _joky, _mòfè,
   {{0x764601c8,0x69dd023f,0xf1b9023a,0x7bc10051}},	//   _moky, vase, _kašn_, fclu,
   {{0x40960082,0xb4d610b7,0x69dd9941,0x69c4016e}},	//   _الطر, _सबै_, wase, _afie,
   {{0x3ae30381,0x6a1510dc,0x6441009e,0x00000000}},	//   gıp_, омну, _òlie, --,
   {{0x7bc3008d,0x7646021e,0x7bd80103,0x00000000}},	//   _efnu, _noky, _wevu, --,
   {{0xd90f00bf,0x6443013c,0x69dd196b,0x7ae3055c}},	//   رید_, önik, rase, _evnt,
   {{0x69dd9942,0x68e400c7,0x68e90009,0x9f450079}},	//   sase, _dvid, šedo, _gcló_,
   {{0xf7730dd2,0x69dd9943,0x7646010d,0x7ac60274}},	//   ساس_, pase, _boky, _усле,
   {{0x8afc004e,0x00000000,0x00000000,0x00000000}},	//   rzęd, --, --, --,
   {{0x68e42b26,0x7646010d,0x26de05fa,0x6e220044}},	// [ab30] _gvid, _doky, átor_, _maob,
   {{0xa3a70bfe,0xf8b500b4,0x00000000,0x00000000}},	//   бјек, ंदीप, --, --,
   {{0x68e40097,0xe2c80088,0xb87b0042,0x26de02c4}},	//   _zvid, مولو_, brír, štor_,
   {{0x09ad00c8,0x200c09df,0x99891bfc,0xb87b07c0}},	//   _ক্যা, _abdi_, _znaš_, prís,
   {{0x7bc10223,0x69bc0bdd,0x3ae30225,0x00000000}},	//   yclu, _एलसी, zıp_, --,
   {{0x3ae301d6,0x7ff500f8,0xd8dc016b,0x00000000}},	//   yıp_, زستا, נקור, --,
   {{0xaad70066,0xee390274,0x20070009,0x8fa21682}},	//   _भौंक, инк_, rfni_, маше,
   {{0x44239944,0x6e229945,0x2f019946,0xece90665}},	//   _haj_, _caob, róg_, адил_,
   {{0x44239947,0x64470537,0x628b341e,0x6e221c8b}},	//   _kaj_, _koji, mogo, _daob,
   {{0x3d0907ba,0x60c99948,0x44239949,0x3ae30225}},	//   _वहीं_, _item, _jaj_, tıp_,
   {{0xeb990192,0x6447994a,0x68e44922,0x64900086}},	//   рин_, _moji, _svid, päiv,
   {{0x4423994b,0x6447994c,0x628b994d,0xf8bf52d1}},	//   _laj_, _loji, nogo, rvén_,
   {{0x229c0187,0xad276846,0x7bc12652,0x76460355}},	//   níka_, _دراو, pclu, _roky,
   {{0x6e2211d7,0x442397a3,0x649000ab,0x628b994e}},	//   _zaob, _naj_, näit, hogo,
   {{0x61e90274,0x96ba0202,0x76464877,0xa7aa527d}},	//   _odel, ругу_, _poky, рква_,
   {{0x44232b28,0x61e900d1,0x3d1d000c,0x7c23994f}},	//   _aaj_, _ndel, _भनाइ_, _hanr,
   {{0x68e405ed,0x661660d4,0x64471942,0x628b9950}},	// [ab40] _uvid, reyk, _boji, dogo,
   {{0x61e98169,0x44234c28,0x64479951,0xa49b01a6}},	//   _adel, _caj_, _coji, _spòr,
   {{0x44239952,0x7c2312c3,0x26050785,0x64470a66}},	//   _daj_, _manr, _हॉकी_, _doji,
   {{0x7afd006a,0x6b7a02b5,0x628b55a0,0xd62a03fa}},	//   ństw, ברענ, gogo, _томе_,
   {{0x44239953,0x64a61c4d,0x0086141d,0x61e9001e}},	//   _faj_, _мама, олдо, _ddel,
   {{0x29120657,0x61e94914,0x6e229954,0xe9f901a5}},	//   _mpya_, _edel, _saob, _khả_,
   {{0xcf26004f,0x60c9759b,0xddc20160,0x00000000}},	//   ترشي, _etem, _cloş, --,
   {{0x442301a9,0x7c2302e6,0x628b9955,0x3ddf0051}},	//   _zaj_, _aanr, cogo, gauw_,
   {{0x44230189,0x7c239956,0x212d18b0,0xf1b90124}},	//   _yaj_, _banr, _greh_, _zašo_,
   {{0x4cc30083,0x4423006f,0x61e92801,0x7c2300e9}},	//   _শিখু, _xaj_, _zdel, _canr,
   {{0x6e221093,0x64900086,0x61e935bc,0x7c239957}},	//   _taob, läis, _ydel, _danr,
   {{0xbebc0080,0xf1b10299,0x7c2301da,0xfe720079}},	//   _brīv, ुँचन, _eanr, _غدا_,
   {{0xd910006c,0x649000c3,0xddc200af,0x7eb5010b}},	//   نیٹ_, näis, _emoţ, _išpa,
   {{0x7c23001e,0xd7fb021d,0x8afc0067,0x00000000}},	//   _ganr, шум_, rzęb, --,
   {{0x44239958,0xe9f90019,0x64478173,0x466b9959}},	//   _raj_, _chả_, _roji, арам_,
   {{0x4423995a,0x6447023a,0xf1b9010b,0x628b01dd}},	//   _saj_, _soji, _rašo_, xogo,
   {{0x4423995b,0x644701c0,0x628b0ce9,0xf1b90116}},	// [ab50] _paj_, _poji, vogo, _sašo_,
   {{0xb87b0079,0xe94400b5,0xf8bf0132,0x8afc0035}},	//   msío, _آرٹی, nvém_, częc,
   {{0x442301a9,0x6447995c,0x60c94893,0xb87b0037}},	//   _vaj_, _voji, _stem, lsío,
   {{0xb87b0279,0x7bcd0009,0x78690009,0xf1b9008b}},	//   juíz, _đaum, džvi, _vašo_,
   {{0x4423995d,0x628b55a0,0x649000ab,0x3f9e0065}},	//   _taj_, rogo, täit, _aztu_,
   {{0x4423006d,0x44b401d3,0x628b3a34,0xd12e147f}},	//   _uaj_, _обяс, sogo, امو_,
   {{0xa2ab0387,0x13590037,0x2904027b,0x00000000}},	//   जगद्, _الأخ_, çmaz_, --,
   {{0xee394ae8,0x61e9995e,0x7c23995f,0xa77c0122}},	//   сни_, _udel, _sanr, ירופ,
   {{0x7c239852,0x61e4008a,0x5fcf162b,0xa1581018}},	//   _panr, ðile, _स्थल, _дату_,
   {{0x98a907e7,0x00000000,0x00000000,0x00000000}},	//   _brač_, --, --, --,
   {{0xf989012b,0x7c2346e9,0x260c0907,0xdce701d6}},	//   _ער_, _vanr, ड्डी_, ğlık,
   {{0xc86902b8,0xdce701d6,0xf1b90009,0x69c10035}},	//   _גן_, şlık, _jgš_, ślen,
   {{0x7c239960,0x00000000,0x00000000,0x00000000}},	//   _tanr, --, --, --,
   {{0x8d740312,0x6490005b,0xe9f900e2,0xccf90067}},	//   _تاما, häir, _phả_, muś_,
   {{0x2bd102cb,0x1867052c,0x07a30166,0x81e10033}},	//   _द्या, чари_, еарн, _দান_,
   {{0x98a00009,0x6b9c033b,0x7e7b0e78,0x00000000}},	//   _orić_, ürge, nnup, --,
   {{0xcaa50125,0x959a3cf6,0x29120054,0x0566123a}},	// [ab60] _تصوي, ству_, _upya_, чван,
   {{0x14233f97,0xe9f90019,0xb87b0279,0x7e7b033b}},	//   ндум, _thả_, nsíl, hnup,
   {{0xdc9a0070,0x69450647,0x00000000,0x00000000}},	//   ציעל, _فضیل, --, --,
   {{0x64900086,0xcfd80033,0xf12601e0,0xb87b0042}},	//   täis, _সাইন, зько, xuíz,
   {{0xc5f30100,0x99800409,0x00000000,0x00000000}},	//   _אדר_, _inių_, --, --,
   {{0x64900086,0x859b00a5,0x5f9403f5,0xc0aa06ee}},	//   räis, _לשכו, милт, حاصل_,
   {{0x64a33fe2,0x6383192f,0x98a002c4,0x649000c3}},	//   _чара, _згра, _erić_, säis,
   {{0x44449961,0x64909962,0x7644713a,0x2bd10035}},	//   lj_, päis, njiy, _द्बा,
   {{0x444401a9,0x443853d4,0x62800223,0x2d820c6f}},	//   oj_, _knr_, _ijmo, çke_,
   {{0x44449963,0xfd0f004f,0x7e7b0176,0x44380345}},	//   nj_, اجي_, anup, _jnr_,
   {{0x44440189,0x44380173,0x4f6600bc,0x00000000}},	//   ij_, _mnr_, _عاطف, --,
   {{0x7f3b0122,0x6aa49964,0x61e2254a,0x98a900f4}},	//   _לעבו, _chif, naol, _vrač_,
   {{0x3ebe0090,0x81e10083,0x44446dcb,0x6aa47272}},	//   _hutt_, _দাম_, kj_, _dhif,
   {{0x8c430423,0x98a91d7d,0x61e20312,0x7b0500c3}},	//   _пече, _trač_, haol, öttö,
   {{0x44449965,0x3ebe00ab,0x7c389966,0x6aa4009e}},	//   dj_, _jutt_, _invr, _fhif,
   {{0x44449967,0x7afa9968,0x6aa400d7,0x7c289969}},	//   ej_, mutt, _ghif, lddr,
   {{0x7afa20b7,0x4438996a,0x61e200be,0xe97300b5}},	// [ab70] lutt, _bnr_, daol, _سندھ,
   {{0x44380a11,0x7c28541f,0xf1b90009,0x6a760009}},	//   _cnr_, nddr, _sgš_, ršfe,
   {{0x7afa996b,0x2c0e00a1,0x4438996c,0x69df0031}},	//   nutt, त्यू_, _dnr_, _keqe,
   {{0x44440d4b,0x27e3996d,0x645c996e,0x628821a4}},	//   aj_, lajn_, _elri, _ídol,
   {{0x4444013a,0x92b41062,0x7afa2245,0x69df0031}},	//   bj_, رحما, hutt, _meqe,
   {{0x7afa996f,0x44385f0b,0x27e301e9,0xe0d028c0}},	//   kutt, _gnr_, najn_, ازن_,
   {{0x9ea91346,0x69c6022a,0x7afa9970,0x61e23176}},	//   овка_, ycke, jutt, baol,
   {{0x7afa9971,0xa29400d4,0x7c282193,0x27e30009}},	//   dutt, _засі, eddr, hajn_,
   {{0x3e6a00d1,0xa3a909b1,0xc21200a5,0x6aa400e9}},	//   تجوی_, खेर_, _בהן_, _rhif,
   {{0x6aa49972,0x8b070355,0x7afa9973,0xccf99974}},	//   _shif, _naří, futt, ruś_,
   {{0x3ebe0282,0x7afa0282,0x4ea7021d,0xb5fb00ac}},	//   _gutt_, gutt, _ерда, _klád,
   {{0x60db04fb,0x7d550036,0x7eb5004b,0x00000000}},	//   _kwum, _овех, _išpo, --,
   {{0xb5fb053d,0x660d6efb,0x752d00cb,0x00000000}},	//   _mlád, dfak, jvaz, --,
   {{0x7afa9975,0x6e299976,0xed16006c,0x60db01d5}},	//   butt, ldeb, _کہیں_, _mwum,
   {{0x4438009e,0x7afa9977,0xb87b0138,0x660d9978}},	//   _rnr_, cutt, csím, ffak,
   {{0x444401a9,0x6e299979,0x6aa4002f,0x96951964}},	//   wj_, ndeb, _uhif, еруш,
   {{0xfaa704e8,0xa5071dd6,0xc9860037,0xb5fb0e82}},	// [ab80] _تجوی, мета_, _تشغي, _amás,
   {{0x44440d4b,0xa3ba004f,0x660d028b,0x7d09997a}},	//   uj_, زائر_, afak, ites,
   {{0x020601c8,0xf2c5368f,0x7d09997b,0x4444997c}},	//   дзен, есін, htes, rj_,
   {{0x8b0701c0,0x7d0934f2,0x4444997d,0x6e290207}},	//   _zaří, ktes, sj_, jdeb,
   {{0x61e204e6,0x7d0900da,0x518303fa,0x2fde023a}},	//   raol, jtes, куша, _petg_,
   {{0x41ce00be,0x645c2ad3,0xdfcf0ad9,0xf1a901b2}},	//   _ह्रस, _ulri, ليه_, سانه_,
   {{0x61e20036,0xdde100cd,0x08770070,0x60db073a}},	//   paol, _šuša, ועסט_, _ewum,
   {{0x27e31ac4,0x7d09997e,0x7afa00c3,0x6e293af4}},	//   zajn_, ftes, vutt, gdeb,
   {{0x7eb5010b,0x5fcf022e,0x7d09997f,0x6fcf0380}},	//   _išpl, _स्वल, gtes, _स्वं,
   {{0x7afa9980,0x61e0013c,0x3ebe0382,0x2d9802d4}},	//   tutt, _heml, _tutt_, āre_,
   {{0x27e30009,0x93f7011d,0x6e2901ef,0x201c9981}},	//   vajn_, וציא_, bdeb, mevi_,
   {{0x60c09982,0x7afa5d3b,0xd9ad0083,0x61e008b7}},	//   _kumm, rutt, _ক্ষম, _jeml,
   {{0x27e301f2,0x7d099983,0x7afa9984,0x61e0027d}},	//   tajn_, ctes, sutt, _meml,
   {{0x60c09985,0x7afa9986,0x201c849e,0x3e7a00ea}},	//   _mumm, putt, nevi_, dīti_,
   {{0x27e30484,0xf79400d8,0x60c09987,0x7bca007a}},	//   rajn_, варэ, _lumm, _iffu,
   {{0x61e09988,0xb5fb0079,0xfe140026,0x60c000f6}},	//   _neml, _amár, _थॉमस_, _oumm,
   {{0xd7d01e79,0x1fab0e6f,0xddc90029,0xd9ad0033}},	// [ab90] _त्वच, _चण्ड, nieš, _ক্রম,
   {{0x201c0a78,0x752d9989,0xb5fb0097,0x2c600107}},	//   jevi_, rvaz, _slád, _fòde_,
   {{0xa3a9006a,0xc7d60052,0xd3712e63,0x3a290173}},	//   खें_, _אותי_, دها_, _kaap_,
   {{0x3a2901e4,0xa4d500d4,0x7d09517f,0x60c064d3}},	//   _jaap_, _помі, ytes, _bumm,
   {{0xb5fb0076,0x7bca998a,0x61e40093,0x3a2900f8}},	//   _vlád, _offu, ðila, _maap_,
   {{0x8fa541fe,0xa5bb01ef,0x61e00223,0x78fc00a5}},	//   нале, _anóx, _eeml, קלופ,
   {{0x2eb50370,0xd00e0037,0x3ea60211,0x6e29998b}},	//   нсис, صلي_, _bhot_, tdeb,
   {{0x6d2506c2,0x60db01d5,0x1ea800e0,0x63bc1bd8}},	//   едиз, _twum, وايي_, _zgrn,
   {{0x6fca0653,0x6e29998c,0x26c11292,0xb5fb00d5}},	//   _स्कू, rdeb, _luho_, _kláb,
   {{0x61e00496,0x201c998d,0xf1b91834,0x224d998e}},	//   _zeml, cevi_, _naši_, _hoek_,
   {{0x09ad0083,0xdbdc0093,0x7d09998f,0x224d9990}},	//   _ক্লা, ráði, stes, _koek_,
   {{0x7bca018e,0x60c09991,0x7d099992,0xc332025a}},	//   _effu, _yumm, ptes, אוט_,
   {{0x3ead0c60,0xddc90080,0x27e10282,0x19b900af}},	//   mmet_, cieš, _behn_, дурь_,
   {{0x3ead9993,0x26c19994,0x224d0223,0x69de021a}},	//   lmet_, _buho_, _loek_, परही,
   {{0xe7370665,0x4ac6060a,0x5a960370,0x60130644}},	//   нер_, _रूपव, _приф, mımı,
   {{0x09da0083,0x3e7a00ea,0x3a299995,0xe61f01ba}},	//   _থাকা, tīti_, _gaap_, _skôr_,
   {{0x33f69996,0x3ead9997,0x61e09998,0x201c00a8}},	// [aba0] ечес, imet_, _reml, yevi_,
   {{0x60c09423,0x3ead81a1,0x225f012f,0x601306d3}},	//   _rumm, hmet_, _aluk_, nımı,
   {{0x224d0903,0x60c09999,0x38cb0088,0x201c59a6}},	//   _boek_, _summ, _وایی_, vevi_,
   {{0x3ead01f4,0x27e101ae,0x20054132,0x786201ba}},	//   jmet_, _zehn_, _acli_, _dôve,
   {{0x645b0332,0x3ead016f,0x201c7cbe,0x6013027d}},	//   áció, dmet_, tevi_, kımı,
   {{0xddc91772,0xe4d70037,0x3ea63cc2,0x55770070}},	//   vieš, _سوفت_, _shot_, _װעלן_,
   {{0x03a30bfe,0x442a0221,0x53a3999a,0xda200084}},	//   _биро, _iab_, _барб, _बसंत_,
   {{0x442a999b,0x60c0999c,0xaf3300b5,0xddc900ea}},	//   _hab_, _tumm, اروت, tieš,
   {{0x644e006a,0x60c008dd,0x442a8d3c,0x201c05c7}},	//   _kobi, _uumm, _kab_, pevi_,
   {{0x224d04ce,0x644e999d,0xddc96caf,0x442a026e}},	//   _zoek_, _jobi, rieš, _jab_,
   {{0x442a999e,0x3ea601f4,0x27e1999f,0x59f92b79}},	//   _mab_, _thot_, _rehn_, меня_,
   {{0x2456008a,0x69c01b29,0xf1b903c9,0x26c100cd}},	//   _dæmi_, žmen, _saši_, _ruho_,
   {{0x2bd11ea2,0x442a0279,0xf1b900ea,0xc9840432}},	//   _द्वा, _oab_, _paši_, гури,
   {{0x442a006f,0x7bca0036,0x60130448,0x984800af}},	//   _nab_, _uffu, cımı, няса_,
   {{0xf1b999a0,0x7c2a0345,0x443f00e2,0x81e10033}},	//   _vaši_, _iafr, _đu_, _দাস_,
   {{0x442a99a1,0x3a2931dc,0x7c2a99a2,0x00000000}},	//   _aab_, _uaap_, _hafr, --,
   {{0x442a00bf,0x59d4004f,0x00000000,0x00000000}},	// [abb0] _bab_, _صغير, --, --,
   {{0x442a99a3,0x224d0626,0xaaa50fc3,0x644e6f0a}},	//   _cab_, _soek_, _गीतक, _cobi,
   {{0x644e1851,0x442a01a9,0x7c2a614a,0x224d0051}},	//   _dobi, _dab_, _mafr, _poek_,
   {{0x7c2a02d0,0x442a0065,0x41b50372,0x717948d0}},	//   _lafr, _eab_, نمار, мбер_,
   {{0xe10901ee,0x6013027b,0x00000000,0x00000000}},	//   фелд_, yımı, --, --,
   {{0x644e99a4,0x80d30083,0x442a99a5,0x7c2a0176}},	//   _gobi, _সিদ্, _gab_, _nafr,
   {{0x3ead99a6,0xf83800a5,0x00000000,0x00000000}},	//   tmet_, תנות_, --, --,
   {{0x3eb999a7,0x442a25e8,0x68ed99a8,0x7c2a00be}},	//   öst_, _zab_, _ovad, _aafr,
   {{0x3ead3e11,0x22841385,0x518716c0,0x442a99a9}},	//   rmet_, _сург, _чува, _yab_,
   {{0x09e10083,0x3ead99aa,0x442a006f,0x69cd00e9}},	//   _ভাষা, smet_, _xab_, _afae,
   {{0x60130d6f,0x6fca0084,0x68ed99ab,0x7c2a99ac}},	//   rımı, _स्टू, _avad, _dafr,
   {{0x16110141,0x2bd101d1,0x80d80067,0x2a600024}},	//   _डॉलर_, _द्रा, नीके, _qlib_,
   {{0xed4e99ad,0x8d9205f5,0x68ed0160,0x60130225}},	//   _то_, _پلوش, _cvad, pımı,
   {{0x68ed3ce5,0x31560070,0x38a4013c,0xfaf800ea}},	//   _dvad, דישן_, föra_, brī_,
   {{0x644e307f,0x442a0221,0x6b6699ae,0x38a401ff}},	//   _robi, _rab_, _végé, göra_,
   {{0x442a01a9,0x644e99af,0x7c2a99b0,0xdbe2000d}},	//   _sab_, _sobi, _zafr, _rééd,
   {{0x644e2460,0xd0400669,0x442a0d4b,0x6e2b8409}},	// [abc0] _pobi, _etmə, _pab_, _magb,
   {{0x442a01a9,0x446300c9,0x627c0097,0x42d61958}},	//   _qab_, авув, nčov, віду,
   {{0x2c13018d,0x442a01e8,0xf1b90506,0x00000000}},	//   त्यं_, _vab_, _mašu_, --,
   {{0x6e2b8409,0xd25900d4,0x627c00ac,0x90e600f8}},	//   _nagb, нці_, hčov, نستن,
   {{0x442a01a9,0xa06a10e3,0x00000000,0x00000000}},	//   _tab_, мада_, --, --,
   {{0x442a99b1,0x644e0a78,0x627c00b8,0xf1b999b2}},	//   _uab_, _uobi, jčov, _našu_,
   {{0x7c2a99b3,0x6e2b99b4,0x627c00ee,0xe9f900e2}},	//   _rafr, _bagb, dčov, _chẻ_,
   {{0x7c2a99b5,0x6604431f,0x387802b1,0x00000000}},	//   _safr, ngik, hirr_, --,
   {{0xa3d60440,0x6282329f,0xdbdc0093,0x00000000}},	//   _सभा_, mnoo, _báðu, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fd80967,0x68ed0928,0xb87b0334,0x6e2b0249}},	//   _न्यू, _svad, príz, _fagb,
   {{0x6f7900c2,0x62823774,0xb87b0279,0x75240d95}},	//   _אָנג, nnoo, nsív, kwiz,
   {{0x6e2099b6,0xe0c00083,0xd8770c74,0x7c2a99b7}},	//   memb, _উবুন, ناسب, _tafr,
   {{0x6e2099b8,0x58d45451,0x3e7a00ea,0x7d003cdc}},	//   lemb, рорт, rītu_, mums,
   {{0x7e628356,0xfaa7021d,0x8c1b0122,0x6e2b0159}},	//   _klop, _ишин, _חווי, _yagb,
   {{0x6e2006b3,0x80d30083,0x6604043d,0x628202c4}},	//   nemb, _সিস্, ggik, jnoo,
   {{0x628299b9,0xa5070086,0x3944013c,0x75240848}},	// [abd0] dnoo, ъявл, ämst_, gwiz,
   {{0x07eb006c,0x47d50bf5,0x6e200010,0xd37b029f}},	//   _کرکٹ_, _حيدر, hemb, мче_,
   {{0x6e204a9f,0x7e620159,0x43751c64,0x764f00e9}},	//   kemb, _olop, دهار, _tocy,
   {{0x7d0099ba,0x62530279,0x6e2099bb,0xcb130070}},	//   kums, _açor, jemb, ילע_,
   {{0x6e2b2646,0x7d002b8c,0xed46006c,0x6e2001a8}},	//   _ragb, jums, _اپ_, demb,
   {{0x62820298,0xaa20004e,0x6e2b99bc,0x7eb500c7}},	//   anoo, _बस्छ_, _sagb, _išpi,
   {{0x6282006d,0x6e2b7396,0x44218303,0xdbdc0093}},	//   bnoo, _pagb, meh_, _ráðu,
   {{0x44212873,0x7e62002d,0x13e80083,0x3e7a0029}},	//   leh_, _clop, _পায়, dīts_,
   {{0xf1b900ea,0x627c0009,0x7d000228,0x00000000}},	//   _pašu_, tčov, gums, --,
   {{0x442199bd,0xe9f901a5,0x5184005f,0x7e62081b}},	//   neh_, _thẻ_, _туса, _elop,
   {{0xf1b999be,0x6e2b99bf,0x6e201944,0x09e64555}},	//   _vašu_, _tagb, bemb, лонн,
   {{0x442199c0,0xcd350357,0x7d000f0a,0x00000000}},	//   heh_, _مرتب, bums, --,
   {{0x442109df,0x9f470031,0x7ea56551,0x94030067}},	//   keh_, kanë_, cópa, _लांच_,
   {{0x4421029d,0x7e620506,0x8c4200af,0x229c008d}},	//   jeh_, _zlop, _геше, ríki_,
   {{0x91e30006,0x442199c1,0x7eb50168,0xf1b900cd}},	//   खराज_, deh_, _ašpi, _zašt_,
   {{0x787400a8,0x752499c2,0x44210118,0x00000000}},	//   _müvə, twiz, eeh_, --,
   {{0xe9f901a5,0x96b999c3,0x85060037,0x628207e7}},	// [abe0] _nhẹ_, туру_, طوان, vnoo,
   {{0x6e2099c4,0x290299c5,0x752499c6,0x442199c7}},	//   zemb, muka_, rwiz, geh_,
   {{0xe1fa1fd8,0x6e202f60,0x290299c8,0x62826ae3}},	//   еге_, yemb, luka_, tnoo,
   {{0x2c13012f,0x26d899c9,0x518602c4,0x628200f4}},	//   त्तं_, mpro_, лула, unoo,
   {{0x628299ca,0x290299cb,0x442101ca,0xb87b0132}},	//   rnoo, nuka_, beh_, rsív,
   {{0x3cf9006a,0xb87b0370,0x6e200b28,0x62820223}},	//   ोंने_, ssív, wemb, snoo,
   {{0xe8160ed1,0x29020010,0x7e6235c1,0x26d800cc}},	//   द्या_, huka_, _plop, npro_,
   {{0x290299cc,0xe3c1045e,0x7d0099cd,0xb5fb01ef}},	//   kuka_, ğış_, tums, _llán,
   {{0x127b00c2,0x6e20682f,0x52750183,0x9be600d8}},	//   _נאמע, remb, _туру, лінк,
   {{0x29028d2d,0x13e80083,0x7ea5006c,0x3e7a0029}},	//   duka_, _পাড়, rópa, tīts_,
   {{0x7d0099ce,0x7d090031,0x6e2099cf,0x7bda99d0}},	//   sums, _përç, pemb, rbtu,
   {{0x2902462e,0xfce60fb4,0xdd8f00f8,0x320699d1}},	//   fuka_, _бодо, _کوه_, ngoy_,
   {{0x6e930082,0x442199d2,0x3e7a0029,0x290258bf}},	//   _النا, yeh_, sīts_, guka_,
   {{0xf7733fec,0xb5fb00d5,0x36d537a3,0x6d4600c3}},	//   ماز_, _clán, иогр, äkau,
   {{0x395f2686,0x2bda000c,0x81ea0033,0xab27052c}},	//   šus_, _म्या, _মান_, _боја_,
   {{0x2902024c,0xf8bf0248,0x442199d3,0x45d51676}},	//   buka_, uvés_, weh_, роас,
   {{0xf8bf02e1,0x442199d4,0x62830248,0x229c00b8}},	// [abf0] rvés_, teh_, énom, níku_,
   {{0xb5fb27c2,0x35b46726,0xe3b30037,0x26d800a2}},	//   _glán, сбур, مرض_, bpro_,
   {{0x44213086,0x9f4700da,0x69dd0159,0x00000000}},	//   reh_, ranë_, obse, --,
   {{0x644802e9,0x60cd99d5,0xeb970070,0x3206067f}},	//   _òdin, íamo, נדאר_, ggoy_,
   {{0x442199d6,0xa5bb0473,0xd0098cb1,0x2d8001ba}},	//   peh_, _caót, веле_, _žien_,
   {{0x3f9e024e,0x9f4700d1,0x008400d4,0x5fcf0096}},	//   _bytu_, lané_, бліо, _स्खल,
   {{0x290204f7,0x656d033b,0x02a7010b,0x7c21397d}},	//   zuka_, lzah, _брам, velr,
   {{0xee391761,0x7c2199d7,0x764d20fb,0x29021944}},	//   тни_, welr, njay, yuka_,
   {{0x656d99d8,0x7c2199d9,0xb87b01ef,0x98a90067}},	//   nzah, telr, nsís, _grać_,
   {{0x9f6b0133,0x2902035a,0x5c55107b,0x61eb99da}},	//   _през_, vuka_, ртиф, lagl,
   {{0x29020198,0x68fd2b78,0x6aad0211,0x9f4799db}},	//   wuka_, ersd, _bhaf, kané_,
   {{0x290299dc,0x6f03005d,0x6aad99dd,0x61eb300c}},	//   tuka_, munc, _chaf, nagl,
   {{0xb5fb0076,0x9f4799de,0x6f032090,0x8c4589c4}},	//   _plán, dané_, lunc, _веле,
   {{0x29028ec7,0x200799df,0x6d5b01e8,0x61eb99e0}},	//   ruka_, ngni_, myua, hagl,
   {{0x6f036873,0x66e699e1,0xfaa699e2,0x29028228}},	//   nunc, роба, _како, suka_,
   {{0x290299e3,0x7afc99e4,0x7e7b046a,0x6aad99e5}},	//   puka_, árte, niup, _ghaf,

   {{0x6d5b0189,0x69c4186f,0x61eb99e6,0x21046d67}},	// [ac00] nyua, _igie, dagl, _रमेश_,
   {{0x6f0399e7,0x7ae30159,0x7e7b0008,0x69c40024}},	//   kunc, _kwnt, hiup, _hgie,
   {{0x6f0399e8,0xf74608ae,0x6d5b012f,0x7e7b4df5}},	//   junc, _тено, hyua, kiup,
   {{0x61eb99e9,0xb87b006c,0x6f03011c,0x68e46ff2}},	//   gagl, ssít, dunc, _kwid,
   {{0x7bc302fb,0x6d5b006d,0xb17d01ba,0x84ed00b4}},	//   _ognu, jyua, _deťo, _चौपट_,
   {{0xa07302ce,0xb60800ac,0x68e44583,0x00000000}},	//   огіч, _fešá, _mwid, --,
   {{0x6f036edc,0x69c45f91,0x61eb027a,0x53aa0240}},	//   gunc, _ogie, bagl, _करिश,
   {{0xa2cb5c40,0xd17602ee,0x628901f4,0x61eb0036}},	//   _तंत्, _кызы, _gjeo, cagl,
   {{0x6d5b006d,0xbebc00ea,0x904600f8,0x68e4009e}},	//   gyua, _krīz, _پناه, _nwid,
   {{0x9f47290b,0x6aad99ea,0x229c0093,0x69c499eb}},	//   zané_, _shaf, ríku_, _agie,
   {{0xe9f90028,0x6f031755,0x9f4700bf,0x9b940e9f}},	//   _chế_, cunc, yané_, синц,
   {{0xc3330122,0x6d5b006d,0xddc200ac,0x64410176}},	//   קור_, byua, _hmož, _òliv,
   {{0x9f47114d,0xdd9201b2,0xac180009,0x272700e9}},	//   vané_, _بوش_, _болу_, _sŵn_,
   {{0x7862016f,0xdc0800ea,0x68e42b66,0x69c40065}},	//   _dôvo, _rēķi, _dwid, _egie,
   {{0xe81609b8,0xe9f90019,0xb4c0000c,0x9f4799ec}},	//   द्धा_, _ghế_, ँदै_, tané_,
   {{0x798d0d4b,0x656d033b,0xb8fd0033,0x9f450359}},	//   _txaw, tzah, _ডি_, _delè_,
   {{0x2c13012f,0x764d2a37,0x61eb99ed,0x9f4799ee}},	// [ac10] त्वं_, rjay, vagl, rané_,
   {{0x98650332,0xe8160e96,0xea000019,0x629b35f7}},	//   _ایسے_, द्दा_, _trải_, _skuo,
   {{0x61eb99ef,0x656d033b,0xbebc00ea,0xb17d00ee}},	//   tagl, szah, _drīz, _peťo,
   {{0x09bb00c8,0x200c0103,0x7e690031,0x611a02d4}},	//   _অ্যা, _acdi_, xhep, kālā,
   {{0xe1f800c7,0x200c04fb,0x6fd81371,0x00000000}},	//   ргі_, _bcdi_, नुभू, --,
   {{0x6f0399f0,0x6d5b006d,0x00000000,0x00000000}},	//   tunc, vyua, --, --,
   {{0x61eb99f1,0xb5fb00de,0x443101d7,0x7e7b012f}},	//   pagl, _llám, _iaz_, tiup,
   {{0x443199f2,0x6f0358ce,0x6d4906a2,0x7ea599f3}},	//   _haz_, runc, txea, rópo,
   {{0xee361db7,0x443199f4,0x7ea56493,0x9f4501ef}},	//   сны_, _kaz_, sópo, _melé_,
   {{0x3c6599f5,0x4431108a,0x62990273,0xe9f90023}},	//   ског, _jaz_, lowo, _phế_,
   {{0x645599f6,0x61e90006,0x443199f7,0x20120095}},	//   _mozi, _keel, _maz_, əyi_,
   {{0x6455116d,0x7862016f,0x60c199f8,0x5f1c0ec5}},	//   _lozi, _pôvo, _hilm, _महत्_,
   {{0x61e90006,0x61e4003e,0x60c1010b,0x60c90118}},	//   _meel, ðili, _kilm, _juem,
   {{0xe9f900e8,0x645599f9,0x443199fa,0x60c199fb}},	//   _thế_, _nozi, _naz_, _jilm,
   {{0x629999fc,0x00000000,0x00000000,0x00000000}},	//   kowo, --, --, --,
   {{0x2c1301d1,0x9f45033a,0x68e42ea2,0xcf92134d}},	//   त्रं_, _celé_, _twid, פטן_,
   {{0x20a7009a,0x443199fd,0x62995ba4,0x6455264f}},	// [ac20] गताध, _baz_, dowo, _bozi,
   {{0x64558258,0x443199fe,0x60c15b06,0x480601e0}},	//   _cozi, _caz_, _nilm, _упов,
   {{0x61e90a45,0x64550a18,0xddcb0035,0x9f45006c}},	//   _beel, _dozi, _mogł, _felé_,
   {{0xdb9a0070,0x171b0070,0x66ed046c,0x9f4500f6}},	//   אסער, _גוטע, _जबतक_, _gelé_,
   {{0x60c10dac,0x443199ff,0x61e90a45,0x86370122}},	//   _bilm, _faz_, _deel, _הרכב_,
   {{0x60c100ec,0xd2590080,0x60c907e5,0xb4db0176}},	//   _cilm, _viņa_, _duem, _bràf,
   {{0x60c103e6,0x61e900a5,0x7e79027a,0xb7db1804}},	//   _dilm, _feel, _bmwp, אקצי,
   {{0x61e99a00,0x6299004e,0xa2c5021a,0x26c208c7}},	//   _geel, cowo, िदर्, _jiko_,
   {{0x443106d3,0x64550027,0xe9f90023,0xdc3c035f}},	//   _yaz_, _yozi, _chẽ_, _aġġu,
   {{0xddc21840,0x26c29a01,0x60c19a02,0x61e99a03}},	//   _umož, _liko_, _gilm, _zeel,
   {{0xb4db0443,0xfd0f0a86,0x26c2081b,0x00000000}},	//   _gràf, وجی_, _oiko_, --,
   {{0x26c29a04,0x61e900fe,0xaa671053,0x00000000}},	//   _niko_, _xeel, сток, --,
   {{0x1dac00c4,0x9f450fb5,0x2e3700a5,0xb5fb094c}},	//   _चरित, _relé_, _לראש_, _imáx,
   {{0x67d42d7a,0x00000000,0x00000000,0x00000000}},	//   зору, --, --, --,
   {{0x4431307f,0x27ff0092,0xeac901a5,0x9c1700a5}},	//   _raz_, ğun_, _hẹn_, _החוק_,
   {{0x64559a05,0xf1ba017a,0x44319a06,0xea000019}},	//   _sozi, ेशान, _saz_, _trại_,
   {{0x44311423,0x54551150,0x26c29a07,0x2a69023a}},	// [ac30] _paz_, оват, _diko_, _ilab_,
   {{0x2a690221,0xe7873c77,0x44310095,0x61e99a08}},	//   _hlab_, _гумо, _qaz_, _seel,
   {{0x645527a8,0x94a80133,0x44319a09,0x0ec40a44}},	//   _vozi, стта_, _vaz_, _लंगड,
   {{0x60c19a0a,0x26c20027,0xb5fb07c0,0x44310bf7}},	//   _silm, _giko_, _mlák, _waz_,
   {{0xe3e800c8,0x44319a0b,0x61e99a0c,0x62992d79}},	//   _পারব, _taz_, _veel, rowo,
   {{0x81e10083,0x60c11505,0x212d108a,0x61e91472}},	//   _দাও_, _qilm, _vseh_, _weel,
   {{0x786b0723,0x61e939e1,0xb4db0211,0x6ed1013a}},	//   _güve, _teel, _bràg, _bāba,
   {{0x82650118,0xeac900cc,0x00000000,0x00000000}},	//   _بهرن, _bẹn_, --, --,
   {{0x60c10022,0x5bb30387,0x9f479a0d,0x60c900ab}},	//   _tilm, ीश्व, maní_, _uuem,
   {{0x2a69010d,0x2f400160,0xb4db0392,0x00000000}},	//   _alab_, _băgă_, _tràf, --,
   {{0x2dd59a0e,0xb4db0392,0x00000000,0x00000000}},	//   _джер, _fràg, --, --,
   {{0x753d0332,0x9f4700a0,0x7afc9a0f,0x00000000}},	//   _orsz, naní_, árta, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c450009,0x26c29a10,0x2a6900ab,0x25dc0066}},	//   _феке, _siko_, _elab_, गुनी_,
   {{0x18a301c8,0x81ea0083,0x26c25e5d,0x2a6900fe}},	//   фарм, _মাস_, _piko_, _flab_,
   {{0x2a690159,0x8afc0035,0x00000000,0x00000000}},	//   _glab_, rzęt, --, --,
   {{0x9f4701ba,0xeac90023,0x786b9a11,0xa50a32a6}},	// [ac40] daní_, _kẹo_, _süve, реза_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c27f6e,0xeac90019,0xd1ca00af,0x00000000}},	//   _tiko_, _mẹo_, алее_, --,
   {{0xe8161bc6,0xe29a00d8,0x290207df,0xa3d600ab}},	//   द्रा_, шае_, orka_, _सभक_,
   {{0xb4db0211,0x764683fe,0x2ba600b4,0x00000000}},	//   _cràd, _inky, _ऑर्थ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed500332,0x3e6a2079,0xb5fb9a12,0x42d64747}},	//   کھا_, ишин_, _bláh, _фігу,
   {{0xbe8a03fa,0x2000002d,0x9f4700d5,0x3ce60260}},	//   јске_, şii_, caní_, _pwov_,
   {{0xd00a02cc,0xddc20035,0xd25900ea,0xb4db0284}},	//   _везе_, _umoż, _ziņo_, _gràd,
   {{0x09e302cb,0x0bf30086,0x62830187,0x61e29a13}},	//   पर्य, мпью, énov, lbol,
   {{0x2a69006f,0x20d001a5,0x290200a0,0x2c6002d0}},	//   _plab_, _hài_, erka_, _jòdi_,
   {{0x61e29a14,0xb5fb0314,0x00000000,0x00000000}},	//   nbol, _vlák, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20d00023,0xd7c91902,0xfb86002d,0x00000000}},	//   _mài_, صوره_, _мыйн, --,
   {{0x61e29a15,0x7c284cce,0x29029a16,0xdcc80023}},	//   kbol, medr, arka_, _mỉm_,
   {{0x61e202dd,0x00000000,0x00000000,0x00000000}},	//   jbol, --, --, --,
   {{0x9f470d88,0x61e2054e,0x20d000e2,0x00000000}},	// [ac50] vaní_, dbol, _nài_, --,
   {{0x97150d8d,0x7c282038,0xa3a703fa,0x76469a17}},	//   _емоц, nedr, ојек, _enky,
   {{0xd498093e,0x8c250083,0x78a70207,0xc1f8021a}},	//   іру_, বাচন_, mljv, ुलंब_,
   {{0x20d0098b,0x98a00124,0xe5030354,0xb87b01ef}},	//   _bài_, _psić_, _लिपि_, spíd,
   {{0xdd860514,0x20d001a5,0x9f47024e,0x712701b2}},	//   _أو_, _cài_, raní_, ترال,
   {{0x20d00028,0x55ba0122,0x61e20036,0x660d1e7b}},	//   _dài_, _למרו, abol, lgak,
   {{0x4ac6065a,0x61e29a18,0x752d9a19,0xdb0305d3}},	//   _रंगव, bbol, lwaz, _ozná,
   {{0x660d9a1a,0x2902014e,0x69db188a,0xeac90023}},	//   ngak, yrka_, ñuel, _sẹo_,
   {{0x64470888,0x57a8018d,0xb5fb004f,0xd8400187}},	//   _knji, _गर्ह, _clái, íčky_,
   {{0x7c2806c3,0x60db9a1b,0x4c693537,0x2c699a1c}},	//   gedr, _itum, сион_, _búda_,
   {{0xeb99260f,0x628b0054,0xfaa60ea0,0xbb452743}},	//   син_, ongo, зано, ченк,
   {{0x628b9a1d,0x213f2190,0x752d24ed,0xce380037}},	//   nngo, _kruh_, kwaz, _وأنا_,
   {{0x7c281192,0x20d00019,0x628b9a1e,0x290270a9}},	//   bedr, _xài_, ingo, urka_,
   {{0x60db0657,0x6e290562,0x7d099a1f,0x9f470132}},	//   _mtum, leeb, mues, canã_,
   {{0xa7aa9a20,0x7d099a21,0x61e29a22,0xf74324f8}},	//   сква_, lues, ybol, неро,
   {{0x6447005d,0x61fb9a23,0xc6c3613e,0x80e10033}},	//   _anji, _ndul, ейск, _নিন্,
   {{0x7d0901f4,0x2bd20f8a,0xb4db01f7,0x628b0159}},	// [ac60] nues, _सलमा, _aràb, dngo,
   {{0x39409a24,0x673e022f,0x628b1908,0x660d01b7}},	//   _iris_, _trpj, engo, agak,
   {{0x20d001a5,0x60db2f38,0xf8b30122,0x2486011c}},	//   _sài_, _atum, _רשת_, đom_,
   {{0x39409a25,0x64479a26,0x7d0901f4,0x2ab2006c}},	//   _kris_, _enji, kues, lább_,
   {{0x463b02b5,0x7d0901f4,0xf53f33d4,0xc24300d8}},	//   _העכע, jues, _grå_, энцк,
   {{0x20d001a5,0x213f024e,0x628b4c55,0x61fb9a27}},	//   _vài_, _druh_, ango, _edul,
   {{0x7c289a28,0xb5fb004f,0x91e68c10,0x213f3a35}},	//   vedr, _slái, _нове, _eruh_,
   {{0x20d000e8,0x786b0095,0x787001ff,0xb5fb0098}},	//   _tài_, _müva, _hävd, _plái,
   {{0x2ab2006c,0x3940006d,0x62820196,0x00000000}},	//   kább_, _nris_, mioo, --,
   {{0xf0440df3,0x62829a29,0x00000000,0x00000000}},	//   _تعری, lioo, --, --,
   {{0x7c284409,0x09b705f8,0x2fd700f8,0x673c0124}},	//   redr, ृश्य, _روند_, jvrj,
   {{0xaf49004f,0xe81f00db,0xcf25004f,0x39409a2a}},	//   _بشكل_, म्ना_, _تركي, _bris_,
   {{0x8c4654d0,0x7d093318,0xb5fb024e,0x9f479a2b}},	//   _неде, cues, _kláv, maná_,
   {{0x80e10033,0x3940009e,0xc91d00b4,0xd91800c3}},	//   _নিম্, _dris_, _फहीम_, чью_,
   {{0x628b00e9,0xec3700a5,0x8c1b00a5,0xbc3704cd}},	//   yngo, _מאגר_, _הווי, _رسوا_,
   {{0x443f01d6,0x752d9a2c,0xdb030187,0x39400d35}},	//   _şu_, twaz, _uzná, _fris_,
   {{0x660d9a2d,0x6fcc0099,0xba3b9a2e,0x5fcc074f}},	// [ac70] rgak, ाशां, roïd, ाशाल,
   {{0x628b001e,0x2919006d,0x290b0371,0xb4db009e}},	//   wngo, mtsa_, muca_, _pràb,
   {{0x290b9a2f,0x7d0901f4,0x60db3585,0xb4db0284}},	//   luca_, zues, _stum, _bràc,
   {{0xe3b00082,0x628b9a30,0xaacf0387,0x628200ab}},	//   ارك_, ungo, _संसक, gioo,
   {{0x6e299a31,0x291906a2,0x9f470187,0x7d0901f4}},	//   veeb, ntsa_, daná_, xues,
   {{0xf99400c2,0x6e290273,0x8fa5029f,0x00000000}},	//   ערס_, weeb, мале, --,
   {{0xe81f0099,0x902800d8,0x628202e2,0xc7d800a5}},	//   म्या_, яцца_, bioo, לוגי_,
   {{0x7d094b4a,0xb4db0955,0x7bca009e,0x290b012e}},	//   tues, _gràc, _agfu, kuca_,
   {{0x60db0657,0x290b9a32,0xb5fb0279,0x63a701f4}},	//   _utum, juca_, _fláv, _hyjn,
   {{0x7d0900da,0x290b9a33,0xe81f0e96,0x787000c3}},	//   rues, duca_, म्मा_, _käve,
   {{0x6ee70514,0x7d0900da,0x2ab20332,0x9f4700d5}},	//   _رسال, sues, vább_, baná_,
   {{0x39401cd4,0x7d090083,0x38a402c9,0xc86902b8}},	//   _pris_, pues, hört_, _דן_,
   {{0x7d099a34,0x290b3dff,0x786b9a35,0x00000000}},	//   ques, guca_, _süva, --,
   {{0x04030083,0xcb695093,0x7aee0098,0x00000000}},	//   র্তী_, _мале_, úntó, --,
   {{0xe7370810,0x07a39a36,0xb8d5007c,0x5a9601af}},	//   мер_, варн, _छी_, _ориф,
   {{0xd9f237e8,0x38a40093,0x39409a37,0x00000000}},	//   _अजित_, vöru_, _tris_, --,
   {{0x39400176,0x14c800bf,0xddc20a18,0x6aa41982}},	// [ac80] _uris_, سهای_, _kloš, _ikif,
   {{0x26cc1ec0,0xa2e600c3,0x7870017b,0x98b10207}},	//   ídos_, дожд, _bäve, _ćaću_,
   {{0xb4db12c3,0x3e7a00ea,0x62821130,0x98a900f4}},	//   _pràc, sūti_, tioo, _građ_,
   {{0x41aa156c,0xb5fb0237,0xb87b9a38,0xb35503fc}},	//   овен_, _sláv, mpía, ریقا_,
   {{0x9f470076,0xb5fb9a39,0x6282007c,0xddc200f4}},	//   vaná_, _cláu, rioo, _ološ,
   {{0x62820006,0xa3c80ca1,0x00000000,0x00000000}},	//   sioo, _उलट_, --, --,
   {{0x44389a3a,0x9f4751b8,0x645c1200,0x22160009}},	//   _iar_, taná_, _iori, _офар,
   {{0x44380c7d,0x645c9a3b,0x1d34071d,0xc2430043}},	//   _har_, _hori, ения, _инск,
   {{0x645c0bc6,0x656418c5,0x443839ea,0x9f479a3c}},	//   _kori, nyih, _kar_, raná_,
   {{0x645c9a3d,0x6280006d,0x6aa49a3e,0x515b00a5}},	//   _jori, _hmmo, _akif, _וכמו,
   {{0x44389a3f,0x645c9a40,0xda0a04bc,0xb5fb00d5}},	//   _mar_, _mori, वलंत_, _klát,
   {{0xaacf0567,0x6ab60297,0x60c8009f,0x290b66a7}},	//   _संरक, _chyf, _hidm, tuca_,
   {{0x8d7364e5,0x394d0279,0xb5fb00ac,0x6e229a41}},	//   _لاوا, ães_, _mlát, _ibob,
   {{0x645c9a42,0x44389a43,0xf77300b2,0x29199a44}},	//   _nori, _nar_, ناز_, rtsa_,
   {{0x67d40044,0x62800024,0x25ad7ca4,0x290b4857}},	//   тосу, _ommo, _šel_, suca_,
   {{0x645c0009,0x443845ca,0x60c89a45,0x78700523}},	//   _aori, _aar_, _lidm, _räve,
   {{0x67d525a0,0x44381ed8,0x38a49a46,0x7c38027d}},	// [ac90] _попу, _bar_, tört_, _kavr,
   {{0x6280556b,0x645c1dc2,0x44380e15,0x6abd0699}},	//   _ammo, _cori, _car_, lmsf,
   {{0x44389a47,0x645c9a48,0x7c389a49,0xb5fb9a4a}},	//   _dar_, _dori, _mavr, _blát,
   {{0x23df017f,0x68ed9a4b,0xb3df04cc,0x60c819fd}},	//   _प्रद, _kwad, _प्रख, _aidm,
   {{0x645c53b1,0x602505e8,0x6d4400d8,0x44386138}},	//   _fori, едла, _šian, _far_,
   {{0x645c0169,0x7c389a4c,0x3e710076,0x44389a4d}},	//   _gori, _navr, _máte_, _gar_,
   {{0x6d429a4e,0x8fa21964,0xe8170324,0xb5fb1d2b}},	//   _aroa, лаше, _ताना_, _coág,
   {{0x645c9a4f,0x9f45024e,0x69cd0037,0x6d429a50}},	//   _zori, _celá_, _ngae, _broa,
   {{0x44389a51,0x645c6191,0xddc23e39,0xb5fb0187}},	//   _yar_, _yori, _ploš, _hlás,
   {{0x645c1442,0x765d9a52,0x6aa410db,0x7c3817a4}},	//   _xori, _losy, _skif, _cavr,
   {{0x7c38037a,0x6d429a53,0x09c825de,0x68ed16c8}},	//   _davr, _eroa, रख्य, _awad,
   {{0xdb1e00b8,0x68ed9a54,0x765d9a55,0x7c3a0345}},	//   áván, _bwad, _nosy, adtr,
   {{0x44239005,0x7c389a56,0x6d42002d,0x7e69008a}},	//   _obj_, _favr, _groa, mkep,
   {{0x60c801c2,0x7e691314,0x7c389a57,0x7ea50093}},	//   _xidm, lkep, _gavr, rópu,
   {{0x645c0183,0x7d1b9a58,0x443815b7,0x765d165a}},	//   _rori, ltus, _rar_, _bosy,
   {{0x7c380bc6,0x44389a59,0x645c9a5a,0x998d08c2}},	//   _zavr, _sar_, _sori, žeš_,
   {{0x44389a5b,0xeb1f1033,0x645c9a5c,0x765d9a5d}},	// [aca0] _par_, _बहुत_, _pori, _dosy,
   {{0x645c1505,0x7d1b0086,0x65640027,0x4438013b}},	//   _qori, itus, ryih, _qar_,
   {{0x44389a5e,0xb5fb9a5f,0x645c9a60,0x02069532}},	//   _var_, _clás, _vori, езен,
   {{0xe29711eb,0x44388fb9,0x6e395d2b,0x765d010d}},	//   нах_, _war_, _nawb, _gosy,
   {{0x44389a61,0x21671714,0x645c9a62,0x44230118}},	//   _tar_, ници_, _tori, _fbj_,
   {{0x8143083a,0xdfcf00ad,0x68fb0279,0x6e220036}},	//   انون, ميه_, áudi, _sbob,
   {{0x6e390008,0x60c89a63,0x7d1b00be,0x7c38008c}},	//   _bawb, _vidm, etus, _ravr,
   {{0xb65b00c2,0x6d429a64,0x7c3801cc,0x60c8002c}},	//   ִדיש, _proa, _savr, _widm,
   {{0xb5fb9a65,0x2dd7004f,0x7d1b9a66,0x6e390260}},	//   _klár, ربية_, gtus, _dawb,
   {{0x7f7600af,0x69cd01ed,0x68ed0371,0x00000000}},	//   _пуец, _sgae, _rwad, --,
   {{0x141b02b5,0xdfcf0105,0x68ed9a67,0x9b9450f1}},	//   הויב, _ايم_, _swad, тинц,
   {{0x79a72ce2,0x6d420a5f,0x2bd20b4d,0xed5a2746}},	//   ерге, _troa, _सलवा, _ное_,
   {{0x3ea6067f,0x765d9a68,0x7c381008,0x61ed008d}},	//   _ikot_, _rosy, _tavr, ðali,
   {{0x765d1473,0xd2590029,0x2ab26802,0x290401ef}},	//   _sosy, _viņi_, rába_, ámaa_,
   {{0x36d503fa,0x5a4700af,0x00000000,0x00000000}},	//   тобр, _зэпа, --, --,
   {{0x68ed9a69,0x25dc0066,0xb5fb9a6a,0x44239a6b}},	//   _twad, गुली_, _alár, _sbj_,
   {{0xe5980210,0x00000000,0x00000000,0x00000000}},	// [acb0] екті_, --, --, --,
   {{0xb5fb0514,0x7bda9a6c,0xb4ab0953,0xb4db0211}},	//   _clár, nctu, खते_, _fràn,
   {{0xf990006c,0xb4db01da,0x229c0187,0x72191eb9}},	//   _نبی_, _gràn, líky_, джер_,
   {{0x61cb012f,0xd9f1046c,0xb5fb00ac,0x00000000}},	//   िशेष, चरित_, _vlás, --,
   {{0x865a011d,0x229c00b8,0xe0d801e0,0x3219027d}},	//   _חדרי, níky_, еві_, _ösym_,
   {{0x1ae60033,0x00000000,0x00000000,0x00000000}},	//   _কিনে_, --, --, --,
   {{0x201a0443,0xd00e1902,0x7afa0223,0x00000000}},	//   òpia_, زلي_, jstt, --,
   {{0x7d1b9a6d,0x7bda002d,0x26d39a6e,0xfe4503e6}},	//   ttus, ectu, _muxo_, тнио,
   {{0xee361db7,0x7e699238,0x6e3b9a6f,0x26d30f84}},	//   тны_, rkep, rdub, _luxo_,
   {{0x7d1b9a70,0x3ea601ff,0x26cb099e,0x229c0097}},	//   rtus, _ekot_, _lico_, díky_,
   {{0x7d1b136d,0x6e39023c,0x7afa0051,0x78700282}},	//   stus, _tawb, gstt, _näva,
   {{0x26cb9a71,0x225f02e9,0x7ea5016f,0x7d1b9a72}},	//   _nico_, _jouk_, róps, ptus,
   {{0x3ebf9a73,0x3ead9a74,0x4e7a0070,0x6fd8258f}},	//   mmut_, mlet_, _קאנצ, नुकू,
   {{0x3ead9a75,0x3ea00bcc,0x7d099a76,0x3ebf1c52}},	//   llet_, čite_, mres, lmut_,
   {{0x44ef006a,0x26d30391,0x07a611b9,0x7d09711e}},	//   eż_, _cuxo_, тавн, lres,
   {{0x7aed004e,0x26cb5bbb,0x7d099a77,0x229c00d5}},	//   _łatw, _cico_, ores, bíky_,
   {{0x7d0912c3,0x26cb9a78,0x25ab0223,0x00000000}},	// [acc0] nres, _dico_, _cycl_, --,
   {{0xb4db9a79,0x3ead8ff9,0x224d673d,0x7d096fef}},	//   _tràn, hlet_, _anek_, ires,
   {{0x26cb9a7a,0x3ead9a7b,0x7d0901ae,0x225f02d0}},	//   _fico_, klet_, hres, _bouk_,
   {{0x7d099a7c,0x6d4400d8,0x27f80523,0x5186439b}},	//   kres, _šiam, larn_, кула,
   {{0x224d0051,0xc05a01e0,0xe81f06fe,0x9f4e01f7}},	//   _dnek_, дій_, म्वा_, rafí_,
   {{0x260a009a,0x7d0954de,0x80e10083,0x3ea66923}},	//   िलकी_, dres, _নিশ্, _skot_,
   {{0x3ead9a7d,0x644e9a7e,0x7d0955c9,0xceba0274}},	//   flet_, _inbi, eres, мљи_,
   {{0x80e10b52,0x7d090297,0x8c3c06d3,0x3ead3e80}},	//   _নির্, fres, doğa, glet_,
   {{0x7d09449a,0x8cf300d8,0x27f89a7f,0xd9e3021a}},	//   gres, азыц, karn_, _क्षत_,
   {{0x3ead9a80,0xa3b9049c,0x2a600a8a,0x4de20066}},	//   alet_, _चरम_, _aoib_, _ट्रै_,
   {{0x3ead9a81,0xe7bd0083,0x27f800e9,0x7bda9a82}},	//   blet_, _অভ্য, darn_, rctu,
   {{0x9e6624f9,0x26c000cd,0x0d860036,0x27f80a3b}},	//   _швед, jmio_, _илен, earn_,
   {{0x26cb9a83,0x29040124,0x27f800e9,0x58872ad9}},	//   _rico_, šman_, farn_, выва,
   {{0x5887004b,0x27f8721c,0x26d30391,0xd7770841}},	//   тыма, garn_, _puxo_, نازع,
   {{0x26cb0473,0xd2590029,0x25ae013b,0x00000000}},	//   _pico_, _ziņu_, əfli_, --,
   {{0x644e9a84,0x88e20033,0x00000000,0x00000000}},	//   _anbi, _বিরক, --, --,
   {{0x27f88873,0x26cb027a,0xf99f0176,0x00000000}},	// [acd0] barn_, _vico_, rgès_, --,
   {{0x224d00d7,0xa3c122a7,0x3e719a85,0x291e00af}},	//   _snek_, ुशल_, _máta_, ătat_,
   {{0x3e71008a,0x3ea49a86,0x3ead9a87,0x225f08b7}},	//   _láta_, komt_, ylet_, _pouk_,
   {{0x69dd006c,0x644e1b71,0x9f4c0176,0x7d091781}},	//   ncse, _enbi, _cedí_, yres,
   {{0x3ead01d6,0x7d090523,0x00000000,0x00000000}},	//   vlet_, xres, --, --,
   {{0x3ead008c,0x7d099a88,0xd12e0079,0x644e0359}},	//   wlet_, vres, سمى_, _gnbi,
   {{0x28da12e7,0xeaca0023,0xf2c72d1e,0x224d01ed}},	//   _यूनि, _kẹt_, _асан, _tnek_,
   {{0x7d099a89,0x3ead00f6,0x224d027c,0x290b00f4}},	//   tres, ulet_, _unek_, krca_,
   {{0x3ebf9a8a,0x2284081b,0x3ead394e,0x31342d4d}},	//   rmut_, _тург, rlet_, _кетр,
   {{0x3e713651,0xd2590029,0x3ead9a8b,0xef65013b}},	//   _dáta_, _viņu_, slet_, çısı_,
   {{0x27f89a8c,0xba3b9a8d,0x290b58bd,0x00000000}},	//   varn_, roïn, erca_, --,
   {{0x7d093bbe,0x3f7a00c2,0x2904002a,0x00000000}},	//   pres, _אָדע, ámao_, --,
   {{0x323600c2,0xf99202e7,0x27f8416a,0x00000000}},	//   נטשן_, صبح_, tarn_, --,
   {{0x27f80107,0x764f0088,0xe73a1667,0x61f944d1}},	//   uarn_, _ancy, нег_, hawl,
   {{0x290b1c02,0x61f92a07,0x386101ef,0x3e6a00f1}},	//   arca_, kawl, _dohr_, _bùth_,
   {{0x644e0159,0x2bdf05f7,0x26c00207,0xfbdf00b8}},	//   _snbi, पुरा, umio_, पुरम,
   {{0x26c09a8e,0xa5072133,0x3e6a0211,0xe7a400ab}},	// [ace0] rmio_, лета_, _dùth_, _खुरप,
   {{0x9f4c0097,0xb4db0284,0x00000000,0x00000000}},	//   _sedí_, _gràm, --, --,
   {{0xa3b9717a,0x9f4c0453,0x1bf60070,0xd9fa0099}},	//   _चरण_, _pedí_, רצער_, _्यात_,
   {{0x2ca59a8f,0x20d90118,0x00000000,0x00000000}},	//   hold_, _bèi_, --, --,
   {{0x64430370,0x6a660093,0x00000000,0x00000000}},	//   ônic, _hófs, --, --,
   {{0x3e710037,0xd8d70070,0x20d9027a,0x10a305c2}},	//   _ráta_, אוסט_, _dèi_, бичн,
   {{0x7c3e021d,0xaacf258f,0x00000000,0x00000000}},	//   _ópri, _संगक, --, --,
   {{0xa3b9009a,0x68e49a90,0x61ed008d,0x00000000}},	//   _चरत_, _otid, ðalt, --,
   {{0x5c741e26,0xa2a1004e,0x2ca59a91,0x61434e35}},	//   илит, गकर्, fold_, _лета,
   {{0x1dc00567,0x3ea4035b,0x290b0207,0x00000000}},	//   शेषत, somt_, vrca_, --,
   {{0x68e400d8,0x386102b1,0x00000000,0x00000000}},	//   _atid, _rohr_, --, --,
   {{0xf41a0033,0xdd000225,0x00000000,0x00000000}},	//   ড়ির_, ştık, --, --,
   {{0x2ca59a92,0x6c540370,0x786b00ab,0x8aa4010b}},	//   bold_, _вклу, _hüvi, срэд,
   {{0xb8fd0302,0x6d3b0122,0x9f4701ba,0x68e4009e}},	//   _तं_, _נתונ, vanú_, _dtid,
   {{0x9999006c,0x68e402e9,0xf41a0033,0x23c30026}},	//   reső_, _etid, ড়ার_, _वृंद,
   {{0x58d50021,0xc6a71e96,0x00000000,0x00000000}},	//   _коит, урги, --, --,
   {{0xb4db12c3,0xeaca00e2,0x78700523,0x260a00ab}},	// [acf0] _tràm, _vẹt_, _kävl, िलजी_,
   {{0x7870013c,0xe5080312,0x7e62086f,0xe9df0176}},	//   _jävl, ايلو_, _loop, lcú_,
   {{0x2c1c009a,0xd49809ce,0xe7eb00a1,0x998d0035}},	//   _मानू_, урт_, _ज्या_, żeń_,
   {{0x39499a93,0x764f01ef,0x00000000,0x00000000}},	//   _kras_, _uncy, --, --,
   {{0x61f90005,0xc5fa00a5,0x68e401ed,0x00000000}},	//   rawl, _בפרט, _xtid, --,
   {{0x216602c4,0xd0060f8c,0xa3d41566,0x00000000}},	//   риши_, аеше_, _горч, --,
   {{0x2ca517ad,0x7e620282,0x270100c7,0x00000000}},	//   vold_, _boop, nėn_, --,
   {{0x39499a94,0x2ca50051,0x0e650b30,0x9f4c021d}},	//   _oras_, wold_, ркин, _sedã_,
   {{0x7ae43ce5,0x39490221,0x7e629a95,0x2ca59a96}},	//   _čita, _nras_, _doop, told_,
   {{0x3ea00bc6,0xac85081b,0xcd280286,0x4b25440d}},	//   čita_, ргол, اسين_, амов,
   {{0xeb9928a1,0x39499a97,0x68e40254,0x2005009e}},	//   тин_, _aras_, _stid, _idli_,
   {{0xa96a0202,0xfaa69a98,0x39499a99,0x628b00e9}},	//   вима_, рамо, _bras_, nigo,
   {{0x39499a9a,0x999e0355,0xec6e7352,0x00000000}},	//   _cras_, ětů_, _дп_, --,
   {{0x7870013c,0x628b681e,0x39499a9b,0x5d7a0317}},	//   _gävl, higo, _dras_, _באנק,
   {{0xb8fd0e1d,0x44333ec3,0xe7e50084,0x39490138}},	//   _तू_, dex_, कड़ा_, _eras_,
   {{0x7e620024,0x5ed70083,0x63ae4a84,0xc7a30370}},	//   _xoop, _সবাই, _rybn, циск,
   {{0x39490c53,0x44330298,0x9f4501ba,0xb4aa1402}},	// [ad00] _gras_, fex_, _celú_, вказ_,
   {{0x78a70345,0x00000000,0x00000000,0x00000000}},	//   cojv, --, --, --,
   {{0x8c3c2f80,0x2bab3e9e,0x00000000,0x00000000}},	//   doğl, _घुमा, --, --,
   {{0x9f4c0187,0xd36f0037,0x20056de5,0x161d05a6}},	//   _nedá_, بهم_, _adli_, _फायर_,
   {{0x7e628072,0xf1b900ee,0x90c6210e,0x00000000}},	//   _roop, _czš_, абде, --,
   {{0x403432a6,0x201a00be,0x7e629a9c,0x00000000}},	//   секс, üpi_, _soop, --,
   {{0x628b877d,0xa2c600b8,0xe817021a,0x00000000}},	//   bigo, िषद्, तलता_, --,
   {{0xf2a316e2,0x628b002a,0xb4db0211,0x290c0035}},	//   _дисп, cigo, _bràh, ądaj_,
   {{0xe81711b5,0x61ed0831,0xf1aa0088,0xf8bf000d}},	//   _ताला_, ñale, _شاره_, ltée_,
   {{0x8c660fdd,0x5c745da8,0x7e620118,0x442a0051}},	//   ртид, слот, _woop, _jbb_,
   {{0xf8bf0248,0x78a77f6b,0xdb030a8a,0xa3e400b8}},	//   ntée_, vojv, _lynæ, _नभई_,
   {{0x1bf20299,0xbd8703c5,0x39499a9d,0xfe7900b8}},	//   _आजकल_, انین_, _pras_, chů_,
   {{0x7870022a,0xcd360416,0xdb030187,0x95fc0033}},	//   _tävl, _خراب, _vyná, ইলাম_,
   {{0x628b9a9e,0xe9df9a9f,0x39490055,0x442a021d}},	//   zigo, scú_, _vras_, _nbb_,
   {{0x1cbb00c2,0xf65305f5,0x00000000,0x00000000}},	//   _שמוע, يئر_, --, --,
   {{0x39499aa0,0x442a9aa1,0xaa2d00c3,0x8c3c0457}},	//   _tras_, _abb_, ämää_, zoğl,
   {{0x628b9aa2,0x39490a21,0x6aad08c7,0x8c3c0225}},	// [ad10] vigo, _uras_, _ikaf, yoğl,
   {{0xc3cb0037,0xeaca0023,0xd7f8005f,0x00000000}},	//   نظام_, _hẹp_, _кую_, --,
   {{0x628b130f,0x389c02b5,0xe3b007a9,0xed4600b5}},	//   tigo, _ביזנ, ورم_, _کپ_,
   {{0xdb0700b5,0x7d020124,0x27e60207,0x00000000}},	//   ülék, _ovos, _đoni_, --,
   {{0x3ce601e8,0xc24400d8,0x95cb0274,0xaad001c0}},	//   _ntov_, ўнік, _јуна_, _संघक,
   {{0x628b9aa3,0x656d0159,0x65600211,0xa3e400b8}},	//   sigo, myah, _àmha, _नभए_,
   {{0x656d9aa4,0x4917018d,0x43941574,0x628b0176}},	//   lyah, भूतो_, _дарс, pigo,
   {{0x51870081,0xb4db0211,0x7c2a033b,0xddd300a0}},	//   _куза, _arài, _abfr, ťaže,
   {{0x62894a60,0x212d028b,0xb4db0284,0xc21200a5}},	//   _imeo, _upeh_, _brài, _מהן_,
   {{0x6aad6020,0x7d020496,0x3e71016f,0x10170647}},	//   _akaf, _dvos, _táto_, _خبرد,
   {{0xb4db01da,0x7c640037,0xeaca00e2,0xdce701fb}},	//   _drài, تايل, _bẹp_, ılım,
   {{0xc8690779,0x2d7f0035,0x753d00fd,0x00000000}},	//   _אן_, _płeć_, _ossz, --,
   {{0xeaca0023,0x1d092070,0x81c90033,0x656d01d5}},	//   _dẹp_, _сели_, লুর_, jyah,
   {{0xb4db00f1,0x14d8012f,0x37e30210,0x00000000}},	//   _grài, _भूषण, зорг, --,
   {{0x628907e5,0x66e601e0,0x753d00b5,0x9f450036}},	//   _omeo, соба, _assz, _pelù_,
   {{0xaad0045c,0x6aad0118,0x7d020051,0x00000000}},	//   _सूचक, _gkaf, _yvos, --,
   {{0x442a26fb,0x656d00e0,0x69d600b5,0x6d5b00cc}},	// [ad20] _pbb_, gyah, _igye, nxua,
   {{0x29020169,0x98a900d8,0x62890054,0x06e70033}},	//   mska_, _ypač_, _ameo, _ফিরি,
   {{0x29029aa5,0xf8bf00f7,0x656d011e,0x130a002d}},	//   lska_, utée_, ayah, уней_,
   {{0x786b0095,0x673e9aa6,0xf1fa14ac,0xf8bf00f7}},	//   _qüvv, _ispj, اعات_, rtée_,
   {{0x29029aa7,0x656d0010,0xf8bf00f7,0xa06a2447}},	//   nska_, cyah, stée_, лада_,
   {{0x76440095,0x29029aa8,0xf8bf00f7,0x10a312fb}},	//   ldiy, iska_, ptée_, пичн,
   {{0x6d4b0291,0x44449aa9,0x68f600e9,0xe82007b5}},	//   _arga, md_, _lwyd, _बाना_,
   {{0x22960082,0x76449aaa,0x3ea00a78,0x7e7b0008}},	//   _الرس, ndiy, čito_, ghup,
   {{0x290218b0,0x75249aab,0x444458f1,0x26da9aac}},	//   jska_, ntiz, od_, _lupo_,
   {{0x61e29aad,0x29026a40,0x6aad0c7d,0x6d4b67b3}},	//   lcol, dska_, _skaf, _drga,
   {{0x7e7b028b,0x6d4b9aae,0x29029aaf,0x68f600e9}},	//   bhup, _erga, eska_, _awyd,
   {{0x29022648,0x6d4401c8,0x44449ab0,0x75249ab1}},	//   fska_, _šiau, hd_, ktiz,
   {{0x76449ab2,0x05a70026,0xd0410095,0xd5a71edf}},	//   ddiy, _कुंब, _ailə, _कुंज,
   {{0x69d600f5,0xd0410669,0x8c430d07,0x444404ce}},	//   _egye, _bilə, _нече, jd_,
   {{0x44441973,0xaae60fab,0x1bfb011d,0x2902005f}},	//   dd_, _استو, _גלוב, aska_,
   {{0xd6d814b4,0x44442066,0x656d9ab3,0x76449ab4}},	//   стр_, ed_, tyah, gdiy,
   {{0x9f47024e,0x44440a75,0x68f6001e,0x290200b5}},	// [ad30] daný_, fd_, _gwyd, cska_,
   {{0x656d7b6e,0x80dc006a,0x44449ab5,0xd37b7f43}},	//   ryah, _पढ़े, gd_, лче_,
   {{0x656d397b,0x45d5487f,0xdb0302b1,0x57fa024b}},	//   syah, _монс, _gynä, _דלתו,
   {{0x44449ab6,0x7ae4011c,0x73c40037,0x656d2326}},	//   ad_, _čitl, سينم, pyah,
   {{0x444477c2,0xf65f0b3e,0x673e02a7,0x00000000}},	//   bd_, _diæt_, _zspj, --,
   {{0x44440118,0x26da0054,0xddc20124,0x00000000}},	//   cd_, _yupo_, _blož, --,
   {{0x64559ab7,0x7e7b0118,0x6d4700ea,0x9f4700ac}},	//   _inzi, thup, ājam, baný_,
   {{0x644594cd,0x29029ab8,0x62890054,0x6d5b01a3}},	//   ldhi, yska_, _umeo, txua,
   {{0xb5fb0187,0xec7924c8,0x00000000,0x00000000}},	//   _bláz, ипи_, --, --,
   {{0x64459ab9,0x61fb5baa,0x7e7b034d,0x6d4b0124}},	//   ndhi, _heul, shup, _vrga,
   {{0xe820017a,0x76440669,0x68f602c7,0x2902004e}},	//   _बाबा_, ydiy, _swyd, wska_,
   {{0x29020877,0x60db9aba,0x6d4b1d7d,0x62999abb}},	//   tska_, _kuum, _trga, nnwo,
   {{0x61fb9abc,0xddc201ba,0x26da1a84,0x7870127d}},	//   _meul, _zlož, _supo_, _hävi,
   {{0x29020bcc,0x6ff902b5,0x60db9abd,0x26da053b}},	//   rska_, יפֿג, _muum, _pupo_,
   {{0x61e29abe,0xe73a5b87,0xf74367e9,0x29020d14}},	//   ycol, шев_, меро, sska_,
   {{0x29029abf,0x64559ac0,0x61fb5497,0x75249ac1}},	//   pska_, _anzi, _neul, ttiz,
   {{0x9f47114d,0x764401c2,0xb466277d,0x60db9ac2}},	// [ad40] vaný_, rdiy, окал, _nuum,
   {{0x6299053e,0x44449ac3,0x26da9ac4,0x3e788cd4}},	//   enwo, ud_, _tupo_, _méta_,
   {{0x673e0280,0x61fb9ac5,0x213f022e,0x201e06df}},	//   _uspj, _beul, _asuh_, _rcti_,
   {{0x44449ac6,0x64550f51,0x64456f7d,0x61fb0090}},	//   sd_, _enzi, adhi, _ceul,
   {{0xddc20956,0x61e29ac7,0x9f5c024e,0x61ed0033}},	//   _slož, rcol, mavé_, ñala,
   {{0x61e2298d,0x1df20d1f,0x3940028b,0xb87b00b8}},	//   scol, घर्ष_, _msis_, spív,
   {{0xdfcf00ad,0x61e20176,0x9f4700ac,0x00000000}},	//   نيه_, pcol, paný_, --,
   {{0xddc20e6a,0x61fb5546,0xa2d70026,0x3e782507}},	//   _vlož, _geul, यदर्, _béta_,
   {{0x6eda018d,0x3eb800ea,0xf65f0a8a,0x91030dec}},	//   _पूरु, ērt_, _kiær_, _опте,
   {{0x3a206fe6,0x224608d4,0x80e10033,0x26c20065}},	//   _acip_, ldok_, _নিচ্, _lhko_,
   {{0xddc20097,0x39409ac8,0xee3a00c3,0x9f5c0097}},	//   _ulož, _asis_, _вне_, kavé_,
   {{0xb4db0176,0x0dca18cd,0x3a2000f6,0x00000000}},	//   _kràt, _кули_, _ccip_, --,
   {{0x21260f1a,0x8c460dfc,0x394d98d9,0x9f5c00ac}},	//   ntoh_, _меде, íes_, davé_,
   {{0x3ea903c9,0xfbcf03c5,0x95f500c0,0xa5bb0079}},	//   čate_, عتی_, ेण्ट_, _mbót,
   {{0x368b1d77,0x64430279,0x39409ac9,0x9f450b88}},	//   асан_, ônim, _esis_, _aflê_,
   {{0xcb1302da,0xf1ca06bc,0x9865006c,0x9f5c02d0}},	//   _חלק_, िधान, _کیسے_, ravè_,
   {{0x95cb029f,0x3940010d,0x61fb0284,0xa3cd012f}},	// [ad50] рува_, _gsis_, _reul, शेन_,
   {{0x61fb02e1,0x7af80221,0x2919018e,0x60db4a73}},	//   _seul, _kwvt, musa_, _ruum,
   {{0x3e71004f,0x64454288,0x25a200a6,0x29199aca}},	//   _fáth_, rdhi, _exkl_, lusa_,
   {{0x9f450076,0x2a690359,0xb4db00f1,0x2cac5d83}},	//   _celý_, _joab_, _bràt, hodd_,
   {{0xd13b67d7,0x2a699acb,0x61fb9acc,0x62990051}},	//   рхе_, _moab_, _veul, rnwo,
   {{0x64559acd,0x38b601b4,0x26c94cef,0x3e4700cc}},	//   _unzi, værk_, lmao_, _ốt_,
   {{0x2cac0297,0x61fb9ace,0x902801c8,0x29191766}},	//   dodd_, _teul, юцца_, husa_,
   {{0xe1ff00fb,0x291980e0,0x1ea801cb,0x60db03a6}},	//   _þó_, kusa_, يايي_, _tuum,
   {{0x29190c99,0x2cac0297,0x22640237,0x9f470036}},	//   jusa_, fodd_, žská_, ganò_,
   {{0xe8200825,0x291996ed,0x2cac001e,0x6d499acf}},	//   _बाधा_, dusa_, godd_, rvea,
   {{0xf41202b5,0x3e71008d,0x3a390183,0xb3ad0033}},	//   עפט_, _láti_, fesp_, _কৃতজ,
   {{0x394000e7,0x3a39021d,0x00000000,0x00000000}},	//   _psis_, gesp_, --, --,
   {{0x2eaa00f5,0x5ed20083,0x8c64006c,0x29199ad0}},	//   _اپنی_, _সবচে, سطین, gusa_,
   {{0x26c201f4,0xb87b01ba,0x00000000,0x00000000}},	//   _shko_, dpís, --, --,
   {{0x38ca006c,0x3a390183,0xeb9601ee,0xc052016b}},	//   لاڑی_, besp_, _ниш_, עזל_,
   {{0x39401020,0xe9a60823,0xb90602fb,0x3a39021d}},	//   _tsis_, _найп, _език, cesp_,
   {{0x29199ad1,0x9f5c0187,0x39400103,0x3ae1008d}},	// [ad60] cusa_, ravé_, _usis_, _hóp_,
   {{0x3d136e80,0xf507171d,0xdbe3000d,0x63b50355}},	//   _दिने_, янул_, _déçu, _byzn,
   {{0x2a69012f,0x7ae400f4,0xb7db0277,0x9f5c00d5}},	//   _yoab_, _čitk, _לקיי, pavé_,
   {{0xf8bf9ad2,0x7ebe0031,0x828901e0,0x28bc007e}},	//   ntén_, këpa, осіб_, ोगवि,
   {{0x25d700a5,0xb4db01a6,0x3ead0223,0xb87b2f21}},	//   _מוכן_, _dràs, doet_, mpír,
   {{0x7646034d,0x38b6008a,0x55bb00a5,0xe20a0067}},	//   _haky, færi_, _למכו, dróż_,
   {{0x7646001c,0x443a38c6,0x27470355,0x29196799}},	//   _kaky, mep_, míná_, zusa_,
   {{0x443a9ad3,0x29193ab1,0x2cac00e9,0x539b011d}},	//   lep_, yusa_, wodd_, _הילו,
   {{0x76469ad4,0x00000000,0x00000000,0x00000000}},	//   _maky, --, --, --,
   {{0x443a9ad5,0x3ae10019,0x29199ad6,0x95880035}},	//   nep_, _bóp_, vusa_, ciąż,
   {{0x59a50fd1,0x200c001e,0x2cac001e,0xddc90a66}},	//   _गुजर, _iddi_, rodd_, rkeš,
   {{0x443a97f6,0x2cac00e9,0x76465233,0x6e960037}},	//   hep_, sodd_, _naky, _علشا,
   {{0x443a00f8,0x3d130035,0x6480018d,0x3a39021d}},	//   kep_, _दिये_, _köid, resp_,
   {{0x443a0c21,0x764608dd,0xdd3b00a5,0x00000000}},	//   jep_, _aaky, _לעדכ, --,
   {{0x3ae10028,0x443a9ad7,0xf7731168,0x29193f47}},	//   _góp_, dep_, راس_, susa_,
   {{0x29199ad8,0xfbb700a5,0x8aa400d8,0x00000000}},	//   pusa_, _מפות_, _прыд, --,
   {{0x200c001e,0x764600d7,0x26c901ef,0x6e2200d7}},	// [ad70] _oddi_, _daky, rmao_, _mcob,
   {{0x7c3a9ad9,0x443a00d1,0x68ed1b68,0x00000000}},	//   netr, gep_, _itad, --,
   {{0x61ed0300,0x87072f7a,0x00000000,0x00000000}},	//   ñalo, _عبدل, --, --,
   {{0x7c3a9ada,0x63b5024e,0x6d4206a2,0x200c05ee}},	//   hetr, _vyzn, _osoa, _addi_,
   {{0x7c3a1cdb,0xa0699adb,0x63b50035,0x443a027d}},	//   ketr, жала_, _wyzn, bep_,
   {{0x443a9adc,0x6e2201f7,0x940100a8,0x7c3a15f2}},	//   cep_, _acob, yihə_, jetr,
   {{0x7c3a9add,0x4423028b,0x8fa20f16,0x44310176}},	//   detr, _icj_, каше, _ibz_,
   {{0x68ed9ade,0x6f0802d7,0x6447023c,0x200c03d0}},	//   _otad, _dvdc, _haji, _eddi_,
   {{0x64473c5d,0x1c1800a1,0xf2d200a5,0x3ead01bf}},	//   _kaji, _दाखल_, _יעל_, roet_,
   {{0x6447029d,0x7c3a3d7d,0xeb990274,0x00000000}},	//   _jaji, getr, жио_, --,
   {{0x64471476,0x68ed9adf,0xf1e155f5,0xe81708b6}},	//   _maji, _atad, _फलान, _ताजा_,
   {{0xdd8e0105,0x64471f60,0x6ee70225,0x4423008c}},	//   اوی_, _laji, _tıbb, _lcj_,
   {{0xda1f9ae0,0x76462bab,0x5d6902f3,0x7c3a9ae1}},	//   _भारत_, _raky, _филм_, betr,
   {{0x64478f6e,0xf8bf9726,0x7d1b03a6,0x76469ae2}},	//   _naji, stén_, muus, _saky,
   {{0x68ed9ae3,0x7d1b9ae4,0xdca20009,0x00000000}},	//   _etad, luus, _шаши, --,
   {{0x44239ae5,0x44319ae6,0x61ed01ef,0x00000000}},	//   _acj_, _abz_, ñall, --,
   {{0x443a00bf,0x64470a04,0x4423012f,0x7d1b9ae7}},	// [ad80] tep_, _baji, _bcj_, nuus,
   {{0x3ea01851,0xe73a0202,0x64470453,0x44239ae8}},	//   čiti_, _део_, _caji, _ccj_,
   {{0x443a00bf,0xc20a01cb,0x76469ae9,0x366a88f0}},	//   rep_, ققان_, _taky, _дано_,
   {{0x443a9aea,0xe2973c60,0x7d1b9aeb,0xd250103b}},	//   sep_, мах_, kuus, طنت_,
   {{0xd1300357,0x66049aec,0x443a035f,0x64470031}},	//   امت_, maik, pep_, _faji,
   {{0x660458ee,0x64474358,0x6e220139,0x7d1b02ea}},	//   laik, _gaji, _scob, duus,
   {{0xdfd00037,0x44e41b4b,0x7e6b1736,0x78700523}},	//   ديث_, _hö_, _bogp, _hävs,
   {{0x667b02b5,0x941e00c0,0x644701c0,0x44e49aed}},	//   ַװיג, _पाँच_, _zaji, _kö_,
   {{0x2d840129,0x9f5e00da,0x7d1b067f,0x7e6b008c}},	//   uzme_, _ketë_, guus, _dogp,
   {{0x9f5e01d2,0x3e7801c0,0x66049aee,0xcf0c0033}},	//   _jetë_, _této_, haik, _শহীদ_,
   {{0x68ed9aef,0x66049af0,0x44e49af1,0x7c23009e}},	//   _stad, kaik, _lö_, _dcnr,
   {{0x628242f9,0x7c3a9af2,0x7d1b01a8,0xed5a151d}},	//   nhoo, setr, buus, _мое_,
   {{0x941e0b4a,0x7c3a9af3,0x44e49af4,0x6d42002d}},	//   _पांच_, petr, _nö_, _usoa,
   {{0x58d4036c,0xa3c044d2,0x62820159,0x39520a8a}},	//   коят, ुधा_, hhoo, _drys_,
   {{0x6604002f,0x8aa700af,0xb9060066,0xe82025fe}},	//   faik, _орид, _बू_, _बारा_,
   {{0x64470b4f,0x66049af5,0x39521cfe,0x62820051}},	//   _saji, gaik, _frys_, jhoo,
   {{0x644701f4,0x628208c7,0x44315785,0x39529af6}},	// [ad90] _paji, dhoo, _pbz_, _grys_,
   {{0x3e71008a,0x44e401ff,0x62820345,0x660400e0}},	//   _hátt_, _dö_, ehoo, aaik,
   {{0x660443a2,0xa5bb004f,0xf8bf03e6,0x64479af7}},	//   baik, _gcón, ntém_, _vaji,
   {{0x64470b4f,0xfd5e0023,0x630405f5,0xd5b000b5}},	//   _waji, _quyể, ئونل, افے_,
   {{0xc6160052,0x64479af8,0x5bbb10aa,0x50b59af9}},	//   _אחרי_, _taji, _उर्व, нску,
   {{0x26d99afa,0x62820553,0x6447034d,0x00000000}},	//   _hiso_, ahoo, _uaji, --,
   {{0xfd5e0028,0x38b60c71,0x9f5e0260,0x9f5c0097}},	//   _tuyể, mært_, _jetè_, baví_,
   {{0x62829afb,0x7d1b0273,0x05c30084,0x3e7105ee}},	//   choo, tuus, _शराब, _nátt_,
   {{0xdc3a0095,0xe82023e3,0xf8bf00fd,0x00000000}},	//   _açıq, _बाला_, ttél_, --,
   {{0x66049afc,0x0d8201c8,0x26d99afd,0x6ac80127}},	//   zaik, ульн, _liso_, रग्र,
   {{0x442141f0,0x7d1b18af,0x7e6b008c,0x00000000}},	//   igh_, suus, _togp, --,
   {{0x26d902c6,0x39520173,0xef18010b,0x00000000}},	//   _niso_, _prys_, _імі_, --,
   {{0xed59058f,0xceb200a5,0x66049afe,0xfe790355}},	//   _хол_, _גיא_, vaik, mků_,
   {{0x660400d7,0xf1b90187,0x7d099aff,0xfe790355}},	//   waik, _myš_, mses, lků_,
   {{0x6ab60439,0x7d099b00,0x660400d8,0x26d900d1}},	//   _псих, lses, taik, _biso_,
   {{0x7bc30254,0x3952010b,0x9f5e0107,0xfe790355}},	//   _iznu, _trys_, _detè_, nků_,
   {{0x26d90391,0x66049b01,0x7d090e45,0x6aa4034d}},	// [ada0] _diso_, raik, nses, _ijif,
   {{0x66045422,0x7d090086,0x26de01dd,0x25a6003c}},	//   saik, ises, ítos_, ħol_,
   {{0x9f5e9b02,0x628212ba,0x66049b03,0x9f5c0187}},	//   _vetë_, thoo, paik, taví_,
   {{0x7d099b04,0x442101a6,0x23660a78,0x44e49b05}},	//   kses, agh_, ćoj_, _tö_,
   {{0x62829b06,0x9f5c033a,0xfe7900b8,0xa49b0260}},	//   rhoo, raví_, dků_, _bwòd,
   {{0xe3b100f5,0x403410da,0x7aed023a,0x00000000}},	//   ارے_, текс, _čatn, --,
   {{0x64a39b07,0x645c9b08,0x63b30097,0x37db0070}},	//   _сара, _inri, čené, פֿגע,
   {{0x9f5e9b09,0x00000000,0x00000000,0x00000000}},	//   _jeté_, --, --, --,
   {{0x628003ad,0x7d099b0a,0xdd9000d1,0x3cfb01c0}},	//   _ilmo, gses, شود_, लीले_,
   {{0x3e710093,0xe61f07c0,0x6aa408c7,0x9f5e007e}},	//   _sátt_, _hmôt_, _ajif, _leté_,
   {{0x69c40133,0xa5bb01ef,0xfe7900b8,0xa41e00b4}},	//   _azie, _acól, bků_, _पाईप_,
   {{0x0d860c88,0x69c40024,0xfce60036,0xc33300a5}},	//   _плен, _bzie, _зодо, נור_,
   {{0xf8bf05d3,0x26d99b0b,0x60da0103,0x3a7430ed}},	//   stém_, _riso_, _kitm, уляр,
   {{0x69c49b0c,0x26d90118,0x3ea000cd,0xba3b00a2}},	//   _dzie, _siso_, čitu_, roïq,
   {{0x60da9b0d,0x26d99b0e,0x62805891,0x7793014a}},	//   _mitm, _piso_, _olmo, ایجا,
   {{0xba7701b2,0x941e046c,0xdb23008d,0x00000000}},	//   _ساعت, _पाउच_, _árás, --,
   {{0x26d90ef7,0x9f5e0176,0x645c009e,0x00000000}},	// [adb0] _viso_, _deté_, _bnri, --,
   {{0x44219b0f,0x7d1d0443,0x62809b10,0x6abd9b11}},	//   ugh_, àssi, _almo, llsf,
   {{0xad9d0035,0x68b8016b,0xbb3b016b,0x26d900ee}},	//   jaźn, _אלזא_, ּעדי, _tiso_,
   {{0xa3cd25de,0xaab300b8,0x290b0079,0x60da0312}},	//   शेष_, ीतिक, osca_, _aitm,
   {{0xfe7901c0,0x60da9872,0x765d9b12,0xdced00ea}},	//   vků_, _bitm, _insy, ējīg,
   {{0x628000b5,0x22490bc6,0x60da00ee,0x290b0036}},	//   _elmo, žak_, _citm, isca_,
   {{0x752d15a1,0xb4bd0084,0x60da9b13,0xfe7900b8}},	//   ltaz, आती_, _ditm, tků_,
   {{0x764d9b14,0x7d09007c,0xee391400,0x291900cb}},	//   nday, tses, фни_, krsa_,
   {{0x752d83d5,0x290b004e,0x7d0900af,0xfe790355}},	//   ntaz, jsca_, uses, rků_,
   {{0x60da01d6,0x752d5077,0x6ab613a4,0xfe790355}},	//   _gitm, itaz, _skyf, sků_,
   {{0x200744a5,0x8c3c0723,0x5f7900bf,0x7d099b15}},	//   mani_, toğr, _تماس_, sses,
   {{0x7d099b16,0x20070b4f,0x26f00083,0x60da0223}},	//   pses, lani_, _ছিলো_, _zitm,
   {{0x764d018e,0xf2d20070,0x9f5c0187,0x9f5e0176}},	//   dday, יעט_, mavá_, _reté_,
   {{0x200799c5,0x765d02e9,0x7e699b17,0x628800d8}},	//   nani_, _ansy, ljep, _įdom,
   {{0x290b9b18,0xe7270c98,0x29199b19,0x66e65c36}},	//   asca_, корд_, arsa_, тоба,
   {{0x20079b1a,0x764d9b1b,0x7e7b01f4,0x752d5e55}},	//   hani_, gday, nkup, ftaz,
   {{0x20079b1c,0xa507095d,0x7ae36544,0x044a00af}},	// [adc0] kani_, кета_, _hunt, мпак_,
   {{0x20070116,0x7ae39b1d,0xba3b001e,0x7e7b0e06}},	//   jani_, _kunt, mnïa, hkup,
   {{0x7ae39b1e,0x68e40244,0x43860af8,0x7e7b9b1f}},	//   _junt, _huid, خلاق, kkup,
   {{0x7ae39b20,0x68e40006,0xf5061c89,0x00000000}},	//   _munt, _kuid, _измо, --,
   {{0x20079b21,0x60da0118,0x00000000,0x00000000}},	//   fani_, _pitm, --, --,
   {{0x443e9b22,0x20079b23,0x68e40d4c,0xf1a945fd}},	//   _út_, gani_, _muid, رانه_,
   {{0x7ae39b24,0x6e9409d0,0x68e49b25,0x60da7526}},	//   _nunt, лику, _luid, _vitm,
   {{0xf8bf006c,0x7e7b8d28,0x60da03bc,0xad9d0035}},	//   tték_, gkup, _witm, raźn,
   {{0x20079b26,0xc69302b8,0xe29703fa,0xc0e600d4}},	//   bani_, יאה_, _рат_, _розк,
   {{0x7ae3239a,0x20079b27,0x60da03c4,0xa0c90037}},	//   _bunt, cani_, _uitm, _كذلك_,
   {{0x7ae3004f,0x441b02b5,0x8fa330ed,0x09bd23e3}},	//   _cunt, וויס, _кафе, ोध्य,
   {{0x68e40014,0x7ae39b28,0xeaf700b5,0x7e690506}},	//   _buid, _dunt, کریت_, cjep,
   {{0x68e40874,0x61ed00de,0x7ae301ed,0x29190124}},	//   _cuid, ñali, _eunt, ursa_,
   {{0xa8a43e10,0x7ae306a2,0x68e40a45,0xcb5416a4}},	//   арск, _funt, _duid, _منتظ,
   {{0x7ae39b29,0x764d046a,0xd6db00d8,0x290b028b}},	//   _gunt, tday, дта_, ssca_,
   {{0x0bb70122,0x752d9b2a,0x34db00a1,0xa3d6073f}},	//   _שלהם_, ttaz, बद्द, ाइन_,
   {{0x764d991b,0x68e40dc5,0xb604145f,0x7ae39b2b}},	// [add0] rday, _guid, ряск, _zunt,
   {{0x752d9b2c,0x764d9b2d,0x2c6900ee,0x3949099e}},	//   rtaz, sday, _búdy_, _isas_,
   {{0x7ae31a71,0x752d9b2e,0x68e40120,0xa3cd0067}},	//   _xunt, staz, _zuid, शें_,
   {{0x20079b2f,0x3d1302cb,0xf67902b5,0x657200da}},	//   wani_, _दिले_, _נאָמ, ëdhë,
   {{0x20079b30,0x956402fb,0x00000000,0x00000000}},	//   tani_, _кърд, --, --,
   {{0xb97c00a5,0x34959b31,0x63bc9b32,0x3ea602ee}},	//   ונדי, _сагр, _fyrn, _ajot_,
   {{0x20079b33,0x61e40b16,0xd00e11cf,0xf65f08c8}},	//   rani_, žila, سلي_, _knæ_,
   {{0xdd910332,0x3949007c,0xdb25006c,0x7e7b011c}},	//   یوں_, _osas_, épít, ukup,
   {{0x7ae39b34,0xee360104,0x7e7b9b35,0x78b55906}},	//   _sunt, уны_, rkup, kozv,
   {{0x1abe018d,0x68e49b36,0x629992bc,0x20079487}},	//   ोष्ठ, _ruid, liwo, qani_,
   {{0xb0b602b5,0x68e49b37,0x39499b38,0x99c00033}},	//   _עפעס_, _suid, _asas_, _ইলেক,
   {{0x68e49b39,0x20059b3a,0x394902d7,0x7e7b0031}},	//   _puid, _heli_, _bsas_, qkup,
   {{0x68e49b3b,0x20059b3c,0x394900fe,0xddc000d5}},	//   _quid, _keli_, _csas_, jemň,
   {{0x7ae39b3d,0x6846004b,0x3ebf03ad,0x20059b3e}},	//   _tunt, ынга, llut_, _jeli_,
   {{0x39499b3f,0x20059b40,0x7ae30159,0xeabf027a}},	//   _esas_, _meli_, _uunt, blù_,
   {{0xcf920070,0x8ee50033,0x200505f5,0x7d1b0553}},	//   צטן_, _নবাগ, _leli_, orus,
   {{0xe9da4def,0x7d1b9b41,0xee5c0093,0x3ebf00c3}},	// [ade0] _яки_, nrus, æðið_, ilut_,
   {{0x200500ab,0x4433026e,0x00000000,0x00000000}},	//   _neli_, gfx_, --, --,
   {{0x25ab9b42,0x224d09ba,0x32040107,0x00000000}},	//   _excl_, _baek_, _pemy_, --,
   {{0x7d1b9b43,0x979b016b,0x64800523,0xa3d600ab}},	//   krus, _טשיק, _göin, ाइब_,
   {{0x200538cb,0x00000000,0x00000000,0x00000000}},	//   _beli_, --, --, --,
   {{0xf8b40084,0x26c09b44,0x200503c9,0xc306004f}},	//   ंकिय, llio_, _celi_, _مبرو,
   {{0x20059b45,0xd8d702b5,0x66062930,0x442a0176}},	//   _deli_, נוצט_, _kekk, _icb_,
   {{0x644e0147,0xb5fb0279,0x26c0027a,0x442a00cc}},	//   _habi, _inác, nlio_, _hcb_,
   {{0x66069b46,0xd291006c,0x26c000e9,0xf8bf000d}},	//   _mekk, _بینظ, ilio_, luée_,
   {{0x66069b47,0x9b5800c9,0x644e1049,0xdee6095d}},	//   _lekk, виот_, _jabi, _божи,
   {{0x644e9b48,0x443801da,0x7d1b00b9,0x26c0010b}},	//   _mabi, _mbr_, arus, klio_,
   {{0x644e9b49,0x7d1b9b4a,0x2005025c,0x66066822}},	//   _labi, brus, _zeli_, _nekk,
   {{0x4438151a,0x9f5e0453,0x9f4c0260,0xc9840c9f}},	//   _obr_, _metí_, _gedò_, бури,
   {{0xac1802ce,0x26c0005f,0x44380183,0x9f5e0097}},	//   _року_, elio_, _nbr_, _letí_,
   {{0x66069b4b,0xdb0a11cb,0x00000000,0x00000000}},	//   _bekk, _nyfø, --, --,
   {{0x26c00021,0x569406cd,0x44389472,0x644e9b4c}},	//   glio_, баст, _abr_, _aabi,
   {{0x644e2618,0x66069b4d,0x39491b39,0x629902d0}},	// [adf0] _babi, _dekk, _usas_, viwo,
   {{0x442a021d,0x45b80f99,0x7d023998,0x00000000}},	//   _ccb_, угую_, _mwos, --,
   {{0x644e3448,0x26c09b4e,0x20059b4f,0x6606001c}},	//   _dabi, blio_, _reli_, _fekk,
   {{0x66069b50,0x443800e9,0x62356cb4,0x26c09b51}},	//   _gekk, _ebr_, реду, clio_,
   {{0x20059b52,0x9f5e01ba,0xd7c80118,0x3ce60036}},	//   _peli_, _detí_, _لویه_, _nuov_,
   {{0x644e9b53,0x44250c71,0x225f61d7,0x8f152447}},	//   _gabi, _øl_, _wnuk_, афич,
   {{0x20059b54,0xb5fb0037,0x660601a8,0x764f04fb}},	//   _veli_, _gnác, _yekk, _kacy,
   {{0x644e9b55,0x20050090,0x7d023c4c,0x8e5503d0}},	//   _zabi, _weli_, _bwos, рткі,
   {{0x644e01d0,0x645a0279,0x6f04012e,0x20059b56}},	//   _yabi, _ótic, ćica, _teli_,
   {{0x3ebf022a,0x7d1b9b57,0x644e9b58,0x200517f0}},	//   slut_, rrus, _xabi, _ueli_,
   {{0xda6643be,0x26c000e9,0x7d020118,0x5aca4bf1}},	//   авни, ylio_, _ewos, клом_,
   {{0xeb9600c3,0x7d1b9b59,0x764f01d5,0xa3d600ab}},	//   рию_, prus, _nacy, ाइत_,
   {{0x66069b5a,0x7d0202d0,0x00000000,0x00000000}},	//   _rekk, _gwos, --, --,
   {{0x6d4b0409,0x8d740d93,0x660600ab,0x26c000e9}},	//   _isga, _داما, _sekk, wlio_,
   {{0x644e9b5b,0xb8ce22a7,0x66069b5c,0x3ce60009}},	//   _rabi, _कद_, _pekk, _zuov_,
   {{0x644e9b5d,0x7ebe00da,0x44389b5e,0x1dd2112b}},	//   _sabi, tëpi, _sbr_, देवत,
   {{0x644e2aaf,0xf5e72252,0x4438081b,0xa50a9b5f}},	// [ae00] _pabi, рмул_, _pbr_, теза_,
   {{0x644e40eb,0x26c00a78,0x446300d4,0xf8bf0248}},	//   _qabi, slio_, овув, tuée_,
   {{0x6606007c,0x26c00831,0x644e008b,0x442a9b60}},	//   _tekk, plio_, _vabi, _vcb_,
   {{0x6d599b61,0x644e1548,0x673e035f,0x764f0371}},	//   _orwa, _wabi, _ippj, _gacy,
   {{0x644e9b62,0xe0461837,0xa06a03fa,0x7644012f}},	//   _tabi, инди, када_, meiy,
   {{0x442a01a2,0x7d020010,0x764f6ff2,0x3e78008d}},	//   _ucb_, _rwos, _zacy, _létt_,
   {{0x6d4b9b63,0x6d599b64,0xf8bf0248,0x75240051}},	//   _asga, _arwa, quée_, luiz,
   {{0x7d0202e9,0xa5bb0079,0x68f60523,0x00000000}},	//   _pwos, _scói, _otyd, --,
   {{0xe7fb9b65,0x4444034d,0x22590093,0xe0da59d4}},	//   ्रमा_, oe_, _óska_, _ава_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44449b66,0x6d5902c9,0xe8200387,0xe45702b5}},	//   ie_, _erwa, _बाजा_, בייט_,
   {{0x44449b67,0xd00b0083,0x1eda004f,0x7d0204fb}},	//   he_, _রায়_, _شباب_, _twos,
   {{0x81e80083,0x673e01f7,0xdca60aec,0xb4db0176}},	//   _মজা_, _appj, _кади, _isàv,
   {{0x8c4332a6,0x764f0371,0x75249b68,0x7a3c0a8a}},	//   _мече, _sacy, duiz, _påtæ,
   {{0x7e6250e9,0x68f603d0,0x00000000,0x00000000}},	//   _knop, _etyd, --, --,
   {{0x44449b69,0x9f5e02fb,0x96210026,0x6d4b00e9}},	//   ee_, _metà_, यलेट_, _ysga,
   {{0x44449b6a,0x7524002a,0x00000000,0x00000000}},	// [ae10] fe_, guiz, --, --,
   {{0xd37b12a2,0x3ea92eaf,0x7c289b6b,0x764f04fb}},	//   кче_, čati_, ngdr, _wacy,
   {{0xf3670165,0x2d8d0069,0x7e629b6c,0x00000000}},	//   штан, zzee_, _onop, --,
   {{0x4b370052,0x7bd90070,0x00000000,0x00000000}},	//   שראל_, אַנק, --, --,
   {{0x660d04ce,0x463a02b5,0x7f5a0176,0x27ec01ba}},	//   maak, _גערע, _artq, ždne_,
   {{0x660d3d74,0x7e62647d,0x83f800af,0x6d590027}},	//   laak, _anop, _верс_, _rrwa,
   {{0xf8bf9b6d,0x64450054,0x3e7801f7,0x00000000}},	//   ltés_, mehi, _néts_, --,
   {{0x6445190b,0xc3320122,0x7ebe00da,0x660d2ada}},	//   lehi, _מול_, këpu, naak,
   {{0xf8bf9b6d,0x3e7800fb,0x00000000,0x00000000}},	//   ntés_, _rétt_, --, --,
   {{0x4c851c76,0x64459b6e,0xcc8900d1,0x7074004f}},	//   слов, nehi, انده_, _والذ,
   {{0x5f7915f4,0x908a006c,0x09e62315,0x75240054}},	//   _حماس_, _حملے_, йонн, zuiz,
   {{0x6d59004e,0xff5002fd,0x64450055,0x00000000}},	//   _trwa, _زخم_, hehi, --,
   {{0x44442591,0x64459b6f,0x6d590010,0xec6e73a8}},	//   ye_, kehi, _urwa, _еп_,
   {{0x44449b70,0x6e299b71,0x644501f2,0x3ff90070}},	//   xe_, lgeb, jehi, טפֿע,
   {{0x177908a6,0xcaf539e6,0x00000000,0x00000000}},	//   асть_, _استب, --, --,
   {{0x07a300ef,0x660d9b72,0x75249b73,0x6e290c58}},	//   часн, gaak, tuiz, ngeb,
   {{0xe4ea00f3,0x6d4923a0,0x00000000,0x00000000}},	// [ae20] اعره_, nwea, --, --,
   {{0x44445c74,0x3940067f,0x9f5e0097,0x64459b74}},	//   ue_, _ipis_, _letá_, gehi,
   {{0x187702b8,0x935a081b,0x6e291192,0x660d01a8}},	//   _העיר_, ырау_, kgeb, baak,
   {{0x366a0b46,0x41d92135,0x2c210099,0x6e290223}},	//   _само_, _बृहस, _माझं_, jgeb,
   {{0xf8bf0248,0x75241bea,0x644501cb,0x00000000}},	//   ctés_, quiz, behi, --,
   {{0x444401f4,0x6d4901cb,0x6e2909ef,0x64450118}},	//   qe_, dwea, egeb, cehi,
   {{0x43860082,0x6e2901ae,0xe7fb13ab,0xf8bf0093}},	//   _الأق, fgeb, ्रता_, bréf_,
   {{0x8cf49b75,0x39409b76,0x6e290c55,0x628b009e}},	//   озиц, _opis_, ggeb, chgo,
   {{0x3940006d,0xf65300a5,0x6d490159,0xdb18031d}},	//   _npis_, לצה_, gwea, _vyví,
   {{0x62829b77,0x8fa60423,0x660d01a8,0x20c90079}},	//   lkoo, _лазе, zaak, lúin_,
   {{0x2d8204c3,0x200e88e4,0x6e2956ec,0x7c280051}},	//   ške_, mafi_, bgeb, rgdr,
   {{0x62827980,0x7e62817b,0x6e2901f2,0x6d492cb7}},	//   nkoo, _unop, cgeb, bwea,
   {{0xc984002d,0x660d01a8,0x3940021d,0x6445023c}},	//   пури, vaak, _cpis_, yehi,
   {{0x200e1051,0xd9180086,0x7afa0159,0x660d9b78}},	//   nafi_, щью_, pptt, waak,
   {{0x62829b79,0x644500af,0x5c370d85,0x39400359}},	//   kkoo, vehi, _הטוב_, _epis_,
   {{0xf96b01d3,0x6282006d,0xfaa40166,0x56946a23}},	//   _брой_, jkoo, _најо, паст,
   {{0x660d9b7a,0x6282388d,0xf8bf0248,0x549900d8}},	// [ae30] raak, dkoo, utés_, аваў_,
   {{0x7afd0c99,0x660d9b7b,0xf8bf9719,0xf80703fa}},	//   ćstv, saak, rtés_, _учин,
   {{0x64454b79,0xf8bf9b7c,0x62820b88,0x628b9b7d}},	//   rehi, stés_, fkoo, thgo,
   {{0xaac91bb5,0x4ac9000c,0xf8bf00f7,0x64459b7e}},	//   रतिक, रतिव, ptés_, sehi,
   {{0x7aea9b7f,0x6aad00da,0x21692c0f,0x47d500d1}},	//   _luft, _mjaf, рили_, _ديگر,
   {{0x7bc60035,0xa3d60084,0x11d40934,0x62829b80}},	//   ękuj, ाइश_, ستند, akoo,
   {{0x6e29829e,0x287c0070,0x224601ed,0x00000000}},	//   tgeb, רנומ, beok_, --,
   {{0x628200d5,0x623499c3,0x69cd0065,0x6d499b81}},	//   ckoo, _несу, _ozae, twea,
   {{0xd13104a3,0x6e290b19,0x7aea02c9,0x320f0282}},	//   _زما_, rgeb, _auft, magy_,
   {{0x6e2908f3,0x320f84db,0x301400af,0x7aea0395}},	//   sgeb, lagy_, _ндур, _buft,
   {{0x3df500d8,0x39409b82,0x6e2901bf,0x7aea008c}},	//   _дзес, _spis_, pgeb, _cuft,
   {{0xc8691759,0x7aea9b83,0x00000000,0x00000000}},	//   _בן_, _duft, --, --,
   {{0x3eb8006c,0x6aad012f,0x6dc706ee,0x00000000}},	//   _írta_, _djaf, _ازال, --,
   {{0x628902c7,0x3940008b,0xf41f0033,0x66e62401}},	//   _lleo, _vpis_, ন্তর_, жова,
   {{0x869a03e6,0x39400035,0x1af30831,0x629b0103}},	//   атат_, _wpis_, _আটকে_, _omuo,
   {{0x6aad0093,0x4df9016b,0x00000000,0x00000000}},	//   _gjaf, שפּא, --, --,
   {{0x39400254,0xf8bf05f6,0x00000000,0x00000000}},	// [ae40] _upis_, rtér_, --, --,
   {{0xf8bf0987,0xa3d60b4a,0x03a60c46,0xb5fb0300}},	//   stér_, ाइल_, оизо, _unán,
   {{0x7ae458ad,0x62899b84,0xe9a90118,0xf8bf1da9}},	//   _kiit, _bleo, _ندین_, ptér_,
   {{0x628999d4,0x7ae4081b,0x09de0033,0x84e300b4}},	//   _cleo, _jiit, _ভ্যা, कआउट_,
   {{0x62823f87,0x7ae49b85,0x224601ed,0x00000000}},	//   rkoo, _miit, reok_, --,
   {{0x7ae41ba4,0x67210496,0x62829b86,0x22460009}},	//   _liit, šlje, skoo, seok_,
   {{0x628212ba,0x00000000,0x00000000,0x00000000}},	//   pkoo, --, --, --,
   {{0xf41f00c8,0x7ae403ad,0x628911d9,0x221500af}},	//   ন্দর_, _niit, _gleo, _нфур,
   {{0x78bc9b87,0x10a601af,0x2b5c04fb,0x7bc30457}},	//   korv, _диан, _srvc_, _aynu,
   {{0xb5fb0aca,0x6aad022e,0x7d1d006c,0x20c90079}},	//   _anál, _sjaf, ássa, núil_,
   {{0x7bc30297,0x200c021d,0x78bc23b5,0x5457016b}},	//   _cynu, _iedi_, dorv, קסטן_,
   {{0xe8d90028,0xf8bf0391,0x81de0033,0x69c40107}},	//   _trị_, guén_, _দ্য_, _byie,
   {{0x7ae44fa0,0x78bc0249,0x200c0225,0xac730088}},	//   _diit, forv, _kedi_, سایش,
   {{0x50ca018d,0x7aea9b88,0x6d420036,0xa5bb2651}},	//   ितिष, _tuft, _ipoa, _ocór,
   {{0x200c96a9,0x20c90037,0x7bc300e9,0x37c50037}},	//   _medi_, dúil_, _gynu, سيرف,
   {{0xd9e3009a,0x7c3a0345,0x4668097b,0xf8bf00a2}},	//   _गणपत_, lftr, орум_, drée_,
   {{0xa5bb0279,0x200c00e9,0xe534051a,0x00000000}},	// [ae50] _acór, _oedi_, меть, --,
   {{0x28d22450,0x629b0036,0x78bc3945,0x20c90079}},	//   _दीपि, _smuo, corv, gúil_,
   {{0x62894031,0xf8bf000d,0x29090118,0x8c3c027d}},	//   _pleo, grée_, _hwaa_, ciğe,
   {{0x68ed9b89,0xd6270037,0x7ae49b8a,0xb60800d5}},	//   _kuad, _بعدي, _xiit, ruší,
   {{0x68ed028b,0x200c01a3,0x1a9c0070,0x59d300be}},	//   _juad, _bedi_, סידע, _सरफर,
   {{0x37df0033,0x68ed9b8b,0x3dd00033,0xf8bf000d}},	//   _ব্যর, _muad, াখাল, brée_,
   {{0x200c06d0,0x02a75095,0x68ed04e6,0xa5bb0037}},	//   _dedi_, _драм, _luad, _gcór,
   {{0x64559b8c,0x7c3a095a,0x629b023c,0x00000000}},	//   _hazi, eftr, _umuo, --,
   {{0x7ae40086,0x68ed01a6,0x61e9209d,0x7c3a0d92}},	//   _riit, _nuad, _igel, fftr,
   {{0x7ae403ad,0x64559b8d,0x320d0223,0x200c9b8e}},	//   _siit, _jazi, _heey_, _gedi_,
   {{0x64555f46,0x6abd9b8f,0x7ae42119,0x7ebe0031}},	//   _mazi, fosf, _piit, rëpr,
   {{0x64555e3c,0x68ed0284,0x7c3a0223,0x61e90024}},	//   _lazi, _buad, aftr, _jgel,
   {{0x7ae49b90,0x68ed4efb,0x78bc9b91,0xdb189b92}},	//   _viit, _cuad, torv, _vyvá,
   {{0x64559b93,0x7ae40714,0x61e9008c,0x68ed4582}},	//   _nazi, _wiit, _lgel, _duad,
   {{0x7ae41b43,0x2aa400b5,0x366a2746,0x61e90282}},	//   _tiit, rűbb_, баво_, _ogel,
   {{0x61e99b94,0x61e4025c,0xf8bf9b95,0x68ed0874}},	//   _ngel, žili, quén_, _fuad,
   {{0x64559b96,0x68ed9b97,0x20c90037,0x18a66b65}},	// [ae60] _bazi, _guad, túil_, _наим,
   {{0x6ad100c8,0xf8bf02e1,0xa84a0037,0x64559b98}},	//   _সংযো, trée_, _الدم_, _cazi,
   {{0xb5fb0076,0x645a0370,0xa87b0122,0x200c9b99}},	//   _znám, _ótim, _האיר, _redi_,
   {{0x20c9004f,0x3d1c0b4a,0x25ad0a78,0x200c9b9a}},	//   súil_, _मिले_, _žele_, _sedi_,
   {{0x660422e5,0x200c9b9b,0x6d5b006d,0x26c21c2b}},	//   mbik, _pedi_, jvua, _ikko_,
   {{0x61ff01c2,0x64559b9c,0x66049b9d,0x00000000}},	//   ıqla, _gazi, lbik, --,
   {{0x43430b7d,0x200c01d3,0xddcb0067,0xdfcf0079}},	//   _перв, _vedi_, _nagł, هيه_,
   {{0x200c1973,0x75241c98,0x00000000,0x00000000}},	//   _wedi_, oriz, --, --,
   {{0x64559b9e,0xc106017e,0xfe6f0037,0x3eaf00ee}},	//   _yazi, _رواي, ادى_, _djgt_,
   {{0x68ed00f1,0x7524907e,0x7c3a033b,0x7aed00f4}},	//   _ruad, iriz, uftr, _čatr,
   {{0x6abd9b9f,0xb5fb0037,0x395200ee,0x29090371}},	//   tosf, _snám, _asys_, _swaa_,
   {{0x75249ba0,0x2909034d,0x00000000,0x00000000}},	//   kriz, _pwaa_, --, --,
   {{0xac1848b6,0x68ed9ba1,0x6298000d,0xc4be0067}},	//   _долу_, _quad, évoy, ्ताओ,
   {{0x75240069,0xe8d90019,0x6b81008d,0x387a00e5}},	//   driz, _trọ_, bylg, _copr_,
   {{0x64559ba2,0xddc90c0a,0x6af3004f,0x4c3b0122}},	//   _razi, mješ, _كثير, _התוב,
   {{0x64559ba3,0x75240b5e,0xddc96645,0x6604010d}},	//   _sazi, friz, lješ, gbik,
   {{0x64559ba4,0xa3df0127,0xc8673851,0x752479c9}},	// [ae70] _pazi, देन_, _етни, griz,
   {{0x2a69006f,0xddc90c99,0x64551952,0xb4d721b2}},	//   _hnab_, nješ, _qazi, ागे_,
   {{0x64559ba5,0x925900c3,0x2a6900ea,0x752409c5}},	//   _vazi, жает_, _knab_, ariz,
   {{0x64550657,0x75249ba6,0xa49b0107,0x00000000}},	//   _wazi, briz, _otòg, --,
   {{0xdb1803ad,0x75247a57,0x64552387,0x854400af}},	//   _hyvä, criz, _tazi, _пэре,
   {{0x26c91725,0x660f3236,0xf95800a5,0x00000000}},	//   llao_, _heck, פסות_, --,
   {{0xdb1800c3,0x660f4a7a,0xddc920dc,0x00000000}},	//   _jyvä, _keck, dješ, --,
   {{0x61e99ba7,0x77fb0246,0x00000000,0x00000000}},	//   _ugel, ्रुक_, --, --,
   {{0x9f5c0187,0x660f9ba8,0x00000000,0x00000000}},	//   mavý_, _meck, --, --,
   {{0x660f9ba9,0x6d5b01f4,0x2a690107,0x13aa00b5}},	//   _leck, rvua, _anab_, _انہی_,
   {{0xf8bf0370,0x661d02b2,0x6e3b04fb,0xa3d60067}},	//   guém_, _odsk, pfub, ाइए_,
   {{0x2f1800d8,0xedd542c5,0xa3b5007c,0xa3df021a}},	//   _хоць_, _قياد, _जखन_, देय_,
   {{0x3ead0044,0x3ebf9baa,0xcdcb21b6,0xddc900f4}},	//   mnet_, mout_, _اذان_, bješ,
   {{0x3ebf289c,0x661d035b,0x9f5c00ac,0xb4db0211}},	//   lout_, _adsk, havý_, _spàn,
   {{0xfbd1007c,0x3ead01f4,0xeb99002d,0xca7600af}},	//   _हरिम, onet_, _фий_, _жупы,
   {{0x3ead9bab,0x3ebf000c,0x75249bac,0x26c90207}},	//   nnet_, nout_, triz, glao_,
   {{0x660f9bad,0xe5a34a36,0x3ead5ed3,0x00000000}},	// [ae80] _deck, вити, inet_, --,
   {{0x75240291,0x67211851,0x3ebf9bae,0xfbd10b57}},	//   rriz, šlja, hout_, _हराम,
   {{0x3ebf02e9,0x3ead9baf,0x93c3002d,0x00000000}},	//   kout_, knet_, _ţări, --,
   {{0x75249bb0,0x3ebf00a2,0xd1ca1667,0xf77300a5}},	//   priz, jout_, олее_, _סקר_,
   {{0x3cfd006d,0x3ead9bb1,0x2ee6009e,0x00000000}},	//   _ntwv_, dnet_, _riof_, --,
   {{0x3ead9bb2,0x32e8027d,0xb5fb02d7,0x660f02b1}},	//   enet_, _eşya_, _anáh, _zeck,
   {{0xddc903fd,0x20b901c8,0x3ead9bb3,0x3ebf29df}},	//   vješ, чыць_, fnet_, fout_,
   {{0x3ebf9bb4,0x3ead0304,0x26c00036,0xd84300d5}},	//   gout_, gnet_, noio_, _krčí_,
   {{0x32069bb5,0xddc90124,0xe3b00831,0x00000000}},	//   mboy_, tješ, _করিব, --,
   {{0x3ead9bb6,0x00000000,0x00000000,0x00000000}},	//   anet_, --, --, --,
   {{0x3ebf2a5a,0xdddb9bb7,0xddc91942,0xda351482}},	//   bout_, rkuš, rješ, нены,
   {{0xcfa90180,0x32069bb8,0xdddb008b,0xf8bf2e38}},	//   _عالم_, nboy_, skuš, dréa_,
   {{0xddc90c21,0x26c007e5,0xdb0a01ff,0x3ce7023a}},	//   pješ, doio_, _nyfö, _finv_,
   {{0xf77304cd,0xb4b801c0,0x00000000,0x00000000}},	//   پاس_, ङको_, --, --,
   {{0x660f00ac,0xbc670919,0xcc334574,0x32060159}},	//   _peck, _زمين_, _شروع, kboy_,
   {{0x26c00036,0xe8d900e2,0x2a6902d7,0x8505028f}},	//   goio_, _trỏ_, _unab_, فورن,
   {{0x660f06d7,0x2d846fd1,0xf8ae00bf,0xd9e30ed1}},	// [ae90] _veck, nyme_, شکی_, _गणित_,
   {{0xdb18022a,0x26c90254,0x3ebf9bb9,0x3ead0b9b}},	//   _tyvä, slao_, zout_, znet_,
   {{0x3ead9bba,0x660f022a,0x9f5c00ac,0x00000000}},	//   ynet_, _teck, tavý_, --,
   {{0x661d054e,0xe29800d4,0x3ebf011e,0xd84300d5}},	//   _udsk, має_, xout_, _frčí_,
   {{0x61ed9bbb,0x291903ad,0x9f5c0187,0x3ead9bbc}},	//   žalo, nssa_, ravý_, vnet_,
   {{0x7ff50e3a,0x291903ad,0x3ebf9bbd,0xf53602b8}},	//   رستا, issa_, wout_, _אנשי_,
   {{0x3ead23c2,0xdbd6073c,0x752d01d7,0xa295093e}},	//   tnet_, _jääk, luaz, _заві,
   {{0x3ead3905,0x00000000,0x00000000,0x00000000}},	//   unet_, --, --, --,
   {{0xdbd603ad,0xc0cb709a,0x752d07e5,0xb5fb0079}},	//   _lääk, _дуже_, nuaz, _cnái,
   {{0x9b0532dc,0xeb990274,0x3ebf887d,0x00000000}},	//   нзод, зио_, sout_, --,
   {{0x3ead9bbe,0x291903ad,0x20075a3d,0x6ef50024}},	//   pnet_, essa_, mbni_, _iġbo,
   {{0x3d951eba,0xb5fb00d5,0xddc200ee,0x752d0065}},	//   _пиер, _unáh, _oboň, kuaz,
   {{0x96150083,0xf2d202b5,0x61fb0054,0x7e6b0118}},	//   িলাম_, טעט_, _mful, _ingp,
   {{0x752d778f,0xeb9905a1,0xdb18008c,0x00000000}},	//   duaz, _нил_, _syvå, --,
   {{0x26c00382,0xfbc6000c,0x2ca50093,0x29190086}},	//   toio_, _रुपम, mild_, assa_,
   {{0xe81c000c,0x764d0103,0x61fb030d,0x00000000}},	//   _भएका_, geay, _nful, --,
   {{0xd9de0033,0x26c09bbf,0xb4660183,0x00000000}},	// [aea0] _ভ্রম, roio_, нкал, --,
   {{0x64c60098,0x26c0539a,0x61fb018e,0x00000000}},	//   ريال, soio_, _aful, --,
   {{0x389b00c2,0xb2267ef0,0x7e6b0159,0x2d849bc0}},	//   _זיינ, емел, _ongp, zyme_,
   {{0x2ca59bc1,0xd84300d5,0x6aa69bc2,0x00000000}},	//   hild_, _trčí_, nikf, --,
   {{0xc1e70086,0x2ca515ed,0x752d027a,0xd8430097}},	//   ньше_, kild_, cuaz, _určí_,
   {{0x661610d6,0x7e6b6e51,0x32060088,0x59d30864}},	//   layk, _angp, sboy_, _सरसर,
   {{0xb5fb0082,0x44f60093,0x7ee6002d,0xce9402fb}},	//   _snái, _hæ_, нцие, какъ,
   {{0x661601a2,0x648000c3,0x433b016b,0x44f6008c}},	//   nayk, _töis, _מעלב, _kæ_,
   {{0x2900006d,0x2ca5908d,0x00000000,0x00000000}},	//   _ntia_, fild_, --, --,
   {{0x4f969bc3,0x253702b5,0x6ac90517,0x00000000}},	//   _преу, עניש_, रत्र, --,
   {{0xa3d623e3,0x29001442,0x3d10035d,0xab2703e6}},	//   ाइट_, _atia_, _दौरे_, ноќа_,
   {{0xdbd6007c,0x2d8402d7,0x84ea0066,0x00000000}},	//   _rääk, pyme_, _झंझट_, --,
   {{0x2ca59bc4,0x291900c3,0x00000000,0x00000000}},	//   bild_, ussa_, --, --,
   {{0x3a20027d,0xdbd600c3,0x672100fd,0x00000000}},	//   _edip_, _pääk, áljo, --,
   {{0x921055c7,0x764d02d7,0x69c09bc5,0x00000000}},	//   ाराज_, teay, ümer, --,
   {{0x752d01d3,0x7af70300,0x44f60093,0x67210478}},	//   tuaz, _éxta, _bæ_, šljo,
   {{0x65940089,0x29000453,0xd25100fd,0x00000000}},	// [aeb0] гату, _gtia_, یچر_, --,
   {{0x752d3681,0xa49b0211,0x9538002d,0x00000000}},	//   ruaz, _stòb, эзут_, --,
   {{0xe7870279,0x00000000,0x00000000,0x00000000}},	//   _чупо, --, --, --,
   {{0x78a70120,0x44f60093,0xe7fb0266,0x00000000}},	//   lijv, _fæ_, ्रका_, --,
   {{0x752d027a,0x69da0067,0xa2b207df,0x82340118}},	//   quaz, ęteg, _अदर्, ارما,
   {{0x8fa53b41,0x9992021e,0xb4ed021a,0xd1b829fe}},	//   кале, _deyň_, जदीप_, رانا_,
   {{0x7e6b012f,0xa3d40011,0xb88200b8,0x623500af}},	//   _pngp, _борч, _říka, _иеву,
   {{0x2ca57f1f,0x394900c3,0x92580409,0x61fb23f4}},	//   wild_, _opas_, _паст_, _uful,
   {{0x2d8b031b,0x39490221,0x00000000,0x00000000}},	//   áce_, _npas_, --, --,
   {{0x9d4405f5,0x4c8500d4,0x4433055c,0x61e600d5}},	//   ائين, тлов, ngx_, _úkla,
   {{0x39499bc6,0x2d8b9bc7,0x6aa69bc8,0x2900093b}},	//   _apas_, šce_, tikf, _stia_,
   {{0xfeb80082,0x60c39bc9,0xfaa61b81,0x628b0298}},	//   _كانت_, lonm, тамо, nkgo,
   {{0x827600c2,0x78a70031,0x6ad10033,0x394900f6}},	//   דערע_, fijv, _সংশো, _cpas_,
   {{0x6aa69bca,0x7d1b9bcb,0xd05a013b,0x00000000}},	//   sikf, msus, _bitə, --,
   {{0xe7370192,0x7d1b9bcc,0x7bca00e9,0x8cca0035}},	//   кер_, lsus, _gyfu, _सीटो,
   {{0xfbd0026e,0x61ed05e2,0x60c35b2e,0xddd90359}},	//   _اته_, žalj, honm, _pawň,
   {{0x66160a21,0x958308a6,0x7d1b9bcd,0x59de00dc}},	// [aec0] rayk, алте, nsus, नेशर,
   {{0x14c801ca,0x7d1b1130,0xf4840220,0x3f8700d5}},	//   رهای_, isus, داری, kynu_,
   {{0xddc20254,0x7d1b9bce,0x6d5c0228,0x00000000}},	//   _mnoš, hsus, ārai, --,
   {{0x7d1b9bcf,0xd36f004f,0x527504bf,0x6b7a0070}},	//   ksus, تهم_, лучу, ורענ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0430043,0xa3df0084,0x7d1b9bd0,0x399b1804}},	//   инчи, देह_, dsus, וינד,
   {{0x03a60210,0x4256291e,0x6aa40176,0x00000000}},	//   _риво, _итат, _omif, --,
   {{0x645c9bd1,0xc7b300a5,0x44389bd2,0xeea7005f}},	//   _hari, יבו_, _hcr_, ктык_,
   {{0x645c9bd3,0x7d1b149b,0xd1c70012,0xdd900957}},	//   _kari, gsus, _алте_, صود_,
   {{0xa3df1649,0x645e1bc5,0x9f98024e,0x44380176}},	//   देव_, ndpi, lším_, _jcr_,
   {{0x7d1b00b9,0x61480093,0x394905f0,0x5fb69bd4}},	//   asus, _félö, _spas_, _अखिल,
   {{0x645c923a,0xf8bd021a,0xc3330bed,0x2fd700bf}},	//   _lari, ोत्प, סור_, _شوند_,
   {{0x81e40b52,0x628008eb,0xf65300b5,0x8d7304cd}},	//   পুর_, _momo, یئر_, _ناوا,
   {{0x645c9bd5,0x62809bd6,0xdca31e5b,0x7bca0051}},	//   _nari, _lomo, _качи, _tyfu,
   {{0x9cd70122,0x78a79bd7,0x65660185,0xdbcc0093}},	//   _שווה_, rijv, _arkh, _góði,
   {{0x628000a1,0x9f98024e,0x60c3021e,0xeb7700a5}},	//   _nomo, jším_, zonm, _יעוץ_,
   {{0x645c5822,0x44389bd8,0x35f417d0,0x61ed01ba}},	// [aed0] _bari, _bcr_, рпур, žalk,
   {{0x7d1d9bd9,0x62809bda,0x1477211f,0x98a2560c}},	//   ássi, _aomo, خارج, tuką_,
   {{0x645c2873,0x44330034,0x69cd00d7,0x7aed9bdb}},	//   _dari, rgx_, _hyae, _kiat,
   {{0x7d029bdc,0x645c099e,0xf3649bdd,0x7aed0024}},	//   _otos, _eari, штун, _jiat,
   {{0x645c9bde,0x628074f0,0x7aed0332,0x62349bdf}},	//   _fari, _domo, _miat, речу,
   {{0x2ecb0517,0x765d6338,0x7aed9be0,0x1dc60066}},	//   ात्त, _hasy, _liat, _लड़त,
   {{0xa3df035d,0x7d029be1,0x60c3832d,0x62800a39}},	//   देश_, _atos, ronm, _fomo,
   {{0x7d1b0006,0x645c9be2,0x7aed0034,0x60c3965e}},	//   tsus, _zari, _niat, sonm,
   {{0x765d2c04,0x645c9be3,0x0e6200af,0xa5bb0176}},	//   _masy, _yari, скын, _acóz,
   {{0x645c01c2,0x765d0359,0x7d020079,0x6e22030d}},	//   _xari, _lasy, _dtos, _edob,
   {{0x7d1b9be4,0x62800027,0x7d020298,0xdfd111cf}},	//   ssus, _yomo, _etos, _ايا_,
   {{0x765d0c1f,0x7aed0211,0x7d1b00ab,0x00000000}},	//   _nasy, _ciat, psus, --,
   {{0x8c451761,0x7aed0614,0x22b8008b,0xe8f70823}},	//   _беле, _diat, nčka_, лля_,
   {{0x6d590034,0x7e7b0c0a,0x6e2212ad,0xddc2011c}},	//   _iswa, ljup, _zdob, _unoš,
   {{0x7aed9be5,0xb8dc018d,0x765d2505,0x7c2e002a}},	//   _fiat, _अद_, _basy, óbre,
   {{0x645c9be6,0x44239be7,0x7aed9be8,0x96950f99}},	//   _sari, _adj_, _giat, аруш,
   {{0x765d046a,0x645c9be9,0x9f9801c0,0x05661397}},	// [aee0] _dasy, _pari, vším_, ыван,
   {{0x62809bea,0x645c9beb,0x6d59002f,0x399b00a5}},	//   _somo, _qari, _mswa, _נייד,
   {{0x032610fe,0xe61f099e,0x00000000,0x00000000}},	//   уден, _clôs_, --, --,
   {{0xe29706a9,0x6d4b9bec,0xdce20484,0xa5bb0300}},	//   лах_, _opga, _proċ, _idón,
   {{0x645c9bed,0x9f980097,0x2167562d,0xa1583b21}},	//   _tari, rším_, лици_, талу_,
   {{0x645c9bee,0x443802d7,0xd00f0037,0xe8d90023}},	//   _uari, _ucr_, كله_, _trễ_,
   {{0x6d599bef,0xb4e00953,0x7d02004e,0x6d4b2686}},	//   _aswa, दगी_, _stos, _apga,
   {{0x44449bf0,0x62800036,0x7c3800d5,0x44231cb0}},	//   lf_, _uomo, _scvr, _zdj_,
   {{0x7aed8557,0x0caa0896,0x44443cb9,0xb5fb0097}},	//   _riat, етни_, of_, _znás,
   {{0x44441097,0x7aed9bf1,0x6d590b88,0x7c2301ed}},	//   nf_, _siat, _dswa, _cdnr,
   {{0x44449bf2,0x7aed9bf3,0x69cd012f,0x54770070}},	//   if_, _piat, _syae, אגיע_,
   {{0x6e2202dd,0x8c0c0033,0xf1b82821,0x20c90079}},	//   _udob, _শাওন_, _अशान, búis_,
   {{0x7aed8117,0xa80206d0,0x6da30e05,0x765d9bf4}},	//   _viat, ğınd, _лица, _rasy,
   {{0xa8020d6f,0x444404ce,0xdce21002,0x7aed0035}},	//   şınd, jf_, _kroč, _wiat,
   {{0xd6db3e10,0x765d6976,0x6d4000ae,0x7aed0088}},	//   ета_, _pasy, ltma, _tiat,
   {{0x7bd80470,0x61ed655d,0x44443e8f,0xb5fb01ef}},	//   _izvu, žali, ef_, _anár,
   {{0x44449bf5,0x1fe13e6d,0xf1a40035,0x999900c7}},	// [aef0] ff_, _पण्ड, _खेलन, resų_,
   {{0x78a5008a,0xdce20207,0x765d9bf6,0x00000000}},	//   _umhv, _oroč, _wasy, --,
   {{0x765d9bf7,0x3ea6764e,0x1cbb02b5,0xf36700d8}},	//   _tasy, _omot_, עמבע, ытан,
   {{0x44447ee9,0x9f5e01f7,0x6d4005aa,0x00000000}},	//   af_, _letó_, ktma, --,
   {{0x660d2b63,0xe1f800d8,0x6d409bf8,0x00000000}},	//   mbak, угі_, jtma, --,
   {{0x7bd800ac,0x3ea69bf9,0x752d00ac,0x660d02ce}},	//   _ozvu, _amot_, mraz, lbak,
   {{0x752d00d7,0xf8bf00a2,0x660d2206,0x1e952368}},	//   lraz, lués_, obak, ирир,
   {{0x660d06a2,0x752d1200,0xdce2023a,0xb5fb00d5}},	//   nbak, oraz, _droč, _znár,
   {{0x212b01a5,0xadf60066,0x7e7b00be,0x6d4008c8}},	//   _ích_, ीड़न_, rjup, gtma,
   {{0x3ea6022a,0x103500d1,0x0b4502c4,0x752d0042}},	//   _emot_, _خبرگ, анон, iraz,
   {{0xbb456e5f,0x752d01c0,0x76440095,0xdce202c4}},	//   шенк, hraz, yfiy, _groč,
   {{0x09e62294,0xfc3f000c,0x6d599bfa,0x752d9bfb}},	//   ионн, ří_, _tswa, kraz,
   {{0x89d60210,0x6d599bfc,0x752d18b0,0x6d400223}},	//   рінш, _uswa, jraz, ctma,
   {{0x752d9a57,0x6d5c013a,0x225f1be2,0xfd10026e}},	//   draz, ārat, _lauk_, _رجه_,
   {{0x752d0291,0x7d099bfd,0x444400fe,0x64920093}},	//   eraz, lpes, vf_, _bæin,
   {{0xfb2400d1,0xcf9202b5,0x4444001e,0x660d0f3a}},	//   _اروپ, קטן_, wf_, gbak,
   {{0xf8bf9bfe,0x752d9bff,0xa3e8258f,0x7d090421}},	// [af00] gués_, graz, मेन_, npes,
   {{0x44449c00,0x2a600221,0x225f008c,0xd90d042c}},	//   uf_, _haib_, _aauk_, _سیف_,
   {{0x44449c01,0x752d9c02,0x66fc01f2,0xd764042c}},	//   rf_, araz, _ičko, _انجی,
   {{0x752d2ab5,0xe210021a,0xd7bb0122,0xe246004f}},	//   braz, ारेण_, _יציר, شخصي,
   {{0x28db0f8a,0x752d0382,0x444401ae,0xdce200cd}},	//   _मीडि, craz, pf_, _sroč,
   {{0xdce20668,0x2a600221,0x394d0225,0x7e0e074f}},	//   _proč, _laib_, çesi_, सर्ग_,
   {{0x20c90037,0xd3720bdf,0x4fc60d6e,0x00000000}},	//   túir_, _ظهر_, јсла, --,
   {{0x6d409361,0x2a6002c2,0x629901ae,0xdce202c6}},	//   ttma, _naib_, chwo, _vroč,
   {{0x8c3c01d6,0x39400189,0x66fc156f,0xddc901d6}},	//   liği, _nqis_, _očko, rdeş,
   {{0xac985cfa,0x6721068b,0x5fa70efa,0x20c90079}},	//   اندا_, šlji, _केवल, súir_,
   {{0x752d0d5c,0x99920260,0x7d090f00,0x201c0471}},	//   zraz, _deyō_, apes, mavi_,
   {{0x201c665c,0x2a6014c4,0x66fc0355,0x752d9c03}},	//   lavi_, _caib_, _ačko, yraz,
   {{0x2a60006d,0x14c6021a,0xf8bf00b5,0x0e9b076b}},	//   _daib_, ववाण, nség_, _בשאל,
   {{0xda07045c,0x8d850609,0xb5fb0279,0x752d193b}},	//   _व्रत_, _دشمن, _anáp, vraz,
   {{0x2a60006f,0x62980029,0x23a50035,0x00000000}},	//   _faib_, īvoj, _गेंद, --,
   {{0x35f59c04,0x8c3c0723,0xf8bf00f7,0xeb9700a5}},	//   спар, diği, tués_, _כדור_,
   {{0x201c03c9,0x95cb9c05,0x752d0036,0x6ef50409}},	// [af10] kavi_, тува_, uraz, _išbe,
   {{0x201c068b,0x752d0505,0xf367949f,0x7af8006d}},	//   javi_, rraz, итен, _kuvt,
   {{0xa8560122,0x201c01d6,0x225f33d6,0x93270118}},	//   _היתה_, davi_, _pauk_, شران,
   {{0x752d9c06,0x2a600189,0xb4db0176,0x6235052c}},	//   praz, _xaib_, _apàt, седу,
   {{0xf8bf9c07,0x386100ee,0xddd9021e,0x00000000}},	//   qués_, _kahr_, _pawō, --,
   {{0x386102c9,0x77f50084,0x62992b28,0x201c0e5e}},	//   _jahr_, _आलोक_, shwo, gavi_,
   {{0xb3e500c8,0xe3e500c8,0x33950037,0x2bc60066}},	//   _প্রজ, _প্রব, _الأز, _रुला,
   {{0x02a49c08,0x945400a8,0x57b800a5,0x62340384}},	//   _друм, _çərş, ילוב_, _месу,
   {{0x201c2802,0x2a60012f,0xa2c4364c,0x59d30066}},	//   bavi_, _raib_, िकर्, _सरगर,
   {{0x2a6001a9,0x0dc803fa,0x201c9c09,0xec799c0a}},	//   _saib_, јући_, cavi_, упо_,
   {{0x7d099c0b,0x1fa77f32,0x2a600221,0xaffa016b}},	//   spes, _траг, _paib_, _תּמי,
   {{0x7d094f61,0x2a60006f,0xdb1e00b8,0xc33200a5}},	//   ppes, _qaib_, íván, הוט_,
   {{0xddc90470,0x3ead9c0c,0xa49b0392,0x290d002d}},	//   ljež, miet_, _atòm, ţean_,
   {{0x3ead9c0d,0xe73a9c0e,0xdd8e0037,0xa3e800b4}},	//   liet_, лег_, _سوى_, मेड_,
   {{0xd62a3c60,0x2a60104e,0xf8bf006c,0x38610024}},	//   лове_, _taib_, zség_, _dahr_,
   {{0x3ead9c0f,0x62980080,0x201c9c10,0xa3cb0066}},	//   niet_, īvok, zavi_, _लड़_,
   {{0x201c0107,0x98a600c3,0x38610110,0x20ca0099}},	// [af20] yavi_, _гипе, _fahr_, ाकमध,
   {{0xb97b0122,0x3ead9c11,0x8c3c027d,0x2d9f0065}},	//   _עניי, hiet_, tiği, izue_,
   {{0x8c1a0122,0xa2c40963,0x3ead9c12,0x00000000}},	//   רועי, िकल्, kiet_, --,
   {{0x3ead2251,0xf8bf006c,0x8c3c027d,0x490f0761}},	//   jiet_, tség_, riği, तीको_,
   {{0x3ead9c13,0x724300f8,0x00000000,0x00000000}},	//   diet_, سپول, --, --,
   {{0x2eb209a8,0x04960037,0x2ef900d5,0x31660055}},	//   ुक्त, _السح, _čsfr_, rvoz_,
   {{0x201c502c,0xf8bf006c,0x321d0035,0xf99f027a}},	//   ravi_, sség_, bawy_, zzè_,
   {{0x25ad1851,0xe2976350,0x3ead53a2,0x93b700a5}},	//   _želi_, _лас_, giet_, _הללו_,
   {{0x25a02f80,0x41dc00ab,0x201c030a,0x2b4e0183}},	//   nzil_, _बरिस, pavi_, _spfc_,
   {{0xddc90207,0x00000000,0x00000000,0x00000000}},	//   bjež, --, --, --,
   {{0x3ead9c14,0xf8bf00f7,0x547b0070,0x2cac9c15}},	//   biet_, nsée_, אטיו, ridd_,
   {{0x59aa0e1d,0x3ead9c16,0xf8bf000d,0x38610345}},	//   _चेहर, ciet_, isée_, _sahr_,
   {{0xa3e805b7,0x00000000,0x00000000,0x00000000}},	//   मेत_, --, --, --,
   {{0x321d0035,0xf99f0036,0xa49b009e,0x00000000}},	//   zawy_, rzè_, _ptòm, --,
   {{0x25a0011e,0x2bcf0b35,0x212400f6,0x48a81f7c}},	//   ezil_, _सुपा, _lvmh_, стям_,
   {{0x3861033b,0xab8302c4,0x9f4d00a2,0xa3be00ab}},	//   _wahr_, _хушк, înée_, ुअन_,
   {{0x94193cc0,0x7d040211,0x7c3a0051,0x00000000}},	// [af30] ижат_, _éisd, ogtr, --,
   {{0x7c3a9c17,0x7e629c18,0x3ead00ea,0x00000000}},	//   ngtr, _laop, ziet_, --,
   {{0xd3710514,0x321d004e,0x24980160,0x96b800b4}},	//   بها_, tawy_, _dlrm_, ्कशॉ,
   {{0x7e629c19,0x95cb027f,0xddc9025c,0x6aaf011e}},	//   _naop, _буга_, vjež, nicf,
   {{0x2bcf9c1a,0x763a02b5,0x321d0035,0x61f800a0}},	//   _सुना, _דערג, rawy_, _šalá,
   {{0xa0691c56,0x29090054,0x67213b64,0xb444002d}},	//   рака_, _mtaa_, šlju, _нэск,
   {{0x3ead9c1b,0x7e62055c,0x00000000,0x00000000}},	//   tiet_, _baop, --, --,
   {{0x64579c1c,0x7e620211,0x00000000,0x00000000}},	//   lexi, _caop, --, --,
   {{0x3ead46cb,0x0c79021f,0xa28200b5,0x8d5501e0}},	//   riet_, асны_, _تینو, ітич,
   {{0x6457095e,0x3ead9c1d,0x4b250847,0x6ad2112b}},	//   nexi, siet_, омов, सत्र,
   {{0x3ead9c1e,0xa49b0107,0x3f67011c,0x29090103}},	//   piet_, _atòk, _uđu_, _ataa_,
   {{0x28d20035,0x39ea0142,0xe8d900cc,0x00000000}},	//   _दीजि, идно_, _trớ_, --,
   {{0x6abd0453,0x224d01cb,0x67250523,0x00000000}},	//   érfa, _mbek_, _avhj, --,
   {{0x64b805f7,0xf8bf175d,0xfc461dab,0x7e625ba2}},	//   _आदेश, ysée_, čích_, _zaop,
   {{0x7c64006c,0x378703e6,0x29096b23,0xaa462725}},	//   _راول, обро_, _etaa_, _дейл,
   {{0x6e3b4381,0x29090107,0x224d0065,0x316d00af}},	//   ngub, _ftaa_, _nbek_, _orez_,
   {{0x34aa0274,0xda7b00a5,0x00000000,0x00000000}},	// [af40] авао_, _כנקר, --, --,
   {{0xe3b25b16,0x61e60355,0x224d01ed,0x142601e0}},	//   ورا_, _úkli, _abek_, ідем,
   {{0x2bcf00a1,0xe1fa03fa,0xf8c600b4,0xa5bb02d7}},	//   _सुमा, аге_, लकीप, _neóf,
   {{0x316d108a,0x366a03fa,0xf8bf1f96,0x200598b2}},	//   _brez_, _тамо_, rsée_, _afli_,
   {{0xf8bf0248,0x60ca0afc,0x316d0139,0x00000000}},	//   ssée_, tofm, _crez_, --,
   {{0x7e629c1f,0x2bcf0325,0xdc4500c7,0x75246de5}},	//   _saop, _सुभा, _būči, msiz,
   {{0x6fb30118,0xd2590107,0x644e009f,0x75240471}},	//   ومها, _djņb_, _ibbi, lsiz,
   {{0x442a0069,0x6e3b9c20,0x656900f4,0x00000000}},	//   _hdb_, ggub, _šehi, --,
   {{0x442a422c,0x75248146,0x316d00f6,0x00000000}},	//   _kdb_, nsiz, _grez_, --,
   {{0x62820086,0x7524773b,0x00000000,0x00000000}},	//   ljoo, isiz, --, --,
   {{0x442a00a8,0xc3fb0070,0x0eba010b,0x644e0118}},	//   _mdb_, יליש, _куды_, _mbbi,
   {{0x6282073a,0x75242a48,0x442a29dc,0x00000000}},	//   njoo, ksiz, _ldb_, --,
   {{0x6e209c21,0x644e07e5,0x6ef5010b,0xa2b20355}},	//   mamb, _obbi, _išba, _आगन्,
   {{0x6e2080e0,0x6aaf0051,0x75249c22,0x442a007e}},	//   lamb, sicf, dsiz, _ndb_,
   {{0x58d419fa,0x00000000,0x00000000,0x00000000}},	//   форт, --, --, --,
   {{0x6e203152,0x644e9c23,0x8ca600b4,0x3d000260}},	//   namb, _abbi, टोरो, _kòw_,
   {{0x64570391,0x442a9c24,0x6e200054,0x7a4400b5}},	// [af50] texi, _bdb_, iamb, sító,
   {{0x6e209c25,0xd5b81958,0xc9540317,0x66040027}},	//   hamb, іст_, _חמץ_, acik,
   {{0x6e2044fa,0xd37b00d8,0xf1b90009,0x316d02c4}},	//   kamb, шча_, _meše_, _srez_,
   {{0x442a0a8c,0x6e2028f7,0x644e018e,0x7179081b}},	//   _edb_, jamb, _ebbi, йбер_,
   {{0x661d2686,0xc61700c0,0xd0091676,0x21690f68}},	//   _iesk, तरीय_, беле_, сили_,
   {{0xa5bb0037,0x80a801e0,0x00000000,0x00000000}},	//   _ndói, овів_, --, --,
   {{0x661d9c26,0x442134c7,0x00000000,0x00000000}},	//   _kesk, mah_, --, --,
   {{0x44210464,0x6e209c27,0xa5bb9c28,0x661d9c29}},	//   lah_, gamb, _adói, _jesk,
   {{0x661d9c2a,0x2d8b02e1,0xf1b900cd,0x316d4445}},	//   _mesk, âce_, _beše_, _urez_,
   {{0x4421402e,0xa3e801d1,0x6aad0b55,0x23bf02cb}},	//   nah_, मेव_, _amaf, _एखाद,
   {{0x44219c2b,0x6e205c23,0xfa6a34a2,0x39520298}},	//   iah_, bamb, банк_, _spys_,
   {{0x44219c2c,0x661d9c2d,0x6e2033c4,0xa5bb1dad}},	//   hah_, _nesk, camb, _geóg,
   {{0x44211221,0x66fc02c4,0xed5801e0,0x00000000}},	//   kah_, _ički, _мої_, --,
   {{0x20cb00c0,0xf8bf7c6e,0x45090083,0x2bc60324}},	//   िविध, drés_, _লিংক_, _रुका,
   {{0x66e69c2e,0x44210464,0x661d9c2f,0x96969c30}},	//   зова, dah_, _besk, праш,
   {{0x661d9c31,0x752400c1,0x7bc301f7,0xa5bb0042}},	//   _cesk, tsiz, _ixnu, _xeóg,
   {{0x2bcf065a,0x442126fb,0xf8bf34fc,0x442a01d1}},	// [af60] _सुता, fah_, grés_, _pdb_,
   {{0x44212b63,0x660449d1,0x7c212aab,0x7524037a}},	//   gah_, scik, nalr, rsiz,
   {{0x6e209c32,0x0af90033,0x442a2652,0x656f016e}},	//   yamb, _আবুল_, _vdb_, _erch,
   {{0x661d250a,0x6e200183,0x75240381,0x7c2102b1}},	//   _gesk, xamb, psiz, halr,
   {{0x44219c33,0x7c211ae5,0x22b8008b,0x6282136b}},	//   bah_, kalr, nčki_, rjoo,
   {{0x442180fc,0x6e202f38,0x10a31169,0x66fc0009}},	//   cah_, wamb, ничн, _ački,
   {{0x6e209c34,0xb4d8020c,0x7ae49c35,0xf1b902c4}},	//   tamb, ाती_, _ohit, _reše_,
   {{0x2bcf0fcf,0x3da602ce,0x629b005f,0x62890069}},	//   _सुधा, зроб, _gluo, _goeo,
   {{0x6e209c36,0x81d30033,0x22b8008b,0xa3e83b29}},	//   ramb, হেব_, jčki_, मेर_,
   {{0x6e2099c5,0x7ae408bd,0xc19b0d85,0x7af60260}},	//   samb, _ahit, _השמי, _aiyt,
   {{0x6e20000e,0x7ae4004a,0x69c80381,0x201e01ef}},	//   pamb, _bhit, şdel, _ieti_,
   {{0x7ae49c37,0x44219c38,0x201e5e13,0xcfa9186e}},	//   _chit, zah_, _heti_, _ظالم_,
   {{0x44210ce8,0xa3d30311,0x661d02e9,0x7ae400f1}},	//   yah_, _हुन_, _resk, _dhit,
   {{0x7ae40006,0x201e028b,0x7c2157f4,0xf8bf00f7}},	//   _ehit, _jeti_, calr, vrés_,
   {{0x44219c39,0xc7c40e60,0x661d9c3a,0x7ae49c3b}},	//   vah_, ести, _pesk, _fhit,
   {{0xddc20e6a,0x44212bab,0x201e9c3c,0xf8bf2b9f}},	//   _množ, wah_, _leti_, trés_,
   {{0x442161f5,0x661d7480,0xd8cb002d,0xa2c00ea3}},	// [af70] tah_, _vesk, _гынд_, लचन्,
   {{0x656f053d,0x661d6f1a,0xf8bf2226,0x201e5c9d}},	//   _vrch, _wesk, rrés_, _neti_,
   {{0x44210464,0x6abd9c3d,0x661d9c3e,0xd6d1004f}},	//   rah_, onsf, _tesk, _لقد_,
   {{0xb184024e,0xf8bf01f7,0x00000000,0x00000000}},	//   _šťas, prés_, --, --,
   {{0x44219c3f,0x201e06a2,0x656f9c40,0xf19400d4}},	//   pah_, _beti_, _urch, ниць,
   {{0x44210ac8,0xe7e40437,0x00000000,0x00000000}},	//   qah_, _गरमा_, --, --,
   {{0x201e0038,0x7c219c41,0x00000000,0x00000000}},	//   _deti_, valr, --, --,
   {{0x2d95386a,0x00000000,0x00000000,0x00000000}},	//   дрос, --, --, --,
   {{0x313409d0,0x4c3501c8,0x62980029,0x7c219c42}},	//   _петр, мэнт, īvot, talr,
   {{0x7ae49c43,0x201e008a,0x2d8300f4,0x00000000}},	//   _shit, _geti_, ćje_, --,
   {{0x7ae40211,0x60c40037,0x7fb900f8,0xb0ca00ab}},	//   _phit, éime, _بهار_, ाकरग,
   {{0x201e0009,0x00000000,0x00000000,0x00000000}},	//   _zeti_, --, --, --,
   {{0x8c452462,0xd6c50033,0x7c298de1,0x7e6900cc}},	//   _желе, ্ষায, _долг_, mdep,
   {{0x7ae40122,0x7e6936a2,0x6d499c44,0x22b808b7}},	//   _whit, ldep, mtea, rčki_,
   {{0x6d49148b,0x61fb9c45,0x7ae49c46,0x1a6600fd}},	//   ltea, _ogul, _thit, _قیدی_,
   {{0xe8d90028,0x7e691b06,0x61fb9c47,0x7ae49c48}},	//   _trở_, ndep, _ngul, _uhit,
   {{0x6aca00b4,0x17fa0037,0x00000000,0x00000000}},	// [af80] रवीर, _وردة_, --, --,
   {{0xb4d82135,0x6d490094,0xb93702b5,0x61fb9c49}},	//   ाते_, itea, _קריג_, _agul,
   {{0xe8140429,0xa3e81db6,0x201e9c4a,0x04431858}},	//   _त्या_, में_, _reti_, техн,
   {{0x673c2163,0x201e9c4b,0xe0cf0594,0xf506081b}},	//   murj, _seti_, یزو_, _озмо,
   {{0x201e9c4c,0xba4800d8,0x7e69035f,0x662900b8}},	//   _peti_, _grįž, ddep, řský,
   {{0xd00f317b,0x6d49004f,0x61fb001c,0x2bc60354}},	//   لله_, dtea, _egul, _रुझा,
   {{0x201e9c4d,0x6d49139c,0x321f0107,0xe29a208b}},	//   _veti_, etea, _feuy_, _дав_,
   {{0x61fb0273,0x6d494885,0x3a20009e,0x00000000}},	//   _ggul, ftea, _neip_, --,
   {{0x1ee80332,0x6d490037,0x63ae010b,0x6abd0a8a}},	//   _ہوئی_, gtea, žinė, vnsf,
   {{0xe57102b5,0x2bcf3e9e,0x00e30043,0x00000000}},	//   אַט_, _सुहा, _ажун, --,
   {{0x764d01d6,0x6d499c4e,0xaab500d8,0x8f75010b}},	//   yfay, atea, ейні, _пуці,
   {{0x3a200443,0x3d1908a9,0x29009c4f,0xbb9300c3}},	//   _ceip_, _मौके_, _buia_, тающ,
   {{0x6d498c24,0x1de20a40,0xdd9202fd,0x2900021d}},	//   ctea, _परित, _جوش_, _cuia_,
   {{0xfb19006c,0x29000392,0xb4d84f13,0x2bcf052b}},	//   _کروں_, _duia_, ातो_, _सुवा,
   {{0xeaf80416,0x368b0dfc,0x67d4737f,0xf1b902f6}},	//   ثریت_, осан_, вору, _meša_,
   {{0x1de200be,0xdce20009,0x70ca04aa,0xdddb011c}},	//   _परात, _broć, ाकुल, ljuš,
   {{0x29009c50,0xd7fb0132,0x7d0d0031,0x36d40dba}},	// [af90] _guia_, _мун_, _çast, тотр,
   {{0x2a6930bc,0xdddb00cd,0x6ee501ef,0x656d9c51}},	//   _haab_, njuš, móbe, rvah,
   {{0x5fae0302,0x656d3115,0x6d4906a2,0x08760070}},	//   _झेलल, svah, ztea, _װערט_,
   {{0x4ed00033,0x99920107,0x02c90099,0x00000000}},	//   াগুল, _deyņ_, िकेन, --,
   {{0x7e6901ba,0x6d491005,0xa3b49c52,0x00000000}},	//   vdep, xtea, _जेठ_, --,
   {{0x04c901cb,0xfc4e00e2,0x00000000,0x00000000}},	//   _روزي_, _sửng_, --, --,
   {{0xff5118dd,0x7bd803c1,0xf1b90207,0x00000000}},	//   اخت_, _nyvu, _deša_, --,
   {{0x2a69006d,0xfbcf0026,0xcee80079,0x6d4906c7}},	//   _naab_, _सुषम, ورين_, ttea,
   {{0x7e697e05,0xee36005f,0x78b502c4,0x00000000}},	//   rdep, хны_, kizv, --,
   {{0x6d499c53,0x317841bd,0x7e690968,0x3a20256a}},	//   rtea, _تحفظ_, sdep, _seip_,
   {{0x6d4911be,0x2a69012f,0x7e6901f7,0x7a6a0adb}},	//   stea, _baab_, pdep, пинг_,
   {{0x9cea00f5,0x6d499c54,0x00000000,0x00000000}},	//   _ہونے_, ptea, --, --,
   {{0x2900012f,0xfbcf0808,0x00000000,0x00000000}},	//   _quia_, _सुरम, --, --,
   {{0x6f0100b5,0x673c9c55,0x2a6901ed,0xddd90260}},	//   _kulc, turj, _eaab_, _pawņ,
   {{0x3a209c56,0x7bd8010b,0xc5f80253,0xc1dc09b4}},	//   _teip_, _gyvu, ंख्य_, _बर्ग,
   {{0xb4d89c57,0x3ebf03ad,0xdce20c0a,0x290001ef}},	//   ात्_, nnut_, _proć, _tuia_,
   {{0x69c101d6,0xe5a30374,0x3ebf0328,0xcdac016b}},	// [afa0] şler, гити, inut_, ֿיבֿ,
   {{0x03a62217,0x3ebf0168,0x629919c1,0xa3be00b4}},	//   низо, hnut_, ekwo, ुअल_,
   {{0xdce902c6,0x3ebf9c58,0xf48401df,0xcb12016b}},	//   jveč, knut_, _یاسی, ָלד_,
   {{0x2a69006d,0xe8140380,0x26c29c59,0xa6839c5a}},	//   _xaab_, _त्ता_, _ujko_, _блюд,
   {{0x3ebf02b2,0x26d20b4f,0x26c09c5b,0x00000000}},	//   dnut_, moyo_, mnio_, --,
   {{0x74160105,0x26c0010b,0x232a0352,0x2ee60031}},	//   _سورا, lnio_, _ноги_, _shof_,
   {{0x645e9c5c,0x6f019c5d,0x82a600d4,0x2bcf252c}},	//   mepi, _culc, _завж, _सुला,
   {{0x6f01412e,0x645e9c5e,0x26c01de2,0x3ebf0254}},	//   _dulc, lepi, nnio_, gnut_,
   {{0x8ffa0df3,0x2a691789,0x26c09c5f,0x76460298}},	//   _فرار_, _raab_, inio_, _mcky,
   {{0x2a699c60,0x645e9c61,0xa3e70084,0xc5f302b5}},	//   _saab_, nepi, _परम_, נדז_,
   {{0x2a69006d,0x34b7011d,0xdb1c0225,0x00000000}},	//   _paab_, תפים_, _özür, --,
   {{0x2a69006d,0x6ee59c62,0xa3d30722,0x645e9c63}},	//   _qaab_, tóbe, _हँस_, hepi,
   {{0x26c0004e,0x6f0102c4,0x26d200f8,0x00000000}},	//   dnio_, _zulc, doyo_, --,
   {{0x645e24e4,0x7c660312,0x26c09c64,0x3b540328}},	//   jepi, _ساتل, enio_, _аккр,
   {{0x645e9c65,0x6566008c,0x26c04c98,0x67d562a2}},	//   depi, _askh, fnio_, тову,
   {{0xa3e7009a,0xd6d89c66,0x7bdb02b8,0x7d029c67}},	//   _परब_, ету_, _מקוו, _kuos,
   {{0x7d02021f,0xa802027b,0x35f5021d,0x00000000}},	// [afb0] _juos, ğırd, тпар, --,
   {{0x64a40202,0x7d02034d,0x03c7002d,0x3ebf0124}},	//   гађа, _muos, нсем, znut_,
   {{0x69d50099,0x26d27c26,0x00000000,0x00000000}},	//   _युती, boyo_, --, --,
   {{0x46a50e96,0x26d29c68,0x26c00176,0x00000000}},	//   _ऐतिह, coyo_, cnio_, --,
   {{0x7d0201c8,0x62991e65,0x645e005f,0x463a016b}},	//   _nuos, rkwo, bepi, _קעשע,
   {{0x6f019c69,0xf4240831,0x00000000,0x00000000}},	//   _pulc, _পাথর_, --, --,
   {{0x6e2201ae,0xb4bf018d,0x6f010036,0x33580c8a}},	//   _beob, ुकी_, _qulc, _парэ_,
   {{0x44239c6a,0x6f011bc0,0x44310c21,0x7d0260cc}},	//   _hej_, _vulc, _hdz_, _buos,
   {{0x50f5431b,0x6e2239e7,0xdce93977,0xc05b00d4}},	//   _азат, _deob, sveč, _ніж_,
   {{0xeb992c49,0x442349d3,0x1fa70610,0x26c09c6b}},	//   дио_, _jej_, _прег, znio_,
   {{0x44239c6c,0xfaa66cb0,0x3ebf9c6d,0x443102d7}},	//   _mej_, вано, pnut_, _mdz_,
   {{0x645e004e,0x4423006f,0x2ecc44d2,0x5a962519}},	//   zepi, _lej_, ावृत, троф,
   {{0x645501cc,0x81d30083,0x645e9c6e,0xc95500af}},	//   _obzi, হের_, yepi, лтры,
   {{0x44239c6f,0x26d20273,0xf1b90124,0xe8f72aeb}},	//   _nej_, woyo_, _lešo_, кля_,
   {{0x26c0004e,0x645e4f8a,0x25a9021d,0x00000000}},	//   tnio_, vepi, ezal_, --,
   {{0x7c233e48,0x7e6b0345,0x25bf00d5,0x645502b1}},	//   _henr, _jagp, _žula_, _abzi,
   {{0x7e6b6854,0x26d29c70,0x442300da,0x645e9c71}},	// [afc0] _magp, royo_, _bej_, tepi,
   {{0x26c03262,0x7e6b08dd,0x6d5908c7,0x2912007b}},	//   snio_, _lagp, _mpwa, _itya_,
   {{0x442301a9,0x645e9c72,0x7c23046a,0x28db0e04}},	//   _dej_, repi, _menr, _मीटि,
   {{0xe2971897,0x7e6b12d7,0x7c230159,0x6d590fdb}},	//   ках_, _nagp, _lenr, _opwa,
   {{0x6e220392,0x443101b7,0x00000000,0x00000000}},	//   _reob, _fdz_, --, --,
   {{0x6e22042a,0x44239c73,0x212d02c6,0x7644027d}},	//   _seob, _gej_, _dveh_, lgiy,
   {{0x7d0203ad,0xb17d016f,0x7e6b9c74,0x6d59021e}},	//   _suos, _vzťa, _bagp, _apwa,
   {{0x7644070b,0xa3e79c75,0x44449c76,0x4423006f}},	//   ngiy, _परत_, lg_, _zej_,
   {{0x44449c77,0x9cca005f,0x7e6b9c78,0x4423006d}},	//   og_, дына_, _dagp, _yej_,
   {{0x7d0203ad,0x7c2302d4,0x00000000,0x00000000}},	//   _vuos, _cenr, --, --,
   {{0xdeef26cb,0x44449c79,0xeb970370,0x765f01f4}},	//   _вы_, ig_, виќ_, yeqy,
   {{0x7d020086,0x656401d5,0x13b50033,0x7c230afc}},	//   _tuos, kwih, _জুড়, _eenr,
   {{0xf2d300c2,0x7e609c7a,0x20b6018d,0x00000000}},	//   שער_, memp, _अगाध, --,
   {{0x7c239c7b,0x6d4048fc,0x44440a75,0x00000000}},	//   _genr, muma, jg_, --,
   {{0x6d400669,0x87040133,0x44232af4,0xb8cb0907}},	//   luma, ияте, _rej_, _खत_,
   {{0x44449c7c,0x7c289c7d,0x7e609c7e,0x44239c7f}},	//   eg_, ladr, nemp, _sej_,
   {{0x4423006f,0x4431013a,0x00000000,0x00000000}},	// [afd0] _pej_, _pdz_, --, --,
   {{0x44443bd1,0x64bf04bc,0x34bf111a,0x4423006d}},	//   gg_, ्वेश, ्वेद, _qej_,
   {{0x6d409c80,0x4423054e,0x3cfc0036,0xf1b90168}},	//   huma, _vej_, _mivv_, _pešo_,
   {{0x44449c81,0x1de25c40,0x7e609c82,0x7c289c83}},	//   ag_, _परंत, jemp, hadr,
   {{0xdd861b15,0x05848f61,0x44239c84,0x6d409c85}},	//   _او_, _курм, _tej_, juma,
   {{0x7c28016f,0x6d409c86,0xe8d900e2,0xc0c80274}},	//   jadr, duma, _trổ_, кује_,
   {{0x7e6b132a,0xa3e79c87,0x752d325f,0xc4d20317}},	//   _pagp, _परि_, lsaz, _הגם_,
   {{0x660d0182,0x7e60128f,0x6d409c88,0x929400d8}},	//   ncak, gemp, fuma, _касц,
   {{0x6d409c89,0x752d9c8a,0x7c23016e,0x41b70026}},	//   guma, nsaz, _penr, _अधिस,
   {{0x64459c8b,0x7c280987,0xa3e7035d,0x4c850c90}},	//   nghi, gadr, _परा_, улов,
   {{0x64450014,0x7e6b9c8c,0x7c239c8d,0xeb9920c3}},	//   ighi, _tagp, _venr, хин_,
   {{0xc8690bed,0x6d409c8e,0x38a6053e,0x7c230b88}},	//   _מן_, buma, _môre_, _wenr,
   {{0x6d409c8f,0xf2d20319,0x7c2311ef,0x7bca081d}},	//   cuma, מעט_, _tenr, _exfu,
   {{0x7c289c90,0x91ba0122,0xb4bf000c,0xa5bb0042}},	//   cadr, תמשי, ुको_, _peón,
   {{0xb8dc00fa,0x07a39c91,0xc795010b,0x00000000}},	//   _आग_, барн, арты, --,
   {{0x44440189,0x6b9c01b4,0x64450036,0xa49b1da5}},	//   wg_, ørge, eghi, _quòn,
   {{0x44440210,0x6aa40054,0x7644027b,0x29120371}},	// [afe0] tg_, _ilif, rgiy, _utya_,
   {{0x444401a9,0x7e609c92,0x6445027a,0x00000000}},	//   ug_, zemp, gghi, --,
   {{0x7e600f15,0x6d409c93,0xe29a3240,0xd62a01d3}},	//   yemp, zuma, наж_, _поне_,
   {{0x4444004a,0x6d409c94,0xddc20009,0x7e609c95}},	//   sg_, yuma, _laoš, xemp,
   {{0x7c2800e7,0x39428721,0x7d090031,0xa3e8046c}},	//   yadr, nuks_, jqes, मेज_,
   {{0xc95300a5,0x6aa400e9,0x6d409c96,0x7e60018e}},	//   צמו_, _llif, vuma, wemp,
   {{0x6aa49c97,0x7c281b2a,0x3942361b,0x00000000}},	//   _olif, vadr, huks_, --,
   {{0x1d34392c,0x3942007c,0x60c3004f,0x98a90009}},	//   ания, kuks_, annm, _rvač_,
   {{0x7e609c98,0x628054cf,0x2293004f,0x91e300d4}},	//   remp, _inmo, _القس, _готе,
   {{0x6d409c99,0x7e609c9a,0x6aa43eb0,0xfc4600b8}},	//   ruma, semp, _alif, _číst_,
   {{0x7e60028b,0x6aa40523,0xf8bf00fd,0x00000000}},	//   pemp, _blif, ssék_, --,
   {{0x7c286cc3,0x22469c9b,0x6d400328,0x0dca20c3}},	//   sadr, ngok_, puma, _пули_,
   {{0x7c289c9c,0x8d731c2d,0x2f0a009e,0xdebb016b}},	//   padr, _هاوا, _hùg_, _אמאל,
   {{0x6aa49c9d,0x2a6d01c0,0x01d10033,0x00000000}},	//   _elif, žeb_, ়েকদ, --,
   {{0x62809c9e,0xa3b419b7,0x81b80083,0xe7849c9f}},	//   _onmo, _जेल_, _ঘুম_, буто,
   {{0x7d0d004f,0xa61507e5,0xddc200cd,0xb4bf0efa}},	//   _éasc, рмач, _zaoš, ुक्_,
   {{0x660d9ca0,0x7aed9ca1,0xa5bb014c,0x44b50f27}},	// [aff0] rcak, _ihat, _geól, абас,
   {{0x752d36c1,0x68fe011e,0x6445009e,0x62809ca2}},	//   rsaz, _gipd, ughi, _anmo,
   {{0x7aed9ca3,0x64459ca4,0x752d9ca5,0xb4b50437}},	//   _khat, rghi, ssaz, _जगी_,
   {{0x224600d7,0x7d090055,0x00000000,0x00000000}},	//   ggok_, yqes, --, --,
   {{0x7aed9ca6,0x7aff01f4,0x21690b90,0xa5bb0042}},	//   _mhat, _miqt, тили_, _xeól,
   {{0xf4870402,0x2edd01d1,0x22460065,0x00000000}},	//   _сумн, मत्त, agok_, --,
   {{0x7aed9ca7,0xb4e1162b,0x04c8026e,0x00000000}},	//   _ohat, दती_, _صوفي_, --,
   {{0x8d550086,0xed5903e6,0x7aed0023,0x00000000}},	//   аточ, вои_, _nhat, --,
   {{0x776701e8,0x31580037,0x98a20067,0x00000000}},	//   hwjx, _مجلة_, lską_, --,
   {{0x7aed9ca8,0x61e9013a,0xc1b80112,0x7d090055}},	//   _ahat, _izel, _слух_, rqes,
   {{0x2bcf55c7,0xfbcf060a,0x7aed09bb,0x6a8607c1}},	//   _सुखा, _सुखम, _bhat, ална,
   {{0x7f4301d3,0x3942007c,0x00000000,0x00000000}},	//   munq, tuks_, --, --,
   {{0x7aed00bf,0x7f4302fb,0x787c0523,0x00000000}},	//   _dhat, lunq, _nåvä, --,
   {{0x8c420352,0x7ebe4df2,0x39429ca9,0x8f0001e0}},	//   _деше, rūpe, ruks_, цiї_,
   {{0x4cba0122,0x7aed0014,0xd62a9caa,0x394200ab}},	//   _במסג, _fhat, кове_, suks_,
   {{0x7aed9cab,0xa5bb2cad,0x3942007c,0x6aa4002f}},	//   _ghat, _teól, puks_, _ulif,

   {{0xe9df0391,0x68fe7b9b,0x942600c3,0x61e904fb}},	// [b000] lgún_, _tipd, имае, _nzel,
   {{0xc4834406,0xf65f008c,0xaa7b00ac,0x6ef50409}},	//   олук, _hjæl_, plýc, _išbu,
   {{0xa3d3006a,0xe9df09ab,0x1459004b,0xadff0084}},	//   _हुआ_, ngún_, ышты_, _उलझन_,
   {{0x5b560070,0x00000000,0x00000000,0x00000000}},	//   ישען_, --, --, --,
   {{0xe2970d6e,0x61e90067,0x00000000,0x00000000}},	//   јач_, _czel, --, --,
   {{0x26120907,0x61e90029,0x64a65e64,0x00000000}},	//   धुरी_, _dzel, _тага, --,
   {{0x61e99cac,0x270300ee,0x00000000,0x00000000}},	//   _ezel, _tŕne_, --, --,
   {{0xe2970804,0x628064d3,0x00000000,0x00000000}},	//   _кас_, _unmo, --, --,
   {{0xe2970390,0x3b0700de,0x7aed016e,0x00000000}},	//   _тат_, _aunq_, _rhat, --,
   {{0xaa1f01c0,0x00000000,0x00000000,0x00000000}},	//   पर्छ_, --, --, --,
   {{0xb47900c2,0x78bc003e,0x7aed959a,0x9e661470}},	//   אָרי, dirv, _phat, _введ,
   {{0xd90f00f8,0x00000000,0x00000000,0x00000000}},	//   ویب_, --, --, --,
   {{0xa3d3006a,0x1ea900bc,0x6f080523,0x65760097}},	//   _हुई_, _حالي_, _hudc, jvyh,
   {{0xa8a48d78,0x7aed00a5,0xa3e7007c,0xb4b5046c}},	//   орск, _what, _परल_, _जगे_,
   {{0x7aed9cad,0x7c6501ca,0x3ea60523,0xd6db029f}},	//   _that, _دانل, _klot_, вта_,
   {{0x6f081c8b,0xabfb00a5,0x00000000,0x00000000}},	//   _mudc, _בהור, --, --,
   {{0x04c90833,0x38c902fd,0x98a20067,0x00000000}},	// [b010] هوري_, _مادی_, wską_, --,
   {{0x4427004f,0x6abd9cae,0x673a08b7,0xe5c41645}},	//   ún_, lisf, štja, істо,
   {{0x61e9006c,0x3ea69caf,0xf8b2016b,0x00000000}},	//   _szel, _olot_, _זשי_, --,
   {{0x7f43027a,0xd37800c7,0x6abd9cb0,0x42d812ea}},	//   vunq, шчу_, nisf, афія_,
   {{0x29019cb1,0x61e0099e,0x00000000,0x00000000}},	//   _kiha_, _cyml, --, --,
   {{0x41740ef5,0x2bcf19b7,0x61e9008b,0xe0d801e0}},	//   غانس, _सुझा, _vzel, аві_,
   {{0x29019cb2,0x3d0c0722,0x6abd003e,0x53341eb9}},	//   _miha_, _डूबे_, kisf, _мерт,
   {{0xa3d30755,0x3ea69cb3,0x1e859cb4,0x29012933}},	//   _हुए_, _clot_, слим, _liha_,
   {{0xf2d202b5,0x17e4252c,0x61e99cb5,0x6abd003c}},	//   _זען_, _गर्व_, _uzel, disf,
   {{0xdce20124,0x29019cb6,0xf65f08c8,0x00000000}},	//   _brođ, _niha_, _sjæl_, --,
   {{0x3ea6054e,0x60da0070,0x00000000,0x00000000}},	//   _flot_, _עקענ, --, --,
   {{0xe8b2022e,0x3a29006b,0x6b9c03d0,0x00000000}},	//   ुच्च, _ceap_, ørga, --,
   {{0x29013266,0x3a290211,0x78bc003e,0x00000000}},	//   _biha_, _deap_, tirv, --,
   {{0x7d1b9cb7,0x9620258f,0x2909034d,0x00000000}},	//   mpus, बर्ट_, _duaa_, --,
   {{0x29012487,0x31ae00b5,0xe7371285,0x78bc0093}},	//   _diha_, _közé_, йер_, rirv,
   {{0xf74303e6,0x598601e0,0x3a290183,0x316d00a2}},	//   џето, _глиб, _geap_, _osez_,
   {{0x2901003c,0x28ba002d,0xe45a027a,0x00000000}},	// [b020] _fiha_, _бунэ_, лжа_, --,
   {{0x7d1b9cb8,0x29010371,0x38a603d0,0x00000000}},	//   ipus, _giha_, _fôra_, --,
   {{0x28970397,0x3a2900d7,0xa3e707df,0x61e0016e}},	//   _הדין_, _yeap_, _परः_, _syml,
   {{0x200501d3,0x63ae0b16,0x2a720260,0x29010371}},	//   _agli_, _đinđ, _jayb_, _ziha_,
   {{0x6f08020b,0x613a027a,0x78c700b5,0x2901007b}},	//   _sudc, учер_, _árví, _yiha_,
   {{0x987a02b5,0x94072b79,0xa87a0070,0x3ea69cb9}},	//   ראַט, _герб_, ראַר, _slot_,
   {{0x645c9cba,0x7d1b9cbb,0x3ea6024b,0x442a0065}},	//   _ibri, epus, _plot_, _ieb_,
   {{0x442a9cbc,0x200502fb,0x9d14107b,0x539b011d}},	//   _heb_, _egli_, одич, _גילו,
   {{0x442a01e8,0x7d1b2a16,0x7c3c0300,0x3ea619c1}},	//   _keb_, gpus, órro, _vlot_,
   {{0xdce20254,0x442a0029,0xd12f0037,0x443800f6}},	//   _prođ, _jeb_, _أمل_, _jdr_,
   {{0x44389cbd,0xef1a07c1,0xf1b9552b,0x442a9cbe}},	//   _mdr_, _сме_, _reši_, _meb_,
   {{0x442a4859,0xe8d901a5,0x3ea60159,0x29012206}},	//   _leb_, _trừ_, _ulot_, _siha_,
   {{0x645c1ec5,0x588715eb,0x81da0083,0x6abd03c1}},	//   _obri, быва, ডের_, risf,
   {{0x442a9cbf,0xac180202,0x60c4004f,0x6da303fa}},	//   _neb_, _току_, éimh, _хиља,
   {{0xdce2011c,0x499300d1,0x2901194e,0x6ef5004b}},	//   _urođ, زیگر, _viha_, _išbr,
   {{0x237f0a16,0x442a01a3,0x59da0d1f,0x29010027}},	//   _čuj_, _aeb_, _युवर, _wiha_,
   {{0x29011942,0x442a51c4,0xf1b90009,0xca3800a5}},	// [b030] _tiha_, _beb_, _teši_, _הנחה_,
   {{0xf99f02e9,0x7c2a9cc0,0x645c009e,0xadf00035}},	//   myè_, _jefr, _cbri, _चरनन_,
   {{0x442a4c28,0x443807c5,0x9327006c,0x6d4010c0}},	//   _deb_, _ddr_, صران, hrma,
   {{0x645c001e,0x7c2a021e,0x442a9cc1,0xab680024}},	//   _ebri, _lefr, _eeb_, _gażż,
   {{0x7c381942,0x442a26b2,0xf99f02d0,0x00000000}},	//   _odvr, _feb_, nyè_, --,
   {{0xb6080076,0x657d028b,0x4438027a,0x7c2a9cc2}},	//   _vyšš, _irsh, _gdr_, _nefr,
   {{0x6d400479,0x26c908c7,0x44210110,0xd00e0079}},	//   erma, onao_, mbh_, خلى_,
   {{0x442a0189,0x4421004a,0x6f029cc3,0x645c7f71}},	//   _zeb_, lbh_, _cioc, _zbri,
   {{0x44211093,0x7c2a9cc4,0x6d409cc5,0xf8bf000d}},	//   obh_, _befr, grma, nsés_,
   {{0x44218888,0x442a01e8,0x4034095d,0x44380395}},	//   nbh_, _xeb_, _неус, _xdr_,
   {{0xda6602cc,0x44210058,0x6d404222,0x6f022399}},	//   овни, ibh_, arma, _fioc,
   {{0x6f020133,0x4fd60070,0xc332011d,0x7d1b9cc6}},	//   _gioc, _וועב_, ווט_, ppus,
   {{0xdce901cc,0x3ebf9cc7,0x7de71d05,0x3ead370d}},	//   jveć, miut_, _اسام, mhet_,
   {{0x7c2a3388,0x7cef0909,0x3ead9cc8,0x25dd0354}},	//   _gefr, føre, lhet_, _खड़ी_,
   {{0x7d0b200b,0x7cef054e,0x656f9cc9,0x442a9cca}},	//   _hugs, gøre, _asch, _reb_,
   {{0xe61a0dbf,0x442a9ccb,0x7d039ccc,0x3ead9ccd}},	//   рда_, _seb_, _hins, nhet_,
   {{0x442a1020,0x7d034ba3,0x6e2b006c,0x7d04004f}},	// [b040] _peb_, _kins, _megb, _éist,
   {{0x7d039cce,0x442a006f,0x6e2b9ccf,0x25de00a1}},	//   _jins, _qeb_, _legb, _कुणी_,
   {{0xdddb02c4,0x442a9cd0,0x656f9cd1,0x4438081c}},	//   jjuž, _veb_, _esch, _vdr_,
   {{0x442102a8,0xf99f0248,0x4b4c02b5,0x4438033b}},	//   abh_, ccès_, רגאַ, _wdr_,
   {{0x442a0d4b,0x64430f56,0x3ead0055,0x6f0209bb}},	//   _teb_, ónic, dhet_, _rioc,
   {{0x7d039cd2,0x645c1f1c,0x10a35d57,0x6f029216}},	//   _nins, _ubri, мичн, _sioc,
   {{0x7d0b0080,0xf99f0c1f,0x3ead03bc,0x6f025173}},	//   _augs, zyè_, fhet_, _pioc,
   {{0x7d039cd3,0x3ead9cd4,0x7d0b1fcb,0x63a31217}},	//   _ains, ghet_, _bugs, ønne,
   {{0x6d400d35,0x6fda1451,0x7d039cd5,0x6e390090}},	//   urma, _पुरू, _bins, _ddwb,
   {{0x7d039cd6,0x26c90a78,0x6d409cd7,0xf99f02e9}},	//   _cins, znao_, rrma, vyè_,
   {{0x7d033bfb,0x6f0204e6,0xdee66f06,0xf41300a5}},	//   _dins, _tioc, _дожи, ופת_,
   {{0x7d039cd8,0x3ead9cd9,0xf99f02d0,0xed5a1353}},	//   _eins, chet_, tyè_, _вод_,
   {{0x7d039cda,0x7c2a08d7,0x26c90207,0x00000000}},	//   _fins, _tefr, vnao_, --,
   {{0x7d039cdb,0xf77310ad,0x24989cdc,0xf99f02e9}},	//   _gins, واز_, _norm_, ryè_,
   {{0xf99f02d0,0xeabf027a,0x23d92f41,0x7d0b0110}},	//   syè_, più_, _बुंद, _zugs,
   {{0x7d039cdd,0x00000000,0x00000000,0x00000000}},	//   _zins, --, --, --,
   {{0x20bc00b4,0x1dca00e7,0x7d030027,0xf1b900fe}},	// [b050] ्चाध, ापित, _yins, _ješt_,
   {{0xd37b57d2,0xde8f0019,0x3ead9cde,0x92c70083}},	//   иче_, _kịch_, zhet_, _উঠে_,
   {{0x44211093,0xdce90a78,0xf8bf0248,0x24981bae}},	//   rbh_, sveć, ssés_, _dorm_,
   {{0x656f01ae,0x1dca0ea3,0x3ead70ce,0x6ee50067}},	//   _tsch, ापात, xhet_, róbk,
   {{0x656f1cc5,0xde8f00e8,0x2498293a,0xf1b9022f}},	//   _usch, _lịch_, _form_, _nešt_,
   {{0xc5fa0052,0xccf801c0,0x7d0b9cdf,0x6ee501dd}},	//   _לפרט, jmě_, _rugs, móbi,
   {{0x3ead9ce0,0x656d81cf,0xf1b9023a,0x7d030147}},	//   thet_, lwah, _rešu_, _rins,
   {{0x764d9ce1,0x7d039ce2,0x656d023c,0x00000000}},	//   ngay, _sins, owah, --,
   {{0x7d039ce3,0x3ebf00da,0x3ead9ce4,0x656d3224}},	//   _pins, riut_, rhet_, nwah,
   {{0x6e2b1090,0x2ca90665,0x3ead9ce5,0xde8f00e2}},	//   _wegb, скоп_, shet_, _bịch_,
   {{0x7d035d3c,0x3ebf011e,0x3ead9ce6,0x00000000}},	//   _vins, piut_, phet_, --,
   {{0xde8f00e8,0x7d03190e,0x656d9ce7,0xa96a5a4b}},	//   _dịch_, _wins, kwah, бима_,
   {{0x7d03003c,0x499900c3,0x290f000d,0x5fdf0d4e}},	//   _tins, отря_, _égal_, _पुतल,
   {{0x23bd0567,0x764d001c,0xa3ab1163,0x7e69081b}},	//   ्पाद, egay, गना_, leep,
   {{0x177903ad,0xfaa61279,0x6d4900af,0x271800cd}},	//   ость_, _нако, luea, _očne_,
   {{0x764d9ce8,0x6b9c1193,0x6ee59111,0x784e00b5}},	//   ggay, ärge, fóbi, _bőví,
   {{0xb5fb01ef,0x656d7abf,0x00000000,0x00000000}},	// [b060] _abáb, gwah, --, --,
   {{0x6aac0325,0x7e692193,0x897b011d,0x00000000}},	//   _चतुर, heep, _פריצ, --,
   {{0x389b168d,0x24984b27,0x35fa00d1,0x764d10a2}},	//   _היינ, _vorm_, _گردد_, bgay,
   {{0x5b3a0070,0x656d01d5,0x317f00f6,0x24980147}},	//   מגעק, bwah, _bruz_, _worm_,
   {{0x317f9ce9,0x24986675,0x05550340,0x3a3700a5}},	//   _cruz_, _torm_, _отря, פרסם_,
   {{0xf1b9023a,0x00000000,0x00000000,0x00000000}},	//   _rešt_, --, --, --,
   {{0xa85700a5,0x00000000,0x00000000,0x00000000}},	//   פיקה_, --, --, --,
   {{0x877b02b5,0xbd18262e,0x00000000,0x00000000}},	//   מאצי, ожих_, --, --,
   {{0x6d490831,0x504600d8,0x614327de,0x6ce60409}},	//   guea, _неаб, _пета, зіне,
   {{0x2f110037,0xd00f0037,0xf1b902c4,0x2a60678b}},	//   _fág_, _ملك_, _vešt_, _abib_,
   {{0xe45702b5,0xccf800b8,0x7e690159,0xa0675b87}},	//   הייט_, rmě_, beep, _хаха_,
   {{0xdc0200ac,0x00000000,0x00000000,0x00000000}},	//   _učím, --, --, --,
   {{0xc98702c4,0xc98450f1,0x69da00af,0x00000000}},	//   чуни, нури, şten, --,
   {{0xddeb0779,0xde8f01a5,0x22b800d5,0x00000000}},	//   _פֿאָ, _tịch_, rčky_, --,
   {{0xe7e00084,0xd7f83091,0x7b0600b8,0x24c40033}},	//   _खुदा_, зут_, ístě, ্তাহ,
   {{0x5694095d,0xe8d90028,0x27ed0355,0x656d9cea}},	//   наст, _trữ_, řeno_, twah,
   {{0x764d0a99,0xa5f811eb,0x5499010b,0x26c700cd}},	// [b070] rgay, зету_, оваў_, đno_,
   {{0xe8d30332,0x656d9ceb,0x6ee50473,0x870700d8}},	//   _سمجھ, rwah, róbi, _няме,
   {{0x656d9cec,0x98ab002d,0x6aad1b04,0x5275002d}},	//   swah, ască_, _klaf, дулу,
   {{0x38af033b,0xddd40355,0x00000000,0x00000000}},	//   _würd_, žařs, --, --,
   {{0xe8141604,0x999200fe,0x6aad034d,0x00000000}},	//   तुका_, _kdyš_, _mlaf, --,
   {{0x2f1125ec,0x6aad2db2,0x3cf6046c,0x00000000}},	//   _pág_, _llaf, ँगों_, --,
   {{0xb4d902cb,0xa34400af,0x690b0069,0x00000000}},	//   ावी_, _пэтл, _jżeb, --,
   {{0x92580807,0x7c240207,0x271802a7,0x00000000}},	//   _наст_, _đira, _učne_, --,
   {{0x7e6932c5,0xdb080097,0x628901da,0x00000000}},	//   reep, vzdá, _ineo, --,
   {{0x4c691283,0x6aad9ced,0x7cef0185,0x25f000b4}},	//   цион_, _alaf, føra, _आरसी_,
   {{0xeb993d56,0x6aad1c1c,0x60c3081b,0xbc6901df}},	//   цин_, _blaf, minm, ممکن_,
   {{0x929d004e,0x60c35257,0x44332889,0xb807007c}},	//   _miło, linm, hax_, _शलजम_,
   {{0x6d490aca,0x4433007a,0x3ea2013c,0x00000000}},	//   quea, kax_, ökte_, --,
   {{0x44330024,0x20dd0e61,0xb69b0132,0x4dfa00a5}},	//   jax_, यविध, _diâm, _ופנא,
   {{0x66e69cee,0x480719fa,0x6aad008c,0x00000000}},	//   дова, дерн_, _flaf, --,
   {{0x26f80006,0x6443003e,0x6aad9cef,0x00000000}},	//   ंगेर_, ónin, _glaf, --,
   {{0x44339cf0,0x38af01d6,0x66160ab8,0x7ae49cf1}},	// [b080] fax_, _süre_, rcyk, _ikit,
   {{0xf8d20084,0x6dc5009f,0x7cf40176,0x00000000}},	//   _सदिय, _iċaħ, càrd, --,
   {{0xa0130033,0x60c31e81,0x00000000,0x00000000}},	//   হরাব_, dinm, --, --,
   {{0xeb9602b5,0x2d800029,0x9c7c51e4,0xf7730919}},	//   ודער_, _šiem_, moče, _شاپ_,
   {{0x9c7c6917,0x7ae4237c,0x00000000,0x00000000}},	//   loče, _mkit, --, --,
   {{0x1de108a9,0x60c30093,0x92c00033,0x6dc50069}},	//   _पड़त, ginm, ুতে_, _mċaħ,
   {{0x41de0299,0xb4ea112b,0x7ae49cf2,0x2d991171}},	//   _फुरस, मती_, _okit, äsen_,
   {{0x3da6263b,0x629b011e,0xf8bf00a2,0x645e081b}},	//   дроб, _gouo, mpée_, lfpi,
   {{0x9c7c00b8,0x459b016b,0x60c30088,0x00000000}},	//   hoče, ַסטע, binm, --,
   {{0x7ae405ba,0x9c7c9cf3,0x00000000,0x00000000}},	//   _akit, koče, --, --,
   {{0x69da00af,0x9c7c2a14,0x00000000,0x00000000}},	//   ştel, joče, --, --,
   {{0x1d0a3c16,0x9c7c1342,0x7af69cf4,0xf8bf00f7}},	//   _деди_, doče, _chyt, ipée_,
   {{0x25de007c,0x7e620279,0x44331505,0xb9e401e0}},	//   _कुली_, _ibop, yax_, віри,
   {{0x7ae49cf5,0x1bd4172a,0xdb0200a2,0x394b0392}},	//   _ekit, _поля, hylè, rucs_,
   {{0x248d01a5,0x9c7c177a,0xa2bf0035,0x00000000}},	//   _đem_, goče, लोड्, --,
   {{0xbebc0029,0x8f9b00a5,0x6aad023c,0x00000000}},	//   _avīz, חילי, _ulaf, --,
   {{0x44339cf6,0x929d0067,0x60c30457,0x00000000}},	// [b090] tax_, _siło, yinm, --,
   {{0xb4d94bdd,0x7afd9cf7,0xa7751f7e,0x9c7c9cf8}},	//   ावे_, lmst, _злоч, boče,
   {{0x44339cf9,0xca4800d1,0x7afd0051,0x7cf40176}},	//   rax_, _علیه_, omst, càre,
   {{0xd6270082,0x7cef11cb,0xd9f300a1,0x65951607}},	//   _تعدي, jørn, _घरात_, _заму,
   {{0xde8f00e2,0x60c39cfa,0xf07500fd,0x00000000}},	//   _bịnh_, tinm, ٹیاں_, --,
   {{0xe1f00037,0x00000000,0x00000000,0x00000000}},	//   جسم_, --, --, --,
   {{0x60c39cfb,0xd0062368,0xa5bb0183,0x00000000}},	//   rinm, неше_, _geór, --,
   {{0xee391761,0xfe710125,0x62898c27,0x63b1011c}},	//   чни_, ادث_, _uneo, đenč,
   {{0x44310723,0xc05b1958,0x98ef08a9,0x7af69cfc}},	//   _kez_, _між_, छताछ_, _rhyt,
   {{0x7ae41791,0xd0110082,0x44319cfd,0x16010e62}},	//   _skit, _إلا_, _jez_, लेयर_,
   {{0x09c800b4,0x7cef0b3e,0x271802b2,0x00000000}},	//   रप्य, børn, _očna_, --,
   {{0xeab20dc0,0x44319cfe,0x8d77026e,0x68e50858}},	//   اعد_, _lez_, _ياشا, _akhd,
   {{0x8c4528a1,0x443100d5,0x00000000,0x00000000}},	//   _зеле, _oez_, --, --,
   {{0x26fa00c0,0xb4d9018d,0x7e7b4a11,0x7afd0fdb}},	//   ्द्र_, ावो_, ldup, amst,
   {{0x46f62aac,0x6d5b9cff,0x61e99d00,0x00000000}},	//   ечат, ltua, _lyel, --,
   {{0xcf9202b5,0xd7070336,0x9c7c043e,0x7ae49d01}},	//   נטן_, енсе_, roče, _ukit,
   {{0x44319d02,0x61e90a86,0xceb2011d,0x60c10103}},	// [b0a0] _bez_, _nyel, אין_, _omlm,
   {{0x23d60665,0x9c7c011c,0x4431016f,0xb9db0122}},	//   нцер, poče, _cez_, _מחפש,
   {{0x6fdf009a,0x7b090092,0x44319d03,0x6d5b9d04}},	//   _पुलं, _üstü, _dez_, htua,
   {{0x6d5b9d05,0xa50a7a6e,0xe8d900e8,0x29129d06}},	//   ktua, _нема_, _trợ_, _kuya_,
   {{0x44310370,0x6d5b00da,0x387a6f6d,0xda020d55}},	//   _fez_, jtua, _kapr_, ोशित_,
   {{0xa5bb332c,0xd00f017e,0x6d5b043d,0x75240116}},	//   _teór, مله_, dtua, mpiz,
   {{0x25fc02e4,0x29120cca,0xde8f0023,0x232a02fb}},	//   लेरी_, _luya_, _vịnh_, _хоби_,
   {{0x6d5b01f4,0x38b4013c,0xdb0200d5,0x44313497}},	//   ftua, _färg_, bylé, _zez_,
   {{0x6d5b9d07,0xde8f0023,0xf65f01cf,0x00000000}},	//   gtua, _tịnh_, _kjær_, --,
   {{0x387a016f,0xe0850037,0x00000000,0x00000000}},	//   _napr_, _لجمي, --, --,
   {{0xe7e000dc,0xd00f004f,0x79840010,0x6d5b01b7}},	//   _खुला_, _الم_, _ariw, atua,
   {{0x291200e7,0x9e730833,0x798400e5,0xd33700a5}},	//   _buya_, _مهمت, _briw, ערכה_,
   {{0xf2d300c2,0x29120831,0x7afd135a,0x6d5b9d08}},	//   רער_, _cuya_, rmst, ctua,
   {{0x7984099e,0xb4ea112b,0x00000000,0x00000000}},	//   _driw, मतो_, --, --,
   {{0xe7db1e79,0x64436828,0x7984018e,0x67d40132}},	//   _मुखप, ónim, _eriw, гору,
   {{0x4431027a,0x63a50334,0xb4d9012f,0x79840090}},	//   _sez_, vyhn, ाव्_, _friw,
   {{0x25fc02cb,0x9984004f,0x44310453,0x54559d09}},	// [b0b0] लेली_, _مليو, _pez_, кват,
   {{0x26c2016d,0x5fb00761,0x6fb00099,0xb60400af}},	//   _emko_, जनाल, जनां, уяск,
   {{0x44311423,0x92590086,0x6d5b01d7,0x26c201ed}},	//   _vez_, дает_, ztua, _fmko_,
   {{0x61e901a2,0x44319d0a,0x291213d6,0x7ec70118}},	//   _pyel, _wez_, _yuya_, _mèpè,
   {{0x44319d0b,0xf7730987,0x7cef11cb,0x7ec701cb}},	//   _tez_, _شاھ_, førl, _lèpè,
   {{0xfaff01f4,0x6d5b006d,0xe0420ded,0x9f6400ac}},	//   hmë_, vtua, анши, _štáb_,
   {{0xe0d00037,0x7e790103,0x00000000,0x00000000}},	//   حزن_, _pawp, --, --,
   {{0xfaff01d2,0x6d5b9d0c,0xa3e629ce,0x00000000}},	//   jmë_, ttua, _पडत_, --,
   {{0xc21202b8,0x7e7b9d0d,0x6b9c6d0a,0x61e99d0e}},	//   _כהן_, rdup, ärgn, _uyel,
   {{0x5ba91b60,0xcfab00b5,0x38b40523,0x53d5021a}},	//   дком_, _ٹائم_, _käre_, _दशाश,
   {{0x6d5b9d0f,0x7984149f,0x29129d10,0xf412011d}},	//   stua, _sriw, _suya_, יפי_,
   {{0x6d5b49ef,0x29129d11,0x00000000,0x00000000}},	//   ptua, _puya_, --, --,
   {{0x6e292972,0xec6e0f24,0x00000000,0x00000000}},	//   mbeb, _кп_, --, --,
   {{0xdca21d6b,0x2eed9d12,0x7c28009e,0x7d0a9d13}},	//   _ваши, llef_, cbdr, _gifs,
   {{0x7ec70118,0xcada00af,0xe73a0421,0xeb9900af}},	//   _gèpè, _офич_, ьев_, _ций_,
   {{0x79849d14,0x29129d15,0xb4ea012f,0x9c7c0009}},	//   _triw, _tuya_, मत्_, moča,
   {{0x6d499d16,0x9c7c869a,0x6f0b9d17,0xf50a3cc0}},	// [b0c0] nrea, loča, _migc, днал_,
   {{0x6d4941e3,0x293702b8,0x7ebe010b,0x752401a3}},	//   irea, _שאין_, rūpi, rpiz,
   {{0x6d499d18,0xaac60299,0x4ac6007c,0x3cf900dc}},	//   hrea, _लगाक, _लगाव, _उठने_,
   {{0x23270c87,0xdcfb00cd,0xb6a64ed5,0x26c2023a}},	//   тоци_, dvuč, _римл, _umko_,
   {{0xdce24481,0x754307f5,0xaa7b0334,0x6e29729a}},	//   _spoč, _княз, plýv, dbeb,
   {{0x6f0b0211,0x2ee60b88,0x00000000,0x00000000}},	//   _aigc, _skof_, --, --,
   {{0x7bc72a04,0xfaff0031,0x6d490065,0x24072e50}},	//   újul, ymë_, erea, _анри_,
   {{0x63a3461a,0x6d490037,0x9c7c0254,0xb5fb0187}},	//   änne, frea, doča, _obál,
   {{0x6d499d19,0x6ee501ba,0x20560714,0x00000000}},	//   grea, tóbr, _атер, --,
   {{0x8ffa1c0c,0x21261d11,0x38a600ee,0xcb9801e0}},	//   _قرار_, mpoh_, _kôru_, евої_,
   {{0x6d499d1a,0xda3515eb,0x3f851942,0x9c7c008b}},	//   area, лены, _grlu_, goča,
   {{0x6d499d1b,0x8aa70043,0x2eed9d1c,0x4ea30d6e}},	//   brea, трод, clef_, _врша,
   {{0x6d490052,0xfaff01f4,0x3ed9016b,0x00000000}},	//   crea, rmë_, _אַסא, --,
   {{0xa3b2073f,0x929d004e,0x690b007a,0x9c7c1bd8}},	//   टना_, _piłk, _eżen, boča,
   {{0x57a42f40,0x00000000,0x00000000,0x00000000}},	//   ашта, --, --, --,
   {{0x2f1800f5,0xa3e60299,0x497531d3,0x96f80c98}},	//   _még_, _पड़_, _блис, вест_,
   {{0xdcfb00cd,0xd6840fb4,0x26190387,0x00000000}},	// [b0d0] zvuč, јусп, युगी_, --,
   {{0xd3a70afd,0x00000000,0x00000000,0x00000000}},	//   креп, --, --, --,
   {{0x53e400d8,0x00000000,0x00000000,0x00000000}},	//   ацца, --, --, --,
   {{0xe29801e0,0xfb150070,0x3a39021d,0x00000000}},	//   кає_, אַסט_, nasp_, --,
   {{0x38b402c9,0x9c7c2209,0x7abc0122,0x26c99d1d}},	//   _wäre_, zoča, וצאו, miao_,
   {{0x6d494c7a,0x26c9258e,0x69da02b1,0xf53f03d0}},	//   vrea, liao_, ßtei, _ivå_,
   {{0x5334957f,0x2eed9d1e,0x2f1800b5,0xdb2000a8}},	//   _вест, tlef_, _cég_, ətçi,
   {{0x6d499d1f,0x26c90132,0x2d86008c,0x00000000}},	//   trea, niao_, _broe_, --,
   {{0x6468008a,0x6d490284,0xdcfb00cd,0x6e299d20}},	//   _þrið, urea, svuč, rbeb,
   {{0x9c7c0693,0x75220132,0x6d490ca5,0x2d860298}},	//   toča, ãozi, rrea, _droe_,
   {{0x2d8607e5,0xfaa60969,0x26c9034d,0x00000000}},	//   _eroe_, гано, kiao_, --,
   {{0x9c7c02c6,0x38af9d21,0x26c900d7,0x6d5c002d}},	//   roča, _büro_, jiao_, ărar,
   {{0x9c7c502f,0x38c800d1,0xc956021f,0x9d450009}},	//   močn, ناسی_, ытны, _селд,
   {{0x9c7c4481,0x3ead1b2f,0x290c1a17,0x00000000}},	//   ločn, lket_, öda_, --,
   {{0xaa7b00fb,0x81a90033,0xb5fb00d5,0x9cda0277}},	//   glýs, খছি_, _dbám, _אקספ,
   {{0x9c7c05cd,0xa3d70af6,0x26c953d2,0x3ead3993}},	//   nočn, ापन_, giao_, nket_,
   {{0x598300d8,0x7ae68db4,0xdb0200b5,0xb466081b}},	// [b0e0] _глыб, mokt, szló, лкал,
   {{0xf4c40083,0xf5e7002d,0x7ae651b1,0xaa7b00d5}},	//   ্ত্ব, умул_, lokt, blýs,
   {{0x39401879,0x3ead8118,0x07a60f16,0xb46300af}},	//   _hvis_, kket_, _санн, скхл,
   {{0x26c90036,0x7ae69d22,0x5b56016b,0x00000000}},	//   ciao_, nokt, טשען_, --,
   {{0xc1e73634,0x9c7c9d23,0x10a60192,0xc6931804}},	//   льше_, dočn, лидн, _האר_,
   {{0x3ead9d24,0xe9f900e2,0x7ae612ba,0x00000000}},	//   eket_, _hoả_, hokt, --,
   {{0x4375081b,0x80a50067,0x00000000,0x00000000}},	//   _кутт, _कवरे, --, --,
   {{0x443a9d25,0x3ead012f,0x2d8603bc,0xdd901b20}},	//   lap_, gket_, _proe_, قوب_,
   {{0x7ae69d26,0xe05600d1,0x2f180345,0x00000000}},	//   dokt, _مخاب, _wég_, --,
   {{0x443a9d27,0x5b2601db,0x201e028b,0x3a200453}},	//   nap_, льма, _ufti_, _afip_,
   {{0x39409d28,0xdeef9d29,0xdfcf004f,0xdd9200d1}},	//   _avis_, _гы_, _فيك_, _گوش_,
   {{0x3ead9d2a,0x7eb500a0,0x00000000,0x00000000}},	//   cket_, _pápe, --, --,
   {{0x2d860044,0x00000000,0x00000000,0x00000000}},	//   _uroe_, --, --, --,
   {{0xed570052,0x6b9c0022,0x443a128f,0xfd5700a5}},	//   _עבור_, ørgs, jap_, _עשוי_,
   {{0x443a49c2,0x8c1b0397,0x69c09d2b,0x3cf90026}},	//   dap_, _אווי, úmer, _उठते_,
   {{0x7c3a9d2c,0xaa7b0093,0x3a20021d,0x00000000}},	//   latr, rlýs, _gfip_, --,
   {{0x443a9d2d,0x344b2503,0xaa7b003e,0x26c901ef}},	// [b0f0] fap_, ечен_, slýs, riao_,
   {{0xaa7b00fb,0x443a9d2e,0x25a99d2f,0x9c7c025c}},	//   plýs, gap_, ryal_, zočn,
   {{0xd37138b7,0xe78763fa,0x7c3a07e5,0xdc3b0070}},	//   تها_, _супо, iatr, געבר,
   {{0xf53f06d7,0x7c3a9d30,0x443a0159,0x00000000}},	//   _två_, hatr, aap_, --,
   {{0x7c3a9d31,0x763a02b5,0x210f131c,0x11670416}},	//   katr, _בערג, ादेश_, التی_,
   {{0x7c3a01a0,0xa0699d32,0x38b40454,0x8fa502fb}},	//   jatr, така_, _kära_, иале,
   {{0x9c7c9d33,0xc4d20052,0x7ae63120,0x3ead0421}},	//   točn, _וגם_, yokt, tket_,
   {{0x29030031,0x00000000,0x00000000,0x00000000}},	//   hmja_, --, --, --,
   {{0x9c7c9d34,0x6d469d35,0x7c3a0090,0x38b4013c}},	//   ročn, škan, fatr, _lära_,
   {{0x3ead0b80,0x64579d36,0xa2a13893,0x2d80003c}},	//   sket_, ngxi, कॉर्, _ġiet_,
   {{0xdfd10413,0x38b4022a,0xc10400b2,0x39400009}},	//   _بيا_, _nära_, _اولي, _svis_,
   {{0x8a060340,0x1fa40227,0x9c7c00ac,0x8d7500f3}},	//   изне, _уруг, bočo, _ناتا,
   {{0xfeb809b9,0x443a0464,0xed594025,0xb2760070}},	//   _حالت_, yap_, _рол_, בערג_,
   {{0x6e3b9d37,0x38b401ff,0xa3e600ab,0x394003d0}},	//   laub, _bära_, _पडल_, _vvis_,
   {{0xac7401ca,0x443a0723,0xe7376a94,0x7ae61364}},	//   _دانش, vap_, иер_, pokt,
   {{0x443a9d38,0x7a0c00ea,0x6e3b4c18,0x38b40282}},	//   wap_, _pētī, naub, _dära_,
   {{0x443a9d39,0xe61711ab,0x80d62135,0x690b0024}},	// [b100] tap_, рду_, _बदले, _mżej,
   {{0xe3b2004f,0x25fc0035,0x7cef1123,0x6aa40037}},	//   يرا_, लेगी_, føri, _hoif,
   {{0x443a9d3a,0x6e3b9d3b,0xe9f900e2,0x316d0065}},	//   rap_, kaub, _toả_, _apez_,
   {{0x443a72ec,0x63a3013c,0xd186195c,0xe9f90019}},	//   sap_, änna, илей, _hoạ_,
   {{0x7c3a9d3c,0x7a40005f,0x00000000,0x00000000}},	//   yatr, _ištį, --, --,
   {{0x6ab602c7,0xe8d901a5,0x98a00207,0x00000000}},	//   _llyf, _trụ_, _otič_, --,
   {{0x7c3a4232,0xdfcf381f,0x44383c7a,0x316d0065}},	//   vatr, ويه_, _ier_, _epez_,
   {{0x4438523d,0x7c3a485d,0x6e3b9d3d,0x27fa0069}},	//   _her_, watr, gaub, _mzpn_,
   {{0x4438108a,0xe51c19b7,0xdd90149c,0x62800116}},	//   _ker_, _भूमि_, سود_, _iamo,
   {{0x44381254,0x62809d3e,0x628209a6,0x6aa40098}},	//   _jer_, _hamo, ldoo, _aoif,
   {{0x443882e1,0x7c3a9d3f,0x6ab6198d,0x76460168}},	//   _mer_, ratr, _blyf, _odky,
   {{0x62829d40,0x62801a84,0x44389d41,0x6aa40248}},	//   ndoo, _jamo, _ler_, _coif,
   {{0x44389d42,0xdd8f0082,0x62809d43,0x290301f4}},	//   _oer_, _يوم_, _mamo, tmja_,
   {{0x443806d7,0x8cf300d8,0x644a9d44,0x6d406430}},	//   _ner_, _дзіц, ófil, msma,
   {{0x6ab61bc5,0x628200ab,0x6aa4009e,0xe9f900e2}},	//   _flyf, kdoo, _foif, _doạ_,
   {{0x62809d45,0x44389d46,0x5a350043,0x0bb700a5}},	//   _namo, _aer_, _унит, _כלום_,
   {{0x62820103,0x44388857,0x6d409d47,0xf5590037}},	// [b110] ddoo, _ber_, nsma, طلاب_,
   {{0x7c380bec,0x4438555c,0x62820298,0x6d400421}},	//   _jevr, _cer_, edoo, isma,
   {{0x44380588,0xdd86040d,0x7c382193,0x628018f9}},	//   _der_, _کو_, _mevr, _bamo,
   {{0xe695004f,0x6d409d48,0x645c0248,0x44389d49}},	//   _الحد, ksma, _ecri, _eer_,
   {{0x44389d4a,0x7aed000e,0x7eb5024e,0x78a500ab}},	//   _fer_, _mkat, _nápa, _kohv,
   {{0x44389d4b,0x6280053f,0x6e22021d,0x3e7100e2}},	//   _ger_, _eamo, _afob, _ạt_,
   {{0x6d4000ea,0x9c7c03ab,0x6d460520,0x7aed9d4c}},	//   esma, ročl, škal, _okat,
   {{0x4421188f,0x44380291,0x62809d4d,0x417700d1}},	//   lch_, _zer_, _gamo, _پارس,
   {{0x44380d6f,0x4421009d,0x7c3803c4,0x9c7c02c6}},	//   _yer_, och_, _bevr, močj,
   {{0x7aed6b3b,0x44214a87,0x6aa49d4e,0x443801f7}},	//   _akat, nch_, _soif, _xer_,
   {{0x44219d4f,0x7c389d50,0xa3d705f7,0x628087c7}},	//   ich_, _devr, ापि_, _yamo,
   {{0xf8a90d85,0x6d400a8a,0x7cfd000d,0xcff600a5}},	//   _אש_, bsma, dère, _הצעה_,
   {{0x7c389d51,0x82760070,0x6b8a19c1,0x78a50168}},	//   _fevr, זערע_, _erfg, _bohv,
   {{0x7c380903,0x7aed0260,0xa3d70437,0xe8f70043}},	//   _gevr, _ekat, ापा_, йля_,
   {{0x7eb50076,0x78a5044d,0x7cfd0248,0x44389d52}},	//   _zápa, _dohv, gère, _rer_,
   {{0x645c9d53,0x4438248a,0x44219d54,0x6447027c}},	//   _scri, _ser_, ech_, _adji,
   {{0x44389d55,0x6280377e,0x7c381505,0x2bb70095}},	// [b120] _per_, _ramo, _yevr, dəcə_,
   {{0x9992000c,0x64470b88,0x44238abc,0x44380055}},	//   _když_, _cdji, _cfj_, _qer_,
   {{0x443836b0,0x62808b69,0x61fb0152,0x44230009}},	//   _ver_, _pamo, _azul, _dfj_,
   {{0x443802bf,0x44214c34,0xd25900d4,0x6b9c00ab}},	//   _wer_, ach_, иці_, ärgi,
   {{0x44389d56,0x6280365e,0x62820244,0x673b044d}},	//   _ter_, _vamo, rdoo, ćuje,
   {{0xdb1a0332,0x645c0036,0x443801ef,0x61fb09df}},	//   szté, _ucri, _uer_, _dzul,
   {{0x62807824,0x65649d57,0x6d4041c7,0xd09500d8}},	//   _tamo, ltih, wsma, ўшчы,
   {{0x6d409d58,0x6d469c6b,0x7c382a5a,0x7eb53cf2}},	//   tsma, škam, _sevr, _pápa,
   {{0x65649d59,0x6d409d5a,0x7c8600af,0xb1460043}},	//   ntih, usma, буне, _ынал,
   {{0x7aed9d5b,0x9c7c008b,0x7d190051,0x757b025a}},	//   _skat, močk, _duws, נטיפ,
   {{0xc5f52450,0x95f5170c,0x7f8600fd,0x00000000}},	//   _आर्य_, _आर्ट_, _دلان, --,
   {{0x38af0d6f,0xda6711c0,0x15fa0433,0x6d409d5c}},	//   _türk_, حادي, ्धार_, psma,
   {{0x44216200,0x78a502dd,0x7c3802e6,0x984b02fb}},	//   ych_, _pohv, _tevr, лява_,
   {{0x7cfd0248,0xd90f01cb,0x3f8c00f4,0x00000000}},	//   tère, ژیک_, _krdu_, --,
   {{0x7aed9d5d,0x38af00ab,0x49190f9c,0x00000000}},	//   _tkat, _jüri_, _यूरो_, --,
   {{0x442102c7,0x7aed9d01,0x7cfd000d,0x60d80051}},	//   wch_, _ukat, rère, hnvm,
   {{0x44214305,0x69da9d5e,0x3ea6081f,0xf7780484}},	// [b130] tch_, şter, _moot_, ħħa_,
   {{0x3f8c03cb,0x442164f1,0x3ea6081f,0x9d1b00a5}},	//   _ordu_, uch_, _loot_, טומט,
   {{0x44219d5f,0x656400d7,0xcfad0033,0x61fb9d60}},	//   rch_, atih, _কেনন, _szul,
   {{0x44219d61,0xe570006c,0x798d9d62,0x3ea64b11}},	//   sch_, بطہ_, _kraw, _noot_,
   {{0xa2bf045c,0x3f8c0176,0x656f4473,0x6d461793}},	//   लोग्, _ardu_, _upch, škaj,
   {{0x3f8c05e2,0x2eb101c0,0x493c0317,0x44230065}},	//   _brdu_, जस्त, נגוו, _ufj_,
   {{0x29131e2e,0x3ea61229,0xf3f30c74,0x291b009f}},	//   _mixa_, _boot_, _رأس_, _luqa_,
   {{0x92b70071,0x9c7c024e,0x3f870355,0x6f1a5d2d}},	//   _احسا, bočk, rvnu_, _dutc,
   {{0x798d006f,0x225f022e,0x2d8b00b8,0x3f8c01ed}},	//   _nraw, _icuk_, íce_, _erdu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x798d9d63,0xf9890d85,0x3ea620ac,0x00000000}},	//   _araw, _שר_, _foot_, --,
   {{0x798d9d64,0xef0e1728,0x65649d65,0x24830031}},	//   _braw, _ім_, ytih, _lajm_,
   {{0x8c4513a1,0x6da50a80,0x29130107,0x798d9d66}},	//   _деле, _фила, _bixa_, _craw,
   {{0x798d9d67,0x6c6700b5,0xd94303e6,0x690b0069}},	//   _draw, _طلبہ_, ќери, _mżew,
   {{0xfaa667be,0x798d9d68,0x7cfd07a7,0x00000000}},	//   _мако, _eraw, pèrb, --,
   {{0x2ca702e6,0x291301f7,0x291b0069,0x798d016e}},	//   _hond_, _eixa_, _fuqa_, _fraw,
   {{0x29139d69,0x798d2c9f,0xb5fb01ef,0xcfad0033}},	// [b140] _fixa_, _graw, _acáb, _কেমন,
   {{0x33f61283,0x65649d6a,0x26cb00fe,0x00000000}},	//   очес, rtih, _emco_, --,
   {{0x2ca79d6b,0x7eb50076,0x6564388f,0x3e4c00d8}},	//   _mond_, _nápo, stih, lėtų_,
   {{0x7ebc0332,0x2ca74d6e,0xfbd200a5,0x6f1a008c}},	//   _képe, _lond_, ותב_, _rutc,
   {{0x6f1a012f,0x3ea69251,0x2ca70b88,0x055500af}},	//   _sutc, _root_, _oond_, _нтря,
   {{0x9c7c03c9,0x27ed156b,0x11391482,0x60cd00a2}},	//   ročk, şene_, сяцы_, éamp,
   {{0x7eb50097,0x3ea69d6c,0xd00f0088,0x9c7c00f4}},	//   _vápn, _poot_, نله_, sočk,
   {{0xa3d7065a,0xbe8a03fa,0x7cf40443,0x9c7c03e0}},	//   ापर_, рске_, màri, moči,
   {{0x9c7c108a,0x41273425,0xeeb700d4,0x2ca7024b}},	//   loči, _мото_, ільш_, _bond_,
   {{0x0caa47c5,0x387801f4,0x38af00be,0x3e4c00c7}},	//   ртии_, jerr_, _türi_, dėtų_,
   {{0x3ea6010d,0x7cf40443,0x38780031,0x2ca702d7}},	//   _toot_, nàri, derr_, _dond_,
   {{0x798d9d6d,0x5fc30026,0xb4b6018d,0x00000000}},	//   _praw, _वेटल, जसु_, --,
   {{0xc984002d,0xf1bc7d61,0x7eb51d8a,0x99920035}},	//   мури, ्छिन, _zápo, _gdyż_,
   {{0x7ebc0248,0x9c7c0a03,0x2ca700b5,0x6f02009e}},	//   _dépe, koči, _gond_, _hhoc,
   {{0xa8140370,0x9c7c008b,0x9a8732a6,0x00000000}},	//   ддрш, joči, _дупл, --,
   {{0x798d9d6e,0x5694010b,0x7eb50187,0x9c7c0bc6}},	//   _traw, маст, _nápl, doči,
   {{0x7ebc006c,0x6f029d6f,0x798d0027,0x00000000}},	// [b150] _gépe, _mhoc, _uraw, --,
   {{0x7d1d24c5,0x449810b0,0x752d02d7,0x290101ef}},	//   íssi, овую_, rpaz, _uhha_,
   {{0x395901ae,0x9c7c008b,0xd2510037,0xd5d000ab}},	//   luss_, goči, فنا_, _सेठज,
   {{0xb77a0779,0x6f020023,0x877a0317,0xdb9b016b}},	//   _פארש, _nhoc, _פארי, יסבר,
   {{0xc6920779,0x39599d70,0x71240088,0x248300f4}},	//   _נאך_, nuss_, ورول, _tajm_,
   {{0x9c7c02b2,0x00000000,0x00000000,0x00000000}},	//   boči, --, --, --,
   {{0x2ca79d71,0x6f020874,0x3959033b,0xf838011d}},	//   _rond_, _bhoc, huss_, חנות_,
   {{0x3eb9008a,0x6f029d72,0xfe4503e6,0x7d080298}},	//   óst_, _choc, чнио, emds,
   {{0xee3600d8,0x3861001e,0x6f020719,0x2ca70f00}},	//   чны_, _ochr_, _dhoc, _pond_,
   {{0x7ebc0248,0xdce2003c,0x7eb50187,0x38610260}},	//   _répe, _proġ, _zápl, _nchr_,
   {{0x2ca79d73,0x6f02184f,0x7cfd00e0,0x00000000}},	//   _vond_, _fhoc, gèra, --,
   {{0x6f02009e,0x2ca79d74,0x00000000,0x00000000}},	//   _ghoc, _wond_, --, --,
   {{0x9c7c022f,0x6f0951f1,0x00000000,0x00000000}},	//   zoči, mmec, --, --,
   {{0x3e4c00d8,0xddc20009,0x6f099d75,0xbdf800fd}},	//   rėtų_, _uboš, lmec, _برما_,
   {{0xc7a601d3,0x3b0a02fb,0xb8d4193c,0x00000000}},	//   чивк, _леко_, _झक_, --,
   {{0x39599d76,0x7ebc4e1c,0x6f1e1e66,0x9c7c1dab}},	//   buss_, _tépe, ípci, voči,
   {{0xcb130122,0x18181a95,0x38780a21,0x00000000}},	// [b160] _אלה_, _وردک_, perr_, --,
   {{0xf8e00299,0x7cf412c3,0xb5fb01ef,0x6f09033b}},	//   _नदिय, tàri, _abás, hmec,
   {{0x6f094549,0x3ebf7c01,0x00000000,0x00000000}},	//   kmec, khut_, --, --,
   {{0x9c7c01fe,0xdddb9d77,0x7cf40443,0xa186005f}},	//   roči, zduš, ràri, зыкл,
   {{0x9c7c00b8,0x290a0054,0x26d20381,0x2eed0345}},	//   soči, omba_, miyo_, doef_,
   {{0x26d29d78,0x92cc0083,0x6f029d79,0xed59012e}},	//   liyo_, রকে_, _shoc, duž_,
   {{0xdfd00037,0x6f029d7a,0xdddb008b,0x290a9d7b}},	//   ضية_, _phoc, vduš, imba_,
   {{0x6d55006a,0x3ebf00d7,0x00000000,0x00000000}},	//   ązan, ghut_, --, --,
   {{0x38af027d,0x7c8601fd,0x24980051,0xed590124}},	//   _kürt_, пуне, _knrm_, guž_,
   {{0x26d29d7c,0x645e02b3,0x31bb02b8,0xc1bb0122}},	//   hiyo_, ngpi, _הזמנ, _הממש,
   {{0x2d8f9d7d,0x26d29d7e,0x6f024c86,0x1a790f99}},	//   _erge_, kiyo_, _thoc, обны_,
   {{0xed5a38a6,0x26d20381,0x395900ea,0xbf9b016b}},	//   _год_, jiyo_, tuss_, _ליבש,
   {{0x26d2041b,0x7e62008c,0x26c000e0,0x2d8f0207}},	//   diyo_, _icop, dhio_, _grge_,
   {{0xa3ac0324,0x395900ec,0x26de00a2,0xb69b00e5}},	//   गहा_, russ_, éton_, _chân,
   {{0x6c830c74,0x00000000,0x00000000,0x00000000}},	//   _سليم, --, --, --,
   {{0x26d20103,0x0ccd0083,0x26c0011e,0x24980160}},	//   giyo_, রকৃত, ghio_, _anrm_,
   {{0x1ddc0387,0x27ed0067,0x7bdc008d,0x00000000}},	// [b170] मपित, łen_, úruf, --,
   {{0x4427009e,0x39490207,0x00000000,0x00000000}},	//   ùn_, _ivas_, --, --,
   {{0x237916a4,0x57b4002d,0xdcfb0207,0x00000000}},	//   تماد_, _збэт, svuć, --,
   {{0x26c09d7f,0x394902a7,0x00000000,0x00000000}},	//   chio_, _kvas_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e629d80,0xf4840133,0x44259d81,0x00000000}},	//   _acop, _пусн, _ül_, --,
   {{0x38b400be,0xd34700f8,0x6f091008,0x00000000}},	//   _särk_, _ریشه_, tmec, --,
   {{0x394902d7,0xf8bf021d,0x00000000,0x00000000}},	//   _ovas_, mpéu_, --, --,
   {{0x7aef9d82,0x6f099d83,0x224d9d84,0xdceb00ea}},	//   doct, rmec, _idek_, _apgā,
   {{0x7e629d85,0x2eed022e,0x26d29b96,0x38b4312a}},	//   _ecop, soef_, ziyo_, _värk_,
   {{0x3b0a19b6,0x39491c97,0x9c7c0009,0x00000000}},	//   жено_, _avas_, joču, --,
   {{0xe3bf0033,0x5f74186e,0x2d8f02a7,0x9c7c0207}},	//   _আশাব, _سامر, _trge_, doču,
   {{0x68ee0103,0x7e7b023c,0x38b40282,0x2d8f15b7}},	//   tobd, meup, _häri_, _urge_,
   {{0x315600c2,0xa3bd0803,0xdc3c00a0,0x290a9d86}},	//   וישן_, इना_, _záľu, umba_,
   {{0x26c00297,0x26d26451,0x7ebc000d,0x00000000}},	//   thio_, tiyo_, _hépa, --,
   {{0xf484132d,0x7e7b0282,0x224d01cb,0x00000000}},	//   کاری, neup, _ndek_, --,
   {{0x26d206ff,0x34aa03fa,0x26c00009,0x6d4600f4}},	// [b180] riyo_, овао_, rhio_, škav,
   {{0x26d29d87,0x224d44ce,0x26c00054,0x7984002f}},	//   siyo_, _adek_, shio_, _isiw,
   {{0x7e7b0282,0x212d5f0b,0x00000000,0x00000000}},	//   keup, _ateh_, --, --,
   {{0xe1fa2217,0x38af033b,0xdb1a00b5,0x6d5b9d88}},	//   оге_, _fürs_, nztá, kuua,
   {{0x76449d89,0x7ebc00a2,0xd043013b,0x20540043}},	//   maiy, _népa, linə, еӂер,
   {{0x7e629d8a,0x7984002f,0x9c7c0009,0x76441505}},	//   _scop, _msiw, nočt, laiy,
   {{0x63830525,0x442a1442,0x75240bf4,0x00000000}},	//   _игра, _ifb_, lqiz, --,
   {{0x44449d8b,0xf8bb0567,0x2f170086,0x764402b3}},	//   la_, _उत्प, мощь_, naiy,
   {{0xe0da3fe5,0x44440291,0x7ebc00a2,0x614622a9}},	//   _два_, oa_, _cépa, _цеза,
   {{0x7ebc02e1,0x00000000,0x00000000,0x00000000}},	//   _dépa, --, --, --,
   {{0x403302ce,0x7aef0036,0x76441292,0x79849d8c}},	//   _реєс, toct, kaiy, _asiw,
   {{0x44449d8d,0x63a33162,0x764400d7,0x6d5b0dc3}},	//   ha_, änni, jaiy, buua,
   {{0x44449d8e,0x644e5520,0x76449d8f,0x7aef151a}},	//   ka_, _odbi, daiy, roct,
   {{0xfbcf0ef5,0x690b0024,0x7984008c,0x38a60168}},	//   اتی_, _ażer, _dsiw, _kôry_,
   {{0xd7f81a72,0x2f019d90,0x86020107,0x7c2a007a}},	//   дут_, lóga_, _dakٍ_, _iffr,
   {{0x44440012,0x442a598f,0x561d0033,0x7d1800ee}},	//   ea_, _afb_, তর্ক_, _hivs,
   {{0x44449d91,0x09d900c8,0x39490473,0x442a0be2}},	// [b190] fa_, _সরকা, _uvas_, _bfb_,
   {{0x599600a5,0x80b30722,0x9c7c00a0,0x690b035f}},	//   _נכתב_, _अवधे, poču, _eżer,
   {{0x70db0084,0x442a7406,0x3255066d,0xf36751fe}},	//   _बदौल, _dfb_, евер, ьтан,
   {{0x44449d92,0x7d1804ca,0x442a0a8a,0x644e0160}},	//   aa_, _livs, _efb_, _edbi,
   {{0x44449d93,0x7c2a9d94,0x442a00f8,0xe16411cf}},	//   ba_, _offr, _ffb_, ندوي,
   {{0xd1b80041,0x7ebc0248,0x644a0a20,0xc1040037}},	//   باما_, _répa, ófit, نوني,
   {{0x64457152,0x7ebc0248,0x00000000,0x00000000}},	//   mahi, _sépa, --, --,
   {{0x64459d95,0x7c2a9d96,0x59df021a,0x0d851169}},	//   lahi, _affr, नपार, елин,
   {{0x7e7b9d97,0x7d180bde,0x629b0159,0xa3d709a0}},	//   reup, _bivs, _inuo, ापक_,
   {{0x64454189,0x3134049f,0xf0bb0416,0xb16e00b8}},	//   nahi, _рефр, _بارش_, ížeč,
   {{0xeb9916c0,0x7eb521a4,0x7d1802d4,0x4ea70183}},	//   чин_, _lápi, _divs, _орда,
   {{0x64452f59,0x1a6603c5,0x628b2fe5,0x6aad002d}},	//   hahi, ریخی_, ndgo, _coaf,
   {{0xed4e6a01,0x6445149b,0xd010006c,0x7eb50097}},	//   _що_, kahi, _ملے_, _nápi,
   {{0x44444f54,0xdb1a0332,0xfc3104e8,0x6d49009d}},	//   xa_, sztá, _صحت_, msea,
   {{0x6d499d98,0x64459d99,0x67220009,0x6d46003d}},	//   lsea, dahi, _čojs, škat,
   {{0x44449d9a,0x6443008a,0x98a000cb,0x442a0371}},	//   wa_, ðnin, _otić_, _sfb_,
   {{0x6d4962a0,0x9c7c024e,0x7eb50b06,0x7984002f}},	// [b1a0] nsea, počt, _cápi, _usiw,
   {{0x44449d9b,0x6d491093,0xb4637ae1,0x64459d9c}},	//   ua_, isea, лкул, gahi,
   {{0x7c240dac,0x929d004e,0x764408dd,0x442a4212}},	//   _şirk, _chło, paiy, _vfb_,
   {{0x44449d9d,0xaa7b024e,0xf7d70070,0xbb3a0070}},	//   sa_, mnýc, _טויש_, פעני,
   {{0x64459d9e,0xaa7b024e,0xa2b10b54,0x291a9d9f}},	//   bahi, lnýc, _अकर्, _kipa_,
   {{0x444490e8,0x6d4901a6,0x10a317c2,0x64455040}},	//   qa_, dsea, личн, cahi,
   {{0x7eb5024e,0xaa7b024e,0x291a05ca,0x7ae4226b}},	//   _zápi, nnýc, _mipa_, _ojit,
   {{0x6d494e8b,0x66db0328,0x3da630cc,0x6f190090}},	//   fsea, mäkä, ероб, _ciwc,
   {{0x6d499da0,0x7d18003d,0x291a0036,0x301a0037}},	//   gsea, _pivs, _oipa_, _فتاة_,
   {{0x7ae44d56,0x291a541c,0x2246010d,0x7af6004b}},	//   _ajit, _nipa_, laok_, _akyt,
   {{0xaa7b024e,0x54570070,0x31e20033,0x66db0328}},	//   jnýc, עסטן_, _বরিশ, näkä,
   {{0xaa7b1840,0x6d499da1,0x34dd0803,0x9f790036}},	//   dnýc, bsea, _मद्द, _юсуф_,
   {{0x64459da2,0x6d499da3,0x6aad034d,0x7ae4023a}},	//   yahi, csea, _voaf, _djit,
   {{0xdd8f0365,0x7eb52140,0x26f90591,0x6d460bc5}},	//   _دوه_, _rápi, ंत्र_, škas,
   {{0x291a9da4,0x64459da5,0x6aad012f,0xa2b10ea3}},	//   _dipa_, vahi, _toaf, _अकल्,
   {{0x7ae4071f,0x64459da6,0x7cf40310,0x7b2100f6}},	//   _gjit, wahi, càrr, _bœuf,
   {{0x64459da7,0xf8bf00a2,0x291a0103,0x38350279}},	// [b1b0] tahi, upés_, _fipa_, _инпр,
   {{0x7afd9da8,0x98650332,0xaa7b4cbf,0xa3bd3123}},	//   llst, _جیسے_, bnýc, इनल_,
   {{0xf09f01a5,0x764b006c,0xaa7b0187,0xd6d10d93}},	//   _đà_, ógys, cnýc, _نقد_,
   {{0x64459da9,0x22460159,0xf1d2007c,0xf8bf000d}},	//   sahi, gaok_, _देहन, ppés_,
   {{0x64451fd9,0xc2c40037,0xb22401e0,0x216908ce}},	//   pahi, ديني, уміл, фили_,
   {{0x7afd3177,0x656d7e8a,0x00000000,0x00000000}},	//   hlst, mtah, --, --,
   {{0x656d9daa,0x6d490088,0x23e4010b,0x00000000}},	//   ltah, wsea, _бітв, --,
   {{0xf1d2238a,0x7ebc02e1,0x6d499dab,0x7afd310c}},	//   _देवन, _dépo, tsea, jlst,
   {{0x656d9dac,0x6e299dad,0xaa7b00b8,0xbebc013a}},	//   ntah, rceb, znýc, _atīs,
   {{0x6d499dae,0x7af633d4,0x61fb00a8,0x3959027a}},	//   rsea, _skyt, _iyul, drss_,
   {{0xb5fb0079,0x656d9daf,0x38b400be,0xf65f008c}},	//   _scál, htah, _märt_, _klæd_,
   {{0x291a9db0,0xaa7b290b,0xe61f01a5,0x6d4914c0}},	//   _sipa_, vnýc, _ngô_, psea,
   {{0x6d4601cc,0x656d028b,0x3eaf0282,0x98d601e0}},	//   škar, jtah, _iogt_, вівщ,
   {{0xaa7b1840,0x7afd12ba,0x20180392,0xdca50bfe}},	//   tnýc, alst, _úric_, _јаки,
   {{0xf7430370,0x656d03bc,0x7ae4616d,0x98a33f0a}},	//   иеро, etah, _tjit, шире,
   {{0xcf9200c2,0xaa7b024e,0x321f01a5,0x6ea40026}},	//   סטן_, rnýc, _nguy_, कायु,
   {{0xceb20bed,0x656d85f9,0xaa7b024e,0x60c10037}},	// [b1c0] בין_, gtah, snýc, _ollm,
   {{0xaa7b0187,0x3eaf0051,0xfaf900ea,0x66db0421}},	//   pnýc, _logt_, stīt_, täkä,
   {{0x61e99db1,0x213f0118,0x3eaf0223,0x00000000}},	//   _axel, _awuh_, _oogt_, --,
   {{0x7ebc1010,0x60c19db2,0x66db0328,0x61fb0027}},	//   _répo, _allm, räkä, _byul,
   {{0x7ebc0248,0xf1d20efa,0x863700a5,0x80b31365}},	//   _dépl, _देशन, _ברכב_, _अवशे,
   {{0x2126012f,0xed590187,0x61fb00e0,0x69090093}},	//   rqoh_, drž_, _dyul, rþeg,
   {{0x61e91db8,0x7ee6004c,0x03a31d30,0x213f00e0}},	//   _exel, кцие, _киро, _ewuh_,
   {{0x2d863f66,0x999901ba,0xc7b30d85,0x8fa30274}},	//   _psoe_, lasť_, שבה_, раће,
   {{0x61fb00b5,0x7c2d027d,0xe04600af,0x00000000}},	//   _gyul, _şara, _анзи, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34b70122,0x394000f8,0x38b40282,0x7b2100a2}},	//   דפים_, _awis_, _lärs_, _nœud,
   {{0x4fd900c2,0x395902d7,0x7bc801ed,0x00000000}},	//   _אַנד, trss_, rzdu, --,
   {{0x394d105d,0xdd92064e,0x7afd013c,0x1dd90577}},	//   ées_, _خوش_, rlst, _बेपत,
   {{0x79968bd9,0x26c247da,0x3a20023a,0x00000000}},	//   _dryw, _alko_, _egip_, --,
   {{0x7ac72ce2,0xb8670647,0x97251062,0xb8db018d}},	//   _аспе, _یادو, افرو, _अक_,
   {{0x656d5c9a,0x38b40523,0x645805ee,0x00000000}},	//   ttah, _bärs_, óvin, --,
   {{0xcb1400a5,0x7af8021d,0x00000000,0x00000000}},	// [b1d0] _דלק_, _êxta, --, --,
   {{0xfaff01d2,0x656d8c28,0xa5bb2fba,0x6abd9db3}},	//   llë_, rtah, _agóc, lksf,
   {{0x656d9db4,0xa2b4142a,0x38b4013c,0xf8b20070}},	//   stah, _आवश्, _värt_, _השי_,
   {{0x656d008d,0x38b40282,0x2ee60055,0x00000000}},	//   ptah, _färs_, _njof_, --,
   {{0x2124009e,0x865a00a5,0xc6a40043,0xa2b4143a}},	//   _cumh_, _אדרי, _трэи, _आवर्,
   {{0xd0090012,0x6725018d,0xe05700f8,0x00000000}},	//   неле_, _kuhj, ئیات_, --,
   {{0x3d060299,0x83840043,0x38b40282,0x00000000}},	//   _सीधे_, _кыте, _kärr_, --,
   {{0x2a69006d,0x61e99db5,0x6abd0051,0x7cfd0310}},	//   _ncab_, _txel, jksf, mèri,
   {{0x40359db6,0x2b4e00ee,0x68f500d5,0x213f01cb}},	//   _безс, _avfc_, kozd, _uwuh_,
   {{0x60c19db7,0x5ba91353,0x2481033b,0xaba92ee2}},	//   _ullm, еком_, nehm_, евоз_,
   {{0x7a6a3bd5,0x7c9501ca,0x3f671b3a,0x8e7507e5}},	//   нинг_, نشگا, _штаб, _булч,
   {{0x7996006a,0x7eb501ef,0x66e5010b,0x2e3800af}},	//   _pryw, _cápt, dėko, _апць_,
   {{0x6e3b0f20,0x80b90380,0x00000000,0x00000000}},	//   mbub, ्सपे, --, --,
   {{0x7996053e,0xdce902c4,0x6e3b005f,0x7c24013b}},	//   _vryw, oteč, lbub, _şirv,
   {{0x2cb89db8,0xeb999db9,0x869a002d,0x79965089}},	//   örde_, _чий_, нтат_, _wryw,
   {{0x2925004f,0x6abd038e,0x7996016e,0x78bc00f4}},	//   úpaí_, cksf, _tryw, skrv,
   {{0xe5a344cf,0x1dd907b5,0x394000f8,0x00000000}},	// [b1e0] бити, _बेमत, _uwis_, --,
   {{0x88860426,0x03a61181,0xf7f6097f,0x7cfd0392}},	//   _слож, лизо, _مسجد, fèri,
   {{0xfaf90029,0x9cd600a5,0x7cfd0392,0x38b402b1}},	//   brīd_, נועה_, gèri, _wärs_,
   {{0x6d5b01d2,0x2bf60070,0x00000000,0x00000000}},	//   krua, אמען_, --, --,
   {{0x35fa006c,0xc5b600d8,0x60d89dba,0x6e3b00f4}},	//   _سرحد_, _сёнь, tivm, dbub,
   {{0x7ebc00b5,0x6d5b0055,0x7dda008c,0x7cfd13b6}},	//   _gépj, drua, _løsø, bèri,
   {{0x7cfd0176,0x764640f7,0x00000000,0x00000000}},	//   cèri, _keky, --, --,
   {{0x6e3b121e,0x72790786,0x539b011d,0x7d5402fb}},	//   gbub, _исус_, _אילו, авих,
   {{0x6d5b9dbb,0x764600d5,0x00000000,0x00000000}},	//   grua, _meky, --, --,
   {{0xddcb002d,0x2a691ebb,0xbb740bfe,0x00000000}},	//   ţişt, _scab_, агој, --,
   {{0x7eb51fca,0x5fa801c0,0x4f5a00d2,0x68f50300}},	//   _cáps, _कपिल, _سجاد_, vozd,
   {{0x68f50067,0x76469dbc,0x6efe0055,0x672300e0}},	//   wozd, _neky, këbi, _énji,
   {{0x6abd5bd9,0x6e220027,0x7c240139,0x00000000}},	//   rksf, _igob, _şiru, --,
   {{0x5fa806bc,0x9b94002d,0xe7879dbd,0x00000000}},	//   _कपाल, _викц, лубо, --,
   {{0x76468a22,0x68f547bc,0x00000000,0x00000000}},	//   _beky, rozd, --, --,
   {{0x96353f97,0xf1c46ff9,0x6d5d008d,0x79a73cc0}},	//   рнац, वनान, ásag, _брое,
   {{0x68f500ee,0xf8ae042c,0x628272d5,0x00000000}},	// [b1f0] pozd, سکی_, deoo, --,
   {{0xddc22209,0x7cfd12c3,0xdce900b8,0x7646030d}},	//   _obož, tèri, yteč, _eeky,
   {{0xc7ab0079,0x6e22073a,0xd2510079,0x00000000}},	//   _أدخل_, _ogob, قنا_, --,
   {{0x6e229dbe,0x0ce1170c,0x7646053e,0x628212ba}},	//   _ngob, _पद्म, _geky, geoo,
   {{0xa0699dbf,0xe0450390,0xd04a0095,0xdd8628c0}},	//   вала_, анли, lifə, _بو_,
   {{0x2f5534a2,0x7eb50187,0x6e229dc0,0xb5fb0168}},	//   атис, _nápr, _agob, _obáz,
   {{0x256f2485,0x30c9006c,0x64550035,0xd49802fb}},	//   lül_, _یورپ_, _idzi, _сря_,
   {{0x26c99dc1,0x443100ee,0xdce900d5,0x00000000}},	//   nhao_, _hfz_, rteč, --,
   {{0xa2c22fa9,0x256f7cd8,0xd04a0095,0x6e3b046a}},	//   लसर्, nül_, hifə, rbub,
   {{0x6d5b9dc2,0x6447000c,0xeb9903fa,0x1c4502d6}},	//   rrua, _jeji, вио_, шном,
   {{0x64479dc3,0xc0c80043,0xdb220093,0x4423008c}},	//   _meji, _суте_, ærðf, _mgj_,
   {{0x644702e9,0x6d5b01f4,0x256f9dc4,0xddd40124}},	//   _leji, prua, kül_, šašt,
   {{0xddc2000c,0x3ead01f4,0xdca50112,0x64559dc5}},	//   _zbož, mjet_, _вали, _odzi,
   {{0xe8f7434e,0x3ead9dc6,0x256f9dc7,0x764686ac}},	//   иля_, ljet_, dül_, _seky,
   {{0x29040029,0xb8de1f57,0xf74699ad,0x657d0197}},	//   ēma_, _आव_, ребо, _apsh,
   {{0x3ead9dc8,0x44310051,0x068603e6,0x1fe70033}},	//   njet_, _afz_, јган, _ফরাস,
   {{0x4ad8006c,0x256f5f16,0xa44653b7,0x64470107}},	// [b200] _لاکھ_, gül_, инад, _beji,
   {{0x389a0070,0x4431021d,0x3ead5dab,0x7646030d}},	//   _ייִנ, _cfz_, hjet_, _weky,
   {{0x644700a0,0x3ead01f4,0x7d010014,0x07a63242}},	//   _deji, kjet_, ills, _танн,
   {{0x645544db,0x41d20d43,0xa3e70099,0x00000000}},	//   _edzi, _देउस, _बखर_, --,
   {{0x3ead0c21,0x27f7064e,0xf19410be,0x690000c3}},	//   djet_, _مفید_, силь, töeh,
   {{0x6455006a,0x154338ea,0x60f71958,0x899700a5}},	//   _gdzi, _ферм, анія_, יכנס_,
   {{0x656400c3,0x00000000,0x00000000,0x00000000}},	//   luih, --, --, --,
   {{0x3ead00da,0x3f98008a,0xb5fb0037,0x3ebf9dc9}},	//   gjet_, _árum_, _scái, gkut_,
   {{0xd04a0095,0x81d40033,0x7b330395,0x00000000}},	//   zifə, _সুর_, _lăud, --,
   {{0x9c7c00d5,0x00000000,0x00000000,0x00000000}},	//   ančn, --, --, --,
   {{0x256f006c,0x26c00036,0x3ead3e90,0xa5bb00e2}},	//   zül_, kkio_, bjet_, _ngón,
   {{0x65640328,0x6e221857,0x6d420260,0x7d0119fd}},	//   kuih, _ugob, _twoa, alls,
   {{0xfce60e05,0xe8b4073f,0x00000000,0x00000000}},	//   _кодо, ुसूच, --, --,
   {{0xe7f206bb,0x256f006c,0xaa7b0097,0x00000000}},	//   _आँखा_, vül_, mným, --,
   {{0xab27282d,0x64479dca,0xb8ef0066,0xaa7b0187}},	//   _која_, _reji, _शत_, lným,
   {{0x256f9dcb,0x644a008d,0x443100ee,0x00000000}},	//   tül_, ðfin, _sfz_, --,
   {{0xaa7b0187,0x64478255,0x44310176,0x4423021d}},	// [b210] nným, _peji, _pfz_, _pgj_,
   {{0x256f006c,0x35e400d8,0x798d681e,0x7ebc00f7}},	//   rül_, іцтв, _isaw, _dépi,
   {{0x29030496,0x9f5e00da,0x64479dcc,0x69cf00ea}},	//   mlja_, _dytë_, _veji, lzce,
   {{0xb69b0248,0x29039dcd,0x64550067,0x00000000}},	//   _chât, llja_, _wdzi, --,
   {{0x764d9dce,0x3ead9dcf,0x64479dd0,0xd24e5b76}},	//   maay, vjet_, _teji, رنو_,
   {{0x764d018e,0x6455004e,0xaa7b0bca,0x26d905b9}},	//   laay, _udzi, dným, _hmso_,
   {{0x3ead00da,0x987c02b5,0x02a72327,0x7bdc0093}},	//   tjet_, דרוק, _крам, úrul,
   {{0x764d9dd1,0x212b000d,0x798d0103,0x00000000}},	//   naay, _écho_, _osaw, --,
   {{0x31342070,0x3ead9dd2,0x3ebf9dd3,0x29031bd8}},	//   _метр, rjet_, rkut_, klja_,
   {{0x3ead9dd4,0x3ebf9dd5,0x26c001d7,0x5f7708cf}},	//   sjet_, skut_, zkio_, _ناصر,
   {{0x798d0d0d,0x764d80f2,0x5f9500b5,0x3ead9dd6}},	//   _asaw, kaay, _دلائ, pjet_,
   {{0xaa7b0097,0xddd9035f,0x3ead0055,0x00000000}},	//   bným, _kawż, qjet_, --,
   {{0xed592503,0x764d46a4,0xfe700fab,0x6bd500b5}},	//   _сол_, daay, _آدم_, شتگر,
   {{0x6c350ef5,0x29030a66,0x7ebc00a2,0x7e6900b9}},	//   _افغا, glja_, _répi, lgep,
   {{0x5b352087,0xdc360070,0x764d01a8,0xaa461285}},	//   _اعتر, _פאקט_, faay, _лейл,
   {{0x7e699dd7,0x764d7767,0x9f5e01f4,0x752d00a8}},	//   ngep, gaay, _sytë_, fqaz,
   {{0x290302dd,0x6aa49dd8,0x26c09dd9,0xe5a3154b}},	// [b220] blja_, _inif, rkio_, пити,
   {{0x07fa00d1,0x26c07e04,0x387a0371,0x00000000}},	//   _مرجع_, skio_, _ubpr_, --,
   {{0xe29a1126,0x764d001c,0xa2e60945,0xb69b000d}},	//   лаж_, baay, божд, _châs,
   {{0x764d0103,0xa97a0070,0x10f900b5,0x673b0207}},	//   caay, ָאַכ, یبوں_, ćujt,
   {{0xf1d20b4a,0x7ebc006c,0x6aa49dda,0x00000000}},	//   _देखन, _képv, _mnif, --,
   {{0xaa7b0187,0x2bca06fe,0xf99300a5,0x00000000}},	//   vným, ानमा, פרו_, --,
   {{0xef1800ec,0x7e6902b1,0x00000000,0x00000000}},	//   _apļa_, fgep, --, --,
   {{0xa5bb004e,0x1dd90b4a,0xaa7b0187,0x1d3407e5}},	//   _ogól, _बेहत, tným, ония,
   {{0xc6930122,0xa1c60009,0xfbd50033,0x61434fc7}},	//   לאה_, _убад, _সুলত, _нета,
   {{0x6aa4001e,0xb5b700a5,0x3b542b4b,0xaa7b0097}},	//   _anif, צליח_, окор, rným,
   {{0x29031851,0x764d001c,0xb4fb0070,0x6ab64a17}},	//   vlja_, yaay, רליר, _boyf,
   {{0xaa7b00ac,0x00000000,0x00000000,0x00000000}},	//   pným, --, --, --,
   {{0x290300cd,0x80bd0033,0x00000000,0x00000000}},	//   tlja_, ্চর্, --, --,
   {{0x764d01a8,0xac180b5e,0x5ba61461,0x00000000}},	//   waay, _колу_, _гриз, --,
   {{0x9cdb0bed,0x764d018e,0x249102c4,0xb6c73df1}},	//   _תקופ, taay, _razm_, бсай,
   {{0x798d0189,0x36d41c1b,0xbb3b02b5,0x29030612}},	//   _tsaw, поср, _געהי, slja_,
   {{0x764d001c,0x290310ec,0xeb0500dc,0x7aed02c4}},	// [b230] raay, plja_, रतीत_, _ijat,
   {{0x764d0273,0x00000000,0x00000000,0x00000000}},	//   saay, --, --, --,
   {{0x7c2d0723,0x764d02b3,0xdce000cd,0x00000000}},	//   _şark, paay, jumč, --,
   {{0x26d902b1,0xddd90024,0x00000000,0x00000000}},	//   _umso_, _pawż, --, --,
   {{0x60250132,0x00000000,0x00000000,0x00000000}},	//   одла, --, --, --,
   {{0x10a201b8,0x90c51303,0x66e5010b,0xe1f01c73}},	//   дишн, юбле, dėki, رسن_,
   {{0x7e6911cc,0xaa7b008d,0x9ea91d30,0x00000000}},	//   tgep, rnýj, ивка_, --,
   {{0x7aed9ddb,0x8d555084,0x00000000,0x00000000}},	//   _njat, оточ, --, --,
   {{0xc1040088,0x2d94010b,0xed59516d,0x00000000}},	//   _کولي, прэс, шоп_, --,
   {{0x7aed28e5,0xcd280c74,0x7e697031,0xec7600af}},	//   _ajat, حسين_, sgep, опь_,
   {{0x6a862746,0x00000000,0x00000000,0x00000000}},	//   олна, --, --, --,
   {{0x6d4f002a,0x78a500cc,0x00000000,0x00000000}},	//   ácas, _anhv, --, --,
   {{0x7aed01f4,0x0f1801b2,0x272e008d,0x78b70523}},	//   _djat, _اغلب_, _sýn_, _boxv,
   {{0x8afd0755,0x186a00c9,0x52b62088,0x7ebc00f7}},	//   stęp, јави_, _अक्स, _dépu,
   {{0xd7f20037,0x00000000,0x00000000,0x00000000}},	//   ذكر_, --, --, --,
   {{0x7aed01d2,0xb6a30de3,0x78a510db,0x00000000}},	//   _gjat, мисл, _enhv, --,
   {{0x2bc1162b,0x00000000,0x00000000,0x00000000}},	// [b240] शनका, --, --, --,
   {{0x7ebc01ef,0x2d9d0103,0x00000000,0x00000000}},	//   _hépt, _mrwe_, --, --,
   {{0x93460210,0xb5fb0037,0x2f0101ba,0x987b0070}},	//   інде, _scát, lógu_, _דריק,
   {{0xf1db135e,0xe5a60de3,0x68fc933b,0xa2061c80}},	//   _मेहन, _дими, lord, опед,
   {{0x9c7c0a0b,0x68fc01e4,0x29180079,0x70c5021a}},	//   liče, oord, omra_, वसूल,
   {{0x68fc9ddc,0x2574022a,0x399b016b,0x92da0831}},	//   nord, mäl_, יינד, ঠকে_,
   {{0x9c7c33dc,0x00000000,0x00000000,0x00000000}},	//   niče, --, --, --,
   {{0x1ef70037,0x68fc8906,0xb5fb0079,0xbdb41d77}},	//   يعية_, hord, _gcás, збиј,
   {{0x0caa1714,0x65764a5c,0x307600c3,0x00e638d2}},	//   атни_, ntyh, _мужс, _джан,
   {{0xf06310ac,0x7ebc0248,0x68fc2172,0x7aed012e}},	//   _окуп, _répu, jord, _sjat,
   {{0x7aed9ddd,0x6d4f0279,0x9c7c05e2,0x2d9d0b88}},	//   _pjat, ácar, jiče, _erwe_,
   {{0xf3ec0b52,0x9c7c0292,0x8afd0035,0x7b330139}},	//   _করার_, diče, dręc, _săuc,
   {{0x2d969dde,0xae1600c0,0x68fc987f,0x257401ff}},	//   _фрес, देशन_, ford, jäl_,
   {{0x2bca00c4,0xbb2a002d,0x00000000,0x00000000}},	//   ानदा, _кцие_, --, --,
   {{0xd6db9ddf,0x3ea69de0,0x9c7c02f6,0xcb670274}},	//   ата_, _knot_, giče, _даје_,
   {{0xa5350c14,0x00000000,0x00000000,0x00000000}},	//   знач, --, --, --,
   {{0x06cd0033,0xdb170067,0x00000000,0x00000000}},	// [b250] রচলি, ńców, --, --,
   {{0x7afd9de1,0x68fc4562,0x3949067f,0x9c7c1405}},	//   lost, cord, _iwas_, biče,
   {{0xfbca0099,0x00000000,0x00000000,0x00000000}},	//   ानिम, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f9e9de2,0x66c300be,0x00000000,0x00000000}},	//   _artu_, _lõkk, --, --,
   {{0xfbca0e61,0xe0d802ce,0x55ba0122,0x3ea6010b}},	//   ानाम, ові_, _המשו, _anot_,
   {{0x3f9e00cb,0x7ebc00b5,0x602218e2,0x387c01ff}},	//   _crtu_, _néps, ндша, _övre_,
   {{0x0ea903ad,0x7afd01a0,0x68fc564b,0x5187021d}},	//   ский_, jost, zord, _муза,
   {{0x7afd0590,0x68fc01d6,0x3f9e008a,0x7ebc2314}},	//   dost, yord, _ertu_, _répt,
   {{0x2b47001e,0x7ebc1721,0x3ea608b7,0x68fc002a}},	//   _pwnc_, _sépt, _enot_, xord,
   {{0x68fc9de3,0x7ebc01dd,0x7afd9de4,0x394908eb}},	//   vord, _pépt, fost, _awas_,
   {{0x7afd9de5,0x9c7c008b,0x212d00d7,0x290101ef}},	//   gost, viče, _kueh_, _akha_,
   {{0x224d9de6,0x6da50374,0x9916010b,0x41bd0b35}},	//   _meek_, _хила, зьві, ्निस,
   {{0x9c7c02c6,0xa3bd035d,0x20120095,0x224d9de7}},	//   tiče, ेना_, əyib_, _leek_,
   {{0x07a338ea,0x26cb0069,0x2d8d021d,0x00000000}},	//   нарн, _blco_, lwee_, --,
   {{0xcf920779,0x7afd2d1e,0x9c7c04c3,0xf1bd2483}},	//   עטן_, cost, riče, ्नान,
   {{0x68fc4d61,0x38b401ae,0x056650d9,0xc56602fb}},	// [b260] pord, _märz_, яван, якак,
   {{0x9c7c08b7,0xf4840d4f,0x26cb397d,0x00000000}},	//   piče, باری, _elco_, --,
   {{0x224d44c2,0x657600d7,0x7ebc000d,0x00000000}},	//   _beek_, styh, _mépr, --,
   {{0xaacc022e,0x212d0453,0xc7b31804,0x7ebc00f6}},	//   ासिक, _bueh_, _טבת_, _lépr,
   {{0xd24f0a9b,0x76449de8,0x7bc100fe,0x00000000}},	//   انه_, mbiy, hylu, --,
   {{0x7afd3d2c,0x200506d9,0x3ea60298,0xfd079de9}},	//   zost, _byli_, _snot_, _سج_,
   {{0x6d5d0037,0x7afd3ebc,0x44449dea,0xc3060088}},	//   ásan, yost, mb_, _فبرو,
   {{0x44447c39,0x3f9e0b67,0x224d265b,0x76440260}},	//   lb_, _vrtu_, _geek_, nbiy,
   {{0x44440d4b,0x7afd9deb,0x644e0452,0x00000000}},	//   ob_, vost, _kebi, --,
   {{0x644e9dec,0x44449ded,0x3d060722,0xdb1b006c}},	//   _jebi, nb_, _सीखे_, sztü,
   {{0x44440189,0x44380211,0x28b000df,0x7ebc00f7}},	//   ib_, _mfr_, ञानि, _dépr,
   {{0x644e203f,0x645c00d7,0x44380103,0x13df0033}},	//   _lebi, _ldri, _lfr_, _বুড়,
   {{0xdca69dee,0x645c9def,0x44380107,0x0e9b00a5}},	//   _нади, _odri, _ofr_, _לשאל,
   {{0x644e9df0,0x65647946,0x645c01f4,0x442a0345}},	//   _nebi, drih, _ndri, _ngb_,
   {{0x6c7b0122,0x44449df1,0x628002c6,0xe7849df2}},	//   _האופ, db_, _obmo, нуто,
   {{0x44449df3,0x442a02c9,0x44389df4,0x394904f4}},	//   eb_, _agb_, _afr_, _twas_,
   {{0xdb1b1f11,0x224d0088,0x6726035f,0x442a8c16}},	// [b270] sztó, _reek_, _dikj, _bgb_,
   {{0x44389df5,0x76440103,0x644e9df6,0x66ca0187}},	//   _cfr_, abiy, _cebi, _výka,
   {{0x644e9df7,0x76449df8,0x932713cf,0x645c0d11}},	//   _debi, bbiy, سران, _ddri,
   {{0x44441020,0x66ca024e,0x3cf000a1,0x65649df9}},	//   ab_, _týka, ीकडे_, brih,
   {{0x44442845,0x9c7c010b,0x644e00d5,0xc6920070}},	//   bb_, anči, _febi, _סאך_,
   {{0x644e0d21,0x224d161f,0x44442733,0x6f020345}},	//   _gebi, _week_, cb_, _akoc,
   {{0x7ebc1f96,0x224d0223,0x6d400298,0xf83800a5}},	//   _répr, _teek_, epma, הנות_,
   {{0x3eb90093,0x644e2cc2,0x7c3819c1,0xa5bb0079}},	//   ðst_, _zebi, _afvr, _agói,
   {{0x628b9dfa,0x80270e3a,0x3cfe3bf9,0x644e5fd8}},	//   mego, _فرام, fotv_, _yebi,
   {{0x628b9dfb,0x62999dfc,0x2d8d0345,0x75270051}},	//   lego, ldwo, rwee_, _jijz,
   {{0x644526c9,0x752702a2,0x752f00fe,0x00000000}},	//   ibhi, _mijz, _lucz, --,
   {{0x628b9dfd,0xbe151c51,0x764f00ee,0x63a364ed}},	//   nego, _قواع, _necy, änny,
   {{0xed4e9dfe,0x6f1b0036,0x6726009f,0x00000000}},	//   _шо_, mmuc, _rikj, --,
   {{0x6f099dff,0x628b20d9,0x6d590260,0x765d00d5}},	//   llec, hego, _ivwa, _adsy,
   {{0xa3dd020c,0x64450312,0x99ce0033,0xd70601e0}},	//   _तेल_, dbhi, রপেক, дзви,
   {{0x644e9e00,0x44449e01,0x628b3802,0x44389e02}},	//   _sebi, wb_, jego, _sfr_,
   {{0x76449e03,0x9c7c0496,0x628b9e04,0x75270a75}},	// [b280] rbiy, liča, dego, _bijz,
   {{0x444401a9,0x6f099e05,0x6f1b01ae,0x76440381}},	//   ub_, hlec, hmuc, sbiy,
   {{0x9c7c0a78,0x6f091321,0x764f0176,0x67260223}},	//   niča, klec, _fecy, _tikj,
   {{0x656411d7,0x6606623f,0x6d400345,0x628b29ca}},	//   prih, _tykk, ypma, gego,
   {{0x644e1138,0x6f099e06,0x4438027a,0xa2da000c}},	//   _tebi, dlec, _tfr_, पोष्,
   {{0x6f099e07,0x6f029e08,0x645c9e09,0x9c7c0a66}},	//   elec, _skoc, _udri, kiča,
   {{0x6f099e0a,0xdfd00037,0x6d4b0211,0x6d590107}},	//   flec, طية_, _awga, _avwa,
   {{0x628b0207,0x9c7c00cd,0x75270051,0x6f090f00}},	//   cego, diča, _zijz, glec,
   {{0x22468ec2,0xf53f0a8a,0x24989e0b,0x00000000}},	//   mbok_, _gråd_, _karm_, --,
   {{0xa2da162b,0x9c7c3957,0x673e025c,0xd24f006c}},	//   पोर्, fiča, _otpj, _منہ_,
   {{0x6f0909ab,0x7d08022a,0x9c7c011c,0x3cfe02d7}},	//   blec, rlds, giča, rotv_,
   {{0x7c2d01d6,0x03570070,0x6d409e0c,0x24981a42}},	//   _şart, ויטש_, ppma, _larm_,
   {{0x673e005f,0x22460345,0xace901df,0x00000000}},	//   _atpj, ibok_, _کرنل_, --,
   {{0x9c7c0a78,0x31669e0d,0x628b9e0e,0x6f00543f}},	//   biča, iroz_, zego, lomc,
   {{0xa3dd0456,0x764f00e9,0x628b61d0,0x75270223}},	//   _तें_, _pecy, yego, _rijz,
   {{0x4e022f78,0xbbca06d9,0x290a02d7,0x929d0067}},	//   _लडाई_, ानीक, alba_, _okła,
   {{0x310e07df,0x99480037,0x22463356,0x00000000}},	// [b290] िताः_, _قليل_, dbok_, --,
   {{0x24980fa0,0x00000000,0x00000000,0x00000000}},	//   _carm_, --, --, --,
   {{0x644509c3,0xdce90254,0x6f099e0f,0x75270223}},	//   rbhi, steć, ylec, _vijz,
   {{0x752704ce,0xd25b00d8,0x217501e0,0x2d860051}},	//   _wijz, іце_, еукр, _opoe_,
   {{0x9c7c0f44,0x62999e10,0xa1580de9,0x463a0070}},	//   ziča, rdwo, дачу_, _מערע,
   {{0x628b9e11,0x3cf80066,0x6d5d0079,0x4f9503e6}},	//   sego, ँवों_, ásam, ериу,
   {{0x628b0523,0x656d0a4e,0x6f099e12,0xfe710037}},	//   pego, luah, tlec, هدة_,
   {{0xf53f0c66,0x2735013c,0x9c7c030a,0x26c90207}},	//   _tråd_, _mån_, viča, nkao_,
   {{0x6f099e13,0x9980004e,0x273502df,0x656d011e}},	//   rlec, _dziś_, _lån_, nuah,
   {{0xc4d200c2,0x91e40202,0x9c7c01cc,0x6f099e14}},	//   ָגט_, _рође, tiča, slec,
   {{0x2735022a,0x6f091110,0xb0ac0387,0x3b0a3af1}},	//   _nån_, plec, चारग, зено_,
   {{0x9c7c1a2e,0x5fd829ce,0x73da016b,0x656d023c}},	//   riča, _भेटल, פֿיצ, kuah,
   {{0x9c7c068b,0xa3e614ab,0x66ca0097,0x213f0069}},	//   mičn, _बेन_, _sýko, _jtuh_,
   {{0x9c7c4693,0x213f034d,0x00000000,0x00000000}},	//   ličn, _mtuh_, --, --,
   {{0x9cd60052,0x8cac0035,0x3ebd35df,0xe9df0093}},	//   _רוצה_, जारो, _kowt_, rbúa_,
   {{0x9c7c824d,0x7bda0052,0x66ca1840,0x225f00e0}},	//   ničn, _מקצו, _výko, _nduk_,
   {{0x27ff037a,0x656d010d,0x24980553,0x5ee7021a}},	// [b2a0] ğuna_, guah, _parm_, _जगन्_,
   {{0x225f20fb,0xca4a00d1,0x33f6692c,0x850608cf}},	//   _aduk_, _بلکه_, нчес, روان,
   {{0x213f0118,0x929d004e,0x24985c1b,0x69c69e15}},	//   _atuh_, _skła, _varm_, lyke,
   {{0x656d1ea7,0x26c90506,0x8ca10066,0x24989e16}},	//   buah, ckao_, _कोसो, _warm_,
   {{0x9c7c9e17,0x27f20029,0x22469e18,0x326500d4}},	//   dičn, šanā_, rbok_, ттєв,
   {{0x225f0009,0x7ae69e19,0x31660065,0x6acc012f}},	//   _eduk_, hikt, rroz_, ासुर,
   {{0x9c7c02f0,0x6f0000f2,0x929d0035,0xb4db009e}},	//   fičn, tomc, _wkła, _ftàb,
   {{0xe2972c11,0x9c7c0496,0xc7b30bed,0xdd90211b}},	//   _пас_, gičn, רבה_, لوب_,
   {{0x394001e8,0xe0da277d,0x929d004e,0x25a09e1a}},	//   _ntis_, _ева_, _ukła, nvil_,
   {{0x236702cc,0x20120095,0x2a609e1b,0x443a4605}},	//   šnje_, əyin_, _adib_, ncp_,
   {{0xdeef247f,0x9c7c10ec,0x39409e1c,0xa8030095}},	//   _бы_, bičn, _atis_, _çıxm,
   {{0x7ec600f7,0x25a00009,0x00000000,0x00000000}},	//   _dépê, kvil_, --, --,
   {{0x66ca0187,0x2735013c,0xc98400af,0x212b02a2}},	//   _výkl, _sån_, лури, _écht_,
   {{0x2a600669,0x25a00009,0x52bd00b4,0x00000000}},	//   _edib_, dvil_, _ऍक्स, --,
   {{0xb90902cb,0x3940022e,0xf53f2172,0x7ae60c47}},	//   _मग_, _etis_, _stå_, bikt,
   {{0x569434a2,0xf1c60028,0x7c250187,0x656d023c}},	//   ласт, _đánh_, _úhra, tuah,
   {{0x6aad000e,0x69c69e1d,0x25a00009,0xdce900af}},	// [b2b0] _inaf, cyke, gvil_, _înăl,
   {{0x9c7c0169,0x26c9022f,0x47359e1e,0x656d00d7}},	//   zičn, skao_, _инос, ruah,
   {{0x290319c6,0x26c90207,0x527500af,0x7c3a0098}},	//   moja_, pkao_, вулу, ictr,
   {{0xd6db1728,0x29039e1f,0x68e702a2,0x00000000}},	//   _хто_, loja_, lijd, --,
   {{0x9c7c02f6,0x6aad002f,0x00000000,0x00000000}},	//   vičn, _mnaf, --, --,
   {{0x29039e20,0x9c7c016f,0xd0090043,0x68e702a2}},	//   noja_, dičo, меле_, nijd,
   {{0x9c7c02dd,0x6aad152b,0x7d0155c6,0x00000000}},	//   tičn, _onaf, vols, --,
   {{0x290300c3,0x225f0118,0x6aad001c,0x00000000}},	//   hoja_, _uduk_, _nnaf, --,
   {{0x9c7c02dd,0x29036f6f,0x7ae69e21,0x7d012c9a}},	//   ričn, koja_, vikt, tols,
   {{0x9c7c0888,0x6aad9e22,0x629b023c,0x29031466}},	//   sičn, _anaf, _hauo, joja_,
   {{0x76560107,0x7ae65d1b,0x9c7c15d7,0x29039e23}},	//   yayy, tikt, pičn, doja_,
   {{0xd010006c,0x78be0009,0x4b23002d,0x6aad099e}},	//   _چلے_, _sopv, имэв, _cnaf,
   {{0x7ae69e24,0x7d01004e,0x645701ed,0x00000000}},	//   rikt, pols, kaxi, --,
   {{0x7ae69ccd,0x29030a03,0x69c601bc,0x6aad0103}},	//   sikt, goja_, ryke, _enaf,
   {{0x6d5b9e25,0x66e69e26,0x4807499a,0x645700a8}},	//   lsua, вова, верн_, daxi,
   {{0x6e3b02c2,0x24640029,0xe3b20609,0x25a03cd6}},	//   ncub, zīmē_, یرا_, tvil_,
   {{0x7ae49e27,0x29039e28,0x78be01bf,0x64574d05}},	// [b2c0] _imit, boja_, _topv, faxi,
   {{0x2903245c,0xa44308ce,0xe0bc0831,0x00000000}},	//   coja_, инуд, _অগ্ন, --,
   {{0x6d5b02c2,0x443a0282,0x25a002c4,0x7ae49e29}},	//   hsua, rcp_, svil_, _kmit,
   {{0x61460a93,0xd04101c2,0x25ad008b,0x00000000}},	//   веда, _illə, _šele_, --,
   {{0x6d5b5b0b,0x28a70035,0x7ae4030d,0x00000000}},	//   jsua, खाचि, _mmit, --,
   {{0x04439e2a,0x9c7c0334,0x70be0e6f,0x00000000}},	//   _верн, vičo, ्सेल, --,
   {{0xc6070033,0x66d1013c,0x7ae404d5,0x00000000}},	//   লেদা_, _håka, _omit, --,
   {{0x9c7c3f23,0xe81a0461,0x0cca170c,0x6f1900e5}},	//   tičo, _धरना_, िस्म, _chwc,
   {{0x5bca035d,0xaca9006c,0x127b0070,0x62821eb8}},	//   ान्व, کھنے_, _קאמע, mfoo,
   {{0x6282053e,0x7ae49e2b,0xe6bf045c,0x4c9403fa}},	//   lfoo, _amit, _एक्ज, ћинс,
   {{0x29039e2c,0x00000000,0x00000000,0x00000000}},	//   voja_, --, --, --,
   {{0x68e701e4,0x628202ee,0xdb14008d,0x7e980413}},	//   wijd, nfoo, ðaða, _سنتر_,
   {{0x29039e2d,0x7ae49e2e,0x5ee706fe,0x80b90803}},	//   toja_, _dmit, _जगत्_, ्सचे,
   {{0x7ae4955d,0x5ba61c89,0xfce32ef5,0x00000000}},	//   _emit, _ариз, _кочо, --,
   {{0xc7c40cf9,0x29039e2f,0x68e70120,0x6aad0069}},	//   асти, roja_, rijd, _tnaf,
   {{0x6aad0054,0x8f9b0070,0x29039e30,0x212c0031}},	//   _unaf, וילי, soja_, _lidh_,
   {{0x963400d8,0x2903212b,0xa6159e31,0x628200be}},	// [b2d0] рнуц, poja_, умач, dfoo,
   {{0x03c72aa9,0xca2a0070,0x6d5d0172,0x6d4208c7}},	//   ксем, _אופֿ, ásai, _mtoa,
   {{0x64579e32,0x7e6200ac,0x442700c3,0x68e50211}},	//   raxi, _odop, än_, _imhd,
   {{0xe8e10019,0x64570042,0x212c0284,0x6d5d00ea}},	//   _đột_, saxi, _aidh_, šsai,
   {{0x212c0014,0x21690210,0x6d420139,0x208901af}},	//   _bidh_, хили_, _ntoa, ейли_,
   {{0x92e30083,0x200c0345,0xaf99496e,0xf53f0523}},	//   নকে_, _bydi_, етих_, _gråa_,
   {{0x6d4201a3,0x2f54010b,0xd0060f8c,0x212c0211}},	//   _atoa, атыс, леше_, _didh_,
   {{0xdd910ad9,0x64551043,0x6d5b9e33,0x200c9e34}},	//   موع_, _hezi, tsua, _dydi_,
   {{0x6d5b9e35,0xa1940279,0x6e3b9e36,0x44319e37}},	//   usua, _катч, rcub, _kgz_,
   {{0x6e3b09ab,0x9c7c0121,0x7ae4593a,0x332d0024}},	//   scub, ličj, _smit, _hiex_,
   {{0x6d5b9e38,0xa3d6046c,0xd0110082,0x64559e39}},	//   ssua, िनय_, _الا_, _mezi,
   {{0xd94607c1,0x64559e3a,0xa96a03fa,0xcf270833}},	//   леми, _lezi, нима_, _شراي,
   {{0x60c1247d,0xdbc900ab,0xc27a0070,0x332d0024}},	//   _kolm, _rõõm, ערשי, _miex_,
   {{0x64551045,0x8d5a0122,0x8b959d83,0x66d101ff}},	//   _nezi, _טכני, _брич, _råka,
   {{0x657d012f,0x66d10c61,0x7bc80035,0x00000000}},	//   _aqsh, _såka, cydu, --,
   {{0x7ae49e3b,0x66e30009,0xdb0400a2,0x332d0069}},	//   _umit, боса, _orné, _niex_,
   {{0x64557144,0x25a60037,0x399f00ee,0xdb0900f8}},	// [b2e0] _bezi, íol_, _päsť_, _جزوه_,
   {{0x779402fd,0xf65f008c,0x00000000,0x00000000}},	//   _پیرا, _slæt_, --, --,
   {{0x332d2251,0x64559e3c,0x62829e3d,0x287b0122}},	//   _biex_, _dezi, tfoo, _אנימ,
   {{0xe1fa3534,0x20d00211,0x23660506,0x64550103}},	//   нге_, _càin_, čoj_, _eezi,
   {{0x60c19e3e,0x20d00284,0x63a70103,0xa05401e0}},	//   _bolm, _dàin_, _erjn, авлі,
   {{0x64559e3f,0x26c2022e,0x23670496,0xb42641bd}},	//   _gezi, _hoko_, šnja_, _معزو,
   {{0x26c29e40,0xbf0f02cb,0x6d422000,0x60c16de5}},	//   _koko_, ातून_, _stoa, _dolm,
   {{0x26c29e41,0x64559e42,0x332d0024,0x443102d7}},	//   _joko_, _zezi, _giex_, _zgz_,
   {{0x50466444,0x7ebc006c,0x26c29e43,0x64559e44}},	//   _безб, _képz, _moko_, _yezi,
   {{0x26c22505,0x9c7c1ac4,0x859702b5,0x60c10ce9}},	//   _loko_, mičk, נדיג_, _golm,
   {{0x69c0081b,0x9b430416,0xee86010b,0xfaf900ea}},	//   ämen, ینیو, _было, krīt_,
   {{0xbda60125,0xdfcf017e,0x26c20044,0x3952016e}},	//   _محتو, _عين_, _noko_, _bwys_,
   {{0x9c7c1269,0x7bda1f11,0x6d420054,0x00000000}},	//   ničk, sztu, _utoa, --,
   {{0x3aeb021e,0x752e009f,0x3952016e,0x00000000}},	//   _bòpè_, _nibz, _dwys_, --,
   {{0x64559e45,0x9c7c0254,0xdc3c02c6,0xbb4310b4}},	//   _rezi, hičk, nšči, _лејк,
   {{0x64559e46,0x00000000,0x00000000,0x00000000}},	//   _sezi, --, --, --,
   {{0x54553f6e,0xa3dd0953,0x64559e47,0x9c7c201d}},	// [b2f0] иват, _तेज_, _pezi, jičk,
   {{0xf53f4b47,0x9c7c531e,0xdc3c00d8,0x2bb81604}},	//   _från_, dičk, kšči, इमपा,
   {{0x925903ad,0x26c201ed,0x5c370070,0x60c12069}},	//   вает_, _foko_, ארבן_, _rolm,
   {{0x6455030d,0x9c7c0254,0x60c19e48,0x00000000}},	//   _wezi, fičk, _solm, --,
   {{0x64559e49,0x60c19e4a,0x9c7c0926,0xb46500d1}},	//   _tezi, _polm, gičk, _نگاه,
   {{0xe0570a86,0x656d00f8,0xf95832e3,0xd5ae00b5}},	//   ایات_, mrah, נסות_, _کہے_,
   {{0x20540210,0x60c19e4b,0xa3dd0099,0x764d0103}},	//   стір, _volm, _तेच_, obay,
   {{0x764d9e4c,0x8c0a00c8,0x9c7c3e39,0x8d659e4d}},	//   nbay, রধান_, bičk, авие,
   {{0x798d006f,0x60c19e4e,0x9c7c0097,0x660f1ba3}},	//   _npaw, _tolm, cičk, _jyck,
   {{0x660f4b47,0x3b8511eb,0x656d0a4e,0xdc3c008b}},	//   _myck, алог, irah, bšči,
   {{0x660f022a,0x764d9e4f,0x5f9500b5,0x20d001da}},	//   _lyck, kbay, _خلائ, _màil_,
   {{0x656d9e50,0x3eaf150b,0x00000000,0x00000000}},	//   krah, _ungt_, --, --,
   {{0x26c29e51,0x660f013c,0x656d12e0,0x9f0401cb}},	//   _roko_, _nyck, jrah, _اونو,
   {{0x6d499e52,0x26c29e53,0x656d9e54,0x4dda00a5}},	//   mpea, _soko_, drah, _בחנו,
   {{0x9c7c10ec,0x26c202e9,0x6d499e55,0xeb99002d}},	//   zičk, _poko_, lpea, _рий_,
   {{0x764d18ad,0xdce2007a,0x973500af,0xf65f8857}},	//   gbay, _ipoġ, сэрч, _slær_,
   {{0x656d9e56,0x7afd9e57,0x6d499e58,0x2bd300b4}},	// [b300] grah, érte, npea, दनवा,
   {{0x2ed209b8,0x9c7c0252,0x6d499e59,0x20d000f1}},	//   _तत्त, vičk, ipea, _càil_,
   {{0x3dbd00c8,0x26c21d86,0x656d9e5a,0x764d3599}},	//   েছিল, _toko_, arah, bbay,
   {{0x9c7c01cc,0x656d9e5b,0xdc3c008b,0xdce2009f}},	//   tičk, brah, všči, _mpoġ,
   {{0xa3e60006,0x6724003c,0x20d0009e,0x660f2670}},	//   _बेर_, mmij, _fàil_, _gyck,
   {{0x9c7c0537,0x273c9e5c,0x66d800d5,0x3f660dec}},	//   ričk, _kín_, _díke, атиб,
   {{0x6d49262d,0x9c7c19f6,0x2f0100a0,0xdce20024}},	//   epea, sičk, lógy_, _npoġ,
   {{0x273c00fb,0x3de70083,0x9c7c1b97,0xbe8a03fa}},	//   _mín_, _পড়ল, pičk, тске_,
   {{0x61431368,0x9c7c0496,0x00000000,0x00000000}},	//   _мета, liči, --, --,
   {{0x5cc60009,0x273c01ef,0xafe60b25,0xdc3c008b}},	//   рсиз, _oín_, _козл, pšči,
   {{0x50b53d9f,0x764d190b,0xa3d61f4c,0x9c7c0928}},	//   _усту, ybay, िनि_, niči,
   {{0x7b22000d,0x67249e5d,0x66d10a8a,0x00000000}},	//   _sœur, jmij, _råko, --,
   {{0x2c0602cb,0x66d103d0,0x00000000,0x00000000}},	//   _सुरू_, _såko, --, --,
   {{0xa3d63efe,0x386d01ae,0x660f01ff,0x66d10523}},	//   िना_, ßer_, _ryck, _påko,
   {{0x386d08a1,0xa3e60907,0x57a403e6,0x9c7c19be}},	//   ğer_, _बेल_, ошта, jiči,
   {{0xd6d809a7,0x9c7c9e5e,0x386d01fb,0x764d08dd}},	//   ату_, diči, şer_, ubay,
   {{0x764d048f,0x672f0176,0x89da00b5,0xef11016b}},	// [b310] rbay, _vicj, _موٹر_, פּל_,
   {{0xb895004f,0x672400b9,0x764d592a,0x656d6de5}},	//   _الدع, amij, sbay, rrah,
   {{0x656d2a85,0x06cc0831,0x00000000,0x00000000}},	//   srah, রোধি, --, --,
   {{0x660f06d7,0x2367008b,0x7d080207,0x569428fa}},	//   _tyck, šnjo_, hods, _дают,
   {{0xe1f011c0,0x7d0801a2,0xa0699e5f,0x00000000}},	//   وسه_, kods, гала_, --,
   {{0x66d8024e,0x248a00d7,0x9c7c0121,0x00000000}},	//   _víke, _gbbm_, biči, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77f8011d,0x29f800e2,0x00000000,0x00000000}},	//   ימוד_, ọai_, --, --,
   {{0xdcfb9e60,0x6d49000d,0x7b330160,0x00000000}},	//   stuč, upea, _lăut, --,
   {{0x2ba50ae0,0x6d499e61,0x672400cb,0x66d101ff}},	//   _pēc_, rpea, zmij, _såkl,
   {{0x1fe50033,0xfaa60ded,0xcfe50033,0xe2170c03}},	//   _পুরস, бано, _পুরন, _तरुण_,
   {{0x2d99003c,0x6d499e62,0xb5fb0184,0xb4db009e}},	//   ħseb_, ppea, _adám, _stàl,
   {{0xdca54234,0x273c008a,0x09cb0033,0xfe7000d1}},	//   _гали, _sín_, _লেবা, _زدن_,
   {{0x2eed9e63,0x7b3300af,0x1c0200ab,0xbbe800f8}},	//   lief_, _băut, _रुकल_, اریم_,
   {{0xb8f006bb,0xdc120095,0x7b330043,0xe9df1c5b}},	//   _शव_, _işğa, _căut, azú_,
   {{0x9c7c9e64,0x3ebf0f1a,0x273c7491,0x28a80387}},	//   viči, njut_, _vín_, _छोरि,
   {{0x67249e65,0xb4660763,0x9986004f,0xb5fb00b8}},	// [b320] rmij, йкал, _الخو, _udál,
   {{0x67240c21,0x2eed309a,0x273c01a5,0xdce93c73}},	//   smij, hief_, _tín_, kreč,
   {{0x1d160070,0x00000000,0x00000000,0x00000000}},	//   צקער_, --, --, --,
   {{0x9c7c31f1,0x68ee0be2,0x2d8f0345,0x2d030099}},	//   riči, libd, _opge_, रकुल_,
   {{0x9c7c7abe,0x7b1d002a,0x2eed0a81,0x00000000}},	//   siči, léuc, dief_, --,
   {{0x290a9e66,0x26c0011c,0x66ca0187,0x9c7c0169}},	//   noba_, ljio_, _výku, piči,
   {{0x645e9e67,0x7d080169,0x2d9d021e,0x9346002d}},	//   mapi, vods, _aswe_, _ынве,
   {{0x645e56ad,0x2eed053e,0x26c09e68,0xb3f70277}},	//   lapi, gief_, njio_, _המלח_,
   {{0x7cd8386a,0xa3d60026,0xa1130088,0x7d089e69}},	//   имир_, िनव_, _کولت, tods,
   {{0x645e280c,0x00000000,0x00000000,0x00000000}},	//   napi, --, --, --,
   {{0x7d089e6a,0xdee69e6b,0x290a088a,0x8af9210e}},	//   rods, _ложи, doba_, инос_,
   {{0x645e9e6c,0x3f9e9e6d,0xf8d12135,0xed5a0d6e}},	//   hapi, _istu_, हस्प, _бод_,
   {{0x645e9e6e,0x1ea90372,0x7d080097,0xf53f03d0}},	//   kapi, _خالي_, pods, _pråm_,
   {{0x290a01a8,0x645e9e6f,0x7d7b100a,0x00000000}},	//   goba_, japi, _ענוו, --,
   {{0x368b005f,0x67d428ea,0x645e919e,0xccf800b8}},	//   лсан_, пору, dapi, mně_,
   {{0xccf8000c,0x2d840009,0x20cb008c,0xe3df0033}},	//   lně_, otme_, _høit_, _বুঝব,
   {{0x634501c8,0xfaf800f8,0x290a0371,0xdce90207}},	// [b330] _mėne, _دروغ_, boba_, zreč,
   {{0x7aef92d8,0x645e9e70,0x290a0f5d,0xadeb0006}},	//   lict, gapi, coba_, _जइसन_,
   {{0x43941174,0x16350086,0x2d8400be,0x66d10282}},	//   захс, _меня, htme_, _jåkk,
   {{0x7aef75bc,0xdce938cb,0xd0480095,0x9c7c0207}},	//   nict, vreč, _ildə, miču,
   {{0x3f9e9e71,0xccf800b8,0x416b0274,0x00000000}},	//   _astu_, kně_, ујем_, --,
   {{0x661d0029,0xccf801c0,0x9fc92c72,0x3949021d}},	//   _izsk, jně_, игла_, _mtas_,
   {{0x2eed0a45,0xccf8000c,0x00000000,0x00000000}},	//   tief_, dně_, --, --,
   {{0xee3936eb,0x63b40097,0x290a9e72,0x25a900d5}},	//   шни_, šený, zoba_, oval_,
   {{0x7aef4827,0x2eed0a45,0x39498e10,0x6da51eb9}},	//   dict, rief_, _ntas_, ципа,
   {{0x2a691051,0x2eed28e9,0xdce99e73,0x6f040a61}},	//   _adab_, sief_, preč, čica,
   {{0x39493635,0x66d8008a,0xeaba516d,0xf53f15ed}},	//   _atas_, _líka, айн_, _bråk_,
   {{0xeb960086,0x290a0010,0xc9aa0370,0x3b0a0185}},	//   цию_, woba_, авме_, ремо_,
   {{0xdd9401c8,0x290a000e,0xccf801c0,0x6458008a}},	//   _нацы, toba_, bně_, ðvik,
   {{0x26d99e74,0xccf800b8,0x6efe00ea,0x25a903d0}},	//   _also_, cně_, mība, dval_,
   {{0x290a7124,0x6efe0029,0x645e9e75,0x68ee0510}},	//   roba_, lība, vapi, ribd,
   {{0x645e0054,0x7e7b9e76,0x290a3588,0x7aef0176}},	//   wapi, ngup, soba_, cict,
   {{0x6efe0029,0x056602ce,0x645e9e77,0x54c600af}},	// [b340] nība, юван, tapi, обаб,
   {{0xa3d574a8,0x6aa4002f,0xdb210086,0x7b340139}},	//   ाईं_, _haif, ätök, _găur,
   {{0x6aa49e78,0x39849e79,0xadeb021a,0x00000000}},	//   _kaif, lös_, _जेसन_, --,
   {{0x645e9e7a,0x41aa0ca6,0xccf801c0,0x914a0011}},	//   sapi, ивен_, zně_, ачка_,
   {{0xccf801c0,0x3984418e,0x20184054,0x6aa43b03}},	//   yně_, nös_, _šri_, _maif,
   {{0x6efe0029,0x3d030067,0x65640b4f,0x8f46021d}},	//   dība, रकों_, msih, охид,
   {{0x63831964,0xccf8000c,0x4444028b,0xc05900d8}},	//   _огра, vně_, mc_, сіі_,
   {{0x44449e7b,0x764401fb,0xa2d60312,0xadeb0066}},	//   lc_, nciy, _بيرت, _जेहन_,
   {{0x645c1581,0x44449e7c,0xccf8000c,0x65649e7d}},	//   _keri, oc_, tně_, nsih,
   {{0x44449e7e,0x645c02e9,0x44384160,0x00000000}},	//   nc_, _jeri, _jgr_, --,
   {{0x44449e7f,0x44389e80,0x2018008a,0xccf801c0}},	//   ic_, _mgr_, _ári_, rně_,
   {{0x6aa4230d,0xccf801c0,0xe8e10019,0x645c9e81}},	//   _caif, sně_, _đốt_, _leri,
   {{0x6efe0080,0x7e609e82,0x645c9d14,0xccf801c0}},	//   cība, mamp, _oeri, pně_,
   {{0x645c9e83,0x7e609e84,0x4444117f,0x9c7c00cd}},	//   _neri, lamp, jc_, tiču,
   {{0x25a90051,0x7aef9e85,0x3cf800ab,0x00000000}},	//   wval_, pict, ुवीं_, --,
   {{0x7e603b4a,0x645c9e86,0x44449e87,0x4e1e0035}},	//   namp, _aeri, ec_, _पराई_,
   {{0x645c9e88,0x5f0b0edf,0x6564010d,0x44449e89}},	// [b350] _beri, ावत्_, gsih, fc_,
   {{0x645c1221,0x7e609e8a,0x44440009,0x63ae009e}},	//   _ceri, hamp, gc_, _brbn,
   {{0x6efe0029,0x44389e8b,0x25a90cd9,0x628007c0}},	//   zība, _dgr_, sval_, _bcmo,
   {{0x7e6000d8,0x645c1eb8,0x63ae00d5,0x479a011d}},	//   jamp, _eeri, _drbn, _פירס,
   {{0x27ff036a,0x78a572a3,0x661d0029,0x60c80168}},	//   ğunu_, _kahv, _uzsk, _bodm,
   {{0x645c9e8c,0x850503c5,0xb5fb004f,0x78a59e8d}},	//   _geri, _روزن, _ndái, _jahv,
   {{0x64459e8e,0x765d0c1f,0xa3d6012f,0xd34303c5}},	//   mchi, _kesy, िनः_, _آفری,
   {{0x64459e8f,0x645c3400,0x6efe0029,0x201b0095}},	//   lchi, _zeri, tība, əqil_,
   {{0x645c9e90,0x765d9e91,0x75359e92,0xdea400e0}},	//   _yeri, _mesy, _kizz, بینی,
   {{0x7aed9e93,0x75350069,0x6aa41051,0x753d2510}},	//   _amat, _jizz, _saif, _musz,
   {{0x64459e94,0x6efe0080,0x75359e95,0x753d9e96}},	//   ichi, sība, _mizz, _lusz,
   {{0x6efe00ea,0x64459e97,0x319d0359,0x00000000}},	//   lībn, hchi, _kňz_, --,
   {{0x64450d3c,0xec6e10a4,0x78a50118,0x3f8700f4}},	//   kchi, _пп_, _bahv, ltnu_,
   {{0x7aed0291,0xdca529e5,0x17fa004f,0x75359e98}},	//   _emat, _хаки, مرأة_, _nizz,
   {{0x6aa49e99,0x753d9e9a,0x61e202fb,0x44380088}},	//   _taif, _ausz, zzol, _rgr_,
   {{0x3b070133,0x443801a6,0x6445033b,0x753d0d7f}},	//   _нещо_, _sgr_, echi, _busz,
   {{0x7644027b,0x765d0107,0x6603002d,0xa3de01c0}},	// [b360] rciy, _desy, епта, दैन_,
   {{0x6564005d,0x44449e9b,0x644530bc,0x753d0035}},	//   rsih, uc_, gchi, _dusz,
   {{0x75359e9c,0x44449e9d,0x645c9e9e,0x7aed0297}},	//   _dizz, rc_, _veri, _ymat,
   {{0xd7bb01f3,0x44449e9f,0x78a50496,0x62996d4e}},	//   _הצטר, sc_, _zahv, gewo,
   {{0x60c84a9c,0x7e609ea0,0xa928010b,0x9c7c00d5}},	//   _podm, vamp, pažį, lhče,
   {{0x64450133,0x5f94946a,0x75350103,0x7e609ea1}},	//   cchi, дикт, _gizz, wamp,
   {{0x7e609ea2,0x6d4b01c8,0x61e2006c,0x6d591f1d}},	//   tamp, _atga, szol, _awwa,
   {{0x62990069,0x6f04011c,0x7535030d,0x00000000}},	//   cewo, čico, _zizz, --,
   {{0x7e6009df,0xa06a0de6,0xb4db00f1,0x7aed0110}},	//   ramp, _газа_, _stài, _rmat,
   {{0x7aed01cc,0x7e6009df,0xa0c9004f,0x00000000}},	//   _smat, samp, _وذلك_, --,
   {{0x78a50006,0xa3be193c,0x7e6003b9,0x6d4b0044}},	//   _rahv, ेहि_, pamp, _etga,
   {{0xdee30217,0x00000000,0x00000000,0x00000000}},	//   _похи, --, --, --,
   {{0xf2d300c2,0x765d016e,0x2d9601e0,0x7c3801ed}},	//   גער_, _resy, _хрес, _tgvr,
   {{0x23670496,0x3d140b4a,0x6299004e,0x765d0554}},	//   šnji_, _नीचे_, zewo, _sesy,
   {{0x75359ea3,0x78a528e5,0x2246012f,0x9c7c0097}},	//   _rizz, _vahv, kcok_, sičs,
   {{0xabfb0052,0x7aed9ea4,0x753d392f,0x4b7b00a5}},	//   _להור, _umat, _pusz, _האהו,
   {{0x753572ee,0x644500a5,0x78a59ea5,0xa5359b31}},	// [b370] _pizz, tchi, _tahv, днач,
   {{0x3ea62c50,0xda0700d1,0x66d800fe,0x98d101c0}},	//   _laot_, _ويژه_, _fíko, _सकिए,
   {{0x62999ea6,0x75359ea7,0x64459ea8,0x7afe0501}},	//   tewo, _vizz, rchi, čstv,
   {{0x753d9ea9,0x7afd9eaa,0x64455259,0x3863003c}},	//   _tusz, nnst, schi, lajr_,
   {{0x6ec00026,0x64459eab,0x628b0223,0x00000000}},	//   वानु, pchi, rfgo, --,
   {{0x7afd9eac,0x66d8008a,0xb4db0176,0x6d590027}},	//   hnst, _líkl, _atàv, _rwwa,
   {{0xdce200d5,0xdb2400b5,0x26cb757d,0x439413fe}},	//   _cvoč, őség, _koco_, _парс,
   {{0x24bf00c8,0xdd911dbf,0x7afd9ead,0x3f87011c}},	//   _ইতিহ, نوع_, jnst, rtnu_,
   {{0x3f879eae,0x26cb00f8,0xfce52b4b,0x00000000}},	//   stnu_, _moco_, допо, --,
   {{0x7afd9eaf,0xd13101ca,0x26cb9eb0,0x225f01ed}},	//   enst, _شما_, _loco_, _heuk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc8690052,0x673e00ea,0x225f19c1,0x7afd4af9}},	//   _כן_, _rupj, _jeuk_, gnst,
   {{0x6d4b00d4,0xdce2008b,0x225f0051,0x1eea05f5}},	//   _utga, _zvoč, _meuk_, _بونی_,
   {{0x225f0a75,0x7afd78d6,0x673e0223,0xe73a2368}},	//   _leuk_, anst, _pupj, жев_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cb9eb1,0x2ca73d29,0x4ae2060a,0x225f2c74}},	//   _coco_, _hand_, _पतिव, _neuk_,
   {{0x09065eca,0x2ca79eb2,0x612401f7,0x213f034d}},	// [b380] _опин, _kand_, lòle, _nuuh_,
   {{0xa5bb00b5,0xb4e800ab,0x33f60036,0x00000000}},	//   _szóc, यफे_, мчес, --,
   {{0x39400d26,0x2ca7054e,0x26cb0179,0x33d500d8}},	//   _huis_, _mand_, _foco_, ніцт,
   {{0x2ca79eb3,0xfbae06fe,0xab6201fb,0x00000000}},	//   _land_, टितम, _şükr, --,
   {{0x6143342d,0xa1580086,0x39400173,0xddc20936}},	//   веча, чалу_, _juis_, _odoš,
   {{0x394011cc,0x2a602afd,0x213f2014,0x26cb0138}},	//   _muis_, _leib_, _duuh_, _zoco_,
   {{0x39400083,0xa3e60084,0xdb020187,0x7afd9eb4}},	//   _luis_, _बेच_, zvlá, ynst,
   {{0x2ca70173,0x25ad0009,0x225f01a3,0xbd6a0421}},	//   _aand_, _šeli_, _geuk_, орое_,
   {{0x7afd0a8a,0x25a03eb7,0x2ca79eb5,0x20d0009e}},	//   vnst, nwil_, _band_, _bàit_,
   {{0x2ca70012,0x225f01d7,0x20d001da,0x3b540009}},	//   _cand_, _zeuk_, _càit_, нкор,
   {{0xc4770397,0xb5fb0187,0x2ca70139,0x2cb8013b}},	//   ותיו_, _udáv, _dand_, ırd_,
   {{0x3940406e,0xf9e70033,0x2bac00b8,0x25a02c50}},	//   _buis_, _গুগল_, _věc_, kwil_,
   {{0x7afd9eb6,0xc9840043,0xb5fb0037,0x2ca72299}},	//   rnst, кури, _meác, _fand_,
   {{0x39401325,0x6e2202c6,0x26cb9eb7,0xa80301d6}},	//   _duis_, _izob, _soco_, _çıkm,
   {{0x26cb9eb8,0x5ba30409,0x55fb0033,0x61240310}},	//   _poco_, _арыз, _আরেক_, còle,
   {{0x2ca701e4,0x56947798,0x39404b31,0x00000000}},	//   _zand_, каст, _fuis_, --,
   {{0x2ca700d7,0x44b5022b,0x66d80093,0x3940021d}},	// [b390] _yand_, нбас, _kíkj, _guis_,
   {{0xdb0401ae,0xd1380035,0x6515126b,0x2edb20af}},	//   _ernä, _nią_, روائ, _बत्त,
   {{0x68f50d6f,0xb2750424,0x29115d6d,0x26cb2278}},	//   mizd, елеш, moza_, _toco_,
   {{0x66d8003e,0x00000000,0x00000000,0x00000000}},	//   _líkj, --, --, --,
   {{0x672d9eb9,0x20d0009e,0x6e22007b,0x00000000}},	//   mmaj, _nàis_, _nzob, --,
   {{0x68f506d3,0x6458008a,0x29119eba,0x672d9ebb}},	//   nizd, ðvit, noza_, lmaj,
   {{0x38610446,0xbf640312,0x2ca79ebc,0x6e2200fe}},	//   _mehr_, نديو, _rand_, _azob,
   {{0xf8385c8e,0xfaff071f,0x7b1621a4,0xed590384}},	//   ונות_, jnë_, náut, пои_,
   {{0x29119ebd,0x2ca7213d,0x6f020024,0x6e220168}},	//   koza_, _pand_, _djoc, _czob,
   {{0x23670a78,0x6f020160,0x68f5007e,0x39409ebe}},	//   šnju_, _ejoc, jizd, _ruis_,
   {{0x39401010,0x2ca79ebf,0x2b4e0176,0x29110139}},	//   _suis_, _vand_, _ctfc_, doza_,
   {{0xfe7000e0,0x394002e1,0x2ca79ec0,0x2b4e0069}},	//   _نده_, _puis_, _wand_, _dtfc_,
   {{0x39400279,0x19ba00af,0x00000000,0x00000000}},	//   _quis_, чунь_, --, --,
   {{0xdca2034b,0x29119ec1,0x6576053e,0x80c20066}},	//   _баши, goza_, vryh, लाये,
   {{0x6f020118,0x00000000,0x00000000,0x00000000}},	//   _yjoc, --, --, --,
   {{0x39400173,0x6f1b9ec2,0x777c01dd,0x63a2004e}},	//   _tuis_, nluc, rurx, łonk,
   {{0xe6e00299,0xb5fb0037,0x29110b69,0x6f1b02d7}},	// [b3a0] _नतीज, _reác, boza_, iluc,
   {{0x657600ac,0x6f1b9ec3,0x20d001da,0xdc3c00cd}},	//   rryh, hluc, _làir_, ršći,
   {{0x6f1b9ec4,0xe29a0409,0x65760421,0x00000000}},	//   kluc, зае_, sryh, --,
   {{0xc7b3011d,0x01665ceb,0x672d0d9a,0x20d0009e}},	//   _עבר_, екдо, cmaj, _nàir_,
   {{0xc69300c2,0xd1380035,0x6f1b034d,0x00000000}},	//   _גאר_, _pią_, dluc, --,
   {{0x6aa90083,0x644300a0,0x7f410bf4,0xfff80118}},	//   গাযো, ľnic, _bulq, وکات_,
   {{0x6e22006c,0x20d00211,0x66d80093,0xf53f0a8a}},	//   _szob, _bàir_, _ríkj, _frås_,
   {{0x20d00211,0x29119ec5,0x23890355,0x8fa30279}},	//   _càir_, zoza_, žují_, ѓање,
   {{0x3d0c01c0,0x569b00a5,0x00000000,0x00000000}},	//   ठकले_, ליקצ, --, --,
   {{0x62820207,0xa5bb00ac,0x672d00f4,0x00000000}},	//   lgoo, _ozón, zmaj, --,
   {{0x29112209,0x6f02013c,0x66d8008d,0xdbde002a}},	//   voza_, _tjoc, _víkj, tíña,
   {{0x386102bf,0x62820273,0x20d00211,0x00000000}},	//   _sehr_, ngoo, _gàir_, --,
   {{0x4dd31dbf,0x29119ec6,0x7ae80031,0x6e220027}},	//   _متوس, toza_, ëjta, _uzob,
   {{0x52dd157d,0xddc90097,0x00000000,0x00000000}},	//   _मत्स, dceň, --, --,
   {{0xd6db16ac,0x672d9ec7,0x81d60033,0x69c084e0}},	//   пта_, tmaj, াছি_, ämer,
   {{0xf5e71958,0x291101d5,0x6d4208c7,0x80c200b4}},	//   нізм, soza_, _kuoa, लाडे,
   {{0x672d9ec8,0x68f59ec9,0x62820345,0x95cb0370}},	// [b3b0] rmaj, pizd, dgoo, чува_,
   {{0x672d1210,0x6d42034d,0xba3b0176,0x00000000}},	//   smaj, _muoa, reïd, --,
   {{0xd2510180,0xdcfb011c,0x7b1601ef,0x7ce4009e}},	//   لنا_, stuć, cáus, _iòrd,
   {{0x62821e7e,0xba3b0176,0xe8d10387,0x00000000}},	//   ggoo, peïd, _सकुच, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c9011c,0xf07500b5,0x20d0009e,0x00000000}},	//   ljao_, ئیاں_, _sàir_, --,
   {{0xc4d200a5,0x6f1b9eca,0xbea502fb,0x00000000}},	//   _דגם_, tluc, вайк, --,
   {{0x26c90254,0x00000000,0x00000000,0x00000000}},	//   njao_, --, --, --,
   {{0x7e6200af,0x00000000,0x00000000,0x00000000}},	//   _deop, --, --, --,
   {{0x6f1b0514,0xdbde008d,0x63b50a23,0x7ce401f7}},	//   sluc, tíða, _krzn, _nòrd,
   {{0x3b0a13a1,0x2c0b022e,0x20d001da,0xef740647}},	//   дено_, _सुखं_, _tàir_, _مدنظ,
   {{0x7e625979,0xf4120122,0xdce90254,0x63b51e85}},	//   _geop, שפט_, kreć, _mrzn,
   {{0x4e78004f,0xdbde008d,0x7ce40211,0x26c90124}},	//   _أحمد_, síða, _bòrd, djao_,
   {{0x3ead9ecb,0x7ce400f1,0xa3e10826,0x5fa501c0}},	//   ldet_, _còrd, धना_, _खनाल,
   {{0xb90a020d,0x224d00d7,0xa6db05ee,0x62827487}},	//   _मत_, _ofek_, _miðf, ygoo,
   {{0x3ead0d51,0x7e621497,0x00000000,0x00000000}},	//   ndet_, _xeop, --, --,
   {{0x3ead2b3b,0x044603fa,0x63b5033b,0x2d8d9ecc}},	// [b3c0] idet_, везн, _arzn, ntee_,
   {{0xb97b9ecd,0xe8f74cb5,0x3ead00c3,0x7ce400f1}},	//   _קניי, _аль_, hdet_, _gòrd,
   {{0x316d02e1,0x18770122,0x64a313fe,0x62821e7e}},	//   _avez_, _בעיר_, раха, tgoo,
   {{0x3ead054e,0xdb040176,0x63b50693,0x2bc209b1}},	//   jdet_, _arnú, _drzn, षमता,
   {{0x644300d8,0x3ead9bab,0x6ec00bad,0x62824d01}},	//   žnia, ddet_, वासु, rgoo,
   {{0x224d9ece,0xc9530122,0x6282394d,0xdce201ba}},	//   _efek_, סמו_, sgoo, _spoľ,
   {{0x7e629ecf,0x741600d1,0x62820345,0x63b59ed0}},	//   _peop, _شورا, pgoo, _grzn,
   {{0xb5fb0037,0x3ead01e9,0x00000000,0x00000000}},	//   _meán, gdet_, --, --,
   {{0x9d1416b8,0x6ce600d8,0x80c25860,0xb5fb00fd}},	//   лдич, віне, लादे, _leán,
   {{0x9b58051b,0xfba800af,0x8f7601e0,0x00000000}},	//   ниот_, еӂий_, _ауді, --,
   {{0x753c9ed1,0x4ea64054,0x316d0116,0x5eaa0831}},	//   _mirz, _арла, _zvez_, কাবে,
   {{0xb4df0096,0xbe851902,0xf41300a5,0x75da00ea}},	//   _तत्_, _مجهو, יפת_, _kāzā,
   {{0x7e7d2cad,0xba3b0176,0x00000000,0x00000000}},	//   óspe, deïc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09cb00c8,0xb5fb01ef,0xd7f800c3,0xdd3100a8}},	//   _লেখা, _adáp, вут_, ləşi,
   {{0xdce0010b,0xa3b60d34,0x644e2cdc,0xdce900f4}},	//   tumė, जिन_, _afbi, treć,
   {{0x753c9ed2,0xa5f82739,0xe6640183,0x00000000}},	// [b3d0] _birz, вету_, ртсо, --,
   {{0x6aad0051,0x798d0024,0xf53f0523,0x00000000}},	//   _haaf, _iqaw, _dråp_, --,
   {{0xdce90a78,0x753c004b,0x29032570,0x3ead9ed3}},	//   sreć, _dirz, mnja_, ydet_,
   {{0x6aad104e,0xdce90009,0xa6db008d,0x2d8d055c}},	//   _jaaf, preć, _siðf, ytee_,
   {{0x6aad000e,0x753c2b6c,0x667a00a5,0x3ead9ed4}},	//   _maaf, _firz, _אטרק, vdet_,
   {{0x66d800fb,0x89dc0122,0x3d0c0035,0x63b5003d}},	//   _ríki, וחדי, सकों_, _trzn,
   {{0xa6db008d,0x93880166,0x673d9ed5,0xd34700f8}},	//   _viðf, _иста_, _kisj, _شیشه_,
   {{0x6aad073a,0x2903022f,0x2d8d00a5,0x3ead00c3}},	//   _naaf, hnja_, ttee_, udet_,
   {{0x656d03a2,0x3ead9ed6,0x798d006d,0x673d9ed7}},	//   nsah, rdet_, _nqaw, _misj,
   {{0x66d8008d,0x661d9ed8,0x656d9ed9,0x290300f4}},	//   _víki, _mysk, isah, jnja_,
   {{0x29039eda,0x2d8d9edb,0xa5bb0332,0x9f5517a3}},	//   dnja_, stee_, _szól, _свеч,
   {{0x6aad0051,0xa5bb006c,0x673d313c,0x00000000}},	//   _caaf, _gyóg, _nisj, --,
   {{0x6dc427f6,0x661d039b,0xaa7b00ac,0xa6db003e}},	//   _نزول, _nysk, chým, _miðd,
   {{0xd9433e62,0xa3b600dc,0x656d0009,0x29030207}},	//   сери, जिम_, dsah, gnja_,
   {{0x1cb81062,0x66e61714,0x673d0009,0x37e301e0}},	//   _جانب_, гова, _bisj, борг,
   {{0x6aad030d,0x673d0176,0x661d008c,0x75d60413}},	//   _gaaf, _cisj, _bysk, هيزا,
   {{0x29030c21,0x7ae49edc,0x2bcb0240,0x656d9edd}},	// [b3e0] bnja_, _ilit, ाहका, gsah,
   {{0x661d004e,0x7ae40009,0xe6170d73,0x290300f4}},	//   _dysk, _hlit, уду_, cnja_,
   {{0x2b4f0043,0x753c0029,0x656d0dc3,0x7e69010d}},	//   _încă_, _virz, asah, kaep,
   {{0x55e62070,0x656d2977,0x6efe00ea,0x25bf01f2}},	//   _бомб, bsah, lībv, _šule_,
   {{0x7ae49ede,0x6fb80e61,0x6b819edf,0x00000000}},	//   _mlit, ्मभू, hulg, --,
   {{0x7ae403b6,0x7ce40211,0x779100b5,0xf99300a5}},	//   _llit, _mòrc, _دیہا, צרו_,
   {{0xfbc7317b,0x7ae402ea,0x248a6dcd,0x661d0035}},	//   _ات_, _olit, _icbm_, _zysk,
   {{0xa6db008d,0x290319cd,0x7ae40118,0xda0400dc}},	//   _viðg, znja_, _nlit, रपात_,
   {{0x4aaf009a,0xa2069ee0,0x386a0d32,0x6aad012f}},	//   _जोगव, _спад, kabr_, _raaf,
   {{0x7ae49ee1,0x6aad030d,0x764d9ee2,0x3ae20079}},	//   _alit, _saaf, zcay, _rópa_,
   {{0x7ae49ee3,0x29030c21,0x656d024e,0x447b02b5}},	//   _blit, vnja_, zsah, ענטע,
   {{0x80c2009a,0xf4260083,0xb5fb006c,0xd437100a}},	//   लावे, _বলার_, _beál, טריק_,
   {{0x29032802,0x7ae40079,0x90d50023,0x8d569ee4}},	//   tnja_, _dlit, _mìn, _стеч,
   {{0x6aad0054,0x661d9ee5,0x6b819ee6,0x7ce4009e}},	//   _waaf, _rysk, bulg, _dòrc,
   {{0x7ae49ee7,0x2903030a,0x661d3ee4,0x66d80093}},	//   _flit, rnja_, _sysk, _líku,
   {{0x656d9ee8,0x29039dd6,0x213e022e,0x36880036}},	//   tsah, snja_, _lith_, лсун_,
   {{0x764d0464,0x29039ee9,0x656d02c2,0x673d01e0}},	// [b3f0] rcay, pnja_, usah, _visj,
   {{0x661d040e,0x656d0ec0,0xe81629ce,0x7ae4076e}},	//   _vysk, rsah, _दुवा_, _zlit,
   {{0x56959eea,0x7ae400c3,0x656d9eeb,0x90d500e2}},	//   _кант, _ylit, ssah, _bìn,
   {{0x661d0c60,0x213e0211,0x515501e0,0x98b30395}},	//   _tysk, _aith_, атку, _fixă_,
   {{0xe13500c7,0x213e003b,0x201e0359,0xd6d8002d}},	//   анды, _bith_, _ayti_, _стэ_,
   {{0x6ae2162b,0x210f0084,0xdddb0c99,0x3a2901ed}},	//   _पत्र, िवेश_, jguš, _mzap_,
   {{0x213e0284,0xa3d50210,0x6b8101ef,0x00000000}},	//   _dith_, _товч, xulg, --,
   {{0x6b815277,0xfe450370,0x2d950165,0x201e0031}},	//   vulg, шнио, арос, _dyti_,
   {{0x386a0d32,0x6087004f,0x518703fa,0x61240176}},	//   yabr_, _مشاك, _љуба, còlo,
   {{0x7ae44d17,0xb5fb2eef,0x6b8101a2,0xee360bbc}},	//   _slit, _reál, tulg, шны_,
   {{0x9b0667d7,0xa6db0093,0x66d80093,0x00000000}},	//   изод, _miðb, _kíkt, --,
   {{0x4e190086,0xa3b60808,0x60c1028b,0x7ce40176}},	//   _июля_, जित_, _hnlm, _pòrc,
   {{0xd94603ad,0x00000000,0x00000000,0x00000000}},	//   реги, --, --, --,
   {{0xcc8900bf,0x271e0d53,0x9d520037,0xf1b90124}},	//   _شنبه_, पत्र_, _بنوت, _mrš_,
   {{0x46f66cfe,0x25e8111e,0x18672c86,0xbebd123c}},	//   ачат, चैनी_, раси_, plūd,
   {{0xfd4c01a5,0x3eaf01b4,0x7ae49eec,0x29d801ba}},	//   _nhiễ, _jagt_, _ulit, eľať_,

   {{0xb4663acc,0xe737279d,0x25ab0176,0x44663355}},	// [b400] икал, рет_, _cscl_, ивав,
   {{0x3eaf41d7,0xa3e1022e,0xdb0b02b1,0xe4570cc7}},	//   _lagt_, धनं_, _erfä, ижу_,
   {{0x213e004f,0xa87b00a5,0x25ab0036,0x3a2042f7}},	//   _rith_, _באיר, _escl_, _hyip_,
   {{0x29189eed,0xeb9600c2,0x213e01da,0x96969eee}},	//   lora_, ידער_, _sith_, _трош,
   {{0xaa7b0355,0x80c20380,0x7bda0067,0x00000000}},	//   lkýc, लाले, zytu, --,
   {{0xa87a0070,0x68fc0457,0x66d8008d,0xa6db008d}},	//   דאַר, nird, _víku, _viðe,
   {{0xa3ba007c,0x7ee654d3,0x6d4f20d9,0x2d9d021e}},	//   _अछि_, ицие, ícan, _apwe_,
   {{0x213e35d9,0x29189eef,0x68fc9ef0,0x442a01ba}},	//   _with_, hora_, hird, _izb_,
   {{0x291876a4,0x68fc00d0,0xaa7b00ac,0x00000000}},	//   kora_, kird, hkýc, --,
   {{0x14c90d91,0x29189ef1,0x7bda297a,0xa3ba0387}},	//   रायण, jora_, tytu, _अछा_,
   {{0x26c203ad,0x68fc0716,0x7ce400f1,0xa1130647}},	//   _onko_, dird, _còra, _بولت,
   {{0x3f9e0132,0x7bda297a,0xc4d3018d,0x7ce40211}},	//   _iptu_, rytu, _दक्ख, _dòra,
   {{0x14c906fe,0x5337016b,0x00000000,0x00000000}},	//   रामण, ינטן_, --, --,
   {{0x291856f2,0x2b47300e,0x68fc9ef2,0x26c202e9}},	//   gora_, _func_, gird, _anko_,
   {{0xbb84004f,0x442a0051,0xb8ff0066,0x67d4081b}},	//   _العي, _nzb_, _थक_, оору,
   {{0x68fc009e,0x00000000,0x00000000,0x00000000}},	//   aird, --, --, --,
   {{0x7afd9ef3,0x29189ef4,0xb995004f,0x644313a6}},	// [b410] mist, bora_, _الخب, žnim,
   {{0x29180133,0x2a6900d7,0x26c29ef5,0x9fa201ef}},	//   cora_, _heab_, _enko_, _líña_,
   {{0xaa7b114d,0xa6db008a,0x394901e8,0x2ee69ef6}},	//   ckýc, _viðb, _huas_, _olof_,
   {{0x39499ef7,0x2d849ef8,0x7b1d0b4c,0xb0620421}},	//   _kuas_, kume_, céut, äänk,
   {{0x2d840df4,0x39490a17,0x442a7358,0xf1a700c3}},	//   jume_, _juas_, _ezb_, ррен,
   {{0x3eaf008d,0x3949006f,0xd009140e,0x2d849ef9}},	//   _sagt_, _muas_, леле_, dume_,
   {{0x7afd9efa,0x39499efb,0x2ee60260,0x00000000}},	//   kist, _luas_, _blof_, --,
   {{0x7afd9efc,0x29187ae9,0x68fc9efd,0x98a90069}},	//   jist, zora_, zird, _ftaħ_,
   {{0x25a90269,0x39490014,0x2d849efe,0xd9c604bc}},	//   nwal_, _nuas_, gume_, _लपेट,
   {{0x50db035d,0x7afd39cc,0x69dd03d0,0x3eaf0110}},	//   _भविष, eist, dyse, _wagt_,
   {{0x7f84004f,0x68fc9eff,0xeb990274,0xa3d71b8f}},	//   _ولكن, vird, ћим_, िहि_,
   {{0x39490034,0x2ee6011e,0x7b1d0042,0x00000000}},	//   _buas_, _glof_, déus, --,
   {{0x39491c31,0x68fc7c99,0x2d8401dd,0xdd910088}},	//   _cuas_, tird, cume_, _روغ_,
   {{0x39499f00,0x644301cc,0x6d5b5443,0x2b470510}},	//   _duas_, žnij, mpua, _tunc_,
   {{0x7afd9f01,0x29189f02,0x5eaa00c8,0x2ca59f03}},	//   bist, rora_, কারে, meld_,
   {{0x39490211,0x5b7a025a,0x68fc9f04,0x00000000}},	//   _fuas_, _ערפא, sird, --,
   {{0xf50a28a1,0xaa7b033a,0x9fa20093,0x70b701c0}},	// [b420] гнал_, skýc, _líða_, _आफूल,
   {{0x77ca0f94,0x68fc009f,0x7986313a,0xfe790355}},	//   _блог_, qird, mukw, chův_,
   {{0x2d849f05,0x493b0122,0x7b1d42ae,0x2b911da9}},	//   zume_, _תגיו, péut, nác_,
   {{0x2ca59f06,0x6d5b0ac8,0x26c200d7,0x394901e8}},	//   held_, kpua, _unko_, _yuas_,
   {{0x2ca59f07,0x672471b0,0x3949006f,0x67360051}},	//   keld_, mlij, _xuas_, mmyj,
   {{0x7afd9f08,0x9fa20093,0x3d110035,0x836a00d1}},	//   zist, _bíða_, ठकों_, _مصرف_,
   {{0x7afd9f09,0x442a902f,0x22490ce9,0x24e7021d}},	//   yist, _uzb_, žaka_, _умри_,
   {{0x7afd40e7,0x2d849f0a,0x672404ce,0x7986018e}},	//   xist, tume_, nlij, kukw,
   {{0x67243899,0x2ca59f0b,0x6d5b00a7,0xe81f0084}},	//   ilij, feld_, gpua, _मुना_,
   {{0x2d849f0c,0x7afd9f0d,0x2ca50b37,0x39499f0e}},	//   rume_, wist, geld_, _ruas_,
   {{0x39499f0f,0x2a690006,0x74c9021a,0x2d843359}},	//   _suas_, _peab_, रातः, sume_,
   {{0x394901a9,0x612d008a,0x67249f10,0x79860b65}},	//   _puas_, rúle, jlij, fukw,
   {{0x394901e8,0xa6db008e,0x67249eca,0x2ca501e4}},	//   _quas_, _niða, dlij, beld_,
   {{0xa3e802e4,0x69dd5d89,0x3949006d,0x672401e4}},	//   यना_, ryse, _vuas_, elij,
   {{0x7afd9f11,0x644303ab,0x25a9007a,0x7d1a9f12}},	//   pist, žnik, wwal_, mots,
   {{0x39499f13,0xaae710ad,0x25a915aa,0x67240a09}},	//   _tuas_, _دستو, twal_, glij,
   {{0xf8ae103b,0x555500b5,0x862700d8,0xb8ef0033}},	// [b430] رکی_, زپار, сьве, _শত_,
   {{0xf990004f,0xfaff152b,0x6e229f14,0x7d1a9f15}},	//   _أبي_, lië_, _myob, nots,
   {{0x67249f16,0xb5fb0037,0x25a91292,0x6e22030d}},	//   blij, _meái, swal_, _lyob,
   {{0x7d1a01d5,0xfaff11cc,0x326b0037,0x9fa2003e}},	//   hots, nië_, احاً_, _ríða_,
   {{0xdd862b2d,0x9fa20093,0x6e229f17,0x7d1a01d5}},	//   _تو_, _síða_, _nyob, kots,
   {{0x7bc5008a,0xf77000e0,0xa3b60461,0xfaff0051}},	//   _áhug, _تای_, जिश_, hië_,
   {{0x2ca502e6,0xdb0b0a20,0x6e2201d5,0xe3b3028f}},	//   veld_, _esfé, _ayob, _عرس_,
   {{0x2ca59f18,0xa3b61a75,0x9fa20093,0x798601d5}},	//   weld_, जिर_, _víða_, yukw,
   {{0x2ca59f19,0x6d5b08dd,0x6e22007b,0x44230031}},	//   teld_, upua, _cyob, _hyj_,
   {{0x7d1a9f1a,0x6d5b9f1b,0x67240506,0x463c0070}},	//   gots, rpua, zlij, נעזע,
   {{0xeb994d2e,0x2ca50d26,0x7ced01f7,0x7ce4009e}},	//   шин_, reld_, _lúrg, _eòro,
   {{0x628b65f3,0x3f879f1c,0x79860428,0x20c70099}},	//   nggo, munu_, tukw, लावध,
   {{0x7d1a9f1d,0xec6e09ce,0x6f1b00b8,0x3f8704d4}},	//   bots, _оп_, mouc, lunu_,
   {{0x6d5998db,0x644701f4,0x6f1b22af,0x44230421}},	//   _itwa, _ngji, louc, _oyj_,
   {{0x31a60af9,0x67249f1e,0x3f879f1f,0x6d4b9f20}},	//   _गन्ध, tlij, nunu_, _huga,
   {{0x6d439f21,0x6d4b1548,0x6f099f22,0x7c2b0b16}},	//   _hina, _kuga, nnec, đorđ,
   {{0x6d439f23,0x6d4b5a35,0x672404ce,0x7e6b00b5}},	// [b440] _kina, _juga, rlij, _megp,
   {{0x67249f24,0x6d4b9f25,0x6d439f26,0x3f879f27}},	//   slij, _muga, _jina, kunu_,
   {{0x6d4b9f28,0x6d439f29,0x389b02b5,0x67249f2a}},	//   _luga, _mina, _דיינ, plij,
   {{0xe29a9f2b,0xdcfb01cc,0x6d439f2c,0xd2502e63}},	//   рад_, druč, _lina, رنت_,
   {{0x6d430291,0x6f099f2d,0x6d4b010b,0x6f1b01c0}},	//   _oina, dnec, _nuga, douc,
   {{0x6d439f2e,0xfbc900ab,0x99bb0070,0xc0e31523}},	//   _nina, िमाम, יזנט, мочк,
   {{0x6d591939,0x6d4b9f2f,0xa6db008d,0xdce902c4}},	//   _atwa, _auga, _miðn, jređ,
   {{0x6d4b7059,0xf1aa00f8,0x644700da,0x6d439f30}},	//   _buga, _پاره_, _zgji, _aina,
   {{0x6d4b12c3,0x6d439f31,0x7d1a9863,0xddc900af}},	//   _cuga, _bina, tots, rbeş,
   {{0x6d4b03be,0x3f879f32,0x6d439f33,0x33260484}},	//   _duga, bunu_, _cina, llox_,
   {{0x6d599f34,0x6f1b9f35,0x7c23001e,0x7d1a9f36}},	//   _etwa, bouc, _cynr, rots,
   {{0x6d432129,0x2eed9f37,0x6f1b00f7,0x7d1a9f38}},	//   _eina, chef_, couc, sots,
   {{0x6d4b0adf,0x5a4400d8,0x6e2201d5,0xdd8f02e7}},	//   _guga, дэра, _uyob, _لون_,
   {{0x6d430ee7,0xfaff0b0d,0x6f0033cd,0x61240176}},	//   _gina, sië_, limc, fòli,
   {{0x6d4b3fa4,0x466b1159,0x7c2300e9,0xd66b0166}},	//   _zuga, ирам_, _gynr, ијал_,
   {{0x6d439f39,0x6d4b9f3a,0x290a008e,0x6f009f3b}},	//   _zina, _yuga, anba_, nimc,
   {{0x44230a4e,0x344b1285,0x3f8700c1,0x612d0098}},	// [b450] _syj_, ачен_, zunu_, húla,
   {{0xb9a4006c,0x6f0d11d7,0x612d05ee,0x6d4301ed}},	//   _کمیٹ, čaci, kúla, _xina,
   {{0x1419004f,0xa5bb00b5,0x612401f7,0x8cb2021a}},	//   حياة_, _azót, còli, _असनो,
   {{0x994803c5,0x332600d7,0x3f870b43,0x00000000}},	//   _دلیل_, glox_, vunu_, --,
   {{0x6f0000cd,0xdce902c4,0x6f1b0355,0x7e6b448b}},	//   dimc, zređ, vouc, _regp,
   {{0x6d4b9f3c,0x463a0317,0xe4a4141d,0x7ced9f3d}},	//   _ruga, _לערע, _орсо, _kúre,
   {{0x6d439f3e,0x3326271e,0x6d4b9f3f,0x26d95010}},	//   _rina, blox_, _suga, _koso_,
   {{0x6d439f40,0xdce90b16,0x3f879f41,0x6d4b9f42}},	//   _sina, vređ, runu_, _puga,
   {{0x6d432eb9,0x6f099f43,0xddcb0029,0x26d99f44}},	//   _pina, rnec, _iegū, _moso_,
   {{0xa3df4e90,0x6d4b0371,0x6f099f45,0x6f1b5bfa}},	//   _तथा_, _vuga, snec, souc,
   {{0x6d439f46,0x6f002802,0xf9890070,0xdce9011c}},	//   _vina, bimc, _תר_, uređ,
   {{0x6d4b9f47,0x6d439f48,0x26d90391,0xfeb8017e}},	//   _tuga, _wina, _noso_, _وانت_,
   {{0x6d430e08,0xdc3c0029,0x6d4b067f,0x6d599f49}},	//   _tina, kšķi, _uuga, _utwa,
   {{0xdce90bec,0xe8e10019,0x6b889f4a,0x00000000}},	//   pređ, _đợt_, budg, --,
   {{0x6fbd0066,0xe81f007c,0x26d900d1,0xb8e40518}},	//   ्मिं, _मुदा_, _boso_, _एफ_,
   {{0x3f5101a5,0x9c7c053d,0x2bb0000c,0x26c60138}},	//   _máu_, nkčn, _जनता, ñoo_,
   {{0x26d99f4b,0xe5a3432e,0x00000000,0x00000000}},	// [b460] _doso_, нити, --, --,
   {{0xe523320c,0x6ab601ef,0x5fbd05b7,0x7d01101d}},	//   едуп, _hayf, ्माल, nils,
   {{0x26d907a6,0xa5bb00b5,0x6ab61505,0xfda8111b}},	//   _foso_, _szót, _kayf, _कन्फ,
   {{0x26d90176,0x7d010a8a,0x8b560070,0x6f0000e2}},	//   _goso_, hils, ליעס_, ximc,
   {{0x6ab60602,0xa6db0093,0x7d019f4c,0x2240018d}},	//   _mayf, _miðl, kils, äik_,
   {{0x3f510023,0x612d9f4d,0x26d90139,0x00000000}},	//   _báu_, túla, _zoso_, --,
   {{0x03a3059b,0x53a300af,0x3f5100e2,0x6f009f4e}},	//   _пиро, _парб, _cáu_, timc,
   {{0xe2979f4f,0xc7b30122,0x74c49f50,0x64620035}},	//   _нас_, תבה_, राकृ, świę,
   {{0x21670274,0x612d9d90,0x00000000,0x00000000}},	//   _нити_, súla, --, --,
   {{0x3b540036,0x61e20107,0x7d019f51,0x00000000}},	//   мкор, myol, gils, --,
   {{0x60c801b4,0x61e29f52,0x3f7700af,0xa2c1021a}},	//   _indm, lyol, cău_, _रोड्,
   {{0x60da07d6,0x00000000,0x00000000,0x00000000}},	//   _hotm, --, --, --,
   {{0x7d019f53,0x61e29f54,0xa3b31db9,0x26d900f8}},	//   bils, nyol, _जैन_, _roso_,
   {{0x7d570122,0x26d940a8,0xa5bb021d,0x00000000}},	//   _ציוד_, _soso_, _ozór, --,
   {{0xb8f50953,0x26d905ca,0x57a432a6,0xdc9b00a5}},	//   _सच_, _poso_, ншта, _הסוכ,
   {{0xf77000b5,0x6ab601ed,0xd6d80f7e,0x60da96cc}},	//   طاف_, _gayf, пту_, _lotm,
   {{0xf6502e36,0x7aed5d15,0x26d9002a,0x44b50336}},	// [b470] ائف_, _ilat, _voso_, мбас,
   {{0x60da008c,0x7aed0345,0x61e29f55,0x2d840098}},	//   _notm, _hlat, dyol, irme_,
   {{0x7aed9f56,0x929500d8,0xa77400af,0x0edc0066}},	//   _klat, даец, _плэч, _बवंड,
   {{0x60c80006,0x0ca906fe,0x7d019f57,0x629e006c}},	//   _andm, _कस्म, zils, őpon,
   {{0x7aed51e7,0x3f514043,0x60da0298,0x7d01013b}},	//   _mlat, _sáu_, _botm, yils,
   {{0x29039f58,0x7aed9f59,0x7ced0392,0x60da1377}},	//   nija_, _llat, _múrc, _cotm,
   {{0x7d0178a8,0x7aed9f5a,0xdb0b0176,0x7ae60093}},	//   vils, _olat, _asfí, ykkt,
   {{0x29039f5b,0x44310051,0xc2c50312,0x00000000}},	//   hija_, _izz_, _تيري, --,
   {{0xdd8e0bf5,0x7d019f5c,0x44310207,0xbeed1b8f}},	//   لوي_, tils, _hzz_, _जतीन_,
   {{0x7aed9f5d,0x6ab608a1,0x2903023a,0x60da0103}},	//   _alat, _sayf, jija_, _gotm,
   {{0xa3b60035,0x7d019f5e,0x2d849f5f,0xdb0b01ef}},	//   जिए_, rils, arme_, _esfí,
   {{0x7aed9f60,0x7d019f61,0xdd8e00f8,0x44310116}},	//   _clat, sils, دوی_, _mzz_,
   {{0x29039f62,0xe8160302,0x80b4004e,0x7aed004e}},	//   fija_, _दुजा_, _इसमे, _dlat,
   {{0x7aed9f63,0xdcfb0029,0x7ced02d7,0xfc0518cd}},	//   _elat, bruā, _dúrc, _опло,
   {{0xd9432608,0x7aed9f64,0x6ab6045e,0x44319f65}},	//   тери, _flat, _tayf, _nzz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb1301f3,0xa5bb006c,0x4431027a,0xe57a2fa5}},	// [b480] _שלח_, _szór, _azz_, юза_,
   {{0x7aed15d8,0x61e27587,0x4431013a,0x00000000}},	//   _zlat, vyol, _bzz_, --,
   {{0xa6db0093,0x00000000,0x00000000,0x00000000}},	//   _miðj, --, --, --,
   {{0x05000083,0x60da9f66,0xfbb00266,0x44310371}},	//   ্তের_, _sotm, _जनसम, _dzz_,
   {{0x6fc00302,0x44310103,0x00000000,0x00000000}},	//   विभू, _ezz_, --, --,
   {{0x61e200c1,0xd2590260,0x00000000,0x00000000}},	//   ryol, _efņ_, --, --,
   {{0xe2aa2abf,0x61e29f67,0x00000000,0x00000000}},	//   _وارن_, syol, --, --,
   {{0x3f8000d8,0xdde101a0,0x877b0070,0x00000000}},	//   čiu_, _šušn, קאפי, --,
   {{0xa3b606bc,0x6459006a,0x60da01f7,0xa6db0093}},	//   जिक_, świe, _totm, _biðj,
   {{0x7aed5657,0x29030484,0x7ce4021e,0x8c3c0225}},	//   _slat, xija_, _kòri, leği,
   {{0x290305e2,0x92d00033,0x00000000,0x00000000}},	//   vija_, ষসী_, --, --,
   {{0x8c3c01d6,0x29030b35,0x00000000,0x00000000}},	//   neği, wija_, --, --,
   {{0xf2d30779,0x7aed0c21,0x7ce401f7,0x2bb00b54}},	//   דער_, _vlat, _lòri, _जनवा,
   {{0xa6db0093,0x3cf70037,0x00000000,0x00000000}},	//   _viðm, _يعود_, --, --,
   {{0xd6db0426,0x7aed00d1,0x3cf901f4,0x79860051}},	//   ота_, _tlat, ësve_, arkw,
   {{0x7aed9f68,0x2cac9f69,0x3b120031,0x8b080355}},	//   _ulat, ledd_, _gjyq_, _vyří,
   {{0x2cac0297,0xa5359f6a,0x00000000,0x00000000}},	// [b490] oedd_, енач, --, --,
   {{0x2cac001e,0x29030031,0x00000000,0x00000000}},	//   nedd_, qija_, --, --,
   {{0xd37b38ea,0xb5fb026e,0x00000000,0x00000000}},	//   юча_, _ceár, --, --,
   {{0x52150036,0x2cac0297,0x7ce41da5,0x00000000}},	//   ндет, hedd_, _dòri, --,
   {{0x865a0052,0x21690b90,0x612d3c2b,0xb65a1804}},	//   _מדרי, чили_, búll, _מדרש,
   {{0xa29f00b4,0x7ce403d0,0x6ea100b8,0x00000000}},	//   _गॉर्, _fòri, क्नु, --,
   {{0xf1b90187,0x8c3c027d,0x2b4901f7,0x2cac00e9}},	//   _myši_, beği, _oiac_, dedd_,
   {{0x8c3c0723,0xb4db0443,0x680e00fd,0x00000000}},	//   ceği, _guàr, lődé, --,
   {{0x3a290392,0x2cac00e9,0xa3b31b8f,0x00000000}},	//   _nyap_, fedd_, _जैत_, --,
   {{0xdb0b01ae,0x2b490176,0x2cac580c,0x7ced07c0}},	//   _erfü, _aiac_, gedd_, _búra,
   {{0x7ced004f,0xab2a0923,0x00000000,0x00000000}},	//   _cúra, зона_, --, --,
   {{0xf4120070,0x7ced0079,0x73fa016b,0xdceb009f}},	//   רפט_, _dúra, פּיו, _oqgħ,
   {{0xc33202b8,0x3ead9b41,0x19b900af,0x6da50812}},	//   טוט_, meet_, мурь_, _чила,
   {{0xdce90b16,0x3ead9f6b,0x26cb9f6c,0xa2c100b4}},	//   dseć, leet_, _anco_, _रोस्,
   {{0x07a311b9,0x68e1008d,0xe73a0183,0x00000000}},	//   ларн, ölda, зев_, --,
   {{0x3ead03ad,0x2901046a,0x224d08dd,0x2b4900e2}},	//   neet_, _emha_, _ngek_, _giac_,
   {{0xd5af00b5,0x7ce40176,0x6aa404fb,0x3f8700ac}},	// [b4a0] یفہ_, _sòri, _ibif, hrnu_,
   {{0x3ead00c3,0x05000083,0x395f0391,0x224d0118}},	//   heet_, ্ত্র_, íuse_, _agek_,
   {{0x3ead073c,0x66e61e5b,0x39520051,0xdb049f6d}},	//   keet_, _зона, _huys_, _apné,
   {{0x69c49f6e,0x3ead0086,0xdb190097,0x00000000}},	//   _krie, jeet_, _krvá, --,
   {{0x67260044,0x8c3c027d,0xf1261cba,0x2cac016e}},	//   _ikkj, reği, нько, yedd_,
   {{0x65649f6f,0xab680024,0x69c407c0,0x00000000}},	//   mpih, _heżż, _mrie, --,
   {{0x3ead11ad,0x65640159,0xba3b01f7,0x6aa40103}},	//   feet_, lpih, leït, _obif,
   {{0x2cac0297,0x539b0122,0x81af0083,0x3ead0298}},	//   wedd_, _מילו, _ওপর_, geet_,
   {{0x3952012f,0xdce20c99,0x10a61f08,0xcd065674}},	//   _nuys_, _svođ, _пиан, ечни,
   {{0x55970779,0x3f870129,0x9b580370,0x7e76022f}},	//   עדיע_, brnu_, миот_, _šapć,
   {{0x2cac0411,0xa3b60066,0xe1ff0093,0x3ead32c6}},	//   redd_, जिट_, _þór_, beet_,
   {{0xa6db008a,0x2cac0411,0x290402e9,0x69c40191}},	//   _viðk, sedd_, èman_, _brie,
   {{0xfce60bd7,0x2b490038,0x645c9f70,0x7fb300a8}},	//   _подо, _viac_, _ofri, _rəqə,
   {{0x6aa401a8,0x69c40191,0x7ced9f71,0x7d0600f6}},	//   _ebif, _drie, _túra, _dérè,
   {{0x62804abd,0x8ccd045c,0xdce20254,0x69c49f72}},	//   _odmo, तारो, _uvođ, _erie,
   {{0x645c9f73,0x69c49f74,0x6d4a2f59,0x644e0159}},	//   _afri, _frie, _hifa, _agbi,
   {{0x6d4a9f75,0x39529f76,0x6564043d,0x644e0024}},	// [b4b0] _kifa, _guys_, gpih, _bgbi,
   {{0x6abd9f77,0x3f8e69a0,0x799d006d,0x6d4a023c}},	//   ldsf, kufu_, mtsw, _jifa,
   {{0xa6db008a,0x6d4a0054,0x799d02b1,0x00000000}},	//   _liði, _mifa, ltsw, --,
   {{0x6abd9f78,0xf67900c2,0x7c2a0526,0x6d4a9f79}},	//   ndsf, _קאָמ, _myfr, _lifa,
   {{0x799d095a,0x645c0297,0xa3ad046c,0x7c2a00e9}},	//   ntsw, _ffri, _कनक_, _lyfr,
   {{0x672d9f7a,0x3ead0173,0x6d4a9f7b,0x91e21c84}},	//   llaj, weet_, _nifa, роше,
   {{0x3ead28e5,0x02a700d8,0x6fb20037,0x3f8e0010}},	//   teet_, _прам, لموا, gufu_,
   {{0x78bc1ac4,0xa6db003e,0xe2c900e0,0xdce000ea}},	//   zdrv, _biði, _تورو_, ksmē,
   {{0x2607004e,0x3ead9f7c,0x6d4a9f7d,0xa6db0093}},	//   _सेमी_, reet_, _bifa, _viðh,
   {{0x2d8302dd,0x8234004f,0x6d4a02c4,0x3ead0c7d}},	//   čje_, _إرفا, _cifa, seet_,
   {{0x7c2a9f7e,0x6d4a9f7f,0x672d9f80,0x3ead9f81}},	//   _cyfr, _difa, klaj, peet_,
   {{0x69c49f82,0x29119f83,0x2a720510,0x6d4f01dd}},	//   _prie, enza_, _qeyb_, ícas,
   {{0x6b8812ba,0x2d8d00f6,0x69c40024,0x00000000}},	//   ardg, quee_, _qrie, --,
   {{0x69c41c47,0xe6ca0355,0x6d4a04fb,0x765d2bb7}},	//   _vrie, ाञ्ज, _gifa, _afsy,
   {{0x7c2a0297,0xf0920122,0x81d70083,0xa6960274}},	//   _gyfr, ינם_, ানি_, крај,
   {{0x29119f84,0x442a0963,0x6d4a1cf5,0x799d006d}},	//   anza_, _ryb_, _zifa, btsw,
   {{0x69c43f66,0xa2d5012f,0x7afd0031,0x6d4a04fb}},	// [b4c0] _urie, णान्, ërte, _yifa,
   {{0x81d700c8,0x7ce40955,0x65640ec0,0x25b20626}},	//   ানা_, _fòru, rpih, rwyl_,
   {{0xe29a00d8,0x672d9f85,0x25b200e9,0x6280008c}},	//   дае_, blaj, swyl_, _pdmo,
   {{0x672d0831,0x1dd1112b,0x6d460187,0x14170037}},	//   claj, तमात, íkaz, خيمة_,
   {{0x6459004e,0x7d0303d0,0x00000000,0x00000000}},	//   świa, _omns, --, --,
   {{0x28d5317c,0x7e690051,0x6f029f86,0x01e10033}},	//   दायि, ebep, _smoc, _মেহদ,
   {{0xdfd0004f,0xc29a0274,0x7e6912ba,0x00000000}},	//   صية_, _отац_, fbep, --,
   {{0x3f8e000e,0x7ced0168,0x7bc103bc,0x00000000}},	//   rufu_, _búro, dvlu, --,
   {{0xb14601f5,0x3f9c02dd,0x3f8e876b,0x6d4a0409}},	//   _анал, stvu_, sufu_, _pifa,
   {{0x799d006d,0x00000000,0x00000000,0x00000000}},	//   vtsw, --, --, --,
   {{0x6d4a000e,0x09cb00e7,0x7bc19f87,0x00000000}},	//   _vifa, ाम्य, gvlu, --,
   {{0xb69b00af,0x6d4a007b,0x799d0110,0x00000000}},	//   _amân, _wifa, ttsw, --,
   {{0x6d4a0358,0x6abd85b1,0x00000000,0x00000000}},	//   _tifa, rdsf, --, --,
   {{0x3ea60009,0xac1851be,0xdb0b0093,0x6f070118}},	//   _hbot_, _полу_, _erfð, _tèbè,
   {{0x799d6cdb,0xa6db008a,0x6eb8021a,0x7d081107}},	//   stsw, _miðv, ्यपु, mids,
   {{0x6609008a,0x1db6021a,0x7d089f88,0x7cf60160}},	//   _þekk, _अनात, lids, _bârg,
   {{0x06c50083,0x672d9f89,0x96350e9f,0xd49b0212}},	// [b4d0] _একদি, rlaj, унац, дре_,
   {{0x7d0802c4,0x672d6ca2,0x00000000,0x00000000}},	//   nids, slaj, --, --,
   {{0xd2511d6c,0xf8b2025a,0xd49802fb,0x00000000}},	//   منا_, _פשט_, ърт_, --,
   {{0xaad60084,0x2498011e,0x2bc300e7,0x721900af}},	//   धायक, _ecrm_, षिता, нжер_,
   {{0xf99f0c1f,0x7d080009,0x656f001e,0x7ced07c0}},	//   ntè_, kids, _uwch, _búrl,
   {{0x3ea69f8a,0x6e2b00e9,0xf07500b5,0x7ce4009e}},	//   _abot_, _rygb, ایاں_, _mòrs,
   {{0x3f5803e6,0x63b808c8,0x4ac30099,0xd34300b5}},	//   _céu_, ævnt, षयाव, _نفسی,
   {{0xf8380122,0xf99f0c1f,0x3f580443,0x38782d20}},	//   כנות_, ktè_, _déu_, zarr_,
   {{0x7bc1006d,0x7e696079,0x6ef50168,0x3dc60147}},	//   wvlu, rbep, _nábe, _crow_,
   {{0xee3600d8,0x3f580392,0x61e40421,0x7d080afc}},	//   ыны_, _féu_, äile, gids,
   {{0xfc052a24,0x225f3da1,0xe81f00ab,0x67243436}},	//   упно, _kfuk_, _मँगा_, yoij,
   {{0x94070095,0xa3b60066,0x224900cd,0xb69b0139}},	//   ünə_, ड़ित_, žaku_, _smân,
   {{0x6f09004e,0x5ca50dde,0x38780454,0xdca50368}},	//   miec, _билб, tarr_, _бали,
   {{0x6f090029,0x3ebd0176,0xa6db0093,0x7cf60160}},	//   liec, _hawt_, _miðu, _cârd,
   {{0xa6db0093,0x9d1a011d,0x7ce40176,0x3ebd0024}},	//   _liðu, _אוסט, _vòrt, _kawt_,
   {{0xb8eb1a75,0x6f099f8b,0x3ebf1aec,0x6d4103d0}},	//   _रो_, niec, ndut_, lmla,
   {{0xa6db00fb,0x3ebd00d7,0x80b30084,0x2d9f9f8c}},	// [b4e0] _niðu, _mawt_, ंजाइ, ntue_,
   {{0x690908b7,0x7cf60160,0x78a900f4,0x00000000}},	//   lžen, _gârd, đevc, --,
   {{0x389b0779,0x37e630dd,0x290a9f8d,0x6f09560c}},	//   _איינ, _сонг, miba_, kiec,
   {{0x290a9f8e,0x7cf6002d,0x3f580132,0xa6db003e}},	//   liba_, _târg, _réu_, _biðu,
   {{0xc05a02ce,0x3f5800fb,0x281300bf,0x6f099f8f}},	//   ній_, _séu_, _نویس, diec,
   {{0x290a5656,0x6ea10d1f,0xe5a30274,0x00000000}},	//   niba_, क्सु, _ћири, --,
   {{0x7d083e48,0xa6db008d,0x6d5d9f90,0xa85700a5}},	//   vids, _viðv, ísan, ניקה_,
   {{0x2d828540,0x81ac0033,0x717600f8,0x290a9f91}},	//   škem_, গিব_, _مهرا, hiba_,
   {{0x7d084409,0x290a0428,0x6ce6005f,0x26c0016e}},	//   tids, kiba_, гіне, idio_,
   {{0xdce9016f,0x8f7600d4,0x290a001c,0x00000000}},	//   ateľ, _буді, jiba_, --,
   {{0x6f099f92,0x290a9f93,0x6ef501dd,0x7d080c7d}},	//   biec, diba_, _sábe, rids,
   {{0xa2ca00be,0x6f090035,0x7ce4487b,0xf99f0036}},	//   _सोम्, ciec, _còrr, ttè_,
   {{0x26c0001e,0xa2d50569,0x7ce40176,0x2d9f67f7}},	//   ddio_, णात्, _dòrr, ctue_,
   {{0xac97004f,0x7faa01c2,0x290a9f94,0x5d83004f}},	//   _منها_, _təqd, giba_, _الول,
   {{0xd7f803ad,0xf99f4797,0x00000000,0x00000000}},	//   гут_, stè_, --, --,
   {{0x7c380496,0xa4ff0d53,0x00000000,0x00000000}},	//   _izvr, ोच्च_, --, --,
   {{0x659505c7,0x44382955,0x290a9f95,0x00000000}},	// [b4f0] разу, _azr_, biba_, --,
   {{0x290a9f96,0x753c0035,0x6f090035,0x4438008c}},	//   ciba_, _chrz, ziec, _bzr_,
   {{0x3255010b,0x26c029e7,0x00000000,0x00000000}},	//   авер, bdio_, --, --,
   {{0xd6db3dee,0x659501c8,0xb7da0d85,0x6d410a21}},	//   _что_, _каму, _סקרי, zmla,
   {{0x25a0215f,0x8c080033,0x867a00a5,0x6abf0024}},	//   ctil_, _রুমন_, _שרשו, _maqf,
   {{0xa6db008a,0x6f09004e,0xdd0101ba,0xc05b00d4}},	//   _viðu, wiec, _ľuďo, хід_,
   {{0x6f090080,0x7fd50210,0x3ebf011e,0x14d2012f}},	//   tiec, рілі, tdut_, सारण,
   {{0x290a462e,0x0d858d30,0x2d9f06b9,0x225f1d52}},	//   ziba_, алин, ttue_, _ufuk_,
   {{0x6ea120af,0x3ebf37fa,0xf1ca0187,0xee390382}},	//   क्षु, rdut_, _pláž_, ъни_,
   {{0x6f093040,0x26c0012e,0xa5bb014c,0x2d9f33e6}},	//   siec, zdio_, _exóg, rtue_,
   {{0x6f090080,0x6d419f97,0xd0110789,0x2fd90ca8}},	//   piec, rmla, _بلا_, _جواد_,
   {{0xa6db008d,0x1f5a00a5,0x69090355,0x00000000}},	//   _miðs, _סדנא, užen, --,
   {{0x290a9f98,0x69099f99,0xa6db0093,0x0d6700c3}},	//   tiba_, ržen, _liðs, _съем,
   {{0x7e7b9f9a,0x6d5b00cc,0x2ca701a5,0xa9671888}},	//   laup, mqua, _ubnd_, рира_,
   {{0x290a9f9b,0x61eb008a,0x37e30ecd,0x7ce40211}},	//   riba_, hygl, оорг, _tòrr,
   {{0x26c09f9c,0x09e69f9d,0x290a25b6,0x7cf60160}},	//   udio_, _воин, siba_, _gârb,
   {{0x6d5b9f9e,0x2d8d01ed,0x00000000,0x00000000}},	// [b500] nqua, nree_, --, --,
   {{0x25a09f9f,0x69090076,0x7ae41fa0,0x629b0b06}},	//   rtil_, nžel, _hoit, _acuo,
   {{0x25a09fa0,0x7e7b9fa1,0x2d8d492d,0x4ada5f12}},	//   stil_, kaup, hree_, _बचाव,
   {{0x82a600d8,0x877b0070,0x7ae40086,0x2d8d0298}},	//   радж, _באטי, _joit, kree_,
   {{0x41b6290a,0x7ae43612,0x4426006a,0xa6db008a}},	//   рсет, _moit, ło_, _viðt,
   {{0x7ae4043f,0xb1140083,0x7af6001e,0x6b5e00ea}},	//   _loit, িত্ব_, _llyt, _līga,
   {{0xd00f0ad9,0xa5070dc8,0xa2c101c0,0x44380510}},	//   وله_, _тера_, _रोक्, _uzr_,
   {{0x7ae49fa2,0x975700a5,0x3da69fa3,0x91e690f5}},	//   _noit, סיפו_, ароб, _кобе,
   {{0x2d8d295f,0x50b601e0,0xf1a90698,0x00000000}},	//   gree_, _всеу, _ماله_, --,
   {{0x7af600d8,0xc19b00a5,0x7cf69fa4,0x9ce6002d}},	//   _alyt, _בשמי, _sârb, рцил,
   {{0xdeef01c8,0x7ae40248,0x6d5b0069,0x00000000}},	//   _ды_, _boit, aqua, --,
   {{0x7ae4006e,0x6da66cab,0x6d5b006d,0x7ce401a6}},	//   _coit, _вида, bqua, _eòrp,
   {{0x7ae40065,0x4efb0317,0x7cf60139,0x00000000}},	//   _doit, _בלאג, _cârc, --,
   {{0xa6db0093,0x69090009,0x7af60409,0xdca30200}},	//   _niðr, ržeo, _elyt, _даљи,
   {{0x7af6167f,0xc7c401ee,0x7c380254,0x9a8713ad}},	//   _flyt, ости, _uzvr, _купл,
   {{0x31a002d0,0x7ae401a3,0xddc90139,0x3a751d30}},	//   kòz_, _goit, nceş, _улир,
   {{0xa2d500e7,0x00000000,0x00000000,0x00000000}},	// [b510] णास्, --, --, --,
   {{0x04670de9,0x629b01d3,0x7ced07c0,0x00000000}},	//   ртам, _scuo, _rúrk, --,
   {{0xd6d1004f,0x6136002d,0x3b0900e0,0xddc200f4}},	//   _فقد_, tâln, _kmaq_, _neož,
   {{0xa6db00fb,0x91b5045c,0x63bc1d35,0x6d5b00cc}},	//   _viðs, _आईआई, _dsrn, yqua,
   {{0x68e503ad,0x6eee009e,0xf994016b,0x80a50033}},	//   _kohd, _iùbh, ַרק_, _গোষ্,
   {{0x61eb001e,0x68e50086,0x6d5d0300,0x92d70033}},	//   rygl, _johd, ísam, িসে_,
   {{0x7e7b23c6,0x213e0211,0xa3bb01c0,0x63bc01ed}},	//   taup, _dhth_, _अनि_, _gsrn,
   {{0x2d8d9fa5,0x2bb00567,0x3818011d,0x2d9598d7}},	//   tree_, _जनजा, יקום_, брос,
   {{0x6b5e0080,0x7ced002a,0x7e7b9fa6,0x6ef50138}},	//   _rīga, _húri, raup, _cába,
   {{0x7af69fa7,0x6d5b9fa8,0x7ae49fa9,0x2d8d0d35}},	//   _slyt, rqua, _soit, rree_,
   {{0x7ae49faa,0x690900d8,0x7af69fab,0x7e7b86a7}},	//   _poit, ržel, _plyt, paup,
   {{0x60c19fac,0xa96a03fa,0xdce00029,0x3d950421}},	//   _halm, лима_, rpmā, _гидр,
   {{0x7ae49fad,0x60c19fae,0x333f048c,0x7bca1bc9}},	//   _voit, _kalm, _mhux_, _erfu,
   {{0xeb9918cd,0x60c19faf,0xb4d60099,0x7cf60395}},	//   _бик_, _jalm, _ाचे_, _vârc,
   {{0xbb850082,0x60c160a3,0x6ef50076,0x6d599fb0}},	//   _البي, _malm, _zába, _huwa,
   {{0x6d599fb1,0xaa7b0093,0x6eee0211,0xa3ae00ab}},	//   _kuwa, skýr, _cùbh, _कहब_,
   {{0xe7370923,0x7faa0095,0x63bc0009,0x6d5909e7}},	// [b520] сет_, _məqa, _ssrn, _juwa,
   {{0x6d5974b7,0x00000000,0x00000000,0x00000000}},	//   _muwa, --, --, --,
   {{0x6d599fb2,0x8ca92af7,0xcc7a02b5,0x7ced2df0}},	//   _luwa, ज्यो, רװער, _cúri,
   {{0x64559fb3,0xe5a69fb4,0x9186004f,0xe1fa20c3}},	//   _egzi, _лими, مجتم, лге_,
   {{0x26c201cc,0x2b400094,0x6d599fb5,0x4a9b100a}},	//   _iako_, _mhic_, _nuwa, רינג,
   {{0xa50a2e76,0x863700a5,0x9f4701ba,0x7ced0a4f}},	//   _сега_, _לרכב_, rzný_, _fúri,
   {{0x26c21376,0x6ef57af6,0x60c10e46,0x68e1008a}},	//   _kako_, _sába, _dalm, öldi,
   {{0x26c20fa9,0x6d599fb6,0x76400187,0x43750043}},	//   _jako_, _buwa, _úmys, _фурт,
   {{0x26c29fb7,0xa2d50d91,0x2dda0037,0xbd870037}},	//   _mako_, णार्, ابعة_, منين_,
   {{0x6d590468,0x26c29fb8,0x387a0478,0x2d8a4034}},	//   _duwa, _lako_, _nepr_, čbe_,
   {{0x7afd01f4,0x68e59fb9,0x09e60033,0x6eaa02fb}},	//   ërto, _rohd, _পেলা, _бълг_,
   {{0x26c29fba,0x2b40785e,0x612d002a,0x00000000}},	//   _nako_, _chic_, súlt, --,
   {{0x6d599fbb,0x14c8012f,0x13b10033,0x68e59fbc}},	//   _guwa, रयाण, ছিয়, _pohd,
   {{0x1958004b,0xa2d502cb,0x2ee60173,0x26c20103}},	//   сары_, णाऱ्, _hoof_, _aako_,
   {{0x6e3c0250,0x26c201ed,0x78b59fbd,0x2ee60051}},	//   ərba, _bako_, rezv, _koof_,
   {{0xceb900b8,0xdce000ea,0x2c4e00a8,0x2ee60345}},	//   toři_, ksmī, məd_, _joof_,
   {{0x26c29fbe,0x26c700b8,0xaad60d91,0x7ced6ef7}},	// [b530] _dako_, ěno_, धारक, _súri,
   {{0x2ee603bc,0xe415010b,0x26c201b7,0x69cd0065}},	//   _loof_, одзь, _eako_, _irae,
   {{0x2c4e00a8,0xaadd1662,0x00000000,0x00000000}},	//   nəd_, यापक, --, --,
   {{0x26c2443a,0x69cd502d,0x60c160a2,0x81bd0033}},	//   _gako_, _krae, _salm, ইমস_,
   {{0x9948042c,0xdb0b03d0,0x7faa013b,0x6aad2973}},	//   _خلیل_, _dsfø, _rəqa, _mbaf,
   {{0x656d2f18,0x60c10095,0x26c20054,0x6d599fbf}},	//   mpah, _qalm, _zako_, _ruwa,
   {{0x26c20657,0x60c1135f,0x6d591148,0xfe57006c}},	//   _yako_, _valm, _suwa, میاب_,
   {{0x60c19fc0,0xa3ae007c,0x7d0a009e,0x6d595b97}},	//   _walm, _कहत_, _amfs, _puwa,
   {{0x60c16cd3,0x2ee6320a,0x4add073f,0x656d9fc1}},	//   _talm, _doof_, यानव, npah,
   {{0x3b8534a2,0x6aad0198,0x63a514d8,0x5ba913f9}},	//   олог, _abaf, othn, аком_,
   {{0x63a500d7,0x656d0703,0x2f1a00ea,0x6aad0b23}},	//   nthn, hpah, cīgo_, _bbaf,
   {{0x6d599fc2,0x63a5066a,0x2b8301c2,0x7afd0284}},	//   _tuwa, ithn, rıc_, ghst,
   {{0xabd70332,0x26c201d7,0x6ef500b5,0x6f0b0312}},	//   _گزشت, _rako_, _hábo, _imgc,
   {{0x26c200d8,0x672f004e,0x69cd9fc3,0x6aad030d}},	//   _sako_, _akcj, _drae, _ebaf,
   {{0x628901e9,0x69cd9fc4,0x8cd60067,0x68fc00d5}},	//   _odeo, _erae, बारो, rhrd,
   {{0x7afd02bf,0x1b180033,0x62890098,0x3a2001ed}},	//   chst, _ধীরে_, _ndeo, _txip_,
   {{0x69cd9fc5,0x6443008d,0x656d2700,0x26c20124}},	// [b540] _grae, ýnin, gpah, _vako_,
   {{0x26c20657,0xe5770402,0x6289023c,0x00000000}},	//   _wako_, юзу_, _adeo, --,
   {{0x26c29fc6,0x6efc1fe2,0x6ef5024e,0x66e62d35}},	//   _tako_, _hébe, _nábo, _дона,
   {{0x657b0098,0x8c1a00a5,0x81b30831,0x00000000}},	//   úchó, בועי, টিন_, --,
   {{0x63a5004f,0xdce21ada,0x2ee69fc7,0x2c4e00a8}},	//   athn, _stoč, _roof_, zəd_,
   {{0xc5f30052,0xa2ca0026,0x67360328,0x6b5e013a}},	//   _חדש_, _सोर्, llyj, _bīgl,
   {{0x4aca007c,0xaadd045c,0xa3ae007c,0xaaca01c0}},	//   ियाव, यामक, _कहि_, ियाक,
   {{0xe2979fc8,0xddaa2d93,0x9ed800af,0x7cf60139}},	//   _мас_, атол_, смит_, _cârn,
   {{0xfd4600d8,0x00000000,0x00000000,0x00000000}},	//   жэнн, --, --, --,
   {{0xa3ae0755,0xbc4a3cee,0x28de0380,0x6ef502d7}},	//   _कहा_, ичне_, माफि, _hábl,
   {{0x6ef51d37,0xdce2011c,0x28de14eb,0x7d1d00a2}},	//   _gábo, _utoč, मानि, éssa,
   {{0x69cd9fc9,0xeb0702ce,0x6efc3762,0x7f19010b}},	//   _prae, ічно, _bébe, _лічу_,
   {{0xad5a00c3,0x9e6500f8,0x6ef51534,0xddc3002d}},	//   _трех_, _رانن, _zábo, _обци,
   {{0x6efc0391,0x69cd03bc,0x63a500e9,0xd90f02fd}},	//   _débe, _vrae, ythn, ئید_,
   {{0x6ea123f0,0x6d4814ca,0x36d51a55,0x00000000}},	//   क्कु, mmda, повр, --,
   {{0x69cd3a23,0xd6d806a9,0x6d48097d,0x656d011e}},	//   _trae, оту_, lmda, tpah,
   {{0x8ca10084,0x61e40421,0xe80b00be,0x00000000}},	// [b550] _खामो, äill, _हेरा_, --,
   {{0x656d1ea7,0xe46b2682,0x7d1a6438,0x81e00831}},	//   rpah, ршал_, nnts, দনা_,
   {{0x29119fca,0x7d1a9de2,0x68e10093,0x00000000}},	//   miza_, ints, öldu, --,
   {{0x29119fcb,0x0cb71cc3,0x63a50297,0x2d840029}},	//   liza_, _अस्म, rthn, ksme_,
   {{0xa06949b8,0x81b30033,0x1a9c016b,0x6d48013b}},	//   бала_, টিভ_, שידע, kmda,
   {{0x29119fcc,0x7d1a01e8,0xf8cb0066,0xdcfb00ea}},	//   niza_, jnts, ायिय, ksuā,
   {{0x3cf00099,0x00000000,0x00000000,0x00000000}},	//   ेसने_, --, --, --,
   {{0x2d955de9,0x7d1a5f89,0x29119fcd,0x3358002d}},	//   прос, ents, hiza_, _фатэ_,
   {{0x2911262a,0xfaff00da,0x00000000,0x00000000}},	//   kiza_, dhë_, --, --,
   {{0xeb9903fa,0x2911002f,0x6ef500ac,0x6efc00a2}},	//   био_, jiza_, _zábl, _rébe,
   {{0xca298c74,0xc10416e6,0x2d849fce,0x29110138}},	//   _עם_, _تولي, asme_, diza_,
   {{0x28de06fe,0xdb0401b4,0x5e590079,0x00000000}},	//   माभि, _opnå, _الإس_, --,
   {{0x29111678,0x7d1a006d,0x00000000,0x00000000}},	//   fiza_, bnts, --, --,
   {{0x291116fe,0x18670be8,0x00000000,0x00000000}},	//   giza_, зари_, --, --,
   {{0x7faa0095,0x31b80355,0xc1b8021a,0x00000000}},	//   _nəql, _इन्ध, _इन्ग, --,
   {{0x05660109,0x66e35a57,0x4b7a0070,0x6f1b9fcf}},	//   зван, носа, _פאפו, nnuc,
   {{0x29110b55,0x8afb00a5,0xba9b00a5,0x28ba002d}},	// [b560] biza_, _להקי, _הספי, _лунэ_,
   {{0x29110160,0x2eb83933,0x7ced008e,0x00000000}},	//   ciza_, _आस्त, _túru, --,
   {{0x9c7c0a18,0x6f1b0069,0x6d4319fd,0x00000000}},	//   njča, knuc, _mhna, --,
   {{0xe29a0678,0x2d849fd0,0xd36f0098,0x00000000}},	//   сад_, ysme_, اهن_, --,
   {{0x5ee10083,0x7cf60139,0xaadd0761,0x6d484628}},	//   বসাই, _bârl, यातक, ymda,
   {{0x7f4201d2,0x66040054,0x7cf60139,0x6eee009e}},	//   _shoq, mzik, _cârl, _lùbt,
   {{0xd0100082,0x6ef53345,0x7d1a006d,0x7f4200a2}},	//   ضلة_, _tábl, vnts, _phoq,
   {{0xe2f8006c,0x6f1b9fd1,0x29119fd2,0x2d8400be}},	//   _بورڈ_, gnuc, ziza_, tsme_,
   {{0x205654d6,0x3cfe01a2,0x29112d06,0x6604313a}},	//   _етер, thtv_, yiza_, nzik,
   {{0x6d43860d,0x7d1a0065,0x7cf60160,0x798602a2}},	//   _chna, unts, _gârl, dskw,
   {{0xfaff01d2,0x7d1a0523,0x29119fd3,0x6d489fd4}},	//   thë_, rnts, viza_, rmda,
   {{0xf7730332,0x23be01c0,0x7d1a006d,0x291101d5}},	//   ہار_, _můj_, snts, wiza_,
   {{0xdd8f27f6,0x7ced004f,0x291105ba,0xa5bb0042}},	//   _مون_, _cúrs, tiza_, _axón,
   {{0xfaff00da,0x7bdc007c,0xc2fa0033,0xa3c13e9e}},	//   shë_, ärus, েকটি_, ्टम_,
   {{0x29119fd5,0x368b005f,0x672d9fd6,0x3d2b006c}},	//   riza_, йсан_, toaj, _اتنی_,
   {{0xb8f4051d,0x70b90d00,0x29119fd7,0xec37076b}},	//   _सो_, _इस्ल, siza_, _מאור_,
   {{0xdce9114d,0xa5bb002a,0x29119fd8,0x69090506}},	// [b570] zpeč, _exón, piza_, džev,
   {{0xe9450a86,0x672d08c7,0x28de0ec5,0x00000000}},	//   _تربی, soaj, माणि, --,
   {{0xccf302b5,0xc7ab0037,0xf53f029e,0x00000000}},	//   עכע_, _ادخل_, _spås_, --,
   {{0xd2512e36,0xa3ae0127,0x7afd0031,0x28d5021a}},	//   ننا_, _कहर_, ërth, दाकि,
   {{0xdd8600f5,0x6f000037,0x2d910035,0x00000000}},	//   _جو_, dhmc, ązek_, --,
   {{0x25a99fd9,0xc2441958,0xf77000d1,0x6847000d}},	//   mtal_, хнік, _جای_, cédé,
   {{0x25a99fda,0x7cf60139,0x00000000,0x00000000}},	//   ltal_, _cârm, --, --,
   {{0x26c9000e,0xdb1901ba,0x25a99fdb,0x6d439fdc}},	//   ndao_, _prvý, otal_, _shna,
   {{0x25a99fdd,0xa1949fde,0x00000000,0x00000000}},	//   ntal_, _патч, --, --,
   {{0xab6509c0,0x6f1b009e,0x2a699fdf,0x7ce40260}},	//   мвол, snuc, _afab_, _kòry,
   {{0x1c450ebb,0x6b9a010d,0x7cff03bc,0xeaba0036}},	//   ьном, gutg, _nêre, ойн_,
   {{0x25a99bda,0xc9aa0279,0x00000000,0x00000000}},	//   ktal_, овме_, --, --,
   {{0x644800d5,0xdca50af4,0x00000000,0x00000000}},	//   _údiv, _жали, --, --,
   {{0xa3ae0006,0x28d504bc,0x7cff0298,0xdcfb0124}},	//   _कहल_, दागि, _bêre, pruđ,
   {{0x07a31018,0x25a90223,0x7cff0298,0x00000000}},	//   карн, etal_, _vêrd, --,
   {{0x660481d3,0x79860051,0x25a90223,0x7bc3004b}},	//   tzik, pskw, ftal_, _isnu,
   {{0x28de00ab,0x25a90479,0xdb0b01ef,0x54c65163}},	// [b580] मादि, gtal_, _esfó, мбаб,
   {{0x26d99fe0,0x3f8797bc,0xf53f9fe1,0x66049fe2}},	//   _enso_, ksnu_, _spår_, rzik,
   {{0xf36503d0,0x78bc7b6b,0x69c4780e,0x316d01b7}},	//   етін, merv, _hsie, _atez_,
   {{0x7cf60160,0x69c40067,0x25a90211,0x00000000}},	//   _cârj, _ksie, btal_, --,
   {{0x8c110083,0x7afd00da,0x914a159f,0x9599002d}},	//   _সুমন_, ërti, очка_, _нтру_,
   {{0x7bc304c3,0x69c473d8,0x6ef50037,0x2f1a00ea}},	//   _osnu, _msie, _hábh, mīgi_,
   {{0x64a32360,0x645c9ee9,0x3ead9fe3,0xe36322a9}},	//   _шара, _igri, ffet_, _акси,
   {{0x78a90a78,0x6efc00d1,0x69c473c9,0x04433f20}},	//   đevi, _béba, _osie, _ресн,
   {{0x44389fe4,0x78bc9fe5,0x2f1a0029,0x5d54029f}},	//   _hyr_, kerv, nīgi_, нкит,
   {{0x62809fe6,0x6efc0248,0xb143875c,0x69090097}},	//   _hemo, _déba, _анул, nžet,
   {{0x78bc9fe7,0x69c49fe8,0xaad0007c,0xd49700a5}},	//   derv, _asie, _तोहक, וכית_,
   {{0xed5a1de4,0x69c40069,0x00000000,0x00000000}},	//   _дод_, _bsie, --, --,
   {{0x5ea30332,0x16000066,0x645c003d,0x3f9c9fe9}},	//   _شمول, लैमर_, _ogri, luvu_,
   {{0x645c9fea,0x6aa40069,0x78bc9feb,0xa3de000c}},	//   _ngri, _ecif, gerv, तमा_,
   {{0x69099fec,0xdb1901ef,0xe7330037,0x69c485a9}},	//   džet, _esvá, نصر_, _esie,
   {{0x25a99fed,0x6d58006c,0x1dd21cce,0xe7840274}},	//   ttal_, _hiva, तिपत, ђусо,
   {{0x7cff0626,0x60da0136,0x4438009e,0x6d589fee}},	// [b590] _wêre, _ontm, _ayr_, _kiva,
   {{0x60c80500,0x7aed9fef,0x3f9c0273,0x44389ff0}},	//   _nadm, _hoat, kuvu_, _byr_,
   {{0x6d5805f5,0x62809ff1,0x44381db3,0x78a50260}},	//   _miva, _bemo, _cyr_, _ichv,
   {{0x6d589ff2,0x44381e54,0x7aed06a2,0x25a99ff3}},	//   _liva, _dyr_, _joat, ptal_,
   {{0x7aed01a2,0x6280426b,0xa0699ff4,0x7d08010b}},	//   _moat, _demo, пала_, _kūrė,
   {{0x7aed40d5,0x6d58081b,0x44389ff5,0x98c6011c}},	//   _loat, _niva, _fyr_, ćući_,
   {{0x6ef504a5,0xa29501c8,0x6efc00f7,0x6abd09e1}},	//   _hábi, _паві, _séba, kesf,
   {{0x6280152b,0x6d589ff6,0x7aed4a6d,0x645c0207}},	//   _gemo, _aiva, _noat, _zgri,
   {{0x6d589ff7,0x6abd9ff8,0xa2dc0354,0x00000000}},	//   _biva, desf, फार्, --,
   {{0x3ead9ff9,0x620106d3,0x6aa49ffa,0x62801290}},	//   sfet_, ızlı, _scif, _zemo,
   {{0x290300da,0x78bc2726,0x7c9500bf,0xa3c122a3}},	//   dhja_, verv, وشگا, ्टि_,
   {{0x6d589ffb,0x6abd4dd0,0x7aed9ffc,0x00000000}},	//   _eiva, gesf, _coat, --,
   {{0x99d6006c,0x799d0143,0x2bb1007c,0x7aed01ed}},	//   رتحا, gusw, _जहवा, _doat,
   {{0xa3c10e96,0x6ef5004f,0x6d580e6c,0x200700f4}},	//   ्टा_, _sábh, _giva, ozni_,
   {{0x0ea60084,0x656f099e,0x7bc320f1,0x7e6903d0}},	//   क्कड, _atch, _usnu, ocep,
   {{0x645c4666,0xc4c600bf,0x6d589ffd,0x6abd0176}},	//   _sgri, کترو, _ziva, cesf,
   {{0x62809ffe,0x443e9fff,0xf98a004f,0x4438a000}},	// [b5a0] _remo, _št_, _عندي_, _syr_,
   {{0x2ebd0d34,0x628061f5,0x4aac25de,0x2f1a0029}},	//   ्युत, _semo, ट्रव, rīgi_,
   {{0x6ef5004f,0x62800ec0,0x60c85f83,0x7e69088a}},	//   _tábh, _pemo, _radm, kcep,
   {{0x869a03ad,0xe3639c0a,0x222800bf,0x6ef56493}},	//   _этот_, укци, وزشی_, _fábi,
   {{0x62801721,0x6ef5007e,0x645c0107,0x00000000}},	//   _vemo, _gábi, _tgri, --,
   {{0x645ca001,0x7faa0095,0xc0e30eb1,0x6280030d}},	//   _ugri, _həqi, лочк, _wemo,
   {{0x6280a002,0x04430c4c,0x443e006c,0x395a0168}},	//   _temo, _берн, _át_, _mips_,
   {{0x03d70122,0x6d58a003,0x395a470b,0xc059010b}},	//   _אולם_, _siva, _lips_, фіі_,
   {{0x6d58012e,0xe1fa005f,0x7aed00af,0x7ced0138}},	//   _piva, _эга_, _roat, _púrp,
   {{0x81b300c8,0x395a008c,0x7e6901ef,0x00000000}},	//   টিশ_, _nips_, acep, --,
   {{0x6d58a004,0x7aed09eb,0xa2d500a1,0x201800ab}},	//   _viva, _poat, णाच्, _äri_,
   {{0x81b300c8,0x78a5024e,0x141b0070,0x7c380187}},	//   টির_, _schv, לויב, _vyvr,
   {{0x69092acc,0xee3a29d6,0x6d58a005,0xdc1200c1}},	//   džer, _энд_, _tiva, rşım,
   {{0x661b02c4,0x00000000,0x00000000,0x00000000}},	//   _žuko, --, --, --,
   {{0x7aed09eb,0x7a490029,0xed4d006c,0x6ef50132}},	//   _toat, _sūtī, _بھي_, _sábi,
   {{0x290300da,0xdc3b02b8,0xa3c100b4,0x00000000}},	//   shja_, _מעור, ्टस_, --,
   {{0x65943d9b,0x7faa0095,0x7afd01f4,0x00000000}},	// [b5b0] лату, _dəqi, ërtu, --,
   {{0x78a500ac,0x6ef500d5,0x2f1a0228,0xa3e20067}},	//   _uchv, _vábi, mīgu_, _गपशप_,
   {{0x28de0084,0x2901a006,0x80a431d7,0x2b490023}},	//   मारि, _ilha_, च्छे, _khac_,
   {{0x75830088,0x395a0168,0x29010118,0x91bf0e6f}},	//   _میرم, _zips_, _hlha_, _एनआई,
   {{0x2b4909c3,0x10a5757c,0xdb190282,0xa0a50369}},	//   _mhac_, вилн, _isvä, валд,
   {{0x6e3900e9,0x25b90024,0x395a0176,0xdddb00ea}},	//   _rywb, _ipsl_, _xips_, jauš,
   {{0x26cb0118,0x7faa00a8,0x00000000,0x00000000}},	//   _kaco_, _yəqi, --, --,
   {{0x2ebd05f8,0xd00e0098,0x2b490019,0x26cb053e}},	//   ्येत, غلي_, _nhac_, _jaco_,
   {{0x0d82005f,0x26cb5459,0x290103e6,0xf2d202b5}},	//   алын, _maco_, _olha_, _דען_,
   {{0x6b5e0080,0x26cb063c,0xfc3f00b8,0x7d0600ea}},	//   _līgu, _laco_, řím_, ūksn,
   {{0x2b49006b,0xab2a0272,0x4add00a1,0x6efc0118}},	//   _bhac_, дона_, यांव, _kébl,
   {{0x26cb58d1,0x2b494605,0xf1b9023a,0x29130312}},	//   _naco_, _chac_, _kpš_, _amxa_,
   {{0xed4e2302,0x6cc50210,0x28de0e04,0x7faa00a8}},	//   _во_, _айла, मालि, _rəqi,
   {{0xd9460665,0x7c871578,0x2901009e,0xabd50bfe}},	//   теги, _чуде, _clha_, _ациј,
   {{0x1867021d,0x395aa007,0xdb0201ef,0x2b490211}},	//   таси_, _vips_, atlá, _fhac_,
   {{0x3ebf033b,0x07a30370,0x2b490024,0x81d80033}},	//   neut_, јатн, _ghac_, াহত_,
   {{0xe737606e,0xe81211b5,0x395a0122,0x26cba008}},	// [b5c0] тет_, _डेरा_, _tips_, _daco_,
   {{0x33f6002d,0x3ebfa009,0x69d60371,0x00000000}},	//   кчес, heut_, _irye, --,
   {{0x29183a34,0x26cb5927,0x940600f8,0x00000000}},	//   mira_, _faco_, خواه, --,
   {{0x69d6071f,0x291809d6,0x2ebd0808,0x26cb4ba6}},	//   _krye, lira_, ्योत, _gaco_,
   {{0x6efc00f7,0x6ecc0067,0x4aaa1b8f,0x21670112}},	//   _débl, _दोगु, _कानव, вичи_,
   {{0x291809ec,0x81b300c8,0x3ea6a00a,0x26c0021d}},	//   nira_, টিং_, _scot_, leio_,
   {{0x0fe000c8,0x73e31fcf,0x00000000,0x00000000}},	//   বন্ধ, _корз, --, --,
   {{0xa3c10653,0x2918a00b,0x69d62505,0x2a600069}},	//   ्टर_, hira_, _orye, _ngib_,
   {{0x29181415,0xf1aa00bf,0x41bf02e4,0x1d3402fb}},	//   kira_, _تازه_, _एनएस, лния,
   {{0x64437082,0x2918a00c,0x6ab600f6,0x26c00183}},	//   żnie, jira_, _abyf, heio_,
   {{0x2918a00d,0x3ebf0088,0x25a0a00e,0x69d6a00f}},	//   dira_, beut_, huil_, _arye,
   {{0x29180bc8,0x3ebf0c6f,0x69d603d0,0x7cff0345}},	//   eira_, ceut_, _brye, _vêra,
   {{0xc3330052,0xdd94081b,0x6f02a010,0x26c00132}},	//   שור_, _салы, _iloc, deio_,
   {{0x2918a011,0x26cb7397,0xe94500fd,0x2f1a00ea}},	//   gira_, _saco_, انسپ, rīgu_,
   {{0x195800d8,0x26cb215f,0x6f02a012,0x69d6001c}},	//   тары_, _paco_, _kloc, _erye,
   {{0x25a002aa,0x69d6a013,0x6ef50473,0x3704a014}},	//   fuil_, _frye, _fábu, ачув,
   {{0x2918a015,0xa4d90c06,0x44b541d5,0x2f1a00ea}},	// [b5d0] bira_, ндау_, лбас, līgs_,
   {{0x29183aa0,0x6f024aa7,0x7afda016,0x3ebf0055}},	//   cira_, _lloc, lkst, zeut_,
   {{0xaaaa112b,0xf2b10083,0x7d1d0310,0x6f023304}},	//   _कामक, _ঘোষণ, éssi, _oloc,
   {{0x7afda017,0x26c00132,0x442a0282,0x25a0009e}},	//   nkst, ceio_, _dxb_, buil_,
   {{0x442aa018,0xf1a73029,0xf62b01e0,0xf5e400c7}},	//   _exb_, трен, _ціни_, _кірм,
   {{0xa5da02b5,0x6f020171,0x80cd0324,0x2bd53421}},	//   _אַלי, _aloc, _धोखे, धिमा,
   {{0x6f023ec3,0x7afd63a4,0x386101da,0x00000000}},	//   _bloc, kkst, _mghr_, --,
   {{0x2918024c,0x7afd0120,0xb7f63893,0xfe71004f}},	//   zira_, jkst, ीनतम_, حدث_,
   {{0x6d4a0082,0x29180b55,0xed59081b,0xdfd100b5}},	//   _bhfa, yira_, нои_, _گيا_,
   {{0x6f02a019,0x29180042,0x7afda01a,0x00000000}},	//   _eloc, xira_, ekst, --,
   {{0xdfd100b5,0x00000000,0x00000000,0x00000000}},	//   _ديا_, --, --, --,
   {{0x6f02a01b,0x2918a01c,0x139a0070,0x38610027}},	//   _gloc, wira_, עברע, _aghr_,
   {{0x29181adc,0x6b9a0051,0x7c2a038e,0xaaaa0edf}},	//   tira_, artg, _exfr, _काठक,
   {{0x6f02a01d,0x7c2aa01e,0xe6dc007e,0x291800a2}},	//   _zloc, _fxfr, मञ्ज, uira_,
   {{0x29186aac,0x31560070,0x81e90033,0x26c00132}},	//   rira_, טישן_, মনি_, teio_,
   {{0xef19003c,0x7faa00a8,0x69d60031,0x6ef50132}},	//   niż_, _təqv, _trye, _tábu,
   {{0x291841a6,0xb90a00c8,0x2d8d3236,0x26c02de8}},	// [b5e0] pira_, _মত_, nsee_, reio_,
   {{0xa3c1012f,0xb5fb002a,0x81e90033,0x26c00132}},	//   ्टं_, _afás, মনা_, seio_,
   {{0x1d160070,0x23d600af,0x2242023a,0x00000000}},	//   נקער_, ыцар, _škk_, --,
   {{0x66e618c4,0x5c360070,0xaadd01c0,0x7cf600af}},	//   _сома, ארען_, याएक, _hârt,
   {{0x25a0a01f,0x67241b86,0xe61f099e,0x00000000}},	//   quil_, mnij, _ddôs_, --,
   {{0x67240ce9,0x6f020523,0xf4870647,0x601802d6}},	//   lnij, _sloc, _مافی, коля_,
   {{0x6f02155b,0x6d470484,0xf503a020,0xdfd0004f}},	//   _ploc, ċjal, _узро, زية_,
   {{0x6724048c,0x6d4a00da,0x64430035,0x6566023c}},	//   nnij, _shfa, żnic, _kukh,
   {{0x9c7c0169,0x2d8d011e,0x0caa0786,0x69c0027d}},	//   ljči, gsee_, нтни_, çmel,
   {{0x65669159,0xa2d8022e,0x672400f4,0x00000000}},	//   _mukh, _नोत्, hnij, --,
   {{0x5ea60332,0x6f0276dc,0x9c7c0124,0x67246893}},	//   _ممال, _tloc, njči, knij,
   {{0x67240a78,0xe45702b5,0x2f1a00ea,0x00000000}},	//   jnij, טייט_, rīgs_, --,
   {{0x6724a021,0xb69b0395,0x3f5100fe,0x00000000}},	//   dnij, _blân, _ešus_, --,
   {{0x7afda022,0x7cf60139,0xbd020097,0x7b1600ac}},	//   skst, _cârt, _šéfr, nšuj,
   {{0x7d1a95b0,0x6b6100ec,0x00000000,0x00000000}},	//   mits, _bēgu, --, --,
   {{0x7d1a9e75,0x65668ae7,0xc8780463,0xeafb00d1}},	//   lits, _bukh, ığa_, _سرعت_,
   {{0xd49b0d07,0xb4c2073f,0xdb0203bc,0xb69b00a2}},	// [b5f0] ере_, ्यू_, kulê, _flân,
   {{0x7d1aa023,0x67242b6c,0x6566067f,0xb69b0183}},	//   nits, anij, _dukh, _glân,
   {{0x6724a024,0x7faa01c2,0x62750088,0x7e620205}},	//   bnij, _məqs, لهائ, _ogop,
   {{0x7d1aa025,0x7e6200d1,0x2d8d79b6,0x6724011c}},	//   hits, _ngop, ysee_, cnij,
   {{0xd49b0370,0x7d1a1eb8,0x91e58207,0x00852f44}},	//   _прв_, kits, роле, алло,
   {{0x7e62027a,0x21660036,0x8ca907df,0x6ef507c0}},	//   _agop, шиши_, ज्ञो, _nábr,
   {{0x7d1a997b,0x35ab0084,0x3ce8363d,0x660d1c3a}},	//   dits, _चमड़, जाने_, lzak,
   {{0x2d8da026,0x64630225,0x0e65a027,0x00000000}},	//   tsee_, ştiğ, шкин, --,
   {{0x628ba028,0x7bd80006,0x660da029,0x7d1aa02a}},	//   mago, _arvu, nzak, fits,
   {{0x7d1aa02b,0x2d8da02c,0x672415d7,0xa3bc0f9c}},	//   gits, rsee_, znij, _अहम_,
   {{0x8c450439,0x3b0a17e3,0x60c3a02d,0x4b2610e3}},	//   рене, вено_, menm, имов,
   {{0x60c30723,0x660d0051,0x81d80083,0xa96a01f2}},	//   lenm, kzak, াহর_, кима_,
   {{0x6ef51ec0,0xfce52cdd,0x7bca0033,0x67240a78}},	//   _fábr, _воло, _esfu, vnij,
   {{0x2eed0b16,0x660da02e,0x7d1a0010,0x6f090279}},	//   ljef_, dzak, cits, lhec,
   {{0x67240a78,0xb8ee0fd1,0xc7160370,0xfb2500fd}},	//   tnij, _रस_, аќањ, _گروپ,
   {{0x6f0900c9,0x67240029,0x6ef50187,0x628ba02f}},	//   nhec, unij, _zábr, jago,
   {{0x672401cc,0x6d410341,0x7b160187,0x60c3a030}},	// [b600] rnij, olla, yšuj, kenm,
   {{0xb4c20429,0x67240537,0x6d41001e,0x2ec20785}},	//   ्ये_, snij, nlla, _शस्त,
   {{0x6d41a031,0x672403c9,0x60c3a032,0x845a74e8}},	//   illa, pnij, denm, трат_,
   {{0xe5a616ac,0x7d1a06a2,0xe29a889e,0xa5bb01ef}},	//   _кими, zits, тад_, _axóu,
   {{0x6d4101e9,0x7d1a0010,0xb0e2051d,0x00000000}},	//   klla, yits, पालग, --,
   {{0x3f9c0274,0x60c3378c,0x2fc700e9,0x64430067}},	//   trvu_, genm, fwng_, żnia,
   {{0x628ba033,0x7d1aa034,0x7b240254,0x21200254}},	//   bago, vits, rđuj, đih_,
   {{0xa8570122,0x6d41a035,0x7d1a9154,0x00000000}},	//   סיקה_, ella, wits, --,
   {{0x7d1a47f1,0x10a602ce,0xa0a603fa,0x290a022e}},	//   tits, _визн, _вазд, khba_,
   {{0x6208033e,0x7bd80009,0x60c31eeb,0x6146010c}},	//   ırlı, _prvu, cenm, _теза,
   {{0x7d1aa036,0x14d90070,0x9b590370,0xe8d90023}},	//   rits, אַרמ, лиот_, _huệ_,
   {{0x6d41148b,0x7d1a0d43,0x6f1ba037,0xdee30036}},	//   alla, sits, ciuc, _мохи,
   {{0x7d1aa038,0x799d03bc,0x7faa00a8,0xfaff0031}},	//   pits, ursw, _təqs, rkë_,
   {{0xb4c2000c,0x290500fb,0x7cf6002d,0x628ba039}},	//   ्यो_, óla_, _vârs, zago,
   {{0xb4c200b8,0x9b9418dd,0xd7f84fa2,0x628ba03a}},	//   ्यै_, _البت, аут_, yago,
   {{0x27ed3b12,0x660d0291,0x60c37b20,0xdce90009}},	//   ćen_, tzak, zenm, tpeć,
   {{0x79840090,0x628ba03b,0x60c300cc,0xd6d80d6e}},	// [b610] _gwiw, vago, yenm, јтс_,
   {{0x660da03c,0x5fc601c0,0x00000000,0x00000000}},	//   rzak, लबाल, --, --,
   {{0x660d006c,0x60c36fff,0xdce900cd,0x00000000}},	//   szak, venm, speć, --,
   {{0x3cdd0067,0x00000000,0x00000000,0x00000000}},	//   _कोने_, --, --, --,
   {{0x6d41a03d,0x60c3a03e,0x9c7c0009,0x645a0987}},	//   ylla, tenm, ljču, _útin,
   {{0x628b300c,0xe8d900cc,0x00000000,0x00000000}},	//   sago, _duệ_, --, --,
   {{0x628ba03f,0x60c3a040,0xa5bb1ea3,0x43943c0c}},	//   pago, renm, _exót, _марс,
   {{0x53340af5,0x3eb90093,0x60c3a041,0x0d85a042}},	//   _дест, ýst_, senm, блин,
   {{0x20c703ad,0xc33202b5,0x6d410443,0x6f1ba043}},	//   _всег, _זון_, tlla, riuc,
   {{0xa5da02b5,0x5fc20433,0xf99f027a,0xdb02000d}},	//   אַטי, _वैकल, drè_, mulé,
   {{0x63a5005d,0x673d00ab,0x6d4100e9,0x00000000}},	//   nuhn, _oksj, rlla, --,
   {{0x6d411733,0xc86902b5,0xb69b00a2,0x7faa013b}},	//   slla, _טן_, _blâm, _təqr,
   {{0xdb026089,0xf99f02d0,0x6d410055,0x00000000}},	//   nulé, grè_, plla, --,
   {{0xcd760122,0x673d01e0,0xed4400d4,0xa9670dc8}},	//   _העסק_, _aksj, _дніп, сира_,
   {{0x69cd01a3,0x66e65128,0x00000000,0x00000000}},	//   _esae, бова, --, --,
   {{0x753c07b3,0x96661ac5,0xc61f0033,0x49ca0421}},	//   _skrz, скае, _দরজা_, _блин_,
   {{0x98a60d13,0x00000000,0x00000000,0x00000000}},	// [b620] _липе, --, --, --,
   {{0x7af6390a,0x88ca0352,0x673d312a,0xdb0200a2}},	//   _hoyt, _слов_, _eksj, dulé,
   {{0x7ae44041,0x63a5005d,0xb4c25f2e,0x25b2a044}},	//   _knit, guhn, ्यौ_, styl_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce20254,0xe2970274,0x61462753,0x7ae49dda}},	//   _suoč, сач_, беда, _mnit,
   {{0x63a50ec0,0x2ba80ea3,0x2fcc01ef,0x54670210}},	//   buhn, _कमला, _psdg_, _гарм_,
   {{0x7ae40160,0x6f190176,0xa3bc00be,0x00000000}},	//   _onit, _bmwc, _अहि_, --,
   {{0xe8d90019,0x3f85099e,0x00000000,0x00000000}},	//   _tuệ_, _dwlu_, --, --,
   {{0x3f512e37,0xdb02000d,0xfe6f00bc,0x7a1c00ea}},	//   _všup_, culé, ردي_, nātī,
   {{0x7ae4a045,0x6aada046,0xf99f02d0,0x7cf60139}},	//   _anit, _scaf, vrè_, _cârp,
   {{0x25a0046a,0x853b0319,0x7af69d6a,0x00000000}},	//   hril_, רגיי, _boyt, --,
   {{0x291aa047,0x7ae4009e,0x00000000,0x00000000}},	//   _ampa_, _cnit, --, --,
   {{0x4aaa1bb5,0xaaaa3dd4,0x2d9f4b2f,0x00000000}},	//   _कारव, _कारक, crue_, --,
   {{0x25a0a048,0x7ae400c3,0xf99f0036,0xee3700af}},	//   dril_, _enit, rrè_, _унч_,
   {{0x28de06bc,0x236a0118,0x7ae40282,0x00000000}},	//   माजि, _nubj_, _fnit, --,
   {{0xf99f02d0,0x7ae4a049,0x7af60132,0x28ad06fe}},	//   prè_, _gnit, _goyt, ञ्जि,
   {{0xddc91a2e,0x49c800af,0x00000000,0x00000000}},	// [b630] zbež, _луэм_, --, --,
   {{0x04673d9f,0x63a5a04a,0x00000000,0x00000000}},	//   стам, tuhn, --, --,
   {{0x645a7e36,0x25a000be,0x00000000,0x00000000}},	//   _útil, aril_, --, --,
   {{0xa29402ce,0x63a50ec0,0x25a09e76,0xe81222d4}},	//   заці, ruhn, bril_, _डेटा_,
   {{0x63a50ac8,0x00000000,0x00000000,0x00000000}},	//   suhn, --, --, --,
   {{0x63a50124,0x2903a04b,0xaf991962,0xdb0200fd}},	//   puhn, nkja_, атих_, rulé,
   {{0xaaaa017f,0x7bde00ac,0x4aaa01d1,0x2903008d}},	//   _कालक, _špun, _कालव, ikja_,
   {{0x2d956cac,0xdb0200a2,0x4ad9227d,0xaad9157d}},	//   орос, pulé, _बोलव, _बोलक,
   {{0x2903a04c,0xdd8e017e,0xa0c50833,0x6efc00a2}},	//   kkja_, نوي_, _ويرو, _nébu,
   {{0x709400af,0x7e9904cd,0xb65c016b,0x2d9fa04d}},	//   _науф, _چنار_, נדזש, rrue_,
   {{0x7af6081b,0xddc20035,0x2d9f02c4,0x00000000}},	//   _poyt, _czoł, srue_, --,
   {{0x6b9c0138,0x68e500e2,0x44315eec,0x00000000}},	//   árga, _anhd, _mxz_, --,
   {{0xa96a0382,0x7ae401c0,0x68f70051,0x00000000}},	//   рига_, _vnit, _boxd, --,
   {{0x6efc02e1,0xb4e8073f,0x00000000,0x00000000}},	//   _débu, _मचे_, --, --,
   {{0xd9430043,0x46f6a04e,0xc1b607df,0x00000000}},	//   фери, очат, _आङ्ग, --,
   {{0x7ae4a04f,0x25a0391b,0x2615007c,0x224d02a7}},	//   _unit, tril_, _नइखी_, _ozek_,
   {{0x24980a4e,0x3cf00099,0x00000000,0x00000000}},	// [b640] _pdrm_, ेसचे_, --, --,
   {{0x25a0a050,0x81cf0033,0x7a1c0228,0x291aa051}},	//   rril_, ষমা_, rātī, _umpa_,
   {{0x80d40b35,0x25a0012f,0xba290416,0x6efc0118}},	//   _योगे, sril_, _نسیم_, _zébu,
   {{0x645a014c,0x55e61956,0x3bba016b,0x6efc0118}},	//   _útim, _домб, ימעד, _yébu,
   {{0x68f701c2,0x00000000,0x00000000,0x00000000}},	//   _yoxd, --, --, --,
   {{0xdfd001b2,0x6ea701c0,0xcf9a0274,0x00000000}},	//   فيت_, _गाउँ, аји_, --,
   {{0x224d006c,0x4aaa0066,0x28b20035,0xaaaa00b4}},	//   _ezek_, _कांव, _जानि, _कांक,
   {{0x644e02dd,0x63b30314,0xe1fa082e,0x00000000}},	//   _izbi, žení, _кгб_, --,
   {{0x62825979,0xd1320180,0x2903008d,0x00000000}},	//   mboo, _قمر_, ykja_, --,
   {{0x6282476c,0x6efc00d5,0x00000000,0x00000000}},	//   lboo, _rébu, --, --,
   {{0x2fd80051,0x44310176,0x00000000,0x00000000}},	//   _érg_, _xxz_, --, --,
   {{0x62822b78,0x539b00a5,0x00000000,0x00000000}},	//   nboo, סיכו, --, --,
   {{0x628201bf,0x00000000,0x00000000,0x00000000}},	//   iboo, --, --, --,
   {{0x644e0a78,0x628264d3,0x00000000,0x00000000}},	//   _ozbi, hboo, --, --,
   {{0x29030bd1,0xa5bb01ef,0x368b2770,0x6282a052}},	//   rkja_, _axóp, исан_, kboo,
   {{0x442d1254,0xb9021649,0x2903a053,0x27030033}},	//   _će_, _नो_, skja_, রোনো_,
   {{0x95cb0370,0xc4cf0033,0x644e0c6f,0x00000000}},	// [b650] шува_, রাসঙ, _azbi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x527500af,0x62820345,0x00000000,0x00000000}},	//   пулу, fboo, --, --,
   {{0x62820298,0x22440132,0x67290009,0x00000000}},	//   gboo, _bymk_, čejs, --,
   {{0x6b730395,0x00000000,0x00000000,0x00000000}},	//   _măga, --, --, --,
   {{0x62820103,0x98aa00b8,0x93970037,0xddc90207}},	//   aboo, době_, _وجزا, jceš,
   {{0x628200f6,0x5ed40033,0x00000000,0x00000000}},	//   bboo, থানে, --, --,
   {{0x0d850fbb,0xe8a80355,0x629602d7,0x6282a054}},	//   плин, _कञ्च, óyot, cboo,
   {{0x25a940d4,0xb36402fb,0x00000000,0x00000000}},	//   nual_, _църк, --, --,
   {{0x7d090274,0x2a690298,0x00000000,0x00000000}},	//   сног_, _agab_, --, --,
   {{0x0c220677,0x6b730395,0x00000000,0x00000000}},	//   емэн, _băga, --, --,
   {{0x7d0a01ff,0x691000be,0x25a901ed,0x00000000}},	//   _elfs, _käeg, kual_, --,
   {{0x25a9005d,0x316d0831,0x14ac0099,0xdddb00e1}},	//   jual_, _juez_, _चालण, lauž,
   {{0x25a9a055,0x3eada056,0xcdf600a5,0xa3bc0067}},	//   dual_, lget_, _ממני_, _अहल_,
   {{0x8c421906,0x66e6032f,0x3ce855f5,0xdb0202d7}},	//   _пеше, пова, जारे_, lulí,
   {{0x3eada057,0x628201a2,0x6efca058,0x7d06025f}},	//   nget_, xboo, _hébr, ūkst,
   {{0xf651006c,0x316d0a17,0x3ce70051,0x00000000}},	// [b660] ہئے_, _nuez_, _knnv_, --,
   {{0x628204f4,0xd88400f8,0x6b730139,0x00000000}},	//   wboo, _تهدی, _zăga, --,
   {{0xc9530122,0xe73a3537,0x00000000,0x00000000}},	//   _רמת_, _ген_, --, --,
   {{0xcfc30083,0x25a9028b,0xe2970f24,0x69c4009f}},	//   ্মান, bual_, зац_, _kpie,
   {{0x628209ef,0x237f0254,0xcb130070,0xd04600a8}},	//   rboo, _čuje_, עלד_, əmən,
   {{0x673b4209,0x628240cf,0x7bc31c77,0x00000000}},	//   čuje, sboo, _opnu, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c4324f,0x3ead0bf3,0x3da6a059,0xb2260012}},	//   _opie, gget_, проб, _ембл,
   {{0xa0a6010b,0x7d0a00d7,0x5d540265,0xdbcb0300}},	//   _наад, _plfs, мкит, dóñe,
   {{0xcb9802ce,0xa61700a5,0x48d70033,0x98aa0355}},	//   ової_, פקיד_, _সক্র, robě_,
   {{0x6efc00f7,0x69c4a05a,0xc05900d4,0x25a9a05b}},	//   _débr, _apie, _дії_, zual_,
   {{0x77660024,0x6b5f005f,0x00000000,0x00000000}},	//   _nikx, _kūgi, --, --,
   {{0x76460086,0x25a972ca,0xdb0200ac,0x6efc00f6}},	//   _nyky, xual_, culí, _fébr,
   {{0xa3bc035d,0xa3dfa05c,0xd90f00bf,0x61e0022f}},	//   _अहं_, तिम_, اید_, _mrml,
   {{0xc7c42252,0x1cbb02b8,0x8c4101ae,0x69c40b88}},	//   нсти, _המוע, ößte, _epie,
   {{0x6d48a05d,0x25a93ec3,0x64430067,0x61e00211}},	//   llda, tual_, żnik, _orml,
   {{0xa63400d4,0xdb020132,0x7b1600c7,0x00000000}},	// [b670] енті, bulâ, ršut, --,
   {{0x64c7018d,0x3ead27c3,0x00000000,0x00000000}},	//   रजेश, zget_, --, --,
   {{0x28b20af6,0x25a93820,0x3ead01ff,0x6d48008d}},	//   _जाति, sual_, yget_, ilda,
   {{0x27fe0168,0xadec0e3b,0x00000000,0x00000000}},	//   ätne_, जमान_, --, --,
   {{0x672d6db7,0xd6d800af,0xa069002d,0x31650110}},	//   mnaj, _этэ_, оала_, _pilz_,
   {{0x69dd00ab,0x656f01a6,0x657d0c6f,0x7b2400f4}},	//   ivse, _iuch, _itsh, nđur,
   {{0xdfce004f,0xdb0903e6,0x656f2494,0x44250282}},	//   ليو_, rudê, _huch, _äl_,
   {{0x656fa05e,0xe3b202b5,0xa3da0084,0x6d5a30bc}},	//   _kuch, _שױן_, ़िर_, emta,
   {{0x61e000cb,0x518701d3,0x7bdc05ee,0x00000000}},	//   _grml, _хуба, ærun, --,
   {{0x656f00c8,0x69dd02c6,0x00000000,0x00000000}},	//   _much, dvse, --, --,
   {{0x656fa05f,0x69c4a060,0xfaa613f8,0x00000000}},	//   _luch, _spie, мано, --,
   {{0x656fa061,0x672d0207,0xf1d400ab,0x00000000}},	//   _ouch, jnaj, _धनमन, --,
   {{0x657d01a9,0x656fa062,0x672d4481,0xdb190b3e}},	//   _ntsh, _nuch, dnaj, _opvæ,
   {{0x7f5b104e,0xdce201ba,0x7f490bf4,0x65670051}},	//   lmuq, _zvoľ, lleq, _nijh,
   {{0x18670272,0x7bc300ac,0xdbcb002a,0x657d00ec}},	//   дари_, _upnu, póñe, _atsh,
   {{0x656fa063,0x63a500d5,0x69c00225,0x00000000}},	//   _buch, drhn, çmes, --,
   {{0x2bd54b05,0x656f0831,0xf74313f8,0x656701e4}},	// [b680] धिका, _cuch, тето, _bijh,
   {{0x656f93e0,0xe5a30947,0x80bf05e7,0x764600d5}},	//   _duch, тифи, ल्मे, _vyky,
   {{0x753e0223,0x00000000,0x00000000,0x00000000}},	//   ropz, --, --, --,
   {{0x2bf600c2,0x4e0d1a75,0xaac106bc,0x71a600d8}},	//   ומען_, िनाई_, ष्पक, дадз,
   {{0xc69302b8,0x6d489b5e,0x00000000,0x00000000}},	//   _באר_, ylda, --, --,
   {{0x6d460355,0x26c201ed,0x00000000,0x00000000}},	//   ůkaz, _hbko_, --, --,
   {{0xd0100082,0x656fa064,0xa0670274,0x660400b5}},	//   طلة_, _zuch, маља_, lyik,
   {{0x6d4300ab,0x26c70009,0xdd9a0132,0x00000000}},	//   _akna, đnog_, ошо_, --,
   {{0x6604002f,0xd1b30e3a,0x00000000,0x00000000}},	//   nyik, _لینک, --, --,
   {{0x672d35b9,0xf0a700af,0x28c021b2,0x00000000}},	//   znaj, _окул_, श्मि, --,
   {{0x6d480523,0x6d5aa065,0x672d0067,0xedb500fd}},	//   rlda, rmta, ynaj, وجیک,
   {{0xdd8f00bf,0xa3df0803,0xdce200a0,0x6abd02b1}},	//   _چون_, तित_, _uvoľ, ufsf,
   {{0x6ef50076,0x6abd008a,0x672d2d5b,0x6724a066}},	//   _náby, rfsf, vnaj, diij,
   {{0x656f12ad,0x67d50183,0xab940274,0x69dd3ccd}},	//   _ruch, ногу, _закљ, rvse,
   {{0x656f0446,0xb882016f,0x672da067,0xdb020392}},	//   _such, _číta, tnaj, bulà,
   {{0x656701a9,0x63a50187,0x656fa068,0x66040027}},	//   _sijh, vrhn, _puch, fyik,
   {{0x672da069,0x656f02d7,0xdb020453,0x057411c0}},	// [b690] rnaj, _quch, atló, نالد,
   {{0x88c4004e,0xdb0205fa,0x672d013a,0x26c201b7}},	//   ęści, mulá, snaj, _ebko_,
   {{0x5695a06a,0x7cf60160,0x656f02b1,0x391400af}},	//   _пант, _bârz, _wuch, _рмэр,
   {{0x798d0428,0x656fa06b,0x65670223,0x3dc600e0}},	//   _kwaw, _tuch, _wijh, _opow_,
   {{0xdb0200b5,0x7cff0298,0x66160067,0xb5fb00fe}},	//   nulá, _mêrr, czyk, _agáv,
   {{0x2c0e022e,0x26d9025c,0x798d018e,0x00000000}},	//   ानां_, _haso_, _mwaw, --,
   {{0x26d9383a,0x798d073a,0xa06601f2,0x6b56683f}},	//   _kaso_, _lwaw, наша_, láge,
   {{0x26d906a2,0xdb02a06c,0xaac100b4,0x6d430159}},	//   _jaso_, kulá, ष्मक, _skna,
   {{0x2d990332,0x2d8b02e1,0x26d9a06d,0xdcfb0009}},	//   ése_, èce_, _maso_, spuč,
   {{0x26d9a06e,0xdb022d87,0x2491005f,0x00000000}},	//   _laso_, dulá, _jezm_, --,
   {{0x8b26372f,0x798d0c2f,0x6b5f00ea,0x00000000}},	//   едне, _awaw, _lūgu, --,
   {{0xa3c20084,0x28b20ca1,0x26d9a06f,0x798d1d6a}},	//   ्बत_, _जाहि, _naso_, _bwaw,
   {{0xdca50b00,0xdb022fc3,0xf1e20567,0x645a0093}},	//   _зали, gulá, पियन, _útiv,
   {{0xfe790355,0x00000000,0x00000000,0x00000000}},	//   lců_, --, --, --,
   {{0x6d41a070,0x672402d4,0x26d9a071,0x3b0a3668}},	//   mola, tiij, _baso_, _неко_,
   {{0x6d41a072,0xaaaa0026,0xfe7900b8,0x96660274}},	//   lola, _काटक, nců_, екбе,
   {{0xe5a37027,0x6724a073,0x26d90260,0x237f0124}},	// [b6a0] лити, riij, _daso_, _čuja_,
   {{0x6d41a074,0x387a0132,0xaac100b8,0x26d90065}},	//   nola, _ufpr_, ष्ठक, _easo_,
   {{0x66043f8b,0x66160035,0x292900a0,0xb69b000d}},	//   syik, szyk, ýtať_, _plât,
   {{0xe292004f,0x26d90159,0x6d41a075,0x6b5600b5}},	//   اذا_, _gaso_, hola, lágb,
   {{0x6d41a076,0x68fea077,0xfe790355,0x00000000}},	//   kola, _kopd, dců_, --,
   {{0x6d417def,0x00000000,0x00000000,0x00000000}},	//   jola, --, --, --,
   {{0x6d41a078,0x7cf600af,0x25762a7d,0x00000000}},	//   dola, _târz, _hæl_, --,
   {{0x78bb0274,0xdce30c99,0xb1830334,0x26c0a079}},	//   đuvi, _dinč, šťan, nfio_,
   {{0x6d41a07a,0xe2a6008a,0x68fe0345,0x00000000}},	//   fola, æðum_, _oopd, --,
   {{0x6d41a07b,0xdce30009,0x798d04fb,0x21750200}},	//   gola, _finč, _rwaw, _јутр,
   {{0x69d6a07c,0xfe790355,0xdce300c7,0x798da07d}},	//   _asye, bců_, _ginč, _swaw,
   {{0x60da6287,0xdb0282f5,0xbebd00c7,0xdb19008c}},	//   _hatm, tulá, liūn, _opvå,
   {{0x6d41a07e,0xc3330122,0x26d92681,0x60daa07f}},	//   bola, רור_, _raso_, _katm,
   {{0xa3c20bc1,0x6d41187d,0xd0480095,0x690b0392}},	//   ्बा_, cola, _sadə, _güel,
   {{0x26d909ab,0x60daa080,0x3cf72ac4,0x26c0a081}},	//   _paso_, _matm, _سعود_, ffio_,
   {{0xdb022eef,0xd6d827ac,0xf7700a72,0x798d876b}},	//   pulá, нту_, صاف_, _twaw,
   {{0x7aeda082,0xe4a72495,0xe5730ad9,0x4ac1143a}},	// [b6b0] _inat, ерео, اطر_, ष्णव,
   {{0xaab12869,0x60daa083,0x81d60033,0x00000000}},	//   _झाँक, _natm, িমা_, --,
   {{0x929501c8,0x6b9a1b04,0xb5fb0097,0x7aed2c7a}},	//   ваец, nstg, _agát, _knat,
   {{0x6d41a084,0x66fb193c,0x7aff007a,0x25760d51}},	//   zola, _एकटक_, _joqt, _fæl_,
   {{0xe4a71a31,0xdce30169,0x7aeda085,0x6d41a086}},	//   _прво, _sinč, _mnat, yola,
   {{0x60daa087,0xeafe10b7,0x6d411c7a,0x6b9aa088}},	//   _catm, _उक्त_, xola, kstg,
   {{0x6d41a089,0x7fd50210,0xe53400c3,0xaab10066}},	//   vola, тілі, _серь, _झांक,
   {{0xdce3a08a,0x6455a08b,0x25a9009e,0x6b5600b5}},	//   _vinč, _izzi, oral_, zágb,
   {{0x6d41a08c,0x6f09005d,0x60daa08d,0x28b20026}},	//   tola, rkec, _fatm, _जालि,
   {{0x7aeda08e,0x270e1fe0,0x25a90dc3,0x6d580097}},	//   _anat, _सत्र_, iral_, _chva,
   {{0x6d580024,0x2127a08f,0x25a900a0,0x6b9a0223}},	//   _dhva, minh_, hral_, gstg,
   {{0x74c1a090,0x25a9a091,0x7aed01da,0x21270023}},	//   र्तृ, kral_, _cnat, linh_,
   {{0x6d41a092,0xd6b90083,0x60da00c1,0xfe7011c0}},	//   pola, ুযায, _yatm, _ادم_,
   {{0xada20210,0x6d411505,0xdca527eb,0x7aed5124}},	//   _ташл, qola, _раки, _enat,
   {{0xa9670de3,0x7aed0282,0x673b0506,0x2576008d}},	//   тира_, _fnat, čujn, _sæl_,
   {{0x212700e2,0x7c2e0138,0x6b5600b5,0x6d580055}},	//   hinh_, úbre, ságb, _zhva,
   {{0x6603a093,0x26c0001e,0x68fea094,0x6455001c}},	// [b6c0] апта, rfio_, _topd, _azzi,
   {{0x7aed01cc,0x25763ce9,0xd9100332,0xdb020098}},	//   _znat, _væl_, _ایس_, irlí,
   {{0xcf850118,0xa3df0f06,0x60da0107,0x21270023}},	//   _دژ_, तिष_, _ratm, dinh_,
   {{0x2ba900c4,0xf62600d8,0x60da00c1,0x130a1482}},	//   _किना, _адмо, _satm, ьней_,
   {{0xdb02177c,0x60daa095,0x41b603e6,0x6e2d023a}},	//   pulæ, _patm, тсет, _žabn,
   {{0xa3df04bc,0x00000000,0x00000000,0x00000000}},	//   तिश_, --, --, --,
   {{0xd00f00ad,0x2d9d0260,0x200700fd,0x60da0160}},	//   يله_, _avwe_, gyni_, _vatm,
   {{0xa3df3914,0x6d5801cc,0x00000000,0x00000000}},	//   तिर_, _shva, --, --,
   {{0x7aed023a,0x324619b6,0x60da0225,0x21270023}},	//   _rnat, _реаг, _tatm, binh_,
   {{0x61e2013b,0x645a4a12,0x00000000,0x00000000}},	//   mvol, _útis, --, --,
   {{0x61e2a096,0x3d180ceb,0xdb02a097,0xaa950036}},	//   lvol, योगे_, kulä, линч,
   {{0x7e7b119e,0xdce300ee,0x00000000,0x00000000}},	//   ccup, _finď, --, --,
   {{0xf2d3012b,0x61e22ce4,0xceb300a5,0x80bf0099}},	//   בער_, nvol, _כיף_, ल्वे,
   {{0x6d580470,0x25a90095,0xa8a41c1b,0x395a0345}},	//   _uhva, vral_, ирск, _chps_,
   {{0xe89400d8,0x394300ea,0x7d1d0c6f,0xd9180421}},	//   рась, rojs_, ësse, тья_,
   {{0x7aeda098,0xdb0202b1,0x7bca04fb,0x23bc00fd}},	//   _unat, gulä, _ipfu, díj_,
   {{0x2737048c,0xb5fba099,0xe664386a,0x61e200f4}},	// [b6d0] għna_, _agár, атфо, jvol,
   {{0x58d50086,0x2ba90099,0x21270023,0x2f1100d5}},	//   _соот, _किमा, xinh_, _mága_,
   {{0x61e2a09a,0xdd860609,0xb8820355,0x212700e2}},	//   evol, _گو_, číte, vinh_,
   {{0x5215027a,0x25a90359,0xf6790070,0xef1f0067}},	//   лдет, pral_, _ראָמ, ężko_,
   {{0xdd86a09b,0x29014c73,0x28c005e7,0x21270023}},	//   _دو_, _koha_, श्वि, tinh_,
   {{0xe3b30919,0x7bca0b3e,0xe1f00079,0x95820067}},	//   _پرس_, _opfu, تسم_, żące,
   {{0xb4c1a09c,0x6455a09d,0xf3671159,0x998d0187}},	//   ्जी_, _uzzi, _атан, šeň_,
   {{0xa3c200b1,0x212700cc,0x00000000,0x00000000}},	//   ्बर_, sinh_, --, --,
   {{0x629900bf,0x7e7ba09e,0x20070093,0x7bca04fb}},	//   mawo, rcup, syni_, _apfu,
   {{0x14c6178c,0x62995589,0x6373009f,0x29017efd}},	//   र्पण, lawo, _aħni, _noha_,
   {{0xa5bb002a,0x5edb0831,0x1dd80067,0xcc8905f5}},	//   _exóx, ভাবে, _बैठत, ونکه_,
   {{0xdd8e05f5,0xdb0900ac,0xdce300ec,0x00000000}},	//   _کوو_, budí, _dinā, --,
   {{0xed4e9ddf,0x6da5059b,0x29010187,0xada502ee}},	//   _го_, _сила, _boha_, _салл,
   {{0xdce300ea,0xeb99002d,0x00000000,0x00000000}},	//   _finā, _зик_, --, --,
   {{0x61e2a09f,0xab2a0086,0x2901a0a0,0x6299a0a1}},	//   zvol, _пока_, _doha_, kawo,
   {{0x236d004e,0x224d01ed,0x00000000,0x00000000}},	//   _niej_, _oyek_, --, --,
   {{0xe73703ad,0xdce30080,0x224d0ec1,0xf99f02d0}},	// [b6e0] ует_, _zinā, _nyek_, nyèl_,
   {{0xa3c20ac4,0x61e20036,0x00000000,0x00000000}},	//   ्बल_, vvol, --, --,
   {{0xdb02022a,0x6e2d00cd,0x29180098,0x00000000}},	//   pulä, _žabl, mhra_, --,
   {{0x28c002b4,0x61e2a0a2,0x6299a0a3,0x248701fb}},	//   श्रि, tvol, gawo, ınma_,
   {{0xf1266e5f,0xdb0901ef,0x00000000,0x00000000}},	//   лько, xudí, --, --,
   {{0x26d26242,0x61e23953,0xbebd01c8,0xdfd00037}},	//   leyo_, rvol, siūl, قيت_,
   {{0x3d07544f,0x61e2a0a4,0x6aa40036,0x4fc61285}},	//   ाउने_, svol, _odif, усла,
   {{0x3f83003c,0x26d205ba,0x6aa41642,0x5ea70033}},	//   _ħjut_, neyo_, _ndif, ক্সে,
   {{0x9d14172a,0x6b830159,0x798401d5,0xa0b60754}},	//   идич, _atng, _ntiw, _محاص,
   {{0xfb86005f,0x2b490124,0x6aa472bf,0x02032701}},	//   лымн, _skac_, _adif, _узун,
   {{0x9b59051b,0xef8617a3,0x61d41579,0x88c40035}},	//   киот_, _слеп, _धनुष, ęśli,
   {{0x290100b5,0x656ea0a5,0xdce3013a,0x7de6017e}},	//   _soha_, _libh, _vinā, _مستم,
   {{0xf2d302b5,0x6aa4001e,0x26d2a0a6,0xdd9406d8}},	//   זער_, _ddif, deyo_, _талы,
   {{0x14c616f5,0x3cee02d7,0x656e39b7,0x2f0a0211}},	//   र्मण, _unfv_, _nibh, _sùgh_,
   {{0x19582ad9,0x7bca04fb,0x644ea0a7,0x00000000}},	//   уары_, _upfu, _nybi, --,
   {{0x2ba92088,0x656e09c3,0x6b5601ef,0x2c010067}},	//   _किता, _aibh, pága, शहरू_,
   {{0x2918004f,0x6f020183,0x35f5010b,0x2bdc1e18}},	// [b6f0] bhra_, _mooc, шпар, यिका,
   {{0x7afd02dd,0xb4c102e4,0x2918548a,0x62800b3e}},	//   ljst, ्जे_, chra_, _afmo,
   {{0x6299a0a8,0x644e011e,0xa87a00a5,0x656e0284}},	//   tawo, _cybi, _באתר, _dibh,
   {{0x6f02030d,0x7afd15d7,0x656e006b,0xdb022b73}},	//   _nooc, njst, _eibh, stlö,
   {{0x6299a0a9,0xf1a70b12,0xf99f02e9,0x69cb00be}},	//   rawo, урен, nsè_, _äged,
   {{0x656ea0aa,0x7777007a,0x00000000,0x00000000}},	//   _gibh, _kuxx, --, --,
   {{0xfe710514,0x8f1519e2,0x6299a0ab,0x23e400d8}},	//   يدة_, ифич, pawo, _літв,
   {{0xf99f02d0,0x3eb9a0ac,0x00000000,0x00000000}},	//   ksè_, üst_, --, --,
   {{0x6f02009e,0x6b840116,0x00000000,0x00000000}},	//   _dooc, _čiga, --, --,
   {{0x656e01e8,0xf99f02d0,0x61e9a0ad,0x7d090274}},	//   _xibh, ryèl_, _irel, тног_,
   {{0x5ea70083,0xf99f02e9,0x61e9a0ae,0x798400e9}},	//   ক্ষে, syèl_, _hrel, _stiw,
   {{0xda661878,0x6f020223,0x2bb60253,0x3d1700b4}},	//   ивни, _gooc, _अमरा, _फतवे_,
   {{0x82d60100,0x00000000,0x00000000,0x00000000}},	//   בורג_, --, --, --,
   {{0x26d218f9,0x7b0601ef,0xdce30160,0x61e90118}},	//   weyo_, _póus, _dină, _mrel,
   {{0x7d03004f,0x61e9011e,0xa696192f,0x96964163}},	//   _ions, _lrel, ирај, ираш,
   {{0x068659c7,0x656ea0af,0x61e91979,0x644e0865}},	//   рган, _sibh, _orel, _rybi,
   {{0x7d03a0b0,0xa52601c8,0x78bb0254,0x6b56006c}},	// [b700] _kons, амад, đuvr, lágo,
   {{0x64a61ce8,0x7d03a0b1,0x26d20008,0xa5a70387}},	//   ража, _jons, seyo_, _चिरौ,
   {{0x656e0069,0xe29a01c8,0x7d03a0b2,0x93460112}},	//   _vibh, вае_, _mons, анже,
   {{0xf99f02e9,0x66e60c06,0x644e0097,0x083b00a5}},	//   zyèm_, _тома, _vybi, _יעיל,
   {{0x644e004e,0x7bc1007c,0x98a30029,0x61e94d7d}},	//   _wybi, htlu, lijā_, _crel,
   {{0x1fa60009,0x656e01a6,0x6f02023a,0x25a00644}},	//   ариг, _uibh, _sooc, msil_,
   {{0xdfd00082,0x03a32839,0x53a3215b,0x98a30029}},	//   سية_, _миро, _марб, nijā_,
   {{0x61e9335e,0x26160066,0x3ec31397,0x5fa700ab}},	//   _frel, पैथी_, осьб, _गिरल,
   {{0x61e96b90,0xe0da9e4d,0x2498578d,0x6b730395}},	//   _grel, _ива_, _kerm_, _măgu,
   {{0xdceb002d,0x8fa608ce,0xdb0901ef,0x00000000}},	//   _rugă, _важе, dudá, --,
   {{0x25a00095,0x69cd081c,0x6c340037,0x00000000}},	//   hsil_, _spae, صفحا, --,
   {{0x4cd30083,0x25a0a0b3,0x9b270f24,0x98a30228}},	//   তাগু, ksil_, рфол, dijā_,
   {{0x7d037516,0xdd8e00b5,0x5ebe0033,0x7777009f}},	//   _fons, _کوڈ_, ্যদে, _suxx,
   {{0x7d03a0b4,0x2d86a0b5,0x00000000,0x00000000}},	//   _gons, _itoe_, --, --,
   {{0x6b5601ef,0x00000000,0x00000000,0x00000000}},	//   cágo, --, --, --,
   {{0x6d48a0b6,0x7d03a0b7,0xa3c2046c,0x2d860107}},	//   loda, _zons, ्बई_, _ktoe_,
   {{0x7d0359a5,0x2498023a,0xd49b20c3,0xe66740dd}},	// [b710] _yons, _berm_, вре_, ртво,
   {{0x6d48a0b8,0x44f40423,0xa8a7097b,0x6e2d0097}},	//   noda, опус, _трик, _žabk,
   {{0x61e9044d,0x9cd70397,0x98a30029,0x39460037}},	//   _srel, שובה_, cijā_, _íosa_,
   {{0xfaff01d2,0x2ba900b1,0xfba9021a,0x00000000}},	//   një_, _किसा, _किसम, --,
   {{0x672d000e,0x2498035f,0x26cb006d,0x91e500af}},	//   miaj, _ferm_, _ibco_, соле,
   {{0x660d1815,0x61e919be,0x672da0b9,0x1c060324}},	//   myak, _vrel, liaj, शहाल_,
   {{0x6d48a0ba,0x8352006c,0x660da0bb,0x23780024}},	//   doda, _کھلا, lyak, _gurj_,
   {{0x7d03a0bc,0x28a700c0,0xf83802b8,0x28380122}},	//   _sons, कृति, ינות_, ינוך_,
   {{0x660d8ae7,0xa3df111b,0x7d03a0bd,0x3ea6012f}},	//   nyak, तिक_, _pons, _ddot_,
   {{0xeb1000c4,0x6d48011c,0x7bc101ae,0x660d010d}},	//   ास्त_, goda, ttlu, iyak,
   {{0x8c45027a,0x660d0010,0x2d9f1cdd,0x672d08c7}},	//   сене, hyak, ssue_, kiaj,
   {{0xa3e8020c,0xf1bb0084,0xfaff01f4,0x7d030107}},	//   बित_, _ईमान, gjë_, _wons,
   {{0xfce5a0be,0x6d48a0bf,0x7bc1a0c0,0x5d85004f}},	//   _голо, boda, stlu, _التل,
   {{0x7d1aa0c1,0x6d48a0c2,0x2f1800b5,0xdc280088}},	//   chts, coda, _vége_, اسیه_,
   {{0x31d4046c,0x6b730139,0x00000000,0x00000000}},	//   _धन्ध, _păgu, --, --,
   {{0x98a30029,0x6b5d00f7,0x25a0a0c3,0x672da0c4}},	//   rijā_, tége, tsil_, giaj,
   {{0x660da0c5,0x98a30228,0x00000000,0x00000000}},	// [b720] gyak, sijā_, --, --,
   {{0x2ed400dc,0x25a0a0c6,0xaa7b0bca,0x044611ca}},	//   _दस्त, rsil_, ndýn, безн,
   {{0x6b5d0332,0x845a0d8a,0x25a01f8d,0x4adc2eb0}},	//   sége, урат_, ssil_, _बसाव,
   {{0x1db702e4,0x0f110066,0x734900d4,0x6d48a0c7}},	//   _आमंत, ़सोस_, ачів_, zoda,
   {{0xc29701c8,0x24980122,0x6d48a0c8,0x660d04fb}},	//   скіх_, _term_, yoda, cyak,
   {{0x61430f94,0xf506a0c9,0xeaf700b4,0xc05a1645}},	//   печа, _узго, _ुक्त_, лій_,
   {{0x6d480076,0xf4870332,0x26cb00d7,0x08770070}},	//   voda, _چاہی, _ybco_, זעצט_,
   {{0x645ca0ca,0xdcd0035d,0x6d480067,0xf77300a5}},	//   _izri, तज्ञ, woda, הקה_,
   {{0x6d48a0cb,0x6282a0cc,0x6ce62659,0xa0a60bfe}},	//   toda, mcoo, біне, _газд,
   {{0x62820160,0xa3bc00c0,0xd24f0037,0x236601e9}},	//   lcoo, _आमा_, _أنك_, lmoj_,
   {{0x6d48a0cd,0xb4fb00a5,0x00000000,0x00000000}},	//   roda, אפיי, --, --,
   {{0x2ba90d55,0x8fa300d8,0x6f660c90,0x00000000}},	//   _किरा, _хаце, _увез, --,
   {{0x6d48053d,0x63ab004e,0x672da0ce,0x2bda0ec5}},	//   poda, ągni, viaj, _बनवा,
   {{0x672d004e,0x29050093,0xf7730037,0x47d20083}},	//   wiaj, ðla_, كار_, হিনী,
   {{0x672da0cf,0xd7f862a6,0x00000000,0x00000000}},	//   tiaj, бут_, --, --,
   {{0x660da0d0,0xec370122,0x6b5d00b5,0x27ff00f4}},	//   tyak, _לאור_, ségb, ćun_,
   {{0x645c0260,0x672da0d1,0x236600cd,0x00000000}},	// [b730] _azri, riaj, dmoj_, --,
   {{0x394aa0d2,0xe6c0011c,0x660da0d3,0xdb090079}},	//   cobs_, čišć, ryak, irdí,
   {{0x8cca00b4,0x660d411b,0x3e6f01d6,0x5275002d}},	//   त्यो, syak, _kötü_, оулу,
   {{0x32550573,0xd6dba0d4,0xa3aa046c,0x00000000}},	//   овер, _сто_, _गटर_, --,
   {{0x28c00953,0x673d0223,0x2381005f,0x00000000}},	//   श्कि, _ijsj, _dėja_, --,
   {{0x6440004e,0xc24400d8,0x216909a5,0xb0c40067}},	//   _śmie, чнік, шили_, ल्लग,
   {{0xdbf101c0,0x23810409,0x2938016b,0x00000000}},	//   _přít, _fėja_, זאגן_, --,
   {{0x0d85a0d5,0xe8b608b6,0x3818011d,0x00000000}},	//   олин, _अञ्च, מקום_, --,
   {{0xfe6e01cb,0x0cc40099,0x2fde4b84,0x00000000}},	//   نگه_, वभूम, _estg_, --,
   {{0xdd8e0118,0x929d0067,0x00000000,0x00000000}},	//   کوی_, _koło, --, --,
   {{0x28c405e7,0xeb9903fa,0x6f1b00e2,0x26c70009}},	//   _लॉगि, јим_, phuc, đnoj_,
   {{0xd2500332,0x442100a2,0xbfb41015,0x00000000}},	//   _آنے_, izh_, _رحمت, --,
   {{0x4e78028c,0xdca50a7c,0xdddb0009,0x5ca50183}},	//   _احمد_, _дали, lbuž, _дилб,
   {{0xdc69002d,0x2d8d393e,0x00000000,0x00000000}},	//   _калд_, mpee_, --, --,
   {{0x186a10fe,0x869a7ae1,0x37e307e5,0x62820a21}},	//   рави_, итат_, морг, ycoo,
   {{0x629ba0d6,0x81d00033,0x00000000,0x00000000}},	//   _neuo, ষিত_, --, --,
   {{0x7ae4a0d7,0x4421013a,0xd7f80043,0x9b4400b5}},	// [b740] _iait, ezh_, ţă_, _ونڈو,
   {{0x7ae4a0d8,0x2f1889e0,0x69c40024,0x8c3c00a8}},	//   _hait, _méga_, _iqie, bağd,
   {{0x7ae4a0d9,0x6b5d00f7,0x14c6142a,0x7af60c60}},	//   _kait, léga, र्षण, _knyt,
   {{0x7ae401d7,0x74130037,0xfaff0031,0x7af60523}},	//   _jait, بوما, hmën_, _jnyt,
   {{0x7ae4a0da,0x69c60332,0x2366a0db,0x6b5d00f7}},	//   _mait, ntke, rmoj_, néga,
   {{0x7ae49fa9,0x628201b1,0x45d902b5,0xfba90099}},	//   _lait, scoo, _פֿרא, _किंम,
   {{0xea010019,0x6f1900e9,0x6b5da0dc,0x7af60523}},	//   _đậu_, _blwc, héga, _onyt,
   {{0x7ae4a0dd,0x3da601e0,0x00000000,0x00000000}},	//   _nait, ороб, --, --,
   {{0xaf07017e,0x69c40024,0x00000000,0x00000000}},	//   تقيم_, _nqie, --, --,
   {{0x7af6a0de,0x409686ad,0x85f70070,0xad260037}},	//   _anyt, _фрат, קציע_, تربو,
   {{0x7ae40291,0x747b0070,0x98a3010b,0x69c6a0df}},	//   _bait, יניג, niją_, etke,
   {{0x7ae40a24,0xa3d200b4,0x25b20097,0x6f190090}},	//   _cait, _वहन_, kryl_, _glwc,
   {{0x7ae4a0e0,0xfce610da,0x00000000,0x00000000}},	//   _dait, _модо, --, --,
   {{0xa3ab0066,0x00000000,0x00000000,0x00000000}},	//   _खिल_, --, --, --,
   {{0xa2db00a1,0x7ae420ac,0x80bf0026,0x00000000}},	//   _नसल्, _fait, ल्टे, --,
   {{0x7ae4a0e1,0xab2800ed,0xba3b14e1,0x69c40069}},	//   _gait, _моја_, raïb, _fqie,
   {{0x690b0443,0xaded0722,0xdb020187,0xd8cb0012}},	// [b750] _qües, जियन_, nulý, _кынд_,
   {{0x7ae406a2,0x929d004e,0x6abd4793,0x00000000}},	//   _zait, _poło, lgsf, --,
   {{0xb4ab004e,0x7ae402cb,0x4421013a,0x98a300c7}},	//   _गयी_, _yait, uzh_, giją_,
   {{0x442101e9,0x8cca004e,0x6aad0033,0x9294010b}},	//   rzh_, त्तो, ট্রো, дацц,
   {{0xe2c800e0,0x68e50086,0x5eb90083,0x237f011c}},	//   تونو_, _kahd, _আসলে, _čuju_,
   {{0x673b0a78,0x68e5a0e2,0xd6d70033,0x00000000}},	//   čuju, _jahd, হাওয, --,
   {{0xa2951728,0x68e503ad,0x657da0e3,0x98a301c8}},	//   _наві, _mahd, _hush, ciją_,
   {{0x657da0e4,0xdfce00d1,0x68e500c3,0xe2c90118}},	//   _kush, ايي_, _lahd, _دورو_,
   {{0x7ae42011,0xc3320070,0x2d8d034d,0x00000000}},	//   _rait, _נומ_, upee_, --,
   {{0x7ae4a0e5,0x0c25141d,0x80b40274,0x657d25ba}},	//   _sait, змон, _обух, _mush,
   {{0x7ae4a0e6,0x657da0e7,0xfaff01f4,0xe5720070}},	//   _pait, _lush, rmën_, ײַז_,
   {{0x2fc7011e,0x2f180118,0xaa460423,0xfaff0055}},	//   mtng_, _téga_, земл, smën_,
   {{0x7ae49c96,0x68e552e2,0x657d5d6d,0x98a300c7}},	//   _vait, _bahd, _nush, ziją_,
   {{0x5fbf000c,0x290301f4,0x7ae49d67,0x68e50024}},	//   _एमाल, gjja_, _wait, _cahd,
   {{0x7ae4a0e8,0x657d033b,0x69c62820,0x332d0282}},	//   _tait, _aush, stke, _omex_,
   {{0x657da0e9,0x7ae4006b,0x691000be,0x7af60d51}},	//   _bush, _uait, _näev, _unyt,
   {{0xf1da006a,0x7abb00a5,0x2b810023,0x65753a5d}},	// [b760] _मैंन, _הצפו, _hóc_, _bizh,
   {{0x657da0ea,0x6b560132,0x00000000,0x00000000}},	//   _dush, dági, --, --,
   {{0xa87b00a5,0x387a0139,0x2381005f,0x00000000}},	//   _לאיר, _igpr_, _dėjo_, --,
   {{0x657d00da,0x2b81a0eb,0x98a300d8,0xe1fa02ee}},	//   _fush, _móc_, riją_, йге_,
   {{0x657da0ec,0x4ac1057c,0x673b0393,0xaac11cce}},	//   _gush, ष्टव, čujt, ष्टक,
   {{0x6455024e,0xf8c0022e,0x2d8200b8,0x00000000}},	//   _fyzi, श्चय, íkem_, --,
   {{0x044324ee,0xb4b80461,0x2b8100e2,0xbbda01c0}},	//   _зерн, छली_, _nóc_, _बनेक,
   {{0x671c114e,0x543b0122,0x00000000,0x00000000}},	//   नसिक_, _העלא, --, --,
   {{0x4343022c,0x6575012f,0x00000000,0x00000000}},	//   _четв, _yizh, --, --,
   {{0x2b810023,0xaa7b00d5,0x00000000,0x00000000}},	//   _bóc_, rdým, --, --,
   {{0xdbf101c0,0x2b810023,0xdfcf39e6,0x0cc40808}},	//   _přát, _cóc_, _ميل_, वभौम,
   {{0x60c4025c,0x7c4200ea,0x2b8100e2,0xaa5927b9}},	//   đimu, _ātrā, _dóc_, жиму_,
   {{0x6abd21de,0x00000000,0x00000000,0x00000000}},	//   rgsf, --, --, --,
   {{0xb4ab004e,0x61ed01c2,0xb4e6000c,0xdddb002d}},	//   _गये_, çilə, भयो_, scuţ,
   {{0x2b810028,0xd7f8551f,0x31570070,0xa3dc02b4}},	//   _góc_, пут_, פילן_, _तैल_,
   {{0x443f039a,0x7d0aa0ed,0x657d3f5f,0xdc3b00a5}},	//   _ću_, _hofs, _push, _לעור,
   {{0x657d012f,0x68e5a0ee,0x1bea0380,0x6aad04fb}},	// [b770] _qush, _tahd, टिवल_, _idaf,
   {{0x04672632,0xe61f001e,0x798da0ef,0x657d0031}},	//   птем, _ffôn_, _itaw, _vush,
   {{0x69100ccf,0x657d052e,0xedd901c0,0xdb0202d7}},	//   _päev, _wush, _भन्छ, culó,
   {{0x657da0f0,0x6b5603e6,0x63a50ca0,0x636300be}},	//   _tush, tági, rshn, kõne,
   {{0x798d0024,0x00000000,0x00000000,0x00000000}},	//   _jtaw, --, --, --,
   {{0xdb1b0086,0x798d002f,0xe4e401e0,0x7d0a003c}},	//   lttä, _mtaw, _пісн, _nofs,
   {{0xa066061c,0x205402fb,0xd00602fb,0x00000000}},	//   маша_, нтър, деще_, --,
   {{0xdb1b00c3,0x6adc0067,0x6aad00f8,0x798d6251}},	//   nttä, _बसेर, _ndaf, _otaw,
   {{0x798d1020,0x2b81a0f1,0x2d9920d0,0x6289034d}},	//   _ntaw, _sóc_, èse_, _ifeo,
   {{0xee360c91,0x691000ab,0x6aad04fb,0x5ba92581}},	//   ьны_, _jäet, _adaf, оком_,
   {{0x3c6502ce,0x798d5961,0xcb6a0432,0xd01b0328}},	//   ьког, _ataw, жане_, _уфа_,
   {{0x2b810023,0x6b5d00fd,0x00000000,0x00000000}},	//   _vóc_, ségn, --, --,
   {{0x80c40af9,0xc6120033,0x6aad00e5,0xddcb0067}},	//   _रामे, _সেনা_, _ddaf, _wygł,
   {{0x2b8101a5,0x3ebf0443,0xeb998662,0x6910023f}},	//   _tóc_, lgut_, _дик_, _näet,
   {{0x3941008c,0x798d096c,0x00000000,0x00000000}},	//   _djhs_, _etaw, --, --,
   {{0x3ebfa0f2,0x9aa613cf,0x00000000,0x00000000}},	//   ngut_, _غمخو, --, --,
   {{0xf50a0d8d,0x8cca0096,0x8c3c0225,0xe5a32f44}},	// [b780] онал_, त्वो, mağa, кити,
   {{0xb4b8006a,0x3ce7a0f3,0x00000000,0x00000000}},	//   छले_, _janv_, --, --,
   {{0x6f0b0223,0x186a1783,0x00000000,0x00000000}},	//   _oogc, _фани_, --, --,
   {{0x0cda035d,0x9586578a,0x00000000,0x00000000}},	//   _भस्म, _олме, --, --,
   {{0xb5fb0187,0xc44800e0,0x316a32b3,0x00000000}},	//   _vzác, _کیان_, ошко_, --,
   {{0x26c02796,0x2918a0f4,0x00000000,0x00000000}},	//   lgio_, nkra_, --, --,
   {{0x2bdd3421,0x6f0b008c,0x7d0a06c5,0x00000000}},	//   _फैला, _bogc, _rofs, --,
   {{0x6910007c,0x26c0a0f5,0x7d0a00d7,0xef9100d1}},	//   _käes, ngio_, _sofs, ایند,
   {{0x2918a0f6,0x8c3c00a8,0x6b8d0124,0x00000000}},	//   kkra_, dağa, _čaga, --,
   {{0x6b5d1010,0x7d0a0031,0x5edb0033,0x9ffa0037}},	//   tégo, _qofs, ভাগে, _وراء_,
   {{0xdb1b0d36,0x34b70122,0xccf801c0,0x798d004e}},	//   yttä, ופים_, dmět_, _staw,
   {{0x7bc803c4,0xef690037,0x00000000,0x00000000}},	//   rtdu, _فإنه_, --, --,
   {{0xff2700bf,0x588706d8,0xa3e50066,0xdb1b0031}},	//   _تبلی, дыба, _बैन_, lutë,
   {{0xfc2f0148,0x7e6200cd,0x3ea4a0f7,0x00000000}},	//   احی_, _izop, lamt_, --,
   {{0xba3ba0f8,0x36d51583,0x9be601e0,0xdb1b0055}},	//   caïn, новр, _цілк, nutë,
   {{0x26c00021,0x8cca97cb,0x6d5aa0f9,0x69c800af}},	//   ggio_, त्रो, llta, ăder,
   {{0x798d5507,0x6d5aa0fa,0xc6120033,0x1634188d}},	// [b790] _utaw, olta, _সেবা_, ветя,
   {{0x2918013c,0x6d5a0103,0xb8f40033,0x7e620207}},	//   ckra_, nlta, _সো_, _mzop,
   {{0xa7750674,0xe859027a,0x6d5a147d,0x691000be}},	//   _плоч, _ханш_, ilta, _väet,
   {{0xfe0e3933,0xae0e0722,0x65952a7c,0x6d5a6474}},	//   िहास_, िहान_, _паму, hlta,
   {{0xf1a709ce,0xa15912bd,0xed5900d5,0x00000000}},	//   френ, паду_, luže_, --,
   {{0x25a901d6,0xa2db01c0,0x2f11008d,0xdb1b0055}},	//   msal_, _नसक्, _lágt_, futë,
   {{0x25a9067f,0x691000b9,0x00000000,0x00000000}},	//   lsal_, _käer, --, --,
   {{0x6d5aa0fb,0x261600a1,0xf3640043,0x00000000}},	//   elta, पैकी_, _атун, --,
   {{0x25a9a0fc,0x3ebfa0fd,0x98a300d8,0xee3938a2}},	//   nsal_, rgut_, siję_, яни_,
   {{0xb69b0260,0x25a90f00,0x00000000,0x00000000}},	//   _goâv, isal_, --, --,
   {{0xc4d202b5,0x25a90644,0x80c40067,0xed5900f4}},	//   נגט_, hsal_, _राते, juže_,
   {{0x6d5a004a,0x25a9a0fe,0x441a32e3,0xed5900cd}},	//   alta, ksal_, פורס, duže_,
   {{0x88e40033,0x776d02d7,0x8c3c00a3,0x00000000}},	//   মাসক, dmax, rağa, --,
   {{0x291e5777,0x8d6509c2,0x8c450714,0x6b5605f5}},	//   óta_, _явле, _пеле, vágu,
   {{0x9d1a02b5,0xc0520070,0x3fbd0033,0x46f63b4d}},	//   _מוסט, ָזן_, _আনুষ, нчат,
   {{0x2918a0ff,0x66e393f3,0x70dc0d1f,0xeab21902}},	//   skra_, лоса, _यस्ल, _صعب_,
   {{0xea0100e8,0x26c04e3d,0x0566195a,0x991600d8}},	// [b7a0] _đầu_, rgio_, еван, _зьні,
   {{0x7d7a0070,0x2ca5a100,0x80c40808,0x69100421}},	//   פרעג, nald_, _राधे, _väes,
   {{0x389b00c2,0x6b8b0395,0x00000000,0x00000000}},	//   _מיינ, _îngă, --, --,
   {{0x2ca5988b,0xfe6718dd,0x96ba37a4,0xb80800fd}},	//   hald_, _مد_, _عاجز_, _ٹکڑے_,
   {{0xa3e50084,0x6d5a01ff,0x6b5600fd,0x3ce00d41}},	//   _बैठ_, ylta, lágs, _कसले_,
   {{0x6724128f,0x2ca5008d,0xdb1b01f4,0x1c0f046c}},	//   lhij, jald_, tutë, ाहाल_,
   {{0xe29a368f,0x4ac600a1,0x7e6207cf,0x201a07c0}},	//   _нав_, _वाढव, _szop, ápi_,
   {{0x91e654d0,0x672400f4,0x00000000,0x00000000}},	//   _побе, nhij, --, --,
   {{0xa3e80299,0x3ea4a101,0x2ca531cb,0xb1461306}},	//   बिक_, ramt_, fald_, _знал,
   {{0x3ea40eaa,0x61e22a5d,0xeb190067,0x00000000}},	//   samt_, mwol, दस्त_, --,
   {{0x9f4c00ac,0xe571016b,0x00000000,0x00000000}},	//   _hrdí_, יַט_, --, --,
   {{0xa4fd0567,0x25a9a102,0x6d43008c,0xd00f00d1}},	//   _उच्च_, ysal_, _ejna, _دلم_,
   {{0x2ca5033b,0x80e30033,0x298b411e,0x61e272d0}},	//   bald_, পার্, ясно_, nwol,
   {{0x63be0097,0xed590b1a,0x3986099e,0x00000000}},	//   kupn, tuže_, _dôs_, --,
   {{0x67d40ce3,0x984802fb,0x00000000,0x00000000}},	//   лору, еята_, --, --,
   {{0x63be005d,0x61e229c5,0x25a9a103,0xed590cc2}},	//   dupn, kwol, tsal_, ruže_,
   {{0xf6532402,0x00000000,0x00000000,0x00000000}},	// [b7b0] ائز_, --, --, --,
   {{0x2edd0f19,0x7d1a00ab,0xf9900c74,0x2f1100ac}},	//   _मस्त, nkts, _ابي_, _jágr_,
   {{0x25a9a104,0x00000000,0x00000000,0x00000000}},	//   ssal_, --, --, --,
   {{0x67240a75,0x25a901c0,0x62750037,0x61e20345}},	//   chij, psal_, نهائ, fwol,
   {{0xdd860ef2,0x5f0422a3,0xaad309a8,0x666401d3}},	//   _خو_, वान्_, ध्यक, _бърз,
   {{0x78a73257,0xccf80355,0x7bd808f7,0x00000000}},	//   najv, změr_, _opvu, --,
   {{0x63be00d7,0x22950037,0xf43500af,0xa4d401e0}},	//   cupn, _للأس, _ревэ, _щорі,
   {{0x25660248,0x2ca5a105,0x63b800a0,0x2d8f0176}},	//   rôle_, wald_, ávne, _ptge_,
   {{0x628401f2,0x2ca50523,0x00000000,0x00000000}},	//   žioc, tald_, --, --,
   {{0x61e4027d,0x2f112278,0x256600f6,0x7d080345}},	//   çile, _págs_, pôle_, gjds,
   {{0x8c451edd,0x00000000,0x00000000,0x00000000}},	//   тене, --, --, --,
   {{0xde950274,0x39860183,0x2b1602fb,0x00000000}},	//   _радњ, _pôs_, тьор, --,
   {{0xdd9400d8,0xb5fb006c,0x6f090124,0xb60300d5}},	//   _бачы, _szán, mjec, nkáč,
   {{0x6f09a106,0x9e6400d4,0x6aa672f4,0x00000000}},	//   ljec, _свід, sakf, --,
   {{0xea010028,0x98a312da,0x61e2004e,0xa2d2166b}},	//   _đấu_, рисе, zwol, ण्ड्,
   {{0x660406a2,0x6b837e8a,0x2b030d1f,0x00000000}},	//   txik, _iung, षाणु_, --,
   {{0x6724a107,0x06830c06,0x6d41a108,0x6b83a109}},	// [b7c0] rhij, ргун, onla, _hung,
   {{0x6b83a10a,0x67240232,0x63be053d,0xe6c9003a}},	//   _kung, shij, tupn, čašć,
   {{0x6b83a10b,0x6d41a10c,0x68fe027a,0x7984a10d}},	//   _jung, inla, _inpd, _huiw,
   {{0x6b83a10e,0x644142c0,0x61e26251,0x9c7c0a8e}},	//   _mung, _žlic, twol, meče,
   {{0x9c7c05d3,0x2eed00e9,0x6b83062c,0x7c280124}},	//   leče, ddef_, _lung, zzdr,
   {{0x61e2001e,0x6aa456e3,0x6b830107,0xdb1b02d7}},	//   rwol, _leif, _oung, ruté,
   {{0x03a31f9b,0xb4de0299,0x6b83a10f,0x8f343425}},	//   _висо, ढ़ी_, _nung, лекц,
   {{0xdb1b00f7,0x3ea2003e,0x04431457,0xd46700af}},	//   puté, úkt_, _тесн, _рисе_,
   {{0x657c02c4,0x91e32349,0x3eb90037,0x5d540be8}},	//   _kirh, _коте, ósta_, лкит,
   {{0x645c04da,0x8c3c2f80,0x00000000,0x00000000}},	//   _kyri, bağl, --, --,
   {{0x9c7c10e5,0x6f09a110,0x6b5da111,0x6b83a112}},	//   ječe, bjec, légi, _cung,
   {{0x9c7ca113,0xddcf011c,0x79840118,0x7d1a0159}},	//   deče, žešk, _buiw, skts,
   {{0x645c0122,0x6aa4a114,0xb0c90fbf,0x20c90066}},	//   _lyri, _deif, _रामग, _रामध,
   {{0x6b83a115,0x7984053e,0x00000000,0x00000000}},	//   _fung, _duiw, --, --,
   {{0xf7730c36,0x28d209b1,0x6b83a116,0x6b560f84}},	//   لار_, द्धि, _gung, rágr,
   {{0x6aa400e5,0x99e401ba,0x00000000,0x00000000}},	//   _geif, žňav, --, --,
   {{0x645c0448,0x657c067f,0x6b83a117,0x1bea258f}},	// [b7d0] _ayri, _birh, _zung, टिकल_,
   {{0x7aeda118,0x6b833633,0x657c00d5,0xe5c400ed}},	//   _haat, _yung, _cirh, јсто,
   {{0x7aeda119,0x5ea80083,0x6b83a11a,0x389a00a5}},	//   _kaat, _গানে, _xung, _איתנ,
   {{0x645c008c,0x7aed57fe,0x00000000,0x00000000}},	//   _dyri, _jaat, --, --,
   {{0x7aeda11b,0x2249027d,0x6f095186,0x6d5808b7}},	//   _maat, çak_, vjec, _okva,
   {{0x645c2ea0,0x1bf40953,0x7aeda11c,0xa069619e}},	//   _fyri, ेमाल_, _laat, нала_,
   {{0x6f09029d,0x272700cc,0x69cf01ed,0xb60300ac}},	//   tjec, _cõng_, htce, skáč,
   {{0x6b83a11d,0x6e29a11e,0x7aeda11f,0x765d03ad}},	//   _rung, tzeb, _naat, _kysy,
   {{0x6aa4a120,0xdce302c4,0x6b831425,0x2eed02d7}},	//   _reif, _sinđ, _sung, rdef_,
   {{0x6b8300bf,0x61e9a121,0x6f09025c,0x6e292642}},	//   _pung, _isel, sjec, rzeb,
   {{0xb5fb0332,0x7aed01a8,0x7984053e,0xfaa66b7f}},	//   _szál, _baat, _suiw, лано,
   {{0x7aed91ac,0x6d585c4d,0x69cf0b41,0x6b830fb2}},	//   _caat, _ekva, ftce, _vung,
   {{0x3f85005d,0x9c7c2190,0x6b83a122,0x7aed4a6d}},	//   _hulu_, veče, _wung, _daat,
   {{0x6b83a123,0x2f18006c,0x6aa40024,0x3f85a124}},	//   _tung, _régi_, _weif, _kulu_,
   {{0x3f85a125,0xc81502ce,0x7aed03d5,0x6b83002f}},	//   _julu_, аєть, _faat, _uung,
   {{0x7bc1a126,0x7aeda127,0x777d002a,0xd7f70023}},	//   mulu, _gaat, _cisx, ững_,
   {{0x765d02c7,0x7bc1a128,0x645c84ed,0x9c7c02f6}},	// [b7e0] _cysy, lulu, _syri, reče,
   {{0xb4de1163,0x645ca129,0x7aed2fb5,0x9c7c01a0}},	//   ढ़े_, _pyri, _zaat, seče,
   {{0x7bc1a12a,0x9c7ca12b,0x61e94f63,0x657c0086}},	//   nulu, peče, _asel, _virh,
   {{0x6b5da12c,0x645ca12d,0x636300ab,0x7bc100af}},	//   tégi, _vyri, sõnn, iulu,
   {{0x7bc11292,0x765d001e,0x1a9b0070,0xc6120033}},	//   hulu, _gysy, גינע, _সেরা_,
   {{0xe505021a,0x7bc1a12e,0x3f85005d,0x645c00d8}},	//   राणि_, kulu, _bulu_, _tyri,
   {{0x7bc1a12f,0xd54722cc,0x61e9a130,0x00000000}},	//   julu, _спре_, _esel, --,
   {{0x7bc1a131,0x3f85124f,0x35a90066,0x6d58a132}},	//   dulu, _dulu_, _चौड़, _skva,
   {{0xd3351a0e,0x7aed87e1,0xf26a00af,0xb637016b}},	//   _тэры, _raat, _чиал_, ָריס_,
   {{0x7aeda133,0x7bc1a134,0x2dd70037,0x1dd70037}},	//   _saat, fulu, ابية_, ابيع_,
   {{0x7bc1a135,0xdeef00af,0x3f85a136,0x7aed84dc}},	//   gulu, _лы_, _gulu_, _paat,
   {{0xb5fb00f5,0x317e0291,0x6da600c9,0xed590009}},	//   _szám, _hitz_, _бида, ruža_,
   {{0x7aed136d,0x00000000,0x00000000,0x00000000}},	//   _vaat, --, --, --,
   {{0x7aed4179,0x272700ab,0x6d58008b,0xdcf80107}},	//   _waat, _mõne_, _ukva, _kivč,
   {{0x7aed1c85,0x7bc13d08,0x69cfa137,0x38c900e0}},	//   _taat, culu, stce, _یادی_,
   {{0xcb6900d1,0x765d0086,0x317e01ed,0xe7840369}},	//   _جمعه_, _pysy, _litz_, суро,
   {{0x4ca70083,0xdb1b0187,0xb8db0033,0x3ea60051}},	// [b7f0] _খাতু, nutí, _ইউ_, _meot_,
   {{0x395a022e,0x765d0097,0x00000000,0x00000000}},	//   _gkps_, _vysy, --, --,
   {{0x61e90069,0x765d004e,0xb97a00a5,0x36d5034b}},	//   _ssel, _wysy, _שנתי, _конр,
   {{0x92eb004f,0x14c700a1,0x61e901ef,0x317e01ed}},	//   عراق_, _लावण, _psel, _aitz_,
   {{0x28d20517,0xf8d20517,0x7bc1a138,0x3f85a139}},	//   द्वि, द्वय, zulu, _sulu_,
   {{0xf77f0723,0x1fb50ca6,0x7bc1a13a,0x61450274}},	//   _hiç_, асир, yulu, јека,
   {{0x6b5d00f7,0x7bc100af,0x2af507b5,0x1aec0033}},	//   légu, xulu, इयाँ_, টাতে_,
   {{0xd3430416,0x7bc156c1,0x61e9018d,0xe0d300b5}},	//   _افری, vulu, _tsel, _گزر_,
   {{0xdb0806fe,0xfaff0031,0x80cd0808,0xb5fb00b5}},	//   álík, hmës_, _सापे, _száj,
   {{0x7bc1a13b,0x3f85a13c,0x6ffc0395,0x00000000}},	//   tulu, _tulu_, _băcă, --,
   {{0x30840514,0x237f0107,0x236d0221,0x2a691e77}},	//   _المف, _kiuj_, _khej_, _azab_,
   {{0x7bc1a13d,0x29010fc2,0xb5fb031d,0x8e750036}},	//   rulu, _anha_, _vzáj, _кулч,
   {{0x7bc1a13e,0xfe9a0052,0x2913a13f,0x6da5141d}},	//   sulu, _סיסמ, _boxa_, _тила,
   {{0x827600c2,0xa96a027a,0x7c87a140,0x26cb3c9a}},	//   יערע_, тига_, _суде, _acco_,
   {{0xa3e5238a,0x29130298,0xbd680166,0x225fa141}},	//   _बैल_, _doxa_, _срце_, _lyuk_,
   {{0xd91004e8,0x6fd80fd1,0x273f0086,0x00000000}},	//   _کیس_, _महसू, vänä_, --,

   {{0x2913002a,0x2ca7a142,0x9c7c0124,0x225f0118}},	// [b800] _foxa_, _kend_, meča, _nyuk_,
   {{0x33f68490,0x26cb01d3,0x2ca7a143,0x9c7c022f}},	//   ичес, _ecco_, _jend_, leča,
   {{0x2ca700da,0x3958a144,0xe1f9004b,0x394d01ef}},	//   _mend_, mors_, _arų_, éese_,
   {{0x28d20f0d,0x317e033b,0x225f00e0,0x39584790}},	//   द्रि, _sitz_, _byuk_, lors_,
   {{0x317e0065,0x273f0421,0x00000000,0x00000000}},	//   _pitz_, sänä_, --, --,
   {{0x3958a145,0xc1560202,0xc05a00d4,0xd12f0754}},	//   nors_, шњењ, кій_, ومن_,
   {{0xf8b30122,0x443ea146,0x3ea60069,0xaac6021a}},	//   קשה_, _ät_, _peot_, _वांक,
   {{0x9c7c0280,0x395800f7,0xdb0219ee,0x317e02b1}},	//   ječa, hors_, nslä, _witz_,
   {{0x39587df2,0x60ea075c,0x2a60006d,0xcd061ade}},	//   kors_, _имам_, _nyib_, ачни,
   {{0x3958a147,0x6443004e,0x20560217,0x7fd601e0}},	//   jors_, źnie, _ктер, _віді,
   {{0x39580955,0x29130952,0x2ca72e0c,0x2a60013b}},	//   dors_, _roxa_, _dend_, _ayib_,
   {{0xee3a0009,0x2ca719c1,0x6ffc0395,0x00000000}},	//   _ине_, _eend_, _văcă, --,
   {{0x8d94004f,0x3958a148,0x27fa011e,0x6ab6001e}},	//   _التش, fors_, _arpn_, _ddyf,
   {{0xf77f00da,0x6fca018d,0x395800ec,0x67260312}},	//   _siç_, संपू, gors_, _alkj,
   {{0xe787a149,0x6f0229ec,0x2b49021d,0x987500ee}},	//   руго, _knoc, _tjac_, _týči_,
   {{0x6c7b1899,0xfaff01f4,0x3704a14a,0x2cac4b22}},	//   _באופ, rmës_, очув, ladd_,
   {{0x2913002a,0x3958a14b,0xfaff0055,0x00000000}},	// [b810] _toxa_, bors_, smës_, --,
   {{0x29014a07,0x39583e11,0x6b5d3645,0x67260a8a}},	//   _unha_, cors_, régu, _elkj,
   {{0x236d006d,0x656e009e,0x00000000,0x00000000}},	//   _phej_, _dhbh, --, --,
   {{0x1fcc0083,0x2b59a14c,0xe505046c,0x256f00ab}},	//   লবাস, nosc_, राहि_, külg_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f02a14d,0x00000000,0x00000000,0x00000000}},	//   _anoc, --, --, --,
   {{0xd37b00af,0x2ca7a14e,0x63be00cd,0x1da9073f}},	//   _ача_, _rend_, crpn, चीनत,
   {{0x85050299,0x2ca70122,0x2489010b,0xe8c40355}},	//   रावट_, _send_, šimą_, _वञ्च,
   {{0x9c7ca14f,0xa1940fa4,0x6f023e90,0x00000000}},	//   veča, _матч, _dnoc, --,
   {{0x0d823665,0x61fba150,0x00000000,0x00000000}},	//   яльн, _irul, --, --,
   {{0x3958a151,0x2ca7a152,0x7f85004f,0x9c7c008b}},	//   vors_, _vend_, _الصن, teča,
   {{0x6f02a153,0x61fba154,0x3958053e,0x2ca703bc}},	//   _gnoc, _krul, wors_, _wend_,
   {{0x9c7c1269,0x3958a155,0xc3320d85,0x3ead03db}},	//   reča, tors_, לוט_, maet_,
   {{0x9c7ca156,0x38610282,0x00000000,0x00000000}},	//   seča, _byhr_, --, --,
   {{0x9c7ca157,0x7d03a158,0x7d1c4641,0x2b596105}},	//   lečn, _inns, örse, bosc_,
   {{0x3958a159,0xdc390484,0x8699a15a,0xa6863bd5}},	//   sors_, _aħħa, итут_, слад,
   {{0x9c7c0076,0x7ae601d6,0xa3ca00a1,0x39583b65}},	// [b820] nečn, mekt, ळून_, pors_,
   {{0x69c6a15b,0x63b801ba,0x63be012e,0xadea007c}},	//   muke, ávno, trpn, _जईसन_,
   {{0xe73a1052,0x69c6276c,0x941800a8,0xdb1b00b5}},	//   _бен_, luke, _yerə_, lutá,
   {{0x7ae6a15c,0x61fba15d,0x6b5d4135,0xfd4d055c}},	//   nekt, _brul, légr, _choẹ,
   {{0x9c7c1aa8,0x7ae60291,0x69c6a15e,0x023a0841}},	//   ječn, iekt, nuke, دثات_,
   {{0x28db0433,0x9f981306,0x7ae60a1e,0x9c7c031d}},	//   म्पि, авку_, hekt, dečn,
   {{0x741600b5,0xdfd00037,0x64a30368,0x61fb0103}},	//   _اوزا, ذية_, _хаса, _erul,
   {{0x69c6a15f,0x7d03a160,0x61fb286f,0x3ead012f}},	//   kuke, _anns, _frul, gaet_,
   {{0xa63b02b5,0x42263e86,0x7ae6a161,0x00000000}},	//   ָגיר, _удав, dekt, --,
   {{0x69c64c75,0xdce3010b,0x00000000,0x00000000}},	//   duke, _minė, --, --,
   {{0x7ae603c1,0x628500b8,0x2cac00e9,0x3ead0159}},	//   fekt, ěhov, radd_, baet_,
   {{0x8e860037,0x3c0e00a8,0xdcf800ea,0x6f02099e}},	//   _الإه, nəvi_, _divā, _unoc,
   {{0xc3330052,0x941800a8,0x69c6a162,0x00000000}},	//   פוש_, _verə_, guke, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d3b01f3,0xd6db7c71,0x776401ef,0x7ae6a163}},	//   _תגוב, лта_, flix, bekt,
   {{0xf77014ac,0x7ae601d6,0xdb1b03e6,0x26c90c99}},	//   فاق_, cekt, butá, ugao_,
   {{0xe667233a,0x6d48a164,0xdb24006c,0xb5053e9e}},	// [b830] ство, onda, _írás, रालय_,
   {{0x6d48a165,0x6aaf0079,0x00000000,0x00000000}},	//   nnda, lacf, --, --,
   {{0x6d48a166,0x1aec0033,0xadea00ab,0x67230160}},	//   inda, টারে_, _जैसन_, _înjo,
   {{0x61fba167,0x6d5aa168,0x6d487b41,0x321d0067}},	//   _prul, hota, hnda, tywy_,
   {{0x21791ad4,0x6d5aa169,0x80c421a8,0x7e62a16a}},	//   айды_, kota, _राखे, _nyop,
   {{0x68e70254,0x6594082e,0x9c7c552b,0xdceb009f}},	//   nejd, _хару, večn, _itgħ,
   {{0x7ae6a16b,0xdfce0037,0x6d5a4931,0x3d0c004e}},	//   yekt, نيو_, dota, ़ाने_,
   {{0x61fb230a,0xef190faf,0x6d48a16c,0x672da16d}},	//   _trul, рми_, enda, nhaj,
   {{0x6b8a02bf,0x6d48008a,0x3ead0249,0x61fb007b}},	//   _aufg, fnda, raet_, _urul,
   {{0x6d5aa16e,0x9c7c3e39,0x3ead009e,0x6d480d3e}},	//   gota, rečn, saet_, gnda,
   {{0x5fdd0567,0xdc69034b,0x9c7c02dd,0x6371022a}},	//   _महिल, ранд_, sečn, gång,
   {{0x6d48a16f,0x2fc700bf,0xdb1ba170,0x69c6577e}},	//   anda, mung_, tutá, tuke,
   {{0x2fc7a171,0x6d5aa172,0x6b5d02e1,0x1d0900c9}},	//   lung_, bota, tégr, _вели_,
   {{0x69c6a173,0x7f5b0132,0xdb0201ef,0x5fdd0e9b}},	//   ruke, louq, nslú, _महाल,
   {{0x3cee02cb,0x272700ab,0x69c6a174,0xddc20506}},	//   _असते_, _sõna_, suke, _izoš,
   {{0x7f494b2f,0x28db01c0,0x291e00ab,0xaa463df1}},	//   nneq, म्बि, ötab_, _мейл,
   {{0xf09f00e8,0x68e74d3e,0x2fc7a175,0xb4aaa176}},	// [b840] _đàn_, bejd, hung_, иказ_,
   {{0x2fc734c2,0x61e40463,0xf507291e,0x6b8400ab}},	//   kung_, çilm, онул_, _hiig,
   {{0x13ea002d,0x2fc7a177,0x2bb50029,0x753e01a3}},	//   рмей_, jung_, nāc_, ripz,
   {{0x2fc7a178,0x672da179,0xe1fa2217,0x6d5aa17a}},	//   dung_, chaj, иге_, zota,
   {{0x6d4800fb,0x6d5aa17b,0xa3e60066,0x00000000}},	//   ynda, yota, _भनक_, --,
   {{0x6b841eca,0xf8aa0084,0x2fc701ae,0x6d5a3d04}},	//   _liig, करिय, fung_, xota,
   {{0x2fc7a17c,0x6d481f8b,0x6d5aa17d,0x4fc602a4}},	//   gung_, vnda, vota, іска,
   {{0x6724a17e,0x68e70035,0xdefa00c7,0x6d5aa17f}},	//   nkij, zejd, рык_, wota,
   {{0x6d5aa180,0xf7730122,0x9c7c33a5,0x1ee800d1}},	//   tota, וקה_, tečo, لوژی_,
   {{0x20ca01cb,0x6d48043d,0x236601f4,0x00000000}},	//   _خبري_, unda, lloj_, --,
   {{0x6d5aa181,0x6d48a182,0xe61f01a5,0x6724a183}},	//   rota, rnda, _ngôn_, kkij,
   {{0x6d5aa184,0x78a201f2,0xf1b10035,0x2bdb111b}},	//   sota, _đova, ुंचन, _बहरा,
   {{0x6d5aa185,0x3f8c0069,0x9f4c004f,0x6b840312}},	//   pota, _hudu_, _ordú_, _diig,
   {{0x3f8c01ca,0x00000000,0x00000000,0x00000000}},	//   _kudu_, --, --, --,
   {{0x23661abc,0x2905027b,0x68e700fe,0xfe6d006c}},	//   kloj_, ıla_, rejd, _لگی_,
   {{0x9f4c0037,0x7d18a186,0xa3e50461,0x3f8c005f}},	//   _ardú_, _hovs, _बैग_, _mudu_,
   {{0x2fc701ae,0x7bc800ae,0x7d18455c,0x8627010b}},	// [b850] zung_, ludu, _kovs, цьве,
   {{0x672da187,0xf09f0028,0x85052188,0xd49b02ee}},	//   shaj, _đào_, राइट_, рра_,
   {{0x80c406bc,0x3eb901c8,0x3f8c00ac,0x7d181505}},	//   _राजे, ųsti_, _nudu_, _movs,
   {{0x80cd0b39,0x7d182d4c,0x67244205,0x23660207}},	//   _साहे, _lovs, ckij, gloj_,
   {{0x2fc7a188,0xa2cc0f17,0x7bc80054,0x9f6500a2}},	//   wung_, _हार्, hudu, _étés_,
   {{0x2fc79841,0x3f8c2fd2,0x798da189,0x7bc8a18a}},	//   tung_, _budu_, _muaw, kudu,
   {{0xe8d90019,0x2fc701ae,0x7bc8028b,0x6371013c}},	//   _quỹ_, uung_, judu, tånd,
   {{0x2fc7a18b,0x7bc80f1a,0xc61200c8,0x3f8c00bf}},	//   rung_, dudu, _সেটা_, _dudu_,
   {{0x7f491505,0x6b840006,0x2fc75112,0x2d9900da}},	//   rneq, _riig, sung_, ëse_,
   {{0x2fc706b3,0xee361482,0x6b8414e7,0x6aad099e}},	//   pung_, яны_, _siig, _aeaf,
   {{0x798d002f,0x7bc85b63,0x3f8c01ed,0x3c65311e}},	//   _auaw, gudu, _gudu_, яког,
   {{0x09e62dc5,0x1bec0f3d,0x6aad0139,0x612f1b99}},	//   помн, _जनरल_, _ceaf, _bølg,
   {{0x6ed0045c,0xb0d200b1,0x7ed403c5,0x6b8400be}},	//   _धातु, _सामग, _آزما, _viig,
   {{0xfe7000bf,0x6f192ea2,0x14c700a1,0x673d03d0}},	//   _شدن_, _howc, _लागण, _amsj,
   {{0xab9915f4,0x6724a18c,0x7bc8033e,0x6b8400be}},	//   _اختر_, tkij, cudu, _tiig,
   {{0x612f0568,0x753c044d,0xfaff01f4,0xed5900cd}},	//   _følg, _smrz, llën_, duži_,
   {{0x5bdb00b4,0x6724a18d,0x9c7c012e,0xdb020249}},	// [b860] _बहुव, rkij, ječj, dslø,
   {{0x6d41319a,0x9a3b00a5,0x79850371,0x7af60a21}},	//   nila, _לתפק, _gihw, _hayt,
   {{0x7af6a18e,0x3d0c0084,0x64a3167d,0x612f0a8a}},	//   _kayt, ़ाते_, хаха, _møld,
   {{0x6d418fc8,0xeb9602b5,0x6f190036,0x7af6055c}},	//   hila, לדער_, _nowc, _jayt,
   {{0x6d41a18f,0x3f8ca190,0x7af600cc,0x7bc8a191}},	//   kila, _sudu_, _mayt, zudu,
   {{0x25a0a192,0x291a0086,0x3f8c028b,0x7af6a193}},	//   mpil_, _jopa_, _pudu_, _layt,
   {{0xc4480ef5,0x23660506,0x80cd1d25,0x7d18788e}},	//   _بیان_, ploj_, _सारे, _rovs,
   {{0x57fb0122,0x7bc8a194,0x6d411472,0x291a34eb}},	//   מלצו, vudu, eila, _lopa_,
   {{0x7d181f6f,0x3f8c05ca,0x6f1996c1,0x4ac60099}},	//   _povs, _wudu_, _dowc, _वाजव,
   {{0x7bc81034,0x00000000,0x00000000,0x00000000}},	//   tudu, --, --, --,
   {{0xd12f1b15,0x1e864a4e,0x6db506d0,0x9dd3006c}},	//   _حمل_, _елем, _aşağ, وزیش,
   {{0x9c7c0e06,0x212c009e,0x25a00051,0x00000000}},	//   lečk, _hldh_, kpil_, --,
   {{0xc3330122,0xc88200a8,0x7bc8a195,0xbea30200}},	//   תור_, əşə_, sudu, _чачк,
   {{0x291a478a,0x9c7c0d5c,0x9f450036,0x256f00ab}},	//   _copa_, nečk, _urlò_, küla_,
   {{0xd1480028,0xf99f02e9,0xaac60099,0x36d5a04e}},	//   yễn_, spè_, _वाचक, мовр,
   {{0xf09f01a5,0x798d0103,0x8f9b0319,0xba3b000d}},	//   _đàm_, _tuaw, מילי, saïq,
   {{0x2bc40963,0x9f5e0031,0xccfd0160,0x291aa196}},	// [b870] लंका, _artë_, _față_, _fopa_,
   {{0x9c7ca197,0x612f01b4,0xed5900f4,0x62890284}},	//   ječk, _køle, tuži_, _sgeo,
   {{0x4427a198,0x25a00008,0x9c7c0184,0x00000000}},	//   án_, apil_, dečk, --,
   {{0x39430080,0x99990035,0x673d0093,0xf8ae00b5}},	//   lijs_, mysł_, _umsj, _مکہ_,
   {{0x6d41a199,0x6f190090,0xdb020b3e,0xd49b00ed}},	//   yila, _rowc, rslø, _грб_,
   {{0x6d41a19a,0x39430029,0x9c7c1b88,0x3cf80067}},	//   xila, nijs_, rečj, ्ञों_,
   {{0x213e01f4,0x9c7c39a2,0x6491082d,0x612f008c}},	//   _dmth_, sečj, ržič, _nøle,
   {{0x6fcf0099,0x3f8600ee,0x6d41a19b,0x212c0282}},	//   संबं, _ciou_, wila, _eldh_,
   {{0x6d419c98,0x3f860107,0xee3902ee,0x00000000}},	//   tila, _diou_, юни_, --,
   {{0x7af601c2,0xfe4201e0,0x00000000,0x00000000}},	//   _sayt, тньо, --, --,
   {{0x291a0083,0x7af60095,0xd01100b5,0x2bc40084}},	//   _ropa_, _payt, _جلا_, लंगा,
   {{0xf1d100dc,0x7af600a8,0x2d8b0caa,0x41d1012f}},	//   _समान, _qayt, íces_, _समास,
   {{0x6d41a19c,0x68f7013b,0x291a811b,0xdb1b03ad}},	//   pila, _baxd, _popa_, yttö,
   {{0x61e40716,0x612f10db,0x6d4100a8,0xdb0b017b}},	//   çili, _føle, qila, _avfä,
   {{0xb8f6a19d,0x7af6314a,0x2d8f00a5,0x2574033b}},	//   _हा_, _tayt, _huge_, näle_,
   {{0x2d8f00cd,0x612f008c,0x25ab099e,0x00000000}},	//   _kuge_, _jølb, _bwcl_, --,
   {{0x2d87a19e,0xb5fb006c,0x2d8f00f7,0x6db500a8}},	// [b880] _kine_, _szár, _juge_, _uşağ,
   {{0xc8ca00bf,0x3eaf347e,0x2d8706fe,0x25a0a19f}},	//   _بودن_, _legt_, _jine_, rpil_,
   {{0x935a02c4,0x25a0221b,0x9c7ca1a0,0x2d87a1a1}},	//   орду_, spil_, večk, _mine_,
   {{0x2bc505f7,0x1aec0033,0x660973c0,0x69c6a1a2}},	//   _विना, টাকে_, _šeke, orke,
   {{0xd00f00d1,0x3f866a8d,0x3cee00a1,0xb0d20066}},	//   یله_, _riou_, _असले_, _सादग,
   {{0xcf9a0202,0x332d0703,0x2d87024b,0x61ed0457}},	//   оји_, _elex_, _nine_, çala,
   {{0x39944b47,0x9c7c0187,0x2d8f0408,0x3d1116d3}},	//   _läs_, rečk, _auge_, ताने_,
   {{0x2d871d2c,0x9c7c0116,0xadf4a1a3,0x00000000}},	//   _aine_, sečk, епиш, --,
   {{0x2d870012,0xc6200083,0x9c7c010b,0x2d8f0124}},	//   _bine_, _নেতা_, meči, _cuge_,
   {{0x2d874552,0x2b4012c3,0x2d8f1fb5,0x9c7c02c6}},	//   _cine_, _amic_, _duge_, leči,
   {{0x69c02736,0x2d871879,0xdb021214,0x2d8f02d7}},	//   ámen, _dine_, mplê, _euge_,
   {{0x2d870446,0x80da00b4,0x39430120,0x2d8f9364}},	//   _eine_, प्रे, wijs_, _fuge_,
   {{0x2d87a1a4,0x69c00bc5,0x9f450298,0x13e70033}},	//   _fine_, šmen, _oplê_, ফিয়,
   {{0x3eaf0a75,0x2b400176,0x00000000,0x00000000}},	//   _zegt_, _emic_, --, --,
   {{0x3943a1a5,0xc1db00b8,0x2bc50066,0x69c615e4}},	//   rijs_, _मङ्ग, _विया, arke,
   {{0x9c7c753e,0x2d87a1a6,0x3d0c00ab,0xd6e800af}},	//   ječi, _zine_, ़ावे_, мфул_,
   {{0xe7843275,0x2d8701d6,0x7bda0086,0x9c7c0a66}},	// [b890] туро, _yine_, lttu, deči,
   {{0x2bc56d67,0x88c60083,0xb8670aaa,0xe46b0421}},	//   _विमा, শ্বক, _يادو, ошел_,
   {{0x3941008c,0x7bda064a,0x00000000,0x00000000}},	//   _imhs_, nttu, --, --,
   {{0x52750012,0x7bdaa1a7,0xe81c0066,0x25c40448}},	//   нулу, ittu, नहरा_, ürlü_,
   {{0x2bc50967,0x332d2278,0xa1eb004f,0x26000ac4}},	//   _विभा, _vlex_, تراك_, रिणी_,
   {{0x70c900a1,0x7d1c01ff,0x80da0d34,0x00000000}},	//   रलेल, örsl, प्ले, --,
   {{0x2d8fa1a8,0x2a69030d,0x00000000,0x00000000}},	//   _suge_, _lyab_, --, --,
   {{0x2d87a1a9,0x69c60304,0x2d8f0176,0x00000000}},	//   _sine_, yrke, _puge_, --,
   {{0x2a690189,0x6ff300a8,0x3f9e6fbf,0x2d870f00}},	//   _nyab_, _məcə, _ettu_, _pine_,
   {{0x28df22d4,0x6e9f52cf,0xfd110037,0x3ea2027d}},	//   _पॉलि, _ग्रु, اجة_, ıkta_,
   {{0x2d87a1aa,0x69b2007c,0x9f4c00ac,0xcb6aa1ab}},	//   _vine_, _अबही, _hrdý_, зане_,
   {{0x2d8fa1ac,0x2d87a1ad,0x20180392,0x81e20033}},	//   _tuge_, _wine_, _ària_, ধির_,
   {{0xed4e5e0a,0x2d87a1ae,0xee2e07e5,0x69c60051}},	//   _бо_, _tine_, _сн_, urke,
   {{0x2eed0173,0x2a690359,0x2d8700f1,0x3941055c}},	//   leef_, _dyab_, _uine_, _cmhs_,
   {{0x66e6103e,0x00000000,0x00000000,0x00000000}},	//   нова, --, --, --,
   {{0x6378862c,0x2c1c0803,0x2a690260,0x00000000}},	//   míng, महरू_, _fyab_, --,
   {{0x7ae40232,0x9c7c6fc9,0xfbc502d1,0x6378a1af}},	// [b8a0] _ibit, veči, _विडम, líng,
   {{0x637101ff,0xb5fb0097,0x2eed0223,0x7ae4007e}},	//   våna, _vzáp, heef_, _hbit,
   {{0x5ef40026,0x20c906bc,0x72c6081e,0x9c7c2381}},	//   ्यम्_, _राजध, ебез, teči,
   {{0xeb920779,0x29070211,0x00000000,0x00000000}},	//   אָס_, _ònar_, --, --,
   {{0x9c7ca1b0,0x2a6901e8,0x7ae41bd7,0x00000000}},	//   reči, _xyab_, _mbit, --,
   {{0xdfd00bdf,0x9c7c040b,0x7bda0093,0x41d1074f}},	//   ليت_, seči, yttu, _समरस,
   {{0x50b7004f,0x7ae4a1b1,0x2d99002a,0xdb02008d}},	//   ردود_, _obit, ísen_, nsló,
   {{0x20d20e04,0x26d202b3,0x68ee8b96,0x2eed01bf}},	//   _सावध, ngyo_, hebd, geef_,
   {{0xdb020248,0x020602ce,0x657e000d,0x00000000}},	//   mplè, _язан, omph, --,
   {{0xe7b10067,0x320400ee,0x00000000,0x00000000}},	//   _जबलप, _irmy_, --, --,
   {{0x7bda081b,0x7ae4009e,0x6f0b0160,0x00000000}},	//   uttu, _bbit, _fngc, --,
   {{0xf09f01a5,0xbacf0083,0x7ae40211,0x7bda00c3}},	//   _đài_, িজ্ঞ, _cbit, rttu,
   {{0x6378213c,0x6ff300a8,0xfaff0055,0x00000000}},	//   mínd, _rəcə, llëk_, --,
   {{0x7ae40273,0x63789106,0x00000000,0x00000000}},	//   _ebit, línd, --, --,
   {{0xc6a711b9,0x78b5068b,0x272e008a,0x6ed700a1}},	//   ерзи, razv, _sýna_, _यामु,
   {{0x64430035,0x6378002a,0x674400af,0x27350282}},	//   źnik, nínd, гэуз, _mång_,
   {{0x2735022a,0x6126008a,0xe8d90023,0x00000000}},	// [b8b0] _lång_, _eðli, _quỳ_, --,
   {{0x7afda1b2,0x7aef4a89,0x48ab0086,0x2727007c}},	//   ldst, lect, _этим_, _mõni_,
   {{0x98c403ad,0x5f032a06,0xd40400c3,0x9fbb0033}},	//   _ссыл, वयम्_, ляци, _অঙ্গ,
   {{0x7aefa1b3,0xe8d90019,0xa3b40035,0x7afd4f7e}},	//   nect, _tuỳ_, _फ़िर_, ndst,
   {{0x69dda1b4,0x7aef0012,0x7afd0b0d,0xa28200b5}},	//   ntse, iect, idst, لیفو,
   {{0xe61f01a5,0x776d0042,0xa0692b34,0x69dda1b5}},	//   _ngôi_, llax, мала_, itse,
   {{0x2bc51365,0x629601d6,0xb0d2018d,0x69dd0a63}},	//   _विधा, ıyor, _सारग, htse,
   {{0x7aefa1b6,0x69cf0088,0x7afda1b7,0xadf200dc}},	//   ject, kuce, jdst, _अनशन_,
   {{0x7aef0168,0x2eed1e7e,0x69dd6c11,0x69cfa01d}},	//   dect, reef_, jtse, juce,
   {{0xdb02a1b8,0x69cfa1b9,0x7afd01bf,0x61e9a1ba}},	//   mplé, duce, edst, _ipel,
   {{0x7aef4805,0x2735022a,0x69dd2193,0x7afd0120}},	//   fect, _gång_, etse, fdst,
   {{0x69dda1bb,0x637801dd,0x61e900e0,0x7afd0051}},	//   ftse, cínd, _kpel, gdst,
   {{0xade50066,0x69dd6bd5,0x2f1800b5,0x69cf1f7f}},	//   _कहिन_, gtse, _négy_, guce,
   {{0x7afd0afc,0xa02100ab,0x61e9002f,0x637806fe}},	//   adst, _ööse, _mpel, míne,
   {{0x69dd04ce,0x18677a3c,0x63783dad,0x290c037a}},	//   atse, вари_, líne, ıda_,
   {{0xc6c315de,0xed590a23,0x7ae4a1bc,0xcf9202b5}},	//   ийск, drži_, _ubit, שטן_,
   {{0xb0d20066,0xa68607e5,0x63bc0207,0x6d430103}},	// [b8c0] _सालग, тлад, _svrn, _kmna,
   {{0x61ed0484,0x34cc0026,0x61340176,0x5ea80033}},	//   ħall, ालेद, _xàld, _গাছে,
   {{0xf65100f5,0x27350249,0x6b5d00b5,0x6d430107}},	//   لئے_, _bånd_, végz, _mmna,
   {{0xfe6703fb,0x8c1a0070,0x776d0042,0x63780042}},	//   _ند_, וועי, clax, xínd,
   {{0xa2d30026,0x80da0033,0x612f008c,0x15430012}},	//   _डार्, _যোগ্, _søla, _ӂерм,
   {{0x64a31813,0x6fd600b4,0x00000000,0x00000000}},	//   _вара, _यमदू, --, --,
   {{0x15432012,0x7aef0083,0x61e9a1bd,0x04460b25}},	//   _терм, yect, _epel, _ревн,
   {{0x7aef3612,0x637801dd,0xd00703fa,0x66060069}},	//   xect, fíne, ђење_, _krkk,
   {{0xe0da09ea,0x7aefa1be,0x28d33100,0xe3556e2d}},	//   _ова_, vect, _तालि, _стрэ,
   {{0x21762fb3,0x69cfa1bf,0x00000000,0x00000000}},	//   _рубр, vuce, --, --,
   {{0x7aef2331,0xdeef002d,0x200500cd,0x776d345d}},	//   tect, _кы_, _grli_, ylax,
   {{0x69cf0248,0x7afd78a3,0x69dd2e40,0x6d4301e9}},	//   tuce, udst, ttse, _emna,
   {{0x7aef15d3,0x00000000,0x00000000,0x00000000}},	//   rect, --, --, --,
   {{0x69dd1de6,0xdc5500b5,0x2735038d,0x00000000}},	//   rtse, ئریک, _måne_, --,
   {{0x6d481423,0x7aef339f,0x69cfa1c0,0x660600c3}},	//   mida, pect, suce, _arkk,
   {{0x6d482132,0x69cfa1c1,0x69dd033b,0x9f5e0176}},	//   lida, puce, ptse, _ortí_,
   {{0xb0d20429,0x6594218b,0x9c7c063b,0x7c28016e}},	// [b8d0] _सांग, иату, reču, lydr,
   {{0x6d480152,0x3cfe008c,0xb4cd0099,0xdb0b0044}},	//   nida, ndtv_, ळले_, _avfø,
   {{0x61e9a1c2,0x6606005b,0xe3b00037,0xe9df0405}},	//   _spel, _erkk, قرن_, ltú_,
   {{0xfaff00da,0x6d48a1c3,0xe3b0004f,0xc2c4004f}},	//   ndë_, hida, ترك_, ليمي,
   {{0x6b8d1296,0xe9df0405,0x00000000,0x00000000}},	//   _miag, ntú_, --, --,
   {{0x30750086,0xe4f902b5,0x6d48a1c4,0x672da1c5}},	//   луйс, _אפֿש, jida, lkaj,
   {{0x62860187,0xe9df0098,0xa0664054,0x00000000}},	//   _úkon, htú_, лаша_, --,
   {{0xdb020248,0x672d2c0e,0x3cfc01f7,0xe1f300d1}},	//   pplé, nkaj, _aavv_, _پسر_,
   {{0x6d4892df,0x2bc50433,0x61e9a1c6,0x6565010d}},	//   fida, _विहा, _upel, oohh,
   {{0xee36002d,0x5ba9190a,0x9cf50fa7,0x672da1c7}},	//   унь_, нком_, учиш, hkaj,
   {{0x6b8d07e5,0x20050714,0xe8d90023,0x672da1c8}},	//   _biag, _urli_, _huỷ_, kkaj,
   {{0x7d1a006d,0x20df02d1,0xe9a612a2,0x672da1c9}},	//   ajts, प्रध, ламп, jkaj,
   {{0xfce536ae,0x2bc5162b,0xa9240097,0x776400a2}},	//   _боло, _विवा, ážov, voix,
   {{0x6d482140,0x6f1b05e2,0x82760070,0x6e2900d7}},	//   cida, ljuc, טערע_, myeb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8da1ca,0x3d110456,0x80cd0803,0x6f1d02b1}},	//   _giag, तावे_, _साझे, ösch,
   {{0x6e291201,0xa3b61343,0xe57aa1cb,0x635c64db}},	// [b8e0] nyeb, चीन_, еза_, nčne,
   {{0xdff30378,0xd91000b5,0x2a3b011d,0x00000000}},	//   _आनंद_, _بیس_, _נעימ, --,
   {{0x42ca0009,0x6ab60716,0xe4d700f8,0xceb900b8}},	//   еген_, _keyf, اومت_, kař_,
   {{0x6d480c1f,0xe29a1fb1,0xe73a03ad,0xdcf4025c}},	//   zida, хад_, _чем_, _čači,
   {{0x6d48a1cc,0xa805002a,0x6e3b00d5,0x00000000}},	//   yida, poñé, jzub, --,
   {{0x6ab6008a,0x66040010,0x6e29010d,0xe3a40df3}},	//   _leyf, mvik, dyeb, _نشری,
   {{0x6d480aca,0x2bc50d34,0x7f49012f,0xfbc50cea}},	//   vida, _विषा, fieq, _विषम,
   {{0xcfe70037,0x612f03d0,0x6e3b02b1,0x00000000}},	//   افيه_, _høll, fzub, --,
   {{0x10a60b32,0x6b8d0014,0x3eb9003e,0x6604a1cd}},	//   _бизн, _riag, ðsta_, nvik,
   {{0x2bc50d00,0x23660189,0x7d1a006d,0xb22300af}},	//   _विशा, looj_, ujts, _умул,
   {{0x2056a1ce,0x40930514,0x6d480152,0xa11306ca}},	//   _стар, _المر, rida, _دولت,
   {{0x2bc50e96,0xfbc5021a,0xde960037,0x8aa7010b}},	//   _विरा, _विरम, _إجاب, ырод,
   {{0x7c3a00f5,0xfe720332,0x6d48a1cf,0xfaff0031}},	//   sztr, _ادا_, pida, rdë_,
   {{0x6d48012f,0x660402a5,0x68fe0443,0xe9df004f}},	//   qida, dvik, _capd, rtú_,
   {{0xb8fd00c0,0xf7730dd2,0x6b8da1d0,0x3d110e62}},	//   _डा_, مار_, _tiag, तारे_,
   {{0x96f82ee2,0x672d002f,0xd6d80f27,0xe9df0176}},	//   лест_, ukaj, лту_, ptú_,
   {{0xf77064e5,0x612f0b3e,0x2d8e021e,0x6d5d00a2}},	// [b8f0] ساف_, _bøll, _kife_, ésag,
   {{0x672da1d1,0x6fea0095,0x45d41018,0xb69b00a2}},	//   skaj, _məcb, софс, _saâd,
   {{0xa9260080,0x672d022f,0x53a4004f,0x6d4f000d}},	//   _dažā, pkaj, مملك, écai,
   {{0x2d8ea1d2,0x63784a7b,0x63a933a5,0xade5007c}},	//   _life_, vínc, _čend, _कहलन_,
   {{0xd5af00f5,0x7aff035f,0xe8d90019,0x66040187}},	//   _رہا_, _maqt, _quỷ_, cvik,
   {{0x2cf302cb,0x34943997,0x2bc552cf,0x60250009}},	//   _असेल_, _гарр, _विला, идла,
   {{0x60de02e9,0x2a7f00a0,0xdce30069,0x00000000}},	//   òpma, ľuby_, _ninġ, --,
   {{0x290400ea,0x6e3b7358,0x272700ab,0x6d5800cd}},	//   ēmai_, tzub, _tõnu_, _ajva,
   {{0xed5901b8,0xef160733,0x3d11000c,0x98b10228}},	//   кои_, рмы_, ताले_, nizē_,
   {{0x6378a1d3,0x61fb18ad,0xd16701d3,0xed4500d4}},	//   mína, _isul, _съби, рноп,
   {{0x2d8e02e9,0x610b0029,0x7aff0069,0x66090009}},	//   _dife_, _vēlē, _baqt, _šekl,
   {{0x8f9a32e3,0xdb1b0183,0x00000000,0x00000000}},	//   _סיני, dutó, --, --,
   {{0x3eada1d4,0x3da70a87,0x61ed0183,0x68fe0260}},	//   mbet_, _среб, çalh, _papd,
   {{0xdca50f28,0x26090380,0xdb02a1d5,0x3eada1d6}},	//   _таки, सिनी_, mplí, lbet_,
   {{0x394a596e,0x186a33ce,0x2366006d,0x290400b8}},	//   ribs_, тави_, yooj_, ěma_,
   {{0xb6a6a1d7,0x7d1c1aee,0x3f8f035f,0xd6d200bc}},	//   риал, örsv, _jigu_, تقر_,
   {{0x66030012,0x68fea1d8,0x597600c3,0x3f8f023a}},	// [b900] опта, _tapd, _выну, _migu_,
   {{0x6604a1d9,0x3ead01d6,0x3f8f00cd,0x499100b5}},	//   rvik, hbet_, _ligu_, _ریفر,
   {{0x6604a1da,0x61fba1db,0x3cdd0a5e,0x66e6a1dc}},	//   svik, _asul, _खाने_, _кона,
   {{0x78bca1dd,0xf3c90833,0xdb1b0176,0x00000000}},	//   larv, ابله_, lutò, --,
   {{0x63a90009,0x63780453,0x27f8016e,0x09e40033}},	//   _čene, gína, lwrn_, মিকা,
   {{0x78bca1de,0x3ead3cc7,0x2366006d,0xfaff0031}},	//   narv, ebet_, sooj_, llët_,
   {{0x61fba1df,0x61340176,0xb3470069,0x00000000}},	//   _esul, _càla, _baħħ, --,
   {{0x6134009e,0x78bca1e0,0x3ead0c06,0x3f8f02a7}},	//   _dàla, harv, gbet_, _cigu_,
   {{0xb5fb006c,0x3f8f01d7,0xad26004f,0xb347007a}},	//   _száz, _digu_, لردو, _daħħ,
   {{0x33240069,0x61e203d5,0x78bc7a20,0x3f8f008d}},	//   _homx_, mtol, jarv, _eigu_,
   {{0x3eada1e1,0x2574013c,0x3f8f0107,0x78bca1e2}},	//   bbet_, väll_, _figu_, darv,
   {{0x79a70036,0x27f8001e,0x78b70479,0x2d8e00a5}},	//   ирге, dwrn_, _sexv, _wife_,
   {{0x61e20e60,0x9da701d3,0x9b5868d3,0x78bc4c6e}},	//   ntol, _къща_, рият_, farv,
   {{0x7aff009f,0x270301a5,0x78bca1e3,0x3cdd00ab}},	//   _waqt, _ổn_, garv, _खाये_,
   {{0xd6db0426,0xb5fb006c,0xed570274,0xad1b00a5}},	//   кта_, _nyár, _њој_, _בוגר,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637801dd,0xdb02013c,0x78bca1e4,0xadf809b4}},	// [b910] xína, tslö, barv, ्टिन_,
   {{0x25a9028b,0x78bc0036,0x929d0035,0x6abd0de8}},	//   rpal_, carv, _małe, lasf,
   {{0x25a977ef,0x75880eb1,0x68f59a51,0x612f008c}},	//   spal_, рств_, mezd, _følj,
   {{0x2901a1e5,0x69ce0803,0x25a900b5,0x3324008c}},	//   _haha_, _तिमी, ppal_, _comx_,
   {{0x877a0052,0x29012326,0x10a51761,0xfaff01f4}},	//   _תארי, _kaha_, билн, llës_,
   {{0xa2d30bc1,0x2903a1e6,0xb3470484,0x2901026a}},	//   _डाक्, ndja_, _saħħ, _jaha_,
   {{0x29010daa,0xb5fb006c,0xdb090093,0x637801ef}},	//   _maha_, _gyár, nsdó, sína,
   {{0x81e600c8,0x6378024e,0x2901023c,0x00000000}},	//   _বছর_, pína, _laha_, --,
   {{0xf2d2012b,0x61fba1e7,0x3eada1e8,0x68f5006c}},	//   _מען_, _usul, rbet_, kezd,
   {{0x68f5a1e9,0x2901a1ea,0xdce30484,0x28dc02b4}},	//   jezd, _naha_, _minħ, _बाधि,
   {{0x237f006d,0xab2a0ddc,0xad24183b,0x2609060a}},	//   _khuj_, гона_, تريو, सिडी_,
   {{0x5e950037,0xdce70225,0x00000000,0x00000000}},	//   _الإط, ımıy, --, --,
   {{0x8e85004f,0x2901a1eb,0x78bca1ec,0xdce30024}},	//   _الشه, _baha_, tarv, _ninħ,
   {{0x7d1c022a,0x18a30ffd,0x2b49081b,0xde7410ab}},	//   örst, зарм, _emac_, _بدمع,
   {{0x290108d2,0xd9431283,0x236da1ed,0xf1d10461}},	//   _daha_, чери, _okej_, _समझन,
   {{0x6abd0069,0x78bc1fe9,0xdceb009f,0x61e234d2}},	//   casf, sarv, _bugħ, ytol,
   {{0x3bc301c2,0x2901009e,0x7bc1a1ee,0x68f50116}},	// [b920] lıq_, _faha_, lslu, bezd,
   {{0x236d00a0,0x29010027,0xfaff0055,0x00000000}},	//   _akej_, _gaha_, blës_, --,
   {{0x7bc1a1ef,0x69c4016f,0x4cba016b,0x3bc3013b}},	//   nslu, _hvie, רמעג, nıq_,
   {{0x59af06bb,0x61e2a1f0,0x69c400d8,0x236d00ee}},	//   जीकर, ttol, _kvie, _ckej_,
   {{0x237f006d,0x2125023a,0x7ce10260,0x61e24ab4}},	//   _dhuj_, _bolh_, _kňrč, utol,
   {{0x7bc1a1f1,0x35a30009,0x67261cb3,0x00000000}},	//   kslu, _харг, _hokj, --,
   {{0x61e2a1f2,0x443e9ccd,0x260005dc,0x7bc101e4}},	//   stol, _åt_, रिकी_, jslu,
   {{0x69c40300,0x63780097,0x3bc300a8,0x00000000}},	//   _ovie, míno, dıq_, --,
   {{0x171b0070,0x6b4f0359,0x8e1401e0,0x00000000}},	//   רופע, _lògè, ідоц, --,
   {{0xccfa03fa,0x2b490036,0x69cf0207,0x00000000}},	//   ући_, _smac_, vrce, --,
   {{0x2901a1f3,0x351b02b5,0x69c4a1f4,0x613d021e}},	//   _raha_, אוינ, _avie, _bèlf,
   {{0x2901a1f5,0xa3e000dc,0x4477016b,0x00000000}},	//   _saha_, _दमन_, מעיל_, --,
   {{0x69cfa1f6,0x4f65004f,0xbf650aaa,0x2901a1f7}},	//   urce, _بالف, _بدلو, _paha_,
   {{0x69c4a1f8,0x6f02009e,0x7bc10097,0xdd9000fd}},	//   _dvie, _haoc, bslu, _غوث_,
   {{0x2903a1f9,0x3cdd0325,0x6d4aa1fa,0x69c41697}},	//   rdja_, _खाते_, _imfa, _evie,
   {{0xdb090093,0x2901a1fb,0x160500b4,0x00000000}},	//   rsdó, _waha_, रिलर_, --,
   {{0x2901007c,0x69c02675,0x7aeda1fc,0x60c803d0}},	// [b930] _taha_, ámet, _ibat, _oddm,
   {{0xdb1b004f,0x6f02a1fd,0x200ca1fe,0x7aed0069}},	//   istí, _laoc, _ordi_, _hbat,
   {{0x69c41490,0x69c000ea,0x00000000,0x00000000}},	//   _zvie, šmet, --, --,
   {{0xd25114ac,0x6f0241d8,0x67260223,0x7aed009f}},	//   ونا_, _naoc, _gokj, _jbat,
   {{0x6d4a02df,0x7aeda1ff,0x4cd00083,0x200c5e14}},	//   _omfa, _mbat, ত্যু, _ardi_,
   {{0xdb1b2ec6,0xe7960118,0x3bc300a8,0x612f08c8}},	//   nstâ, _دایک, yıq_, _køli,
   {{0x69a00821,0x200ca200,0x7aeda201,0x63782f64}},	//   _गंभी, _crdi_, _obat, cíno,
   {{0xf83802b8,0x6d4aa202,0x0dc9878d,0x3eb900fb}},	//   מנות_, _amfa, алий_, úst_,
   {{0x200ca203,0xd34600e0,0x8d59021d,0x00000000}},	//   _erdi_, _بینه_, ишот_, --,
   {{0x7aed1415,0x3bc301c2,0x7bc10c7c,0x613d0260}},	//   _abat, tıq_, tslu, _sèlf,
   {{0x69c4a204,0x81bb0083,0xc4d200a5,0x200c0a66}},	//   _svie, _অমি_, וגי_, _grdi_,
   {{0xf8a901f3,0x7bc1a205,0xcb6a55df,0x3bc30095}},	//   _יש_, rslu, раме_, rıq_,
   {{0x2bc504aa,0x3ebf0ac8,0x916200e2,0xfe700037}},	//   _विका, maut_, _sử_, _كده_,
   {{0x3ebf83f3,0x7aed0cf3,0xdcf800ec,0x00000000}},	//   laut_, _ebat, _divē, --,
   {{0x273c0082,0x2d9f02e1,0x6726022e,0xc7a30c90}},	//   _líne_, lque_, _pokj, диск,
   {{0x7d03a206,0x2a60006f,0x27990043,0x00000000}},	//   _hans, _txib_, стрэ_, --,
   {{0x7d03a207,0x2d9fa208,0xa52602ce,0x69c401ba}},	// [b940] _kans, nque_, омад, _uvie,
   {{0x2bed0953,0x29040080,0x7aed00da,0x75d3004f}},	//   _जहां_, ēmas_, _zbat, بيكا,
   {{0x7d03a209,0x3ebfa20a,0x0d3a0070,0x00000000}},	//   _mans, kaut_, סגעב, --,
   {{0x7d03a20b,0x320d01ef,0xdcb60ec5,0x4c6c016b}},	//   _lans, _brey_, _आज्ञ, נדאַ,
   {{0x7d030523,0x3ebf0430,0x26c00074,0xdb2100fd}},	//   _oans, daut_, maio_, áték,
   {{0x26c0a20c,0x7d03a20d,0x320d08dd,0x25740086}},	//   laio_, _nans, _drey_, käli_,
   {{0xdfd00514,0x256f0332,0x2d9f283e,0x3ebf0248}},	//   رية_, rült_, eque_, faut_,
   {{0x7d030d26,0x26c007e5,0x03672d0c,0x256f00b5}},	//   _aans, naio_, _диск_, sült_,
   {{0x7d03a20e,0x2600111a,0x320da20f,0x00000000}},	//   _bans, रिटी_, _grey_, --,
   {{0x7aed8215,0x644000a8,0x200c08b7,0xe80d02b4}},	//   _sbat, _əmin, _trdi_, हिमा_,
   {{0x7d03a210,0x3ebf01ae,0x2d9f67f7,0x635c501f}},	//   _dans, baut_, aque_, nčno,
   {{0x3ebf4c7a,0x6d4f00a2,0x00000000,0x00000000}},	//   caut_, écar, --, --,
   {{0xed5a5846,0x7d03a211,0xda7b0ae1,0x2d9fa212}},	//   _код_, _fans, рян_, cque_,
   {{0x6d4a23b3,0x7d031b2f,0x5ef40096,0x00000000}},	//   _umfa, _gans, ्यक्_, --,
   {{0x6d5a30bc,0x28dc1282,0x69c02fba,0xdb0200d5}},	//   mnta, _बारि, ámer, splá,
   {{0x4c3b0052,0x7aeda213,0x7d0302e9,0x26c00015}},	//   _כתוב, _ubat, _zans, gaio_,
   {{0xd49b09eb,0x6d5aa214,0x7d03a215,0x3d0f72c4}},	// [b950] аре_, onta, _yans, _थोडे_,
   {{0x6d5aa216,0x25a60037,0x44f4002d,0x7d03a217}},	//   nnta, íola_, мпус, _xans,
   {{0xa2f502ce,0x6d5aa218,0x273c0079,0x2d9f258e}},	//   зпеч, inta, _síne_, zque_,
   {{0x65951b52,0x2cbc0044,0x6d5a61af,0xdb1b0392}},	//   _наму, _levd_, hnta, nstà,
   {{0x86350070,0x00000000,0x00000000,0x00000000}},	//   _זאָג_, --, --, --,
   {{0x6d5a1a0d,0x1fb500af,0x00000000,0x00000000}},	//   jnta, псир, --, --,
   {{0x7d03a219,0xc9540319,0x660f0156,0x91a900fd}},	//   _rans, ומס_, _hrck, جنڈے_,
   {{0xef19a21a,0x660f0cc2,0x25740303,0xf41200a5}},	//   сми_, _krck, väli_, _אפל_,
   {{0x7d03a21b,0x28dc06bc,0x3ebfa21c,0x30a70426}},	//   _pans, _बालि, raut_, _древ,
   {{0x1c4510be,0x6d5a006d,0x613d0260,0x3ebf23bb}},	//   зном, gnta, _bèle, saut_,
   {{0xc4d202b5,0x2d9f1762,0x7d0303d0,0x3ebf028b}},	//   עגט_, sque_, _vans, paut_,
   {{0x2d991423,0x6d5aa21d,0x3cdd009a,0x6fea0095}},	//   íses_, anta, _खावे_, _məcl,
   {{0x7d03a21e,0x6d5a01e8,0x26c0027a,0x81e90033}},	//   _tans, bnta, vaio_, যিক_,
   {{0x7d0310db,0xdb19017b,0x00000000,0x00000000}},	//   _uans, _avvä, --, --,
   {{0x26c0a21f,0x25ab08c7,0xdb1b0310,0x2bc50127}},	//   taio_, _atcl_, bstà, _विटा,
   {{0x2d9d91f7,0x030b0084,0x660fa220,0x06d40831}},	//   _kuwe_, _सोलह_, _brck, হ্নি,
   {{0x26c001d3,0x96631d99,0x6b84a221,0x3ebd035f}},	// [b960] raio_, екте, _ihig, _mewt_,
   {{0x649a539c,0x69c6a222,0x26c00f84,0x2d9d699a}},	//   стар_, mske, saio_, _muwe_,
   {{0x389b00c2,0xa3b60722,0x69c6a223,0x2d9d00f8}},	//   _ליינ, चीं_, lske, _luwe_,
   {{0xc8dc0722,0x637800b8,0x93590044,0x2d9d02a2}},	//   _बाँट, mínk, орчу_, _ouwe_,
   {{0x69c6a224,0x2d9d250a,0x6d5a008c,0x660f012e}},	//   nske, _nuwe_, ynta, _grck,
   {{0xd24f2149,0x9f5e00a0,0xdb1b3659,0x98a4010b}},	//   دنه_, _isté_, istá, ėmė_,
   {{0x6d5a006d,0xb4ca05f8,0x653b0070,0xbef900b4}},	//   vnta, ोली_, _פעלד, ्यून_,
   {{0x6724a225,0x2bc500e7,0xe80d111a,0x91e615df}},	//   njij, _विजा, हिता_, _нобе,
   {{0x4444a226,0xf8dca227,0x69c61912,0x7644a228}},	//   lz_, _बांय, jske, nziy,
   {{0x4444a229,0x6280220b,0x613d2870,0x6d5aa22a}},	//   oz_, _izmo, _pèle, unta,
   {{0x4444a22b,0x6d5a987e,0xf1d22516,0xdb1b01ef}},	//   nz_, rnta, _सिडन, está,
   {{0x4444a22c,0xdee60a71,0x6b84a22d,0x63b800a0}},	//   iz_, _ходи, _chig, ávny,
   {{0x6b844dbb,0x6e93004f,0x3e8500f7,0x5a340340}},	//   _dhig, _كلما, rêté_, енят,
   {{0x2bc5074f,0x7644012f,0x6b8401ed,0xfbcf0919}},	//   _विचा, dziy, _ehig, ختی_,
   {{0xc8640132,0x4444a22e,0xa4270033,0xb8f507df}},	//   етти, jz_, _মধ্য_, _हय_,
   {{0x4444a22f,0x3f9e09e7,0x6b84027a,0x660f00fe}},	//   dz_, _mutu_, _ghig, _prck,
   {{0x7bda087a,0x69c600b5,0x69da0067,0x3f9e008e}},	// [b970] lutu, cske, ątec, _lutu_,
   {{0x272e0093,0x660f0124,0x2a5800a5,0xd49b0183}},	//   _sýnt_, _vrck, _מבחן_, сра_,
   {{0x25f9006a,0x9f5e0033,0xe5700125,0x3f9ea230}},	//   _उनकी_, _esté_, اطق_, _nutu_,
   {{0x52750043,0x25aba231,0x660f0207,0x00000000}},	//   мулу, _ttcl_, _trck, --,
   {{0x7bdaa232,0x444406a2,0xa3cf3421,0x3cdd0d43}},	//   hutu, az_, _शिव_, _खाले_,
   {{0x3f9e3cf1,0x4444a233,0x2d9d1192,0x00000000}},	//   _butu_, bz_, _ruwe_, --,
   {{0x4444006a,0x660da234,0x7bda1b43,0x64e200a1}},	//   cz_, lvak, jutu, _पातळ,
   {{0xee390b46,0xdb1b0187,0x2d9d0159,0x613d0260}},	//   жни_, ystá, _puwe_, _bèlc,
   {{0x612f0a8a,0x2b1c018d,0x3984191b,0x629b262d}},	//   _sølu, यासु_, löse_, _iguo,
   {{0x6b84a235,0x273c008a,0x69c601fe,0xdb1ba236}},	//   _shig, _mína_, vske, nstæ,
   {{0x7bdaa237,0x60c3a238,0x88e30033,0x660d023f}},	//   gutu, manm, য়াক, hvak,
   {{0x60c3a239,0x69c6a23a,0x09e20083,0x929d0035}},	//   lanm, tske, যবসা, _mało,
   {{0xfce503d0,0x25fd0461,0xba2301e0,0x612f0249}},	//   _жоло, _रैली_, вдяк, _følt,
   {{0x69c60687,0x6f09a23b,0x7bdaa0c5,0x673d0120}},	//   rske, ldec, butu, _alsj,
   {{0x6d41006e,0x6b8401a6,0x7bda00af,0x66e61958}},	//   mhla, _thig, cutu, мова,
   {{0x629b0019,0x69c6a23c,0x257401ae,0xbb860037}},	//   _nguo, pske, hält_, _تلبي,
   {{0x09e200c8,0x998d0b67,0xdb1b008a,0xa5f70370}},	// [b980] যবহা, šeš_, fstæ, меѓу_,
   {{0x444408ad,0x6378a23d,0x6d4100cc,0x257401ff}},	//   tz_, míni, nhla, jält_,
   {{0xd91b00c2,0x68fc0f1a,0xf746135d,0x60c3a23e}},	//   _וויל, merd, _жено, danm,
   {{0x4444a23f,0x68fca240,0x3f9e00f4,0x273c008d}},	//   rz_, lerd, _rutu_, _fína_,
   {{0x4444a241,0x2574017b,0x7d08013c,0x6d414507}},	//   sz_, fält_, ydds, khla,
   {{0x68fc01d3,0x60c3a242,0x3f9e0521,0xe00937e8}},	//   nerd, ganm, _putu_, विंद_,
   {{0xd01010ee,0x2b0e1db6,0x6d410608,0x63780037}},	//   الب_, ियाँ_, dhla, híni,
   {{0x68fca243,0x7bda127d,0x00000000,0x00000000}},	//   herd, vutu, --, --,
   {{0x10a603ad,0x929d004e,0x6280a244,0x00000000}},	//   _жизн, _zało, _uzmo, --,
   {{0x6d4141e3,0x3f9ea245,0xe0d703fa,0x60c3099e}},	//   ghla, _tutu_, _ову_, canm,
   {{0x68fca246,0xe0432682,0x660d02d4,0x6f09a247}},	//   derd, _инфи, zvak, bdec,
   {{0x2cb106d0,0x7c440254,0x291a4d48,0x612f082b}},	//   ızda_, _đurđ, _anpa_, _føls,
   {{0x7bda0006,0x6d4109bb,0x68fca248,0x25a60079}},	//   sutu, bhla, ferd, íoll_,
   {{0x6d41a249,0x7bda1a1e,0xf7730416,0x68fca24a}},	//   chla, putu, چار_, gerd,
   {{0x273c00fb,0xf7730180,0x212c009d,0x5c0601d3}},	//   _sína_, نار_, _modh_, _цяла,
   {{0x60c3a24b,0xb8e60035,0x637801ef,0x660da24c}},	//   zanm, _उड़_, bíni, tvak,
   {{0x68fca24d,0x1b7400b5,0x637803e6,0x6d86008d}},	// [b990] berd, _جدوج, cíni, rðaf,
   {{0x69dda24e,0x660d3a2e,0x6f094a9c,0x273c0187}},	//   muse, rvak, zdec, _vína_,
   {{0x69dd0006,0xdb1b4ce5,0xfe080023,0x61340392}},	//   luse, rstæ, _lữ_, _gàli,
   {{0x49070311,0x6d410187,0x273c003e,0x60c31872}},	//   िएको_, zhla, _tína_, wanm,
   {{0xfe080028,0x69dd007c,0xdb1b013c,0x7afd0043}},	//   _nữ_, nuse, mstä, iest,
   {{0x613d0260,0xdb1b1788,0x2d8c0051,0xc0e20dec}},	//   _bèla, lstä, jmde_, гошк,
   {{0x69dd7477,0x6f0901ae,0x60c3a24f,0x6d41006d}},	//   huse, tdec, ranm, vhla,
   {{0x69dd4f61,0xdb1b15e5,0x7afda250,0x60c3a251}},	//   kuse, nstä, jest, sanm,
   {{0x7afd20b7,0x6f09a252,0x68e50284,0x6d41a253}},	//   dest, rdec, _ochd, thla,
   {{0x69dda254,0xfe0801a5,0xc90a0033,0x0c251858}},	//   duse, _dữ_, _রক্ত_, емон,
   {{0x68fc0047,0x116a0148,0x69dd00f7,0xdb1b01ff}},	//   verd, _علمی_, euse, kstä,
   {{0x60c105eb,0xf41200c2,0x9f4701ba,0x68e5a255}},	//   _helm, אפט_, ktné_, _achd,
   {{0x68fc4072,0x69dd0006,0x60c144ce,0x386d033b}},	//   terd, guse, _kelm, ßern_,
   {{0xf1b202da,0xfc3115f4,0x60c1a256,0xfce50d6e}},	//   רסם_, _محب_, _jelm, _чоко,
   {{0xa9670036,0xdb1b02b1,0x00000000,0x00000000}},	//   хира_, fstä, --, --,
   {{0x7afda257,0x28dc0ccf,0x69dda258,0x7ae41e85}},	//   cest, _बाकि, buse, _ucit,
   {{0xcf921899,0x699640dd,0x69dd8e85,0x2b401cbd}},	// [b9a0] רטן_, _прох, cuse, _ilic_,
   {{0xec090028,0x80db0a44,0x200523a2,0xe577a259}},	//   _kế_, _नागे, _osli_, езу_,
   {{0xccf200a5,0x491d0387,0x2b4008b7,0xad36016b}},	//   רכב_, मारो_, _klic_, ענעס_,
   {{0xb37600e0,0x4426011c,0x661b0124,0xe80d00b4}},	//   رداش, ćo_, _šuke, हिरा_,
   {{0x2d8702bf,0x20050452,0x635c008b,0x798e002f}},	//   _ohne_, _asli_, nčni, ombw,
   {{0x7afda25a,0xdb1b071b,0x59d3227d,0x60c100ec}},	//   zest, mstå, _तिसर, _celm,
   {{0x333fa25b,0x3f8601e8,0x60c1a25c,0x2246006c}},	//   _flux_, _phou_, _delm, szok_,
   {{0x60c1007c,0x7afd0391,0x387a028b,0x69dd0103}},	//   _eelm, xest, _mypr_, yuse,
   {{0xdb1b02df,0x60c1a25d,0x91620023,0x6ce60409}},	//   nstå, _felm, _từ_, ніне,
   {{0x7afda25e,0x60c101d6,0x69dd007c,0xec090023}},	//   west, _gelm, vuse, _bế_,
   {{0x69dd0088,0x2b4004c3,0x7afd11f0,0x2d8c6820}},	//   wuse, _blic_, test, rmde_,
   {{0x69dd0ccf,0x26c2a25f,0xec090019,0x9f47031d}},	//   tuse, _neko_, _dế_, ytné_,
   {{0x7afda1b9,0xedd300ce,0xdb1b01ff,0x60c102d7}},	//   rest, _ميند, vstä, _yelm,
   {{0x7afda260,0x69dda261,0xe80d00a1,0x60c1002a}},	//   sest, ruse, हिला_, _xelm,
   {{0x69dda262,0xdb1b0ed4,0xd7f82500,0xd90f01cb}},	//   suse, tstä, нут_, لیک_,
   {{0x26c2a263,0x69dda264,0x7d0aa265,0xfbcf01cb}},	//   _ceko_, puse, _hafs, _اتو_,
   {{0xdb1b08f9,0x7d0a01f4,0x26c249ce,0x2fcc0453}},	// [b9b0] rstä, _kafs, _deko_, _lvdg_,
   {{0xdb1b186a,0x1be41db9,0xfaff03bc,0x3cfe02d7}},	//   sstä, _कमाल_, leë_, netv_,
   {{0x9f47290b,0x66060159,0xec090019,0x7d0a4ed6}},	//   stné_, _eskk, _xế_, _mafs,
   {{0xd6db0d36,0x60c1a266,0xd3240352,0x925900c3}},	//   _это_, _selm, льчи, мает_,
   {{0xa2cd074f,0x52740279,0x3984013c,0x60c177bc}},	//   दृष्, лушу, lösa_, _pelm,
   {{0x7d0a0b4f,0x26c2025c,0x98b4011c,0xd184093e}},	//   _nafs, _zeko_, čeći_, глій,
   {{0xe8140127,0x60c1292c,0xb8140141,0x3cfe0183}},	//   डिया_, _velm, डियम_, detv_,
   {{0x27e7022a,0xa2cd0b35,0x43940421,0x60c13de3}},	//   _ännu_, दृश्, _басс, _welm,
   {{0x60c1a267,0x5f760037,0xd9e300b4,0x39530523}},	//   _telm, خميس_, कूमत_, _omxs_,
   {{0x29cd0038,0x6aada268,0x635c08b7,0x00000000}},	//   dľa_, _afaf, včni, --,
   {{0xcb6aa269,0xbb463ab9,0x2b4002a0,0x2005a26a}},	//   дане_, венк, _plic_, _usli_,
   {{0xec0900e2,0x3cdd29ad,0x00000000,0x00000000}},	//   _vế_, _खाके_, --, --,
   {{0x26c2a26b,0x613401f7,0x8f3600a5,0xee2e167d}},	//   _reko_, _vàlv, _שאנו_, _тн_,
   {{0x49990d36,0xec0900e8,0x23d10cf1,0xdca215ae}},	//   ется_, _tế_, _हिंद, _каши,
   {{0x929d004e,0x8c421583,0x69ce0099,0x26c215ce}},	//   _całk, _веще, _तिकी, _peko_,
   {{0x273c0187,0xdb1b013c,0x41d219b7,0x2eff000d}},	//   _víno_, tstå, _सिलस, neuf_,
   {{0xb6a3002d,0x6f0b22fc,0x967600d8,0x00000000}},	// [b9c0] риул, _magc, тыві, --,
   {{0xdb1b0b87,0x1dd400a1,0x613d0260,0x00000000}},	//   rstå, _दिसत, _sèln, --,
   {{0xd7ca00bf,0x15fe0006,0x26c2a26c,0xd4f500d8}},	//   _توجه_, _उनकर_, _teko_, ыяты,
   {{0x490a0803,0xdb1ba26d,0xdceb00ea,0x00000000}},	//   ायको_, pstå, _augļ, --,
   {{0xe29703fa,0xcb130319,0x7af61e28,0x6fbe0033}},	//   вац_, ילא_, _mbyt, _ইমেই,
   {{0xdfd00c36,0x3958a26e,0xd12f0037,0x6604a26f}},	//   ميت_, nirs_, يمن_, mwik,
   {{0x7af60187,0xa87a0070,0x237d01e8,0x63784a21}},	//   _obyt, ואַר, blwj_, fínt,
   {{0x657e5c38,0x3ce70260,0x35a70066,0x5f19018d}},	//   llph, _acnv_, _कूड़, भाग्_,
   {{0x613401f7,0x63a90009,0x2b21018d,0x6f0ba270}},	//   _bàlt, _čeni, यासँ_, _dagc,
   {{0x20562e2d,0xf26700af,0x2735008c,0x27fa02a7}},	//   _итер, _риул_, _hånt_, _oppn_,
   {{0x3cfe0107,0x6aada271,0x6f0b008c,0x10a300af}},	//   retv_, _pfaf, _fagc, _тихн,
   {{0xee3a03fa,0x66040371,0x0057011d,0x613401f7}},	//   _оне_, kwik, _בשבת_, _vàlu,
   {{0x7d0a484c,0x6d860093,0x637864ec,0x9f5e0183}},	//   _tafs, rðab, líns, _estã_,
   {{0x27fa022e,0xf99f02d0,0x672f828c,0x6f00027d}},	//   _bppn_, twèb_, _socj, lemc,
   {{0x6378a272,0x57a4432e,0x3cfb00a5,0x00000000}},	//   níns, ишта, _חלונ, --,
   {{0xd6d80ed2,0x48e30083,0x2a69006d,0xe1d20026}},	//   кту_, য়ের, _txab_, _सिंघ,
   {{0x69c00132,0x6604010d,0xb0b40edf,0xf794010b}},	// [b9d0] âmet, gwik, ुराग, ратэ,
   {{0xf8b70e6f,0x7bda0298,0x7af61a36,0xf8a7046c}},	//   _अभिय, ortu, _zbyt, _खलिय,
   {{0x82d91e38,0xc7ab0037,0xc867002d,0x7afa00b5}},	//   едес_, _تدخل_, _штии, őtte,
   {{0x6f001075,0x2d9ca273,0x6604a274,0x657e009e}},	//   jemc, _live_, bwik, alph,
   {{0xe4a715d5,0x66041bc5,0x66f60317,0xd17900d8}},	//   _арбо, cwik, _גמרא_, нскі_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ff50c26,0x5ebe0033,0x00000000,0x00000000}},	//   استا, োলনে, --, --,
   {{0x5334784a,0xaf051306,0xe814021a,0x64580067}},	//   _кест, упил, डिता_, ócił,
   {{0x25a9a275,0x9f5e0176,0x7bdaa276,0x63781dad}},	//   nqal_, _artó_, ertu, rínt,
   {{0x9f5e0955,0x7f42a277,0x6378a278,0x61fb011e}},	//   _està_, _eloq, sínt, _ipul,
   {{0x6f0b2029,0xa2c70577,0xccf80355,0x63780097}},	//   _tagc, ारप्, mněl_, cíns,
   {{0x66040159,0x27fa021d,0x2b590176,0xa09a016b}},	//   ywik, _rppn_, gisc_, _װינט,
   {{0x7bda94c5,0x9f4701c0,0x2d9c0122,0xdd8e0416}},	//   artu, ntní_, _five_, توی_,
   {{0x2d9c0122,0x9f5e07c0,0x98760274,0x61fb018e}},	//   _give_, _istá_, губљ, _mpul,
   {{0x1867150d,0x7d01a279,0x39580036,0x00000000}},	//   гари_, mels, rirs_, --,
   {{0x290c01cc,0x7af6114d,0x6604a27a,0x395802e1}},	//   žda_, _ubyt, twik, sirs_,
   {{0x0686027a,0x558aa27b,0x93cb00fd,0x39580176}},	// [b9e0] уган, ебам_, ہانہ_, pirs_,
   {{0x6604a27c,0x7d01029e,0x27350364,0xb9bb00a5}},	//   rwik, nels, _sånt_, _רצית,
   {{0x48e900a1,0x0d3a0070,0x61fb1574,0x6604a27d}},	//   _जातो_, עגעב, _apul, swik,
   {{0xd1ca0009,0xb7db0319,0x6378a27e,0x613d021e}},	//   елде_, _אקטי, víns, _dèlm,
   {{0x7d010b87,0xdcf8007e,0x799e5e74,0x00000000}},	//   kels, _chvě, _kipw, --,
   {{0x64a3a27f,0x7d019c6a,0xf48404cd,0x00000000}},	//   _гара, jels, _نازی, --,
   {{0x2d9c142f,0x7d010304,0x6f001008,0x9982010b}},	//   _rive_, dels, temc, lykų_,
   {{0x2d9c38cb,0x2dd487c1,0x00000000,0x00000000}},	//   _sive_, ажир, --, --,
   {{0x443a0160,0x7d01a280,0x2d9c87a8,0xdb1b0a8c}},	//   lyp_, fels, _pive_, mstø,
   {{0x7d01a281,0xdb1b082b,0x61e2010b,0x637800ac}},	//   gels, lstø, muol, píns,
   {{0x9f5e1423,0x443a0345,0x057700a5,0x7ee60037}},	//   _está_, nyp_, רגים_, _مكان,
   {{0xdb1b11cb,0xe9f900e2,0x543b016b,0x6d43a282}},	//   nstø, _ngả_, געטא, _elna,
   {{0x7d01a283,0x2d9c03e6,0x61e2010b,0x2b59a284}},	//   bels, _tive_, nuol, risc_,
   {{0x7d01a285,0xdd8f250f,0x443a00d5,0xdc551328}},	//   cels, _فون_, kyp_, اریک,
   {{0x273c01a5,0x6d4802a8,0x613d021e,0x61e200c3}},	//   _kính_, mhda, _bèlj, huol,
   {{0x61e2a286,0x8c1b011d,0x00000000,0x00000000}},	//   kuol, _טווי, --, --,
   {{0x613d0c1f,0xdb1b0b3e,0x80ca0033,0x7c3a0185}},	// [b9f0] _sèlm, dstø, _রান্, lytr,
   {{0x6d5a409c,0x273c0019,0x6d480023,0xb4df01c0}},	//   nita, _lính_, nhda, णले_,
   {{0x61fba287,0x02d000a1,0x00000000,0x00000000}},	//   _spul, हणून, --, --,
   {{0x6d5aa288,0x7d014e5f,0x52151eea,0xd21503fa}},	//   hita, zels, идет, имећ,
   {{0x6d5a253e,0x90c501c8,0x3f9d022e,0x6b8da289}},	//   kita, абле, _riwu_, _mhag,
   {{0x672d9ee9,0xdb0401d2,0x6d5aa28a,0x29110b43}},	//   ljaj, _punë, jita, ndza_,
   {{0x7d012895,0x9f47000c,0x273c00e2,0xdb04175d}},	//   vels, stní_, _bính_, _funè,
   {{0xef192337,0x613d02d0,0x7d012308,0xcb140099}},	//   тми_, _kèlk, wels, _तोंड_,
   {{0x6d5aa28b,0x7d01a28c,0x3f830080,0x2903a28d}},	//   fita, tels, ēju_, keja_,
   {{0x6d5aa28e,0x6b8d0010,0xa3dc00a1,0x29031469}},	//   gita, _ahag, णूक_, jeja_,
   {{0x7d015c1b,0x69dd0e54,0x8b26a28f,0x6d4300d5}},	//   rels, erse, адне, _vlna,
   {{0x7d018a22,0x6d48009e,0x6b8d1476,0x672d01a8}},	//   sels, ahda, _chag, jjaj,
   {{0x6b8da290,0x9f040332,0x6d5a1103,0x672da291}},	//   _dhag, _دونو, bita, djaj,
   {{0x6d5aa292,0x6846253f,0x6d48060e,0x2903a293}},	//   cita, анга, chda, geja_,
   {{0x6c7902b5,0x5c790070,0x63a702c6,0x6b8d0874}},	//   _באַפ, _באַה, _nujn, _fhag,
   {{0x6b8d0024,0x00000000,0x00000000,0x00000000}},	//   _ghag, --, --, --,
   {{0x4b7b00c2,0x7b0800ea,0x6d860093,0xdb1b0d51}},	// [ba00] _באקו, āstī, iðan, vstø,
   {{0x443aa294,0xf53f2172,0x273c008e,0x613d021e}},	//   typ_, _står_, _míni_, _dèlk,
   {{0x649a081b,0x4ada0825,0xdb1b0b3e,0x69c4009f}},	//   ттар_, _भयाव, tstø, _hwie,
   {{0x6d5aa295,0x1bf600c2,0x443a03bc,0x2bf60100}},	//   zita, יצער_, ryp_, ימען_,
   {{0xdb1b0c61,0x6d5a2107,0x64a61ea1,0x443a12b8}},	//   rstø, yita, _вага, syp_,
   {{0x6d5aa296,0xdb1b082b,0xf8c60324,0x443a0298}},	//   xita, sstø, वरिय, pyp_,
   {{0x403400d8,0x6d5aa297,0x224011d7,0xcae60067}},	//   сейс, vita, šik_, _कांड_,
   {{0xdefa1482,0x6d5aa298,0x61e23b8c,0x2903a299}},	//   тык_, wita, puol, zeja_,
   {{0x6d5aa29a,0x6b8d0297,0x6d48016e,0x2366011c}},	//   tita, _rhag, thda, mnoj_,
   {{0x23660202,0x69dd003a,0x6aa4251e,0xdd9700af}},	//   lnoj_, vrse, _agif, ишэ_,
   {{0x273c00e8,0x6d5a11f0,0x63a00207,0xa3c97cde}},	//   _tính_, rita, _kimn, लीप_,
   {{0x6d5a35f9,0x69cf2293,0x63a0a29b,0x7f4933f6}},	//   sita, tsce, _jimn, cheq,
   {{0x2903a29c,0x69dda29d,0xa2c7057c,0x69c47853}},	//   teja_, urse, ारत्, _cwie,
   {{0x5ba614a1,0x69c4731b,0xa2d6012f,0x69cf1f2c}},	//   _криз, _dwie, मृत्, rsce,
   {{0x2903a29e,0x6b8d148b,0x6d580010,0x60c8a29f}},	//   reja_, _thag, _imva, _medm,
   {{0x63a70c21,0x2903a2a0,0xa3c90722,0x2366a2a1}},	//   _rujn, seja_, लीफ_, jnoj_,
   {{0x236601cc,0xa3c90e68,0x2bc20026,0x672d008b}},	// [ba10] dnoj_, लीन_, वीरा, rjaj,
   {{0x6441007c,0x63a01c8b,0x4a7c00a5,0x672d0506}},	//   _ülik, _aimn, _ברחב, sjaj,
   {{0xd49b5cdf,0x69c4a2a2,0x80e00067,0x00000000}},	//   тра_, _zwie, नलैं, --,
   {{0xa3e60324,0xc7b200a5,0x7aed0069,0x63bb00d5}},	//   पढ़_, _מבט_, _jcat, _čund,
   {{0x62800297,0x63a003ab,0x6d58a2a3,0xe9df0037}},	//   _cymo, _dimn, _omva, nrú_,
   {{0x6ac40e61,0x2bac01c0,0xb4b800b5,0xa06917f8}},	//   _वज्र, _něco_, _نافذ_, лала_,
   {{0xe9df004f,0x7aed72c2,0x273c6923,0x6b46a2a4}},	//   hrú_, _ocat, _síni_, _lóga,
   {{0x753500f5,0x4f091402,0x2366012e,0x929d0067}},	//   _hozz, унин_, cnoj_, _bałt,
   {{0x6d86008a,0x7f4901f4,0x6280001e,0x60c80249}},	//   rðan, rheq, _gymo, _fedm,
   {{0x63a015b3,0x41541d13,0x61e601ff,0x75350088}},	//   _zimn, _двус, _åkla, _jozz,
   {{0x69c4a2a5,0x7535a2a6,0x628064e8,0xeb9a005c}},	//   _swie, _mozz, _zymo, лио_,
   {{0x6fea0095,0x63a00042,0x6d580103,0x00000000}},	//   _təcr, _ximn, _emva, --,
   {{0x3da75551,0x3ebf1034,0x5f74004f,0x8f9a0d85}},	//   _треб, mbut_, _بالر, _עיני,
   {{0x4e7a00c2,0x7535a2a7,0x23660254,0x7aed25e4}},	//   _גאנצ, _nozz, znoj_, _ecat,
   {{0xa7860c74,0x613d0176,0x6d41a2a8,0xa3c900a9}},	//   مشرو, _cèli, mkla, लीम_,
   {{0x69c4a2a9,0x7aed0037,0x6b6b0035,0x3ebf011e}},	//   _twie, _gcat, lęgn, nbut_,
   {{0x23660a78,0xe61a0bbc,0xe9df0037,0x7535a2aa}},	// [ba20] vnoj_, ыда_, crú_, _bozz,
   {{0x4cd900c8,0x6d41a2ab,0x753507e5,0x613d0392}},	//   ব্রু, nkla, _cozz, _fèli,
   {{0x23660a78,0x63a00009,0x7535027a,0x00000000}},	//   tnoj_, _pimn, _dozz, --,
   {{0x60c80690,0xd37900d4,0xfdf90026,0x4df90066}},	//   _sedm, ачі_, ्बास_, ्बाई_,
   {{0x23663b12,0x26c0a2ac,0x6d41a2ad,0x6b460042}},	//   rnoj_, mbio_, kkla, _xóga,
   {{0x23660a78,0xf1a503d0,0x7535a2ae,0x62800097}},	//   snoj_, ірін, _gozz, _vymo,
   {{0x63a0a2af,0x6d41a2b0,0x2366011c,0x62800067}},	//   _timn, dkla, pnoj_, _wymo,
   {{0x2b18009a,0x543b02b5,0x6280001e,0x7535325f}},	//   _बोलु_, _געלא, _tymo, _zozz,
   {{0x160e00be,0x63a10118,0x00000000,0x00000000}},	//   सिटर_, _èlna, --, --,
   {{0x3ebf043d,0xf1bf00b8,0x7bf80036,0xd6c00033}},	//   abut_, ášen_, анор_, েলিয,
   {{0xdefa03ad,0x3086004f,0x9f47024e,0x929d0067}},	//   _был_, _الاف, stná_, _fałs,
   {{0x613d0107,0x00000000,0x00000000,0x00000000}},	//   _rèli, --, --, --,
   {{0x6e960082,0x5a440c8a,0x161c00dc,0x442700e2}},	//   _الشا, пэра, निफर_, ̣n_,
   {{0x6d41a2b1,0xa3c9009a,0x273c008a,0x3f84003c}},	//   ckla, लीड_, _mínu_, llmu_,
   {{0x7535a2b2,0xe9df0098,0x273c008d,0x79950051}},	//   _rozz, srú_, _línu_, rmzw,
   {{0x6b460037,0x75350036,0xdb1b02b1,0x00000000}},	//   _tóga, _sozz, nstü, --,
   {{0x7535a2b3,0xa2c70517,0xa5350011,0x54a70037}},	// [ba30] _pozz, ारस्, онач, محاف,
   {{0x98c71583,0x3ebf108b,0x00000000,0x00000000}},	//   _усил, zbut_, --, --,
   {{0x26c002fb,0x293802b5,0x2b4900d7,0x635501e0}},	//   bbio_, _לאזן_, _klac_, овжу,
   {{0xe2f90210,0xd9ed0387,0x291301dd,0x6d41a2b4}},	//   реді_, _जमात_, _haxa_, zkla,
   {{0x6d411b4b,0x753559a6,0x291301b7,0xdb9c016b}},	//   ykla, _tozz, _kaxa_, אסאר,
   {{0x661d6560,0xa5bb00fb,0x2eb3022e,0x59dc0722}},	//   _irsk, _próf, ीर्त, _बिसर,
   {{0x6d41013c,0x6d860093,0xa5bb0079,0x3ebf011e}},	//   vkla, rðal, _bróg, tbut_,
   {{0x63b801ba,0x29131c02,0x3cfc0051,0x1dd40035}},	//   ívne, _laxa_, _abvv_, _दिखत,
   {{0xee3615eb,0x161c073f,0xf1e001c0,0x3ebfa2b5}},	//   жны_, नियर_, _नियन, rbut_,
   {{0x2b49009e,0x22640334,0x661d0c6e,0x26c0011c}},	//   _alac_, šská_, _mrsk, zbio_,
   {{0xdb1b008e,0x25a30223,0x6ab500b4,0x28bf0b35}},	//   sstý, _mijl_, ंडूर, ्रनि,
   {{0xa3e10bc1,0x6d41a2b6,0x6e240e5e,0x661d0009}},	//   _दिन_, skla, _šibe, _orsk,
   {{0x2913013b,0xa3c900a1,0x612f008c,0x00000000}},	//   _baxa_, लीत_, _søly, --,
   {{0x07a60798,0x25a30051,0x8c455a57,0x26d901e0}},	//   жавн, _nijl_, _меле, _adso_,
   {{0xe73a3669,0x18a36cef,0x26cb1097,0xae11007c}},	//   аев_, дарм, _beco_, ़िकन_,
   {{0x661d02c6,0x26cb0036,0x236d008b,0x2b4911d9}},	//   _brsk, _ceco_, _njej_, _glac_,
   {{0x26c0287e,0x80ca0083,0x25ab00d7,0x26cba2b7}},	// [ba40] rbio_, _রাস্, _cucl_, _deco_,
   {{0x2d850391,0x661d00cb,0xf1e004aa,0xdb04345b}},	//   nlle_, _drsk, _निबन, _muní,
   {{0x273c008a,0x661d0345,0x2d85a2b8,0x386d02b1}},	//   _sínu_, _ersk, ille_, ßert_,
   {{0x6499049f,0x25a30051,0xa5bba2b9,0x03261583}},	//   стур_, _eijl_, _bród, юден,
   {{0x6726a2ba,0xb77b0070,0xa5bb0312,0x00000000}},	//   _inkj, _כאטש, _cród, --,
   {{0x61430086,0x2bda00b4,0xe476002d,0x00000000}},	//   меча, _भिला, _дубэ, --,
   {{0xb4e60299,0xd4671d1f,0xf1b90009,0xa5bb003e}},	//   फली_, _дире_, _etš_, _próg,
   {{0x2d850044,0x236d00da,0x6d860093,0x25a30223}},	//   elle_, _gjej_, rðam, _zijl_,
   {{0xdb1b02c9,0x28bf06bc,0xcd061b0a,0x00000000}},	//   rstü, ्रमि, очни, --,
   {{0xdd901b15,0x2b4914d8,0xdb1ba2bb,0x00000000}},	//   عود_, _slac_, mpté, --,
   {{0xf1b91269,0x2b49a2bc,0x613d0176,0x61e21b5f}},	//   _vrše_, _plac_, _pèlv, lrol,
   {{0x8cba0af9,0x6da632dc,0x2d8500c3,0x26e404bc}},	//   _श्रो, _дида, alle_, गलोर_,
   {{0x61e2a2bd,0xf8c6115c,0xfd0f0148,0x26cb017b}},	//   nrol, वरूप, رجی_, _reco_,
   {{0x26cb04a5,0x6726008c,0x61e201ef,0xf1b9023a}},	//   _seco_, _ankj, irol, _urše_,
   {{0x7d080107,0x6d4a0036,0x78b00097,0x61e22cea}},	//   meds, _ilfa, _živý, hrol,
   {{0x661d0c21,0x7d08a2be,0x9f5e026e,0x00000000}},	//   _prsk, leds, _astú_, --,
   {{0x2913a2bf,0x25a302a2,0x26cb0228,0x00000000}},	// [ba50] _taxa_, _pijl_, _veco_, --,
   {{0x61e22016,0x7d081cd4,0x201ea2c0,0xbef8073f}},	//   drol, neds, _orti_, ्जुन_,
   {{0x61e2a2c1,0xf3f902fb,0x26cba2c2,0xfa340105}},	//   erol, снеш_, _teco_, _فرید,
   {{0x7d080022,0x80ca0083,0xa87a00a5,0x4bfb0070}},	//   heds, _রাষ্, _לאתר, שלאס,
   {{0x201ea2c3,0x2d858e19,0x25a30051,0xd25b0d6e}},	//   _arti_, ylle_, _tijl_, јце_,
   {{0x8cba25d8,0x2b92016f,0x201e012f,0x7d081b2a}},	//   _श्लो, máce_, _brti_, jeds,
   {{0x236d013c,0xd12e0079,0x25e30b4d,0x61e20036}},	//   _tjej_, امى_, टंकी_, arol,
   {{0x81aa00c8,0x6b46002a,0x60da00ee,0x9f470055}},	//   _খবর_, _rógo, _edtm, munë_,
   {{0x61e21537,0x201e104e,0x2d850392,0x613da2c4}},	//   crol, _erti_, tlle_, _bèlt,
   {{0x2d85a2c5,0x613d0176,0xc5f2011d,0x802700f3}},	//   ulle_, _cèlt, עדי_, _ورام,
   {{0x2d85043f,0x6b4600fe,0x00000000,0x00000000}},	//   rlle_, _fógl, --, --,
   {{0x660d3740,0xe6aa4e96,0x2d850042,0xdb041e60}},	//   kwak, _कलेज, slle_, _tuní,
   {{0x7d083bb6,0x4a4302fb,0xdb040395,0x00000000}},	//   beds, еняв, _punâ, --,
   {{0xfbd1004f,0xdce10228,0x00000000,0x00000000}},	//   _كتب_, rolē, --, --,
   {{0xd823519b,0x613d0176,0xeb9a27de,0xb8f400b4}},	//   ндри, _hèls, _лик_, _हज_,
   {{0xcc3a00c2,0x260d0009,0x38650079,0xdb1b00a2}},	//   _לעצט, _bžo_, úlra_, ypté,
   {{0xe7370de1,0xa3c94f13,0x273c0093,0xbbdb00ab}},	// [ba60] чет_, लीस_, _síns_, _मटुक,
   {{0x2bc20f17,0x260d0df4,0x45830370,0x28bf012f}},	//   वीका, _džo_, егув, ्रणि,
   {{0x49151365,0xe7eb0461,0x493b00a5,0x00000000}},	//   _फोटो_, जूदा_, _הגיו, --,
   {{0x7d08006a,0xe5a6285d,0x29182129,0x660d01a8}},	//   zeds, _ними, ldra_, bwak,
   {{0x26d2a2c6,0xe5a60ef3,0x613d0107,0x00000000}},	//   mayo_, _хиги, _nèls, --,
   {{0x61e200c8,0xe4da1c0c,0x26d2a2c7,0xdfd005bc}},	//   rrol, _دوست_, layo_, نيت_,
   {{0x28bf3010,0xd9d9000c,0x7d0810db,0x9f9800aa}},	//   ्रति, _भट्ट, veds, овку_,
   {{0x26d27a06,0x201e2676,0x64a300d8,0x7d082193}},	//   nayo_, _vrti_, _часа, weds,
   {{0x91e30150,0x7d08008c,0x63ae00b8,0x290a10a2}},	//   _поте, teds, _hubn, keba_,
   {{0x657e6d46,0x63aea2c8,0x26d261f9,0x290a00cb}},	//   noph, _kubn, hayo_, jeba_,
   {{0x26d2a2c9,0x6f092069,0x3a2000e0,0x290aa2ca}},	//   kayo_, beec, _arip_, deba_,
   {{0x657e0602,0x26d22d69,0x00000000,0x00000000}},	//   hoph, jayo_, --, --,
   {{0x63aea2cb,0x26d2a2cc,0x7d081bd8,0x657e008c}},	//   _lubn, dayo_, peds, koph,
   {{0xada303e6,0x290a6aa4,0x29180345,0x00000000}},	//   _зачл, geba_, gdra_, --,
   {{0xd6dba2cd,0x6cfb00a5,0x00000000,0x00000000}},	//   йта_, _הפוס, --, --,
   {{0x2918a2ce,0x26d23d80,0x660da2cf,0x7bd8009f}},	//   adra_, gayo_, twak, _ivvu,
   {{0x4ac30d53,0xaac348cd,0x290a0af0,0xae1f0026}},	// [ba70] _व्यव, _व्यक, beba_, बियन_,
   {{0xa5bb282a,0xd49ba2d0,0x290a03e6,0x7afda2d1}},	//   _prób, бре_, ceba_, lfst,
   {{0x26d20657,0x660d01a2,0xa5bb014c,0x00000000}},	//   bayo_, swak, _bróc, --,
   {{0x1ddd07ba,0x26d202d7,0x63ae3320,0x18681a55}},	//   _मिलत, cayo_, _dubn, _хаџи_,
   {{0xbef80066,0x657e0027,0x63bc0107,0xdb0201ff}},	//   ्जैन_, boph, _etrn, pplö,
   {{0xf8bf09a8,0x2bac00b8,0xdca60037,0x1a9a016b}},	//   ्रिय, _těch_, _لى_, קיװע,
   {{0xe0d016e6,0xdb0400d5,0x7bdc00b5,0x613d0260}},	//   ازه_, _luná, árul, _sèls,
   {{0x3984315b,0x290a004e,0x321f01a5,0x29180187}},	//   löst_, zeba_, _truy_, zdra_,
   {{0x63ae00ac,0xc8bf04bc,0xf8bf143a,0x1ddd00a1}},	//   _zubn, ्राट, ्राय, _मिळत,
   {{0x61e4a2d2,0x26d2a2d3,0x1c4514f8,0x853a0070}},	//   áile, zayo_, дном, ַגרי,
   {{0x63aea2d4,0xeb9a2bc4,0x6f099dda,0x26d21815}},	//   _xubn, жин_, peec, yayo_,
   {{0x290a08dd,0x29010341,0xe8c61371,0x3a2015ce}},	//   weba_, _abha_, वर्च, _prip_,
   {{0x657e03d0,0x7bd8073a,0x00000000,0x00000000}},	//   yoph, _evvu, --, --,
   {{0x26d22f38,0x200500d7,0xdb0400fd,0x9f4701cb}},	//   wayo_, _kpli_, _duná, duné_,
   {{0x26d23733,0x290a0232,0x29185ab1,0xdb040183}},	//   tayo_, reba_, rdra_, _euná,
   {{0x7bc1a2d5,0x290aa2d6,0x3a20a2d7,0x63ae012e}},	//   mplu, seba_, _trip_, _rubn,
   {{0x26d22107,0x6b840232,0x3a2000bf,0x63bca2d8}},	// [ba80] rayo_, _ikig, _urip_, _strn,
   {{0x26d20a25,0x61eba2d9,0xf5070043,0x70ac00ab}},	//   sayo_, dugl, мнул_, _चलेल,
   {{0xe73a519d,0x7bc15eb8,0x7f850132,0xa5bba2da}},	//   _ден_, nplu, lóqu, _próc,
   {{0x27e50038,0x657e52a5,0xd62a1ac5,0x61eb41d7}},	//   álne_, soph, _доме_, fugl,
   {{0x754900f5,0x61eb0069,0x2bac00b8,0x200500ec}},	//   ászó, gugl, _věci_, _apli_,
   {{0xa5bb0035,0x7bc14996,0x5183195c,0x00000000}},	//   _wróc, kplu, куща, --,
   {{0x63bc01a0,0x6b6400b5,0xa5bb0079,0x20050027}},	//   _utrn, zőga, _tróc, _cpli_,
   {{0x1e14290a,0x8e140948,0x48de018d,0xdfd001cb}},	//   емия, едиц, कृतो_, پيک_,
   {{0x753c295e,0x3ea201ff,0x6ce60044,0xf1b9023a}},	//   _korz, äkt_, міне, _trša_,
   {{0x6b844ab3,0xdb1ba2db,0xe2a60093,0xf1b90116}},	//   _akig, nstö, áðum_, _urša_,
   {{0x44440c3d,0x28bf04e9,0x753c2e2f,0x8c4303e6}},	//   ny_, ्रसि, _morz, веќе,
   {{0x44441325,0xa3e1238a,0x7afd8c84,0x6b960282}},	//   iy_, _दिस_, ufst, _chyg,
   {{0x4444086d,0xc3330bed,0x527b02b5,0x753c0120}},	//   hy_, דור_, ַנלא, _oorz,
   {{0x4444114d,0x753c00d7,0x6b840273,0x6e22a2dc}},	//   ky_, _norz, _ekig, _irob,
   {{0x80d30083,0xfe6d13cf,0x6e220187,0x7afd02b1}},	//   _সাম্, _نگی_, _hrob, pfst,
   {{0xf77014ac,0x7d181cdb,0xe7eb0066,0x00000000}},	//   لاق_, _havs, जूषा_, --,
   {{0x4444a2dd,0x753ca2de,0xddc90035,0xdb1b1e70}},	// [ba90] ey_, _borz, czeń, fstö,
   {{0x6d48a2df,0x7d1aa2e0,0x753c153c,0x4444a2e1}},	//   nkda, ndts, _corz, fy_,
   {{0x44442d95,0xa3c90006,0x79854f98,0x36d50086}},	//   gy_, लीं_, _ikhw, _понр,
   {{0x28bf166b,0x9f4701ba,0x6e22a2e2,0x163502fb}},	//   ्रवि, stnú_, _orob, _земя,
   {{0x753ca2e3,0x4444a2e4,0x7d18013c,0xda220066}},	//   _forz, ay_, _oavs, मियत_,
   {{0x444415b3,0x41e00026,0x7d182018,0x6f020392}},	//   by_, _निरस, _navs, _aboc,
   {{0x6286177c,0x224908c2,0x44440f6e,0x636b002d}},	//   _økon, šak_, cy_, _драг_,
   {{0xee390afd,0x6e22a2e5,0x61eb0036,0x673d1d87}},	//   зни_, _brob, pugl, _josj,
   {{0xe1f00df3,0x6e220088,0x673d03d0,0x00000000}},	//   _نسل_, _crob, _mosj, --,
   {{0x63a90086,0x31591d6c,0x29cd176d,0x6aada2e6}},	//   _hien, _علاج_, dža_, _agaf,
   {{0x63a9048c,0x6e22a2e7,0xdb040183,0x06ef0066}},	//   _kien, _erob, _junç, _छांव_,
   {{0x34cb3010,0x63a9003c,0x09e62c0f,0xf0921804}},	//   िरुद, _jien, номн, _גנב_,
   {{0x444405d1,0x63a9a2e8,0xdc3b068b,0x7bc1a2e9}},	//   zy_, _mien, _išče, splu,
   {{0x63a9a2ea,0x6f1b3dcc,0x7f850132,0x7bc10f8e}},	//   _lien, lduc, róqu, pplu,
   {{0x6e22006a,0x6b4625ec,0xb8d8007c,0x4423a2eb}},	//   _zrob, _lógi, _छल_, _nrj_,
   {{0x4444114d,0x63a9a2ec,0xe737606f,0x6f1b1116}},	//   vy_, _nien, нес_, nduc,
   {{0x44440755,0xb8f600c8,0x673da2ed,0x753ca2ee}},	// [baa0] wy_, _হা_, _dosj, _porz,
   {{0x649a0374,0x63a9a2ef,0xdce1010b,0x00000000}},	//   птер_, _aien, rolė, --,
   {{0x63a9a2f0,0xdb1ba2f1,0x44440c22,0x753c01ae}},	//   _bien, rstö, uy_, _vorz,
   {{0x4444900b,0x63a92de1,0x291a0657,0xdb1b87fa}},	//   ry_, _cien, _hapa_, sstö,
   {{0x44440c3d,0x63a9a2f2,0x291aa2f3,0x753c137e}},	//   sy_, _dien, _kapa_, _torz,
   {{0x444493e0,0xa5bb0bd2,0xdb040370,0x63a9a2f4}},	//   py_, _krón, _funç, _eien,
   {{0x63a93356,0x935a002d,0xa2c70099,0x40342bfc}},	//   _fien, _ерау_, ारख्, тейс,
   {{0x63a9a2f5,0x291a0029,0x7d182b69,0x6f19099e}},	//   _gien, _lapa_, _savs, _cawc,
   {{0x442302a7,0x52cc0577,0x00000000,0x00000000}},	//   _zrj_, ारीस, --, --,
   {{0x291a4a91,0x63a906a2,0xd24f004f,0x23660409}},	//   _napa_, _zien, _انك_, lioj_,
   {{0x6f1b751c,0x6d48a2f6,0x224600b5,0x69cd03bc}},	//   bduc, rkda, lyok_, _swae,
   {{0x6e22162d,0x59dc0084,0x63a9006d,0x2366005f}},	//   _trob, _बिखर, _xien, nioj_,
   {{0x291a0b0e,0x7d18a2f7,0x6e22016f,0x2246006c}},	//   _bapa_, _tavs, _urob, nyok_,
   {{0xa3e11033,0x291aa2f8,0x29cda2f9,0xa5bb0079}},	//   _दिल_, _capa_, rža_, _brón,
   {{0x673d0280,0xf7730bdf,0xa5bb0f56,0x1cb70317}},	//   _posj, هار_, _crón, _אלול_,
   {{0x7bdaa2fa,0x2d8c01ff,0x673d0031,0x478810b4}},	//   mstu, llde_, _qosj, есум_,
   {{0x7bdaa2fb,0x63a9a2fc,0x4423042a,0x8f9b00a5}},	// [bab0] lstu, _rien, _srj_, לילי,
   {{0x63a9a2fd,0x22462505,0x3b1b00a8,0xc6a4263b}},	//   _sien, dyok_, _haqq_, урси,
   {{0x9cd70052,0x6289012f,0x2d9ea2fe,0x9f5e0176}},	//   גובה_, _syeo, imte_, _optà_,
   {{0x7bdaa2ff,0x2366005f,0x2d9e02b1,0x490900b8}},	//   istu, gioj_, hmte_, ाजको_,
   {{0x63a9a300,0x213e0052,0x22460332,0x2374036b}},	//   _vien, _both_, gyok_, دالح,
   {{0x7bdaa301,0x26c933a6,0xa3cc0084,0x63a9a302}},	//   kstu, lbao_, _शौक_, _wien,
   {{0x63a9a303,0x3494036c,0x7f4901f4,0x213e51c7}},	//   _tien, _барр, tkeq, _doth_,
   {{0x2366004b,0x61e452eb,0x2d8c03c4,0x26c900cc}},	//   cioj_, šila, elde_, nbao_,
   {{0xc1150836,0xb11506c2,0x7bdaa304,0x2d9502d5}},	//   _имај, _имаш, estu, крос,
   {{0x6b46008e,0x7bda0173,0x63bb00cd,0xdca50fc5}},	//   _jógv, fstu, _čunj, капи,
   {{0x2ef5244e,0x7bdaa305,0xd011186e,0x1b1b0831}},	//   _азер, gstu, _خلا_, ধানে_,
   {{0x291a00d1,0x2d8ca306,0x2d9e000b,0x333f00f6}},	//   _sapa_, alde_, amte_, _joux_,
   {{0x291aa307,0x3b1b009f,0xf8bf022e,0x7bda0084}},	//   _papa_, _daqq_, ्रूप, astu,
   {{0x3f8da308,0xfce518c3,0x7bdaa309,0x23660409}},	//   lleu_, _роко, bstu, zioj_,
   {{0x5d7a0070,0x4879a30a,0x291aa30b,0x6d86003e}},	//   _קאצק, естя_, _vapa_, rðat,
   {{0x27e5016f,0x1fe30033,0xba26002d,0x291aa30c}},	//   álna_, _মহাস, _адик, _wapa_,
   {{0x07a30573,0xdcfa00ea,0x316712ff,0x1a9a016b}},	// [bac0] ратн, lotā, kinz_, _קיִע,
   {{0xa5bba30d,0x291a0211,0xfaff0051,0x00000000}},	//   _trón, _uapa_, niën_, --,
   {{0x66e61837,0x213e345d,0xdcfa00ea,0x00000000}},	//   _иона, _roth_, notā, --,
   {{0xf74694fc,0xa5bb0035,0xf53f008c,0x69c60051}},	//   _ремо, _król, _buås_, opke,
   {{0x6d86008d,0x2366004b,0x333f00f7,0x1dd10246}},	//   iðar, rioj_, _doux_, _दौलत,
   {{0x7bdaa30e,0x3f8609c7,0x2b406634,0xdcfa00ea}},	//   ystu, _skou_, _loic_, kotā,
   {{0xb5020c67,0x351b0122,0xdfd0004f,0xcf9a0370}},	//   र्णय_, _קולנ, حيب_, мји_,
   {{0x2d8792b3,0x7bda2981,0x6d8605ee,0xdcfa00ea}},	//   _akne_, vstu, yðas, dotā,
   {{0x7bda6120,0x00000000,0x00000000,0x00000000}},	//   wstu, --, --, --,
   {{0xfe6f02aa,0x80c1157d,0x569b016b,0x00000000}},	//   تدى_, रुदे, ויפצ, --,
   {{0x6fb6006c,0xc0a9004f,0x2d9e939d,0x7bdaa30f}},	//   _شمشا, _كامل_, rmte_, ustu,
   {{0x7bdaa310,0xd5e26017,0xe50219b7,0x6d860093}},	//   rstu, _पिंज, र्ति_, gðar,
   {{0x2904012e,0x9b58145f,0x9f4700a0,0xa5bb026e}},	//   đman_, тият_, ntný_, _cról,
   {{0x6d86008a,0x3f8400f2,0x3dc80033,0x929d0035}},	//   rðas, lomu_, _শিপল, _cały,
   {{0x58d40145,0x1b080083,0xed5703fa,0x26c90023}},	//   рост, ষয়ে_, _јој_, tbao_,
   {{0x34cb1d25,0x3f84a311,0x9f4700a0,0x5ba4010b}},	//   िर्द, nomu_, ktný_, _крыз,
   {{0x333f19d2,0x387a0160,0x80d80033,0x26c90207}},	// [bad0] _roux_, _expr_, _ঠান্, rbao_,
   {{0xeaaa02b5,0x69dd17ad,0x2d83011c,0x8af000a8}},	//   _אױפֿ, msse, čjeg_, _eləd,
   {{0x2911a312,0x69dd0d51,0x333f000d,0x31675cf7}},	//   meza_, lsse, _poux_, vinz_,
   {{0x29115d31,0xd4984168,0x52750043,0x69dd018d}},	//   leza_, тру_, лулу, osse,
   {{0x80ca0083,0x3f845dc5,0x69dda313,0x00000000}},	//   _রাজ্, domu_, nsse, --,
   {{0x29113d6d,0xd5fa0052,0x69dda314,0x98c6011c}},	//   neza_, _אפשר, isse, čući_,
   {{0x3f843998,0x61420340,0xd3a700ed,0x6d860093}},	//   fomu_, сеща, _арап, yðar,
   {{0x29114ab3,0x69dda315,0x3f8401cb,0x00000000}},	//   heza_, ksse, gomu_, --,
   {{0x29112176,0x69dd01e4,0x0d850421,0x1ea800e0}},	//   keza_, jsse, ллин, پايي_,
   {{0xdcfa0ae0,0x80ca7cde,0xf8bf0355,0x291125ea}},	//   totā, _स्पे, ्रोप, jeza_,
   {{0x69dd1bb3,0x3f840054,0x09be1cce,0x63b50207}},	//   esse, bomu_, ्ठ्य, _juzn,
   {{0x9f040987,0xa5bb33d7,0xdcfa00ea,0x00000000}},	//   _نومو, _pról, rotā, --,
   {{0xee2e09eb,0x6d8600fb,0x69dd19b2,0x69c6002f}},	//   _ун_, rðar, gsse, upke,
   {{0x291108e1,0x28a51e18,0xa5bb0312,0x00000000}},	//   geza_, _गृहि, _cróm, --,
   {{0x66e6a316,0x2d85018e,0x69dda317,0x63b50124}},	//   лова, mole_, asse, _nuzn,
   {{0x80ca0e1d,0x2d850562,0xfaff1e7e,0x00000000}},	//   _स्ने, lole_, niël_, --,
   {{0x2911a318,0xceb202b8,0x7ae40506,0x6db20067}},	// [bae0] beza_, מין_, _idit, _gład,
   {{0xb4c00380,0x2d850043,0x3f842e37,0x63b5a319}},	//   ीरे_, nole_, zomu_, _buzn,
   {{0x69c40024,0x78fb024b,0x00000000,0x00000000}},	//   _htie, _אליפ, --, --,
   {{0x69c4003c,0x63b5012e,0x80c100b4,0x00000000}},	//   _ktie, _duzn, रुसे, --,
   {{0x2d85a31a,0x61460dc8,0xdb040037,0x5ea90033}},	//   kole_, леда, _bunú, ছুতে,
   {{0xca7b0070,0x05b100be,0x00000000,0x00000000}},	//   ענסט, जदरब, --, --,
   {{0xa3e11ae9,0x7ae46dd7,0x9f470334,0x2d85a31b}},	//   _दिए_, _odit, stný_, dole_,
   {{0x20d800d8,0x7ae48a64,0xdb1901ba,0x2911010a}},	//   džių_, _ndit, _otvá, zeza_,
   {{0x80d300c8,0x70f6064e,0x63a2a31c,0xbd6aa31d}},	//   _সার্, _مسائ, mmon, ерне_,
   {{0x2d85a31e,0x7ae4a31f,0xc05a002d,0x551407b5}},	//   gole_, _adit, _прец_, ड़िए_,
   {{0x29110a78,0x4c948ddd,0x261400c0,0x69c4a320}},	//   veza_, ринс, नौती_, _atie,
   {{0x291187fe,0x69dd7b4f,0x69c4009f,0x5e2606ca}},	//   weza_, tsse, _btie, _معتق,
   {{0x2911a321,0x2d85a322,0x69dda323,0x5514046c}},	//   teza_, bole_, usse, ड़ाए_,
   {{0x2d857141,0x6e930ad9,0x63a2a324,0xb4c0046c}},	//   cole_, _الها, hmon, ीरो_,
   {{0x29118ef7,0x69c4a325,0x6db2004e,0x63a2a326}},	//   reza_, _etie, _wład, kmon,
   {{0x63a223cc,0xa6db008d,0x63b5a327,0x69c40069}},	//   jmon, _boða, _ruzn, _ftie,
   {{0x2911a328,0x63b500cd,0x61e40079,0x00000000}},	// [baf0] peza_, _suzn, áill, --,
   {{0x63a201c8,0x3a29a329,0x31b90260,0x7ae402a7}},	//   emon, _irap_, _rèz_, _zdit,
   {{0x3a290159,0x442706fc,0x6b460037,0x63a20afc}},	//   _hrap_, ín_, _tógt, fmon,
   {{0xd2510082,0x3a290a81,0x2bf70070,0x63a200b5}},	//   ينا_, _krap_, רמאן_, gmon,
   {{0xa3c900fa,0xe7040609,0x2d850b23,0xf1b937cb}},	//   लीज_, _اسپی, yole_, _krši_,
   {{0x98ba0080,0x63b5a32a,0x63a2a32b,0xe0450183}},	//   _kopā_, _tuzn, amon, инли,
   {{0x2d8501d3,0x2f55a32c,0xe9df0037,0x63a21ca7}},	//   vole_, итис, hsú_, bmon,
   {{0x2d85a32d,0xddc90035,0x6b46002a,0xa3ea060a}},	//   wole_, cześ, _lógr, _मित_,
   {{0x7bc40009,0x00e500d1,0x00000000,0x00000000}},	//   _čiua, _نتای, --, --,
   {{0xa5bb0453,0x1d090200,0x00000000,0x00000000}},	//   _prój, њени_, --, --,
   {{0x2d85a32e,0x66160035,0x3a29993f,0xeb9a0adb}},	//   role_, zwyk, _arap_, кио_,
   {{0x34b20b4a,0xcd3500b5,0x60d700ea,0xf1b9005f}},	//   _जल्द, ارکب, šamī, _arši_,
   {{0xed4e0185,0xde4600b5,0x3a290f00,0x69c40069}},	//   _до_, _نیٹو_, _crap_, _qtie,
   {{0xa5bb0035,0x3a29a32f,0x9ce700b5,0x79874583}},	//   _trój, _drap_, _صوبے_, gojw,
   {{0x6d43a330,0x7bc3a331,0x3a297623,0x613d0260}},	//   _iona, _utnu, _erap_, _bèlz,
   {{0x6d4306a2,0x70d1000c,0x7ae47e14,0x3a290260}},	//   _hona, हरुल, _udit, _frap_,
   {{0x6d430936,0x0566a332,0x6b460082,0x3a29a333}},	// [bb00] _kona, аван, _fógr, _grap_,
   {{0xa3e10035,0x89db00a5,0x63a20090,0xa6db008d}},	//   _दिख_, _שחיי, wmon, _voða,
   {{0xaaba0939,0x63a2a334,0x6d43a335,0xdd010355}},	//   _इलाक, tmon, _mona, _štěp,
   {{0xb226002d,0x63a2a336,0xa3e70421,0x3f5100ee}},	//   имел, umon, рдца_, _sáun_,
   {{0x70d1000c,0xf8da0066,0xddc90067,0x6d43081b}},	//   हरूल, _बजाय, rześ, _oona,
   {{0x26c0a337,0x29360070,0xf993016b,0x74163c96}},	//   lcio_, שאַן_, ֿרה_, _پورا,
   {{0xd0100037,0x63a20298,0x201a027a,0x00000000}},	//   سلة_, pmon, ìpi_, --,
   {{0x26c05420,0x6d431093,0x6e2d0129,0x9c821840}},	//   ncio_, _aona, _šaba, _účin,
   {{0x6d4305ca,0x26c0a338,0x6db20035,0x2cab00a8}},	//   _bona, icio_, _słab, əkdə_,
   {{0x6d430a24,0x5d5401b8,0x20b901c8,0x2b920187}},	//   _cona, скот, _быць_, lách_,
   {{0x34b70122,0x8cb70084,0x6d43a339,0x26c04cef}},	//   יפים_, ोड़ो, _dona, kcio_,
   {{0x2b92a33a,0x3a2901f4,0x00000000,0x00000000}},	//   nách_, _prap_, --, --,
   {{0x6d43a33b,0x4cd50083,0xee9400b5,0x00000000}},	//   _fona, _দারু, _اداک, --,
   {{0x6d4302d0,0x442a00ea,0xc98706c2,0x2b920187}},	//   _gona, _orb_, руми, hách_,
   {{0xf1b90bec,0x8ccc0246,0x2b92024e,0xe79501df}},	//   _vrši_, _द्यो, kách_, مارک,
   {{0x442d39ea,0x6d43a33c,0xf7730172,0x3a290f00}},	//   _če_, _zona, زاز_, _trap_,
   {{0x61e4068b,0x442aa33d,0x6d43a33e,0x2b921df9}},	// [bb10] šilj, _arb_, _yona, dách_,
   {{0xe7ef0084,0x3dc6012f,0x443a00de,0xa2c906d9}},	//   _छिपा_, _mtow_, fxp_, हुन्,
   {{0xdcf801c0,0x320da33f,0x442a36a6,0x00000000}},	//   _skvě, _spey_, _crb_, --,
   {{0x26c0a340,0x925900c3,0x2b9200ac,0x7c2a023c}},	//   ccio_, лает_, gách_, _mrfr,
   {{0x6d5a42eb,0x442a0078,0x998002c4,0x3ebf027d}},	//   khta, _erb_, _hriš_, vcut_,
   {{0x45d40a46,0x442a0a8a,0xf4350043,0x661d4ba9}},	//   _форс, _frb_, _легэ, _issk,
   {{0x442aa341,0x4425a342,0x3f69a343,0x26d9a344}},	//   _grb_, _él_, лико_, _keso_,
   {{0xef193810,0x7c25008a,0x3cfc0345,0x187800a5}},	//   уми_, _áhri, _acvv_, יעור_,
   {{0x26d90a18,0x764d494f,0xa5bb0079,0x491800b4}},	//   _meso_, nyay, _brói, _फसलो_,
   {{0x98780129,0x3ebf4bcc,0x6b8d595c,0x6d430095}},	//   _ušća_, scut_, _akag, _qona,
   {{0x6d43a345,0x40950082,0x6db2004e,0x2b920097}},	//   _vona, _الار, _płac, láci_,
   {{0x26d901ef,0xa3ea0af9,0x6d4302b1,0x6b560424}},	//   _neso_, _मिस_, _wona, стох,
   {{0x5ea50083,0x42790070,0xc3320122,0x7c2a033b}},	//   _গ্রে, ראָג, פוך_, _erfr,
   {{0x6d5a02aa,0x2c5700a8,0x7c3a0051,0xdb19021d}},	//   chta, hədə_, bxtr, _juvê,
   {{0x26d9a346,0x2c570095,0x25b9027a,0x00000000}},	//   _beso_, kədə_, _ausl_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6443022a,0xf7430370,0x2b92024e,0x764da347}},	// [bb20] änin, чето, vách_, gyay,
   {{0x26c00bff,0x442a8486,0xd91000b5,0x2b9200ac}},	//   scio_, _prb_, _تیس_, dáci_,
   {{0x26c02c90,0x2b92024e,0xa2aa00c0,0x59be0084}},	//   pcio_, tách_, जेन्, _एंडर,
   {{0xd0480095,0x764d01d5,0xe73a440d,0x2bb700af}},	//   _gedə, byay, _сем_, _căci_,
   {{0x2b92024e,0x442a012f,0x672400f4,0x764d309e}},	//   rách_, _wrb_, mdij, cyay,
   {{0x64a628d7,0xdb0b033b,0x6724a348,0xfd070d93}},	//   _гага, _zufä, ldij, _عج_,
   {{0x3dc63889,0x442aa349,0x26d9a34a,0x80d90785}},	//   _stow_, _urb_, _yeso_, _नजरे,
   {{0xc7b30122,0x2c570095,0x6604a34b,0x3f510093}},	//   הבה_, cədə_, otik, _fáum_,
   {{0x6604a34c,0xa5bb004f,0x03a30ea0,0x50d600d1}},	//   ntik, _prói, _хито, _هزار,
   {{0x50cf065f,0x6b8d23f5,0x6604777a,0x67240009}},	//   _स्पष, _skag, itik, hdij,
   {{0x69b20f8a,0x66040086,0x61e2a34d,0x9743011c}},	//   _इंजी, htik, lsol, šćiv,
   {{0x6d5aa34e,0x201ea34f,0x60daa350,0x61e200be}},	//   shta, _isti_, _hetm, osol,
   {{0x4e9618dd,0x26d90382,0x539b0070,0xdc180035}},	//   _اشار, _reso_, טיטו, dłąc,
   {{0x67240051,0x60da27d8,0x6ab600b5,0x2c57013b}},	//   edij, _jetm, _egyf, zədə_,
   {{0x2c5700a8,0x6604a351,0x776d002a,0x00000000}},	//   yədə_, etik, tiax, --,
   {{0xd6d8311c,0x6b8d16fe,0xc7b800c7,0x764d273b}},	//   йту_, _ukag, сёр_, tyay,
   {{0xf770211b,0x6604043d,0x26d90359,0x8cbf06fe}},	// [bb30] راف_, gtik, _veso_, लुको,
   {{0x61e2a352,0x2b920237,0x201ea353,0x764d63fc}},	//   dsol, váci_, _osti_, ryay,
   {{0x67242997,0x61e2a354,0xf9940d85,0x26d94ce3}},	//   bdij, esol, _מרץ_, _teso_,
   {{0x6604011e,0xdb19013c,0x59d00bdd,0xf1b9023a}},	//   btik, _utvä, तीकर, _puš_,
   {{0x4cde0b52,0x2c5701c2,0x6d580332,0x60daa355}},	//   _মানু, rədə_, _olva, _betm,
   {{0x6e2d0009,0x2c5700a8,0xa2c900b4,0x2b9200ac}},	//   _šabo, sədə_, _ह्र्, ráci_,
   {{0x5edd0033,0x7f9e0031,0xdc3b0207,0x60daa356}},	//   _যাবে, zëqe, _išće, _detm,
   {{0x6d58a357,0x61e2a358,0xf1b9008b,0x7c2802d7}},	//   _alva, bsol, _tuš_, dvdr,
   {{0x201e6bbe,0x9f5c000c,0x80ca0d34,0x60da8f14}},	//   _esti_, ctví_, _स्वे, _fetm,
   {{0x60da0095,0x80d30083,0x67244e37,0xbc840023}},	//   _getm, _সাক্, zdij, ườn,
   {{0xca295c8e,0x6604a359,0x69d60345,0x00000000}},	//   _שם_, ztik, _swye, --,
   {{0x6d5803d0,0x60da0051,0x7f9e0055,0x66042dbe}},	//   _elva, _zetm, tëqe, ytik,
   {{0x8d7400d1,0xfce5081e,0x60da0448,0xeab22ac4}},	//   _کانا, _доло, _yetm, بعد_,
   {{0xa3ea27bd,0x6604008b,0x61e40079,0x7f9e0055}},	//   _मिल_, vtik, áili, rëqe,
   {{0x1b0f00c8,0x6e2911cb,0xbb460183,0xdb190359}},	//   িয়ে_, lveb, _мекк, _ouvè,
   {{0x6604a35a,0x61e43426,0x236f0031,0x6f0968db}},	//   ttik, šili, jigj_, nfec,
   {{0x88d90033,0x00000000,0x00000000,0x00000000}},	// [bb40] _তারক, --, --, --,
   {{0x3a2027f9,0xd6cf00fd,0x00000000,0x00000000}},	//   _isip_, فقہ_, --, --,
   {{0x032653b7,0x6e2d06e2,0x291816a3,0xf7462351}},	//   жден, _šabl, mera_, _дено,
   {{0x291833a8,0x60da0955,0x61e26695,0x95c60312}},	//   lera_, _setm, tsol, _ويجه,
   {{0x9c7c0528,0x61e2a35b,0x26d2a35c,0x60da00b9}},	//   mače, usol, mbyo_, _petm,
   {{0x2918a35d,0xe4da0d4f,0x61e2a35e,0x9c7c02a7}},	//   nera_, _خوست_, rsol, lače,
   {{0x6f09a35f,0x2918a360,0x60da00da,0xd8d70070}},	//   ffec, iera_, _vetm, קוקט_,
   {{0x9c7c15d8,0x29182d9a,0x61e2a361,0x61ed64e1}},	//   nače, hera_, psol, šala,
   {{0x2918a362,0x63bc0a2d,0x00000000,0x00000000}},	//   kera_, _hurn, --, --,
   {{0xa06a01d3,0x29182f6e,0x0caa0de3,0x6f0901ef}},	//   _каза_, jera_, итни_, afec,
   {{0x63bca363,0x9c7c01a0,0x201e117c,0x00000000}},	//   _jurn, kače, _usti_, --,
   {{0x63bc272d,0xa5bb004e,0x9c7c03ab,0xfbcf0105}},	//   _murn, _krót, jače, کتی_,
   {{0x32060159,0x9c7c0690,0xfd7900b5,0xda220266}},	//   ntoy_, dače, ششیں_, मिगत_,
   {{0x2918a364,0x09bd0033,0x63bc00f6,0xe6d302b4}},	//   gera_, _অবদা, _ourn, तर्ज,
   {{0xd6db010e,0xa8991c4d,0x36d52b60,0xa2aa01d1}},	//   ита_, скву_, зобр, जेत्,
   {{0x27ed2d72,0x76b907fa,0x9c7c03ab,0x2d8ca365}},	//   čen_, слар_, gače, lode_,
   {{0x29183782,0xe4cb00d2,0xe81d007c,0x63bc01ed}},	// [bb50] bera_, لبان_, _पनवा_, _aurn,
   {{0x2918a366,0x2d8ca367,0xd7fb0012,0xa5bb20d9}},	//   cera_, node_, _кум_, _asóc,
   {{0x9c7c0254,0x29010118,0x69cfa368,0xf77000b5}},	//   bače, _icha_, lpce, راہ_,
   {{0x2d8c0770,0x63bca369,0xe3b80210,0x290101ed}},	//   hode_, _durn, ібі_, _hcha_,
   {{0x2d8ca36a,0x33240069,0x7afda36b,0xdb1900a2}},	//   kode_, _damx_, igst, _cuvé,
   {{0xe8b900b1,0x63bc95c0,0x88d90033,0x7bca0207}},	//   _आलोच, _furn, _তাঁক, _otfu,
   {{0x63bca36c,0xb4d70325,0xa5bb4469,0x290108c7}},	//   _gurn, सरी_, _erót, _mcha_,
   {{0xd00e317b,0x2918a36d,0x636863f5,0x2b920355}},	//   الي_, zera_, _друг_, náct_,
   {{0x236d1d11,0x6f091116,0x5edd0083,0xb0cf0567}},	//   _imej_, rfec, _যাদে, _स्थग,
   {{0x2901a36e,0x2d8c3b09,0x6f0999d5,0x9c7c201d}},	//   _ncha_, gode_, sfec, zače,
   {{0x2b49046a,0x317a02b5,0xab2a0369,0x3156016b}},	//   _boac_, _פרעמ, бона_, _ציען_,
   {{0xe50b23e3,0x2901a36f,0xe45602b5,0x2918a370}},	//   स्ति_, _acha_, פירט_, wera_,
   {{0x2d8c01a0,0x9c7c1c1a,0x442600e2,0xa924031d}},	//   bode_, vače, ̉o_, ížov,
   {{0x27f80122,0x7afd03c4,0x29180065,0x41dd06fe}},	//   turn_, agst, uera_, नीयस,
   {{0x2918a371,0x200708a5,0x9c7c0d5c,0x29017979}},	//   rera_, ntni_, tače, _dcha_,
   {{0x29189f12,0x63baa372,0x2901a373,0x32060159}},	//   sera_, _étni, _echa_, ytoy_,
   {{0x63bca374,0x9c7c05e2,0x26d2011e,0xe4d60037}},	// [bb60] _surn, rače, rbyo_, كتاب,
   {{0x2007068b,0x63bc08eb,0x33240221,0x27f80093}},	//   ktni_, _purn, _samx_, purn_,
   {{0x9c7c03c9,0x320600d7,0xa5bb05ee,0xf99300a5}},	//   pače, wtoy_, _brós, _ארז_,
   {{0xa5bba375,0x2d8c00cd,0x09230033,0x00000000}},	//   _prót, zode_, মাণু_, --,
   {{0x200500d7,0x61ed03ab,0x20070228,0x0cdb0387}},	//   _aqli_, šaln, etni_, _मजूम,
   {{0xf8be00c0,0x20070693,0x00000000,0x00000000}},	//   ्डिय, ftni_, --, --,
   {{0x2d8c0af1,0x35a300d8,0x21250176,0xb4c800dc}},	//   vode_, _чарг, _dalh_, ईडी_,
   {{0x6449037a,0x3d0e00b8,0x547b00a5,0x6726008c}},	//   çmiş, त्ने_, _הטלו, _jakj,
   {{0x798e0232,0x67260118,0x00000000,0x00000000}},	//   kobw, _makj, --, --,
   {{0x7c860954,0x2cb80185,0xdb190139,0x67260987}},	//   зуме, ørd_, _cuvî, _lakj,
   {{0xdeef002d,0xbae10033,0x8af000a8,0xd00f00f8}},	//   _пы_, _ভাবছ, _eləm, _ملل_,
   {{0x8ccc0026,0x29010211,0x2d8ca376,0x7afda377}},	//   _द्रो, _scha_, sode_, ugst,
   {{0xdb040019,0x60cb00b5,0x2606021d,0x00000000}},	//   _khiê, _élmé, jôo_, --,
   {{0x6e22a378,0x6726008c,0x3c58002d,0xb69b0160}},	//   _isob, _aakj, _милэ_, _obâr,
   {{0x7d1aa379,0xd90f00bf,0x672602a2,0x80e10033}},	//   mets, نیک_, _bakj, _নাম্,
   {{0x656e0118,0x95d902fb,0x6d4a0210,0x3cfe08c7}},	//   _ambh, ждат_, _hofa, lgtv_,
   {{0x7aed0291,0xf1d700c8,0x59b70fd1,0x6d4a0527}},	// [bb70] _idat, _সম্ভ, _इंटर, _kofa,
   {{0xb4d70325,0xdb040028,0x7d1a127e,0xecda0083}},	//   सरे_, _nhiê, nets, _দাঁড,
   {{0xa5bba37a,0x9cd700a5,0x3d0e01d1,0xbb1b00a2}},	//   _prós, פואה_, त्ये_, boît,
   {{0x7d1aa37b,0xfaff01f4,0x27e501ba,0x6d4aa37c}},	//   hets, ngë_, álnu_, _lofa,
   {{0x7d1aa37d,0x6e22313a,0x00000000,0x00000000}},	//   kets, _nsob, --, --,
   {{0x7d1a0280,0xd24e0312,0xdb0401a5,0x67266b02}},	//   jets, شنى_, _chiê, _zakj,
   {{0x7aeda37e,0x6e222107,0x90e400f3,0x00000000}},	//   _odat, _asob, رسون, --,
   {{0x0dc90f22,0x3eb90c71,0x20070169,0x2d8304c3}},	//   олий_, øst_, rtni_, čjem_,
   {{0x6adc00c8,0x61e40082,0x7527055f,0x2007a37f}},	//   _ভালো, áilt, _kajz, stni_,
   {{0x7aeda380,0xa2c9193c,0x7d1a0232,0x6ecd09b1}},	//   _adat, हुर्, gets, _ध्रु,
   {{0x69cda381,0x6e22018e,0x7527023a,0x00000000}},	//   _atae, _esob, _majz, --,
   {{0x61e94601,0x2b9200b5,0x443102b1,0x4423a382}},	//   _kvel, vács_, _mrz_, _msj_,
   {{0x7d1a6efe,0x7aed0297,0x6d4a0183,0x6db20067}},	//   bets, _ddat, _fofa, _złam,
   {{0x6d4a0297,0x75270af1,0x7aeda383,0x6f1b5270}},	//   _gofa, _najz, _edat, leuc,
   {{0x672602a2,0x7aed009f,0x00000000,0x00000000}},	//   _pakj, _fdat, --, --,
   {{0x61e94a37,0xd70a00d8,0x2b050067,0x798e01d5}},	//   _ovel, ўнае_, _वायु_, sobw,
   {{0xa52602ee,0x9c7c0124,0x752700ee,0x44310225}},	// [bb80] ммад, mača, _bajz, _arz_,
   {{0x4423028b,0x4431011c,0x9c7c0169,0xa5bb1bea}},	//   _bsj_, _brz_, lača, _prór,
   {{0x61e93945,0x67260088,0x00000000,0x00000000}},	//   _avel, _takj, --, --,
   {{0x9c7c3b12,0x65c62365,0x7d1aa384,0xa2c90ea3}},	//   nača, _обма, zets, हुल्,
   {{0xa3de0953,0xdb040028,0x4cde0033,0x61e9080a}},	//   _दौर_, _phiê, _মাসু, _cvel,
   {{0x75270009,0x6f02557f,0x7d0302a7,0x00000000}},	//   _gajz, _scoc, _ncns, --,
   {{0xd5ad006c,0x4431027a,0x7d1aa385,0x6f1b02b1}},	//   _اہل_, _grz_, vets, feuc,
   {{0x6d4aa386,0x9c7c10ec,0x7d1a0345,0x64a3a387}},	//   _sofa, jača, wets, _раса,
   {{0x7d1a04ca,0xdb040028,0xb0cf0099,0x9c7c00cd}},	//   tets, _thiê, _स्वग, dača,
   {{0x657e0037,0xab640035,0x7aed03d0,0x00000000}},	//   nnph, óżni, _sdat, --,
   {{0x7d1aa388,0xcf8f2123,0x69cd5133,0xdb160359}},	//   rets, _ај_, _stae, _kiyè,
   {{0xee3a47ec,0x7d1aa389,0x61e900f7,0x9c7c05e2}},	//   _мне_, sets, _yvel, gača,
   {{0xf2d300c2,0x6d4a0657,0x5eac0083,0x7d1aa38a}},	//   כער_, _tofa, _ট্রে, pets,
   {{0x9f4e0079,0x3a32008c,0xf1b80024,0x00000000}},	//   irfí_, _dryp_, _jiġ_, --,
   {{0x9c7c011c,0xa3ea0026,0x752700b5,0x3f580118}},	//   bača, _मिग_, _rajz, _léum_,
   {{0xb4d700a1,0x7aeda38b,0x25b8009e,0x99890139}},	//   सर्_, _udat, _airl_, _braţ_,
   {{0xf8d007df,0x3a32053e,0x69cd002f,0x44310e31}},	// [bb90] _त्वय, _gryp_, _utae, _srz_,
   {{0xd49b2462,0xc7c70f08,0x15f30099,0x61e90069}},	//   оре_, _осми, ेंबर_, _rvel,
   {{0xf4850164,0x752700da,0x61e9a38c,0xdb1600f8}},	//   رائی, _vajz, _svel, _biyè,
   {{0x3d0e27c6,0x44230009,0x25b802d7,0xb86601cb}},	//   त्ते_, _vsj_, _eirl_, _ساپو,
   {{0xe5c400c3,0xeb920070,0x44310035,0x44230147}},	//   _ассо, אָג_, _wrz_, _wsj_,
   {{0xa0a51682,0x25b8a38d,0xe8e00019,0x4423a38e}},	//   налд, _girl_, _kiều_, _tsj_,
   {{0x1fb50948,0x4423028b,0xdb160107,0xd00e0413}},	//   нсир, _usj_, _fiyè, ملو_,
   {{0x26c90183,0xa29500d8,0x50cf0edf,0x61e90044}},	//   ncao_, _забі, _स्रष, _tvel,
   {{0x61e902dd,0xfce53f6c,0xe8e00023,0x80ca0efa}},	//   _uvel, нопо, _liều_, _स्के,
   {{0x653a02b5,0x7d090274,0x1c4501e0,0x7c230065}},	//   ִערד, чног_, еном, _psnr,
   {{0xeb9a1346,0x9c7c0c99,0x15f30035,0xab2aa38f}},	//   зин_, tača, ेंडर_, пона_,
   {{0xa2b50517,0x00000000,0x00000000,0x00000000}},	//   ेशप्, --, --, --,
   {{0x9c7c04c3,0xb69b0395,0x00000000,0x00000000}},	//   rača, _scân, --, --,
   {{0x9c7c07fc,0xdb19002d,0x00000000,0x00000000}},	//   mačn, _cuvâ, --, --,
   {{0x2bc62177,0x9c7ca390,0xfbc6000c,0x7b9601e0}},	//   _रूपा, lačn, _रूपम, _приї,
   {{0x28d0a391,0xa5bb0370,0xf8d00b35,0xe8e000e2}},	//   _त्रि, _próp, _त्रय, _diều_,
   {{0x9c7c01cc,0x61ed0a78,0x7ae6a392,0x24f62a5c}},	// [bba0] načn, šalj, makt, ечер,
   {{0xa2b504bc,0x6aa40371,0x26c90183,0x00000000}},	//   ेशन्, _izif, acao_, --,
   {{0x66e61878,0xa3db00a1,0xed56016b,0x6b84023a}},	//   _пона, ढील_, עבער_, _kjig,
   {{0x9c7c024e,0xa5bb0987,0x26c953c5,0xa6db003e}},	//   kačn, _tróp, ccao_, _boðu,
   {{0x9c7c02f6,0x00000000,0x00000000,0x00000000}},	//   jačn, --, --, --,
   {{0x6fc701d6,0x6b84012e,0x7ae6a393,0x998900f4}},	//   _sıca, _ljig, hakt, _kraš_,
   {{0x64a3a394,0x7ae6a395,0xa3ea0066,0xb4dc0b4d}},	//   _бара, kakt, _मिट_, ठरी_,
   {{0x4444035f,0x23271b70,0x28d0022e,0x6b84001c}},	//   mx_, _поси_, तुति, _njig,
   {{0x7ae6a396,0x4444a397,0x9c7c3e39,0x6aa42574}},	//   dakt, lx_, gačn, _nzif,
   {{0xc0aa1015,0x4444a398,0x916200e2,0x5d545b66}},	//   _فاضل_, ox_, _dự_, ткот,
   {{0x7ae6a399,0x4444a39a,0x3e76008c,0x20b9010b}},	//   fakt, nx_, _bøtø_, _жыць_,
   {{0x4444a39b,0xdd2f0355,0x00000000,0x00000000}},	//   ix_, _měři, --, --,
   {{0xc33302b8,0xf99f02e9,0xa3e700c0,0x29c6021d}},	//   אור_, stèm_, _मौन_, _côa_,
   {{0x2b8406d3,0x4444035f,0xd90f0647,0x2905018d}},	//   rıca_, kx_, حید_, üla_,
   {{0x97a71c46,0x6aa4001c,0x7b0600c3,0x9c7c00ac}},	//   ерал, _ezif, ättö, mačo,
   {{0x7ae60723,0x4444035f,0x6d5aa39c,0x7c9b0319}},	//   cakt, dx_, lkta, _משוג,
   {{0x4444035f,0x80e10033,0x26c90207,0x00000000}},	// [bbb0] ex_, _নাস্, rcao_, --,
   {{0x6d5aa39d,0x444429a2,0x6b9d6c85,0x9c7c0187}},	//   nkta, fx_, llsg, načo,
   {{0x9c7c024e,0xa5bb01dd,0x44440024,0x2bc60066}},	//   začn, _isóm, gx_, _रूमा,
   {{0x68e7006c,0x5275002d,0x29032129,0x9327132d}},	//   lajd, кулу, lgja_, عران,
   {{0x22580086,0x9c7c0187,0x673d017b,0x00000000}},	//   ницы_, xačn, _insj, --,
   {{0x865a02da,0x660d3ee0,0x2903a39e,0x7ae62c5b}},	//   _חדשי, mtak, ngja_, zakt,
   {{0xe8e00028,0x660da39f,0x7ae600d4,0x91620023}},	//   _hiểu_, ltak, yakt, _sự_,
   {{0x672da3a0,0x9c7c0097,0xee391a56,0xe8e001a5}},	//   ndaj, tačn, дни_, _kiểu_,
   {{0x0d852d38,0x7ae6a3a1,0x3384440d,0x63a901d5}},	//   клин, vakt, _сурв, _ihen,
   {{0x9c7ca3a2,0x7ae60f1a,0xb274170e,0x41b50148}},	//   račn, wakt, _слуш, _شمار,
   {{0x80ca3933,0x63bb0054,0x660d748a,0x9c7c01ba}},	//   _स्टे, _kiun, htak, sačn,
   {{0x9c7c129f,0x628c0035,0x63bb002f,0x256400b5}},	//   pačn, żnoś, _jiun, _zöld_,
   {{0x63bb0054,0xa5bb01ef,0x63a900e9,0x1d090274}},	//   _miun, _asóm, _mhen, _жели_,
   {{0x7ae631dd,0x29032129,0x673d007a,0x63bb8d75}},	//   sakt, ggja_, _ansj, _liun,
   {{0x660d0291,0x7ae6a3a3,0x59be073f,0x63a90328}},	//   etak, pakt, _एंकर, _ohen,
   {{0x660da3a4,0xe8e00028,0x69df0176,0x00000000}},	//   ftak, _biểu_, _fwqe, --,
   {{0x7bc35881,0x7e6901ae,0x3d0e022e,0x7ae4001e}},	// [bbc0] _hunu, nzep, त्वे_, _ieit,
   {{0x7ae4a3a5,0x63a9198e,0x7bc3000e,0x4444a3a6}},	//   _heit, _ahen, _kunu, tx_,
   {{0x4444105d,0x99802163,0x7bc30c6f,0x6289002a}},	//   ux_, _križ_, _junu, _axeo,
   {{0x4444a3a7,0x7bc3a3a8,0x63a9a3a9,0x69c41c5a}},	//   rx_, _munu, _chen, _kuie,
   {{0x7ae4a3aa,0x63a924cf,0x63bb54d2,0x7bc32af6}},	//   _meit, _dhen, _diun, _lunu,
   {{0x7ae42caa,0x69c40139,0x23a700be,0xae1c00be}},	//   _leit, _muie, võje_, _बैगन_,
   {{0x7bc3a3ab,0x63bb009e,0x9c7c148a,0xfbc71c64}},	//   _nunu, _fiun, vačo, _خت_,
   {{0x63bba3ac,0x63a95ee5,0x03a66435,0x7ae4a3ad}},	//   _giun, _ghen, _рибо, _neit,
   {{0xf7730052,0x9c7c024e,0x2366006d,0x3da638ea}},	//   יקה_, tačo, mhoj_, кроб,
   {{0x7bc3a3ae,0x6d48006d,0x00000000,0x00000000}},	//   _bunu, ujda, --, --,
   {{0x7ae40446,0x68e702c4,0x99800009,0xaf062bb4}},	//   _beit, vajd, _briž_, _апел,
   {{0x7ae40094,0x3f8001c8,0xbf13006c,0x7bc300f8}},	//   _ceit, čius_, _نومب, _dunu,
   {{0x3ea00082,0x7ae4a3af,0x7e690035,0x660d013b}},	//   _áit_, _deit, czep, xtak,
   {{0xbea3178e,0x7bc33a96,0x69c401f7,0x224601ed}},	//   _тачк, _funu, _duie, ixok_,
   {{0x7ae4a3b0,0x7bc30452,0x212c01d2,0x2903a3b1}},	//   _feit, _gunu, _madh_, rgja_,
   {{0x2d9ea3b2,0x61eda3b3,0x3d0e00a1,0xdb0b01f7}},	//   llte_, šali, त्रे_, _eufò,
   {{0x63bb02fb,0x63a9a3b4,0x69c40443,0x672da3b5}},	// [bbd0] _riun, _rhen, _guie, rdaj,
   {{0x63bb1db7,0x7ae402bf,0x63a9a3b6,0x212ca3b7}},	//   _siun, _zeit, _shen, _nadh_,
   {{0x2d9e0094,0x63a99d67,0x660da3b8,0xd49b2d7a}},	//   ilte_, _phen, stak, фра_,
   {{0x7ae41a71,0x660d5112,0xe8e001a5,0x4ae30e61}},	//   _xeit, ptak, _tiểu_, परिव,
   {{0x63bb000e,0x212c026e,0x61e00090,0x644501e9}},	//   _viun, _badh_, _cwml, sxhi,
   {{0x3495578a,0x3f860359,0x212c0211,0x63a917f4}},	//   _багр, _ajou_, _cadh_, _when,
   {{0xd4983cab,0x68e5a3b9,0x212c01da,0xf07500b5}},	//   _арт_, _mehd, _dadh_, دیاں_,
   {{0x68e50086,0x7bc3a3ba,0xd1050d2a,0x2d5b0132}},	//   _lehd, _runu, _रावण_, _vêem_,
   {{0xa3e71db6,0x7bc3a3bb,0x79950010,0x3f860298}},	//   _मौत_, _sunu, kozw, _djou_,
   {{0x7ae4a3bc,0x7bc3a3bd,0x69c4623c,0x00000000}},	//   _seit, _punu, _ruie, --,
   {{0x7ae44ab4,0x7bc3a3be,0x3b0a10a4,0x69c40160}},	//   _peit, _qunu, нено_, _suie,
   {{0xa2aa0518,0x69c4a3bf,0x00000000,0x00000000}},	//   जेक्, _puie, --, --,
   {{0x7ae4008a,0x69c4a3c0,0xe8e00023,0x9c7c0c99}},	//   _veit, _quie, _liễu_, načj,
   {{0x7ae4a3c1,0xfce554d6,0x7bc3a3c2,0xdb1901b4}},	//   _weit, _соко, _tunu, _nuvæ,
   {{0x7ae40297,0x00000000,0x00000000,0x00000000}},	//   _teit, --, --, --,
   {{0xfbd202b8,0x0f210066,0x2fc50160,0x332d00ee}},	//   _פתח_, _मसोस_, _mulg_, _naex_,
   {{0x366735ba,0x2b400009,0x59be0026,0x79950371}},	// [bbe0] гато_, _inic_, _एंटर, bozw,
   {{0x04460573,0xe8e0055c,0x00000000,0x00000000}},	//   лезн, _biễu_, --, --,
   {{0x98a80311,0x212c00f1,0xf8a897c4,0x00000000}},	//   _गरिए, _radh_, _गरिय, --,
   {{0xb8271303,0xe8e000e2,0xf7460183,0x25e80127}},	//   _союз_, _diễu_, _семо, _चौथी_,
   {{0x5b7b02b5,0xa2c600e7,0x00000000,0x00000000}},	//   ערנא, िशब्, --, --,
   {{0xa5bb0042,0x29360070,0x23660031,0x98a801c0}},	//   _apóf, ראַן_, shoj_, _गराए,
   {{0xfaff01f4,0x60c100d7,0x00000000,0x00000000}},	//   dhën_, _dglm, --, --,
   {{0x442a30bc,0x9f54326e,0x752ea3c3,0x00000000}},	//   _isb_, рвич, _habz, --,
   {{0x6ce62286,0x998901ba,0x442a535e,0x00000000}},	//   ліне, _hrať_, _hsb_, --,
   {{0x98ba0107,0x752e0069,0x621b016b,0x2fc50139}},	//   _anpč_, _jabz, _אומק, _fulg_,
   {{0x9c7c01cc,0xe7b40826,0x2cb8013c,0x55970070}},	//   mačk, ंगाप, ärd_, רדיע_,
   {{0x442a1f4e,0xda3541e4,0x2b40021d,0x26c200f8}},	//   _msb_, аемы, _cnic_, _ngko_,
   {{0x442a5a67,0x629e004e,0x79950848,0xce3400e0}},	//   _lsb_, ępow, tozw, _خوشک,
   {{0x4438a3c4,0x9c7c0a78,0xceb30317,0x442a1769}},	//   _orr_, načk, _פיס_, _osb_,
   {{0xd7f8002d,0x442a43c1,0x37ab27eb,0x58d401f5}},	//   лут_, _nsb_, етан_, сост,
   {{0x9c7c1075,0xf40a0083,0x7c2aa3c5,0x387e00a0}},	//   hačk, রবার_, _isfr, útra_,
   {{0x68e5a3c6,0x9c7c0d5c,0x442aa3c7,0x3a2900a7}},	// [bbf0] _tehd, kačk, _asb_, _usap_,
   {{0x04670009,0x9c7c3ce5,0x442a8486,0x998900a0}},	//   лтем, jačk, _bsb_, _brať_,
   {{0x9c7c00ac,0xa2d50413,0x824b0fa2,0x44380027}},	//   dačk, ليات, کشاف_, _crr_,
   {{0x4911021a,0x3dda0033,0x603c0139,0x9f4500ee}},	//   द्रो_, _দিনল, _mămă, _ovlá_,
   {{0x81c70080,0x442a0093,0x39410223,0x3a380070}},	//   klēš, _esb_, _knhs_, ָרום_,
   {{0x9c7ca3c8,0x2fc50453,0x44380160,0xb42500b5}},	//   račj, _pulg_, _frr_, _پٹرو,
   {{0xa15603fa,0xf8b50066,0xdfce1c14,0x00000000}},	//   рају_, ंधिय, ويو_, --,
   {{0xbe3901e0,0x00000000,0x00000000,0x00000000}},	//   вчої_, --, --, --,
   {{0x9c7c0470,0x3eb906fb,0x62349c30,0x672f01e9}},	//   bačk, äst_, _лету, _macj,
   {{0x8d55527e,0x3f84046a,0xed590036,0x9c7c00cd}},	//   ртич, anmu_, тоо_, cačk,
   {{0xdca592b9,0xcb6a0021,0xe8e00028,0x603c0139}},	//   рани, ване_, _hiệu_, _cămă,
   {{0x661da3c9,0xfaff00da,0x61ed1813,0xe8e000e2}},	//   _opsk, shën_, šalu, _kiệu_,
   {{0x6db2004e,0x7c2aa3ca,0xe7e802b4,0x00000000}},	//   _płat, _esfr, टीना_, --,
   {{0x39410107,0xa5bb219d,0x2d8700f4,0x00000000}},	//   _cnhs_, _eróz, _ujne_, --,
   {{0xb8ce1b6a,0xe8e00028,0x661d3caa,0xe7e1052f}},	//   _और_, _liệu_, _apsk, गीला_,
   {{0x2b40a3cb,0x92e70033,0x3ce70a8a,0x00000000}},	//   _unic_, পলু_, _henv_, --,

   {{0x442a0210,0xc4e600c3,0xe8e000e2,0x4438a3cc}},	// [bc00] _ssb_, ижай, _niệu_, _srr_,
   {{0x752e93af,0x442a0183,0x845a3f74,0x6db20035}},	//   _qabz, _psb_, крет_, _ułat,
   {{0xb4d60755,0x9c7c011c,0x1426021d,0x661d05e2}},	//   _सभी_, vačk, рдем, _epsk,
   {{0x442a013a,0x00000000,0x00000000,0x00000000}},	//   _vsb_, --, --, --,
   {{0x2d82006c,0xdb1b00f7,0x672400c3,0x44380051}},	//   ékek_, mptô, meij, _wrr_,
   {{0x442a4217,0xe8e00019,0x99890097,0x443808b7}},	//   _tsb_, _diệu_, _trať_, _trr_,
   {{0x442aa3cd,0x6b5f00da,0x9c7c0ce9,0x4438a3ce}},	//   _usb_, _dëgj, račk, _urr_,
   {{0xd138004e,0x03d70122,0x9c7c0ba8,0xe81e0066}},	//   _skąd_, _כולם_, sačk, _पहना_,
   {{0x9c7ca3cf,0x70f60037,0xf11a017e,0x63a286b2}},	//   mači, _نسائ, _لغات_, mlon,
   {{0x63a2a3d0,0x9c7c129f,0x21a600af,0x40960274}},	//   llon, lači, _тизм, _крет,
   {{0x63a20714,0xa5bb05f6,0x69d60103,0x2ee6023a}},	//   olon, _próz, _atye, _teof_,
   {{0x9c7c0a4c,0x2d850160,0x63a23e36,0x6db20035}},	//   nači, anle_, nlon, _płas,
   {{0x63a246ed,0x672f0035,0x394103d0,0x00000000}},	//   ilon, _racj, _pnhs_, --,
   {{0x7af6004e,0x63a2a3d1,0x6604a3d2,0x9c7c0207}},	//   _edyt, hlon, duik, hači,
   {{0x6db2004e,0x63a205e2,0x9c7c01a0,0x672f0035}},	//   _włas, klon, kači, _pacj,
   {{0x501b0397,0x9c7c01a0,0xd6d8a3d3,0xdb1f01f4}},	//   כולו, jači, иту_, _miqë,
   {{0x63a2a3d4,0xd8430355,0xdc3b009f,0x44f50036}},	// [bc10] dlon, dičů_, _iġġe, йпас,
   {{0x63a20035,0xdce80355,0xb0b80067,0x98ba013a}},	//   elon, vidě, ेखाग, _copē_,
   {{0xd5b82d7a,0x317c02b1,0xf9900037,0x9c7c0207}},	//   рст_, divz_, _تبي_, fači,
   {{0x9c7c0a78,0x63a20118,0x27fe00a0,0x66040d35}},	//   gači, glon, átne_, buik,
   {{0x569400d4,0xa1599463,0x201e0160,0x9647010b}},	//   _мают, ладу_, _apti_, _тэнд,
   {{0x2d9c00d7,0x63a2398b,0x491a157d,0x00000000}},	//   _nkve_, alon, म्पो_, --,
   {{0x63a2a3d5,0x7bce2c90,0x256401ae,0x9c7ca3d6}},	//   blon, íbul, _köln_, bači,
   {{0x4385004f,0x335800af,0x645800c3,0x9c7c00cd}},	//   _الرق, _касэ_, ävie, cači,
   {{0xf99f5c1d,0x3358002d,0x00000000,0x00000000}},	//   ntès_, _татэ_, --, --,
   {{0x7c3e2190,0xdc3b007a,0x7f42021d,0x00000000}},	//   _špra, _aġġe, _enoq, --,
   {{0x3f580132,0x7f1903d0,0xdb040211,0x00000000}},	//   _céus_, _білу_, _phià, --,
   {{0xa5bb01ef,0x3f580392,0x491a018d,0x8e3900bc}},	//   _eróx, _déus_, म्नो_, _مستر_,
   {{0xed4e0382,0x00000000,0x00000000,0x00000000}},	//   _ео_, --, --, --,
   {{0x2bcf0325,0xe50309a3,0xb4d60006,0x290c00be}},	//   _संपा, _लागि_, _सभे_, üda_,
   {{0x6d437710,0x186718cd,0x6e29a3d7,0x00000000}},	//   _inna, бари_, lweb, --,
   {{0x6f09005d,0x290c0035,0x66040421,0x00000000}},	//   ngec, żda_, tuik, --,
   {{0x9c7ca3d8,0xf1a71604,0x6e29a3d9,0x00000000}},	// [bc20] vači, गतान, nweb, --,
   {{0x660403c4,0x3f580118,0x6e290345,0x00000000}},	//   ruik, _yéus_, iweb, --,
   {{0x63a200a7,0x9c7c1ada,0xdd7a0070,0x6e2902b1}},	//   tlon, tači, נטעל, hweb,
   {{0xd24f00d1,0x68eea3da,0xf7720172,0x63a2a3db}},	//   کنه_, labd, _راج_, ulon,
   {{0x9c7c31f1,0x63a22939,0x6d43a3dc,0x7d0801ff}},	//   rači, rlon, _onna, ygds,
   {{0x63a2a3dd,0x9c7c00cd,0x2918a3de,0x7bda008d}},	//   slon, sači, nfra_, yptu,
   {{0x9c7c0207,0x00000000,0x00000000,0x00000000}},	//   pači, --, --, --,
   {{0x6d433bd1,0x984c00ea,0x9df812a0,0x3f580183}},	//   _anna, dēļa_, анит_, _réus_,
   {{0xa5bb0aca,0x2cea2830,0x3f5801ef,0x6e291857}},	//   _próx, льно_, _séus_, gweb,
   {{0x3f9d0069,0x00000000,0x00000000,0x00000000}},	//   _ekwu_, --, --, --,
   {{0xaf0a0ef5,0xfaff01d2,0x459b02b5,0x80a60041}},	//   _مقام_, shëm_, רסיע, _امان,
   {{0x6d43a3df,0x657ea3e0,0x7b674d11,0x6e29a3e1}},	//   _enna, hiph, стое, bweb,
   {{0x2918a3e2,0x5e5a29fe,0xbc67103b,0x00000000}},	//   ffra_, _حجاج_, لمین_, --,
   {{0xdd900413,0x7bdaa3e3,0x00000000,0x00000000}},	//   _توت_, pptu, --, --,
   {{0x115b02b5,0xfbcf0808,0x2bcf018d,0xdbe20042}},	//   נדלע, _संयम, _संया, _téñe,
   {{0x28d90d00,0x443f1b8d,0xc6220033,0x6db20067}},	//   _ब्रि, _ču_, নিনা_, _złap,
   {{0x7aef7a24,0x29050014,0x68ee01ef,0x7bca002f}},	// [bc30] mact, òlas_, babd, _hufu,
   {{0x7bca843f,0x6aad329d,0xf99f01f7,0x00000000}},	//   _kufu, _izaf, rtès_, --,
   {{0x59d4006c,0xa5bb1d2b,0xb719081e,0x7aef0176}},	//   _وغیر, _apóc, _конф_, oact,
   {{0x7aefa3e4,0x2564a3e5,0x7bca1939,0x1dc80127}},	//   nact, _höll_, _mufu, रदात,
   {{0x2bcf0066,0xe299052c,0x657e00cc,0x7bca001c}},	//   _संभा, јал_, biph, _lufu,
   {{0x61420274,0xdb0d01cb,0x6b8d00f4,0xc1e8010b}},	//   деша, _dhaé, _ljag, сьце_,
   {{0xb4e511b5,0x7aef0120,0x7bca6418,0x6b8d030d}},	//   नरी_, kact, _nufu, _ojag,
   {{0x27e5016f,0x9c7c154c,0x6b8d2ada,0x6e295d56}},	//   álny_, naču, _njag, tweb,
   {{0x7aefa3e6,0x7bd80160,0x3f5100ee,0x6f091b7f}},	//   dact, _atvu, _káuz_, rgec,
   {{0x8d590fa7,0x6e295132,0x6b8d53e6,0x7bca313a}},	//   ршит_, rweb, _ajag, _bufu,
   {{0x3a20a3e7,0x7aef449a,0x6aad85ac,0x8b2607be}},	//   _spip_, fact, _azaf, одне,
   {{0xeaba07e5,0xe519000c,0x920d0325,0x2007a3e8}},	//   ийн_, न्ति_, _समाज_, muni_,
   {{0x2007a3e9,0x657e0345,0x6b8d01cb,0xc9aa03e6}},	//   luni_, yiph, _djag, ивме_,
   {{0x7bcaa3ea,0x1d06002d,0x6b8d073a,0x6d43a3eb}},	//   _fufu, _деши_, _ejag, _unna,
   {{0x2007a3ec,0x68eea3ed,0x7bcaa3ee,0x5b3600d8}},	//   nuni_, rabd, _gufu, _дэпу,
   {{0x68eea3ef,0x00000000,0x00000000,0x00000000}},	//   sabd, --, --, --,
   {{0xe57a0426,0x2007a3f0,0x2564013c,0x6443a3f1}},	// [bc40] аза_, huni_, _föll_, ånin,
   {{0x20073dea,0x645ea3f2,0x7bc400ab,0x6aa40371}},	//   kuni_, typi, _hiiu, _iyif,
   {{0x2007a3f3,0x657ea3f4,0x42ca1783,0x93cb00b5}},	//   juni_, riph, аген_, لانہ_,
   {{0xe73a03ad,0x657e7bea,0x2007a3f5,0x9f5c00b8}},	//   _тем_, siph, duni_, prvé_,
   {{0x914a1362,0x27ed0a78,0x645e0067,0x00000000}},	//   ичка_, ćene_, sypi, --,
   {{0x66161217,0x20070848,0x799ca3f6,0xd5b200b5}},	//   mtyk, funi_, norw, _آفس_,
   {{0x64a32681,0x2007a3f7,0xdb0f024e,0xa0670274}},	//   _жара, guni_, ždéh, жаја_,
   {{0x799c2635,0x7aef015e,0xc3230204,0x2c4e013b}},	//   horw, xact, _омск, qədi_,
   {{0xc7b35c8e,0x799c070b,0xed8a83d0,0x661600d8}},	//   ובה_, korw, исок_, ntyk,
   {{0x20070657,0x661601c8,0xdb0d0248,0x7bca0139}},	//   buni_, ityk, _chaî, _pufu,
   {{0x200701d3,0x6aad0035,0x7bc4009e,0x6aa40371}},	//   cuni_, _szaf, _biiu, _ayif,
   {{0x69dd2b28,0x6616a3f8,0x6aa404fb,0xb09b024b}},	//   tpse, ktyk, _byif, _דיבר,
   {{0x7aef783e,0x6aa404fb,0xdcfa0228,0x69dd0328}},	//   ract, _cyif, notī, upse,
   {{0x7aefa3f9,0x7bca276d,0x69dd7ea4,0x799c4204}},	//   sact, _tufu, rpse, gorw,
   {{0xf77001cb,0x6d580160,0xa5bb0132,0x2fcc0260}},	//   چاق_, _iova, _osór, _judg_,
   {{0x2bcf55c7,0x69dd0343,0x27fe00a0,0xf7700098}},	//   _संता, ppse, átna_, ناق_,
   {{0x9c7c02dd,0x2007560a,0xef19731b,0xa6e20093}},	// [bc50] raču, zuni_, niża_, óðan,
   {{0x6d582c3f,0x2007a3fa,0x7aeda3fb,0x7d1a033b}},	//   _jova, yuni_, _heat, nfts,
   {{0x49b800d1,0x7aed0fef,0x65ab02b1,0x00000000}},	//   _بايد_, _keat, bühn, --,
   {{0x6d58a3fc,0x2007a3fd,0x69c500b5,0x7aed0107}},	//   _lova, vuni_, _hihe, _jeat,
   {{0x69c5a3fe,0x2007a3ff,0x7aed23e8,0x614567a0}},	//   _kihe, wuni_, _meat, зела,
   {{0x6d581769,0x200795c9,0x41290de3,0x7aed796c}},	//   _nova, tuni_, соко_, _leat,
   {{0xfbc600c4,0x2bc60ca1,0x2bcf0efa,0x00000000}},	//   _रंगम, _रंगा, _संधा, --,
   {{0x6e220037,0xd3430df3,0x69c5990f,0xcb0a00b4}},	//   _bpob, _تفری, _lihe, _वाइड_,
   {{0xc33214b0,0x2007a400,0x6d584996,0x75350cb9}},	//   _און_, suni_, _bova, _kazz,
   {{0x6d58a358,0x20071c12,0x44230200,0xceb901c0}},	//   _cova, puni_, _kpj_, neři_,
   {{0x7535a401,0x6d5863fa,0x4423a402,0x7aed6512}},	//   _mazz, _dova, _jpj_, _beat,
   {{0x61e9a403,0x69c503ad,0x7535027a,0x66166842}},	//   _kwel, _aihe, _lazz, ytyk,
   {{0x799ca404,0x7aed09c1,0xf1cb012f,0x69c55c03}},	//   torw, _deat, ादिन, _bihe,
   {{0x7535003c,0x61e924ed,0x6d580124,0x291e4d59}},	//   _nazz, _mwel, _gova, ýta_,
   {{0x7aed0052,0x69c50b91,0x2564013c,0x799c01d5}},	//   _feat, _dihe, _följ_, rorw,
   {{0x6d5802c4,0xf1cb00e7,0x7aed26c9,0x799c04fb}},	//   _zova, ादान, _geat, sorw,
   {{0x7535a405,0x799c08c7,0x443100fe,0xb69b0395}},	// [bc60] _bazz, porw, _asz_, _scâr,
   {{0x753502fb,0xaa3b0122,0x661656dd,0x69c501d5}},	//   _cazz, _פתיח, rtyk, _gihe,
   {{0x6616a406,0x7aed2f5f,0x395a0a8a,0x3d1304cc}},	//   styk, _yeat, _iops_, _दाने_,
   {{0x69c5a407,0x6448003c,0x61e93599,0xf74a0079}},	//   _zihe, _ġdid, _bwel, _الحي_,
   {{0x75351f26,0xe519007c,0x44230a8a,0x61e91019}},	//   _fazz, न्हि_, _epj_, _cwel,
   {{0x7535a408,0x61e9a409,0x00000000,0x00000000}},	//   _gazz, _dwel, --, --,
   {{0x6d58a40a,0x442c02e9,0x442300d7,0x61e9a40b}},	//   _rova, _èd_, _gpj_, _ewel,
   {{0x6d5859f5,0x09e20033,0x00000000,0x00000000}},	//   _sova, _বিনা, --, --,
   {{0x61e902c7,0x6d5871ee,0x7aeda40c,0xe8e001a5}},	//   _gwel, _pova, _reat, _chịu_,
   {{0x7bcd02c4,0x7aeda40d,0x63ae010b,0x4431005f}},	//   _čaur, _seat, šinė, _ysz_,
   {{0x6d5800d5,0x7aeda40e,0x9b9508f1,0x6604a40f}},	//   _vova, _peat, динц, hrik,
   {{0xa3e402e4,0x6604a410,0x23660409,0x00000000}},	//   पीए_, krik, nkoj_, --,
   {{0x6d58a411,0x09e401c8,0x65ab01ae,0x69c5a412}},	//   _tova, ноўн, fühl, _pihe,
   {{0x7aeda413,0xdb0d117e,0x395a409c,0x00000000}},	//   _weat, _thaï, _cops_, --,
   {{0x7aeda414,0x7535323f,0x36d58980,0x6604007c}},	//   _teat, _razz, добр, erik,
   {{0x27ff068b,0x2d9ea415,0x97a400af,0x2366006d}},	//   čun_, lote_, ерул, jkoj_,
   {{0x753502fb,0x69c503a6,0x2d8c388e,0x6604a416}},	// [bc70] _pazz, _tihe, onde_, grik,
   {{0x2d9ea417,0x2fc6a418,0xa5bb002a,0xdb0d0079}},	//   note_, _liog_, _epón, _mhaí,
   {{0x66045696,0x2d8ca419,0xf9900037,0x98b00124}},	//   arik, inde_, _حبي_, _ćaće_,
   {{0x2bcf08b6,0x2366006d,0xe1f100d1,0x75350103}},	//   _संसा, gkoj_, نست_, _wazz,
   {{0xb90a00e8,0xe1f8004b,0x75356a25,0x45d4172a}},	//   _nghệ_, згі_, _tazz, _пояс,
   {{0x2d9ea41a,0x442300d7,0x09e20033,0x1a9c0070}},	//   jote_, _tpj_, _বিমা, זידע,
   {{0x2d9e0763,0xd12e00bc,0x2fc60345,0x2b4901ed}},	//   dote_, شمي_, _biog_, _onac_,
   {{0x2d8ca41b,0x53340043,0x6d5ca41c,0x2366003a}},	//   ende_, _пест, öran, ckoj_,
   {{0x09e200c8,0x88c50083,0xee3600d8,0xdb0d01ef}},	//   _বিভা, ্রিক, дны_, _chaí,
   {{0xe81e004e,0x2b490132,0x999200ee,0x9e640037}},	//   _पहला_, _anac_, _kryť_, عاين,
   {{0x26d90051,0x2fc6009e,0x61fc00ea,0x00000000}},	//   _ofso_, _fiog_, _ārli, --,
   {{0x2d8c7984,0xc8e60127,0x09e20033,0x6604a41d}},	//   ande_, कर्म_, _বিবা, yrik,
   {{0x2d9ea41e,0x2bcf3b29,0x34aa052f,0x395a0147}},	//   bote_, _संवा, _कर्द, _pops_,
   {{0xa3cd05a2,0x2d9e08cb,0x2b490036,0xdb0d002a}},	//   रदा_, cote_, _enac_, _diañ,
   {{0x236da41f,0x07a61129,0x2b49a420,0xe73a0652}},	//   _olej_, давн, _fnac_, оев_,
   {{0x6604a421,0x29040d6f,0xdcfa02d4,0x8b9500d8}},	//   trik, şma_, mitā, _прыч,
   {{0xdcfa0080,0x27ed0a78,0x80a40035,0x07a31397}},	// [bc80] litā, ćena_, _चुने, татн,
   {{0x6604a422,0x598338df,0x236d00d5,0xfaff0055}},	//   rrik, _альб, _alej_, nkën_,
   {{0x660418df,0x2366011c,0xdcfa0228,0x3dc70107}},	//   srik, tkoj_, nitā, _minw_,
   {{0x2ca7a423,0x491a051e,0x2d9e002f,0xdb16000d}},	//   _mynd_, म्रो_, zote_, écèd,
   {{0x236d006d,0x2366573c,0x2d9e666e,0x2d8ca424}},	//   _dlej_, rkoj_, yote_, ynde_,
   {{0x23660a78,0xdb040098,0x00000000,0x00000000}},	//   skoj_, _chiú, --, --,
   {{0x2d9e1665,0xe4c30714,0x6563a425,0xdb040037}},	//   vote_, _айри, önhe, _dhiú,
   {{0x2d9e0054,0x93433471,0xdcfa00ea,0x236d008b}},	//   wote_, _инсе, ditā, _glej_,
   {{0x2d9ea426,0x00000000,0x00000000,0x00000000}},	//   tote_, --, --, --,
   {{0x2d8ca427,0xdb0d0138,0x3eb9003e,0xdb040079}},	//   unde_, _riañ, ýsta_, _ghiú,
   {{0xcfa9006c,0xdcfa00ea,0x2d8c033b,0x00000000}},	//   _کالم_, gitā, rnde_, --,
   {{0xa5bb0183,0xdb0d0183,0x00000000,0x00000000}},	//   _apól, _thaí, --, --,
   {{0x2d9ea428,0x61e20170,0x32060298,0xfaff0031}},	//   pote_, npol, nroy_, dhët_,
   {{0x3f84a429,0xdd90a42a,0x2ca70297,0x61e20036}},	//   limu_, _حوت_, _fynd_, ipol,
   {{0x58d40dba,0xb8d70914,0x6d4a28d4,0xdcfa00ea}},	//   тост, _जर_, _infa, citā,
   {{0x3f84a42b,0x65aba42c,0x656e009e,0xa03700a5}},	//   nimu_, rühm, _albh, ואלה_,
   {{0xa3e7111e,0x35b58f2c,0x60da02b1,0x00000000}},	// [bc90] _मौज_, ебар, _oftm, --,
   {{0x3f840657,0x61e20168,0x236d0116,0x00000000}},	//   himu_, dpol, _slej_, --,
   {{0x236d0200,0x3f84a42d,0x68f5a42e,0x61e2a42f}},	//   _plej_, kimu_, mazd, epol,
   {{0xdb040037,0x3f84a430,0x61e2000b,0x9295010b}},	//   _shiú, jimu_, fpol, наец,
   {{0xdb1602e1,0x3f84a431,0xdb040284,0x6d4a0051}},	//   écéd, dimu_, _chiù, _onfa,
   {{0x291101e8,0x660da432,0xdb0400f1,0x6d5c01ff}},	//   ngza_, muak, _dhiù, öral,
   {{0x10a238a2,0x60330095,0x660d5688,0x25a10355}},	//   лишн, _kəmə, luak, mohl_,
   {{0x6d4aa433,0xdcfa0029,0x3f84a434,0xdb040211}},	//   _anfa, vitā, gimu_, _fhiù,
   {{0x2ca709e1,0x656e012f,0x3f8d4c82,0xdb040284}},	//   _synd_, _ylbh, rneu_, _ghiù,
   {{0x68f5a435,0x128a0a86,0x645a01f7,0xdcfa013a}},	//   jazd, _عملی_, _àtic, titā,
   {{0x1ae70083,0x09e20033,0x672d34de,0x3f8d6c04}},	//   _কাজে_, _বিধা, keaj, pneu_,
   {{0x6d4aa436,0xdcfa0029,0xfaff01f4,0x660d0b51}},	//   _enfa, ritā, dhës_, kuak,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09e20083,0x200707e5,0xdcfa00ea,0x68f500b5}},	//   _বিদা, orni_, pitā, gazd,
   {{0xdd8e00e0,0x25a1012f,0xa3bf00c0,0x61e2008b}},	//   _دوو_, dohl_, ँगा_, zpol,
   {{0x2d85a437,0x07a30384,0xc7a30279,0x00000000}},	//   lile_, гасн, гиск, --,
   {{0x660d3b74,0x00000000,0x00000000,0x00000000}},	// [bca0] guak, --, --, --,
   {{0x2d85a438,0x3f84a439,0xba9b0122,0x7c3e0650}},	//   nile_, zimu_, _מספי, _špri,
   {{0xdcfa0043,0x61fb0086,0x13060370,0x7c2402c4}},	//   lită, _avul, езем, _ćirk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d85a43a,0x623409eb,0xdcfa002d,0x2007027a}},	//   kile_, телу, nită, erni_,
   {{0x1ae700c8,0x61e40043,0x2d855f44,0x656e01da}},	//   _কাছে_, ţilo, jile_, _ulbh,
   {{0x2d851c12,0x3f845b62,0x1dd50066,0x61fba43b}},	//   dile_, timu_, _डूबत, _evul,
   {{0x7c3e006c,0x2d8500ab,0x50230037,0xa3cd021a}},	//   _ápri, eile_, افيك, रदर_,
   {{0x2d85a43c,0x3f840428,0x63a2a43d,0xfaff0055}},	//   file_, rimu_, moon, zhës_,
   {{0x2d85a43e,0x63a2a43f,0x3f84a440,0x200705e2}},	//   gile_, loon, simu_, brni_,
   {{0x4c94876f,0xfaff0031,0x12d20033,0x68f56893}},	//   тинс, xhës_, ারীদ, vazd,
   {{0xa3d30243,0x63a2a441,0xe0df0019,0x2d850341}},	//   _हंस_, noon, _đòi_, aile_,
   {{0xb5100302,0x2d85a442,0x00000000,0x00000000}},	//   ालाय_, bile_, --, --,
   {{0x2d85a443,0x63a23d24,0x6d4aa444,0x4aa50cf1}},	//   cile_, hoon, _unfa, _गुणव,
   {{0x5ba73e89,0x27ed0a78,0x63a24dd3,0xb8e94e96}},	//   _приз, ćeno_, koon, _ऋण_,
   {{0x25a102c9,0x63a2a445,0x00000000,0x00000000}},	//   wohl_, joon, --, --,
   {{0x63a200be,0xfaff00da,0xb99903fa,0xdcfa00af}},	// [bcb0] doon, shës_, _ових_, cită,
   {{0xd2510609,0x660d01ed,0xf8d5046c,0x6d9c0225}},	//   ینا_, ruak, _दलिय, _uçağ,
   {{0x63a20a75,0x798701d5,0x61fb1cdb,0x603300a8}},	//   foon, mijw, _svul, _təmə,
   {{0x660da446,0xdb160107,0x2007063b,0x27e1009e}},	//   puak, _chyè, vrni_, _ithn_,
   {{0x2d850371,0xdb040223,0x00000000,0x00000000}},	//   yile_, _skië, --, --,
   {{0xdca6026e,0x798701d5,0xe7e800b8,0x3a290260}},	//   _نى_, nijw, टीका_, _mpap_,
   {{0x63a24f38,0x200e01d5,0x00000000,0x00000000}},	//   boon, gufi_, --, --,
   {{0xc01c0019,0x200701f4,0x2d85a447,0x09e20033}},	//   _hước_, rrni_, wile_, _বিসা,
   {{0xe3b00a72,0x2d85a448,0x798701d5,0x321901b2}},	//   _طرف_, tile_, kijw, _زياد_,
   {{0x4d6589bc,0xdcfa002d,0x1c453b62,0x2901011e}},	//   тков, vită, вном, _ndha_,
   {{0x2d85a449,0xeb9aa44a,0x3a290069,0x3b0a00b6}},	//   rile_, дин_, _apap_, мено_,
   {{0x00560100,0x29016d42,0x3d130127,0x00000000}},	//   _בשעת_, _adha_, _दावे_, --,
   {{0x3f7a02b5,0xeaf20243,0x3a29081f,0x3b0001f4}},	//   _קאנס, _अजीत_, _cpap_, _vdiq_,
   {{0xc01c00e8,0x63a2699a,0xdcfa002d,0xdce8010b}},	//   _nước_, zoon, rită, didė,
   {{0x98a6479c,0x63a205db,0x2901009e,0xf99f0392}},	//   тиве, yoon, _ddha_, prèn_,
   {{0x57be000c,0x00000000,0x00000000,0x00000000}},	//   ्देह, --, --, --,
   {{0x7c240bec,0x6b84a44b,0xc01c01a5,0x96637f11}},	// [bcc0] _ćiri, _imig, _bước_, акте,
   {{0x63a2a44c,0xc01c0019,0x00000000,0x00000000}},	//   woon, _cước_, --, --,
   {{0x63a2a44d,0x80c70083,0x9f4e0031,0x37e602c4}},	//   toon, রুত্, ënës_, _шонг,
   {{0x91e61b5d,0x9343517e,0x00000000,0x00000000}},	//   воде, инхе, --, --,
   {{0x63a2a44e,0x2564008a,0x82330037,0x25b8009e}},	//   roon, _sölu_, لروا, _thrl_,
   {{0x63a2a44f,0x42d20033,0xe0cf0079,0x00000000}},	//   soon, ারেশ, يزى_, --,
   {{0x63a2a450,0xf99300a5,0xf1a90118,0x00000000}},	//   poon, ברג_, راهه_, --,
   {{0x442aa451,0x65b001ae,0x200e002f,0x44381505}},	//   _ipb_, zähl, rufi_, _isr_,
   {{0xa1c61792,0xd2a70043,0x200e01e9,0xab5b02b1}},	//   _абад, _акте_, sufi_, hmüc,
   {{0x6b840d65,0xc01c0023,0x442a023a,0x753e01ed}},	//   _amig, _xước_, _kpb_, ndpz,
   {{0x753c0cc9,0x2175a452,0x09e20033,0x442a33f6}},	//   _marz, _сутр, _বিষা, _jpb_,
   {{0xdee60426,0x44380526,0xf4130122,0x65b001ae}},	//   _роди, _msr_, ספר_, wähl,
   {{0x80c700c8,0xed5a01d3,0x6d4d0079,0x65ab00be}},	//   রুদ্, _оод_, ánaí, sühi,
   {{0x6b84a453,0x753c004e,0x09e20083,0x9c4617d0}},	//   _emig, _narz, _বিশা, _ахил,
   {{0x97a70086,0xd7f8002d,0x79870010,0xc01c0023}},	//   врал, кут_, rijw, _rước_,
   {{0x25fe0461,0x09e20033,0x753c48ee,0x24b80033}},	//   _लिखी_, _বিরা, _aarz, জশাহ,
   {{0xc7c800c3,0xa3be0066,0xa5f813ba,0x45d40a80}},	// [bcd0] тыре_, ुआई_, кету_, иотс,
   {{0x1c091a75,0x6aad0345,0x69350b25,0xe6100079}},	//   _विमल_, _iyaf, _сноу, تشف_,
   {{0x02cb0084,0x753ca454,0x442a250e,0xdce800d8}},	//   िश्न, _darz, _cpb_, sidė,
   {{0x44380a8a,0x31cb06fe,0x442a0168,0x6aad018e}},	//   _dsr_, ाद्ध, _dpb_, _kyaf,
   {{0x753ca455,0xc01c0023,0x442a0282,0x00000000}},	//   _farz, _tước_, _epb_, --,
   {{0x7c3803fd,0x442a0034,0x753ca456,0x673da457}},	//   _osvr, _fpb_, _garz, _hasj,
   {{0xc9540319,0x673da458,0x491b00b4,0x7055600c}},	//   ימס_, _kasj, _बानो_, انعا,
   {{0xee391e46,0x753c004e,0x9324006c,0xef19021d}},	//   ени_, _zarz, _پرِن, хми_,
   {{0x673d781d,0x63a9a459,0xa6e20093,0xa5bb2314}},	//   _masj, _iken, óðin, _apói,
   {{0x257601b4,0x6b84a45a,0x673d08b7,0x09e20033}},	//   _vælg_, _smig, _lasj, _বিলা,
   {{0x9f051d05,0x63bb01a5,0x7bcd492d,0xc4b10066}},	//   _موضو, _khun, _biau, _झरोख,
   {{0x673d02ce,0x6d5a006d,0x7bcd0ffd,0x6aad2107}},	//   _nasj, ajta, _ciau, _byaf,
   {{0x7bcd0fef,0x63a908c7,0x6aad04fb,0xde0515ae}},	//   _diau, _mken, _cyaf, _спли,
   {{0x6447027d,0x6aad0107,0x7bcd01ed,0x25760a8a}},	//   _orji, _dyaf, _eiau, _kæle_,
   {{0x63a90c1f,0xbd9a0070,0x6aad018e,0xbb461b96}},	//   _oken, _אױסט, _eyaf, _бейк,
   {{0x63bb01a5,0xe7378f2c,0x63a901d5,0x6b840159}},	//   _nhun, лес_, _nken, _umig,
   {{0x7e690a6e,0x753ca45b,0x6443054e,0x6e2b01d1}},	// [bce0] nyep, _parz, ænin, _jpgb,
   {{0x20180f61,0x63a9a45c,0x63bb127e,0x649a2d7a}},	//   _årig_, _aken, _ahun, нтер_,
   {{0x63bb066a,0x649a15d6,0x753ca45d,0x69d6a45e}},	//   _bhun, хтар_, _varz, _huye,
   {{0x63bba45f,0xe29a01c8,0x69d62a13,0x753c5268}},	//   _chun, нае_, _kuye, _warz,
   {{0x63bba460,0x753ca461,0xa6831853,0x7e6901d5}},	//   _dhun, _tarz, _гляд, jyep,
   {{0x64a67d29,0x6724a462,0x7af6a463,0x673d044d}},	//   _бага, lfij, _leyt, _zasj,
   {{0x629c006a,0xfbcf04cc,0x69d600e2,0x802600f8}},	//   _środ, _संगम, _luye, ارتم,
   {{0xb4c00243,0x7af6a464,0x63bb19fd,0x44440160}},	//   ँधी_, _neyt, _ghun, mv_,
   {{0xa2cb08b0,0xa5bb004f,0x44448e04,0xe2970036}},	//   _तृप्, _spói, lv_, _бат_,
   {{0x444401a9,0xa3d3006a,0x71d70122,0x7bcd00d8}},	//   ov_, _हूँ_, _עובד_, _siau,
   {{0x7bcd0370,0x6aad108b,0xdb550086,0x213e0211}},	//   _piau, _syaf, авны, _iath_,
   {{0x4444a465,0x69d600a5,0x63bb0055,0x6aad0260}},	//   iv_, _buye, _xhun, _pyaf,
   {{0xc3330052,0x291a0211,0x673d0185,0x444400be}},	//   זור_, _bcpa_, _rasj, hv_,
   {{0x69d600e2,0x673d0207,0x67dc0107,0x00000000}},	//   _duye, _sasj, _sčja, --,
   {{0xa3d3004e,0x673da466,0x213e6048,0x4444a467}},	//   _हूं_, _pasj, _math_, jv_,
   {{0x213e69cb,0x673d0031,0x69d600f6,0x00000000}},	//   _lath_, _qasj, _fuye, --,
   {{0x44440189,0xc9870c8d,0xa3da0084,0xd50b05f5}},	// [bcf0] ev_, _буни, _डूब_, فغان_,
   {{0x63a9a468,0x213e509d,0x7af6033e,0x425500e0}},	//   _sken, _nath_, _zeyt, ینار,
   {{0x3d1c0e04,0xd6d10082,0x63a900d7,0x63bba469}},	//   _माने_, _وقد_, _pken, _phun,
   {{0xb51900ab,0x90d500cc,0x00000000,0x00000000}},	//   न्जय_, _càn, --, --,
   {{0x444401a9,0x213e2954,0x90d500e2,0x69d600cc}},	//   av_, _bath_, _dàn, _xuye,
   {{0x213ea330,0x660da46a,0x3f86484a,0xa5930416}},	//   _cath_, mrak, _amou_, _اگرچ,
   {{0x213e184f,0x70520037,0x63bba46b,0x80ad0033}},	//   _dath_, قنوا, _thun, টেন্,
   {{0x63a9a46c,0x63bb08c6,0x660d01b7,0x6f652d1e}},	//   _uken, _uhun, orak, рвиз,
   {{0x44210052,0x660da46d,0x7af60716,0x213e001e}},	//   lth_, nrak, _reyt, _fath_,
   {{0x0c2504d9,0x213e739a,0x69d604fb,0x660d3706}},	//   амон, _gath_, _ruye, irak,
   {{0x44210122,0xdcfa0228,0x69d60118,0x00000000}},	//   nth_, entē, _suye, --,
   {{0x4421a46e,0x660d0029,0x6e39006d,0xa5bb01ef}},	//   ith_, krak, _tswb, _esóx,
   {{0xeb971d80,0x7ae9a46f,0x386a00e9,0xdd951385}},	//   рия_, ñeta, wybr_, _кады,
   {{0xfce50202,0x7af636c4,0xdb04009e,0x44210055}},	//   _токо, _weyt, _chiò, kth_,
   {{0x660da470,0x02b2364c,0x46f605ac,0x9d1a025a}},	//   erak, _जर्न, ичат, _יוסט,
   {{0x44215f54,0x69d60019,0x291a00d7,0x44440223}},	//   dth_, _tuye, _wcpa_, vv_,
   {{0x44211973,0x44440d4b,0xe73700c3,0x67246b02}},	// [bd00] eth_, wv_, шет_, rfij,
   {{0x6d4118fb,0xe5771523,0x79fb02b8,0x7abb00a5}},	//   ndla, азу_, _שליח, _בצפו,
   {{0x68fca471,0x4444006f,0x213ea472,0x6d4100e9}},	//   mard, uv_, _rath_, idla,
   {{0x77941144,0x68fca473,0x4444a474,0x6d411ea7}},	//   _ایرا, lard, rv_, hdla,
   {{0x80ad00c8,0xab5b0457,0x213e00a5,0x44440d98}},	//   টেম্, kmün, _path_, sv_,
   {{0x68fca475,0x2918a476,0x333f00f7,0x2b404a49}},	//   nard, ngra_, _eaux_, _laic_,
   {{0x216703fa,0x333f8c5b,0x6d41a477,0x00000000}},	//   рији_, _faux_, ddla, --,
   {{0x68fca478,0xd37200e0,0x931603c5,0x6d411032}},	//   hard, _بهر_, _خورش, edla,
   {{0x68fca479,0x27ed0a78,0x2bd0111b,0x2fcfa47a}},	//   kard, ćeni_, _संजा, _digg_,
   {{0x5d663b8b,0x65b0033b,0x2fcf009e,0xb1880168}},	//   ртиз, fähi, _eigg_, _deťú,
   {{0x660da2b4,0x2cb833b7,0x64410093,0xef1a00af}},	//   zrak, ård_, _álit, _аме_,
   {{0x2d872b6f,0x68f74996,0x80ad0033,0xbb9400c3}},	//   _emne_, _sexd, _চলচ্, жающ,
   {{0x68fca47b,0x491b007c,0x00000000,0x00000000}},	//   fard, _बादो_, --, --,
   {{0x4421a47c,0xac180eb9,0x68fca47d,0x9e6500f8}},	//   yth_, _боку_, gard, _دامن,
   {{0x2bd008b6,0xb86804bf,0x2b40148f,0x3a200176}},	//   _संचा, ајте_, _faic_, _eqip_,
   {{0x2d8ca47e,0x2918004f,0x8b670a86,0x36d51d40}},	//   lide_, agra_, _خاتم, соар,
   {{0x7afda47f,0x76b90fc5,0x7bd8022a,0x442100a5}},	// [bd10] mast, улар_, _huvu, wth_,
   {{0x7afda480,0x7bd8a481,0x660da482,0x2d8ca483}},	//   last, _kuvu, rrak, nide_,
   {{0x65ab02c9,0x660d1363,0x4421a484,0x95c86cb5}},	//   führ, srak, uth_, рута_,
   {{0x7afda485,0x442196f9,0x7bd83d10,0x2d8ca486}},	//   nast, rth_, _muvu, hide_,
   {{0x2bd0a487,0x07560122,0xfbdd018d,0x2d8ca488}},	//   _संघा, _הסרט_, _नूनम, kide_,
   {{0x463a00c2,0x7afda489,0x4421024b,0xdb1f00a2}},	//   _געשע, hast, pth_, _piqû,
   {{0x333f0248,0x65ab01ae,0x2d8ca48a,0x6d41006d}},	//   _taux_, bühr, dide_, vdla,
   {{0x7afd2bc9,0x29180129,0x2d8c1192,0x67070325}},	//   jast, zgra_, eide_, षणिक_,
   {{0x7afda48b,0x68fca48c,0x52850037,0x2d8ca48d}},	//   dast, yard, _الذك, fide_,
   {{0x8d55107a,0x7bd8a48e,0x2d8ca48f,0x30a72e50}},	//   стич, _buvu, gide_, _крев,
   {{0x68fca490,0x6d41a491,0x2b4000d7,0xbb460086}},	//   vard, rdla, _paic_, бенк,
   {{0x7afd03d0,0xe45602b5,0x3d1c0722,0x316501ae}},	//   gast, צירט_, _माथे_, _holz_,
   {{0x2d8c06a2,0x139a02b5,0x2b400183,0x68fc09e8}},	//   bide_, רברע, _vaic_, tard,
   {{0x3f8da492,0x7afd00ab,0x0fd60354,0x6d5c00be}},	//   lieu_, aast, _ढूँढ, örat,
   {{0x68fca493,0x2b40004a,0x4807145f,0x29180093}},	//   rard, _taic_, йерн_, rgra_,
   {{0xea5a1453,0x316530bc,0x68fca494,0x2b400160}},	//   _број_, _lolz_, sard, _uaic_,
   {{0x09e200c8,0x7ae4a495,0xe4d60037,0x68fc7605}},	// [bd20] _বিকা, _ifit, متاب, pard,
   {{0x3f8da496,0x68fc610f,0x00000000,0x00000000}},	//   hieu_, qard, --, --,
   {{0xd8d700c2,0xa5bb1fca,0x0fd60035,0x64410009}},	//   _לויט_, _após, _ढूंढ, _šlir,
   {{0x798e0273,0xdce300b8,0x2d8ca497,0x7ae4007a}},	//   libw, _plně, zide_, _jfit,
   {{0x65ab033b,0x7ae4a1fa,0x216a0011,0x745400fd}},	//   rühr, _mfit, лиди_, _ڈھائ,
   {{0x645800c3,0x3d13046c,0xdb060ef0,0x2d8ca498}},	//   ävis, _दागे_, llkä, xide_,
   {{0x2d8ca499,0x7ae40395,0xfbc8157d,0x5577016b}},	//   vide_, _ofit, रगाम, _פעלן_,
   {{0x7bd8035a,0x38c300a2,0x7ae4a49a,0x2d9900fd}},	//   _ruvu, léré_, _nfit, ésen_,
   {{0x7afda49b,0x2d8ca49c,0x798e01a8,0x904601cb}},	//   vast, tide_, kibw, _گناه,
   {{0x867b0052,0x7165004f,0x7ae40232,0x38c300f7}},	//   טרפו, _والك, _afit, néré_,
   {{0x2d8ca49d,0xdeef1023,0xb09a01e0,0x00000000}},	//   ride_, _ны_, _стає_, --,
   {{0x2d8ca49e,0x66160103,0x005732e3,0x3f8d0392}},	//   side_, kuyk, _לשבת_, cieu_,
   {{0x2d8ca49f,0x256f01d6,0x6da600af,0xfe4600af}},	//   pide_, _yılı_, _лида, _ындо,
   {{0x7bd8a4a0,0x7ae4008e,0x798e01a8,0x7afda4a1}},	//   _tuvu, _efit, gibw, sast,
   {{0xe8140302,0x38c300f7,0x7ae400e9,0x00000000}},	//   तूला_, déré_, _ffit, --,
   {{0x3cfe02d7,0xe894010b,0x00000000,0x00000000}},	//   latv_, чась, --, --,
   {{0xf1a80026,0x798e0186,0xfa280033,0x38c3000d}},	// [bd30] गवान, bibw, মিউল_, féré_,
   {{0x67d500d8,0x7d1aa4a2,0x798e04fb,0x3cfe0228}},	//   _sąju, ngts, cibw, natv_,
   {{0xe43501ca,0xa2cb0e6f,0x00000000,0x00000000}},	//   تفاد, तेन्, --, --,
   {{0xdfc60037,0xc178005f,0x316502a7,0x00000000}},	//   _زي_, _alė_, _solz_, --,
   {{0x3f8d0310,0x27ed011c,0x38c32128,0x31652568}},	//   vieu_, ćenu_, béré_, _polz_,
   {{0xdb0605f6,0xa069195c,0x00000000,0x00000000}},	//   roké, иала_, --, --,
   {{0xdb0605f6,0xfaff0031,0x80240037,0x31e60033}},	//   soké, nkës_, كريم, _নিঃশ,
   {{0x798e09d6,0x6567023a,0xa3d600b4,0x00000000}},	//   zibw, _hojh, सदर_, --,
   {{0x63aba4a3,0x332d0453,0x3f8d13dd,0x212c009e}},	//   mogn, _ibex_, rieu_, _fbdh_,
   {{0x63aba4a4,0x1d090202,0x61e97243,0x98ba0029}},	//   logn, јени_, _itel, _lapā_,
   {{0x61e91269,0x443100e0,0x55ac016b,0x656707c0}},	//   _htel, _jpz_, רייַ, _mojh,
   {{0xcaca0b46,0x224d0260,0x65b002e2,0x6d5c01ff}},	//   игне_, _krek_, läht, örar,
   {{0x798e0273,0xa2dc04aa,0x433a016b,0x61e9009f}},	//   tibw, _फलस्, בערב, _jtel,
   {{0x2eff01ae,0x656702c4,0x3cfe027a,0x65b000ab}},	//   lauf_, _nojh, catv_, näht,
   {{0x7ae40484,0x798ea4a5,0x68e50345,0x68431dab}},	//   _tfit, ribw, _dfhd, vídá,
   {{0x6d4370ee,0x46ea1e46,0x6f1b149f,0x61e908e2}},	//   _hana, рдан_, nguc, _otel,
   {{0x05662365,0x63ab0036,0x6736008d,0x4431a4a6}},	// [bd40] ован, dogn, reyj, _apz_,
   {{0x6d43a4a7,0xa5bb2ac4,0xfaff0055,0xa50a0b00}},	//   _jana, _spór, skët_, режа_,
   {{0x224da4a8,0xe72a2705,0x2eff033b,0x3d1c01d1}},	//   _arek_, _конд_, kauf_, _मासे_,
   {{0x6d439817,0xfe67317b,0x224d41a3,0x232a03b1}},	//   _lana, _قد_, _brek_, роди_,
   {{0xc4480987,0x3cfe00d7,0x38c3000d,0x224da4a9}},	//   _گیان_, yatv_, péré_, _crek_,
   {{0x6d43a4aa,0x7bcf0187,0x6604a4ab,0x2d990300}},	//   _nana, íbuz, msik, ésel_,
   {{0x657e0082,0x61e90086,0x3cfe82fc,0x6604a4ac}},	//   mhph, _etel, vatv_, lsik,
   {{0x6d43010d,0x69c70c21,0x63ab8a61,0x644e009f}},	//   _aana, zmje, cogn, _irbi,
   {{0x224d01f4,0x6d43a4ad,0x6604a4ae,0x20051d1b}},	//   _grek_, _bana, nsik, _evli_,
   {{0xa2a300c0,0x1056006c,0x657ea4af,0x6604005b}},	//   _छुट्, _وضاح, nhph, isik,
   {{0x6d430a23,0xdd9700d8,0x00000000,0x00000000}},	//   _dana, ўшы_, --, --,
   {{0x9e6603c7,0x6d43a4b0,0x6e3b0371,0x61e901e0}},	//   _واشن, _eana, bwub, _ytel,
   {{0x6d43a4b1,0x62820479,0x5a440c8a,0x66042544}},	//   _fana, nzoo, мэра, jsik,
   {{0x6d43a4b2,0x273501a5,0x6f00a4b3,0x644ea4b4}},	//   _gana, _ấn_, lamc, _orbi,
   {{0xf773028c,0x69c700da,0x984801d3,0xb4b900be}},	//   وار_, rmje, оята_, _चरे_,
   {{0x6d43a4b5,0x69c7012e,0x660400d7,0x6f00034d}},	//   _zana, smje, fsik, namc,
   {{0x6d43a4b6,0x63ab035b,0x6567006d,0x6604a4b7}},	// [bd50] _yana, vogn, _pojh, gsik,
   {{0x09e200c8,0x344b075c,0xa2cb0808,0x4431028b}},	//   _বিচা, ичен_, _तृष्, _ppz_,
   {{0x61e9a4b8,0x3cfc0345,0x917b00e2,0x6f0088b7}},	//   _stel, _mevv_, hệ_, kamc,
   {{0xb8660118,0x883a0122,0x224da4b9,0x3cfc0051}},	//   _راپو, _פתרו, _prek_, _levv_,
   {{0x644ea4ba,0x63aba4bb,0x65b00303,0x6b8da4bc}},	//   _erbi, rogn, täht, _mmag,
   {{0xd24e0fab,0x63ab01d3,0xc24401c8,0x224d03bc}},	//   انو_, sogn, ьнік, _vrek_,
   {{0x6d43128f,0x6b8da4bd,0xddc9004e,0xf9940d85}},	//   _rana, _omag, rzeż, ורס_,
   {{0x6d43a4be,0x224d0147,0x65b00421,0x00000000}},	//   _sana, _trek_, säht, --,
   {{0x6d43a4bf,0x2eff02c9,0x59ab0380,0x61e9a4c0}},	//   _pana, rauf_, चकार, _utel,
   {{0x0d82a4c1,0x6b8da4c2,0xac856473,0x6d43013b}},	//   ельн, _amag, згол, _qana,
   {{0x6d43600e,0x3d1c0953,0xa3b800b5,0xc17200a5}},	//   _vana, _मारे_, _طاہر_, _רחב_,
   {{0x6d43225e,0xeb9a1837,0x65b001ae,0x6604a4c3}},	//   _wana, сим_, nähr, ysik,
   {{0x6d43a4c4,0xee2e6c9d,0x34b81140,0x80d00033}},	//   _tana, _ян_, _अर्द, _স্প্,
   {{0x6b8da4c5,0xdce33e39,0x6d4304be,0x00000000}},	//   _emag, _konč, _uana, --,
   {{0x08c30200,0x00000000,0x00000000,0x00000000}},	//   ебрн, --, --, --,
   {{0xe51e009a,0x6604a4c6,0x65b0033b,0xab6600d4}},	//   _पाहि_, tsik, jähr, _хвил,
   {{0x644e33dc,0xfbd301f3,0xdce304c3,0xf99f2154}},	// [bd60] _srbi, _אתה_, _lonč, grès_,
   {{0x7d01a4c7,0x660423f4,0x6b8d02c6,0x7bd64f4f}},	//   nals, rsik, _zmag, _hiyu,
   {{0x6604a4c8,0x65b001ae,0x7bd6a4c9,0xf8db00a5}},	//   ssik, fähr, _kiyu, _לחימ,
   {{0x7d017348,0xc7a61574,0xf99f0118,0x93cb00fd}},	//   hals, _химк, brès_, مانہ_,
   {{0x7d0153a3,0x7bd609ba,0x4b4d0070,0x7bc40211}},	//   kals, _miyu, יגאַ, _mhiu,
   {{0x4034036e,0x7bd61d50,0x7d0108b7,0x27fa0223}},	//   декс, _liyu, jals, _kwpn_,
   {{0x64a3a4ca,0x644ea4cb,0x50d6006c,0x62825c49}},	//   _зара, _urbi, _ہزار, szoo,
   {{0x5ea50b52,0x23270b46,0x7bd60371,0x2c820118}},	//   খেছে, _носи_, _niyu, _lédé_,
   {{0x80a604e8,0x6f00a4cc,0x00000000,0x00000000}},	//   _کمان, ramc, --, --,
   {{0x6b8da4cd,0xc243311c,0xdce3a4ce,0xc5f300a5}},	//   _smag, _янук, _fonč, עדת_,
   {{0x7bd6a4cf,0xe6b92c2b,0x00000000,0x00000000}},	//   _biyu, _आर्ज, --, --,
   {{0x7bc401d3,0x7d01007c,0x7bd600e0,0x69d500b4}},	//   _chiu, aals, _ciyu, _यूजी,
   {{0x7d010080,0x602a0095,0x2aab2294,0x7bc401a6}},	//   bals, _məmm, стно_, _dhiu,
   {{0x5e570052,0x827702b5,0xd90f0357,0x7c374193}},	//   _מידע_, לעכע_, دید_, ñarí,
   {{0x68fe0703,0x6d586b97,0x6b8d0159,0x7bc41861}},	//   _depd, _inva, _tmag, _fhiu,
   {{0x6b8d00a7,0x5ba401c8,0x7bd610ce,0x7bc42c46}},	//   _umag, _прыз, _giyu, _ghiu,
   {{0x98ba0139,0x2c8200f6,0x2576008c,0x00000000}},	// [bd70] _papă_, _fédé_, _tæll_, --,
   {{0x6d48a4d0,0x65b001ae,0x261c0066,0xdb1f0176}},	//   ndda, währ, मढ़ी_, _liqü,
   {{0x2903968a,0x6b9da4d1,0xf8c10026,0x7bd6007b}},	//   maja_, onsg, _एरिय, _yiyu,
   {{0xf99f95e0,0xdce30124,0x69df0031,0x42db0033}},	//   près_, _ronč, _kuqe, দর্শ,
   {{0x2d990332,0xdce302c6,0x61454f06,0x2169579f}},	//   ések_, _sonč, дела, жили_,
   {{0xdce329e7,0xe1f00427,0x00000000,0x00000000}},	//   _ponč, اسن_, --, --,
   {{0x7d01a4d2,0x7ae601ff,0x00000000,0x00000000}},	//   vals, yckt, --, --,
   {{0x6d580c1f,0x2903a4d3,0x69d734bb,0xe7bf022e}},	//   _anva, haja_, _lixe, ्षिप,
   {{0x7d01a4d4,0x2903a4d5,0x764d0107,0x78b70523}},	//   tals, kaja_, nvay, _lyxv,
   {{0x290300de,0x7bc4a4d6,0x69d70042,0xdce31164}},	//   jaja_, _shiu, _nixe, _tonč,
   {{0x2903a4d7,0x7d01a4d8,0xd7bf00a1,0x7bd60a2d}},	//   daja_, rals, ्षाच, _piyu,
   {{0x6d5868fd,0x7d01a4d9,0x69d70443,0x3e830118}},	//   _enva, sals, _aixe, _cèté_,
   {{0x7d0100c3,0x69d778ca,0x20070009,0x1d0927de}},	//   pals, _bixe, lsni_, _дели_,
   {{0x2903240f,0x6b9d0051,0xed59002d,0x7bd6007b}},	//   gaja_, ansg, _фок_, _wiyu,
   {{0x69d70391,0xb90600b1,0x7bd61292,0xcb6a03e6}},	//   _dixe, _फल_, _tiyu, _маке_,
   {{0x69c500b5,0x69d72651,0x7f4902d7,0x61fb018e}},	//   _ehhe, _eixe, ndeq, _owul,
   {{0x290323aa,0x7546a4da,0x6e29a4db,0xb8d5051d}},	// [bd80] baja_, мназ, nteb, _छु_,
   {{0xf1e10299,0x29030254,0x2007a4dc,0xb3470024}},	//   _पढ़न, caja_, ksni_, _leħħ,
   {{0x53e502ce,0x395a0382,0x61fb018e,0x998902a7}},	//   еціа, _inps_, _awul, _upaš_,
   {{0x32060159,0x6e29a4dd,0xb347035f,0x00000000}},	//   tsoy_, kteb, _neħħ, --,
   {{0x6d48a4de,0x91e30421,0x00000000,0x00000000}},	//   ydda, воче, --, --,
   {{0xc69300c2,0xc1a800a1,0x257608c8,0x26c20065}},	//   _יאר_, गवेग, _mælk_, _izko_,
   {{0x6e29a4df,0x61fb001c,0x00000000,0x00000000}},	//   eteb, _ewul, --, --,
   {{0x602a00a8,0x29031c90,0x3366010b,0x6e291c9b}},	//   _həmk, zaja_, _ўваг, fteb,
   {{0x6d5801b7,0x6e2909c7,0x00000000,0x00000000}},	//   _pnva, gteb, --, --,
   {{0x2366011c,0x3eb800ea,0xdb0f021d,0x00000000}},	//   ljoj_, ārt_, cocê, --,
   {{0x29030169,0x6d4800e9,0x61e0a4e0,0x69d701ef}},	//   vaja_, rdda, _huml, _rixe,
   {{0x69d77da7,0x23660254,0x61e098ab,0x7c2804c5}},	//   _sixe, njoj_, _kuml, rtdr,
   {{0x2903a4e1,0x61e08ae7,0xb06100be,0x6e290051}},	//   taja_, _juml, _äärd, cteb,
   {{0x66168073,0x61e0a4e2,0x6d580448,0x00000000}},	//   dryk, _muml, _unva, --,
   {{0x2903a189,0x69d701dd,0x5ba7259a,0x80d00083}},	//   raja_, _vixe, _ориз, _স্ত্,
   {{0x316ca4e3,0x36d52447,0x00000000,0x00000000}},	//   _lodz_, еобр, --, --,
   {{0x98bf0095,0x2d9e01ef,0x23661626,0x7dc6008e}},	// [bd90] ırıb_, onte_, djoj_, rðsf,
   {{0x2d9e2a29,0x3324009e,0xae0000b4,0x201ca4e4}},	//   nnte_, _acmx_, लीयन_, kuvi_,
   {{0x2d9ea4e5,0x799523f6,0x6e297358,0x26c20065}},	//   inte_, mizw, zteb, _ezko_,
   {{0x7995000e,0x2d9e033b,0x23660031,0x61e0008c}},	//   lizw, hnte_, gjoj_, _buml,
   {{0x6fc500de,0x290100ab,0x61e0a4e6,0x3a2b002a}},	//   nóce, _keha_, _cuml, ntcp_,
   {{0x349554e1,0xc1050037,0xb347007a,0x00000000}},	//   _загр, روبي, _seħħ, --,
   {{0x2fc601a6,0x25a61a98,0xdce300ea,0xe05700d1}},	//   _bhog_, éole_, _nonā, بیات_,
   {{0x2d9ea4e7,0x2fc60211,0x6e29a4e8,0xfe450370}},	//   ente_, _chog_, tteb, енио,
   {{0xee3647ec,0x79952eb4,0x2fc600e0,0x61e0a4e9}},	//   ены_, kizw, _dhog_, _guml,
   {{0x316c004e,0xdb060187,0x29014565,0xed451b50}},	//   _godz_, doká, _neha_, хноп,
   {{0x6e29a4ea,0x2b49013a,0x00000000,0x00000000}},	//   steb, _baac_, --, --,
   {{0x2d9e21a4,0x25bd012f,0x6e290b88,0x6a860009}},	//   ante_, ्गुण, pteb, елма,
   {{0x29010065,0x00000000,0x00000000,0x00000000}},	//   _beha_, --, --, --,
   {{0x7995035a,0xdca51422,0x00000000,0x00000000}},	//   gizw, _пали, --, --,
   {{0x0d1600a5,0x00000000,0x00000000,0x00000000}},	//   _טקסט_, --, --, --,
   {{0x6616a4eb,0x613301fb,0xf7432dde,0xe9ff055c}},	//   tryk, lılı, лесо, _chẳg_,
   {{0xe61a4e6b,0x7dec0070,0x799501d5,0xf1af06bc}},	// [bda0] яда_, ַקאַ, bizw, टवान,
   {{0x6133037a,0x6616a4ec,0xfaff0031,0x61e0a4ed}},	//   nılı, rryk, njën_, _ruml,
   {{0x61e0558c,0x25e50067,0x69ce02b1,0x00000000}},	//   _suml, _झूठी_, mmbe, --,
   {{0x237f0043,0x25fb007c,0x69ce39ca,0x25760093}},	//   _cluj_, _लौकी_, lmbe, _mæli_,
   {{0x613300d0,0x29010159,0x00000000,0x00000000}},	//   kılı, _yeha_, --, --,
   {{0x602a01c2,0x7646004b,0x00000000,0x00000000}},	//   _həmi, _isky, --, --,
   {{0xe5a30beb,0x35a30c06,0x613300a8,0x69cea4ee}},	//   _сири, _сарг, dılı, imbe,
   {{0x2fc6006d,0x201c0183,0x61e0029e,0x7bde000d}},	//   _qhog_, ruvi_, _tuml, _épui,
   {{0x79950010,0x656e009e,0x929d0067,0x00000000}},	//   yizw, _kobh, _pełe, --,
   {{0xdb061d8a,0x2d9e0036,0x69ce6666,0x656e0a8a}},	//   voká, unte_, jmbe, _jobh,
   {{0x2cb8082b,0x2d9e033b,0x443812a9,0xbfa800af}},	//   ærd_, rnte_, _jpr_, _оӂие_,
   {{0x443801d1,0x1e861c1b,0x656e19fd,0x69cea4ef}},	//   _mpr_, _плем, _lobh, embe,
   {{0x290100d7,0xdb0f06aa,0x79953776,0x76460345}},	//   _peha_, nocé, tizw, _nsky,
   {{0x613306d3,0x4438023a,0x6f02a4f0,0x656e0284}},	//   cılı, _opr_, _heoc, _nobh,
   {{0x7995050f,0xd838004b,0x161e00b4,0x4438a4f1}},	//   rizw, нэт_, यूसर_, _npr_,
   {{0x6d4a0297,0x602a01c2,0x799504fb,0x656e00f1}},	//   _hafa, _cəmi, sizw, _aobh,
   {{0x29010006,0x6d4a6e18,0x4438a4f2,0xc8f50133}},	// [bdb0] _teha_, _kafa, _apr_, _изпъ,
   {{0x4438046a,0x656e09c3,0x27e10159,0x200c0506}},	//   _bpr_, _cobh, _tuhn_, _ovdi_,
   {{0x6d4a289f,0x656ea4f3,0x3cfb016b,0x764609dd}},	//   _mafa, _dobh, פלאנ, _esky,
   {{0x613306d0,0x4438a4f4,0x656e009e,0x602a00a8}},	//   zılı, _dpr_, _eobh, _gəmi,
   {{0x6133037a,0x200c108c,0x7aed007b,0xa2d401c0}},	//   yılı, _avdi_, _mfat, _बृद्,
   {{0x6d4aa4f5,0xd24e026e,0x61330095,0x44380232}},	//   _nafa, زنى_, xılı, _fpr_,
   {{0x8ffa00b5,0x7aed9e24,0xa1560274,0x6f02a4f6}},	//   ورٹر_, _ofat, тају_, _beoc,
   {{0x7aed0027,0x6455009f,0x6f020312,0x00000000}},	//   _nfat, _irzi, _ceoc, --,
   {{0x61331a68,0x0ea902ce,0x6f02a4f7,0x6d4a0010}},	//   tılı, ький_, _deoc, _bafa,
   {{0x7aeda4f8,0x6d4a1b57,0x645a1721,0x673f01f4}},	//   _afat, _cafa, _átic, heqj,
   {{0x61330092,0xdca5257f,0x6d4a016e,0x6f02009e}},	//   rılı, тани, _dafa, _feoc,
   {{0x1eea0332,0x64550c21,0x753e01d7,0x09bca4f9}},	//   _قومی_, _mrzi, zepz, ोग्य,
   {{0x6d4aa4fa,0x613306d3,0xa6db008d,0x4a4302fb}},	//   _fafa, pılı, _faði, аняв,
   {{0x6d4aa4fb,0x64550036,0x602a00a8,0xfce22b56}},	//   _gafa, _orzi, _səmi, _кошо,
   {{0xbbe80037,0x7aed00e9,0x69ce0b17,0x656e19fd}},	//   _كريم_, _ffat, rmbe, _robh,
   {{0x6d210243,0x7d031929,0x6d4aa4fc,0xd910006c}},	//   _माँग_, _hens, _zafa, _گیس_,
   {{0x7d0301d5,0x4438069d,0xc9aa00c9,0x64550036}},	// [bdc0] _kens, _spr_, _овие_, _arzi,
   {{0x7d0311cb,0x645501cc,0x6d4a0392,0x2d850355}},	//   _jens, _brzi, _xafa, nhle_,
   {{0x7d035cd4,0x602a01c2,0x44380069,0x00000000}},	//   _mens, _təmi, _qpr_, --,
   {{0x64550cc1,0xe51e02e4,0xe29a00d8,0x66e600af}},	//   _drzi, _पाकि_, мае_, _шома,
   {{0x6d210b4a,0x6455a4fd,0x6f0201ef,0x6b9d1c98}},	//   _मांग_, _erzi, _reoc, érgi,
   {{0x6f020aac,0x7d03a4fe,0x09df0033,0x25fb0066}},	//   _seoc, _nens, বীকা, _लौटी_,
   {{0x6d4aa4ff,0x5f947566,0xccf80355,0x66e626c6}},	//   _rafa, ликт, vbě_, _कलाक_,
   {{0x6724a500,0x6d4a666e,0x27fe00a0,0xfaff0031}},	//   ngij, _safa, átny_, gjël_,
   {{0x7d036d50,0x63a24d8c,0x6d4a01f4,0x444400e9}},	//   _bens, mnon, _pafa, lw_,
   {{0x6d4a4498,0x7aed0043,0x444407df,0x7d03a501}},	//   _qafa, _sfat, ow_, _cens,
   {{0x351b0100,0xfe6f03c5,0x4444a502,0x6f02a503}},	//   ווינ, مدی_, nw_, _teoc,
   {{0x6d4aa504,0x76440232,0x7d03053e,0xdca30dec}},	//   _wafa, kwiy, _eens, раџи,
   {{0x6d4aa505,0x7d0301ae,0x63a2a506,0x2d850608}},	//   _tafa, _fens, inon, bhle_,
   {{0xf2d30779,0x7d03a507,0x2d85053d,0x6e208e43}},	//   יער_, _gens, chle_, mumb,
   {{0x6d3b1899,0x6fc520d9,0x63a20a2d,0x6e20a508}},	//   _חתונ, lóca, knon, lumb,
   {{0x7d03a509,0x7d08a50a,0x444400e9,0x7aeda50b}},	//   _zens, lads, dw_, _ufat,
   {{0x6e20a50c,0x64550124,0x161e00b4,0x67d403c6}},	// [bdd0] numb, _srzi, यूलर_, роту,
   {{0x7d08a50d,0x271301a5,0x7d0301ef,0x6455a50e}},	//   nads, ện_, _xens, _przi,
   {{0x6e2008bd,0x831900b5,0x98ba00b8,0x00000000}},	//   humb, فقار_, _mapě_, --,
   {{0x6e2043dd,0x63a2a50f,0x3d1c00a1,0x76440232}},	//   kumb, gnon, _माझे_, bwiy,
   {{0x6e20a510,0x471a00a5,0x602a00a8,0x768700af}},	//   jumb, _אורג, _məmu, _рынж,
   {{0x64470bd1,0x6e20a511,0x645518b0,0x660da512}},	//   _tsji, dumb, _trzi, msak,
   {{0x7d03a513,0x645500af,0x660da514,0x00000000}},	//   _rens, _urzi, lsak, --,
   {{0x2f5403ad,0x7d03a515,0x6e20876b,0x63a2046a}},	//   атьс, _sens, fumb, cnon,
   {{0x44210452,0x6e20a516,0xfce50c06,0x00000000}},	//   luh_, gumb, лопо, --,
   {{0x4d6502ce,0x00000000,0x00000000,0x00000000}},	//   уков, --, --, --,
   {{0xa3c70e1d,0x44211201,0x7d038a22,0xeb9a135b}},	//   _उठा_, nuh_, _vens, еин_,
   {{0x660da517,0x7d033440,0x6e2001d0,0x4fa400d4}},	//   ksak, _wens, bumb, _києв,
   {{0x2d8b02e1,0x44216aa1,0xed4e1400,0x7d0800b5}},	//   èces_, huh_, _ло_, bads,
   {{0x44211034,0xfe9a0070,0xdd9400c7,0x660da518}},	//   kuh_, _אינמ, _качы, dsak,
   {{0x6d41573f,0xa6db00fb,0x44210f1a,0xe73a144b}},	//   mela, _maðu, juh_, нев_,
   {{0x442109df,0x6d41a519,0x6f09598f,0x8a9600bf}},	//   duh_, lela, naec, _مشخص,
   {{0x6b8449d2,0x660d5066,0xa7a7a51a,0x628b0e5e}},	// [bde0] _ilig, gsak, укта_, jzgo,
   {{0x6d411b39,0x85065b0c,0x00000000,0x00000000}},	//   nela, اوان, --, --,
   {{0x444425cb,0x290aa51b,0x4421072e,0x660da51c}},	//   uw_, maba_, guh_, asak,
   {{0x290aa51d,0x6e20010f,0x6d4188ac,0x4444a51e}},	//   laba_, yumb, hela, rw_,
   {{0x63a2a51f,0x69dea520,0x257619b4,0x7c2102b1}},	//   rnon, _kipe, _bælt_, hulr,
   {{0x290aa521,0x44212bab,0x6d414efc,0x6b8412c3}},	//   naba_, buh_, jela, _llig,
   {{0x6d41a522,0x442100d7,0x6e20001c,0x290aa523}},	//   dela, cuh_, wumb, iaba_,
   {{0x290a0f15,0xa8570122,0x1e140036,0x69dea524}},	//   haba_, ריקה_, амия, _lipe,
   {{0x6d4100e9,0x290a76a4,0x59b4035d,0x7d0809e1}},	//   fela, kaba_, ंकार, tads,
   {{0x6b84a525,0x01d70789,0x290aa526,0x6b960602}},	//   _alig, _موقع_, jaba_, _amyg,
   {{0x290aa527,0x6e2025b0,0x6b84a528,0x7d08a529}},	//   daba_, sumb, _blig, rads,
   {{0x7d08a52a,0x660da52b,0x6e20a52c,0x2b820037}},	//   sads, ysak, pumb, _póca_,
   {{0x6d411201,0x6b840014,0x7d0800ec,0x44210aac}},	//   bela, _dlig, pads, zuh_,
   {{0x29050514,0x290aa52d,0x6b84a52e,0x69de85ca}},	//   úla_, gaba_, _elig, _cipe,
   {{0x69de0ce8,0xb8fd0387,0x645a042a,0x4cd20083}},	//   _dipe, _तः_, _štin, _দ্রু,
   {{0x660d92fe,0x602a00a8,0x69de0079,0x4c1329fe}},	//   tsak, _həms, _eipe, _ابوس,
   {{0x290aa52f,0x442100d1,0x98a5037a,0xdb0fa530}},	// [bdf0] baba_, wuh_, ılı_, nocí,
   {{0x290a1ec0,0x660da531,0x7afd02c9,0x44211034}},	//   caba_, rsak, lbst, tuh_,
   {{0x660da532,0x7bcd0189,0xf8b90026,0x26190fd0}},	//   ssak, _khau, _इडिय, यूजी_,
   {{0x44210464,0x32550af4,0x6d41a533,0x660d62db}},	//   ruh_, ивер, zela, psak,
   {{0x44210452,0x7bdf12c3,0x201c0036,0x6f09002a}},	//   suh_, _miqu, ervi_, vaec,
   {{0x442106d4,0x6d410a54,0x6edb0029,0x657e89ed}},	//   puh_, xela, _jābū, ckph,
   {{0xddcb00d8,0x98b800af,0x00000000,0x00000000}},	//   žiūr, meră_, --, --,
   {{0xee391714,0x290aa534,0x7bdfa535,0x68fc00cb}},	//   вни_, zaba_, _niqu, zbrd,
   {{0x6d410d1c,0x63bba536,0x290a0371,0x52380416}},	//   tela, _ikun, yaba_, _مسلح_,
   {{0x290a1be9,0x6b96a537,0x6b841fd2,0x7afd02b1}},	//   xaba_, _smyg, _slig, ebst,
   {{0x69dea538,0x6b84a539,0x290aa53a,0x30a72294}},	//   _ripe, _plig, vaba_, _срав,
   {{0x6d41a53b,0x7bcd1010,0xeb9a6010,0x69dea53c}},	//   sela, _chau, тим_, _sipe,
   {{0x7bcda53d,0x63a9a53e,0x7bdf1d2b,0x69dea53f}},	//   _dhau, _mjen, _diqu, _pipe,
   {{0x7bdf002a,0x63a90a16,0x63bb011e,0xb6070024}},	//   _eiqu, _ljen, _lkun, _miġġ,
   {{0x290aa540,0x63bba541,0x7bdfa542,0x98b800af}},	//   raba_, _okun, _fiqu, deră_,
   {{0x63a90bc6,0x290a19c7,0x70e2017a,0x63bba4a5}},	//   _njen, saba_, _पल्ल, _nkun,
   {{0x7ae4070b,0xaa4608a6,0x290a2587,0x69dea543}},	// [be00] _igit, _тепл, paba_, _tipe,
   {{0x63a9a544,0x929d004e,0x63bba545,0x7bdf000d}},	//   _ajen, _pełn, _akun, _épur,
   {{0x99860493,0x799c2107,0x00000000,0x00000000}},	//   _ملکو, mirw, --, --,
   {{0x63a9025c,0x7bdf0310,0x799c0273,0x5c360070}},	//   _cjen, _xiqu, lirw, ירען_,
   {{0x63a90ea5,0x42540037,0x98b800af,0x7ae40118}},	//   _djen, إنتر, beră_, _mgit,
   {{0x63a9054e,0x799c041b,0x63bb073a,0x3ea00121}},	//   _ejen, nirw, _ekun, _žito_,
   {{0x64a300d8,0x50660c95,0xd46738bb,0x63a908c8}},	//   _дара, ртла, _кире_, _fjen,
   {{0x63a956bd,0x7ae4a546,0x799c0010,0x394300ea}},	//   _gjen, _ngit, hirw, zejs_,
   {{0x7bcd01e8,0x799c01d0,0x42540118,0x00000000}},	//   _rhau, kirw, _دچار, --,
   {{0x7bdf25ec,0x7bcda547,0x63a9022f,0x7ae444a7}},	//   _siqu, _shau, _zjen, _agit,
   {{0xdeefa548,0xfe18035d,0x40965320,0x7bcd006f}},	//   _мы_, _दिवस_, _трат, _phau,
   {{0x7bcd01e8,0x81cb0033,0x2fc00098,0xdb0f00d5}},	//   _qhau, _রূপ_, _óig_, pocí,
   {{0xc3330122,0x7bdf12c3,0x798501e8,0x602a0095}},	//   חור_, _viqu, _plhw, _təms,
   {{0x7ae403cb,0x799c01d0,0xa2ce021a,0x7bdf01f7}},	//   _egit, girw, _तरन्, _wiqu,
   {{0x7bcd0d4b,0x7bdf0815,0x37070ea6,0x3f86a549}},	//   _thau, _tiqu, ичав, _klou_,
   {{0x386d044d,0xd7f8021d,0xb8cf0066,0xc9270033}},	//   ćer_, рур_, _कश_, য়েত_,
   {{0x6b870357,0xfaff01f4,0x799c2107,0xd0f8021a}},	// [be10] _مشکل, mbë_, birw, ुराण_,
   {{0x63a9a54a,0x6b9d02b3,0x799c04fb,0xe5c40421}},	//   _sjen, lisg, cirw, осхо,
   {{0x63a9025c,0xaab800d1,0x04676118,0x48ab002d}},	//   _pjen, _مدیر_, штам, _штим_,
   {{0x6cd90070,0x6b9da54b,0x98b800af,0xdce30124}},	//   אַנצ, nisg, seră_, _tonć,
   {{0x63a9a54c,0x4ec10083,0x926b02fb,0x161e060a}},	//   _vjen, _উল্ল, ържа_, _पियर_,
   {{0x6b9d043d,0x614500ca,0x3f8600f6,0x68e50069}},	//   hisg, сека, _alou_, _jghd,
   {{0x3f860173,0x63a91123,0x00000000,0x00000000}},	//   _blou_, _tjen, --, --,
   {{0x63bb0010,0x63a9000e,0x1f6500c3,0xddc20139}},	//   _ukun, _ujen, ским, _proş,
   {{0x799c0010,0x332d02d7,0x6b9da54d,0x98b8396a}},	//   yirw, _icex_, disg, merą_,
   {{0x51740082,0x4174500b,0x7ae40014,0xbd8900d1}},	//   _والأ, _والس, _sgit, اندن_,
   {{0x3b0a0e75,0x61e9a54e,0x4433a54f,0x3f86a550}},	//   лено_, _huel, ntx_, _flou_,
   {{0x61e9000e,0x63b9a551,0x543a0070,0x6b9d7f62}},	//   _kuel, nown, נערא, gisg,
   {{0xeb9715e3,0x61e1a552,0x8d770088,0x61e90b24}},	//   сия_, _kill, _پاشا, _juel,
   {{0x61e1035f,0x645a2676,0x60c100c3,0x6d8400cc}},	//   _jill, _štim, _kylm, _hòan,
   {{0x63b9006a,0xdca24697,0x61e1a553,0x7dc600fb}},	//   kown, _наши, _mill, iðsl,
   {{0x61e1a554,0x799c1642,0x9f450118,0x61e900f6}},	//   _lill, sirw, _bulé_, _ouel,
   {{0x63b9a555,0x9f452b01,0x61e901a3,0x5fdf007c}},	// [be20] down, _culé_, _nuel, _पूछल,
   {{0xd9100357,0xb8ce0033,0x00000000,0x00000000}},	//   _زیر_, _ঔর_, --, --,
   {{0xdb0fa556,0x224d28f4,0x74130037,0x00000000}},	//   locá, _asek_, كولا, --,
   {{0x61e1a557,0x61e901d7,0x00000000,0x00000000}},	//   _aill, _buel, --, --,
   {{0x61e90831,0x61e1a558,0x2b52028b,0x2d870009}},	//   _cuel, _bill, _mayc_, _olne_,
   {{0x61e903cb,0x61e1a559,0x65750055,0x20050090}},	//   _duel, _cill, _gozh, _bwli_,
   {{0x61e1a55a,0x01330082,0xdfd00125,0x40343cab}},	//   _dill, سعود, ويت_, цейс,
   {{0x644e3dca,0x63b9004e,0x645ca55b,0x61e97a92}},	//   _isbi, cown, _irri, _fuel,
   {{0x61e1a55c,0x00000000,0x00000000,0x00000000}},	//   _fill, --, --, --,
   {{0x61e1a55d,0x61ef0248,0xf99f02e9,0xb5fb003e}},	//   _gill, _écla, nsèt_, _fráf,
   {{0xb5fb2140,0x61e901d7,0x6b9d0282,0xe0850037}},	//   _gráf, _zuel, tisg, _وجمي,
   {{0x60db02b5,0xdce3007e,0x00000000,0x00000000}},	//   _עקאנ, _koně, --, --,
   {{0x61e10225,0x6b9d00f1,0xfaff0031,0x753c0067}},	//   _yill, risg, rbë_, _obrz,
   {{0x61e101ef,0x645c0291,0x6b9d416e,0x00000000}},	//   _xill, _orri, sisg, --,
   {{0x6575114d,0x2d8c0079,0xdb0401ed,0x26cb0168}},	//   _rozh, mhde_, _ekiñ, _szco_,
   {{0x2d9ea55e,0x473500d8,0x7d0a0093,0x00000000}},	//   lite_, ўнас, _hefs, --,
   {{0x5575315d,0x64582a7d,0x2d9e11d9,0x644e0ff2}},	// [be30] огат, ævin, oite_, _asbi,
   {{0x2d9ea55f,0x61e91697,0x7c45026b,0x994d00c7}},	//   nite_, _ruel, _útró, ržų_,
   {{0x61e90083,0x63b90067,0x58d554d4,0x00000000}},	//   _suel, town, _фонт, --,
   {{0x61e139f9,0xfbc90967,0x44330024,0xd2f905f5}},	//   _sill, रतिम, rtx_, شکرا_,
   {{0x2d9ea560,0x645c14db,0x61e90dc5,0x63b9004e}},	//   kite_, _erri, _quel, rown,
   {{0x61e90083,0x2d9ea561,0x61e1058c,0x765d046a}},	//   _vuel, jite_, _qill, _irsy,
   {{0x2d9e2676,0x7dc6003e,0x397c00a5,0x297c00a5}},	//   dite_, rðsl, רטונ, רטוא,
   {{0x533413f9,0x61e1086f,0x224da562,0x61e914dc}},	//   _нест, _will, _tsek_, _tuel,
   {{0x61e17744,0x2d9e070b,0x2d87300b,0xb5fb00b5}},	//   _till, fite_, _plne_, _drág,
   {{0xb5fb0aca,0x2d9ea563,0x61e1a564,0x2d8c0037}},	//   _tráf, gite_, _uill, ghde_,
   {{0x5baa65c9,0xb5fba565,0x7f1900f8,0x2ef51b60}},	//   иком_, _frág, _نياز_, _дзер,
   {{0x3c31024e,0x645aa566,0xf4120d85,0xb5fb0187}},	//   ráv_, _štik, ופט_, _krád,
   {{0x2d9ea567,0xab5b1d1b,0x34c6258f,0x64c6021a}},	//   bite_, mlül, _वर्द, _वर्श,
   {{0x2d9ea568,0x80d00083,0x3f8d0279,0x26c201ef}},	//   cite_, _স্ট্, lheu_, _ryko_,
   {{0x765d01d2,0xa3b901c0,0xa4140831,0x00000000}},	//   _arsy, घका_, _সহ্য_, --,
   {{0xfaa60338,0xfbc302fb,0xdd25005f,0x00000000}},	//   _майо, _общо, _jūži, --,
   {{0xb6a62294,0xf50a17a3,0x6f0b00b5,0x07a36da4}},	// [be40] циал, инал_, _megc, фатн,
   {{0x7bc6a569,0x845a021d,0x26c2010b,0x00000000}},	//   llku, ирет_, _vyko_, --,
   {{0x66e61c80,0x2db602b5,0xe73a1783,0x186a0714}},	//   _мона, קלען_, _кен_, _тани_,
   {{0x2d9ea56a,0x89360332,0xd62aa56b,0xdce10228}},	//   zite_, _اٹھا, _коме_, eklī,
   {{0x2d9ea56c,0xbb3b0070,0xdce30355,0x3f8d0031}},	//   yite_, שעני, _poně, dheu_,
   {{0x753c01cc,0x201a0132,0xd01a408d,0x2d9e00cc}},	//   _ubrz, ápio_, афи_, xite_,
   {{0xcc240083,0x645c06a2,0x2d9ea56d,0x7d0a3315}},	//   _বন্ধ_, _urri, vite_, _refs,
   {{0x2d9ea56e,0xfc460314,0xb5fb003e,0xfaff0031}},	//   wite_, šíku_, _frád, njët_,
   {{0x2d9ea56f,0xe29a00c9,0x4fb300b5,0x21a6a570}},	//   tite_, _таа_, بصور, _диам,
   {{0x6609027d,0x291a0009,0x7bc60e54,0x00000000}},	//   _çeke, _ndpa_, elku, --,
   {{0x7d0a008a,0xb5fba571,0x80a600f8,0x00000000}},	//   _vefs, _trág, _بمان, --,
   {{0x3f8d0952,0x291a0027,0xdd25005f,0x00000000}},	//   cheu_, _adpa_, _gūži, --,
   {{0x7fd7012b,0x2d9ea572,0xe8e30355,0x6fc50098}},	//   _וואס_, pite_, पश्च, dóch,
   {{0xa2ab2893,0x2d9e0055,0x00000000,0x00000000}},	//   जपत्, qite_, --, --,
   {{0x67d53e19,0x7af6099e,0x00000000,0x00000000}},	//   зову, _ffyt, --, --,
   {{0x491709a3,0x7c28a573,0x4421053d,0x765d011e}},	//   _भएको_, mudr, vrh_, _prsy,
   {{0x41ca0517,0xf1ca01d1,0x7c280210,0xd6db051a}},	// [be50] ितास, ितान, ludr, ртв_,
   {{0x6d48a574,0x2bc90380,0x4421a575,0x764f021d}},	//   neda, रतवा, trh_, _vscy,
   {{0x69c70888,0x29116f6a,0x2903a576,0xd5b812ea}},	//   mlje, maza_, mbja_, ісу_,
   {{0xdfc6096a,0x6d48007c,0x69c717a2,0xb5fb053d}},	//   _سي_, heda, llje, _prád,
   {{0x6d48a577,0x020401c8,0x291a00d7,0xd17900d8}},	//   keda, дзін, _ydpa_, йскі_,
   {{0x88df00c8,0x6d480a78,0x2911a578,0x764d3ea4}},	//   _ব্যক, jeda, naza_, mway,
   {{0x764da579,0x6d48a57a,0xd3a70012,0xfaff01f4}},	//   lway, deda, _драп, njës_,
   {{0xb5fb004f,0x2911a57b,0x62355e0a,0xf65f008c}},	//   _trád, haza_, _небу, _kræ_,
   {{0x29113aa0,0x69c702f6,0x764d817b,0x60b500b5}},	//   kaza_, klje, nway, _کمائ,
   {{0x69c70c21,0x6d4817fa,0x61fba57c,0x29110f33}},	//   jlje, geda, _itul, jaza_,
   {{0x764d0103,0x63ab00cc,0x02ef00ab,0x69c700f4}},	//   hway, ongn, _छलाह_, dlje,
   {{0x61fb0159,0x2911002d,0x764da57d,0xdb0600ac}},	//   _ktul, eaza_, kway, boký,
   {{0xed591d88,0x6d48a57e,0x63ab04e6,0x29111008}},	//   _гол_, beda, ingn, faza_,
   {{0x6d48a57f,0x764d0107,0x6e290033,0x2911595c}},	//   ceda, dway, mueb, gaza_,
   {{0x7c28009e,0xfaff0031,0x00000000,0x00000000}},	//   cudr, gjës_, --, --,
   {{0xe81d0380,0xa3cb07b5,0xc0520070,0x61fba580}},	//   _फिरा_, _रील_, עזן_, _otul,
   {{0x69c702dd,0x6fc50370,0x29110b55,0x764da581}},	// [be60] blje, góci, baza_, gway,
   {{0xe6171958,0x69c7063b,0x2a605671,0x2911007b}},	//   яду_, clje, _irib_, caza_,
   {{0x98160642,0x61fb018e,0xc8c00026,0xd78a0118}},	//   _عبدا, _atul, _एडिट, _هندو_,
   {{0x764d0273,0x225f0044,0xb5fb00ac,0x6d480035}},	//   bway, _bruk_, _dráb, zeda,
   {{0x11541cba,0x6d48a582,0x6fc52127,0x7d1c7e23}},	//   дклю, yeda, cóci, órsk,
   {{0x225f0903,0xb5fb008a,0x7dc60093,0xc6930070}},	//   _druk_, _fráb, rðsk, _טאר_,
   {{0x6d48a583,0x0443a584,0x395800ea,0x61fb446f}},	//   veda, _перн, idrs_, _etul,
   {{0x6d48a585,0x291101d5,0x69c7022f,0x7c28a586}},	//   weda, zaza_, zlje, vudr,
   {{0x6d486b76,0x69c703d0,0x6e29a587,0x29111815}},	//   teda, ylje, gueb, yaza_,
   {{0x63a2a588,0x71a303fa,0xd5be021a,0xb5fb0097}},	//   lion, _зауз, ्तिज, _hrác,
   {{0x69c702dd,0xfe6f064e,0xdb06024e,0xab5b027d}},	//   vlje, ندی_, soký, slüm,
   {{0x63a2a589,0x29116289,0x764da58a,0x799e0107}},	//   nion, waza_, yway, _ampw,
   {{0x6d48a21f,0x69c70bc6,0x628274b7,0x291188c1}},	//   peda, tlje, nyoo, taza_,
   {{0x63a2a58b,0x2a600107,0x2d85252d,0xed57010b}},	//   hion, _drib_, ckle_, _ноч_,
   {{0x2911a58c,0x63a2a58d,0xb5fb0473,0xed5700fd}},	//   raza_, kion, _orác, _رشوت_,
   {{0x69c70289,0x15f10299,0x764da58e,0xf7730d93}},	//   slje, _अंदर_, tway, راز_,
   {{0x63a255bc,0x69c70496,0x2911a58f,0x6b8d0dc3}},	// [be70] dion, plje, paza_, _ilag,
   {{0x26c700ea,0x6fc50035,0xb5fb0138,0x764d25ba}},	//   āno_, róci, _arác, rway,
   {{0x6b8d7477,0x61fba590,0x80c200c8,0x764d1642}},	//   _klag, _stul, ষেত্, sway,
   {{0xf65f01b4,0x6aa200d5,0xf8b2076b,0x2bd30096}},	//   _træ_, _žofi, _ישי_, _धीमा,
   {{0xb5fb171c,0x2d850035,0x00000000,0x00000000}},	//   _drác, ykle_, --, --,
   {{0x6b8da591,0x90c51fcf,0x00000000,0x00000000}},	//   _llag, мбле, --, --,
   {{0x63a2004e,0x6b8da592,0x645a00cb,0xfe6e0118}},	//   bion, _olag, _štiv, یگه_,
   {{0x225fa593,0x7e640506,0xa3d40d4e,0x61fb073a}},	//   _truk_, _šipa, _सीप_, _ttul,
   {{0xe3b00164,0x61fb0054,0x00000000,0x00000000}},	//   _صرف_, _utul, --, --,
   {{0x6b8da594,0x6e290831,0x4c857bfa,0x00000000}},	//   _alag, rueb, длов, --,
   {{0x6b8d0888,0x1b4a1159,0x00000000,0x00000000}},	//   _blag, озни_, --, --,
   {{0xfaa6005f,0x6b8d009e,0x15ed0026,0x394a0107}},	//   дамо, _clag, जदार_, webs_,
   {{0x2a60003c,0x00000000,0x00000000,0x00000000}},	//   _qrib_, --, --, --,
   {{0x63a2a595,0x57b60099,0x6b8d525a,0x2d58002d}},	//   zion, ंव्ह, _elag, _ничь_,
   {{0x09e30970,0x6b8d521d,0x46e000b4,0x394a37e9}},	//   торн, _flag, पेनह, rebs_,
   {{0x63a22993,0x2905008a,0x2a6013fb,0x6b8d9048}},	//   xion, ðlar_, _trib_, _glag,
   {{0x7bc48d75,0x9f450176,0xab5b027d,0x00000000}},	// [be80] _ikiu, _mulà_, zlük, --,
   {{0x63a2004e,0x62820054,0x66160fe2,0x6b8d0116}},	//   wion, vyoo, rsyk, _zlag,
   {{0x63a28012,0xb5fb0187,0x6616052a,0x69dc191b}},	//   tion, _prác, ssyk, mmre,
   {{0x27f70237,0x6616a596,0xab5b013b,0x00000000}},	//   žené_, psyk, vlük, --,
   {{0x63a2a597,0xd04100a8,0xb5fb0355,0x81c90831}},	//   rion, _izlə, _vrác, োদন_,
   {{0x63a2a598,0x6282314a,0x14b70099,0x59b4021a}},	//   sion, ryoo, _अडचण, ंकटर,
   {{0x03a64717,0xb5fba599,0x63a2a59a,0x7bc40103}},	//   _живо, _trác, pion, _okiu,
   {{0x657c0009,0xab5b027d,0x04430dec,0x00000000}},	//   _horh, rlük, _шесн, --,
   {{0x03a34e36,0x657ca59b,0x7ae9011c,0x63a00069}},	//   _рито, _korh, žetk, _immn,
   {{0x6b8d0687,0xe166017e,0x7bc4002f,0xdb1d002a}},	//   _slag, _تدري, _akiu, mosé,
   {{0xe04600d4,0xdb1d00d5,0x00000000,0x00000000}},	//   _інди, losé, --, --,
   {{0xa3c000c0,0x0a6b12e8,0x4ea62ef5,0x61e8016e}},	//   ुति_, орги_, _орла, _hidl,
   {{0xfe7221a0,0x61e811e9,0xed5a0a26,0x6b8da59c}},	//   _جدا_, _kidl, _мод_, _vlag,
   {{0xc8fb02e4,0x7dcf0c61,0x657c0185,0x7bc40103}},	//   ्रेम_, løsn, _norh, _ekiu,
   {{0xa3c00437,0x61e8a59d,0x3a3900d7,0xdc3e00ea}},	//   ुता_, _midl, stsp_, rģēt,
   {{0x6d58a59e,0x7e62167f,0x6b8da59f,0x6d5a0075}},	//   _hava, _krop, _ulag, ldta,
   {{0x6d58a5a0,0x7aed2790,0x3cfb018d,0x61e8009e}},	// [be90] _kava, _igat, लुवे_, _oidl,
   {{0x6d5aa5a1,0xca4800d1,0x61e80069,0x7e62023c}},	//   ndta, _کلیه_, _nidl, _mrop,
   {{0x6d580054,0x3c38006c,0x69c50051,0x00000000}},	//   _mava, név_, _ikhe, --,
   {{0x6d58a5a2,0x7e62a5a3,0x61e8009e,0xc79700b5}},	//   _lava, _orop, _aidl, _کھڑا_,
   {{0x657c0b41,0x645a0a78,0x7aed011e,0x61e8003c}},	//   _forh, _štit, _mgat, _bidl,
   {{0x6d580a0b,0x61e80791,0x7f4201f7,0xdb1d01ff}},	//   _nava, _cidl, _aboq, llsä,
   {{0x7aed001c,0x05be0380,0x69c50118,0x61e8099e}},	//   _ogat, ्तरब, _mkhe, _didl,
   {{0x7aeda5a4,0xa4d402ce,0x7e62a5a5,0x6d586552}},	//   _ngat, _росі, _brop, _aava,
   {{0x6d58a5a6,0xe4e300c0,0x6d5a0051,0x7e620f00}},	//   _bava, _कृति_, fdta, _crop,
   {{0x6d58a5a7,0x7aed2696,0x777d0221,0x7c3a29b2}},	//   _cava, _agat, _losx, fttr,
   {{0x6d58a5a8,0x7e6206b3,0x00000000,0x00000000}},	//   _dava, _erop, --, --,
   {{0x61e8a5a9,0x69c5a5aa,0x2d8e5d82,0xa11300b5}},	//   _zidl, _akhe, _elfe_, _سوچت,
   {{0xbe87028c,0x6d58027a,0x7e62a5ab,0x6e4503e6}},	//   _تجاو, _fava, _grop, _челз,
   {{0x6d58a5ac,0xed590336,0x7aed92cd,0xa2d700ab}},	//   _gava, _хок_, _egat, _बरन्,
   {{0x1867340a,0x6e3b01b7,0xf7461303,0x00000000}},	//   нари_, ltub, нево, --,
   {{0x6d58a5ad,0x9f4602fb,0x7bc40054,0x69c501a2}},	//   _zava, _cioè_, _ukiu, _ekhe,
   {{0xcf9202b5,0x6e3ba5ae,0x6d583b3d,0x3ea00093}},	// [bea0] אטן_, ntub, _yava, _þitt_,
   {{0x443a4ede,0x6d5860c8,0x6e3ba5af,0x00000000}},	//   ttp_, _xava, itub, --,
   {{0x0326036f,0x657c02c9,0x399b02b5,0x98a6078e}},	//   еден, _vorh, _זייד, _чине,
   {{0xb5fb006c,0x61e8a5b0,0x6e3ba5b1,0x8cb6016b}},	//   _irán, _sidl, ktub, תּמא_,
   {{0x6d4302dd,0x0cac045c,0x657c0408,0x71a61482}},	//   _obna, _चश्म, _torh, надз,
   {{0x64a60be4,0x7e640009,0x6604a5b2,0xa3dc00a1}},	//   _зага, _šipo, mpik, _ठळक_,
   {{0x61e80ce9,0x395aa5b3,0xb0da0035,0x00000000}},	//   _vidl, _maps_, येंग, --,
   {{0xdb1d02e1,0x395a007c,0x7ae90506,0x63a00159}},	//   posé, _laps_, žeti, _ummn,
   {{0x6d58a5b4,0x61e80568,0x6e3b02b3,0xe2971645}},	//   _pava, _tidl, gtub, _зат_,
   {{0x4096282d,0x721b02b8,0x5bc900e7,0x60c80298}},	//   _прет, _מומח, रत्व, _tydm,
   {{0x6d5802ee,0x6fc531f4,0x6e3ba5b5,0x0caa0328}},	//   _vava, tóct, atub, ятии_,
   {{0x317ea5b6,0x6d58087c,0x60c4027d,0xd5be0067}},	//   _hotz_, _wava, ğimd, ्तुओ,
   {{0x6d58a5b7,0x2fc6a5b8,0x7bdd00d7,0xb5fb00b5}},	//   _tava, _ikog_, rmsu, _arán,
   {{0xf2d30779,0xa02402c9,0xdee32535,0x09e401c8}},	//   טער_, _größ, _сочи, лоўн,
   {{0x7aed021d,0x8d5b0122,0x6fc5a5b9,0xdcf80009}},	//   _tgat, _זכוי, mócr, _jovč,
   {{0x0aeb00ad,0x317e01cb,0x7aeda5ba,0x36d5290a}},	//   _عربي_, _lotz_, _ugat, вобр,
   {{0x569403d0,0x66040cca,0x9f46027a,0x00000000}},	// [beb0] гатт, gpik, _cioé_, --,
   {{0x57f50340,0x645500b5,0x61ef00a2,0x00000000}},	//   _ипот, _pszi, _écli, --,
   {{0xdcf8326f,0x26e200c8,0x645a02c6,0x2e3902d0}},	//   _novč, গুলো_, _štir, zèf_,
   {{0xae210299,0x395a0069,0x29130132,0x00000000}},	//   _मिलन_, _zaps_, _hexa_, --,
   {{0xe1f800c7,0x2bb600ea,0x291301b7,0x69d60d12}},	//   егі_, nāca_, _kexa_, _मीडी,
   {{0x25a500fb,0x61452695,0xa0a53148,0xdcf8023a}},	//   _öll_, тека, калд, _bovč,
   {{0x94d4751e,0x1fb5386a,0xf33300b5,0x6fc5002a}},	//   _борц, ксир, _مہاج, dócr,
   {{0xfe4500c9,0x883c00a5,0xdcf800fe,0xd00e0079}},	//   внио, פתחו, _dovč, آلي_,
   {{0x6e3b02d7,0x236d00a0,0xdb0f0031,0xee360328}},	//   utub, _inej_, ancë, вны_,
   {{0x6e3ba177,0xfce54032,0x3994033b,0x0d8503c6}},	//   rtub, копо, _käse_, тлон,
   {{0x660401a3,0x317a0070,0xdcf80107,0x00000000}},	//   zpik, _קרעמ, _govč, --,
   {{0x395aa5bb,0x661d00cd,0x6ff10228,0xdb060055}},	//   _saps_, _ovsk, _nāci, mikë,
   {{0xed4e4dcc,0xeb971960,0x395a14aa,0x7c285e55}},	//   _ко_, тия_, _paps_, ardr,
   {{0x2fcd4290,0x6f0916b1,0x41c10066,0x00000000}},	//   lleg_, lbec, शकिस, --,
   {{0x6f094a8b,0x661d1860,0xa3c12821,0xdb060031}},	//   obec, _avsk, ँवा_, nikë,
   {{0x2fcda5bc,0x6d41a5bd,0x810d05e7,0xeafa0416}},	//   nleg_, lfla, हरुख_, _غربت_,
   {{0xb8c92907,0xfbdf142a,0xf77f0225,0x66090457}},	// [bec0] _खे_, नगरम, _doç_, _çekl,
   {{0xb5fba5be,0x6604a5bf,0x62990067,0x6f0902b1}},	//   _trán, rpik, dzwo, hbec,
   {{0x6604a5c0,0x661d02c4,0x6e29a5c1,0xb5fb7676}},	//   spik, _evsk, hreb, _hrál,
   {{0x29189614,0x69cea5c2,0xb5fb01c0,0xdcf80009}},	//   lara_, llbe, _král, _rovč,
   {{0x27e003ad,0x810d0026,0x6d410408,0x2fcd0044}},	//   mmin_, हरूख_, kfla, dleg_,
   {{0xd24f00f3,0x4a9b0317,0x1a9b0070,0x2fc6a5c3}},	//   تنه_, וינג, וינע, _skog_,
   {{0xe5a30c8d,0x656e004a,0x64a6440d,0xa2ce0084}},	//   _тири, _inbh, _рава, _तरक्,
   {{0x291804f7,0x27e0a5c4,0x2fcd0bd1,0x69ce18d6}},	//   hara_, nmin_, gleg_, hlbe,
   {{0x2918a5c5,0x6e297be3,0x6d41a5c6,0x8e1300d8}},	//   kara_, greb, ffla, адыц,
   {{0x29183cb4,0x2bb600ec,0x27e0a5c7,0x6d410090}},	//   jara_, vāca_, hmin_, gfla,
   {{0x27e020fb,0x6fc520d9,0x6f09a5c8,0x291301ef}},	//   kmin_, rócr, bbec, _rexa_,
   {{0x2913043f,0x7e6d01f2,0x6e2902d7,0x27e00031}},	//   _sexa_, _šape, breb, jmin_,
   {{0x27e02a62,0x2918a5c9,0x6fc52dea,0x6aa20009}},	//   dmin_, fara_, pócr, _žofr,
   {{0x2918a5ca,0x7dc60093,0x6ad3018d,0x6ff10228}},	//   gara_, rðss, _सरीर, _sāci,
   {{0x29130391,0x28f81470,0xc3130083,0x1ae40033}},	//   _vexa_, тесь_, _হাসি_, কুলে_,
   {{0xe4e34f02,0xb5fb003e,0x26cb0168,0x656e026e}},	//   _कृषि_, _frál, _pyco_, _anbh,
   {{0x2918a5cb,0x6ff10029,0x645a25ff,0xdb1d006c}},	// [bed0] bara_, _vāci, _štip, nosí,
   {{0x291850f4,0x27e0a5cc,0x6609027d,0x995500af}},	//   cara_, amin_, _çekm, _скоц,
   {{0x80a202cb,0x6ec9000c,0x95c8917b,0x98b8002d}},	//   _केले, _हुनु, тута_, _алэт_,
   {{0x9f810093,0x9f4c00ac,0x27eb0176,0xb5fb07c0}},	//   jóð_, _budí_, _uicn_, _hrám,
   {{0x6d41a5cd,0x201e0116,0x130801e0,0x629902b1}},	//   yfla, _avti_, тній_, uzwo,
   {{0x6e2901d3,0xdb0600da,0x237f02e9,0xdb1d006c}},	//   vreb, tikë, _wouj_, dosí,
   {{0x2fcda5ce,0x349503fa,0x32060159,0x201e0168}},	//   tleg_, _савр, apoy_, _cvti_,
   {{0x6e290bc9,0x29186fe5,0xdb0601f4,0xa3c00ed1}},	//   treb, zara_, rikë, ुतः_,
   {{0x6d41081c,0xab5b01ae,0x2918a5cf,0x2fcd0044}},	//   tfla, hlüs, yara_, rleg_,
   {{0x6e29a5d0,0x27e0a5d1,0xdb0d0093,0x6f09a5d2}},	//   rreb, zmin_, _skað, sbec,
   {{0x291803d0,0x6d410c61,0x27e0a5d3,0x51841954}},	//   vara_, rfla, ymin_, _тута,
   {{0x291844bc,0x6e29a5d4,0xe81d0066,0x60c40225}},	//   wara_, preb, _फिजा_, şimc,
   {{0x9d45004b,0x2905037a,0x6d41033b,0xfe700079}},	//   _белд, ılan_, pfla, _وده_,
   {{0xed56019e,0x99d600e0,0xab5b02b1,0x21f901cb}},	//   _бош_, اقست, flüs, _mèh_,
   {{0x29183dce,0xf99f0c1f,0xb5fba5d5,0xe61f0132}},	//   rara_, nsèy_, _drám, _avô_,
   {{0x2918268f,0x7c3c12c3,0x3f8d012f,0x00000000}},	//   sara_, àrre, nkeu_, --,
   {{0x2918a5d6,0x7bc6314a,0xb5fb0079,0xb50f046c}},	// [bee0] para_, moku, _frám, िरूप_,
   {{0x7bc6a5d7,0x1a9b00c2,0x7e643015,0x29180510}},	//   loku, _נייע, _šipk, qara_,
   {{0xef19004e,0x07a640dd,0x0d160070,0x1d160070}},	//   każ_, _банн, רקעט_, רקער_,
   {{0x4426a5d8,0x7bc6a5d9,0xef190067,0x00000000}},	//   čo_, noku, jaż_, --,
   {{0xef19004e,0x6965042c,0xdb1d021d,0x00000000}},	//   daż_, _صدیق, losã, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443e01e9,0x7bc6a5da,0xdd41073a,0x853b00a5}},	//   _ët_, koku, _eŋŋi, _רגלי,
   {{0x7bc67cc4,0xdb1da5db,0x083b0070,0x6736005f}},	//   joku, tosí, געקל, ngyj,
   {{0x35d90084,0x013601b2,0xdb160260,0x05160831}},	//   _बीड़, _معاد, _ijyè, ালীর_,
   {{0x7e6d01f2,0xd65700a5,0xdd900037,0xc8850644}},	//   _šapc, ניית_, زوج_, _yaşı_,
   {{0x7bc6a5dc,0x00000000,0x00000000,0x00000000}},	//   foku, --, --, --,
   {{0xd00f00e0,0x7bc604fb,0xdb1da5dd,0x3f8d0176}},	//   _رله_, goku, posí, ckeu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afda5de,0x00000000,0x00000000,0x00000000}},	//   scst, --, --, --,
   {{0x7bc600a8,0x3a20023a,0x3cfb00a5,0x00000000}},	//   boku, _evip_, _אלונ, --,
   {{0x7d1aa5df,0xa3d4020d,0x291e008d,0x00000000}},	//   lats, _सील_, ótar_, --,
   {{0xb5fba5e0,0x398600ee,0x00000000,0x00000000}},	// [bef0] _trám, _pôst_, --, --,
   {{0x7d1a7a3a,0x00000000,0x00000000,0x00000000}},	//   nats, --, --, --,
   {{0xd5b808ae,0x69c7a5e1,0x21f90118,0x545568d3}},	//   уст_, moje, _sèh_, рвет,
   {{0x69c7a5e2,0x7d1aa5e3,0xfaff00da,0x2a69021e}},	//   loje, hats, ncë_, _krab_,
   {{0x7d1aa5e4,0xdb0f01ef,0x0cd106fe,0x7687002d}},	//   kats, locó, _हर्म, _сынж,
   {{0x7d1aa5e5,0x7bc60054,0x69c7a5e6,0xef19004e}},	//   jats, zoku, noje, waż_,
   {{0x7bc646a4,0x99590bca,0x2b490443,0x7d1aa5e7}},	//   yoku, kážu_, _obac_, dats,
   {{0x72050bf5,0x82f8004f,0x4433a5e8,0xd34600d1}},	//   _نورم, _مركز_, mux_, _نیمه_,
   {{0x69c7a5e9,0x3994022a,0x63ab7f21,0x2a69006f}},	//   koje, _läsa_, mign, _nrab_,
   {{0x7d1aa5ea,0x1c452327,0x2007008a,0x7bc6018e}},	//   gats, аном, ppni_, woku,
   {{0xeb9a03b1,0x7bc6a5eb,0x8c45290a,0x5f7400bf}},	//   вин_, toku, шене, _گالر,
   {{0xa3d5018d,0xd0a8408d,0x2b4900e5,0x00000000}},	//   हति_, _студ_, _cbac_, --,
   {{0x7d1a0010,0x7bc6a5ec,0x61ee027d,0x6f1b013a}},	//   bats, roku, _ünlü, mauc,
   {{0x69c70169,0x63ab0036,0x3a20012f,0x2a690b3e}},	//   goje, hign, _vvip_, _drab_,
   {{0xa3d50821,0xdca20cf9,0x7bc60657,0x63ab011e}},	//   हता_, _маши, poku, kign,
   {{0xcc3a02b5,0x4433035f,0x00000000,0x00000000}},	//   _סעפט, dux_, --, --,
   {{0x44330248,0x69c703c9,0x24f6002d,0x63ab10d3}},	// [bf00] eux_, boje, ачер, dign,
   {{0xf5071bdc,0x75d301b2,0x69c702d7,0x6b840341}},	//   инул_, قيقا, coje, _hoig,
   {{0x63062d82,0x224d2b66,0x7afba5ed,0x00000000}},	//   لوال, _apek_, žute, --,
   {{0x7d1aa5ee,0x232aa5ef,0x05160083,0x6b84000d}},	//   zats, тоди_, ালের_, _joig,
   {{0x443302e1,0x7d1aa5f0,0x2005008d,0x3f820093}},	//   aux_, yats, _atli_, ökum_,
   {{0x4433582f,0x6b96001e,0x6b84a5f1,0x994600ee}},	//   bux_, _llyg, _loig, _lôž_,
   {{0x7d1aa5f2,0x2eae01c0,0x6b9600e9,0x63ab2939}},	//   vats, ञप्त, _olyg, bign,
   {{0x7e6d9bbb,0x628b001e,0x7d1a04fb,0x9fae00b8}},	//   _šapa, bygo, wats, _tří_,
   {{0xb355006c,0x7d1aa5f3,0x539b011d,0x69c708c7}},	//   _دینا_, tats, _סימו, yoje,
   {{0xddc2004e,0x6b9600d7,0xbd6a527e,0xe2970009}},	//   _społ, _alyg, трие_, _тау_,
   {{0x7d1aa5f4,0x69c72c26,0x1b190086,0x6f1ba5f5}},	//   rats, voje, лжны_, bauc,
   {{0x7d1aa5f6,0x6f1b23d4,0x6b84184f,0x80bf0963}},	//   sats, cauc, _coig, _लुटे,
   {{0x6b84a5f7,0x69c7a5f8,0x7d1aa5f9,0x37cc0083}},	//   _doig, toje, pats, লগার,
   {{0x660901d6,0xdb0f0015,0x1ea91c2d,0x00000000}},	//   _çeki, tocó, _حامي_, --,
   {{0x628b004e,0x97a73f6b,0xf7730125,0x6b960b6c}},	//   zygo, арал, يار_, _flyg,
   {{0x2a69035f,0x69c7118c,0x6edd018d,0x8aa7a5fa}},	//   _trab_, soje, _परमु, _врод,
   {{0x69c70076,0x7bcd0c6a,0xa93500d8,0x645c00d1}},	// [bf10] poje, _ikau, _лепш, _asri,
   {{0x44330024,0x7d1802c4,0x6ec900ab,0xdb0f01ef}},	//   tux_, _jevs, _हँसु, pocó,
   {{0x63aba5fb,0x6b840453,0x7d18027d,0x224da5fc}},	//   tign, _yoig, _mevs, _spek_,
   {{0x44335fbe,0x28c000b4,0x00000000,0x00000000}},	//   rux_, _शुटि, --, --,
   {{0xd6db3618,0x63aba5fd,0x6f1ba5fe,0x27760070}},	//   _што_, rign, vauc, _הערש_,
   {{0x7d1819f6,0x628ba5ff,0x79850044,0x6f02099e}},	//   _nevs, rygo, _johw, _afoc,
   {{0x04950082,0x63ab0036,0xa2b303de,0x6f1b8495}},	//   _الأح, pign, _अशक्, tauc,
   {{0x7bcd01a9,0x28b80122,0x636800ca,0x6d4a033b}},	//   _nkau, יפוש_, _круг_, _abfa,
   {{0x63a902dd,0x6f1ba600,0x2294a601,0xceb900b8}},	//   _imen, rauc, _дитя, kaře_,
   {{0x7bcd3dc2,0x6e2204c3,0x6f1b0029,0x6b84a602}},	//   _akau, _dvob, sauc, _soig,
   {{0x30a70ed2,0x6b84a603,0x7d1802c4,0x4421a604}},	//   _трав, _poig, _devs, nsh_,
   {{0x69de01d2,0xf9890319,0x63a900b8,0x8b960340}},	//   _shpe, _אר_, _jmen, сроч,
   {{0xeab20332,0x63a9a605,0xdef800d8,0x69c10187}},	//   سٹس_, _mmen, _тых_, člen,
   {{0x63a93ac6,0x63bb013c,0x4421a606,0xb5fb0079}},	//   _lmen, _ljun, ksh_, _grái,
   {{0xb900a607,0x63a9a608,0x765da609,0x442101f4}},	//   _तर_, _omen, _assy, jsh_,
   {{0x07a3263e,0xc7a3846a,0x7d18908d,0x63bba60a}},	//   пасн, писк, _zevs, _njun,
   {{0x75d600bc,0x7af6005f,0x00000000,0x00000000}},	// [bf20] ميرا, _igyt, --, --,
   {{0x63bba60b,0x63a9a60c,0x44210031,0x649a0374}},	//   _ajun, _amen, fsh_, лтер_,
   {{0x28c000b4,0x130a0043,0x291a0490,0x00000000}},	//   _शुचि, гней_, _iepa_, --,
   {{0x63a91a21,0xe29a45ac,0x031a2489,0x00000000}},	//   _cmen, лае_, اتات_, --,
   {{0x7e6d7222,0x291aa60d,0x63a90024,0x63bb119a}},	//   _šapn, _kepa_, _dmen, _djun,
   {{0x55e368be,0x63a9a60e,0x6f0207e5,0x399401ba}},	//   _нояб, _emen, _sfoc, _mäso_,
   {{0xdefa005f,0x50660c7e,0x7d180a8a,0x6e224beb}},	//   лып_, стла, _revs, _svob,
   {{0x44440b41,0xb5fb004f,0x291aa60f,0x6f1900e9}},	//   mt_, _srái, _lepa_, _cewc,
   {{0x76444800,0xa3d507ba,0x877b0317,0xb5fb0079}},	//   ntiy, हतर_, ראפי, _prái,
   {{0x63a90038,0x7bcda610,0x291a012f,0x7bdf01f4}},	//   _zmen, _skau, _nepa_, _shqu,
   {{0xe6d508b6,0x40962ee3,0x6aa60033,0xdb550421}},	//   _दर्ज, _урат, _গুলো, овны,
   {{0x444405f0,0x79850159,0x6f19016e,0x63a901ed}},	//   it_, _sohw, _gewc, _xmen,
   {{0x4444a611,0xb5fba612,0x2aab0274,0x9e760365}},	//   ht_, _trái, утно_, _دهشت,
   {{0x398f00ab,0x442101e9,0x25aa00ee,0xb5fb06fe}},	//   _küsi_, ysh_, _nmbl_, _kráv,
   {{0x4444a613,0x291aa614,0x44210107,0x6f0d002d}},	//   jt_, _depa_, xsh_, _încâ,
   {{0x4444a615,0xd7f89359,0x6d481c9b,0x06150eb1}},	//   dt_, сур_, lfda, ждаю,
   {{0x41ba021a,0x76441292,0x442345f2,0xaa59a616}},	// [bf30] ेवास, gtiy, _svj_, _типу_,
   {{0x63a9a617,0x444471bb,0x63bb013c,0x4421a618}},	//   _smen, ft_, _sjun, tsh_,
   {{0x44443942,0x490f051e,0x8cad0761,0xe46b0421}},	//   gt_, _त्यो_, ुपयो, ышал_,
   {{0x213e0e8f,0x69d501ae,0x291a01f7,0x00000000}},	//   _acth_, llze, _zepa_, --,
   {{0x4444a619,0x60c4033e,0xd9f90246,0x44210c6f}},	//   at_, şiml, ंदित_, ssh_,
   {{0x2903004e,0x444406d1,0x44230009,0x2169159f}},	//   ncja_, bt_, _tvj_, рики_,
   {{0x4444a61a,0x93e90037,0xf4340c8a,0xb5fb01ef}},	//   ct_, _نفسك_, _нерэ, _cráv,
   {{0x63a9a61b,0x63bb0099,0xdfd1004f,0x64453739}},	//   _umen, _ujun, بيع_, mthi,
   {{0x644501a6,0x2903004e,0x660d42f4,0x3f860519}},	//   lthi, kcja_, npak, _doou_,
   {{0x225f01cb,0x0c251353,0xb5fb008d,0xb65c016b}},	//   _isuk_, омон, _fráv, רדזש,
   {{0x6445a61c,0xb5fb8cf6,0x61fb18af,0x7e64030a}},	//   nthi, _gráv, _huul, _šipt,
   {{0x61fb247d,0x6445a61d,0x291aa61e,0x69d5033b}},	//   _kuul, ithi, _sepa_, elze,
   {{0x61fb007c,0x291a4201,0x4444a61f,0xb69b002d}},	//   _juul, _pepa_, zt_, _sfân,
   {{0x61fba620,0x444408d7,0x64450031,0x84020124}},	//   _muul, yt_, kthi, žđic,
   {{0x61fb0f67,0xbc190044,0x23c9021a,0x4444a621}},	//   _luul, _тілі_, िकाद, xt_,
   {{0x2d871c7f,0x44440bf3,0x64450207,0x29030067}},	//   _hone_, vt_, dthi, acja_,
   {{0x44443c59,0x660d149b,0x291a01cb,0x2d87a622}},	// [bf40] wt_, gpak, _tepa_, _kone_,
   {{0x4444a623,0x764467e7,0xddc21635,0x2d87a624}},	//   tt_, rtiy, _kroš, _jone_,
   {{0x3958a625,0x4444a626,0x764427dc,0xe45a150e}},	//   mers_, ut_, stiy, рже_,
   {{0x3958a627,0xa3d40299,0x61fb6819,0x7644268c}},	//   lers_, _सीख_, _buul, ptiy,
   {{0xb5fb021d,0x2a60007a,0x6445666e,0xdb0f021d}},	//   _bráu, _jsib_, athi, ficê,
   {{0x4444a628,0xb5fb114d,0x61fb011e,0x64a600d8}},	//   pt_, _práv, _duul, _дага,
   {{0xcf9a0202,0x4444003c,0x39586039,0xe9df0300}},	//   ији_, qt_, iers_, ntúa_,
   {{0x3958306b,0x61fb0103,0x2d8793e8,0x7dd40176}},	//   hers_, _fuul, _aone_, màsi,
   {{0x39582e12,0x6609027d,0x29030035,0x3f860a54}},	//   kers_, _çekt, ycja_, _voou_,
   {{0x2d98006a,0xb5fb024e,0x3958003c,0x2b400176}},	//   óre_, _tráv, jers_, _acic_,
   {{0x39582212,0x2d87a629,0xe4fb02b5,0x2246394e}},	//   ders_, _done_, יפיש, ltok_,
   {{0x236600da,0xb5fb0076,0xddc20080,0xd9e3112b}},	//   ndoj_, _krát, _droš, पष्ट,
   {{0x2d87a62a,0x3958a62b,0x2246a62c,0x290c00d0}},	//   _fone_, fers_, ntok_, ıdan_,
   {{0x6445a62d,0x13b70f06,0x2d8700a5,0x00000000}},	//   ythi, _अद्भ, _gone_, --,
   {{0xd7fb2217,0x37ab07fa,0xddc202a7,0xdb0f0031}},	//   руг_, атан_, _groš, nicë,
   {{0x2d87a62e,0x2246a62f,0x660d4d91,0x6445006d}},	//   _zone_, ktok_, tpak, vthi,
   {{0xd50b13cf,0x2b590043,0xdb1d169c,0x29030067}},	// [bf50] لغان_, mesc_, rosä, pcja_,
   {{0x660d325b,0x6445a630,0x2b591149,0x39583585}},	//   rpak, tthi, lesc_, cers_,
   {{0x43751714,0x61fba631,0xc8d2020d,0xdb06a632}},	//   зулт, _suul, _दुपट, liká,
   {{0x6445a633,0x2b590043,0x660da634,0x61fb02e2}},	//   rthi, nesc_, ppak, _puul,
   {{0x27e9a635,0x6445a636,0xdb06a637,0xb5fb01dd}},	//   mman_, sthi, niká, _crát,
   {{0x27e9a638,0x6b9d01f4,0xb5fba639,0x00000000}},	//   lman_, ërgj, _drát, --,
   {{0x76590716,0x2d9ea63a,0xb5fb0042,0x27e9a63b}},	//   şayı, dhte_, _usáb, oman_,
   {{0x27e9a63c,0x3958598f,0x61fb0f67,0x2d8727d8}},	//   nman_, zers_, _tuul, _sone_,
   {{0x28d227bd,0xb5fba63d,0x2d871f1f,0x2b59a63e}},	//   _दुनि, _grát, _pone_, desc_,
   {{0xddc23015,0x27e92edd,0x2d9e009d,0xdbd703a6}},	//   _proš, hman_, ghte_, hääl,
   {{0xb5fb0076,0x27e9a63f,0x1b200083,0x3958a640}},	//   _krás, kman_, _ভাবে_, vers_,
   {{0xdb062eef,0x27e902e9,0x9f040841,0x395871ed}},	//   fiká, jman_, _قومو, wers_,
   {{0x27e9a641,0x39583cb9,0xa3cc020d,0x2d9e26c9}},	//   dman_, ters_, रकत_, bhte_,
   {{0x2d9ea642,0xdca5274a,0x3958a643,0x2d876637}},	//   chte_, _нали, uers_, _uone_,
   {{0xddc2a644,0x2c02022e,0x2246006c,0x2b59002d}},	//   _uroš, _रूपं_, ztok_, besc_,
   {{0x3958a645,0x27e9a646,0x2fcd0903,0x2a600189}},	//   sers_, gman_, noeg_, _tsib_,
   {{0x41cb31d7,0x395873e4,0xa3c100ab,0xf1cb0355}},	// [bf60] िवास, pers_, ुवन_, िवान,
   {{0x27e9a647,0xfaff01f4,0x25a90312,0x39940282}},	//   aman_, ndën_, يدلي_, _mäsk_,
   {{0x27e9233c,0xdb0f0176,0x044a0210,0x3994017b}},	//   bman_, ficè, спек_, _läsk_,
   {{0xb5fb0370,0x69cea648,0xdb0f0031,0x2246a649}},	//   _prát, lobe, vicë, ttok_,
   {{0xb5fb0138,0x236600f4,0x3f9f023c,0x00000000}},	//   _drás, rdoj_, dhuu_, --,
   {{0x69cea64a,0xb5fb290b,0x473600bf,0x2246a0f4}},	//   nobe, _vrát, _برگز, rtok_,
   {{0x34a700f0,0xb5fb2603,0x2246a64b,0xdb061d8a}},	//   _евро_, _frás, stok_, ziká,
   {{0xb5fba64c,0x69cea64d,0x6edd0af9,0x00000000}},	//   _trát, hobe, _परशु, --,
   {{0x443aa64e,0xed580038,0x2d9ea64f,0x31652926}},	//   lup_, teľ_, thte_, _falz_,
   {{0x27e902e9,0x4c940652,0x291e008d,0x00000000}},	//   zman_, диос, ðtal_, --,
   {{0x27e9a650,0x2b59002d,0x69ce51e4,0xdb0f0a54}},	//   yman_, tesc_, dobe, licé,
   {{0x2d9e071f,0xdb06006c,0xa3e20084,0x6d8d008d}},	//   shte_, tiká, _नीम_, _búas,
   {{0x27e902e9,0x2b590043,0x69ce0d24,0xdfa50c26}},	//   vman_, resc_, fobe, _تحلي,
   {{0x69ce0273,0x2b590043,0x23de004e,0xac261362}},	//   gobe, sesc_, _फीसद, _ефик,
   {{0x6d5aa651,0xa3be3123,0xa3cc000c,0x2bca0246}},	//   meta, ीका_, रका_, रवशा,
   {{0x443a49c2,0x1cbb0122,0xb76403d0,0x7c3a005f}},	//   dup_, _למוע, нтуй, mutr,
   {{0xd6db2eb3,0x9f4c016f,0x27e91425,0x7bcf002a}},	// [bf70] ств_, _budú_, rman_, mocu,
   {{0x6d5aa652,0x27e9a653,0x7bcf002d,0xf8ae0105}},	//   neta, sman_, locu, اکی_,
   {{0x442733d9,0x27e9a654,0x443a20fb,0x7c3a7222}},	//   én_, pman_, gup_, nutr,
   {{0x6d5aa655,0x245e01c0,0x27e99517,0x3165033b}},	//   heta, _dům_, qman_, _salz_,
   {{0x6d5a7471,0x2fcd0626,0xe6670c28,0xa29401e0}},	//   keta, voeg_, _этно, наці,
   {{0x6d5aa656,0x2d8a393f,0x443a022e,0x00000000}},	//   jeta, öbel_, bup_, --,
   {{0x6d5aa657,0x9508006c,0x00000000,0x00000000}},	//   deta, _رہنے_, --, --,
   {{0x69cea658,0x389c0317,0xa3a9046c,0x00000000}},	//   zobe, מיונ, गोश_, --,
   {{0x200c0095,0x7bcfa659,0x7e62006c,0x6d5aa65a}},	//   _etdi_, docu, _csop, feta,
   {{0x6d5aa65b,0xd5bf0096,0xa3a93556,0xa3d50067}},	//   geta, ्विज, गोर_, हतक_,
   {{0x7bcfa65c,0x656702c6,0x69ce0009,0x2fcda65d}},	//   focu, _majh, vobe, poeg_,
   {{0x2d9ca65e,0xeb970421,0xdea100fd,0x00000000}},	//   _elve_, дию_, _لیبی, --,
   {{0x6d5aa65f,0xd5bf060a,0x65a002c9,0xdce3035f}},	//   beta, ्वाज, _höhe, _kanċ,
   {{0x9f5e0d36,0x443a6bbd,0x6455a660,0x65672dc6}},	//   _että_, yup_, _opzi, _najh,
   {{0x69cea661,0x6e3b001c,0x18670dfc,0x65a000fd}},	//   robe, luub, мари_, _jöhe,
   {{0xe61aa662,0x69cea663,0x332d0069,0x7bcfa664}},	//   жда_, sobe, _ndex_, cocu,
   {{0x69ce7f6b,0x60c401d6,0x64551715,0xdcf80355}},	// [bf80] pobe, ğimi, _apzi, _nově,
   {{0xa3b00026,0x60c4033e,0xe6de0067,0xfe673c96}},	//   टोन_, şimi, _मरीज, _ید_,
   {{0x9f4c02d7,0x07a62cc7,0xa97b00a5,0x00000000}},	//   _vudú_, _жанн, _ואיכ, --,
   {{0x443aa665,0x6d5aa666,0x2a72008c,0x7dd401f7}},	//   rup_, zeta, _kryb_, làst,
   {{0x6d5aa667,0xd2505002,0x925a05bc,0x7c3a02b1}},	//   yeta, انت_, تشار_, zutr,
   {{0x6d5a5840,0x5bbb0864,0xdce30024,0xdcf8007e}},	//   xeta, _उद्व, _canċ, _dově,
   {{0x6d5a12c3,0xa3d90b4a,0x61ea7cda,0x00000000}},	//   veta, _ठीक_, rmfl, --,
   {{0x6d5aa668,0x88c00033,0x6724023c,0xdb060421}},	//   weta, _ইরাক, naij, nikä,
   {{0xb1462252,0x63a24334,0x3df40d6e,0x00000000}},	//   _онал, mhon, нзис, --,
   {{0x60cd06d3,0x67240051,0x200c0a4e,0xaad20035}},	//   şama, haij, _ttdi_, _सड़क,
   {{0x6d5a03c1,0x7bcf0db4,0xc04900e2,0x672402ee}},	//   reta, tocu, _mướn_, kaij,
   {{0x69c002e1,0x442a012f,0x7c3aa669,0x6ec90581}},	//   émen, _mvb_, rutr, _हुकु,
   {{0x6d5aa66a,0x7bcf0171,0xeda60009,0x7e62012f}},	//   peta, rocu, _ошко, _usop,
   {{0x7c3a09df,0x7bcf3637,0x6d430098,0xa2b100b4}},	//   putr, socu, _gcna, _आइस्,
   {{0x656702c4,0x4bdb004f,0x63a2a66b,0x984802fb}},	//   _rajh, _وبعد_, khon, мята_,
   {{0x1b1900c8,0xab5b027d,0x7e6d00cd,0x00000000}},	//   _থাকে_, ylüy, _šapi, --,
   {{0x55750f88,0x656701e8,0x63a2a66c,0x7c28a66d}},	// [bf90] нгат, _pajh, dhon, lsdr,
   {{0xd9e3045c,0x442aa66e,0x995401ba,0xab5b00a8}},	//   _गठित_, _bvb_, _päť_, vlüy,
   {{0x656701e8,0x672411c2,0x7c28a66f,0x7bc8000d}},	//   _vajh, baij, nsdr, éjug,
   {{0xa3a90755,0xd6d00332,0x6567012f,0xa5f95963}},	//   गों_, اقے_, _wajh, _нему_,
   {{0x6b8d0008,0xdcf800b8,0x7d0a593a,0x442a5056}},	//   _moag, _pově, _offs, _evb_,
   {{0xe0454717,0x25e600b4,0x6b8d0553,0x00000000}},	//   енки, _जीपी_, _loag, --,
   {{0x442a0223,0x00000000,0x00000000,0x00000000}},	//   _gvb_, --, --, --,
   {{0x0e650166,0x9e651b0a,0xdbd718af,0x2bbb052f}},	//   екин, евид, _jääh, _उदगा,
   {{0xa3cc1e79,0x7c2a0282,0xfe71104b,0x7c280298}},	//   रकर_, _avfr, ادب_, esdr,
   {{0x4c8537a3,0x00000000,0x00000000,0x00000000}},	//   елов, --, --, --,
   {{0xe5720779,0x3f1503ad,0x801400d8,0x6e3b0273}},	//   אַר_, _здес, _афіц, suub,
   {{0xfe7109b9,0x27f9023a,0x4c8201e0,0xdd25005f}},	//   _مدت_, _nisn_, улюв, _dūši,
   {{0x661d006d,0x998400b8,0xdd9500d8,0x3d1007df}},	//   _nwsk, émů_, _пады, _द्वे_,
   {{0x6e29008c,0x00000000,0x00000000,0x00000000}},	//   mseb, --, --, --,
   {{0x8d740647,0xa3c1a670,0xeb9a3f20,0x9f5e0260}},	//   _جانا, ुवा_, _ник_, _butè_,
   {{0x6f0902c2,0x6d414585,0x1ae60f78,0x7bc8000d}},	//   ncec, lgla, _пойм, éjud,
   {{0x29050d6f,0xdce3a671,0x6e29a672,0xb9060033}},	// [bfa0] ılar_, _manč, nseb, _ফল_,
   {{0x6d41a673,0xdce3029d,0x65a00095,0x7ae404fb}},	//   ngla, _lanč, _söhb, _izit,
   {{0xb5fb07a6,0x63a2a674,0x6d413918,0x6fcf0099}},	//   _usán, thon, igla, हकां,
   {{0x69dca675,0x24860a78,0x8c1a0122,0xb5fb0187}},	//   llre, ćom_, פוני, _tráp,
   {{0x63a2a676,0x45240033,0xe2970274,0x6e2908c8}},	//   rhon, _পাঠক_, нац_, jseb,
   {{0x63a2a677,0x442a00e2,0x7ae4002f,0x6e29008b}},	//   shon, _tvb_, _mzit, dseb,
   {{0x63a2a678,0xdce308b7,0xf99300a5,0xb88200b8}},	//   phon, _banč, ררו_, _říjn,
   {{0xf1aa01cb,0x69dc01ae,0xdd2500d8,0xa85700a5}},	//   _کاره_, hlre, _rūši, תיקה_,
   {{0x03a312a2,0x7ae4289f,0x67c5010b,0x9f4f009f}},	//   _сито, _nzit, nėja, _digà_,
   {{0x7c281a65,0x7bc4002f,0x7bd6018e,0x6b8d0211}},	//   tsdr, _ajiu, _akyu, _soag,
   {{0x7ae43772,0xdce300ee,0xdcba02fb,0x8cca04cc}},	//   _azit, _fanč, ящи_, _सुखो,
   {{0x291800de,0x67c5010b,0x7c28a679,0xdce3023a}},	//   ebra_, kėja, rsdr, _ganč,
   {{0xdfcf01ca,0x4e930416,0x7c280408,0x61faa67a}},	//   _اين_, _مشور, ssdr, _kitl,
   {{0xdb0f0279,0x67c500d8,0x61fa003c,0x6c5400c3}},	//   micí, dėja, _jitl, _акку,
   {{0xdb0f0f56,0x61fa9d1e,0xb9096017,0x7ae4a67b}},	//   licí, _mitl, _बर_, _ezit,
   {{0x61fa2129,0x657c00e9,0x8cdb016b,0xca4900f8}},	//   _litl, _anrh, _מחות, _قلعه_,
   {{0xdb0fa67c,0x39150ecb,0x2918a67d,0xfc450187}},	// [bfb0] nicí, _импр, bbra_, žíte_,
   {{0x9f5e00d5,0x7bdda67e,0x63a00282,0xd4c7034b}},	//   _duté_, llsu, _almn, нсеп,
   {{0xe3be0463,0xa3cc012f,0xc95200a5,0xdce3007a}},	//   ğına_, रकं_, _דמי_, _konġ,
   {{0xe3be06d0,0x04c8004f,0x6d410620,0x6e29001e}},	//   şına_, روني_, zgla, yseb,
   {{0x216938d0,0x6d4100e9,0x61faa67f,0x60da0be2}},	//   дили_, ygla, _bitl, _aytm,
   {{0x23690496,0xd838108a,0xa2b200b4,0x61fa024e}},	//   žaj_, šče_, _अधर्, _citl,
   {{0xdce341da,0x61fa814a,0xa06601d3,0x764d05f9}},	//   _panč, _ditl, ваща_, ltay,
   {{0x6e294190,0x776d002a,0x3994013c,0x6d41006d}},	//   tseb, ndax, _häst_, wgla,
   {{0x764da680,0x6f090118,0x61fa00d5,0x6d414283}},	//   ntay, rcec, _fitl, tgla,
   {{0x6e29120d,0x30a72235,0x6d4135b6,0x61fa0159}},	//   rseb, _прев, ugla, _gitl,
   {{0x6e295771,0xe6de0af9,0xdce3007e,0x212700e2}},	//   sseb, _मर्ज, _tanč, manh_,
   {{0x6d410014,0x3994022a,0x09da00a1,0x69c50009}},	//   sgla, _läst_, णत्य, _ajhe,
   {{0x8d651f7c,0x00000000,0x00000000,0x00000000}},	//   _авле, --, --, --,
   {{0x21270023,0x7bdd00ab,0x67c5010b,0x3f8f0260}},	//   nanh_, alsu, vėja, _hogu_,
   {{0x3f8f007c,0x2918a681,0xdca50390,0x69dc05ee}},	//   _kogu_, rbra_, _шаки, rlre,
   {{0x21270019,0x7ae4028b,0x3f8f013a,0x764d00a3}},	//   hanh_, _tzit, _jogu_, ftay,
   {{0x3f8f0537,0x3994022a,0x764d11e9,0x7ae4a682}},	// [bfc0] _mogu_, _bäst_, gtay, _uzit,
   {{0xa8060ea0,0x67c500d8,0x26dc013a,0x3f8f0228}},	//   _изол, rėja, āvo_, _logu_,
   {{0x499b0d85,0x764d002f,0x21278de6,0x032601e0}},	//   _חשיב, atay, danh_, вден,
   {{0x61ca1bc6,0x3f8f03fd,0x78a301c2,0x61fa264c}},	//   ाक्ष, _nogu_, _ünva, _sitl,
   {{0x425400ad,0x15ba010b,0x60cd01fb,0x3994017b}},	//   انتر, _жывы_, şaml, _fäst_,
   {{0x657c02c7,0x7f950aca,0xa3e20084,0x3994013c}},	//   _unrh, _máqu, _नीर_, _gäst_,
   {{0x934611ca,0x3f8f0ce9,0x61faa683,0x33f60012}},	//   _инве, _bogu_, _vitl, _ачас,
   {{0x61fa2b09,0x7afb3b1a,0xdb0fa684,0x25e60354}},	//   _witl, žuti, ticí, _जीती_,
   {{0x61faa685,0x3f8f01d7,0xa3c105a2,0x443a0159}},	//   _titl, _dogu_, ुवर_, lrp_,
   {{0x61fa0244,0x2ca900b8,0x212700e2,0x54e60067}},	//   _uitl, _řada_, canh_, _कराए_,
   {{0x7e6d022f,0x00000000,0x00000000,0x00000000}},	//   _šapt, --, --, --,
   {{0x443a006b,0x3f8f0139,0xc4d300a5,0x00000000}},	//   irp_, _gogu_, יגת_, --,
   {{0xa5bb4a12,0x00000000,0x00000000,0x00000000}},	//   _kvót, --, --, --,
   {{0xdee339e8,0x3f8f0031,0xdd9300d8,0x5e5700a5}},	//   _точи, _zogu_, _вашы, _סיוע_,
   {{0x59f80043,0x316c03bc,0x03220066,0xcbe700af}},	//   теря_, _madz_, मराह_, _иции,
   {{0xb8db5b7f,0x764da686,0x97a40043,0xddd90107}},	//   _आइ_, ttay, арул, _apwň,
   {{0x8bb40e0c,0xd7f8a687,0xeb1f00dc,0x443a0051}},	// [bfd0] _خصوص, тур_, परीत_, erp_,
   {{0x6b9d6039,0x2127a688,0x9f9a00ab,0x00000000}},	//   lksg, xanh_, _hääl_, --,
   {{0x764d1481,0x69d5a689,0xf9920397,0xdce30029}},	//   stay, moze, _הרי_, _kanā,
   {{0xdb1da68a,0x9f4c02d7,0x317ea68b,0xdb0f01f7}},	//   mosó, _mudó_, _antz_, nicà,
   {{0xdb1d3207,0xf990042c,0xdce30228,0x39940282}},	//   losó, _طبی_, _manā, _gäss_,
   {{0x644a12c3,0xa5bb004e,0x2a69028b,0x1a9c1804}},	//   àfic, _dwóc, _msab_, וידע,
   {{0x65a000a8,0x27eb00e2,0xe0550037,0xdb1d00be}},	//   _köhn, _khcn_, اختب, fosü,
   {{0x43940421,0x69d5a68c,0x6d5c00be,0x6b9d0051}},	//   _касс, hoze, õran, jksg,
   {{0x69d52a6d,0x02b700b4,0x29010284,0x2a690027}},	//   koze, _अधिभ, _ogha_, _nsab_,
   {{0x9f4c0176,0x2fc60118,0x6b9d02a2,0x65a002b1}},	//   _budó_, _ejog_, eksg, _löhn,
   {{0x75eb00d0,0xdb0f0176,0x41df37e8,0xdce302d4}},	//   müzd, ficà, _पीएस, _banā,
   {{0x29cd016f,0x2b490069,0x9f4c02d7,0x20050160}},	//   hľad_, _ccac_, _dudó_, _iuli_,
   {{0x539a00c2,0x6f1b0370,0x200500a7,0xff0401d3}},	//   גירו, mbuc, _huli_, _тяхн,
   {{0x8c4507fa,0x20054368,0x2fdf003c,0x186a01d3}},	//   _беке, _kuli_, llug_, наги_,
   {{0xc4be0083,0x23d3021a,0x2a690282,0xfbdf021d}},	//   _অর্জ, तवाद, _esab_, blê_,
   {{0x2005a68d,0x6f1b02c9,0x7ddd01f7,0xdb0f021d}},	//   _muli_, nbuc, dèsi, ricã,
   {{0xe57a24df,0x2125028b,0x2005a68e,0x6e3b0051}},	// [bfe0] нза_, _oelh_, _luli_, nrub,
   {{0xc9666dc0,0xfe1b32b1,0xdb1d002a,0xab5b00b5}},	//   _свой, पीएस_, bosó, nnün,
   {{0x200500d1,0x26cb0a4e,0xdb0f2314,0x3204a68f}},	//   _nuli_, _exco_, licá, _sumy_,
   {{0x42ca0c98,0xa22a07b4,0x7c2e0b06,0x2fdf0221}},	//   нген_, ежда_, ábri, jlug_,
   {{0x84e60066,0x758400d1,0x2005a690,0xdb0f07a6}},	//   _करवट_, _پیام, _auli_, nicá,
   {{0x27e0a691,0x200509d6,0xb4261d05,0x67260223}},	//   llin_, _buli_, _معرو, _hekj,
   {{0x66063115,0x27e0a692,0x2fdf574d,0x64a63c0c}},	//   _hukk, olin_, flug_, _сава,
   {{0x6606a693,0x69d5a694,0x20051051,0x63b90035}},	//   _kukk, zoze, _duli_, ciwn,
   {{0x244e024e,0x656e0088,0x66062d3e,0xdd900037}},	//   lým_, _kabh, _jukk, قوة_,
   {{0x27e03114,0xdb0f0b06,0xdce30029,0x6606018e}},	//   hlin_, dicá, _sanā, _mukk,
   {{0x244e086d,0x6606a695,0x69d50d5c,0x3cf8330b}},	//   ným_, _lukk, voze, ärv_,
   {{0x656e148b,0xdb0f2587,0x6e3ba696,0x645c011e}},	//   _labh, ficá, brub, _mpri,
   {{0x244e0187,0x69d501d7,0x6b9da697,0x66060196}},	//   hým_, toze, rksg, _nukk,
   {{0xf2d300c2,0x645ca698,0x244e1840,0x656e0211}},	//   מער_, _opri, kým_, _nabh,
   {{0x69d5a699,0xddc208b7,0x67260185,0xa2bb0067}},	//   roze, _krož, _bekj, _शेन्,
   {{0x6606a69a,0x2a690189,0x7ddd02d0,0x2d8c01ff}},	//   _bukk, _tsab_, vèsi, ljde_,
   {{0x2a690b04,0xa9c70a72,0x656e0037,0x69d59269}},	// [bff0] _usab_, _مزدو, _babh, poze,
   {{0x656e0a24,0x2d9ea69b,0xd838108a,0x660610db}},	//   _cabh, nkte_, šča_, _dukk,
   {{0x27e0a69c,0x6d4aa69d,0x2d9e3912,0xddc2008b}},	//   blin_, _mcfa, ikte_, _orož,
   {{0xae040567,0x932721b6,0xb275002d,0x656e0315}},	//   रदान_, اران, илеш, _eabh,
   {{0x2005a69e,0xfdf60324,0xb5fb00ac,0x656e11d9}},	//   _suli_, ीदास_, _mráz, _fabh,
   {{0x656e1093,0xe2961159,0x2005a69f,0x6f02a6a0}},	//   _gabh, раш_, _puli_, _agoc,
   {{0xd00e4dc0,0x34953efc,0xa0a58cda,0x10a5311e}},	//   ولو_, _тавр, райд, рийн,
   {{0xe3b00041,0x6e3b1431,0x66060159,0xa2952659}},	//   _فرق_, trub, _yukk, _кабі,
   {{0xdb0601d2,0x44230189,0x6f1b0bf7,0x4431a6a1}},	//   shkë, _hwj_, rbuc, _hvz_,
   {{0x2005a6a2,0xdcf80029,0x442301e8,0x27e01862}},	//   _tuli_, _novē, _kwj_, zlin_,
   {{0xb17a02b5,0xa17a02b5,0x27e02a8d,0xb5fb00ac}},	//   _שטער, _שטעט, ylin_, _bráz,
   {{0xddc200d8,0x765da6a3,0x6e3b0c47,0x2d9e0b0d}},	//   _grož, _opsy, prub, akte_,
   {{0x7ff403c7,0x4423006f,0x27e002a7,0x6e22001e}},	//   _اسلا, _lwj_, vlin_, _gwob,
   {{0x2d9e15e5,0x3f8d0c99,0x3ead00fd,0x27e03574}},	//   ckte_, ljeu_, mzet_, wlin_,
   {{0x656e02a8,0xa3d510b7,0x660602db,0x4423006d}},	//   _rabh, सका_, _sukk, _nwj_,
   {{0x244e1840,0x656ea6a4,0xb5fb00d5,0x66062931}},	//   vým_, _sabh, _gráz, _pukk,

   {{0x27f29497,0xb69b002d,0x27e006d1,0x3ead0223}},	// [c000] rmyn_, _sfâr, rlin_, nzet_,
   {{0x649a107b,0x244e024e,0x1a9b0317,0xdb0402a2}},	//   ктер_, tým_, _סייע, _olië,
   {{0xb4660ecf,0x4423006f,0x75270009,0x67260093}},	//   ркел, _cwj_, _dejz, _tekj,
   {{0xa3b0004e,0xe29a01c8,0x244e053d,0x27e00024}},	//   टों_, кае_, rým_, qlin_,
   {{0x656e003b,0x443100af,0x98a300ea,0x2d9e00d4}},	//   _tabh, _evz_, majā_, ykte_,
   {{0xfe080028,0x442301e8,0x7644000e,0x77640443}},	//   _nữa_, _fwj_, muiy, leix,
   {{0xddc20690,0xf1a90833,0xdb0401e4,0x6e220067}},	//   _prož, دانه_, _clië, _swob,
   {{0x4444a6a5,0x6e220c1f,0x77640955,0x98a300ea}},	//   mu_, _pwob, neix, najā_,
   {{0x4444a6a6,0xe1fa1294,0xfe080019,0x4423006d}},	//   lu_, _ага_, _bữa_, _zwj_,
   {{0x4444980f,0x4423006f,0x3d160099,0xb7f802b4}},	//   ou_, _ywj_, पुढे_, ंगडम_,
   {{0x2d9e06c3,0xb5fb024e,0x8fa60573,0x4423006d}},	//   rkte_, _práz, _каже, _xwj_,
   {{0x4444a6a7,0xddc90528,0xa3cc252b,0x6e220027}},	//   iu_, rveš, रकट_, _twob,
   {{0x4444a6a8,0x77640443,0x7e79001e,0xddc97946}},	//   hu_, deix, _grwp, sveš,
   {{0x4444a6a9,0x1cba0037,0x6b5c08c8,0x65a002b1}},	//   ku_, _لاعب_, _pågæ, _böhm,
   {{0x44440936,0xa3d654fe,0xad650118,0x77640392}},	//   ju_, हवा_, _دانه, feix,
   {{0x4423006d,0xf7700037,0xb8ff08b0,0x3cfb00a5}},	//   _rwj_, واق_, _तड_, _בלונ,
   {{0x4444a6aa,0x752775d0,0xe6670bfe,0x4431647b}},	// [c010] eu_, _pejz, штво, _svz_,
   {{0x6d480b04,0x4444a6ab,0x443100d8,0x00000000}},	//   ngda, fu_, _pvz_, --,
   {{0x54553be4,0x442301e8,0x69c7030a,0x77640392}},	//   свет, _qwj_, mnje, beix,
   {{0xdfc60c74,0xe3b002ed,0x442301e8,0x69c7008b}},	//   _ري_, ورن_, _vwj_, lnje,
   {{0x4444a6ac,0x4df60722,0x75278de7,0x672d1dfe}},	//   au_, ँगाई_, _tejz, maaj,
   {{0xdca60514,0x672d0086,0x4423006f,0x255706fe}},	//   _فى_, laaj, _twj_, _dělí_,
   {{0x4444a6ad,0x6d48011e,0xa3e2007c,0xb5fb00d5}},	//   cu_, dgda, _नीक_, _vpád,
   {{0xfe0801a5,0x672da6ae,0xfaff01f4,0x69c713a6}},	//   _sữa_, naaj, ndës_, hnje,
   {{0x3ead0129,0x3f9f3f60,0xc8e40035,0x6445a6af}},	//   uzet_, rkuu_, _गर्म_, luhi,
   {{0xcda92e63,0x51840819,0x4c692ab4,0x3eada6b0}},	//   اهده_, _муха, гион_, rzet_,
   {{0x69c702dd,0x644500a7,0x02b72874,0xeb9a00c3}},	//   dnje, nuhi, _अधुन, гин_,
   {{0xe0d003c7,0x09b200e7,0x656529c9,0x672da6b1}},	//   _غزل_, ुच्य, hehh, jaaj,
   {{0x4444a6b2,0xed590aec,0xb5fb0042,0x7bc64df9}},	//   zu_, _бол_, _fráx, rnku,
   {{0x4444a6b3,0x69c704c3,0x9f4f0176,0x7ddd0118}},	//   yu_, gnje, _nigú_, gèst,
   {{0x776412c3,0x68e901c0,0xe73a144b,0x4444a6b4}},	//   teix, ředn, лев_, xu_,
   {{0x81cd00c8,0x6445a6b5,0x81bf0083,0x672da6b6}},	//   রতি_, duhi, ীতি_, gaaj,
   {{0x46ea02c4,0x776412c3,0x4444a6b7,0x69c705e2}},	// [c020] удан_, reix, wu_, bnje,
   {{0x6b965891,0x69c700f4,0x6445a6b8,0x00000000}},	//   _hoyg, cnje, fuhi, --,
   {{0x4444a6b9,0x6445a6ba,0xd7ca0312,0x7ae900ea}},	//   uu_, guhi, _موده_, ļete,
   {{0x7e691982,0x6b960a21,0x00000000,0x00000000}},	//   kwep, _joyg, --, --,
   {{0x4444542c,0x6d480602,0x91e636eb,0x4256315d}},	//   su_, ygda, боде, стет,
   {{0x6445a6bb,0xa97a02b5,0xe9dfa6bc,0x65a00095}},	//   buhi, ראַכ, ltúr_, _möhk,
   {{0xfaff01d2,0x4444a6bd,0x443e01a5,0xdb06004e}},	//   ndër_, qu_, _ít_, nikó,
   {{0x69c70293,0xef9801f2,0x1e14027a,0x00000000}},	//   znje, ркиш_, омия, --,
   {{0x2a6001e8,0xddc20009,0xf77300a5,0x63a2a6be}},	//   _npib_, _asoš, לקה_, mkon,
   {{0x6b840027,0x9f5e00fe,0x00000000,0x00000000}},	//   _anig, _dutá_, --, --,
   {{0xcb0420d8,0x4c941517,0x69c7042a,0x987800fe}},	//   रखंड_, цинс, vnje, _báča_,
   {{0x63a2a6bf,0xddcf0506,0xd90f02fd,0xb5fb021d}},	//   nkon, češl, کید_, _usáv,
   {{0xddc20029,0x69c7011c,0xb5fb0042,0x64450027}},	//   _esoš, tnje, _tráx, zuhi,
   {{0x6b84a6c0,0xfe3702b5,0x67c5010b,0x64455848}},	//   _enig, _פרוי_, mėji, yuhi,
   {{0x63a2a6c1,0x97a72691,0x69c70496,0xb4e797c4}},	//   kkon, брал, rnje, _परे_,
   {{0x69c7a6c2,0x68e901c0,0x8aa700d8,0xaada1fc3}},	//   snje, ředo, _грод, _युवक,
   {{0x69c728c2,0x2a60022e,0xdb0d01d6,0x63a2038d}},	// [c030] pnje, _gpib_, _amaç, dkon,
   {{0x7aed0291,0x6445a6c3,0x672d6f5e,0xec090019}},	//   _izat, tuhi, saaj, _mến_,
   {{0x63a20a8a,0x93190037,0x75eb013b,0x00000000}},	//   fkon, لقاء_, güza, --,
   {{0x6445a6c4,0x67c500d8,0x756500b5,0x63a2a6c5}},	//   ruhi, kėji, _ڈیرہ_, gkon,
   {{0xe1f100d1,0x644511e9,0x91051d67,0xec090023}},	//   وست_, suhi, опле, _nến_,
   {{0x6445a6c6,0x67c5010b,0x80151da6,0x63a200b9}},	//   puhi, dėji, офиц, akon,
   {{0xa2d911b5,0x299c00a5,0x00000000,0x00000000}},	//   _फुर्, רסומ, --, --,
   {{0xee390896,0x2d9891c1,0xec0901a5,0x224608dd}},	//   ани_, ören_, _bến_, buok_,
   {{0x63a90ecf,0xd2510754,0xdb0600be,0xa3e20099}},	//   _ilen, _زنا_, rikü, _नीट_,
   {{0x63a9007e,0x3134a6c7,0x7bcd0328,0x00000000}},	//   _hlen, _неур, _ajau, --,
   {{0x63a9a6c8,0x7aed01d5,0x7e690345,0x7bcd00c7}},	//   _klen, _azat, swep, _bjau,
   {{0xf9890bed,0x67c5010b,0x5e591d13,0x63a90118}},	//   _בר_, bėji, _видя_, _jlen,
   {{0x7997011e,0x7bcd012f,0x63a953be,0x63bb0cb9}},	//   _boxw, _djau, _mlen, _mmun,
   {{0x63a9a6c9,0xdca50cb5,0x63a247bc,0x7aed01cb}},	//   _llen, _мали, zkon, _dzat,
   {{0x929d006a,0x63a25f89,0x63bb09d6,0x63a9136b}},	//   _ogło, ykon, _omun, _olen,
   {{0x6b84001e,0x9f460019,0xec090019,0x2246011e}},	//   _unig, _khoá_, _yến_, yuok_,
   {{0xe61742c2,0x79970345,0xa2d90bdd,0x00000000}},	// [c040] жду_, _foxw, _फुल्, --,
   {{0x63a9a6ca,0x63bba6cb,0xba9b00a5,0x7ae4007b}},	//   _alen, _amun, _כספי, _iyit,
   {{0x130a004c,0x63a2665f,0x63a9a6cc,0xb5fb0097}},	//   аней_, tkon, _blen, _spác,
   {{0x63a99f2d,0x65a0017b,0x69dca6cd,0x9f4c0132}},	//   _clen, _möhi, lore, _judô_,
   {{0x63a23397,0x7f9c0392,0x84e6046c,0xb5fb00fd}},	//   rkon, _xéqu, _करकट_, _csás,
   {{0x63bb31ff,0x7ae404fb,0x3167119b,0x67c500c7}},	//   _emun, _myit, genz_, vėji,
   {{0xe57100c2,0x6286308b,0xbfaa00f0,0x03a66747}},	//   _אַן_, _škod, итие_, _диво,
   {{0xe29a0a93,0xdfd00082,0x69dca6ce,0xa3e21ea9}},	//   _каб_, عية_, hore, _नीच_,
   {{0x69dc070b,0x7ae4a6cf,0x3167a6d0,0x80da0099}},	//   kore, _nyit, benz_, _पुरे,
   {{0x929d006a,0x69dc0083,0xdd9a11cd,0x81f6006c}},	//   _zgło, jore, рши_, _بہتر_,
   {{0x7ae429ac,0xdb1d02e1,0x63bb0297,0x7aed278b}},	//   _ayit, lisé, _ymun, _szat,
   {{0x67c5010b,0x212c0031,0x7ae401d5,0x98a30067}},	//   pėji, _hedh_, _byit, nają_,
   {{0xdb1da6d1,0x7ae40010,0xdce3010b,0x200c0116}},	//   nisé, _cyit, _manę, _hudi_,
   {{0xf1bc06fe,0x7e62010d,0x7aed00ac,0x00000000}},	//   ्चिन, _ipop, _vzat, --,
   {{0xa3bc00a1,0x98a30035,0xa3da473a,0x7ae4018e}},	//   ेचा_, kają_, ठका_, _eyit,
   {{0x3167033b,0xb8f31ca8,0x7aeda6d2,0x200ca6d3}},	//   zenz_, _वश_, _tzat, _mudi_,
   {{0x1ab40086,0x200ca6d4,0x7aeda6d5,0x98a3004e}},	// [c050] _объя, _ludi_, _uzat, dają_,
   {{0x8b3500b5,0x63bb0031,0xb5fb0345,0x98a1a6d6}},	//   _بڑھت, _smun, _asár, _cehă_,
   {{0x200c02dd,0xdce30009,0x63a9a6d7,0x3f8603d0}},	//   _nudi_, _vanć, _plen, _onou_,
   {{0x61d30b35,0x98a30035,0xe51b00b4,0xb51b074f}},	//   दक्ष, gają_, _प्रि_, _प्रय_,
   {{0x4433009f,0x38c903fc,0x3167033b,0xdb7c0070}},	//   ssx_, _خاکی_, tenz_, ינאכ,
   {{0x200ca6d8,0x3f860260,0x59db00b4,0x6d5a0223}},	//   _budi_, _anou_, णविर, jfta,
   {{0x7bdda6d9,0x316701ae,0x200c1a7f,0x98ba027d}},	//   kosu, renz_, _cudi_, _yapı_,
   {{0x63bb070b,0x645701e8,0x63a90118,0xc4d200a5}},	//   _umun, mtxi, _ulen, _נגן_,
   {{0x69dca6da,0xdd9103c7,0x7bdd00fd,0xdb1da6db}},	//   yore, فوظ_, dosu, cisé,
   {{0xc05b0a55,0x41b51062,0x212c0118,0x7ae401d5}},	//   _від_, _عمار, _gedh_, _ryit,
   {{0x69dc0926,0x6575a6dc,0x320d6dcd,0x7e62a6dd}},	//   vore, _mazh, _huey_, _epop,
   {{0x7bdda6de,0x6d5a0b3e,0x320d00d7,0x6575a6df}},	//   gosu, afta, _kuey_, _lazh,
   {{0xde5800d8,0x3a990421,0x200c023a,0x00000000}},	//   _маці_, отрю_, _zudi_, --,
   {{0xceb202b5,0x200c012f,0xa2cc1e82,0x98a30067}},	//   _איד_, _yudi_, तपत्, zają_,
   {{0x2adc0084,0x69dc2a13,0x2d87a6e0,0x7e7b008a}},	//   _गुरु_, rore, _inne_, lvup,
   {{0xdb1d006c,0x4c3a00a5,0xd70a010b,0x67c500c7}},	//   yisé, _התקב, снае_, kėju,
   {{0x69dca6e1,0x7ae4007b,0x65750c6f,0x00000000}},	// [c060] pore, _uyit, _bazh, --,
   {{0x7abb00a5,0x98a30035,0xdb1d000d,0x67c5010b}},	//   _לצפו, wają_, visé, dėju,
   {{0x999b0122,0x399b0317,0x98a30067,0x765600c3}},	//   _הביט, _הייד, tają_, styy,
   {{0x200c6497,0xdb1d3f18,0x320d0453,0xdc3b00ac}},	//   _rudi_, tisé, _buey_, _náče,
   {{0x200ca6e2,0x6286082d,0x3205a6e3,0x98a30035}},	//   _sudi_, _škob, _bily_, rają_,
   {{0xdb1d9b7c,0x67245c92,0x999900d5,0x3f8600ee}},	//   risé, lbij, pusť_, _snou_,
   {{0x7e62a6e4,0x7bdda6e5,0x3205007e,0x6ac80ac4}},	//   _spop, yosu, _dily_, रपुर,
   {{0x2d87a6e6,0x44380409,0xb5fb002a,0x752e0051}},	//   _anne_, _ivr_, _usár, _hebz,
   {{0x442a999e,0x7bdd0254,0xdd1b07c0,0x835300fd}},	//   _hwb_, vosu, _dážd, _سپلا,
   {{0x200c39ea,0x44443d29,0x64430029,0x9c383ef3}},	//   _tudi_, or_, šnie, опот_,
   {{0x7bdda6e7,0x76440457,0x4444a6e8,0x1bd50fa7}},	//   tosu, hriy, nr_, доня,
   {{0x444459d2,0x2d87a6e9,0x68e901c0,0x920200ea}},	//   ir_, _enne_, ředk, žāda,
   {{0x44440938,0x753ca6ea,0x764409df,0x6724a6eb}},	//   hr_, _odrz, jriy, dbij,
   {{0x7644a6ec,0x00000000,0x00000000,0x00000000}},	//   driy, --, --, --,
   {{0x4444a6ed,0x7bdda6ee,0x442a0051,0xec0900e2}},	//   jr_, posu, _nwb_, _yếm_,
   {{0x44447de9,0x6280a6ef,0x672473c0,0x00000000}},	//   dr_, _ormo, gbij, --,
   {{0x44380248,0x442aa6f0,0xdb1d00e9,0x6575a0db}},	// [c070] _avr_, _awb_, lisï, _pazh,
   {{0x64570484,0x4444a6f1,0x4438a6f2,0xb60600ea}},	//   ttxi, fr_, _bvr_, jošā,
   {{0x657501d2,0x442aa6f3,0xf9920122,0x4444a6f4}},	//   _vazh, _cwb_, _סרט_, gr_,
   {{0x320500a0,0x61e10031,0x7644a6f5,0xb602002a}},	//   _sily_, _skll, briy, ñáro,
   {{0x27e9a6f6,0xd25b1958,0x78a101ff,0x32051dab}},	//   mlan_, сце_, älvf, _pily_,
   {{0x27e90e81,0x4444a6f7,0x442a01e8,0xfa780122}},	//   llan_, br_, _fwb_, פעות_,
   {{0x32050187,0x442a102f,0xd49800af,0x27e901b7}},	//   _vily_, _gwb_, _ерт_, olan_,
   {{0x27e9a6f8,0xd8380187,0x753c3f5d,0x00000000}},	//   nlan_, áči_, _zdrz, --,
   {{0x66070a75,0x62800b67,0xc2c40037,0x27e9a6f9}},	//   _kijk, _grmo, _كيفي, ilan_,
   {{0x27e9a6fa,0x67240ce9,0xd83802c6,0x442a006d}},	//   hlan_, zbij, šči_, _ywb_,
   {{0x442a0d4b,0xbb46a093,0x673d044d,0x27e9a6fb}},	//   _xwb_, менк, _odsj, klan_,
   {{0x547a0122,0xfc3f1840,0x66070a75,0xff500312}},	//   קטרו, čí_, _lijk, _مخه_,
   {{0xeb970021,0x27e9a6fc,0x5f050409,0x8db500d4}},	//   фия_, dlan_, _ўзла, _оскі,
   {{0x4444a6fd,0x7644a6fe,0xdd9400d8,0x2ca900b8}},	//   yr_, vriy, _пачы, _řadu_,
   {{0xa3dd02e4,0x661da6ff,0x660fa700,0xeb9a002d}},	//   डवा_, _atsk, _auck, _мик_,
   {{0x7644a701,0x44210e8f,0x2fcd016e,0x27e9a702}},	//   triy, dph_, nneg_, glan_,
   {{0x4444001e,0x6724a703,0x442a0221,0x660701e4}},	// [c080] wr_, rbij, _swb_, _bijk,
   {{0x27e9a704,0x4444a705,0x272c0028,0x7644a706}},	//   alan_, tr_, ến_, rriy,
   {{0x44445bcb,0x27e9a707,0x7644011e,0x442a006d}},	//   ur_, blan_, sriy, _qwb_,
   {{0x4444a708,0x7644a701,0x27e901a6,0x2918a709}},	//   rr_, priy, clan_, lcra_,
   {{0x27e0a70a,0x12170c26,0x6445a70b,0x660f033b}},	//   moin_, وتوث_, arhi, _guck,
   {{0x442a01a9,0x64430caa,0x444458d1,0x443800af}},	//   _twb_, ánic, pr_, _tvr_,
   {{0x660fa70c,0x00000000,0x00000000,0x00000000}},	//   _zuck, --, --, --,
   {{0x64430169,0x27e0a70d,0x69cea70e,0x660701e4}},	//   šnic, noin_, hnbe, _zijk,
   {{0x6ac819b7,0x8d6a0431,0xb5fb0097,0x62800051}},	//   रपोर, ојна_, _opál, _urmo,
   {{0xf1aa00d1,0x69ce94cc,0x68e900b8,0x27e9a70f}},	//   _باره_, jnbe, ředi, zlan_,
   {{0x4f960036,0x27e9a710,0xdb04008d,0x27e00421}},	//   _орду, ylan_, _smið, koin_,
   {{0xf0b702b5,0x61eaa711,0x27e0a712,0xaab50210}},	//   _קלאר_, llfl, join_, еймі,
   {{0x27e901ff,0xdb0600b5,0x27e07f8d,0x332600d5}},	//   vlan_, zikö, doin_, ibox_,
   {{0x660fa713,0x27e9099e,0x0cd43174,0x69ce19b4}},	//   _ruck, wlan_, _полю, gnbe,
   {{0x27e90332,0x6607a714,0x660f5294,0x22460223}},	//   tlan_, _rijk, _suck, hrok_,
   {{0x2fc40069,0x660fa715,0xd7f80009,0x2d9c0a8a}},	//   nimg_, _puck, дуу_, _hove_,
   {{0x35f509c0,0x3ea47492,0x672f08b7,0x00000000}},	// [c090] епар, nymt_, _vecj, --,
   {{0x27e9a716,0x2d9c12c3,0x660fa717,0x3326a2eb}},	//   slan_, _jove_, _vuck, ebox_,
   {{0x2d9c00a5,0x672f0176,0x332600a2,0x66070207}},	//   _move_, _tecj, fbox_, _vijk,
   {{0x2d9ca718,0x660701e4,0x644503d0,0x27e0a719}},	//   _love_, _wijk, rrhi, coin_,
   {{0x201e68d5,0x661d053c,0xdcef0009,0x99d40987}},	//   _atti_, _utsk, _čeča, _ستیا,
   {{0x2d9c3d86,0xdb1d014c,0x018b00c3,0x44210051}},	//   _nove_, disí, ющей_, pph_,
   {{0x2fcd012f,0x201e0176,0x213e0023,0xc0e20431}},	//   tneg_, _ctti_, _ddth_, лошк,
   {{0xb4ab0437,0x80be00a1,0x22466ec2,0x6db900d5}},	//   गनी_, _वेळे, brok_, hňat,
   {{0x201e01d6,0x69ce0298,0x63a400c3,0xe81600ab}},	//   _etti_, ynbe, öine, _दूना_,
   {{0x2fcd001e,0x7bcf01e9,0x2d9c0f00,0x00000000}},	//   sneg_, encu, _cove_, --,
   {{0x6ac80569,0xdca532fa,0x764d91b5,0xfbc63f20}},	//   रप्र, хани, huay, ебно,
   {{0x7f84004f,0xdb040a39,0xb5fb0187,0xcc2400b5}},	//   _للمن, _aliá, _spál, کریٹ,
   {{0x1a660fa2,0x27e000c3,0x65a002b1,0x00000000}},	//   ریدی_, voin_, _möhr, --,
   {{0xe9df0093,0x2018259e,0x06e60831,0x00000000}},	//   trúa_, _éric_, পেডি, --,
   {{0x69ce8dcf,0x7bcf006d,0x27e0a71a,0x291829e3}},	//   rnbe, bncu, toin_, rcra_,
   {{0x2d9c0a78,0xe61a1fde,0xb908007c,0xc3250033}},	//   _zove_, зда_, _बड_, মৃতি_,
   {{0x7bc6a71b,0x764da71c,0x36670265,0x09e6a71d}},	// [c0a0] miku, guay, нато_, _поин,
   {{0x7bc6a71e,0x27e002e1,0x33261a48,0x2d9c01dd}},	//   liku, soin_, wbox_, _xove_,
   {{0xe8990332,0x65a000a8,0x75d30037,0x00000000}},	//   _ہمیں_, _böhr, ديلا, --,
   {{0x7bc6a71f,0x764d046a,0x224601a2,0x80da000c}},	//   niku, buay, trok_, _पुगे,
   {{0x41e60560,0xdb1d0132,0x799e0298,0x2b40021d}},	//   ніка, lisã, _kopw, _mdic_,
   {{0xd83802c6,0xdb1d2314,0x7bc6a720,0x224601a3}},	//   šču_, visí, hiku, rrok_,
   {{0x232a1761,0x7bc6a721,0x2fc4010d,0x00000000}},	//   _нови_, kiku, timg_, --,
   {{0xedc8175f,0x2d9ca722,0x7bc60054,0xdb1d0097}},	//   िच्छ, _sove_, jiku, tisí,
   {{0x7bc6a723,0x443a0283,0x2d9c008b,0x00000000}},	//   diku, lsp_, _pove_, --,
   {{0x2b400027,0x65a0013b,0x00000000,0x00000000}},	//   _adic_, _zöhr, --, --,
   {{0x7bc6a724,0x9ce60012,0x00000000,0x00000000}},	//   fiku, эцил, --, --,
   {{0x443a0159,0x7bc6a725,0x68150035,0xe9df0093}},	//   isp_, giku, _sądo, grún_,
   {{0x69da00b8,0x2d9c45cd,0xada600d8,0x75f000a0}},	//   čten, _tove_, _падл, väzn,
   {{0xddd90107,0x7c940037,0x00000000,0x00000000}},	//   _apwņ, _للتص, --, --,
   {{0x28db0992,0x7bc6a726,0xbd1700a5,0xf77f0381}},	//   _मुखि, biku, _אחוז_, _akça_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c3a8a22,0xe613004f,0x75eb00a8,0x65a0033b}},	// [c0b0] lstr, اشر_, lüzi, _röhr,
   {{0xddc93727,0x7c3aa727,0x6b8d0118,0x68e1018d}},	//   zvež, ostr, _hnag, ülds,
   {{0x69c7a728,0xdb1d0370,0xb4ab0826,0x6b8da729}},	//   mije, cisã, गने_, _knag,
   {{0x69c72fa3,0x7c3aa72a,0x6b9f035f,0x00000000}},	//   lije, istr, _joqg, --,
   {{0xdb0f21a4,0xfe080028,0xa565006c,0x7c3aa72b}},	//   licó, _hữu_, _لگان, hstr,
   {{0x69c70a23,0x7c3a1ac1,0x443a007e,0x216607e5}},	//   nije, kstr, bsp_, виши_,
   {{0x7c3aa72c,0x7bc601d5,0x987f00d5,0xdb0f0138}},	//   jstr, yiku, _méďa_, nicó,
   {{0x7c3aa72d,0x69c73c88,0xa5bb00b5,0xc6240033}},	//   dstr, hije, _utób, _পিতা_,
   {{0x7bc6a72e,0x69c7a72f,0x59e1021a,0x2a690221}},	//   viku, kije, पकार, _npab_,
   {{0x0d820572,0x4c850f08,0xb5fb01ba,0x69c71b68}},	//   альн, влов, _spáj, jije,
   {{0x69c71942,0x40350f22,0x7c3aa730,0xe9df0079}},	//   dije, _реес, gstr, trún_,
   {{0xdb1d0370,0x61e3a731,0x3a20022e,0x799e00d7}},	//   visã, lonl, _ptip_, _sopw,
   {{0x7bc650a2,0x7c3a0043,0x69c75010,0x733a0070}},	//   riku, astr, fije, וערס,
   {{0x7bc6a732,0x2afe022e,0x69c75906,0xdb040310}},	//   siku, रेषु_, gije, _lliç,
   {{0x6e3ba733,0x00000000,0x00000000,0x00000000}},	//   lsub, --, --, --,
   {{0x6f1b0ac8,0x6a86156c,0x6b8da734,0x69c70051}},	//   ncuc, _алиа, _gnag, aije,
   {{0x69c701cc,0x6443008a,0x6e3ba735,0xdce300a8}},	// [c0c0] bije, ánin, nsub, _yanğ,
   {{0x69c70a78,0xa2b706fe,0xca370122,0x75d36f76}},	//   cije, ्छन्, _שניה_, ليقا,
   {{0x61e358bb,0x6e3b1678,0xdce300f4,0x00000000}},	//   donl, hsub, _kanđ, --,
   {{0x61e30036,0x63062abf,0x07a603e6,0xdb0f0392}},	//   eonl, نوال, _рамн, licò,
   {{0x7c3aa736,0x61e3037a,0x63a9003c,0xdce800a0}},	//   zstr, fonl, _ċent, vedč,
   {{0x201a03e6,0x7c3aa737,0x415300d4,0x6e3b008c}},	//   ípio_, ystr, ивіс, dsub,
   {{0x2eca0567,0xddc90035,0xd34200b5,0x7c3a0282}},	//   ाप्त, steś, _نہای, xstr,
   {{0x7c3a17ad,0x245c031d,0x657ca738,0x7bc4009e}},	//   vstr, mím_, _harh, _nmiu,
   {{0x6e3b190b,0x03a38cb1,0x245c0187,0x657c00c3}},	//   gsub, _тито, lím_, _karh,
   {{0x6b8d0537,0x7c3aa739,0x60264025,0x657e0312}},	//   _snag, tstr, _аджа, ndph,
   {{0x69c7039a,0x245c114d,0x657ca73a,0x63a0a73b}},	//   vije, ním_, _marh, _komn,
   {{0xa3d522a7,0xfe4624c8,0x6e3b02ec,0x6f1b0036}},	//   िचय_, _андо, bsub, ccuc,
   {{0xec0a00e8,0x7af6006a,0xfe7207e4,0xf7730148}},	//   _nếu_, _czyt, _خدا_, یار_,
   {{0x63a0a73c,0x7c3aa73d,0x7bc40103,0x6e2d0225}},	//   _lomn, pstr, _emiu, _çaba,
   {{0x6286031d,0x69c701cc,0x245c024e,0x2d0e045c}},	//   _škol, rije, jím_, सशील_,
   {{0x245c024e,0x657c035b,0x69c76b14,0x63a00228}},	//   dím_, _aarh, sije, _nomn,
   {{0x69c785ca,0x628204ce,0x61e30463,0x34ab164f}},	// [c0d0] pije, jvoo, yonl, चन्द,
   {{0xdc420355,0x7aed007b,0x61e328c9,0x88950c7e}},	//   _léče, _iyat, xonl, _биох,
   {{0x260d0009,0x657ca73e,0x61e30421,0x69c5009e}},	//   _džoa_, _darh, vonl, _imhe,
   {{0x657c00e7,0x6e22a73f,0x7f420031,0x7aed018e}},	//   _earh, _otob, _ndoq, _kyat,
   {{0x63a0a740,0x657ca741,0x626502c4,0x6d580124}},	//   _domn, _farh, увла, _ocva,
   {{0xec0a0028,0x245c0187,0x7f4202d7,0x7aed55fa}},	//   _hết_, bím_, _adoq, _myat,
   {{0xec0a00e8,0x61e3a742,0x245c033a,0x6e22a743}},	//   _kết_, ronl, cím_, _atob,
   {{0x61e3a744,0xec0a01a5,0x7ff50d93,0xdff500d8}},	//   sonl, _yếu_, دستا, ыяль,
   {{0x7aed06d4,0x6f1ba745,0x69c50b0d,0xdce302c4}},	//   _nyat, rcuc, _omhe, _ranđ,
   {{0x6e3b046a,0xb5fb0037,0x6f1b8fba,0xdb0d00f7}},	//   rsub, _bpái, scuc, _plaî,
   {{0x6e3ba746,0x7535a747,0x7aeda748,0x6e223f3a}},	//   ssub, _mezz, _ayat, _etob,
   {{0x7535432f,0xeb9a2dfa,0x7aed0a74,0x69c500e9}},	//   _lezz, хим_, _byat, _amhe,
   {{0x7aed0010,0x245c00b8,0x443100fe,0x00000000}},	//   _cyat, zím_, _lwz_, --,
   {{0x9d5503c5,0x99d6004f,0x2bc60324,0x75350118}},	//   _صنعت, اتحا, _लगवा, _nezz,
   {{0x18678aec,0xa3e3051d,0x64430097,0xf7460eb1}},	//   лари_, नका_, ánil, лево,
   {{0x245c01c0,0x657ca749,0x7aed034d,0x00000000}},	//   vím_, _sarh, _fyat, --,
   {{0x657ca74a,0xa686010b,0x63a00159,0x05660f7a}},	// [c0e0] _parh, ылад, _romn, лван,
   {{0x63a0a74b,0x245c031b,0x3ea00014,0x44230282}},	//   _somn, tím_, _àite_, _btj_,
   {{0xe73a05a1,0x63a0a74c,0x80a80083,0x657c9905}},	//   _пен_, _pomn, _কেন্, _varh,
   {{0x387a0009,0x245c1968,0x645ea74d,0x44310223}},	//   _ispr_, rím_, rtpi, _dwz_,
   {{0x442301d2,0x245c05d3,0x71a601c8,0x645ea74e}},	//   _etj_, sím_, ладз, stpi,
   {{0x62820a45,0x5a170070,0x245c00b8,0x91e300c3}},	//   rvoo, אקסן_, pím_, боче,
   {{0x6282a74f,0x6e22a750,0x98a70254,0xf1a900d1}},	//   svoo, _stob, čića_, خانه_,
   {{0x6d435c13,0x628212ba,0x75350103,0x00000000}},	//   _adna, pvoo, _zezz, --,
   {{0xb5fb004f,0xae4300f8,0x00000000,0x00000000}},	//   _spái, مپيو, --, --,
   {{0x3f8f0093,0x7aed01d5,0x660e0024,0x00000000}},	//   _engu_, _ryat, _jibk, --,
   {{0xdfcf0088,0x7aed012f,0xd0120037,0x00000000}},	//   _کين_, _syat, _الص_, --,
   {{0xce3500b5,0x6d43021d,0x660e00d5,0x317e01b7}},	//   _چونک, _edna, _libk, _hatz_,
   {{0x2fc6011e,0x395a0107,0x62860124,0x00000000}},	//   _imog_, _bcps_, _škoj, --,
   {{0x7aed023c,0xa5bb0138,0x660e0024,0x00000000}},	//   _vyat, _atón, _nibk, --,
   {{0x75352c0c,0x7aed09b3,0x395a021e,0x317e72bf}},	//   _rezz, _wyat, _dcps_, _matz_,
   {{0x7535035f,0x64435723,0x317e0065,0x4423a751}},	//   _sezz, ánim, _latz_, _rtj_,
   {{0x753502fb,0x260d0200,0xec0a0019,0x44230279}},	// [c0f0] _pezz, _džon_, _vết_, _stj_,
   {{0x64436639,0xe97300b5,0x670100b4,0x69c514ca}},	//   šnim, _اندھ, लेषक_, _umhe,
   {{0xec0a01a5,0x7535027a,0x2ed10084,0x2fc602c4}},	//   _tết_, _vezz, _तख्त, _omog_,
   {{0xf1ed0067,0x00000000,0x00000000,0x00000000}},	//   _चीज़_, --, --, --,
   {{0x672da752,0xab5b00be,0x00000000,0x00000000}},	//   mbaj, riüh, --, --,
   {{0x644a1423,0x21690b00,0x69d501ae,0x2fc6011e}},	//   áfic, тики_, nnze, _amog_,
   {{0xdb1d008a,0xf77f01d6,0x69d5928b,0x112800d4}},	//   nnsó, _kaç_, inze, уючи_,
   {{0x09d201d1,0xf77f0176,0xfe452123,0x660e02a7}},	//   _सद्य, _jaç_, анио, _zibk,
   {{0xee36086c,0x764d02c2,0x9f5e006c,0xdcf802c6}},	//   аны_, nray, _autó_, _davč,
   {{0x237f0189,0xbc1900d8,0x75f000a0,0xdb1d0093}},	//   _hauj_, кімі_, väzk, rnsý,
   {{0xab2a6058,0x764da753,0x237f0221,0x720400b5}},	//   кона_, hray, _kauj_, _اولم,
   {{0xe45602b5,0x2d98013c,0x9991044d,0xdb0d01dd}},	//   סירט_, örer_, _čašu_, _amañ,
   {{0x237f0221,0xdb0d009e,0x387a0139,0x00000000}},	//   _mauj_, _smaò, _sspr_, --,
   {{0x237f006f,0x764d1497,0x6e290a8c,0x00000000}},	//   _lauj_, dray, mpeb, --,
   {{0xac1603fa,0x64430254,0x8d742b7d,0x764d073a}},	//   _коју_, šnij, _دانا, eray,
   {{0x764da754,0x200f007a,0x672d00b5,0x660e023a}},	//   fray, _jigi_, gbaj, _sibk,
   {{0x25a30009,0x764d00e0,0xd946027a,0x77b8002a}},	// [c100] _bojl_, gray, _кепи, _níxe,
   {{0x200fa755,0x7764a756,0x00000000,0x00000000}},	//   _ligi_, sfix, --, --,
   {{0x6289002a,0x14c800bf,0xddcb00ea,0x00000000}},	//   _areo, دهای_, _apgū, --,
   {{0x764da757,0x317e01ae,0xb4e60324,0x6289a758}},	//   bray, _satz_, _पडी_, _breo,
   {{0x6289a759,0x020600c3,0x25a3007a,0xdb1d00a8}},	//   _creo, аздн, _fojl_, sisç,
   {{0x2fc6a75a,0x27f2a75b,0x77b801ef,0x6289053f}},	//   _smog_, llyn_, _díxe, _dreo,
   {{0x64a6316a,0x9f440138,0x0396a75c,0x044330dd}},	//   _тава, lomé_, _края, _мерн,
   {{0x237f006d,0x27f2a75d,0x22490254,0x77b8002a}},	//   _gauj_, nlyn_, šaka_, _fíxe,
   {{0x623300c9,0xa3e30534,0xddc20097,0x6289376d}},	//   _меѓу, नकर_, _apoš, _greo,
   {{0xcd06448a,0x200f008a,0x50460166,0x00000000}},	//   ични, _eigi_, _вежб, --,
   {{0xdd9700d8,0x200f02e9,0x9df700d8,0xe7fb000c}},	//   ршы_, _figi_, рнэт_, ्षमा_,
   {{0x200fa75e,0x237f0221,0xdb240093,0xee86010b}},	//   _gigi_, _xauj_, örðu, _выко,
   {{0xddc2023a,0x27f20345,0x00000000,0x00000000}},	//   _epoš, dlyn_, --, --,
   {{0x261a0299,0xf77f01d6,0x394d01ae,0x9d17010b}},	//   _बढ़ी_, _saç_, ßes_, _кошт_,
   {{0x69d5033b,0x0c770cd1,0xdb04009e,0xdbf106fe}},	//   rnze, _نصيب_, _mliù, _hříb,
   {{0x6443068b,0x27f200e9,0x248d3fcd,0x98b100af}},	//   šnik, glyn_, _čem_, ează_,
   {{0x2cac0297,0x237f56a0,0x601500c7,0xb5fb0168}},	// [c110] lydd_, _rauj_, _išme, _opát,
   {{0xeb9f2b6f,0x2d9e01f4,0x00000000,0x00000000}},	//   ljø_, njte_, --, --,
   {{0x2cac0297,0x237f0221,0x764d3187,0x6289009e}},	//   nydd_, _pauj_, sray, _sreo,
   {{0x77b839d0,0x764d4808,0x237f006d,0x27f2a75f}},	//   _píxe, pray, _qauj_, clyn_,
   {{0x59bb0d1f,0x27e95997,0xb5fb0312,0x00000000}},	//   _उतार, moan_, _bpát, --,
   {{0xd24e0098,0xc69202b5,0x27e9a760,0x6289002d}},	//   رنى_, _זאך_, loan_, _vreo,
   {{0x237f01e8,0xa0a5081b,0xa4d401e0,0x00000000}},	//   _tauj_, сайд, _дорі, --,
   {{0x27e9a761,0x62890082,0x2cac001e,0x63ad00ab}},	//   noan_, _treo, dydd_, öand,
   {{0xddc2008b,0x6ad109b1,0xe3b00037,0xdb04009e}},	//   _spoš, सपोर, _غرف_, _fliù,
   {{0x2cac001e,0x27e99850,0xdb04009e,0x200f2d0d}},	//   fydd_, hoan_, _gliù, _wigi_,
   {{0x27e90291,0xec0a01a5,0x2cac001e,0x200f2568}},	//   koan_, _bếp_, gydd_, _tigi_,
   {{0x5f7716e6,0xb5fb00b8,0xa5bb008d,0x6e290b41}},	//   _خاطر, _zpát, _stól, ppeb,
   {{0xa5bb332c,0x27e901d7,0x00000000,0x00000000}},	//   _atóm, doan_, --, --,
   {{0x2fcd03bc,0xbea20d6e,0x6fde00ea,0xe61f055c}},	//   lieg_, _хашк, rīce, _crôm_,
   {{0xb4e60907,0x3ead006c,0x27f2010d,0xddc202c6}},	//   _पडे_, lyet_, tlyn_, _upoš,
   {{0x27e9a762,0x491400b8,0x279518cd,0x00000000}},	//   goan_, _दलको_, ошур, --,
   {{0x27f2a763,0x07a33466,0x00000000,0x00000000}},	// [c120] rlyn_, чатн, --, --,
   {{0x8b08004e,0x27f2a764,0x9f443c7a,0x00000000}},	//   _cięż, slyn_, romé_, --,
   {{0xb4b20e62,0x3d3a02b5,0x64a0012e,0x27e9a765}},	//   टने_, רגעס, _ošiš, boan_,
   {{0x69cea766,0xec0a01a5,0xd36f0037,0xe7fb022e}},	//   libe, _xếp_, فهم_, ्षणा_,
   {{0xdb04009e,0x00000000,0x00000000,0x00000000}},	//   _pliù, --, --, --,
   {{0x69cea767,0x91e3a768,0x3ead0f3a,0x64430132}},	//   nibe, поче, dyet_, ânic,
   {{0xe4da1c0c,0x26c0021d,0x00000000,0x00000000}},	//   _صورت_, lzio_, --, --,
   {{0x69ce5e6f,0xdbf101c0,0x00000000,0x00000000}},	//   hibe, _příb, --, --,
   {{0x2cac02c7,0xa3d51649,0x26c0a769,0xe7fb0ebd}},	//   wydd_, िचर_, nzio_, ्षता_,
   {{0x27e901a3,0xec0a0023,0x69ce034d,0x26c03815}},	//   zoan_, _sếp_, jibe, izio_,
   {{0x27e9a76a,0x69ce0065,0x2fcd0035,0x6ad10287}},	//   yoan_, dibe, bieg_, सप्र,
   {{0x2cac0297,0x5f761168,0x26c001d7,0x3ead0cca}},	//   rydd_, _دائر, kzio_, byet_,
   {{0x69ce079a,0x260d0009,0x2cac001e,0xcb03198f}},	//   fibe, _džoj_, sydd_, रेंड_,
   {{0x61ea0e8f,0x3d94083e,0x27e900e0,0x8b0801c0}},	//   nofl, _фикр, woan_, _stří,
   {{0x27e9a76b,0x4ac5007c,0xfdf700a5,0x00000000}},	//   toan_, _लइकव, _הצגת_, --,
   {{0xba1902fd,0x9f5d0107,0x69ce0051,0x58d401e0}},	//   _پيدا_, _chwè_, aibe, чост,
   {{0x56940185,0x27e901d7,0x7bcfa76c,0x69ce66b6}},	// [c130] патт, roan_, micu, bibe,
   {{0x6d5aa76d,0x7bcfa76e,0x69ce0b4c,0x27e9a76f}},	//   ngta, licu, cibe, soan_,
   {{0x44270a75,0x26c001a3,0xb5fba770,0xdce30409}},	//   ën_, azio_, _spás, _danė,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe299a771,0x6b7c0070,0x3cea0066,0x32672c3c}},	//   рал_, טראנ, _घुसे_, стев,
   {{0xa2cd02cb,0x7bcfa772,0x3a290260,0xdce3004b}},	//   _देण्, hicu, _mtap_, _ganė,
   {{0xe1f016e6,0x2fcd033b,0x92a90033,0xf07500fd}},	//   رسه_, tieg_, খছে_, تیاں_,
   {{0x6d5aa773,0x69cea774,0x3a290159,0xef190390}},	//   egta, zibe, _otap_, шми_,
   {{0x69ce006c,0x7bcf1116,0x2fcd8c84,0x62861793}},	//   yibe, dicu, rieg_, _škov,
   {{0x1c458385,0x69cea775,0xfc450187,0xdcf80029}},	//   оном, xibe, žíme_, _savā,
   {{0x3a290ec0,0xdca51283,0x3ead0031,0x645703c8}},	//   _atap_, цани, syet_, nuxi,
   {{0x7bcf01e0,0x7c2d00cd,0x6d5a0223,0x00000000}},	//   gicu, _čard, agta, --,
   {{0x29cd0254,0x00000000,0x00000000,0x00000000}},	//   ržan_, --, --, --,
   {{0x3a296fe6,0x63b80029,0x395e0553,0x1d090011}},	//   _dtap_, īvni, üts_, _кели_,
   {{0x3a29a776,0x7bcfa777,0x673f01f4,0xa7aa2356}},	//   _etap_, bicu, faqj, аква_,
   {{0xa6db008a,0xdb0f00a2,0x260d00f4,0x00000000}},	//   _meðf, ticô, _užoj_, --,
   {{0xd5b21ef9,0x6fde0228,0x00000000,0x00000000}},	// [c140] وفر_, nīca, --, --,
   {{0x6b84a778,0x64575840,0x26c00382,0x2d85a779}},	//   _haig, fuxi, rzio_, ndle_,
   {{0x649a116b,0x07a65de9,0x6b9601c8,0x61ea00f6}},	//   штар_, _данн, _knyg, vofl,
   {{0x77b80042,0x26c001a3,0x7afb0035,0x61fd00ea}},	//   _fíxa, pzio_, żute, _īsla,
   {{0x420a05a1,0x00000000,0x00000000,0x00000000}},	//   андо_, --, --, --,
   {{0x6b8402a8,0x236d0024,0x00000000,0x00000000}},	//   _laig, _ebej_, --, --,
   {{0x2d855101,0xdb0664ed,0x00000000,0x00000000}},	//   ddle_, lkkä, --, --,
   {{0x4444a77a,0x753ca77b,0x442a01d1,0x4fc601c8}},	//   ms_, _herz, _itb_, ўска,
   {{0x7644a77c,0xdb0d0290,0x753ca77d,0x63a2a77e}},	//   nsiy, _ilaç, _kerz, mjon,
   {{0x63a2a77f,0x78a1013c,0x3f820237,0x628000c7}},	//   ljon, älvk, žku_, _ismo,
   {{0x6b8421ca,0x3a290136,0x753ca780,0x4c94439f}},	//   _baig, _stap_, _merz, чинс,
   {{0x63a2a781,0x7644a239,0x6b84a782,0x69de08b7}},	//   njon, ksiy, _caig, _ajpe,
   {{0x7bcf7e21,0x4444a783,0x6b84a784,0xaac509a8}},	//   ricu, hs_, _daig, _लेखक,
   {{0x4444a785,0x7bcfa786,0x76440260,0x29cd0254}},	//   ks_, sicu, dsiy, ržao_,
   {{0x6b841093,0x4444a787,0x97a755c5,0x7bcfa788}},	//   _faig, js_, орал, picu,
   {{0x5bc40037,0x6b84026e,0x2e200107,0x00000000}},	//   _يقول, _gaig, _kòf_, --,
   {{0x4444a789,0x76442d85,0x4438001e,0xf1db0035}},	// [c150] es_, gsiy, _awr_, _बदलन,
   {{0x444473aa,0x672423df,0x6b84a78a,0x44380176}},	//   fs_, acij, _zaig, _bwr_,
   {{0x4444a78b,0x628006a2,0x753c01ae,0x442a8847}},	//   gs_, _asmo, _derz, _ctb_,
   {{0x987a00c2,0x64571e0a,0x443800e9,0x63a201f4}},	//   _פארט, ruxi, _dwr_, gjon,
   {{0x44447c81,0x7985104e,0x442a01a3,0x7644099e}},	//   as_, _kahw, _etb_, csiy,
   {{0x4444a78c,0x7985a78d,0x673d245b,0x00000000}},	//   bs_, _jahw, _hesj, --,
   {{0x4444a78e,0x6280a78f,0x661d10db,0xc5f20122}},	//   cs_, _esmo, _husk, _נדל_,
   {{0x661503cb,0x63a2004e,0xee391159,0xdb0d3253}},	//   _hizk, cjon, бни_, _glaç,
   {{0xd14b03c5,0x63bba790,0x644503c1,0x661da791}},	//   _نشان_, _ilun, lshi, _jusk,
   {{0x6b84a792,0x6b96022a,0xd131004f,0x63a9a793}},	//   _saig, _snyg, _أما_, _hoen,
   {{0x6b84a794,0x644525ba,0x752501ae,0x98b80029}},	//   _paig, nshi, ichz, karā_,
   {{0x2d8302dd,0x63a900c3,0x260d0009,0x7644a795}},	//   žje_, _joen, _džoi_, ysiy,
   {{0xed4e0f36,0x79850429,0x63a90173,0x427902b5}},	//   _по_, _bahw, _moen, זאָג,
   {{0x764406d3,0x63bba796,0x63a20484,0x4444a797}},	//   vsiy, _llun, zjon, ys_,
   {{0x63bba798,0x6d4157fc,0x6b84a799,0x661da79a}},	//   _olun, mala, _taig, _ausk,
   {{0x6d41a79b,0x764458f9,0x4444a79c,0x661d038d}},	//   lala, tsiy, vs_, _busk,
   {{0x4444a79d,0x672411c6,0x66150291,0x753ca79e}},	// [c160] ws_, rcij, _bizk, _perz,
   {{0x6d417ab4,0x63bba79f,0x76449e03,0x661d1472}},	//   nala, _alun, rsiy, _dusk,
   {{0x4444a7a0,0x661da7a1,0x753c8191,0x764401c2}},	//   us_, _eusk, _verz, ssiy,
   {{0x6d41a7a2,0x661d01ff,0x63a9a7a3,0x76440095}},	//   hala, _fusk, _coen, psiy,
   {{0x753ca7a4,0x63a9a7a5,0x661da7a6,0x4e0b0066}},	//   _terz, _doen, _gusk, हगाई_,
   {{0x6d4178c0,0x63a26a01,0x7af600c3,0x69dc2129}},	//   jala, sjon, _myyt, nnre,
   {{0x6d41a7a7,0x6445a7a8,0x44440069,0x3c210093}},	//   dala, cshi, qs_, _nóv_,
   {{0x661501d7,0x63a98765,0x7ae4002a,0x63bb02ec}},	//   _zizk, _goen, _oxit, _glun,
   {{0x6d41a7a9,0x7ae401f4,0xf1b900f4,0x62800a21}},	//   fala, _nxit, _suše_, _usmo,
   {{0xfe6f22c4,0xf1b9012e,0x6ce6010b,0x7bcd11d4}},	//   ادي_, _puše_, зіме, _smau,
   {{0x7ae40042,0x798516ec,0x213e01da,0x00000000}},	//   _axit, _rahw, _ieth_, --,
   {{0x798500d7,0x4f650312,0x69dca7aa,0xb09b32e3}},	//   _sahw, _يانف, enre, _ליבר,
   {{0x6d41a7ab,0xe61f0019,0xf0b000b5,0x98b80228}},	//   bala, _trôi_, _سیکھ, varā_,
   {{0x661d824d,0x201e1bba,0x6445a7ac,0x673da7ad}},	//   _rusk, _kuti_, yshi, _sesj,
   {{0x213e0602,0x7ae4a7ae,0x661da7af,0x64450be2}},	//   _meth_, _exit, _susk, xshi,
   {{0x213e0014,0x201ea7b0,0x77b80042,0x37a80036}},	//   _leth_, _muti_, _díxo, птун_,
   {{0x25aa0297,0x3f8600d7,0x201e030d,0x2617046c}},	// [c170] _bobl_, _maou_, _luti_, _भूखी_,
   {{0x77b80391,0x63bb01c0,0x63a9a7b1,0x98b800ea}},	//   _fíxo, _slun, _soen, sarā_,
   {{0x63a9a7b2,0x63bba7b3,0xb4d700b4,0x201e0160}},	//   _poen, _plun, ापे_, _nuti_,
   {{0x6d41a7b4,0x661da7b5,0x6445a7b6,0x213e001e}},	//   zala, _tusk, rshi, _aeth_,
   {{0x6d41a7b7,0x213e0297,0x6286a7b8,0x201e0124}},	//   yala, _beth_, _škor, _auti_,
   {{0x63a902e6,0x201ea7b9,0x6d41a7ba,0xcf8e00fd}},	//   _woen, _buti_, xala, یژن_,
   {{0x6d41a7bb,0x201ea7bc,0x63a9a7bd,0x213ea7be}},	//   vala, _cuti_, _toen, _deth_,
   {{0x6d41a7bf,0x201e3225,0x63bb09e7,0x98b8002d}},	//   wala, _duti_, _ulun, lară_,
   {{0x6d41a7c0,0x3f860107,0x224600fd,0x213e5c67}},	//   tala, _daou_, csok_, _feth_,
   {{0xe29005bc,0x0c25002d,0x98b800af,0x201ea7c1}},	//   _حذف_, ммон, nară_, _futi_,
   {{0x201ea7c2,0x7af60086,0x3f860051,0x61e40079}},	//   _guti_, _syyt, _faou_, éile,
   {{0x333f1010,0x6d413c5d,0x601500d8,0x7af600c3}},	//   _jeux_, sala, _išmo, _pyyt,
   {{0x6d41a7c3,0x201e0124,0x00000000,0x00000000}},	//   pala, _zuti_, --, --,
   {{0x6d41a7c4,0xe61f01ba,0xe81f0066,0x321f02d7}},	//   qala, _osôb_, _मंशा_, _muuy_,
   {{0x69dc6e78,0x7e69a7c5,0xfbc62349,0x00000000}},	//   rnre, ltep, _обко, --,
   {{0x2d87a7c6,0x9b4600d1,0x7af600c3,0x7ae401b7}},	//   _hane_, _کنکو, _tyyt, _txit,
   {{0x2d8751bd,0x25aa0297,0x99e600c3,0x05aa00d8}},	// [c180] _kane_, _pobl_, _ожид, овай_,
   {{0x2d87a7c7,0xdb04009e,0x6e2d0225,0x00000000}},	//   _jane_, _fliò, _çabu, --,
   {{0x2d87a7c8,0x4806052a,0x999b00a5,0xba2900b5}},	//   _mane_, _опов, _וביט, _وسیم_,
   {{0x333f02e1,0xf6260166,0x201ea7c9,0x3a2002a2}},	//   _ceux_, _одмо, _ruti_, _kuip_,
   {{0x333f1010,0x213e001e,0x201ea7ca,0x2246010d}},	//   _deux_, _peth_, _suti_, usok_,
   {{0x27ed02dd,0x2d870054,0x201e190b,0xd12f017e}},	//   čene_, _nane_, _puti_, لمه_,
   {{0x333f00f7,0x232a00d4,0x213e0051,0x3f860260}},	//   _feux_, _мови_, _veth_, _paou_,
   {{0x2d870103,0x00000000,0x00000000,0x00000000}},	//   _aane_, --, --, --,
   {{0x8e142a34,0x2d873326,0x7c2d0254,0x7e6929c4}},	//   ндиц, _bane_, _čara, gtep,
   {{0x2d87a7cb,0x201ea7cc,0x29cd00f4,0x00000000}},	//   _cane_, _tuti_, ržak_, --,
   {{0x333f0248,0x2cb8a7cd,0x61434717,0x2b40016e}},	//   _yeux_, árd_, _реха, _beic_,
   {{0xdb0401dd,0xbb9400c3,0x2b408fe8,0x7e690159}},	//   _aliñ, вающ, _ceic_, btep,
   {{0xc33302b8,0xbda60037,0x3a20009e,0x98ba021e}},	//   כור_, _يحتو, _cuip_, _depč_,
   {{0x2d87a7ce,0xf1b90207,0x00000000,0x00000000}},	//   _gane_, _kuša_, --, --,
   {{0x3943a7cf,0x2006a7d0,0x9cf401e0,0xde8800e2}},	//   rajs_, _khoi_, _язкі, _hị_,
   {{0x2d87a7d1,0x31db0b35,0x64430132,0xdb1d00be}},	//   _zane_, _बद्ध, ânim, nisü,
   {{0x27e2012f,0x98b8002d,0x443f00a0,0x00000000}},	// [c190] _djkn_, tară_, _ňu_, --,
   {{0x2d870176,0xde8800e2,0x05770413,0x00000000}},	//   _xane_, _mị_, بارد, --,
   {{0x333f02e1,0x81e40083,0x6005a7d2,0xdb04a7d3}},	//   _peux_, নতা_, lóme, _goiâ,
   {{0x69d5a7d4,0x98b800af,0x2b400176,0x200600e2}},	//   lize, sară_, _xeic_, _nhoi_,
   {{0x333f02e1,0x60050f56,0x7e6902d7,0x00000000}},	//   _veux_, nóme, xtep, --,
   {{0x69d5a7d5,0xe61f0168,0x663a016b,0xf1b9a7d6}},	//   nize, _drôt_, _מעשׂ, _buša_,
   {{0x2d8701a0,0xf36702ee,0x1fb5002d,0xdb0d014c}},	//   _rane_, _отан, еспр, _claú,
   {{0xde8800e8,0xc91802b8,0xf1b92353,0x7e69a7d7}},	//   _bị_, וחות_, _duša_, ttep,
   {{0x2d87a7d8,0x3eb92c89,0x2a69006d,0xc17501d3}},	//   _pane_, ást_, _nqab_, _плащ,
   {{0xde8801a5,0x2b401a07,0x69d50124,0x2d87013b}},	//   _dị_, _seic_, jize, _qane_,
   {{0x69d5a7d9,0x2d87942d,0xc5f20d85,0x28cf0d91}},	//   dize, _vane_, רדי_, _हेलि,
   {{0x2d87023c,0x7e690051,0x00000000,0x00000000}},	//   _wane_, ptep, --, --,
   {{0x2d87a7da,0xeb971172,0x69d500b5,0x2b4000ea}},	//   _tane_, хия_, fize, _veic_,
   {{0xbed602b5,0x69d5a7db,0x394100ec,0x00000000}},	//   _אונז_, gize, _cehs_, --,
   {{0x25f50066,0x98b800c7,0x00000000,0x00000000}},	//   ्तनी_, karą_, --, --,
   {{0x3a200051,0x00000000,0x00000000,0x00000000}},	//   _tuip_, --, --, --,
   {{0x69d59863,0xaffa0070,0x00000000,0x00000000}},	// [c1a0] bize, פּלי, --, --,
   {{0x69d5a7dc,0x273e00e2,0x00000000,0x00000000}},	//   cize, ắn_, --, --,
   {{0x19b70100,0x7dc40176,0xf7467457,0x2db6016b}},	//   _נפטר_, _fòsf, _пено, עלען_,
   {{0xd8d702b5,0x753b0c99,0x00000000,0x00000000}},	//   _טויט_, _đuze, --, --,
   {{0x20060297,0x8574006c,0xa3b10067,0xf1b901a0}},	//   _rhoi_, _لگائ, _ओवर_, _suša_,
   {{0x7c2d7f6b,0x27e00031,0xf1b9023a,0x00000000}},	//   _čarn, lnin_, _puša_, --,
   {{0xc5ec16d3,0x27e08f74,0x64580279,0x6f0200b5}},	//   जकीय_, onin_, ávid, _szoc,
   {{0x27e0a7dd,0xb4ac0456,0xc3150033,0x657e77ad}},	//   nnin_, गही_, াড়ি_, leph,
   {{0x645e49e2,0x69d50010,0x27e0a7de,0x00000000}},	//   lupi, yize, inin_, --,
   {{0x657ea7df,0xde880028,0x6282a7e0,0x27e0a7e1}},	//   neph, _vị_, mwoo, hnin_,
   {{0xa5bb0755,0xa6db00fb,0x628211cc,0x20060019}},	//   _któr, _meða, lwoo, _thoi_,
   {{0xdb1d0279,0x69d504fb,0x6282073a,0x205505d8}},	//   visó, wize, owoo, _штур,
   {{0x628202e6,0x27e0a7e2,0x69d5a109,0xfbdf0132}},	//   nwoo, dnin_, tize, rnê_,
   {{0x645ea7e3,0x600520d9,0xc9840395,0xa6db0093}},	//   kupi, róme, луси, _neða,
   {{0xf8075197,0x645ea7e4,0x657e2a13,0x8d630274}},	//   ечан, jupi, deph, _свје,
   {{0x27e0003e,0x62820c7c,0x645e1e1a,0x3cfb00a5}},	//   gnin_, kwoo, dupi, _מלונ,
   {{0x62820051,0x00000000,0x00000000,0x00000000}},	// [c1b0] jwoo, --, --, --,
   {{0xdb1d0035,0x78a101ff,0x27e0a7e5,0xa2bf06fe}},	//   pisó, älvs, anin_, वनस्,
   {{0x645ea7e6,0xddc2a7e7,0x00000000,0x00000000}},	//   gupi, _opož, --, --,
   {{0x62350370,0x62820120,0x7f42220d,0x00000000}},	//   веду, fwoo, _neoq, --,
   {{0x62820173,0x657e011e,0xaab31119,0xdd0100cd}},	//   gwoo, beph, ुनिक, _čuča,
   {{0x657ea7e8,0xe296001f,0x82341c2d,0x98b8010b}},	//   ceph, таш_, ارنا, sarą_,
   {{0x7c2d0e46,0x44250043,0x6567012f,0xdcf800c7}},	//   _čaro, _îl_, _icjh, _tavę,
   {{0x889c02b5,0xd00e0098,0x02d200b4,0x1ab300b4}},	//   לבוי, يلو_, _देवभ, ुनाथ,
   {{0x200d002d,0x26c90054,0x44310124,0xe7c9073f}},	//   rmei_, nzao_, _htz_, _रतनप,
   {{0x442301a9,0x6e2200c7,0x2d95059b,0x6458010b}},	//   _kuj_, _duob, трис, švie,
   {{0xfce52c0f,0x27e08bc2,0x44230107,0xceeb13cf}},	//   тоно, ynin_, _juj_, _کران_,
   {{0x44237fa1,0x2d9c0107,0x224900f4,0xdcf8007e}},	//   _muj_, _enve_, šaku_, _havě,
   {{0xf41200c2,0x4423a7e9,0x27e002a7,0x44310118}},	//   יפט_, _luj_, vnin_, _ltz_,
   {{0xaf0402ce,0x291e03d0,0x44314a4f,0x3f8d0176}},	//   _спіл, øta_, _otz_, ldeu_,
   {{0x44230189,0xd9430011,0x18671761,0x27e0a7ea}},	//   _nuj_, реси, кари_, tnin_,
   {{0x3f8d0bc8,0x6d43a7eb,0x7f4201ef,0x27e0a7ec}},	//   ndeu_, _hena, _xeoq, unin_,
   {{0x27e0a7ed,0x6d434507,0x442378aa,0xfaa67b75}},	// [c1c0] rnin_, _kena, _auj_, _рапо,
   {{0xa5bb161e,0x27ed0a0b,0x6d430452,0x645ea7ee}},	//   _stór, čena_, _jena, tupi,
   {{0x6d431b0f,0x44234e7d,0x224d02e9,0x27e00031}},	//   _mena, _cuj_, _avek_, pnin_,
   {{0x6282201e,0x4423006d,0x7c2d7375,0x7c23a7ef}},	//   twoo, _duj_, _čarl, _munr,
   {{0x02d20c67,0x0ed00ca1,0x657e02d7,0x2d8c0044}},	//   _देशभ, _तेंड, peph, ydde_,
   {{0x6282a7f0,0xf1b9a7f1,0x645e00b9,0xa5bb0067}},	//   rwoo, _dušo_, pupi, _wtór,
   {{0x04438816,0x6282213d,0x44239eb7,0x6e220207}},	//   _весн, swoo, _guj_, _suob,
   {{0x62820090,0xa85700a5,0x00000000,0x00000000}},	//   pwoo, דיקה_, --, --,
   {{0x6d4376c6,0x661ca7f2,0x4423006f,0xd0070202}},	//   _bena, _kirk, _zuj_, њење_,
   {{0x6d43a7f3,0x661c144c,0x68e90043,0x44230221}},	//   _cena, _jirk, şedi, _yuj_,
   {{0x6d43a7f4,0x4423006d,0x3a3200d5,0xa3e600be}},	//   _dena, _xuj_, _atyp_, _पदा_,
   {{0x2d8a04c3,0x799e021e,0x661c03d0,0xab5b02b1}},	//   žbe_, _anpw, _lirk, chül,
   {{0xdfcf38b7,0x6d43a7f5,0x7dc40211,0x00000000}},	//   _بين_, _fena, _pòsd, --,
   {{0x6d43a7f6,0x7c239407,0x7e60536d,0x6fde00ea}},	//   _gena, _funr, mump, dīci,
   {{0x7e60a7f7,0x8a1817dc,0xdce1010b,0x00000000}},	//   lump, торс_, delė, --,
   {{0x4423a7f8,0xa5bb043f,0x6d43a7f9,0x661ca7fa}},	//   _ruj_, _atóp, _zena, _airk,
   {{0x7e6006b3,0x661ca7fb,0xe80704bc,0x6d43a7fc}},	// [c1d0] nump, _birk, _वीणा_, _yena,
   {{0x442301e8,0x6d43a7fd,0x2746010b,0x7dc40260}},	//   _puj_, _xena, vūnų_, _fòse,
   {{0x6b8d6839,0x661ca7fe,0x442301e8,0x67d53faf}},	//   _kaag, _dirk, _quj_, _бону,
   {{0x6d48a7ff,0xa3cd0035,0x44310009,0xe3b011cf}},	//   hada, षों_, _vtz_, يرن_,
   {{0x6d48a800,0x7e6024eb,0x661ca801,0x69c700c3}},	//   kada, jump, _firk, ohje,
   {{0x4423a802,0x6b8d3939,0x6d48a803,0x44310009}},	//   _tuj_, _laag, jada, _ttz_,
   {{0x6d48a804,0x6adf06bc,0x44315ffa,0xc5f200a5}},	//   dada, नपुर, _utz_, _הדם_,
   {{0x6d43a805,0x6b8da806,0x661c2688,0x672da807}},	//   _sena, _naag, _zirk, ncaj,
   {{0x6d430ce8,0x224d3b12,0x7e6000a7,0x3f8d7caa}},	//   _pena, _uvek_, gump, rdeu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c701d2,0xbb46a808,0x6b8d01a8,0x6fde00ea}},	//   dhje, ленк, _baag, zīci,
   {{0x4e950071,0x6d4308eb,0xf9890d85,0x6b8d02d7}},	//   _مشتر, _wena, _מר_, _caag,
   {{0xee2e5c47,0x6d432b63,0x6d48a809,0x6b8d1516}},	//   _ын_, _tena, bada, _daag,
   {{0x7bc601d2,0xdb04021d,0x6d4301cb,0x38c80088}},	//   shku, _loiç, _uena, نازی_,
   {{0xc8b5010b,0xbca80037,0x29cd0228,0x00000000}},	//   асты, _لديك_, ežas_, --,
   {{0xd24500b5,0x6b8d001c,0xab6627eb,0x00000000}},	//   _وچ_, _gaag, _свил, --,
   {{0x661ca80a,0x7bc41040,0x764d0f3a,0x7bd60010}},	// [c1e0] _pirk, _iliu, gsay, _imyu,
   {{0x5986a80b,0x65653dd6,0xf9920c74,0x64a69b31}},	//   _слоб, gghh, _طبخ_, лаза,
   {{0x661c4570,0x29cd19cd,0x62890138,0x5a1700a5}},	//   _virk, ržat_, _aseo, _תקין_,
   {{0x661c02bf,0x6d480aca,0x929d004e,0x926a1517}},	//   _wirk, zada, _czło, ерка_,
   {{0x6d48a80c,0xe2979183,0x764d01ef,0xbb3b016b}},	//   yada, лац_, csay, געני,
   {{0xd37213cf,0x7bc40955,0x6d48a80d,0xa6db0093}},	//   _گهر_, _lliu, xada, _meðl,
   {{0x7bc40176,0x65c32860,0xa5070036,0x00000000}},	//   _oliu, _убра, _бера_, --,
   {{0x6d48a80e,0x7e6000d6,0xdfd021a0,0x60050138}},	//   wada, tump, تيب_, tóma,
   {{0x6d48248d,0x6b8d00b9,0x2ba8166b,0x394aa80f}},	//   tada, _raag, गाना, kabs_,
   {{0x7bc4a810,0xf1b800b4,0x6b8da811,0xc27b0317}},	//   _aliu, _अविन, _saag, _ארמי,
   {{0x7e60a812,0x6b8d0b04,0x7bc4a813,0x61fa01ed}},	//   sump, _paag, _bliu, _iktl,
   {{0x764d27f9,0x321e0865,0x7bc40284,0x2366a0db}},	//   ysay, _hity_, _cliu, ngoj_,
   {{0x6d48a814,0x6b8d878f,0x29cd0009,0x8f9b0070}},	//   pada, _vaag, džar_, _רידי,
   {{0x6b8da815,0x6d480be2,0x7bd6030d,0x7bc41855}},	//   _waag, qada, _emyu, _eliu,
   {{0x6b8d525a,0x4dfb0052,0x7bc404e6,0x69c7a816}},	//   _taag, _רפוא, _fliu, rhje,
   {{0x69c700da,0xdc9b0122,0x8aa71c1b,0x764da817}},	//   shje, _טיול, _брод, tsay,
   {{0x2d8ea818,0xdb1d004f,0x672da819,0xb4bd00b8}},	// [c1f0] _kafe_, bhsá, rcaj, इन्_,
   {{0x99671386,0xb8db0083,0x28d622a3,0x764d0471}},	//   _стил, _আই_, _डेवि, rsay,
   {{0xdb0d0176,0x69d7009f,0xb6040352,0x69c5021d}},	//   _llaü, _imxe, сятк, _ilhe,
   {{0x321e0260,0x61faa81a,0xdc3b016b,0x764d0225}},	//   _aity_, _aktl, געאר, psay,
   {{0x2169195a,0xe1f111c0,0x60150124,0x201d0118}},	//   вили_, يست_, _ušmi, _riwi_,
   {{0x321ea81b,0x20550112,0xdce30069,0xdce80228}},	//   _city_, атир, _lanġ, nedē,
   {{0xdb1d00ab,0xd6c70033,0x201d01ef,0x00000000}},	//   misõ, _এশিয, _piwi_, --,
   {{0xa24600b5,0xdb1d00be,0x62890767,0x8b0800fe}},	//   _چینل_, lisõ, _tseo, _juří,
   {{0xdee52aa5,0x20030029,0x69c50132,0x2b4b000d}},	//   ропи, ēji_, _olhe, dacc_,
   {{0x7bc80029,0x2d8ea81c,0x321e00fe,0xf1d905f8}},	//   ījum, _cafe_, _gity_, _भगिन,
   {{0x7bc4010b,0xa6db0093,0x2d8e0107,0x7aed0139}},	//   _pliu, _seðl, _dafe_, _axat,
   {{0x69c5a81d,0x68fe0345,0x00000000,0x00000000}},	//   _alhe, _rypd, --, --,
   {{0x9e9600b5,0x2d8e0183,0x6da507fa,0x8a061e96}},	//   _پانچ, _fafe_, _вила, изме,
   {{0x8cb50021,0xed5937d7,0x3f8f02c4,0x69c50211}},	//   _всич, _рок_, _hagu_, _clhe,
   {{0x7aed03e6,0x69c507c0,0x7bc401da,0x3f8f018d}},	//   _exat, _dlhe, _tliu, _kagu_,
   {{0x2d8e02d0,0x69c500b5,0x3f8f00be,0xfaff0031}},	//   _zafe_, _elhe, _jagu_, rfër_,
   {{0xf1c50099,0x3f8f4630,0x2d8e0103,0x00000000}},	// [c200] वसान, _magu_, _yafe_, --,
   {{0x3f8f2bab,0x399a0779,0x8af001c2,0x45362fb8}},	//   _lagu_, _ייִד, _edəc, рхат,
   {{0x03263c29,0x98a61334,0xc4860ffd,0xfaff0031}},	//   аден, _тине, рлек, ngën_,
   {{0x3f8f0006,0x69dca81e,0x7dc4009e,0x78a800be}},	//   _nagu_, lire, _mòsa, ädvu,
   {{0x69dc004f,0x23660055,0x0cc10066,0xdb1d018d}},	//   oire, rgoj_, शनुम, bisõ,
   {{0x69dca81f,0xdb1d0279,0x51f7093e,0xf50a7e78}},	//   nire, cisõ, анію_, _англ_,
   {{0x2d8e01ef,0x25f5043b,0x7dc401da,0xc953024b}},	//   _rafe_, ्तरी_, _nòsa, קמה_,
   {{0x69dca820,0x443a01cb,0x2d8e00a5,0xf1b8007a}},	//   hire, mpp_, _safe_, _diġa_,
   {{0x69dca821,0x3f8f046a,0x317a0609,0x9df8004c}},	//   kire, _dagu_, _لحاظ_, лнит_,
   {{0x69dca822,0x2d8e0031,0x00000000,0x00000000}},	//   jire, _qafe_, --, --,
   {{0x6adf0d34,0x60051111,0x3086036b,0x61f829d3}},	//   नप्र, cómo, _خلاف, movl,
   {{0x61f819bf,0x98a30067,0x00000000,0x00000000}},	//   lovl, ncją_, --, --,
   {{0x69dca823,0x2fc60c86,0x3f84a824,0x9b5801d3}},	//   fire, _ilog_, memu_, шият_,
   {{0x61f802dd,0x69dca825,0x00000000,0x00000000}},	//   novl, gire, --, --,
   {{0xed5700c9,0x2ee80083,0xdb1d0279,0xa3e6022e}},	//   _тој_, _পরিষ, visõ, _पदं_,
   {{0x69dc174e,0x3f84a826,0x6aa212b6,0x97a4002d}},	//   aire, nemu_, _šofe, орул,
   {{0x69dc5926,0x7bdda827,0x61f800cd,0x3b0900a8}},	// [c210] bire, misu, kovl, _uzaq_,
   {{0x3f840657,0x7bdda828,0x270708b6,0x69dca829}},	//   hemu_, lisu, _शरीर_, cire,
   {{0x442700e8,0xe475051b,0x61f82bc3,0x3f84a82a}},	//   ên_, слењ, dovl, kemu_,
   {{0x3f84a82b,0x889a0bed,0x24581a0e,0xdb1d00be}},	//   jemu_, _עברי, раць_, sisõ,
   {{0x3f8f1581,0x3f84a82c,0xddc9002d,0x2bba0066}},	//   _ragu_, demu_, nteţ, _उकसा,
   {{0x3f8fa82d,0x2b492c46,0x61f800cd,0xe1f8010b}},	//   _sagu_, _leac_, govl, агі_,
   {{0x2fc62c99,0x3a2900d7,0x7bdda82e,0x645e0124}},	//   _blog_, _luap_, kisu, crpi,
   {{0xf1d9012f,0xdce10080,0x2901028b,0x2fc6a82f}},	//   _भगवन, selī, _myha_, _clog_,
   {{0xef1903ad,0x5fa92188,0x61f80693,0x7bdda830}},	//   ыми_, काबल, bovl, disu,
   {{0x69dc01dd,0x7dc4a831,0x3f8f195f,0x00000000}},	//   xire, _pòsa, _wagu_, --,
   {{0x2fc6a832,0x3f8fa833,0x3f84a834,0x290101ef}},	//   _flog_, _tagu_, bemu_, _nyha_,
   {{0x7bdd02f8,0x69dca835,0x3f84a836,0x3a2902d7}},	//   gisu, wire, cemu_, _buap_,
   {{0x69dc563a,0x37cd0033,0xdcfa02d4,0x2b49a837}},	//   tire, রচার, retā, _deac_,
   {{0xfe7000f8,0x6e3ba838,0x2fc600cd,0xf1b900f4}},	//   _زده_, mpub, _zlog_, _buši_,
   {{0x2d8592a5,0x69dca839,0xdd8e0833,0xeb9a0949}},	//   mele_, rire, _سوي_, _бий_,
   {{0x2d85a83a,0x0b461783,0x236d0221,0x2cb8013c}},	//   lele_, _унин, _ncej_, ärde_,
   {{0xb8ff0534,0xbb3b00c2,0x6e3ba83b,0x2c7100b5}},	// [c220] _दे_, _געפי, npub, lád_,
   {{0x99860514,0x2d85a83c,0x645e0e31,0xa2b8012f}},	//   _الدو, nele_, trpi, ्नस्,
   {{0xf1b90506,0xe45a5467,0xdb0d0093,0x629b004b}},	//   _guši_, уже_, _hlað, _aruo,
   {{0x2d85a83d,0x629b00c7,0x6cfa0070,0xddc20355}},	//   hele_, _bruo, אפעס, _dvoř,
   {{0x2d853939,0xaaba02e4,0x61f808b7,0x02d21fe0}},	//   kele_, ॉनिक, tovl, _देखभ,
   {{0x2d85a83e,0x2fc6a83f,0x64a622a9,0xd9f822c7}},	//   jele_, _slog_, _лага, ंकित_,
   {{0xf8c82fa9,0x2d85a840,0xd010028c,0x3f842536}},	//   रनिय, dele_, ولت_, temu_,
   {{0x9a2900e2,0x2d8532c5,0x00000000,0x00000000}},	//   _lươn_, eele_, --, --,
   {{0x7bdda841,0x25ef0b4a,0xe297150e,0x2bcc0099}},	//   visu, _आदमी_, _лат_, ासना,
   {{0x442a0189,0x7bdd04fb,0x2b490211,0x389800ee}},	//   _kub_, wisu, _seac_, _očr_,
   {{0xfe6f064e,0xb5fb02b5,0x3a290f1c,0x6e3b0036}},	//   ودی_, רליכ, _suap_, apub,
   {{0xdb0d008a,0x442a49f2,0x2fc6012e,0xf1b905e2}},	//   _blað, _mub_, _ulog_, _ruši_,
   {{0x442aa842,0x2d85a843,0x15fa0f9c,0x7bdda844}},	//   _lub_, bele_, ्तार_, risu,
   {{0xf2d300c2,0x0e571759,0x2d85a845,0x7bdd1dae}},	//   לער_, _פשוט_, cele_, sisu,
   {{0x442a01e8,0x443835c1,0xeb9f01b4,0x00000000}},	//   _nub_, _ntr_, rløb_, --,
   {{0x6d4a022e,0xf77000b5,0x603100ea,0x657c00ee}},	//   _hefa, ٹاف_, _jāma, _abrh,
   {{0x442aa846,0xddc937c4,0x443816b7,0xdb0d008d}},	// [c230] _aub_, lteš, _atr_, _glað,
   {{0x7c2a15c2,0x442a0dbc,0x6d4a0453,0xfbdf0183}},	//   _kufr, _bub_, _jefa, liê_,
   {{0xd49b010b,0x6280010b,0x798701d5,0x7c2a0345}},	//   ыра_, _apmo, mejw, _jufr,
   {{0x442aa847,0x2d850043,0x6d4aa848,0x4438a849}},	//   _dub_, zele_, _lefa, _dtr_,
   {{0x6d580d5c,0x27e92326,0x443826d6,0x6f0213b6}},	//   _odva, mnan_, _etr_, _nyoc,
   {{0xddc200b8,0x2d8500af,0x7c380124,0x867a025a}},	//   _tvoř, xele_, _otvr, _דרשו,
   {{0x27e9a84a,0x3dce0083,0x2bcc035d,0xaae00067}},	//   onan_, িচাল, ासमा, _पेनक,
   {{0x27e9a84b,0xdbf20311,0x6d58257c,0x629b0019}},	//   nnan_, _přís, _adva, _truo,
   {{0x2d85a84c,0x27e90388,0x6d4aa84d,0x7c2a01ae}},	//   tele_, inan_, _befa, _aufr,
   {{0x6d4aa84e,0x6e3b00ea,0x798701d5,0x7c2aa84f}},	//   _cefa, rpub, jejw, _bufr,
   {{0x6d4aa850,0x6e3ba851,0x2d85a852,0x1d090b46}},	//   _defa, spub, rele_, рени_,
   {{0x2d85a853,0x2c71a854,0x00000000,0x00000000}},	//   sele_, rád_, --, --,
   {{0xeb971960,0x2d85a855,0x27e995c7,0x4a43a856}},	//   ция_, pele_, dnan_, мняв,
   {{0x6d4aa857,0x8c4507c1,0x7b3e0035,0x27e90328}},	//   _gefa, _деке, dłuż, enan_,
   {{0x6d41a858,0xab5b0644,0x9a290023,0x6e2b008d}},	//   mbla, mkün, _vươn_, _hugb,
   {{0x442aa859,0x27e9a85a,0x29040080,0x98a30035}},	//   _rub_, gnan_, āma_, ncję_,
   {{0x442aa85b,0x7c2aa85c,0x4438a85d,0x6d4100f1}},	// [c240] _sub_, _zufr, _str_, obla,
   {{0x442a0189,0x6d41a85e,0x7c24005b,0x27e9a85f}},	//   _pub_, nbla, _hiir, anan_,
   {{0x7c241eca,0x442a0189,0x6e232118,0x27e99016}},	//   _kiir, _qub_, _minb, bnan_,
   {{0x395a010d,0x13067053,0x6e23a860,0x3ebf010d}},	//   _hdps_, озем, _linb, kyut_,
   {{0xc7b302da,0x27e00086,0x6d411472,0x7c24314a}},	//   _חבר_, miin_, kbla, _miir,
   {{0x442aa861,0x1a9b00c2,0x4a9b02b5,0x27e0a862}},	//   _tub_, יינע, יינג, liin_,
   {{0x6d41a863,0x4438287e,0x61eda864,0x216703fa}},	//   dbla, _utr_, éala, цији_,
   {{0x6d4100de,0x27e000c3,0x6d4aa865,0x6e2b010d}},	//   ebla, niin_, _sefa, _bugb,
   {{0x7c2aa866,0x7c3802b2,0x3f9800b8,0x6d41a867}},	//   _sufr, _stvr, ěru_, fbla,
   {{0x27e0a868,0x27ed02dd,0x44240122,0x6d416d35}},	//   hiin_, čeni_, _him_, gbla,
   {{0x27e000c3,0x7c241505,0x6e23a869,0x6d4aa86a}},	//   kiin_, _biir, _dinb, _vefa,
   {{0x6d4a0297,0x6e23a86b,0xf1b9a86c,0xa067002d}},	//   _wefa, _einb, _dušu_, _фаца_,
   {{0x4424a86d,0x7c240ce8,0x27e05ff9,0x6d41a86e}},	//   _mim_, _diir, diin_, bbla,
   {{0x44247c77,0x69ce0602,0x6d58a86f,0x6e230008}},	//   _lim_, ghbe, _udva, _ginb,
   {{0x61fd00fb,0x7c380a78,0x27e9a870,0x61eaa871}},	//   _ísle, _utvr, tnan_, infl,
   {{0x442474d5,0x27e9a872,0x61ea033b,0x27e00dfa}},	//   _nim_, unan_, hnfl, giin_,
   {{0x2ba80c03,0x25b8023a,0x7bd60055,0x9f4401f7}},	// [c250] गारा, _borl_, ëzue, lomó_,
   {{0xd49b44d9,0x69ce1fb3,0x27e9a873,0x442456ee}},	//   ире_, chbe, snan_, _aim_,
   {{0x27e9a874,0xd76600b5,0x27e04ab4,0x7b3e0067}},	//   pnan_, _کاپٹ, biin_, służ,
   {{0x44240189,0xd0060372,0x78fa0122,0xeda700b4}},	//   _cim_, _سل_, _לפתו, _कच्छ,
   {{0x4424a875,0xe29903fe,0x80d3004e,0x6d414485}},	//   _dim_, сал_, _भेजे, ybla,
   {{0x6e2ba876,0x76ba0052,0xdb040176,0x776d01ef}},	//   _rugb, _המשפ, _dniè, lgax,
   {{0x4424a877,0x671f045c,0x6e2b010d,0x7dc40176}},	//   _fim_, _मृतक_, _sugb, _còsm,
   {{0x6e2301a3,0xffd500d8,0xa2d6364c,0xf3641f39}},	//   _sinb, яўля, _मेक्, _отун,
   {{0x600533d5,0x720541bd,0xd00e5919,0x7d0302df}},	//   nómi, _فورم, دلي_, _syns,
   {{0x4424a878,0xd1b81062,0x7c241130,0x6d41a879}},	//   _zim_, _والا_, _siir, ubla,
   {{0x442401a9,0x7c242efa,0x6d410a81,0xeb9a32a6}},	//   _yim_, _piir, rbla, бин_,
   {{0x6d41a87a,0x4424006f,0x6e2ba87b,0xf1b90009}},	//   sbla, _xim_, _tugb, _vušu_,
   {{0x74c300c8,0xbea518b9,0x6e23a87c,0x7c24a87d}},	//   ্পিউ, _халк, _tinb, _viir,
   {{0x7c240553,0xab5b006c,0xf1b9a87e,0x2caa0079}},	//   _wiir, lkül, _gušt_, óidí_,
   {{0x27e00086,0x7c24a87f,0x18a3004b,0x69ce0009}},	//   tiin_, _tiir, нарм, rhbe,
   {{0xa6db003e,0x69ce0510,0x25b80069,0x00000000}},	//   _leðu, shbe, _sorl_, --,
   {{0x27e0a880,0xa3c522d4,0xc0760023,0xab5b033b}},	// [c260] riin_, एसई_, _bướm_, rhüt,
   {{0x4424a881,0x27e003ad,0x1a9b02b5,0x7bc60421}},	//   _sim_, siin_, _פייע, lkku,
   {{0xc32a004f,0x69de09e8,0x02c4012f,0xa3e700a1}},	//   مكان_, _impe, वन्न, यचं_,
   {{0x7c2e0279,0x7bc6a882,0x7e69373b,0x44240024}},	//   íbri, nkku, kuep, _qim_,
   {{0x442401a9,0xd0560095,0x6d5c006c,0xdd1600a0}},	//   _vim_, əcək, órak, mäťo,
   {{0x4424a883,0x3ea02143,0x1df70f06,0x00000000}},	//   _wim_, _šito_, ुतोष_, --,
   {{0xdb0401ef,0x00000000,0x00000000,0x00000000}},	//   _dnié, --, --, --,
   {{0x67360035,0x32070035,0x672200ea,0xab5b00b5}},	//   ncyj, alny_, žoju, gkül,
   {{0x69de0421,0x9f5f1dad,0x00000000,0x00000000}},	//   _ompe, cluí_, --, --,
   {{0x60e7008a,0x3eb9312a,0x9f4402d7,0x7bc60298}},	//   ármá, ästa_, tomó_, ekku,
   {{0x6736004e,0x31570070,0x1b040033,0x00000000}},	//   kcyj, _זיבן_, রেমে_, --,
   {{0x69dea884,0xa3c50bdd,0xdb0d0183,0x00000000}},	//   _ampe, एसए_, _joaç, --,
   {{0x5fa93f9d,0xada660e9,0x00000000,0x00000000}},	//   कारल, _надл, --, --,
   {{0x64b500b8,0x7bc602ee,0x00000000,0x00000000}},	//   _hřiš, akku, --, --,
   {{0x29050093,0xa3be00ab,0x7dc40107,0x64b506fe}},	//   æla_, ेसा_, _lòsk, _křiš,
   {{0x69dea885,0x6005861c,0x00000000,0x00000000}},	//   _empe, tómi, --, --,
   {{0xe6640798,0x66f409eb,0x05870421,0xf1be0edf}},	// [c270] етхо, епту, зуем, ्सान,
   {{0x7bcda886,0x69de0118,0x600501ef,0x776d01ef}},	//   _hlau, _gmpe, rómi, sgax,
   {{0x7bcd221d,0x600501dd,0x6fe800b8,0x6b96027d}},	//   _klau, sómi, pěch, _yayg,
   {{0xdfc6004f,0x28d602e4,0xdb0d021d,0x00000000}},	//   _شي_, _डेटि, _coaç, --,
   {{0xdb0d03e6,0xd68417d0,0xfe0c046c,0x768400af}},	//   _doaç, _пурп, हतास_, _пырж,
   {{0x91055562,0x7dcd1d2b,0x7bcda887,0x27ed0d77}},	//   мпле, _músc, _llau, čenu_,
   {{0xa6db008a,0x846402fb,0x29381804,0xab5b00be}},	//   _veðu, _пъте, לאגן_, eküm,
   {{0xee3941fe,0xa247006c,0x439400c3,0x00000000}},	//   они_, _فیصل_, _пасс, --,
   {{0x63a9a888,0xab5b34a3,0x63bb009e,0x64dd02b4}},	//   _inen, rkül, _ioun, _मधुश,
   {{0xf1a4004e,0xa2d6114e,0xa2b20567,0x6b9601d6}},	//   _गोपन, _मेट्, _आपत्, _sayg,
   {{0x7bcda889,0x63bb0c1f,0x9d0b0083,0xeb9f0b3e}},	//   _blau, _koun, রশ্ন_, rløn_,
   {{0x63bb0c1f,0x61e3a88a,0x7dcd0300,0xeb9f008c}},	//   _joun, linl, _búsc, sløn_,
   {{0x63a9108a,0x63bb1fb0,0x7e6902d7,0x7bc600c3}},	//   _mnen, _moun, quep, rkku,
   {{0x7bcd30cb,0x63a400ea,0x61e3a88b,0x63bba88c}},	//   _elau, ķini, ninl, _loun,
   {{0x63a906a2,0x7bcda88d,0xabf61303,0xd7c922c7}},	//   _onen, _flau, _очищ, रसंच,
   {{0x63bba88e,0x7bcda88f,0x69c70051,0x63a9001c}},	//   _noun, _glau, akje, _nnen,
   {{0x61e3a890,0xfe7901c0,0xe7df1d25,0x67369974}},	// [c280] kinl, ntů_, _नगरप, rcyj,
   {{0x63a92ee5,0x044600c3,0x2bcc1b8f,0x69dea891}},	//   _anen, дежн, ासवा, _umpe,
   {{0x6d5c0037,0x63bb00a5,0xe72aa892,0x61e30448}},	//   órai, _boun, _монд_, dinl,
   {{0x63bb0052,0xfe7901c0,0x838300c3,0x00000000}},	//   _coun, ktů_, выше, --,
   {{0x63bb00f6,0x61e3a893,0x6e2d0098,0x00000000}},	//   _doun, finl, _éabh, --,
   {{0x61e3008a,0x63a94aff,0xc0aa03c7,0xdcf800c7}},	//   ginl, _enen, قابل_, _gavė,
   {{0x63bb0052,0xf1b80484,0x64b500b8,0x00000000}},	//   _foun, _jiġi_, _přiš, --,
   {{0xdb040176,0x00000000,0x00000000,0x00000000}},	//   _joió, --, --, --,
   {{0xf1b8003c,0x61e3a894,0x00000000,0x00000000}},	//   _liġi_, binl, --, --,
   {{0x7bcda895,0x63a901ba,0x60050093,0xab5b1cc6}},	//   _slau, _znen, dómu, rküm,
   {{0x7bcda896,0x61fd00fb,0xd12f1b15,0x63bba897}},	//   _plau, _ísla, _ضمن_, _youn,
   {{0xaec6562d,0x20140067,0x00000000,0x00000000}},	//   _обел, ócić_, --, --,
   {{0x501b00c2,0x5f1a0026,0x7bd601f4,0x7bcd00e2}},	//   _וואו, मेश्_, ëzua, _vlau,
   {{0x7c660d93,0xc98418cd,0x00000000,0x00000000}},	//   _قابل, куси, --, --,
   {{0x2d8ca898,0x69c70044,0x80e00033,0x64dd00b8}},	//   mede_, rkje, _পুত্, _मधेश,
   {{0x2d8ca899,0x0cca06d9,0x69c702ce,0x61e300c1}},	//   lede_, ानीम, skje, zinl,
   {{0x7dcd0093,0x63bb8418,0xa92b54ea,0x61e300d0}},	// [c290] _húsa, _roun, _міне_, yinl,
   {{0x2d8ca89a,0x63bba89b,0xaa8800bf,0x63a9022f}},	//   nede_, _soun, _کنیم_, _snen,
   {{0x5f05000c,0x63bb3116,0x61e3a89c,0x00000000}},	//   _हुन्_, _poun, vinl, --,
   {{0xe6670021,0x2d8c388e,0x7dcd1529,0x00000000}},	//   _отго, hede_, _músa, --,
   {{0xa2af02cb,0x2d8c7ec1,0x61e3a89d,0xa2946c6a}},	//   ंमध्, kede_, tinl, каці,
   {{0x2d8ca89e,0x409573a8,0xd2440012,0x63bb024b}},	//   jede_, ерит, тэци, _woun,
   {{0x63bb0c1f,0x2d8ca89f,0x61e3a8a0,0x00000000}},	//   _toun, dede_, rinl, --,
   {{0x61e3a8a1,0xb4bd4407,0x63a9a8a2,0x00000000}},	//   sinl, ेनी_, _unen, --,
   {{0x2ec91365,0xa3be238a,0x2d8c8a8d,0x00000000}},	//   िनेत, ेसर_, fede_, --,
   {{0xc6920122,0x2d8c8c56,0x61e30510,0x1c450352}},	//   נאי_, gede_, qinl, нном,
   {{0x4431004e,0xfe7901c0,0x41be00b4,0xeb9a174b}},	//   _juz_, stů_, ्सरस, пин_,
   {{0xeb9a1e31,0x224d08dd,0x4431a8a3,0x7dcd0079}},	//   чим_, _kwek_, _muz_, _dúsa,
   {{0x44312140,0x2d8ca8a4,0xaae00035,0x5ac70eb5}},	//   _luz_, bede_, _पेशक, елям_,
   {{0xf2d202b5,0x2d8ca8a5,0x3e790c1f,0x395e0248}},	//   נעם_, cede_, mèt_, ûts_,
   {{0x3e7902e9,0x997d0228,0x4431063c,0xfe0b02b4}},	//   lèt_, kāņu_, _nuz_, _सीएस_,
   {{0xc5fa0931,0x224d01a8,0x00000000,0x00000000}},	//   ्त्य_, _owek_, --, --,
   {{0x3e790c1f,0x6b84031e,0x44310139,0x00000000}},	// [c2a0] nèt_, _ibig, _auz_, --,
   {{0x24f60043,0xe4d700b5,0xf1b8003c,0x4431a8a6}},	//   нчер, کومت_, _tiġi_, _buz_,
   {{0x224d028b,0x290e00b5,0x8ca20067,0x6aa4008d}},	//   _awek_, _áfa_, गियो, _hrif,
   {{0xe9f90028,0xa6db0093,0x3e7902e9,0x7e7b2f79}},	//   _trả_, _veðr, kèt_, ktup,
   {{0x3d060992,0xa2941112,0x2d8c027d,0xf206a8a7}},	//   _सुने_, талі, yede_, няко,
   {{0xcb1300c2,0x7644a8a8,0x27ff04c3,0x00000000}},	//   אלד_, mpiy, čune_, --,
   {{0x60050093,0x6b84a8a9,0x4fc603f5,0x44313b5e}},	//   jóms, _obig, еспа, _guz_,
   {{0x5fa3009a,0xdfd00082,0x3e7902e9,0x2d8c0dc3}},	//   _खोदल, شيخ_, fèt_, wede_,
   {{0x444402ce,0x2d8c4eb1,0x3ea2008a,0xdb1d00a8}},	//   lp_, tede_, íkt_, üyün,
   {{0x6b84a8aa,0x44310471,0x99890506,0x444442dd}},	//   _abig, _yuz_, _staž_, op_,
   {{0x2d8ca8ab,0x44440359,0x7e7b010d,0x9f440055}},	//   rede_, np_, atup, nimë_,
   {{0x4444a8ac,0x2d8ca8ad,0x6aa4001e,0x6fce009e}},	//   ip_, sede_, _brif, _fùca,
   {{0x2d8ca8ae,0x6aa40e0b,0x5a343367,0x7b1e07c0}},	//   pede_, _crif, лнят, _náuč,
   {{0x6aa41e54,0xdd93005f,0x6b840273,0x7dcd0093}},	//   _drif, _башы, _ebig, _húsn,
   {{0x44440120,0x6a146a63,0x6aa4001c,0x4cde0033}},	//   jp_, умру, _erif, _নুরু,
   {{0x6aa422c0,0x00000000,0x00000000,0x00000000}},	//   _frif, --, --, --,
   {{0xb908111e,0x645c24e0,0x798e25b4,0x44443e8f}},	// [c2b0] _मे_, _avri, bebw, ep_,
   {{0x44310afb,0xd05600a8,0x6b840067,0x00000000}},	//   _puz_, şbəx, _zbig, --,
   {{0xf1b80484,0xb4bd0914,0x98b8010b,0x89dc011d}},	//   _jiġu_, ेने_, darė_, _מחזי,
   {{0x6b9da8af,0xf8b60d85,0x636b00a8,0x00000000}},	//   ndsg, _ספרי_, dönü, --,
   {{0x4444a8b0,0x41be018d,0x44310223,0x645ca8b1}},	//   ap_, ्संस, _wuz_, _evri,
   {{0xc0e52e76,0x4431a8b2,0x2618252b,0xe453097f}},	//   колк, _tuz_, _बीपी_, _مضر_,
   {{0x2ec922a7,0xe1f00180,0xf8d1046c,0xf1b8007a}},	//   िन्त, حسن_, सनिय, _niġu_,
   {{0x6445a8b3,0x5ee20083,0x3e790c1f,0x6b9da8b4}},	//   mphi, _পড়ে, tèt_, jdsg,
   {{0x6445a8b5,0x623537f8,0x3f8d03bc,0x603100ea}},	//   lphi, _резу, reeu_, _māmi,
   {{0x3e79a8b6,0x7e7ba8b7,0x6445a8b8,0xe53000a8}},	//   rèt_, rtup, ophi, _müğə,
   {{0x3e7910af,0xbebd010b,0xcb6a2e14,0x9f5f00a2}},	//   sèt_, ncūz, мане_, houé_,
   {{0xa3d7004e,0x6aa4a8b9,0x5f7400f3,0xdb040065}},	//   ाफट_, _prif, _ماهر, _soiñ,
   {{0x6ec40041,0xb5fb00ac,0x00000000,0x00000000}},	//   _متوق, _kvád, --, --,
   {{0x6e2aa8ba,0x27e2012f,0x200da8bb,0xdce10035}},	//   _gifb, _smkn_, llei_, zglę,
   {{0x4444a8bc,0x798e1939,0xeb9a00af,0xe9a30d6e}},	//   xp_, rebw, _жий_, јасп,
   {{0xa2b20429,0x6aa4a8bd,0x6fde00ea,0x44440116}},	//   _आपल्, _trif, tūci, vp_,
   {{0x78a50022,0x7bdd0031,0x6aa40371,0x645ca8be}},	// [c2c0] _erhv, ërue, _urif, _svri,
   {{0x64a630e0,0x69d50b7b,0x08c688f0,0x4444055c}},	//   каза, chze, _абон, tp_,
   {{0x4444a8bf,0x200da8c0,0xe8f7002d,0x6289021d}},	//   up_, klei_, _алэ_, _apeo,
   {{0x39580955,0x44443754,0x7dc401f7,0x7e69a8c1}},	//   lars_, rp_, _hòst, krep,
   {{0x4444a8c2,0x7e690009,0x98b8010b,0x7dc40107}},	//   sp_, jrep, tarė_, _kòst,
   {{0x3958a8c3,0x4444a8c4,0x7e69a8c5,0xdddb00ea}},	//   nars_, pp_, drep, lruņ,
   {{0x645c025c,0x200600f6,0x00000000,0x00000000}},	//   _uvri, _pkoi_, --, --,
   {{0x28ba25d8,0xb4251b20,0x27f2a8c6,0x6fe70118}},	//   _उपनि, _معقو, nnyn_, _rècè,
   {{0xb22600d8,0x8fa31a31,0x7e69a8c7,0x395800ea}},	//   _амал, рање, grep, kars_,
   {{0x22463a9f,0x20e302cb,0x71a30043,0x27010023}},	//   mpok_, _केवळ_, _кауз, ỗng_,
   {{0x5fa30302,0x1da602cb,0x3958a8c8,0x6d48010b}},	//   _खोवल, _कोणत, dars_, rbda,
   {{0x7d0a0298,0x200d225a,0x00000000,0x00000000}},	//   _vyfs, clei_, --, --,
   {{0x7dc4009e,0x6b9d28a6,0x39580349,0x6d5ca8c9}},	//   _bòst, rdsg, fars_, óras,
   {{0x3958a8ca,0x3cfd0066,0x3c58002d,0x00000000}},	//   gars_, _रुके_, _зикэ_, --,
   {{0xf8078995,0x13ca0033,0x98c400c3,0x3ea600d5}},	//   вчан, লোয়, астл, _hrot_,
   {{0x2d9ca8cb,0x2004a8cc,0x26180437,0x5f1907df}},	//   _have_, nomi_, _बीबी_, _परम्_,
   {{0x2d9c06cc,0xa3b697c4,0x3d0600ab,0x2b59a503}},	// [c2d0] _kave_, जान_, _सुते_, masc_,
   {{0x68ee004f,0x7c2da8cd,0x2d9ea8ce,0x2d9c01f4}},	//   ándá, _hiar, ndte_, _jave_,
   {{0x7c2d0054,0x65941bca,0x2004a8cf,0x2d9c08c8}},	//   _kiar, раху, komi_, _mave_,
   {{0x2d9ca8d0,0xdb040370,0x200489bb,0x6445a8d1}},	//   _lave_, _uniã, jomi_, rphi,
   {{0x7c2da8d2,0x2004a8d3,0xe28502ee,0x200d03bc}},	//   _miar, domi_, улли, vlei_,
   {{0x2d9ca8d4,0x27e93cc2,0x59c60127,0xe2140409}},	//   _nave_, lian_, रॉपर, амчы,
   {{0x7c2d01d7,0x2054005f,0x7e690312,0x316901fb}},	//   _oiar, атыр, wrep, ğaz_,
   {{0x7e69a8d5,0x3ea6a8d6,0x7c2d0312,0x2d9e5504}},	//   trep, _brot_, _niar, edte_,
   {{0x200d0d21,0x51f91470,0x2d9c2e5b,0xa2f500d8}},	//   rlei_, _знаю_, _bave_, _спач,
   {{0x442da8d7,0xb5fb024e,0x5bcc2c2b,0x2bcc0d91}},	//   _hie_, _uvád, ास्व, ास्थ,
   {{0x27e9a8d8,0x442da8d9,0x7c2d983b,0x0c260368}},	//   kian_, _kie_, _biar, лмон,
   {{0x442d01c8,0x27e91221,0x7c2da8da,0x2004a8db}},	//   _jie_, jian_, _ciar, comi_,
   {{0x27e949c2,0x442da8dc,0xd37a02b5,0x6fd53641}},	//   dian_, _mie_, ערשט, _cáce,
   {{0x2d9ca779,0x442da8dd,0x00000000,0x00000000}},	//   _gave_, _lie_, --, --,
   {{0x7c2da8de,0xa3b60084,0x3958744c,0x66050034}},	//   _fiar, जाम_, rars_, dohk,
   {{0x442da8df,0xb8dc0755,0x27e90224,0x7c2d01d3}},	//   _nie_, _आप_, gian_, _giar,
   {{0xe61a292e,0x3958a8e0,0xa3d74407,0x26c90159}},	// [c2e0] еда_, pars_, िसन_, gyao_,
   {{0xa2a72203,0x7c2da8e1,0x27ff02dd,0x200402c4}},	//   चिन्, _ziar, čuna_, zomi_,
   {{0xdd5602b5,0x442da8e2,0xdb0d0176,0x200401cb}},	//   רבעט_, _bie_, _anaè, yomi_,
   {{0xddc90bc6,0x2ca70af0,0x7c3e00f7,0x442da8e3}},	//   jtež, _mrnd_, _épre, _cie_,
   {{0x442d33b3,0xa3b62cb0,0x41e601c8,0x66050ac8}},	//   _die_, जाब_, ліка, bohk,
   {{0x442d0626,0x69ce4aa9,0x00000000,0x00000000}},	//   _eie_, nkbe, --, --,
   {{0x442d0012,0x799e011e,0x2b4002d7,0x3f9d0103}},	//   _fie_, _mapw, _ofic_, _bawu_,
   {{0x09d10d00,0x442da8e4,0xaa860076,0x645e0da2}},	//   _हत्य, _gie_, _zvýš, mspi,
   {{0x7c2d0a32,0x644101f4,0x2d9c01e0,0x645e0c9c}},	//   _riar, _çlir, _pave_, lspi,
   {{0x20046289,0x442d04ce,0x7c2da8e5,0xc6930122}},	//   somi_, _zie_, _siar, צאת_,
   {{0x645e06c6,0x442d0118,0x00000000,0x00000000}},	//   nspi, _yie_, --, --,
   {{0xdce300d0,0x61ea3833,0x27e90065,0x645ea8e6}},	//   _canı, lifl, xian_, ispi,
   {{0xdce30ec4,0x7c2da8e7,0x2d9c010b,0x2b59a8e8}},	//   _danı, _viar, _tave_, rasc_,
   {{0x27e9a8e9,0xa3ab1782,0x7c2d0035,0x799e0024}},	//   wian_, _कोन_, _wiar, _capw,
   {{0x27e996b1,0x248d326f,0x7c2da8ea,0x799e0260}},	//   tian_, _ćemo_, _tiar, _dapw,
   {{0x645ea8eb,0x69ce0223,0xb5fb3536,0x00000000}},	//   dspi, akbe, _ovác, --,
   {{0x645e0c71,0x356b386a,0x00000000,0x00000000}},	// [c2f0] espi, ерен_, --, --,
   {{0x442da8ec,0x6d5aa8ed,0x27e9a074,0x69cea8ee}},	//   _sie_, nata, sian_, ckbe,
   {{0xdce30d6f,0x27e941de,0x7cd300a8,0x442d3cdb}},	//   _yanı, pian_, tərə, _pie_,
   {{0x6d5aa8ef,0xd4980409,0xdce30095,0xa3df0035}},	//   hata, ыру_, _xanı, धों_,
   {{0x6d5a319d,0x442da8f0,0x49b809b9,0x12870a86}},	//   kata, _vie_, _شاید_, امتی_,
   {{0x442d0b19,0x6a6c008a,0xa5f9737f,0x3f9d012f}},	//   _wie_, _höfð, _регу_, _sawu_,
   {{0x442d6781,0x6d5aa8f1,0x7d1c008a,0x3f9d0103}},	//   _tie_, data, ýrsl, _pawu_,
   {{0x442d0298,0x6b9f0024,0x41b500fd,0x00000000}},	//   _uie_, _naqg, _ھمار, --,
   {{0x6d5a0232,0x8db5093e,0xa3ab046c,0x00000000}},	//   fata, асні, _कोय_, --,
   {{0x0d8238df,0xdce301d6,0x629b08dd,0xac857a4e}},	//   ольн, _sanı, _isuo, агол,
   {{0x6b9f007a,0x644101ef,0x3207a8f2,0x7dcd1d54}},	//   _baqg, _élid, mony_, _húsk,
   {{0xa0c4026e,0x6d5a010d,0x8b262f4c,0x3207900b}},	//   _ديمو, aata, идне, lony_,
   {{0x6d5a483d,0x7bdd01f4,0xa3b6073f,0x799e6d4d}},	//   bata, ërua, जात_, _papw,
   {{0x6d5a77e7,0xdca50009,0x68467e78,0x645e2c17}},	//   cata, _ваки, инга, yspi,
   {{0xdce3036a,0x69ce0d35,0x983600d8,0x97c66a2d}},	//   _tanı, rkbe, рэгі, айве,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32071055,0x1b0d00c8,0x2b4d0391,0xe7379d83}},	// [c300] kony_, সেবে_, ñece_, реу_,
   {{0x2d853b46,0x645ea8f3,0x7bc400be,0xd9460274}},	//   nfle_, tspi, _hoiu, _њени,
   {{0x3ea902c4,0x645ea8f4,0x7bc401ed,0x00000000}},	//   _šatl_, uspi, _koiu, --,
   {{0x6d5aa8f5,0x7dcd4a12,0x645e9ae1,0xe3b20312}},	//   zata, _búsk, rspi, غرا_,
   {{0x32071db1,0x645ea8f6,0x61eaa8f7,0x98b10067}},	//   fony_, sspi, tifl, rczą_,
   {{0x64432dd3,0x40340328,0xf8ba0967,0x64a662a6}},	//   ínic, бекс, _उपाय, _кага,
   {{0x6d5aa8f8,0x61eaa8f9,0xa3b60026,0x1c0600b4}},	//   vata, rifl, जाद_, रवाल_,
   {{0x6d5aa8fa,0x201d00e9,0xbfa700c3,0x44380207}},	//   wata, _chwi_, атье_, _iur_,
   {{0x6d5aa8fb,0x44384b47,0x3207a8fc,0xe2971ca9}},	//   tata, _hur_, bony_, _кат_,
   {{0x4438a8fd,0x63a0a8fe,0x61ed0037,0x127b0070}},	//   _kur_, _hamn, éalt, _באמע,
   {{0x6d5aa8ff,0xa3ab0d2b,0x6282928f,0x4438a900}},	//   rata, _कोड_, ltoo, _jur_,
   {{0x63a2a901,0x4438a902,0x6d5aa903,0x63a0a904}},	//   ndon, _mur_, sata, _jamn,
   {{0x6d5a08dd,0x6282a905,0x4438a906,0x63a0055c}},	//   pata, ntoo, _lur_, _mamn,
   {{0x443801f3,0xa2a70c67,0x6d5a9273,0x2481a907}},	//   _our_, चित्, qata, ythm_,
   {{0x44380446,0x19580bbc,0x6d580029,0x29040c27}},	//   _nur_, расы_, _ieva, şman_,
   {{0x63a0a908,0x63a2006c,0x3207a909,0x62826f5e}},	//   _namn, jdon, zony_, ktoo,
   {{0x6d58007c,0x4438a90a,0x63a2a90b,0xc9873832}},	// [c310] _keva, _aur_, ddon, _куни,
   {{0x6d58a90c,0x63a2a90d,0x4438a90e,0x3207a90f}},	//   _jeva, edon, _bur_, xony_,
   {{0x4438003b,0x79951596,0x8ca90035,0xd49b01d3}},	//   _cur_, mezw, टियो, ъра_,
   {{0x6d58a910,0x69c5a911,0x79950054,0x63a28039}},	//   _leva, _hohe, lezw, gdon,
   {{0x7cca01c2,0x69c5a912,0x62820159,0x3207a913}},	//   lərd, _kohe, gtoo, tony_,
   {{0x7c3862e8,0x51870714,0x799536e0,0x6d583cdb}},	//   _ouvr, руда, nezw, _neva,
   {{0x4438a914,0x3207006a,0x161d0084,0x62827259}},	//   _gur_, rony_, _बीयर_, atoo,
   {{0x628201e8,0x63a2a915,0xe3b3006c,0x79952a13}},	//   btoo, cdon, _برس_, hezw,
   {{0x44380446,0x7dcd0093,0x79952f10,0xdee57daf}},	//   _zur_, _húsi, kezw, сопи,
   {{0x6d580723,0x7e6218b0,0x69c504fb,0x6fce0284}},	//   _ceva, _dvop, _nohe, _lùch,
   {{0x6d58a916,0x63a07060,0x00000000,0x00000000}},	//   _deva, _yamn, --, --,
   {{0xe9f90028,0x7c380036,0x69d70042,0x2baf022e}},	//   _trẻ_, _duvr, _alxe, टागा,
   {{0xed4e2784,0x69c5a917,0x00000000,0x00000000}},	//   _но_, _bohe, --, --,
   {{0x6d581c47,0x799508bd,0x7cca00a8,0xed590112}},	//   _geva, gezw, fərd, _сок_,
   {{0x6d41005f,0x63a20381,0xab5ba918,0x7bc40139}},	//   mcla, ydon, rkür, _toiu,
   {{0x6d4101f2,0x228002d0,0x6fce009e,0x4438a919}},	//   lcla, yòk_, _cùch, _rur_,
   {{0x4438a91a,0x05666ac5,0x6282008c,0x28ba0a90}},	// [c320] _sur_, йван, xtoo, _उपवि,
   {{0x63a0a91b,0x63a20b77,0x7cca0095,0x6282006f}},	//   _samn, wdon, bərd, vtoo,
   {{0xb8ed0b52,0x69dc184f,0x63a200e2,0xe0070246}},	//   _শে_, mhre, tdon, शवाद_,
   {{0x53e500d4,0x8c360070,0x6282a91c,0x443800a3}},	//   оціа, צטנס_, ttoo, _vur_,
   {{0x63a2a91d,0x63a001e8,0x44380051,0x69c501d5}},	//   rdon, _vamn, _wur_, _yohe,
   {{0x4438a91e,0x62825b9c,0x9f440079,0xa50a1f6a}},	//   _tur_, rtoo, rimí_, _бега_,
   {{0x6d58a91f,0x63a00690,0x443806ba,0x6282a920}},	//   _reva, _tamn, _uur_, stoo,
   {{0x6d41055c,0x232a2701,0x6d43a921,0x79956ff2}},	//   ecla, _боби_, _afna, zezw,
   {{0x7c380c21,0x6d580a78,0x7cca0095,0x63b30314}},	//   _suvr, _peva, zərd, šení,
   {{0x4426a922,0xdd9a05a1,0xa3b6018d,0x6d4301ed}},	//   lmo_, уши_, जाव_, _cfna,
   {{0x6d58017b,0x69c500ab,0x69dc0037,0x442670de}},	//   _veva, _rohe, dhre, omo_,
   {{0x44260c22,0x6d43008a,0xa09b00a5,0x6d415eb2}},	//   nmo_, _efna, _תיאט, acla,
   {{0x6d410e8f,0x7995035a,0x4426a923,0x6d58a924}},	//   bcla, tezw, imo_, _teva,
   {{0x69dca925,0x2fc602e6,0x6abb0083,0x4426a926}},	//   ghre, _hoog_, উনলো, hmo_,
   {{0x58d43275,0x2fc67048,0xd7fb0395,0x79950010}},	//   порт, _koog_, гуа_, rezw,
   {{0x44260169,0x36d51583,0x69c51508,0x28ba0355}},	//   jmo_, ообр, _wohe, _उपरि,
   {{0x76b9027a,0x2fc6a927,0x69dc09c3,0x6b8da928}},	// [c330] шлар_, _moog_, bhre, _ibag,
   {{0x69dca929,0x2fc60221,0x98a3033e,0x6aad0371}},	//   chre, _loog_, sajı_, _iraf,
   {{0x6d9e0484,0x07350382,0x6aad0093,0x6b8d0118}},	//   _għaż, _меню, _hraf, _kbag,
   {{0xedb51033,0x4426010d,0x6d410020,0x2fc6006f}},	//   _अच्छ, gmo_, zcla, _noog_,
   {{0x6b8da92a,0x601e01f4,0x00000000,0x00000000}},	//   _mbag, këmb, --, --,
   {{0x4426a92b,0x764d7b6e,0x6e390223,0x6b8d0103}},	//   amo_, mpay, _ruwb, _lbag,
   {{0x86fb0033,0x602500d8,0x2fc60fdb,0xdb0d0042}},	//   _আরিফ_, одка, _boog_, _moañ,
   {{0x5fa30722,0x6aad0036,0x7a2001ff,0x6b8d030d}},	//   _खोखल, _oraf, möte, _nbag,
   {{0xa3b600fa,0xee360733,0x2fc6006d,0x764d02e9}},	//   जार_, оны_, _doog_, npay,
   {{0x6b8d1810,0x27080028,0xb8010033,0x27ed0355}},	//   _abag, ởng_, ্ষিত_, čeny_,
   {{0x6d41a92c,0x6aada92d,0x6b8da92e,0x00000000}},	//   rcla, _araf, _bbag, --,
   {{0x6d41a92f,0xab2a0145,0xdb040037,0xa3cc0026}},	//   scla, иона_, _iniú, शॉप_,
   {{0x69dca930,0x2b4d00de,0x6aad8fd4,0x6b8d0118}},	//   thre, ñeca_, _craf, _dbag,
   {{0x6aada931,0x442600d8,0x7a201ac9,0x6b8d030d}},	//   _draf, zmo_, köte, _ebag,
   {{0xe73a3d17,0x44261f81,0x75e90095,0x2fc60221}},	//   иев_, ymo_, _gözə, _yoog_,
   {{0xe7370d36,0x69dc003e,0x6b8d40a8,0x44260523}},	//   жет_, shre, _gbag, xmo_,
   {{0x6aad426b,0x70b62874,0x764d0c47,0x69dc04d3}},	// [c340] _graf, _अप्ल, gpay, phre,
   {{0x9f4d0298,0x00000000,0x00000000,0x00000000}},	//   fieë_, --, --, --,
   {{0xa3b611b5,0x2baf0bdd,0xa4430168,0x9f4d0b88}},	//   जाल_, टाचा, _púšť_, gieë_,
   {{0xccf200a5,0x44260409,0x00000000,0x00000000}},	//   וכב_, umo_, --, --,
   {{0x25a3003c,0x2fc6a932,0x7dcd008d,0xa22a188d}},	//   _fajl_, _roog_, _húsu, ажда_,
   {{0x4426028b,0x7d06006a,0x2fc60345,0x3dc70260}},	//   smo_, ększ, _soog_, _nonw_,
   {{0xfd070332,0x2fc6a933,0xd4670086,0xd12f00ce}},	//   _آج_, _poog_, _мире_, نمه_,
   {{0xb4d60302,0xef19004e,0xe45300fd,0x00000000}},	//   िनी_, leży_, _آہنگ, --,
   {{0x6fdc02e1,0xa3d73933,0x2fc6a934,0xb5fb040f}},	//   _néce, िसर_, _voog_, _ovál,
   {{0x6b8d02fb,0x06cd0033,0x6aad0031,0x5c7436ed}},	//   _sbag, _রেডি, _rraf, плот,
   {{0x2fc60221,0x601e0031,0x212a0211,0x00000000}},	//   _toog_, rëmb, _àbh_, --,
   {{0x6aad9920,0x764d0159,0x00000000,0x00000000}},	//   _praf, ypay, --, --,
   {{0x6fe8004e,0x6448000d,0x6aad00a8,0x764d0f00}},	//   jści, _édif, _qraf, xpay,
   {{0x6fdc02e1,0x7c3e000d,0x1e3300d8,0xb5fb00fe}},	//   _déce, _épro, _жніў, _cvál,
   {{0xa3170066,0x6fe80035,0x02b707df,0x00000000}},	//   _तर्ज_, eści, _आप्न, --,
   {{0x386d1164,0x6b8da935,0x764d0a21,0x00000000}},	//   čer_, _ubag, tpay, --,
   {{0x6aad002f,0x764d0a4e,0xf40200af,0xa3ab12e7}},	// [c350] _uraf, upay, inţă_, _कोष_,
   {{0x29010221,0x764da936,0xdcea027d,0x7a200a48}},	//   _txha_, rpay, _hafı, töte,
   {{0xd37100ad,0x25a30009,0xa3b60096,0x00000000}},	//   فها_, _vajl_, जां_, --,
   {{0xa3ab0e04,0x3cfb02b5,0x9f4d03bc,0xa3e60066}},	//   _कोश_, סלאנ, rieë_, योल_,
   {{0xfbd4024b,0x00000000,0x00000000,0x00000000}},	//   ותף_, --, --, --,
   {{0x1a9c02b5,0xe57002fd,0xfa7800a5,0x61452c83}},	//   יידע, _لطف_, קעות_, чека,
   {{0xdd1c00a0,0x987800cd,0xe0d100fd,0x00000000}},	//   yšši, ršće_, عزت_, --,
   {{0x78fc016b,0x3dc70260,0x00000000,0x00000000}},	//   יפוו, _sonw_, --, --,
   {{0xfe710037,0x00000000,0x00000000,0x00000000}},	//   ردة_, --, --, --,
   {{0x6fdc02e1,0x6fd50097,0xee360f23,0x00000000}},	//   _réce, _zácl, янь_, --,
   {{0xcb0935d9,0x6f021d35,0x2bd00066,0x1d0923ff}},	//   _על_, _exoc, _हकदा, сени_,
   {{0x290401d6,0x6fe80067,0xfbdf0345,0x00000000}},	//   şmak_, yści, ghê_, --,
   {{0xeb978790,0x7dcda937,0x7f3a076b,0x00000000}},	//   чия_, _búst, _התנג, --,
   {{0x7dcd01ef,0xada50009,0xa3b20099,0x200d63e3}},	//   _cúst, _хакл, _झोन_, loei_,
   {{0x291e01ff,0x00000000,0x00000000,0x00000000}},	//   åta_, --, --, --,
   {{0xfbdf0132,0x75e000b5,0xe61f021d,0x7d1ca938}},	//   chê_, _közg, _opôs_, ürse,
   {{0x7c24007b,0x7cca013b,0x00000000,0x00000000}},	// [c360] _ihir, məra, --, --,
   {{0x4994006c,0x7cca013b,0x6fe80067,0x3ebf0176}},	//   _تیسر, ləra, rści, ixut_,
   {{0xc9531899,0xb4d63efe,0xd9100609,0x200d01d7}},	//   _אמת_, िने_, _شیر_, koei_,
   {{0xa3e60755,0x3eaf0310,0x93431283,0x73fc0033}},	//   यों_, _orgt_, енце, েষ্ট_,
   {{0x27e0a939,0x6fd500b8,0x7c243dbf,0x741300d1}},	//   mhin_, _václ, _mhir, روها,
   {{0x27e02700,0x7c24010d,0x91e312b1,0xc297010b}},	//   lhin_, _lhir, ноче, якіх_,
   {{0x021900d8,0x7c24016e,0x3eaf0282,0x76490225}},	//   ціць_, _ohir, _argt_, _çeyr,
   {{0xdfd00082,0x27e0a93a,0xb4fb00a5,0x200d0065}},	//   ئية_, nhin_, _הפלי, goei_,
   {{0x442402c9,0x27e00086,0xa1360037,0x26c0002a}},	//   _ihm_, ihin_, _فراش, nxio_,
   {{0xa0a61b50,0x657ea93b,0x27ff03ab,0x7c24a93c}},	//   _назд, ngph, čuni_, _ahir,
   {{0x3d0600be,0x7dcda93d,0x4424a93e,0x2b4d0453}},	//   _सुखे_, _rúst, _khm_, ñeco_,
   {{0x7dcda93f,0xddc900af,0xdddb03e0,0x00000000}},	//   _súst, treţ, rtuš, --,
   {{0x7c2400f8,0x27e0a940,0x9b2403e6,0xdddb005f}},	//   _dhir, dhin_, ефрл, stuš,
   {{0x80a10066,0x7c240103,0x00000000,0x00000000}},	//   _कैडे, _ehir, --, --,
   {{0x69d501ae,0xb4d60ea3,0x27e0033b,0x44241330}},	//   rkze, िनो_, fhin_, _ohm_,
   {{0x2d8c0d26,0x7c2413fb,0x27e0a941,0xa3ab0067}},	//   lfde_, _ghir, ghin_, _कों_,
   {{0xa3b6007c,0xba6b0037,0x00000000,0x00000000}},	// [c370] जाई_, _احبك_, --, --,
   {{0x06140086,0x4424010d,0x00000000,0x00000000}},	//   едую, _ahm_, --, --,
   {{0xf8d10299,0xd9182dc3,0x27e070cc,0xdb160359}},	//   _हथिय, _нью_, bhin_, _anyè,
   {{0x27e0a942,0x7c240031,0xb5fb00fe,0xd8284747}},	//   chin_, _xhir, _kvák, _ніяк_,
   {{0x59d106bc,0x442401f7,0x46a400d8,0x248d0124}},	//   _सकार, _dhm_, _заўв, _ćemu_,
   {{0x644a2cad,0x76ba00a5,0xe7d505f9,0xd00e0580}},	//   ífic, _ומשפ, _yığı, یلو_,
   {{0x69be0099,0x00000000,0x00000000,0x00000000}},	//   शाती, --, --, --,
   {{0x2d8c0b0d,0x7ddf021d,0xd2590260,0x00000000}},	//   efde_, _mêse, _twņ_, --,
   {{0xc91a0066,0xf8ba021a,0x200d9b66,0x521500c3}},	//   _धर्म_, _उप्प, roei_, _ждат,
   {{0x7c24a943,0x7dcda944,0x27e001f4,0x75e000d0}},	//   _shir, _rúss, zhin_, _gözd,
   {{0xddc91851,0xa3b8006c,0x601e01f4,0x2baf0026}},	//   greš, _ظاہر_, sëma, _जोहा,
   {{0x307802e7,0x2d8c0b88,0x00000000,0x00000000}},	//   _رحمة_, afde_, --, --,
   {{0xbdf800f5,0xbea500d8,0x3ce900b8,0xe7d5045e}},	//   _کرنا_, _цалк, _živě_, _sığı,
   {{0x75e0006c,0xddc90009,0xdb0600b5,0x3f8d0176}},	//   _köze, breš, ndké, lfeu_,
   {{0x27e0a945,0x3ead0c7d,0x7c24a946,0x6fd500d5}},	//   thin_, lvet_, _thir, _náck,
   {{0x6fdc0118,0x7c240027,0x00000000,0x00000000}},	//   _kéca, _uhir, --, --,
   {{0xb4d601c0,0x27e0a947,0xa3ab0066,0x3ead00ee}},	// [c380] िन्_, rhin_, _कोइ_, nvet_,
   {{0x27e001d2,0x6fdc0248,0x7bc60506,0x6aa4a948}},	//   shin_, _méca, ljku, _isif,
   {{0xe73a0133,0x799ca949,0x27e01c9e,0x69de0036}},	//   _мен_, merw, phin_, _ilpe,
   {{0xd36f0082,0x799ca94a,0xb4d6018d,0x7e7b6f5e}},	//   لهم_, lerw, िनौ_, kuup,
   {{0x420a1499,0xaaa7000c,0xddc95620,0x91e6a94b}},	//   ондо_, खिएक, zreš, моде,
   {{0x799ca94c,0x9f46033b,0x6aa408c7,0x6b84009e}},	//   nerw, _bloß_, _msif, _lcig,
   {{0xe36603fa,0x442405f5,0x6b840506,0x320e0c3d}},	//   _окви, _thm_, _ocig, rofy_,
   {{0x442402a9,0x799c8bdf,0x6aa43346,0xce6a98d7}},	//   _uhm_, herw, _osif, ород_,
   {{0x799c0428,0xcebb0095,0xe24616e6,0x4444a94d}},	//   kerw, _şərh_, _آخري, lq_,
   {{0x7dcd00c8,0x6fdc2cad,0xddc930ec,0x236d008b}},	//   _búsq, _déca, treš, _zdej_,
   {{0x05770122,0x75e0a94e,0x44447d40,0xdb0a0187}},	//   וגים_, _közb, nq_, čným,
   {{0x69dea94f,0x44441505,0x6fd5031d,0x644e0168}},	//   _alpe, iq_, _nách, _mtbi,
   {{0x799ca950,0x44440118,0x3ead0009,0x6b840211}},	//   ferw, hq_, cvet_, _dcig,
   {{0xa3aba951,0x2014004e,0x799c0b69,0xddc97615}},	//   _कोई_, ścią_, gerw, preš,
   {{0x6d4a007a,0x6fd500fe,0x29050225,0x7764021d}},	//   _iffa, _bách, çla_, faix,
   {{0x69de2b01,0x656e0211,0x2905003c,0xdc2b00d1}},	//   _elpe, _adbh, ħla_, _بسته_,
   {{0x644e0ae0,0x44440484,0x799ca952,0x6b9d8a9b}},	// [c390] _atbi, eq_, berw, mesg,
   {{0x645c001e,0x7dc402d0,0x6b9d3084,0x39471505}},	//   _bwri, _pòsy, lesg, _üns_,
   {{0x79850118,0x77642ce4,0x7bcd042a,0x224da953}},	//   _ichw, baix, _koau, _stek_,
   {{0x7764a954,0x64413d7f,0x6b9d9399,0x6e380523}},	//   caix, _élim, nesg, _livb,
   {{0x444400d7,0x645c0036,0x6d4a0bd1,0x5334010b}},	//   aq_, _ewri, _offa, вецт,
   {{0x7ff507a8,0x6fd5024e,0x27ff068b,0x6fdc000d}},	//   کستا, _zách, čunu_, _réca,
   {{0x44442c60,0x26180026,0x6fdc076c,0x645c0090}},	//   cq_, _बीटी_, _séca, _gwri,
   {{0x799ca955,0x6d4aa956,0x7e7ba957,0x6fd500ee}},	//   zerw, _affa, tuup, _káci,
   {{0x63bba958,0x799ca959,0xcdf51ac5,0x7cca00a8}},	//   _inun, yerw, ечны, fəro,
   {{0x7bdf0083,0x3eada95a,0x63a9a95b,0x7dcd0138}},	//   _alqu, rvet_, _haen, _cúsp,
   {{0x63a9a95c,0x3ead02c6,0x7e7b0553,0x799c0a2e}},	//   _kaen, svet_, suup, verw,
   {{0xff53028c,0x6565a95d,0x6d4aa95e,0x799ca95f}},	//   _شخص_, hahh, _effa, werw,
   {{0x799ca960,0x63a9a961,0x7cca0095,0x78a5012f}},	//   terw, _maen, lərl, _ashv,
   {{0xada21646,0x63a9007c,0x69c100ab,0x7bdf1c5b}},	//   _башл, _laen, ölep, _elqu,
   {{0x799c2d06,0x63bb0644,0x6445006d,0x98aa037a}},	//   rerw, _onun, jqhi, tabı_,
   {{0x07a35654,0x799ca962,0x63a9a963,0x79850359}},	//   ласн, serw, _naen, _echw,
   {{0xd7073982,0x7cca0095,0x6aa408c7,0x799c0147}},	// [c3a0] енте_, hərl, _usif, perw,
   {{0x2a570319,0xe617a964,0xf0a50023,0x98aa045e}},	//   _רבין_, еду_, _đàng_, sabı_,
   {{0x6fd50453,0x63a90a5f,0x628b0298,0x00000000}},	//   _tách, _baen, etgo, --,
   {{0x6fd50d65,0x63a90df1,0x65650ec1,0x4444a965}},	//   _fáci, _caen, aahh, rq_,
   {{0xa3e6017f,0x79850297,0xdbc7007c,0x76440510}},	//   योग_, _ychw, _tööl, qqiy,
   {{0x6445006d,0x645c00e9,0x7cca00a8,0x00000000}},	//   bqhi, _twri, fərl, --,
   {{0x6603149e,0x644e022a,0x63a9a966,0x7cca00a8}},	//   _спра, _utbi, _faen, gərl,
   {{0xb4be1f29,0x291aa967,0x3a3aa968,0x63a90090}},	//   ेही_, _mypa_, _lipp_, _gaen,
   {{0x3ea90009,0x7e690159,0x7d18008c,0x43750fb4}},	//   _šatr_, gsep, _syvs, _јуст,
   {{0x7cca0669,0x63a9a969,0x00000000,0x00000000}},	//   bərl, _zaen, --, --,
   {{0x63a90c59,0x67fb00c3,0x7fd601e0,0x291a0523}},	//   _yaen, näjä, _піді, _nypa_,
   {{0x79850446,0x7d1800ac,0x00000000,0x00000000}},	//   _schw, _vyvs, --, --,
   {{0x6b9d06a2,0xd00f0037,0x00000000,0x00000000}},	//   resg, _الن_, --, --,
   {{0x6d4a0090,0xdb042f07,0x3ea60421,0x7cca013b}},	//   _uffa, _anió, _isot_, lərm,
   {{0x2d9e018d,0x4e1700a5,0x3a3aa96a,0x00000000}},	//   mete_, _רחוב_, _dipp_, --,
   {{0x2d9e09b3,0x7bdf028b,0x65655efb,0x6fdc000d}},	//   lete_, _ulqu, wahh, _méco,
   {{0xb8c81556,0x473500d8,0x2498a96b,0x25aa0207}},	// [c3b0] _खै_, тнас, _aprm_, _babl_,
   {{0x63a9a96c,0x26c70254,0x395401c0,0x7cca0095}},	//   _saen, ćno_, časí_, yərl,
   {{0xf1bf0028,0x63a9a96d,0xe1f100d1,0x25aa395c}},	//   _đá_, _paen, یست_, _dabl_,
   {{0xe8d601f3,0x6fd50473,0x2d9ea96e,0xa856011d}},	//   _יותר_, _táci, hete_, _שירה_,
   {{0x63a9007c,0x2eca00b4,0xa2c100a1,0xa3b60066}},	//   _vaen, िहोत, लमध्, जाज_,
   {{0x2d9e1554,0x4b3802b5,0x63a9a96f,0xf99402b5}},	//   jete_, ׂראל_, _waen, ָרק_,
   {{0x2d9e15d8,0x63a9a970,0x628ba971,0x3ea6010d}},	//   dete_, _taen, stgo, _asot_,
   {{0x6fdc1010,0x7e69007c,0x63bba972,0x00000000}},	//   _déco, tsep, _unun, --,
   {{0x6fdc0aca,0x2d9ea973,0x80a10066,0xdee51dd6}},	//   _técn, fete_, _कैरे, топи,
   {{0x7e69a974,0x6fd500ac,0x6fdc000d,0x3f860395}},	//   rsep, _nácv, _féco, _ecou_,
   {{0x3ea60029,0x2d8b0067,0x00000000,0x00000000}},	//   _esot_, ęce_, --, --,
   {{0xe73f01a5,0x3a3a453a,0x3167a975,0x442f0159}},	//   _ngõ_, _sipp_, lanz_, nmg_,
   {{0x2d9ea976,0x442f0176,0x00000000,0x00000000}},	//   bete_, img_, --, --,
   {{0x2d9e0076,0x2fcf0211,0x3167033b,0x00000000}},	//   cete_, _hogg_, nanz_, --,
   {{0x98b80029,0xfce50423,0x25aa0009,0xdca500af}},	//   mbrī_, _шоко, _rabl_, _райи,
   {{0x2fcf0523,0xddc2093f,0x00000000,0x00000000}},	//   _jogg_, _ivoš, --, --,
   {{0xa3d50311,0x3a3aa977,0x8ca90567,0x366701d3}},	// [c3c0] ाउन_, _tipp_, टिको, като_,
   {{0x67fb03ad,0x680500d8,0xdb0600b5,0x2fcf02ce}},	//   täjä, rėda, ndkí, _logg_,
   {{0xb4be018d,0x80a10461,0xdb04009e,0x00000000}},	//   ेहे_, _कैले, _gniò, --,
   {{0xdb04a978,0x69dc36a2,0x6fdca979,0x213e009e}},	//   _unió, lkre, _réco, _sgth_,
   {{0x6fdc02e1,0x2d9ea97a,0x69dc75d0,0x25aaa97b}},	//   _décl, yete_, okre, _tabl_,
   {{0x442f0176,0x6fd50952,0xa13c0228,0x316702b1}},	//   amg_, _mácu, _kaķi, ganz_,
   {{0x75e0027d,0x2ca700e2,0x00000000,0x00000000}},	//   _göza, _nsnd_, --, --,
   {{0x2d9ea97c,0x08770070,0x2d87a97d,0x2fcf026e}},	//   wete_, דעקט_, _acne_, _cogg_,
   {{0x7d1d0095,0x69dca97e,0x31670027,0x00000000}},	//   əssi, kkre, banz_, --,
   {{0xf77f027d,0x69dc00ee,0xf8d2175f,0x7ddf021d}},	//   _ilçe_, jkre, सहाय, _pêsa,
   {{0xdfd2014a,0x69dca97f,0x06d60033,0x00000000}},	//   _پيش_, dkre, _সেমি, --,
   {{0x40ab0332,0xdfcf0286,0xdb040042,0x69dc0223}},	//   _زخمی_, _ويل_, _aniñ, ekre,
   {{0xdd94061c,0x6ab600e9,0x6b96008c,0x929d0067}},	//   _балы, _cryf, _dbyg, _były,
   {{0xc33300a5,0x6ab61cbf,0x00000000,0x00000000}},	//   יור_, _dryf, --, --,
   {{0xd83b00d8,0x6d5a0031,0x7c861218,0x644a01ef}},	//   дэа_, mbta, _руле, ífil,
   {{0x2bc4022e,0x6d5a00c7,0x5fc50099,0xdce10228}},	//   षाणा, lbta, वायल, zglī,
   {{0x6fdc00f7,0x6ab6101b,0x02be0067,0x00000000}},	// [c3d0] _récl, _gryf, ्होन, --,
   {{0x69dca980,0x56940c06,0xa3e50066,0x00000000}},	//   ckre, рафт, _फतह_, --,
   {{0x3167742d,0xdb1d007c,0x61f8011c,0x601e01f4}},	//   vanz_, rksõ, divl, rëmj,
   {{0x24581c8a,0x7bdd1eb8,0x2fc001da,0x00000000}},	//   таць_, nksu, _òigh_, --,
   {{0xe3b000d1,0x81ac0033,0x3167a981,0x00000000}},	//   ترل_, গান_, tanz_, --,
   {{0x6fd52de1,0x2fcf0036,0x2089262e,0xbbd00099}},	//   _láct, _sogg_, ейки_, _हक्क,
   {{0x2edb000c,0x316768b6,0x26100099,0x51843821}},	//   यन्त, ranz_, तकरी_, руча,
   {{0xfe7900b8,0xa3ab0035,0x61f803bc,0x7bdd0051}},	//   trů_, _कोच_, aivl, jksu,
   {{0xee390133,0x0ccb012f,0x327900fd,0x816b0200}},	//   нни_, ाह्म, _سماج_, _жреб_,
   {{0x2b9e00e2,0x41b7073f,0x3c3b005f,0xd1bb04cd}},	//   _ắc_, _आफिस, _būvo_, _تارا_,
   {{0x905500d8,0xd0840421,0x00000000,0x00000000}},	//   _свец, _вычи, --, --,
   {{0xb5fb00d5,0x50da016b,0x6d5a0312,0x00000000}},	//   _kvás, _אקעא, abta, --,
   {{0x69dc0408,0xf412016b,0x00000000,0x00000000}},	//   tkre, מפט_, --, --,
   {{0x6fd50183,0x7bdd0345,0x00000000,0x00000000}},	//   _vácu, aksu, --, --,
   {{0x69dca982,0x27e20a4e,0xdd8e00d1,0x6fd50138}},	//   rkre, _plkn_, _روي_, _fáct,
   {{0x69dca983,0x61f80124,0xad1a1804,0xb6a602c4}},	//   skre, zivl, _אוצר, либл,
   {{0x2d850210,0x857a05f2,0x25a1033b,0x00000000}},	// [c3e0] ogle_, есет_, fehl_, --,
   {{0x2d850122,0x80b30324,0x29040095,0xe9a60274}},	//   ngle_, ंटाइ, şmaq_, _саоп,
   {{0xdcea02c4,0x7e7b0207,0xf1c706fe,0x629b29d6}},	//   ćiće, hrup, लानन, _apuo,
   {{0xb5fb00b8,0xa4f40099,0x130a0aeb,0x660a0207}},	//   _svát, _आधीच_, нней_, _šokč,
   {{0x9f4400da,0x61f8a984,0x00000000,0x00000000}},	//   shmë_, tivl, --, --,
   {{0x15434697,0xf12601e0,0xd9f6073f,0x3eba00d5}},	//   _герм, льйо, ुचित_, _čpt_,
   {{0xa50a002d,0x7e7b0051,0x64430098,0x201f0384}},	//   _чева_, erup, ínit, flui_,
   {{0x7646018e,0x4fd41b0a,0x00000000,0x00000000}},	//   _kuky, ржит, --, --,
   {{0x7e7b0e45,0x63a2248e,0x7306a985,0x7cca00a8}},	//   grup, meon, _спаз, məri,
   {{0x7cca0250,0x211a004f,0x27130019,0xa2c100b4}},	//   ləri, _كتاب_, ệng_, लमर्,
   {{0xdd97004b,0xdb040093,0x4c94206f,0x7c6602e7}},	//   ушы_, _snið, шинс, داخل,
   {{0x201f0279,0x7dd60139,0x00000000,0x00000000}},	//   clui_, _râsu, --, --,
   {{0x7bdd09bd,0x7dd60160,0x2c4c007e,0x76460103}},	//   rksu, _bâst, _děda_, _nuky,
   {{0x7cca0095,0x63a20098,0xcee900fd,0x7dd60139}},	//   həri, heon, _جرمن_, _câst,
   {{0xba050302,0x6fd50b4c,0x6d47011c,0x63a20298}},	//   _रदीफ_, _táct, žjac, keon,
   {{0x61d1060a,0x0ea80035,0xb8860279,0x69c8a986}},	//   _तक्ष, _कनाड, _suíç, öder,
   {{0x311b00c0,0x7c2d3ed7,0x6fc50099,0x7cca00a8}},	// [c3f0] _पुनः_, _ihar, वातं, dəri,
   {{0x7c2d45bd,0x00000000,0x00000000,0x00000000}},	//   _hhar, --, --, --,
   {{0x7c2d662d,0x06d60083,0x7cca0095,0xd3710037}},	//   _khar, _সেদি, fəri, قها_,
   {{0x439522bb,0x63a2a987,0x7646a988,0x7c2d60cb}},	//   радс, geon, _fuky, _jhar,
   {{0x7c2da989,0x27e9009c,0x75e0006c,0x98b10644}},	//   _mhar, mhan_, _közl, mazı_,
   {{0x27e939cf,0x867a00a5,0x2be213a0,0xf67a0317}},	//   lhan_, _ברשו, _पत्थ, _באשמ,
   {{0x7c2d1605,0xc0e503fe,0x657500d7,0x7cca0095}},	//   _ohar, ройк, _idzh, bəri,
   {{0x27e9a98a,0x201f002d,0x645501a3,0x1e95021d}},	//   nhan_, ului_, _itzi, арор,
   {{0x442d0371,0x6fdc00f7,0x6447002f,0xdce100ea}},	//   _ihe_, _méch, _huji, dalā,
   {{0x644719c6,0x5bde2874,0x7c2da98b,0x201f002d}},	//   _kuji, मस्व, _ahar, slui_,
   {{0x7c2d4b53,0x443fa98c,0x1d090d28,0x442da98d}},	//   _bhar, _kiu_, тени_, _khe_,
   {{0x7c2d0e24,0x7f840118,0x6447000e,0x6d5c05ee}},	//   _char, _هلمن, _muji, ðrar,
   {{0xed4e6e2d,0x27e9a98e,0x7c2da98f,0xfc490019}},	//   _мо_, dhan_, _dhar, _bậc_,
   {{0x442d0370,0x2fcd0254,0xbd880098,0x7cca00a8}},	//   _lhe_, ljeg_, _منهن_, zəri,
   {{0x7a2001ae,0x7c2d09bb,0x67e3007c,0x63a2002f}},	//   nöti, _fhar, _sõja, yeon,
   {{0x27e9a990,0x443fa991,0x7c2da992,0x290c0484}},	//   ghan_, _niu_, _ghar, ħda_,

   {{0x05660091,0x63a201a2,0x6fdc0248,0x6455a993}},	// [c400] иван, veon, _déch, _atzi,
   {{0x75e00dac,0x443f0211,0x442d0027,0x27e9a994}},	//   _gözl, _aiu_, _ahe_, ahan_,
   {{0xb97b0122,0x27e901a6,0x442da995,0x766301c0}},	//   _בניי, bhan_, _bhe_, _čtyř,
   {{0x442da996,0x27e9a997,0x443f12c3,0x6447a998}},	//   _che_, chan_, _ciu_, _duji,
   {{0x442d5428,0x443f12c3,0x63a2a999,0x31c601d3}},	//   _dhe_, _diu_, reon, искв,
   {{0x63a2a99a,0xc5690332,0x442da99b,0x5ab70070}},	//   seon, _محفل_, _ehe_, ילנע_,
   {{0x443fa99c,0x442d00f1,0xb5fb300b,0x7e6201ef}},	//   _fiu_, _fhe_, _tvár, _swop,
   {{0x27e00d36,0x06cd00c8,0x443f02fb,0x7e6202e9}},	//   nkin_, _রেটি, _giu_, _pwop,
   {{0x41aa1a1c,0x27e0a99d,0x64470124,0x00000000}},	//   _иван_, ikin_, _zuji, --,
   {{0x7c2da99e,0x80a1018d,0x6440a99f,0x2d8a01d6}},	//   _shar, _कैके, _himi, übe_,
   {{0x27e0a7de,0xa5b702b5,0x7c2da9a0,0x270208a9}},	//   kkin_, בליק_, _phar, लपुर_,
   {{0x75e0036a,0x6440a9a1,0xcfd00083,0x7e620359}},	//   _sözl, _jimi, ়োজন, _twop,
   {{0x6440a9a2,0x27e9012f,0x6fdc178d,0x6d5c0225}},	//   _mimi, vhan_, _réch, ırab,
   {{0x27e006a2,0x27e902b3,0x6fdc00f7,0x7c2da9a3}},	//   ekin_, whan_, _séch, _whar,
   {{0x27e9a9a4,0x6c840082,0x7c2da9a5,0x98480021}},	//   than_, _العم, _thar, ията_,
   {{0x6440a9a6,0x7c2da9a7,0x27e0067f,0xf7730037}},	//   _nimi, _uhar, gkin_, غاز_,
   {{0x443fa9a8,0x442d006d,0x27e9a9a9,0x06cd0033}},	// [c410] _riu_, _rhe_, rhan_, _রেজি,
   {{0x442d0052,0x6fdca9aa,0x27e9a9ab,0x6440a9ac}},	//   _she_, _déci, shan_, _aimi,
   {{0xf8b101ca,0x27e9a02c,0x443f01d3,0xfa340037}},	//   _عکس_, phan_, _piu_, _بريد,
   {{0x27e0a9ad,0x6447a9ae,0x98a10028,0x6440a9af}},	//   ckin_, _vuji, _nghĩ_, _cimi,
   {{0x443f1561,0xe299002d,0x479a0122,0x00000000}},	//   _viu_, уал_, _גירס, --,
   {{0x6447a9b0,0x442d16df,0x764d0095,0x6aad0054}},	//   _tuji, _whe_, mqay, _msaf,
   {{0x442da9b1,0x645501d7,0x00000000,0x00000000}},	//   _the_, _utzi, --, --,
   {{0x6440a9b2,0x91780023,0x6f040a16,0x442d0027}},	//   _gimi, _với_, _žica, _uhe_,
   {{0x3eb9a9b3,0x6d430159,0xfe710037,0x764d0be2}},	//   íst_, _pgna, أدب_, nqay,
   {{0x27e00291,0x3f770019,0xdddb4bef,0x6440a9b4}},	//   zkin_, ểu_, stuž, _zimi,
   {{0x6440251e,0x6aad2899,0x6441a9b5,0x27e01363}},	//   _yimi, _asaf, _élis, ykin_,
   {{0x05c9021a,0x00000000,0x00000000,0x00000000}},	//   राडब, --, --, --,
   {{0xf1db0302,0x6d430159,0xdfb828c0,0xddc9080a}},	//   _भवान, _tgna, _خالص_, mrež,
   {{0x6d4300a7,0x6fdc0248,0x5fc50026,0x6d5c04d4}},	//   _ugna, _réci, वावल, ırac,
   {{0x27e00086,0xc8b51397,0xdce3004b,0x00000000}},	//   tkin_, осты, _kenč, --,
   {{0x27e0a9b6,0x30da0070,0xf77f0176,0xdce3a9b7}},	//   ukin_, אַמע, _plça_, _jenč,
   {{0x27e00ede,0x7bc4067f,0x6440a9b8,0x915e00cc}},	// [c420] rkin_, _iniu, _rimi, _lắm_,
   {{0x64404912,0xc9aa265e,0xdce3023a,0x00000000}},	//   _simi, _свое_, _lenč, --,
   {{0xc7a60dc8,0x6440a9b9,0x7bd6027d,0x387e00f4}},	//   _линк, _pimi, _koyu, štrb_,
   {{0x64400069,0xdb040183,0x201d0027,0x6fdc021d}},	//   _qimi, _caiç, _nkwi_, _téci,
   {{0x9f91008a,0x6440a9ba,0xe29603e6,0x8c1b011d}},	//   _ráð_, _vimi, среќ, נוני,
   {{0xd46a0041,0xdb04021d,0x64400371,0x00000000}},	//   _محرم_, _uniõ, _wimi, --,
   {{0xdce307e7,0x64401116,0x00000000,0x00000000}},	//   _benč, _timi, --, --,
   {{0xa8570122,0x61ea01a2,0x64400fa7,0x00000000}},	//   זיקה_, shfl, _uimi, --,
   {{0x43750279,0x00000000,0x00000000,0x00000000}},	//   _фуст, --, --, --,
   {{0x6b8da9bb,0x9f440453,0x2d9900b5,0x644100a2}},	//   _scag, timó_, ősen_, _élir,
   {{0x7bd606d3,0xddc900a0,0x25f008a9,0x459b0070}},	//   _boyu, brež, _इतनी_, נסטע,
   {{0x7bd619f3,0x80a10066,0xac191cba,0x0ed800b5}},	//   _coyu, _कैटे, рому_, _پاؤں_,
   {{0x80b80026,0xa3d014eb,0x7bd60448,0x00000000}},	//   ्मवे, _वचन_, _doyu, --,
   {{0x2d570086,0x00000000,0x00000000,0x00000000}},	//   _лишь_, --, --, --,
   {{0xfc490019,0x25b10009,0x06d60033,0x2c4500ec}},	//   _hận_, _razl_, _সেলি, _bēdu_,
   {{0x6aad012f,0xdc553c96,0x7bc4005f,0x00000000}},	//   _tsaf, _بروک, _gniu, --,
   {{0x6aad000e,0x34e1000c,0x9f460051,0x00000000}},	// [c430] _usaf, पन्द, _aloë_, --,
   {{0x99672a34,0xddc9063b,0xfc4900e2,0x00000000}},	//   _утил, zrež, _mận_, --,
   {{0xfc490023,0x67d500af,0x69c5a9bc,0x22580116}},	//   _lận_, _дону, _inhe, _črka_,
   {{0x7cca0095,0x69d701ef,0x78fa00a5,0x61fa179b}},	//   lərs, _hoxe, _כפתו, _amtl,
   {{0x3abc0070,0xdce3210c,0x00000000,0x00000000}},	//   ָמונ, _renč, --, --,
   {{0xd4e770e1,0x518703ad,0x95cb1056,0x69d701a3}},	//   _люби, суда, _сума_, _joxe,
   {{0x69d701ef,0x70520aaa,0x00000000,0x00000000}},	//   _moxe, ونوا, --, --,
   {{0xfc490019,0xb0680037,0x40320370,0x69d701f7}},	//   _bận_, حصول_, мејс, _loxe,
   {{0xdce3042a,0xfc490019,0x600600d8,0x69c50b0d}},	//   _venč, _cận_, ўным_, _onhe,
   {{0x7bd604d4,0x69d72658,0x00000000,0x00000000}},	//   _soyu, _noxe, --, --,
   {{0xddc90936,0x2cae0097,0x00000000,0x00000000}},	//   prež, _csfd_, --, --,
   {{0x7bd60095,0x69c52665,0xa3e907df,0xeaba083e}},	//   _qoyu, _anhe, यसि_, айм_,
   {{0x81ac0083,0x2b170722,0x69d7a9bd,0xbe6900af}},	//   গার_, _धुआँ_, _boxe, _талж_,
   {{0xfce51493,0xed591169,0x69d7002a,0x6fdc00a2}},	//   _моло, _ток_, _coxe, _décu,
   {{0xd9431334,0x186a2701,0x02a60d55,0x7bd6013b}},	//   дери, раби_, _गन्न, _toyu,
   {{0x7bc4a9be,0xb8d206bc,0x3ea90187,0x69c502ce}},	//   _uniu, _टन_, _šaty_, _enhe,
   {{0x69d71d35,0x2fc00037,0x00000000,0x00000000}},	// [c440] _foxe, _óige_, --, --,
   {{0x6fdc0d2e,0x7c26a9bf,0x75e000b5,0x7a2000fd}},	//   _héct, llkr, _közi, gött,
   {{0xdd7a00c2,0xfecf0033,0xf746019e,0xf34a002d}},	//   שטעל, িনিধ, _мено, апел_,
   {{0x0326a9c0,0x741301cb,0xdc8c016b,0x00000000}},	//   оден, وولا, רװאָ, --,
   {{0xdc3702b5,0x7791042c,0x81b30831,0x00000000}},	//   קאנט_, _سیلا, টান_, --,
   {{0x6f0400cd,0x644100e0,0x7c2602b1,0x91e30421}},	//   _žico, _èlin, hlkr, моче,
   {{0x7cca00a8,0xc0ca00af,0x00000000,0x00000000}},	//   hərr, руле_, --, --,
   {{0x6fdc1d2b,0x645e00c3,0x30170037,0x00000000}},	//   _néct, mppi, يتية_, --,
   {{0x4426001e,0x3eaf0023,0x3ebd099e,0x00000000}},	//   mlo_, _csgt_, _crwt_, --,
   {{0x442609e8,0xfc4901a5,0x6fdc0248,0x645e00c3}},	//   llo_, _vận_, _récu, oppi,
   {{0x6fdca9c1,0x4426a9c2,0x69d78cf4,0xa3ae00a1}},	//   _sécu, olo_, _roxe, _कसा_,
   {{0x4426a9c3,0xfc4901a5,0x7a2000b5,0x645e35a1}},	//   nlo_, _tận_, zött, ippi,
   {{0x4426a9c4,0x62820afc,0x2fc60159,0x7cca013b}},	//   ilo_, nroo, _inog_, tərs,
   {{0x44260e6a,0x9e6500bf,0x321c0187,0x6fdc000d}},	//   hlo_, _راهن, novy_, _vécu,
   {{0x62820223,0xdcf80225,0x7cca013b,0x9f4600f6}},	//   hroo, _tavı, rərs, _aloé_,
   {{0x44262b5b,0x7df900b8,0xa6d60033,0x321c00d5}},	//   jlo_, yňsk, _সেইট, hovy_,
   {{0x4426a9c5,0xdce30029,0x321c0097,0x2d8c2193}},	// [c450] dlo_, _ienā, kovy_, ogde_,
   {{0x44263dfe,0x2d8c2172,0x69c5345d,0x62820191}},	//   elo_, ngde_, _unhe, droo,
   {{0x2fc603fd,0x321c024e,0x6282a3b5,0x00000000}},	//   _onog_, dovy_, eroo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1dbc00b4,0xa7560122,0x62822b09,0x59df2e64}},	//   ्ञात, _משרד_, groo, _नकार,
   {{0x4426a9c6,0x2166a9c7,0xd24e0088,0xe1f8010b}},	//   alo_, пиши_, دنو_, огі_,
   {{0x442600de,0x6282011e,0xdb0a0187,0xd244002d}},	//   blo_, aroo, čném, фэци,
   {{0xb4d7009a,0x62823eed,0x4acb112b,0x2d8c12ba}},	//   िही_, broo, ामाव, egde_,
   {{0x6d5c0457,0x00000000,0x00000000,0x00000000}},	//   ıran, --, --, --,
   {{0x271a0019,0x4c852c0f,0x236d2cdc,0x2d8c01ff}},	//   ỏng_, плов, _heej_, ggde_,
   {{0x236d0221,0xeaf60387,0x29040448,0x00000000}},	//   _keej_, ीप्त_, şmaz_, --,
   {{0xfaa601c8,0xeb9a2698,0x2d8c2193,0xdce300ea}},	//   памо, щим_, agde_, _cenā,
   {{0x236d0189,0x67ea008a,0x2b495f4a,0x00000000}},	//   _meej_, _nýja, _dgac_, --,
   {{0xceb2168d,0x236d0d4b,0x4426a9c8,0x645e00c3}},	//   _ניו_, _leej_, zlo_, yppi,
   {{0x4426a9c9,0xdca22294,0x75e0006c,0x7cca0095}},	//   ylo_, _защи, _közv, sərr,
   {{0x236d01a9,0x62820269,0xdb041be9,0x68430ce3}},	//   _neej_, yroo, _maiú, енса,
   {{0x3a21012f,0x44263f84,0xe7379dbd,0x2c0b01df}},	// [c460] _fkhp_, vlo_, зет_, _دعوی_,
   {{0x4426a9ca,0x20bd0b35,0x2245009e,0x8afb00a5}},	//   wlo_, ्माध, _nilk_, _להפי,
   {{0x4426a9cb,0x89db035e,0x8cbe0066,0xdb0600b5}},	//   tlo_, _החיי, षियो, deké,
   {{0x6282a9cc,0x4426018e,0xc3150033,0xd4690037}},	//   troo, ulo_, ়েছি_, تحكم_,
   {{0x442610e9,0xd36f0a42,0x321c1dab,0x224d012f}},	//   rlo_, اهه_, tovy_, _cuek_,
   {{0x98b808d2,0x44264caa,0x62821eb8,0x244a1ee1}},	//   ları_, slo_, rroo, _هجري_,
   {{0x64a340b4,0xd12f00bc,0x321c0097,0x6282a9cd}},	//   _пара, همه_, rovy_, sroo,
   {{0x644e0043,0x6282a9ce,0x645c0036,0x6aa40036}},	//   _iubi, proo, _itri, _opif,
   {{0x644e0033,0x656e012f,0x63a000e0,0xdce30228}},	//   _hubi, _kebh, _ibmn, _renā,
   {{0x644ea9cf,0x236d0221,0x2d8c11ad,0xdce30228}},	//   _kubi, _zeej_, ugde_, _senā,
   {{0x236d0d4b,0x6fdc0248,0x98b801d6,0x515b0d85}},	//   _yeej_, _décr, karı_, _הכבו,
   {{0x644e0198,0x661e00cd,0x2d820225,0x656e5999}},	//   _mubi, hopk, şke_, _lebh,
   {{0x644ea9d0,0xdfcf0c74,0x98b8045e,0x67260a8a}},	//   _lubi, _حين_, darı_, _nykj,
   {{0x645ca9d1,0x19581023,0x644e6251,0xddc200fe}},	//   _otri, зары_, _oubi, _hvož,
   {{0xda6713cf,0x645c0024,0x59f8186f,0x00000000}},	//   _کابي, _ntri, черя_, --,
   {{0x25bf0160,0x98b8242d,0xfc15010b,0x00000000}},	//   _şul_, garı_, _імпэ, --,
   {{0x35b50d54,0x95d915df,0x644e614c,0x4b7c00a5}},	// [c470] мбар, одат_, _aubi, _האחו,
   {{0x644e0b69,0x996702ee,0x236d0221,0x3c3200a0}},	//   _bubi, _этил, _seej_, ráve_,
   {{0x644ea9d2,0x236d01e8,0x98b8027b,0x224d01ed}},	//   _cubi, _peej_, barı_, _suek_,
   {{0x644ea9d3,0x236d01e8,0x645c0079,0x224508ee}},	//   _dubi, _qeej_, _dtri, _silk_,
   {{0xae0c1f57,0x92391f7c,0xfc4900e2,0x22450d98}},	//   िचान_, очку_, _rậm_, _pilk_,
   {{0x765d0036,0xed4600d1,0xcb14016b,0x69d000b4}},	//   _itsy, _لپ_, עלס_, दायी,
   {{0x644e0a78,0x236d0221,0x6d47011c,0xf4840274}},	//   _gubi, _teej_, žjak, _путн,
   {{0x7ff500d1,0x6d5802e6,0x6fdca9d4,0x764f05a8}},	//   بستا, _afva, _bécq, _kucy,
   {{0x644e54ae,0x764701d5,0xdce802d4,0xddc202a7}},	//   _zubi, _kijy, vadā, _dvož,
   {{0x63aba9d5,0x644e0095,0x628ba9d6,0x98b8037a}},	//   legn, _yubi, mugo, zarı_,
   {{0x644802e1,0x644e01dd,0x628ba9d7,0x98b800c1}},	//   _édit, _xubi, lugo, yarı_,
   {{0x273400fb,0xddc20b16,0x6d580176,0x98b800a8}},	//   _júní_, _gvož, _efva, xarı_,
   {{0x0f560052,0x628b0c86,0x75e0006c,0xdce800ea}},	//   _חינם_, nugo, _közt, radā,
   {{0x63ab008c,0x7647007b,0xbea267d7,0x00000000}},	//   hegn, _nijy, _рашк, --,
   {{0xaa432682,0x628b1292,0x98b80448,0x62990051}},	//   терл, hugo, tarı_, htwo,
   {{0x5d4402b5,0x764f0848,0x62990359,0x628b3a3c}},	//   _אָפּ_, _bucy, ktwo, kugo,
   {{0x644e8a4c,0xcf9200c2,0x776401ed,0x386d044d}},	// [c480] _subi, כטן_, rbix, ćera_,
   {{0xf98a00f8,0x98b800a3,0x200d0160,0x628ba9d8}},	//   _بندي_, sarı_, hnei_, dugo,
   {{0xb4e80d2a,0x661e00a0,0x76470260,0xec1305f5}},	//   यने_, ropk, _dijy, _سوید,
   {{0x656e00ac,0x63ab4c5a,0x62992b28,0xd90d006c}},	//   _webh, gegn, ftwo, _ایف_,
   {{0x656e006d,0x6684042c,0xf77300a5,0x628b24a8}},	//   _tebh, _سیال, _בקר_, gugo,
   {{0x644ea9d9,0x200da9da,0x645c03d0,0x00000000}},	//   _tubi, enei_, _ttri, --,
   {{0x645ca9db,0x63ab1a2e,0x7c2499b8,0x92ce0033}},	//   _utri, begn, _okir, শনে_,
   {{0xdfd00082,0xd7d100a1,0x764701d5,0x7c24251e}},	//   اية_, हायच, _zijy, _nkir,
   {{0x25b801ae,0x8d862e14,0xf65f0b3e,0x76470371}},	//   _karl_, мунд, _græd_, _yijy,
   {{0x7c2461f9,0x200d00af,0x25b803c1,0x26c20207}},	//   _akir, anei_, _jarl_, _mrko_,
   {{0x6e28034d,0xdce30160,0x64480118,0x00000000}},	//   rldb, _renă, _édis, --,
   {{0x44242bd6,0xa2c20bdd,0x7c3600e9,0x75e000b5}},	//   _jkm_, लिप्, _chyr, _közs,
   {{0x2004a9dc,0x6b9da9dd,0x442400b9,0x6e930037}},	//   mimi_, rfsg, _mkm_, _للنا,
   {{0x2004a9de,0x6abd0b3e,0x7c2409d6,0xdb160260}},	//   limi_, rvsf, _ekir, _mayè,
   {{0x26c2026f,0xa3ae00a1,0xdb160107,0x7647007b}},	//   _arko_, _कसं_, _layè, _rijy,
   {{0x2004a9df,0x2d9e22f7,0x27f2099e,0x23660009}},	//   nimi_, lfte_, ghyn_, jboj_,
   {{0x98af0d6f,0x63aba9e0,0x26c20124,0x00000000}},	// [c490] ınız_, vegn, _crko_, --,
   {{0x200401f4,0xa2c223db,0x6eb10066,0x38cb00af}},	//   himi_, लिन्, _अनसु, _думн_,
   {{0x63aba9e1,0x2004a9e2,0x2bc402e4,0x81c60033}},	//   tegn, kimi_, षाचा, ৎসা_,
   {{0x2004a9e3,0x629901ae,0x628ba9e4,0xb5fba9e5}},	//   jimi_, ttwo, tugo, _stád,
   {{0x27e90f1a,0x63ab177c,0x2004a9e6,0xe9450e3a}},	//   mkan_, regn, dimi_, _ترکی,
   {{0x27e9120d,0x63aba9e7,0x628b01d5,0x9f98008a}},	//   lkan_, segn, rugo, _séð_,
   {{0x659403d0,0x545414a1,0x63ab01d3,0x628b7e30}},	//   _шару, _авст, pegn, sugo,
   {{0x27e91201,0x66050464,0x2004a9e8,0xdddb201d}},	//   nkan_, lihk, gimi_, druš,
   {{0x27e9a9e9,0x200d0ced,0x52151645,0xdcea0107}},	//   ikan_, rnei_, _здат, _defč,
   {{0x27e9120d,0xee3615eb,0x6d4e044d,0x3c3201ba}},	//   hkan_, нны_, žban, dáva_,
   {{0x27e9a9ea,0x2004a9eb,0x7c240159,0x3ea60260}},	//   kkan_, bimi_, _pkir, _epot_,
   {{0xca2901f3,0x2004a9ec,0x660500d7,0x645a000d}},	//   _הם_, cimi_, hihk, _étie,
   {{0x27e95443,0x00000000,0x00000000,0x00000000}},	//   dkan_, --, --, --,
   {{0x67e3007c,0xdddb3c56,0x23660009,0xa3c10067}},	//   _mõju, bruš, zboj_, ्फ़त_,
   {{0x27e9a9ed,0xa3c10d1f,0x66050034,0x18a32b34}},	//   fkan_, ्ञा_, dihk, ларм,
   {{0x27e9a9ee,0x25b800f7,0x7c2469ca,0xfaff0031}},	//   gkan_, _sarl_, _ukir, mbën_,
   {{0xb4e80d55,0x70bd0066,0x00000000,0x00000000}},	// [c4a0] यन्_, ्मुल, --, --,
   {{0x20047f6a,0x27e9a177,0x6e21001e,0x66050a4e}},	//   zimi_, akan_, nolb, gihk,
   {{0x27e91201,0x4424104e,0x64490042,0x20047b85}},	//   bkan_, _pkm_, _biei, yimi_,
   {{0x27e906d7,0xe29a0ae6,0xd36f004f,0xd5c90f9c}},	//   ckan_, зад_, مهم_, राउज,
   {{0xd3231470,0x66050034,0x2004a9ef,0x2ca700e7}},	//   льши, bihk, vimi_, _lpnd_,
   {{0x69dea9f0,0x20040103,0xf48403fc,0x70bd1bc6}},	//   _jope, wimi_, _لاری, ्मूल,
   {{0x2004a9f1,0x69dea9f2,0x26c01ca9,0xe4da006c}},	//   timi_, _mope, lvio_, _عورت_,
   {{0x69dea9f3,0x44240ec0,0x1b1b0033,0x00000000}},	//   _lope, _ukm_, নেটে_, --,
   {{0x2004a9f4,0x26c03cba,0x69de00be,0x200a0207}},	//   rimi_, nvio_, _oope, đbi_,
   {{0xdd900041,0x2004a9f5,0x69dea9f6,0x463b0070}},	//   جود_, simi_, _nope, ּעטע,
   {{0x6f66725d,0x2d9ea9f7,0x27e90a21,0xc5f300a5}},	//   _звез, rfte_, ykan_, רדת_,
   {{0x69dea9f8,0x3c3200a0,0x785500c7,0x00000000}},	//   _aope, táva_, _sąvo, --,
   {{0x81b300c8,0x6e2108d4,0x69de00e9,0x2bb229ad}},	//   টার_, bolb, _bope, _जसरा,
   {{0x69dea9f9,0x3c3205d3,0x26c00207,0x00000000}},	//   _cope, ráva_, dvio_, --,
   {{0x27e9120d,0x2a600051,0x00000000,0x00000000}},	//   tkan_, _etib_, --, --,
   {{0xf77321a0,0x0828002d,0xb5fb0168,0x00000000}},	//   طار_, ецуи_, _otác, --,
   {{0x27e9120d,0xf6532e36,0x69de01a2,0x7d2100b5}},	// [c4b0] rkan_, ائر_, _fope, _مہین,
   {{0x27e91201,0x984ba9fa,0x6d5aa9fb,0x7bdf0310}},	//   skan_, _няма_, ncta, _hoqu,
   {{0x27e91201,0x225f0244,0xb5fb01ef,0x9c7c0187}},	//   pkan_, _stuk_, _atác, zyčn,
   {{0x660506b3,0x27e9012f,0x69de008b,0x987a0070}},	//   sihk, qkan_, _zope, _קארט,
   {{0x6449a9fc,0x7bdfa9fd,0x326703fa,0xdb16000d}},	//   _viei, _moqu, хтев, _payé,
   {{0x7bdf2c35,0x1e1a0067,0x814500b5,0x69de0176}},	//   _loqu, नकोष_, نچان, _xope,
   {{0x70bd210a,0xd3a73ce8,0x81b30033,0x70b20037}},	//   ्मेल, _прап, টাল_, لموض,
   {{0x442b0023,0x6d5a0160,0x7bdf0138,0x6d4e00cd}},	//   _óc_, ecta, _noqu, žbal,
   {{0xee390de3,0x2284898c,0x225f046a,0x75e0006c}},	//   мни_, _бухг, _utuk_, _közp,
   {{0x63bba9fe,0x645a08c0,0x657701f4,0x61eaa9ff}},	//   _haun, _étic, naxh, ckfl,
   {{0x63bbaa00,0xa8060092,0x69deaa01,0x3207aa02}},	//   _kaun, lmış, _rope, miny_,
   {{0x63bbaa03,0x32071b66,0x7bdfaa04,0xfaff0031}},	//   _jaun, liny_, _coqu, rbën_,
   {{0x63bbaa05,0xa80606d0,0x6ee400ff,0x64c5012e}},	//   _maun, nmış, _مسول, lčić,
   {{0x32074a8b,0x63bbaa06,0x26c0027a,0x7bcd6b23}},	//   niny_, _laun, vvio_, _enau,
   {{0x7d760312,0x64c50254,0x44c1010b,0x7bdf0176}},	//   _شمير_, nčić, _nė_, _foqu,
   {{0xb8da0fd1,0x63bb1fd9,0x78b7012f,0xa8060225}},	//   _आई_, _naun, _dsxv, kmış,
   {{0x32074a9c,0x7e7baa07,0x00000000,0x00000000}},	// [c4c0] kiny_, nsup, --, --,
   {{0x3207024e,0xe7372b5b,0x26c0aa08,0x64c500f4}},	//   jiny_, теу_, rvio_, kčić,
   {{0x32071840,0x63bbaa09,0x26c0072c,0x64c500cd}},	//   diny_, _baun, svio_, jčić,
   {{0x7bdf01f7,0x7e7b02e2,0x63bb00ec,0x44c1005f}},	//   _xoqu, ksup, _caun, _dė_,
   {{0x63bba75e,0x320707df,0x92b30079,0x00000000}},	//   _daun, finy_, لحوا, --,
   {{0xa3ae0775,0x00000000,0x00000000,0x00000000}},	//   _कसक_, --, --, --,
   {{0xc9530122,0xfc4a0028,0x00000000,0x00000000}},	//   סמה_, _hậu_, --, --,
   {{0x63bb00d8,0x00000000,0x00000000,0x00000000}},	//   _gaun, --, --, --,
   {{0x7bdf0d99,0x2bd60099,0x7e7b2487,0xfbd60761}},	//   _roqu, धाना, gsup, धानम,
   {{0x63a28440,0xe8020825,0x7bdf1e60,0xfc4a0023}},	//   lfon, रोता_, _soqu, _mậu_,
   {{0x7bdf865d,0x0cd00083,0x61462a7c,0x6acb0761}},	//   _poqu, ান্ত, _режа, ाम्र,
   {{0x4ea641d5,0x9f46021d,0x00000000,0x00000000}},	//   _арка, _eloá_, --, --,
   {{0x80c00992,0x7e7baa0a,0xfc3f0176,0x00000000}},	//   विवे, csup, rmí_, --,
   {{0x7a3201b4,0xfc3f00b8,0x7e620107,0x00000000}},	//   sætn, smí_, _itop, --,
   {{0xdb0401ef,0xa806045e,0x6fb8142a,0x3a3a021d}},	//   _baió, zmış, ्यपू, _dhpp_,
   {{0x7bcdaa0b,0x81d80083,0x0eb6046c,0x320705d1}},	//   _unau, াসি_, _अनाड, ziny_,
   {{0x63bbaa0c,0xfc4a01a5,0xe8020380,0xc987002d}},	// [c4d0] _raun, _cậu_, रोधा_, _иуни,
   {{0x7c2f14d8,0x35f410e3,0xfc4a00e2,0x63a201bf}},	//   llcr, апур, _dậu_, efon,
   {{0xb9080b52,0x32070076,0x63bbaa0d,0x63a2aa0e}},	//   _মে_, viny_, _paun, ffon,
   {{0x64c5029d,0xc43500fd,0x7e62aa0f,0xa8060644}},	//   včić, اکست, _otop, tmış,
   {{0x3207024e,0x2ba53010,0xfba50355,0x63bb0421}},	//   tiny_, ग्या, ग्यम, _vaun,
   {{0xa806045e,0x63bbaa10,0x6d4e00cd,0x40950a80}},	//   rmış, _waun, žbaj, грит,
   {{0x7e621a71,0x63bbaa11,0x32070e7d,0xa4d40185}},	//   _atop, _taun, riny_, _корі,
   {{0x81b30083,0x7e7baa12,0x32070fbf,0x64c5011c}},	//   টাই_, tsup, siny_, rčić,
   {{0xfc4a0028,0x32071840,0x6575012f,0xe31503fa}},	//   _mật_, piny_, _kezh, _смањ,
   {{0x645543d1,0x80c01cc3,0x2bd604bc,0xfc4a0023}},	//   _kuzi, विशे, धाभा, _lật_,
   {{0xeb9a135d,0xd1310a9b,0x7e7baa13,0x5f9515f4}},	//   нин_, _اما_, ssup, _ملائ,
   {{0x65750031,0x320500ee,0x3f79016b,0x7ff4103b}},	//   _lezh, _hmly_, _װאַס, _پسما,
   {{0x61e1aa14,0x6da5316d,0x6455aa15,0xada500c3}},	//   _koll, _била, _luzi, _балл,
   {{0x090500c8,0x61e103ad,0x657539c0,0x4e7a0070}},	//   _শুধু_, _joll, _nezh, _טאנצ,
   {{0x61e1aa16,0xfc4a01a5,0x6455aa17,0x2c460228}},	//   _moll, _bật_, _nuzi, _mēdz_,
   {{0xfd100088,0x6846081b,0x61e10d19,0x00000000}},	//   _بجه_, унба, _loll, --,
   {{0x7c26aa18,0x6455aa19,0x6575aa1a,0x6b840065}},	// [c4e0] mokr, _auzi, _bezh, _idig,
   {{0x61e13c69,0x64552696,0x442f0211,0xa2c20efa}},	//   _noll, _buzi, elg_, लिस्,
   {{0x65750024,0x399b02b5,0x35c90066,0x64556947}},	//   _dezh, _אייד, राज़, _cuzi,
   {{0x2486016f,0x64559031,0xfc4a00e2,0x25f00099}},	//   čom_, _duzi, _gật_, _इतकी_,
   {{0x0cb005f7,0xc69400c2,0x91e6a5fa,0x6455021d}},	//   _जन्म, _דאָ_, лоде, _euzi,
   {{0x61e128be,0x64554b34,0x2fcf7bad,0x7c260097}},	//   _coll, _fuzi, _angg_, hokr,
   {{0x6455aa1b,0xee0900c8,0x6b8410ec,0x61e1aa1c}},	//   _guzi, রকাশ_, _odig, _doll,
   {{0xd25200d1,0x6b84aa1d,0xc0340274,0x80d90033}},	//   _هنر_, _ndig, јниј, _ভেঙ্,
   {{0x61e1aa1e,0x3df418ea,0x44265e74,0x645535e2}},	//   _foll, изис, moo_, _zuzi,
   {{0x6b84aa1f,0x57e102cb,0x61e122a6,0x32460036}},	//   _adig, _नव्ह, _goll, _сезг,
   {{0xd00f0118,0xb5fb0070,0x7a3205ee,0x80664555}},	//   _کلن_, גליכ, rætl, _свеж,
   {{0x4426aa20,0xab6204d4,0x6442aa21,0x61e1aa22}},	//   noo_, şünd, nmoi, _zoll,
   {{0x61e10092,0x6b840297,0x80370070,0xdb0401a3}},	//   _yoll, _ddig, _ענדע_, _baiñ,
   {{0x4426055c,0x764e0010,0xe802007c,0x5a3400d4}},	//   hoo_, _niby, रोसा_, йнят,
   {{0x4426aa23,0xdcea0160,0x7c860fc5,0x27e203d0}},	//   koo_, _defă, _суле, _bokn_,
   {{0xb8dd006a,0x6455aa24,0xf65f0a8a,0xdb061534}},	//   _इन_, _ruzi, _dræn_, seká,
   {{0xfc4a0028,0x55750e0a,0x6455aa25,0x2ba500a1}},	// [c4f0] _vật_, игат, _suzi, ग्णा,
   {{0xdb0401b7,0x764e099e,0x60c81b99,0x6b840207}},	//   _gaiñ, _ciby, _ordm, _zdig,
   {{0x44b50043,0x38c90a86,0xfc4a0019,0x764eaa26}},	//   рбес, _شادی_, _tật_, _diby,
   {{0x61e1aa27,0x4426aa28,0x628b0169,0x9a6800b5}},	//   _soll, goo_, trgo, _جمیل_,
   {{0x877a0100,0xa2c20b35,0x61e1aa29,0x60c80098}},	//   _בארי, लिष्, _poll, _ardm,
   {{0x645544fa,0x14774a57,0x764e001c,0x6aad0027}},	//   _tuzi, _مارج, _giby, _mpaf,
   {{0x44263c2e,0x61e10c58,0x00000000,0x00000000}},	//   boo_, _voll, --, --,
   {{0x61e106d1,0xafe51988,0x1e853175,0xd7d80099}},	//   _woll, роил, алим, डायच,
   {{0x61e1aa2a,0x63a9aa2b,0x6fa1022e,0xa02402b1}},	//   _toll, _iben, क्षू, _stöß,
   {{0x67ea00b8,0xdb060225,0xa2c2018d,0xd1b80cd1}},	//   _výji, lekç, लिर्, _ماما_,
   {{0xee36002d,0xa281006c,0xdb04002a,0xa3bc0354}},	//   рнэ_, _ایڈو, _raiñ, _असम_,
   {{0x92d70083,0xf047010b,0x00000000,0x00000000}},	//   ানী_, _сэзо, --, --,
   {{0x63a900d1,0x2ba500b4,0x00000000,0x00000000}},	//   _mben, ग्धा, --, --,
   {{0xfe700833,0x4426aa2c,0xb5fbaa2d,0xed564ae8}},	//   _رده_, zoo_, _stán, _кош_,
   {{0x7c263d9c,0x63a9aa2e,0xd9462896,0x6aad0260}},	//   pokr, _oben, реви, _epaf,
   {{0x4426aa2f,0x764eaa30,0x644200a2,0x63a9aa31}},	//   xoo_, _siby, xmoi, _nben,
   {{0x4426aa32,0xa6650c74,0x00000000,0x00000000}},	// [c500] voo_, مطلو, --, --,
   {{0x63a9aa33,0x44262b08,0x764e028b,0xb8dc0033}},	//   _aben, woo_, _qiby, _আপ_,
   {{0xb5fbaa34,0x7e6900d7,0x63a9009f,0x62800176}},	//   _itál, hpep, _bben, _svmo,
   {{0xa87b02b5,0xb5fb006c,0x875502fb,0x764e0371}},	//   _באטר, _után, _гърц, _wiby,
   {{0x4426aa35,0x764e30bc,0xdce300b8,0x00000000}},	//   roo_, _tiby, _peně, --,
   {{0x4426aa36,0x63a902c9,0x80aa0083,0x645a000d}},	//   soo_, _eben, কিস্, _étio,
   {{0x442600c3,0x7e691a89,0xdb0f9106,0x40a8103b}},	//   poo_, epep, recé, اختی_,
   {{0x4fc63335,0x7afd90c1,0x67f802d7,0x6fa10066}},	//   рска, yzst, _fíje, क्लू,
   {{0x7e6908dd,0x386d0207,0x7e6d0457,0x00000000}},	//   gpep, ćeri_, _çapl, --,
   {{0x7f8600b5,0x63a90160,0x00000000,0x00000000}},	//   _چلان, _zben, --, --,
   {{0xf9fc0033,0x00000000,0x00000000,0x00000000}},	//   ঁচাল_, --, --, --,
   {{0x7afd033b,0x67f10a8a,0x00000000,0x00000000}},	//   tzst, _råjo, --, --,
   {{0x9ce60033,0x8fa300af,0xd00f0118,0xbea35e0c}},	//   খছেন_, _фаче, _غله_, _мацк,
   {{0x7afd0576,0xdb16021d,0x00000000,0x00000000}},	//   rzst, _sayã, --, --,
   {{0xfc640ef5,0xf8072901,0x9c7c010b,0x2018aa37}},	//   _اختی, ачан, kyči, _íris_,
   {{0xe8020026,0x69da66bd,0x59d500b8,0x3f860355}},	//   रोला_, öter, दाहर, _jdou_,
   {{0x7c2daa38,0x67ea008a,0x6284010b,0xf1c60099}},	// [c510] _ikar, _nýju, šioj, लयान,
   {{0x63a90088,0x00000000,0x00000000,0x00000000}},	//   _sben, --, --, --,
   {{0x090500c8,0x7c2d009f,0x00000000,0x00000000}},	//   _শুরু_, _kkar, --, --,
   {{0x97a702d6,0xdb1602d7,0x59d5143a,0xdcfa0a21}},	//   _трол, _hayá, दावर, netı,
   {{0x623503e6,0xfc4a0023,0xdb060225,0x7c2daa39}},	//   беду, _mập_, rekç, _mkar,
   {{0xfc4a0028,0xa4d52659,0x5ab8016b,0x00000000}},	//   _lập_, _логі, ילדע_, --,
   {{0x92d70b52,0xd00e00e0,0x601e0029,0x6e280009}},	//   ানে_, کلي_, zīme, dodb,
   {{0xc9180bed,0x43940086,0x63a90088,0x7c2daa3a}},	//   יחות_, _масс, _uben, _nkar,
   {{0x442d2b06,0x443faa3b,0xed591a55,0xfaff0031}},	//   _ike_, _ihu_, лоп_, jzë_,
   {{0x7c2daa3c,0x6e2802c6,0x7e6901a2,0x07920355}},	//   _akar, godb, rpep, _čímž_,
   {{0x443f0028,0x0c261f39,0x442d1b99,0xfc4a00cc}},	//   _khu_, ймон, _kke_, _bập_,
   {{0xfc4a00e8,0xb5fb05d3,0x443f0069,0x81b30033}},	//   _cập_, _stál, _jhu_, টাও_,
   {{0x442d000e,0x200d002d,0xeb9701d3,0xfc4a0023}},	//   _mke_, miei_, щия_, _dập_,
   {{0x7c2d06a2,0x200d8c27,0x237d0189,0x433a0070}},	//   _ekar, liei_, hawj_, טערב,
   {{0x442daa3d,0x7c95004f,0x6c850312,0xa3da0324}},	//   _oke_, _العص, _البم, ़ाम_,
   {{0x200d0012,0x443f01a5,0x442d01d5,0x2fdf0009}},	//   niei_, _nhu_, _nke_, njug_,
   {{0xed1607a8,0xe61a0d36,0xe7e90066,0x00000000}},	// [c520] _نہیں_, гда_, _टकरा_, --,
   {{0x442daa3e,0x443f9df8,0x0556010b,0xd6cf0037}},	//   _ake_, _ahu_, стая, عقل_,
   {{0x92d70083,0x442d00d7,0x395700a5,0x6d4e00cd}},	//   ানো_, _bke_, _לשים_, žbav,
   {{0x443faa3f,0x037a0b82,0x442daa40,0x645aaa41}},	//   _chu_, احات_, _cke_, _étim,
   {{0x21780aeb,0x200d1e86,0x1db7198f,0x00000000}},	//   айлы_, diei_, _असंत, --,
   {{0x442daa42,0x27e01d6d,0x443f01d7,0x3ea000c3}},	//   _eke_, ljin_, _ehu_, _äiti_,
   {{0x8459002d,0xdb1f0031,0x200d00af,0x00000000}},	//   _врут_, _paqë, fiei_, --,
   {{0x741603c7,0x5f9406c2,0x657e3e4c,0x200d8c27}},	//   _اورا, циит, laph, giei_,
   {{0x644003ad,0xfc4a00e2,0x2d870139,0x00000000}},	//   _ihmi, _rập_, _bdne_, --,
   {{0xf1a900bf,0x22f70122,0x628d042a,0x657e0023}},	//   _نامه_, _הזמן_, šaoc, naph,
   {{0xa3bc02cb,0x70560a86,0x62829283,0x11d70037}},	//   _असा_, _انصا, lsoo, _دولة_,
   {{0x27e0003c,0x200d0ebc,0x442d33c4,0x657e0044}},	//   jjin_, ciei_, _xke_, haph,
   {{0x6282987b,0x27e00260,0x6e28008b,0x78be0282}},	//   nsoo, djin_, podb, _aspv,
   {{0x998300b8,0x69d000b4,0x00000000,0x00000000}},	//   rojů_, दागी, --, --,
   {{0xfc4a00e8,0x16d14092,0x37ab15ae,0x6440081b}},	//   _tập_, सम्ब, лтан_, _ohmi,
   {{0x27e001f4,0x7c2daa43,0xbc6711c0,0x237d01e8}},	//   gjin_, _ukar, _امين_, xawj_,
   {{0x36d40ecb,0x44c80644,0x2bd60099,0x62820051}},	// [c530] потр, _ağ_, धारा, jsoo,
   {{0x2ba5046c,0x442daa44,0x9b9500bf,0x657e0088}},	//   ग्रा, _ske_, _الکت, gaph,
   {{0x2bdd0266,0xe7c4035d,0x443faa45,0x54b91482}},	//   यापा, _लोकप, _phu_, ргея_,
   {{0x628201bf,0x4374648d,0xdc9b076b,0xdb0f0183}},	//   fsoo, пушт, ריאל, mecâ,
   {{0x62821b1c,0x200d350b,0x386d0124,0x2bca00b8}},	//   gsoo, viei_, ćeru_, ियता,
   {{0x237d006d,0xa2ba0026,0x657e008c,0x27f90282}},	//   sawj_, _एनर्, caph, _hlsn_,
   {{0x443faa46,0x200d0043,0x61421fd8,0xdb0f0300}},	//   _thu_, tiei_, меша, decí,
   {{0x442d01e0,0x443f6ced,0x4fe90819,0xa295010b}},	//   _uke_, _uhu_, рмин_, _мабі,
   {{0x2bdd0d91,0x200d09f3,0x2a6901e8,0xfbdd0e61}},	//   याना, riei_, _ntab_, यानम,
   {{0x4c8538d0,0x200d002d,0xac8543f0,0x320e024b}},	//   олов, siei_, огол, cify_,
   {{0xab5baa47,0x200d58f7,0xf65f0a8a,0x2a69099e}},	//   rdün, piei_, _bræk_, _atab_,
   {{0x1b4a021d,0xeb9a1158,0x657e2a13,0x2ba500b8}},	//   изни_, шим_, zaph, ग्ला,
   {{0x2a69012f,0xce6b12e8,0x201d01d5,0x2b3a0012}},	//   _ctab_, _сред_, _ijwi_, рянэ_,
   {{0x0dcb0202,0xd7f10023,0xf77f0132,0x00000000}},	//   _људи_, ễn_, _roça_, --,
   {{0x2a6901d7,0x75e00225,0xf65f08c8,0x9c6500f8}},	//   _etab_, _gözy, _fræk_, _بهبو,
   {{0x6ecd00b8,0xf77f0183,0xab5baa48,0x00000000}},	//   तिपु, _poça_, ndül, --,
   {{0xe57a498a,0x7bd60232,0x060a03fa,0x6d4e012e}},	// [c540] иза_, _inyu, анак_, žbat,
   {{0x7bd601e8,0x67f800b5,0x27f2aa49,0x645a0118}},	//   _hnyu, _díja, skyn_, _étik,
   {{0x2eb64f02,0xd94612f3,0x78ad00b8,0xdddb0254}},	//   _अन्त, _фени, čová, kruž,
   {{0x2bdd09a8,0xd36f004f,0x6282aa4a,0x67f80453}},	//   याया, نهم_, tsoo, _fíja,
   {{0xdddb24d4,0x7bc4aa4b,0x2bac2095,0x657e0159}},	//   druž, _maiu, ट्या, paph,
   {{0x6282201e,0xdce30009,0x7bc400ab,0xfaff0031}},	//   rsoo, _lenđ, _laiu, mbët_,
   {{0x2bdd0c03,0x80bd00b8,0xfbca6ecd,0x6282aa4c}},	//   यामा, _वैदे, ियाम, ssoo,
   {{0x657caa4d,0xeeaaaa4e,0x7bc41292,0x7bd60273}},	//   _herh, аток_, _naiu, _nnyu,
   {{0xdefa3b8c,0xdde3002d,0x62820069,0x657ca0ee}},	//   рый_, ârşi, qsoo, _kerh,
   {{0x645caa4f,0x50d61d05,0x7bd6aa50,0x7bc401ed}},	//   _kuri, _وزار, _anyu, _aaiu,
   {{0x26c90a78,0xdb0f0f56,0x657c01d6,0x645caa51}},	//   zvao_, recí, _merh, _juri,
   {{0x645caa52,0x7bc466a7,0x5c07010b,0x61e87a0f}},	//   _muri, _caiu, іяна, _hodl,
   {{0x61e8008f,0x2bdd0967,0x657c01ff,0x00000000}},	//   _kodl, याबा, _oerh, --,
   {{0x645caa53,0xdb1f0176,0x61e8023a,0xba3b016e}},	//   _ouri, _inqü, _jodl, rtïo,
   {{0x61e805d1,0xf65f01b4,0x77930647,0x00000000}},	//   _modl, _træk_, ویدا, --,
   {{0xcb0b071d,0x3e6002d0,0x00000000,0x00000000}},	//   _вход_, _kòt_, --, --,
   {{0x657c1201,0x645caa54,0x2c570160,0x00000000}},	// [c550] _berh, _auri, _dădu_, --,
   {{0x2bac004e,0xdce100d8,0x35b418cd,0x645caa55}},	//   ट्ठा, galė, мбур, _buri,
   {{0x3e60142f,0x69d70391,0x657caa56,0x645c1adb}},	//   _lòt_, _inxe, _derh, _curi,
   {{0x6b9daa57,0x645c0122,0x69c53f5c,0x61faaa58}},	//   ngsg, _duri, _hahe, _altl,
   {{0x216932ff,0x69c5aa59,0x61e8aa5a,0xa3bc00b1}},	//   били_, _kahe, _bodl, _असर_,
   {{0x645c1315,0x69c7aa5b,0x61e8aa5c,0x69c500be}},	//   _furi, ndje, _codl, _jahe,
   {{0x290388d9,0x69c5aa5d,0x758200bf,0xd05800d8}},	//   nzja_, _mahe, _سینم, орыі_,
   {{0x69c5007c,0xb5fb01c0,0x7a3205ee,0x765d00d7}},	//   _lahe, _stáh, lætt, _kusy,
   {{0x645caa5e,0x61e800e9,0x3e600107,0xb5fb0079}},	//   _zuri, _fodl, _còt_, _atái,
   {{0x645caa5f,0x765d1f1d,0xc332134d,0x69c5aa60}},	//   _yuri, _musy, _טון_, _nahe,
   {{0x645c764f,0x7bc40160,0xa3df074f,0x00000000}},	//   _xuri, _paiu, ताप_, --,
   {{0xe672037a,0xb5fb0037,0x69d7002a,0x7a32aa61}},	//   _ölçü, _dtái, _anxe, hætt,
   {{0x69c5aa62,0x75f301d6,0x7bc6aa63,0x00000000}},	//   _bahe, _kızı, rdku, --,
   {{0xcefd0463,0xa96716c0,0x69c50118,0xee380402}},	//   ığın_, зира_, _cahe, _дні_,
   {{0xa3bc1a75,0x69c502c9,0x52b8007e,0x31af037a}},	//   _असल_, _dahe, _इन्स, mızı_,
   {{0x69d78a27,0xb8e40d00,0x645c01d5,0x2bdd00e7}},	//   _enxe, _एन_, _ruri, याणा,
   {{0xa3df23e3,0x645caa64,0xdb9b0397,0xa3da004e}},	// [c560] तान_, _suri, _הספר, ़ास_,
   {{0x2c612eef,0x31af1a68,0x3c32053d,0xfaff01f4}},	//   _kód_, nızı_, rávu_, rbët_,
   {{0x657c1892,0x6fbd0429,0x5fbd065f,0x61e86592}},	//   _verh, ्यां, ्याल, _rodl,
   {{0xe3632a25,0x2c612ac4,0x645caa65,0x7b010225}},	//   екци, _mód_, _vuri, _öztü,
   {{0x61e8531e,0x657caa66,0x2bdd060a,0x645c0a04}},	//   _podl, _terh, याता, _wuri,
   {{0xb5fb0300,0x22bd0107,0xd2590746,0x00000000}},	//   _cuád, _dňk_, іці_, --,
   {{0xf1a900f8,0x645c0006,0x777d006f,0x0ef4aa67}},	//   تانه_, _uuri, _yesx, इन्स_,
   {{0x3e6002d0,0x69c754c4,0x765d022e,0x629902f4}},	//   _pòt_, zdje, _yusy, buwo,
   {{0xb5fb004f,0xdb0f00d5,0x00000000,0x00000000}},	//   _stái, kecá, --, --,
   {{0x7206064e,0xa3da0084,0x3e6002d0,0xf1aa00d1}},	//   _عوام, ़ाव_, _vòt_, _داره_,
   {{0x2c610082,0xd00a1676,0xdc3f00b8,0xdb0f2fba}},	//   _cód_, _леже_, síčn, decá,
   {{0xa3df01d1,0x236601e9,0x317e0a8a,0x26c200ee}},	//   ताय_, ncoj_, _hetz_, _osko_,
   {{0x69c56d0b,0xfe46693e,0x00000000,0x00000000}},	//   _pahe, _ендо, --, --,
   {{0xa3b31e79,0x225902e9,0xf77f0132,0x765daa68}},	//   _जॉन_, _èske_, _poço_, _rusy,
   {{0x69c50ccf,0x26c20291,0xa3bc02cb,0x28f80086}},	//   _vahe, _asko_, _असं_, перь_,
   {{0x2d9e0909,0x69c5aa69,0xdcf800ee,0x76550359}},	//   lgte_, _wahe, _jevč, _sizy,
   {{0x69c500ab,0x656530bc,0x6b8d0269,0x81e70083}},	// [c570] _tahe, tchh, _idag, মোট_,
   {{0x2d9e4003,0x317e01ae,0xdcf83020,0x00000000}},	//   ngte_, _netz_, _levč, --,
   {{0x7a323e88,0x765530bf,0x656502b1,0xb5fb0132}},	//   rætt, _vizy, rchh, _otáv,
   {{0x7a32054e,0xe3b3004f,0x76550035,0xd6e40033}},	//   sætt, عرض_, _wizy, _নেওয,
   {{0xa3df0b4a,0x6fbd022e,0x38c70355,0x00000000}},	//   ताब_, ्यसं, bírá_, --,
   {{0xf77f01c2,0x75f30095,0x785c02d0,0x7c2f0079}},	//   _heç_, _qızı, _sčvi, hocr,
   {{0x63b9004e,0xdb0d002a,0x6b8d00cd,0xf77f013b}},	//   pewn, _maañ, _odag, _keç_,
   {{0xa0091d6c,0xdcf802c4,0x6b8d01d0,0xb4e905b7}},	//   تقبل_, _cevč, _ndag, यही_,
   {{0xa3da0035,0xdcf80207,0x00000000,0x00000000}},	//   ़ार_, _devč, --, --,
   {{0x6b8d17b4,0xee36010b,0x317e00cc,0x2d9e033b}},	//   _adag, мны_, _getz_, ggte_,
   {{0xcf270594,0x00000000,0x00000000,0x00000000}},	//   _کراي, --, --, --,
   {{0x442faa6a,0xe7d800c8,0x2ef51eb9,0x395a021d}},	//   nog_, _সত্য, _озер, _sgps_,
   {{0xee2e37d5,0xef0e5fa1,0x6b8d001c,0x6fda0127}},	//   _ан_, _рм_, _ddag, भारं,
   {{0x442faa6b,0x7d2800b5,0x6b8d0103,0x2bda0066}},	//   hog_, épsé, _edag, _बचका,
   {{0x442f1254,0xd9ff065a,0xc8b5010b,0x1867261d}},	//   kog_, _उतरत_, нсты, даси_,
   {{0xdb1600de,0x3f9f002f,0x442f0ef2,0xfaff0055}},	//   _mayú, nguu_, jog_, rbër_,
   {{0xe73703ad,0x442f0297,0xf41300c8,0x225f0a8a}},	// [c580] дет_, dog_, িকার_, _nuuk_,
   {{0x7a3201b4,0x3dc70260,0xa3b337e8,0xf91f0160}},	//   ræts, _janw_, _जॉब_, _ţâţe_,
   {{0xc48628ea,0xdce10029,0xfaff01f4,0xa3cf007c}},	//   флек, dalī, ncën_, _वोह_,
   {{0xb4ae1163,0x442f011c,0x225f011e,0x2a6000d7}},	//   _कही_, gog_, _buuk_, _kuib_,
   {{0x317e05f5,0x26c2aa6c,0xc17a01e0,0xdcf802a7}},	//   _petz_, _usko_, оїй_, _revč,
   {{0xb5fb024e,0xbbca3100,0xeb9f0c71,0x2fc611ae}},	//   _stáv, ियुक, niør_, _saog_,
   {{0x442faa6d,0xa2c200b8,0xe5a3174b,0xdcfa0228}},	//   bog_, लिङ्, _шири, katā,
   {{0x442f00f8,0x232a708d,0xab5b045e,0x8fa30274}},	//   cog_, _доби_, rdük, ваће,
   {{0x2bdd0429,0xfbdd1e82,0x7c2f0207,0x6d4705ee}},	//   यासा, यासम, vocr, ýjan,
   {{0xdd900206,0xdb0f0279,0x3dc70090,0x201800fd}},	//   دود_, lecç, _canw_, őri_,
   {{0x2d9eaa6e,0x91e3002d,0x55970319,0x2bd0007c}},	//   rgte_, _шофе, ודיע_, _तोहा,
   {{0x225f0118,0x00000000,0x00000000,0x00000000}},	//   _yuuk_, --, --, --,
   {{0xa3df0429,0x81b30083,0xb4bb0785,0x3f847a7a}},	//   तात_, য়ার_, _अन्_, mamu_,
   {{0x3f84aa6f,0x442f219d,0xfd0f0a86,0x2bdd142a}},	//   lamu_, zog_, اجی_, याहा,
   {{0x19580bbc,0xcec80028,0xa9341cba,0x442faa70}},	//   дары_, _hộ_, верш, yog_,
   {{0x3f84aa71,0x442f006d,0x6b8da68b,0xdb0600ac}},	//   namu_, xog_, _udag, leký,
   {{0x442f0537,0xf77f01f4,0x2a60009e,0xba3b01f7}},	// [c590] vog_, _veç_, _guib_, juïg,
   {{0x3f84000e,0xcec80019,0x2bdd0bdd,0x442f2cbc}},	//   hamu_, _mộ_, यावा, wog_,
   {{0x442faa72,0x3f84aa73,0xcec801a5,0xdb0f0279}},	//   tog_, kamu_, _lộ_, fecç,
   {{0x3f84aa74,0xfc4a0023,0xf65f008c,0x61f80298}},	//   jamu_, _bậy_, _bræt_, ekvl,
   {{0x3f8443d1,0xfc4a0023,0xf07500b5,0xcec800e2}},	//   damu_, _cậy_, ڑیاں_, _nộ_,
   {{0x442faa75,0xfc4a0019,0x21690eb1,0x6ecd1cce}},	//   sog_, _dậy_, чики_, तिसु,
   {{0x236031f3,0x20550b32,0x442faa76,0x09c90033}},	//   žija_, нтир, pog_, শাপা,
   {{0xcec800e8,0x4439aa77,0xa2ba0d53,0x3f84001c}},	//   _bộ_, _ós_, _शैक्, gamu_,
   {{0xef1910a9,0x15f37cde,0xdb1d16ad,0x28d100a1}},	//   ями_, _आकार_, ndsä, हिडि,
   {{0x645a0310,0xba3b0176,0x00000000,0x00000000}},	//   _ètic, nuïd, --, --,
   {{0x3f846289,0xc1e600b5,0xfc4a00e2,0xf65f008c}},	//   bamu_, _سکول_, _zậy_, _kræs_,
   {{0xc4d202b5,0x26c0001e,0xfaff0031,0x00000000}},	//   אגט_, ywio_, rcën_, --,
   {{0x539a00a5,0x501a0070,0x3dc70260,0x00000000}},	//   הירו, _צונו, _tanw_, --,
   {{0x6da507fa,0x38c83c96,0x38610069,0x1d0923b6}},	//   _чика, وازی_, _buhr_, _нели_,
   {{0xb4ae3e72,0xd8260896,0x2d8530b3,0x6e2600b5}},	//   _कहे_, едви, male_, ékbe,
   {{0x6d4301cc,0x2d85aa78,0x66e602c4,0x00000000}},	//   _izna, lale_, ноба, --,
   {{0x86460e88,0xd70a00d8,0x2bdd00a9,0xdb0600b5}},	// [c5a0] енаж, чнае_, यारा, nekü,
   {{0x2bac0967,0xfbac00df,0x3f843a34,0x386102b1}},	//   ट्रा, ट्रम, zamu_, _fuhr_,
   {{0xdb06007c,0xdb0f0279,0xddd80107,0x00000000}},	//   hekü, tecç, _divň, --,
   {{0xff470a42,0x2d85aa79,0xb5fb01c0,0x59de052b}},	//   _مخ_, hale_, _stát, मावर,
   {{0xdb0f0279,0x386100d7,0xc7b3011d,0xb5fb0023}},	//   recç, _zuhr_, _גבר_, _quác,
   {{0x2d8596ef,0xfc4a0028,0x64a600d8,0xcec80023}},	//   jale_, _vậy_, _пага, _rộ_,
   {{0x2d85aa7a,0x3f84aa7b,0xa3ea0945,0x999b0317}},	//   dale_, tamu_, _едва_, לבסט,
   {{0x7c2416c8,0xf65f0b3e,0x6e23023a,0x00000000}},	//   _njir, _træt_, _ajnb, --,
   {{0x3f8416c8,0x2d85aa7c,0x241702b5,0xfe6f03c5}},	//   ramu_, fale_, _נחמן_, یدی_,
   {{0x63a2aa7d,0x7c24000e,0x3f84aa7e,0x00000000}},	//   lgon, _ajir, samu_, --,
   {{0x2bdd0aad,0x6ab90167,0x6ac9021a,0x1ac90b35}},	//   याला, इब्र, िट्र, िट्ठ,
   {{0x63a2aa7f,0x68f500d8,0x38614fb1,0x7c24023a}},	//   ngon, vyzd, _ruhr_, _cjir,
   {{0xdcf80228,0x63a201a2,0x3861081c,0x6d4301ed}},	//   _devā, igon, _suhr_, _ezna,
   {{0x2d85aa80,0x7d0600f7,0xc3330d85,0x9f5d0260}},	//   cale_, _céré, רוש_, _alwè_,
   {{0x63a20987,0xb5fb0183,0x7d06aa81,0x00000000}},	//   kgon, _otár, _déré, --,
   {{0x7c2401f4,0x7e6200c3,0xddc905e2,0xdb1d0031}},	//   _gjir, _kuop, mpeš, nesë,
   {{0xa3da0953,0x63a2aa82,0xa3df143a,0x00000000}},	// [c5b0] ़ाई_, dgon, तास_, --,
   {{0x7c3daa83,0x7d06000d,0x63a20345,0x00000000}},	//   llsr, _géré, egon, --,
   {{0xd37138b7,0xb7d90332,0x7e620421,0xd49b38ab}},	//   لها_, _ہوگا_, _luop, яра_,
   {{0x2d855b67,0x63a200d1,0x30af0083,0x23e4010b}},	//   zale_, ggon, কিৎস, лічв,
   {{0x27e903c9,0x7d0600f8,0x00000000,0x00000000}},	//   mjan_, _yéré, --, --,
   {{0x27e9aa84,0xe1f800c7,0xb5fb0279,0x44240176}},	//   ljan_, нгі_, _etár, _ejm_,
   {{0x2d851c12,0x00000000,0x00000000,0x00000000}},	//   vale_, --, --, --,
   {{0x27e9aa85,0x2d85aa86,0x201f0139,0xdb1d0055}},	//   njan_, wale_, unui_, gesë,
   {{0x1e820409,0x2d850681,0x32553f96,0x27e9085a}},	//   алым, tale_, _авар, ijan_,
   {{0x7c36aa87,0xa3df052f,0x64490211,0x645a00a2}},	//   _skyr, ताव_, _hhei, _étir,
   {{0x2d85aa88,0xeb9a1d91,0xfbdd16d3,0x4e9500b5}},	//   rale_, мин_, यांम, رشکر,
   {{0x0f150086,0x7d06000d,0x88c00033,0x6add021a}},	//   _имею, _séré, _উপলক, ममूर,
   {{0xa3b3035d,0x2d850cb4,0x27e9aa89,0x6449004f}},	//   ज्य_, pale_, djan_, _mhei,
   {{0x798701d5,0xaa4602fb,0x27e902d7,0x645b009e}},	//   gajw, тегл, ejan_, _liui,
   {{0x3ead9aef,0x6d4312ad,0x7c240345,0x64490421}},	//   ltet_, _uzna, _tjir, _ohei,
   {{0x2fcd3cb7,0x73ec0083,0x27e9aa8a,0xa3b30066}},	//   ndeg_, _কষ্ট_, gjan_, ज्म_,
   {{0x3eadaa8b,0x9f4f0443,0x63a601ff,0x79870979}},	// [c5c0] ntet_, _algú_, _ökni, bajw,
   {{0x6b8400a5,0x3ead01ae,0x4424350d,0x64490160}},	//   _heig, itet_, _sjm_, _ahei,
   {{0x644930d2,0x26cf06d7,0x69de01a3,0x3eadaa8c}},	//   _bhei, ågor_, _inpe, htet_,
   {{0x64492c46,0x645b0284,0xe29a0f08,0x6b8401c8}},	//   _chei, _ciui, дад_, _jeig,
   {{0x644909e3,0x645baa8d,0x2360008b,0x2baa29ce}},	//   _dhei, _diui, žijo_, _काना,
   {{0x6b84aa8e,0x63a2432a,0xb5fb0453,0x80ce0066}},	//   _leig, sgon, _huán, थिले,
   {{0x6449006e,0xdb1d0031,0xb5fb0183,0x3ead02b1}},	//   _fhei, tesë, _itáp, etet_,
   {{0x6449111c,0x3ead0c60,0xb4de00a1,0x765c0010}},	//   _ghei, ftet_, तमी_, _hiry,
   {{0xa3df0fcf,0x3f9806d3,0x3ead01b4,0x645a00f7}},	//   तार_, ğru_, gtet_, _étiq,
   {{0x200401f4,0xa3da0066,0xa8060644,0xdcf80139}},	//   shmi_, ़ाक_, llığ, _nevă,
   {{0x6b84aa8f,0xd59b0122,0x659b00a5,0x765c018c}},	//   _beig, וביל, וייק, _miry,
   {{0xa80606d0,0x69de02e9,0x69ce54f1,0x765c2fb5}},	//   nlığ, _anpe, edbe, _liry,
   {{0x6b84aa90,0x6f09aa91,0x79870054,0x4dfc045c}},	//   _deig, czec, tajw, एसआई_,
   {{0x765c04fb,0x5a34359e,0xd7c90088,0x69ce1167}},	//   _niry, инят, کوره_, gdbe,
   {{0x27e9aa92,0xa806027d,0xaa582581,0x97a79e5f}},	//   tjan_, klığ, тиру_, крал,
   {{0xb5fb4e5c,0x69deaa93,0xf77305bc,0x7af201f4}},	//   _cuán, _enpe, شار_, ëjtë,
   {{0x6449aa94,0x27e9aa95,0x35b51783,0xa8060095}},	// [c5d0] _rhei, rjan_, лбар, dlığ,
   {{0x6449aa96,0x6b8402c9,0x645b3889,0xfc3f0037}},	//   _shei, _zeig, _siui, llí_,
   {{0x2baa00a1,0xa3df00b1,0x290a004e,0x7bcd010d}},	//   _कामा, ताल_, czba_, _kaau,
   {{0x7b0800d0,0x628b448b,0x3eadaa97,0x765c0103}},	//   _örtü, tsgo, ytet_, _eiry,
   {{0x02a71283,0xe299aa98,0x877a011d,0xfc3f0079}},	//   трем, хал_, _ראשי, ilí_,
   {{0xb6da02b5,0x7d1501ba,0x785c0a23,0x765c02ea}},	//   _אַלט, úzsk, _učvr, _giry,
   {{0x6449aa99,0xdb04009e,0xa3ab00b4,0x628b1e2e}},	//   _thei, _dbiù, _खाप_, ssgo,
   {{0xb4c10026,0x3ead48d9,0x44d3003a,0x21f90118}},	//   ्टी_, ttet_, _ić_, _mèhi_,
   {{0x2fcd6041,0xdbdd008a,0x63a93225,0xf1a70e60}},	//   rdeg_, _ráðs, _icen, _арен,
   {{0x3eadaa9a,0x6b84aa9b,0x7bdf0138,0x6f090035}},	//   rtet_, _seig, _anqu, rzec,
   {{0x3eadaa9c,0xed580038,0x6b84aa9d,0x25a5008a}},	//   stet_, teľa_, _peig, _öllu_,
   {{0x3ead1e74,0x7d1c0037,0xf3f90160,0x2d990225}},	//   ptet_, úrsa, _fiţe_, şse_,
   {{0xa3ab05f8,0x6b84aa9e,0xfbaa000c,0xa806033e}},	//   _खान_, _veig, _काठम, nlış,
   {{0x6e920082,0x5e92004f,0xbf3602b5,0x6b8491e8}},	//   _الوا, _الوط, _גאנץ_, _weig,
   {{0x69d9009a,0x63a9aa9f,0xfc3f0082,0x6b8400d8}},	//   माजी, _ocen, blí_, _teig,
   {{0xfc3f0037,0xb5fb00e2,0x3e69aaa0,0x6eb700ab}},	//   clí_, _quán, _kút_, _अहाँ,
   {{0x66e3265e,0x00000000,0x00000000,0x00000000}},	// [c5e0] бота, --, --, --,
   {{0x63a9aaa1,0x8a7b0122,0xa50a0de2,0xb4c1020d}},	//   _acen, _ראית, неза_, ्टू_,
   {{0xa3df0026,0xb4de018d,0x5dfa0070,0xa8060644}},	//   तां_, तमे_, עפענ, tlığ,
   {{0x765c8994,0x289b0070,0x37750043,0x00000000}},	//   _wiry, _איטא, _вырс, --,
   {{0xa8060463,0x3e690019,0x8c1b00a5,0x753c0035}},	//   rlığ, _nút_, עוני, _wyrz,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66032178,0xdb1d0332,0xc653006c,0xab5b04d4}},	//   _упра, resé, _اہلک, ndür,
   {{0xa3df04cc,0x3e690019,0xb4d000a1,0xa3ab007c}},	//   ताः_, _bút_, वटी_, _खाय_,
   {{0x3e6900e2,0x9f5f0098,0x2d9801ef,0xc3260678}},	//   _cút_, chuí_, óreo_, _смак,
   {{0x3207000c,0x1e1402ee,0xb5fb0037,0x6f1d0079}},	//   chny_, рмоя, _nuál, úsca,
   {{0x0ce20083,0x7bcd23c6,0x459b0070,0x23690a23}},	//   মন্ত, _paau, עסטע, žaje_,
   {{0xac191470,0xdb550086,0x79850345,0x3e690098}},	//   тому_, ивны, _sehw, _fút_,
   {{0xdd9200f8,0x3e6900cc,0xc2f80831,0x00000000}},	//   _هوش_, _gút_, _আইডি_, --,
   {{0xc3330052,0xb5fb0831,0xfc3f0187,0xa7fb01ed}},	//   מור_, _cuál, slí_, _miñe,
   {{0xb5fb6cc7,0x00000000,0x00000000,0x00000000}},	//   _duál, --, --, --,
   {{0xc8640445,0x32070107,0x3f860359,0x8ae701e0}},	//   стри, zhny_, _jeou_, _біол,
   {{0xa7fb0831,0xa3e83e9e,0x25aa01f7,0x061531e6}},	// [c5f0] _niñe, बान_, _bcbl_, адаю,
   {{0x2bdd00a1,0x65952192,0x25b8009e,0x00000000}},	//   याका, ражу, _cbrl_, --,
   {{0xb4c1006a,0x6d5e0097,0x00000000,0x00000000}},	//   ्टे_, _úpad, --, --,
   {{0xd9e30e04,0xa7fb01ed,0x00000000,0x00000000}},	//   खावत_, _biñe, --, --,
   {{0xa2e502c4,0x63a900ee,0xc7d802fb,0x00000000}},	//   ролд, _vcen, _смях_, --,
   {{0x409515e1,0x3e6901a5,0xa7fb01dd,0x213e00e9}},	//   арит, _rút_, _diñe, _byth_,
   {{0x69adaaa2,0x3e690023,0x44d30124,0x854400af}},	//   _जानी, _sút_, _uć_, _гэте,
   {{0x63a9669b,0xb275aaa3,0xdb160107,0x00000000}},	//   _ucen, _влаш, _mayò, --,
   {{0x4fe600af,0xd00e0037,0x9e650836,0x2bd906fe}},	//   рмын_, بلي_, јвод, _बोधा,
   {{0x81b30033,0xfe4201e0,0x213e016e,0x5f9500b5}},	//   _জোর_, жньо, _fyth_, _چلائ,
   {{0x9d450ecb,0x0c26059d,0xa7fb01ed,0x2cae00a2}},	//   ренд, имон, _ziñe, _cqfd_,
   {{0x3f8900fb,0x26d9027a,0x3e6900cc,0x9f4f00f6}},	//   _þau_, _orso_, _tút_, _logé_,
   {{0xeb974a10,0x3d150066,0xdb1602d7,0x00000000}},	//   шия_, _फेरे_, _rayó, --,
   {{0x602100ea,0x00000000,0x00000000,0x00000000}},	//   dēmi, --, --, --,
   {{0x26cb0ddb,0x2d87695e,0xb4c10af9,0xf77202e7}},	//   _asco_, _iene_, ्टो_, قاء_,
   {{0xb8de018d,0xab5b027d,0x2d87aaa4,0x2fcf1dab}},	//   _इह_, rdür, _hene_, _jagg_,
   {{0xb4de0ea3,0x2d8714f2,0xa3df1fb4,0x46a643ca}},	// [c600] तम्_, _kene_, ताई_, разв,
   {{0x2d87aaa5,0xe57721be,0xe8fa10bb,0x2fcf0282}},	//   _jene_, изу_, _ало_, _lagg_,
   {{0x2d872676,0x399b02b5,0xf1a906fe,0x26cb027a}},	//   _mene_, _בייד, च्छन, _esco_,
   {{0x2d874c06,0xa7fb2b83,0xb6a6021d,0x7c266037}},	//   _lene_, _piñe, _кимл, nnkr,
   {{0xe7fb00c0,0xa3e804bc,0x213e00e9,0x2d870051}},	//   _एकता_, बाब_, _syth_, _oene_,
   {{0x2d87aaa6,0xa7fb1111,0x25aa011e,0x98a70160}},	//   _nene_, _viñe, _ucbl_, _ână_,
   {{0xf9930122,0xdce800ea,0x91f50023,0x4fc600c7}},	//   קרה_, radī, _tín, аспа,
   {{0x44c8036a,0x61e10955,0x03a3021d,0x3205572c}},	//   _iş_, _enll, _мисо, _elly_,
   {{0x44260169,0x539b0052,0x2d87aaa7,0xa3cf0299}},	//   mno_, _שימו, _bene_, _वोट_,
   {{0x442602dd,0x644203ad,0x2d87aaa8,0x6b960118}},	//   lno_, lloi, _cene_, _adyg,
   {{0xd5d900c2,0x4426aaa9,0x2d8700d1,0x3a3811cc}},	//   אַרש, ono_, _dene_, dorp_,
   {{0x4426aaaa,0xef1a0ca6,0x92d80033,0x2d8702a2}},	//   nno_, _име_, াহী_, _eene_,
   {{0x545702b5,0x2d87aaab,0x64420160,0x6b96016e}},	//   יסטן_, _fene_, iloi, _ddyg,
   {{0xedd30c26,0x2d87aaac,0x59de0a44,0x68fc016e}},	//   _ويند, _gene_, मागर, fyrd,
   {{0xb7fb0581,0x2d8caaad,0x37ab01f2,0x442600d1}},	//   _एकदम_, made_, ктан_, kno_,
   {{0x442602dd,0x2d8caaae,0x2d87aaaf,0x46d2035d}},	//   jno_, lade_, _zene_, सिंह,
   {{0x44260a0b,0x44c8aab0,0xac070609,0x00000000}},	// [c610] dno_, _aş_, _مذکو, --,
   {{0x2d8caab1,0x4426aab2,0x2d8701dd,0x7afd30aa}},	//   nade_, eno_, _xene_, myst,
   {{0x2a6901a9,0xa3ab0066,0x321c00ac,0x00000000}},	//   _huab_, _खाद_, divy_, --,
   {{0x44260021,0x2d8c106d,0x2a6901e8,0x2d98004e}},	//   gno_, hade_, _kuab_, órej_,
   {{0x2d8caab3,0xf2c70133,0x2a69006d,0x60daaab4}},	//   kade_, рсен, _juab_, _artm,
   {{0x4426aab5,0x2a690d4b,0x20068552,0x2d8c7fb9}},	//   ano_, _muab_, _aloi_, jade_,
   {{0x2d8c6a79,0x442602dd,0x2a6901e8,0x2fcf027a}},	//   dade_, bno_, _luab_, _pagg_,
   {{0x4426a82b,0xe2ab006c,0x2d87aab6,0x1e850171}},	//   cno_, _لائن_, _sene_, блим,
   {{0xee391761,0x63bb0452,0x2d87aab7,0x2d8c8e38}},	//   лни_, _ibun, _pene_, fade_,
   {{0x2d8700da,0x2006487b,0xa3df0581,0x41e400d8}},	//   _qene_, _eloi_, ताक_, _міха,
   {{0x2d87525c,0x69c3008e,0x2fcf4a11,0x00000000}},	//   _vene_, _óney, _tagg_, --,
   {{0xc0b20019,0x26c904f7,0x2d870345,0x200600e5}},	//   _lưới_, kwao_, _wene_, _gloi_,
   {{0x63bbaab8,0x2a690189,0x7c26aab9,0x3a38013c}},	//   _mbun, _cuab_, rnkr, torp_,
   {{0x4426096f,0x7f3a0779,0x499903ad,0x2a6901a9}},	//   zno_, _גענו, ится_, _duab_,
   {{0x4426aaba,0x63bb0273,0x00000000,0x00000000}},	//   yno_, _obun, --, --,
   {{0x23606395,0x7afd01ba,0x5baa16b8,0x6c3600b2}},	//   žiji_, byst, _ским_, _دفعا,
   {{0x44260888,0x7bc60657,0x7afdaabb,0x00000000}},	// [c620] vno_, meku, cyst, --,
   {{0x63bb109d,0x4426004e,0xc0b201a5,0x00000000}},	//   _abun, wno_, _cưới_, --,
   {{0x44260888,0xc0b20028,0x78be029b,0x69ad1e18}},	//   tno_, _dưới_, _uppv, _जाती,
   {{0x4426aabc,0x7bc6aabd,0x2d8caabe,0x2a69006d}},	//   uno_, neku, zade_, _yuab_,
   {{0x2ca54d5a,0x2a6901e8,0x6442026e,0x321c00b8}},	//   huld_, _xuab_, rloi, tivy_,
   {{0x44261851,0x3c32114d,0x798eaabf,0x7bc6aac0}},	//   sno_, rávy_, nabw, heku,
   {{0x7afd0755,0x64a388c0,0x6442aac1,0x44260121}},	//   zyst, _нара, ploi, pno_,
   {{0x4fc60086,0x2ca56ce1,0x7bc607e2,0x798e0010}},	//   сска, duld_, jeku, habw,
   {{0x2d8caac2,0xdb1d00b5,0x7e7b0c86,0x798e8e43}},	//   tade_, tesí, gpup, kabw,
   {{0x273701a5,0x63bb95a0,0xa7fb01dd,0xea010019}},	//   ủng_, _zbun, _miña, _đắt_,
   {{0x2a690189,0xa7fb0391,0x2d8c49f7,0x7afd001e}},	//   _suab_, _liña, rade_, wyst,
   {{0x7afdaac3,0x2d8caac4,0x7bc60054,0x2a69006f}},	//   tyst, sade_, geku, _puab_,
   {{0xa3ab0e1d,0x2d8caac5,0xa7fb0020,0x2baa0c67}},	//   _खास_, pade_, _niña, _कारा,
   {{0x7afdaac6,0x2a69006d,0xdb0401ef,0x2bd955f5}},	//   ryst, _vuab_, _abió, _बोरा,
   {{0x7afd0533,0x7bc60ccc,0x195900d8,0x00000000}},	//   syst, beku, равы_, --,
   {{0x2a690221,0x7bc60950,0x26c908c7,0x00000000}},	//   _tuab_, ceku, twao_, --,
   {{0x7c2d5a0c,0x798e0010,0x35f5516d,0xb5f5195c}},	// [c630] _ijar, babw, опар, озащ,
   {{0xd5676f49,0x7c2daac7,0xa7fb01ed,0x00000000}},	//   стап, _hjar, _diña, --,
   {{0x7c2d2cce,0x69c7aac8,0xddc2023a,0x00000000}},	//   _kjar, meje, _otož, --,
   {{0x69c7aac9,0x6e3a022e,0x2b5f0009,0x69d56cc0}},	//   leje, hotb, žucu_, ldze,
   {{0xc0b20023,0xa7fb01b7,0x7c2d023c,0x00000000}},	//   _tưới_, _giña, _mjar, --,
   {{0x04c90987,0x69d5aaca,0x7bc6aacb,0x69c70371}},	//   _پوري_, ndze, zeku, neje,
   {{0xb5fb0d88,0x92e900c8,0x7bc6000e,0x2baa09b8}},	//   _otáz, মনে_, yeku, _काला,
   {{0x63bb4583,0xfaff00da,0x2bd9aacc,0x2ca50120}},	//   _ubun, ncës_, _बोला, vuld_,
   {{0x443f01ca,0x442d0371,0x69c7aacd,0x7bc6aace}},	//   _iku_, _ije_, keje, veku,
   {{0x7c2d1b0f,0x69c7aacf,0x443f04f4,0x78a701f4}},	//   _ajar, jeje, _hku_, kujv,
   {{0x7c2daad0,0x1ee700bf,0xfbc60426,0x442d02c6}},	//   _bjar, _گوشی_, обно, _kje_,
   {{0x2baa02cb,0x798e44fa,0x7e7b0421,0x443f034d}},	//   _काळा, wabw, ppup, _jku_,
   {{0x7bc6aad1,0x69c7006c,0x7c2daad2,0xdb040176}},	//   reku, feje, _djar, _abiò,
   {{0xed592a67,0x201f00d8,0x69c7aad3,0x200d0132}},	//   _кол_, liui_, geje, lhei_,
   {{0xdd8e0c74,0x443faad4,0x7c2d008a,0x7e6b3081}},	//   _شوي_, _oku_, _fjar, _hugp,
   {{0x442daad5,0xfc325002,0x798e0010,0x7c2d545f}},	//   _nje_, _تحت_, sabw, _gjar,
   {{0xe61a4011,0xc60500c8,0xe7fb0006,0x661eaad6}},	// [c640] ада_, োচনা_, _एकरा_, tipk,
   {{0x443f1c04,0xe5a33dd9,0x857a002d,0x7c2d00da}},	//   _aku_, дифи, рсат_, _zjar,
   {{0x7e636b11,0x201f010b,0x7e6b0345,0xdb0401ed}},	//   _minp, kiui_, _lugp, _ibiñ,
   {{0x66e6292e,0xa7fb043f,0x661e06b3,0x6d43016e}},	//   _дома, _tiña, sipk, _myna,
   {{0x442d00da,0xf77300d1,0xa3ab00ab,0x443f00e0}},	//   _dje_, _تاپ_, _खार_, _dku_,
   {{0x443f0069,0x6d4306d0,0xddc213a6,0x442daad7}},	//   _eku_, _oyna, _stož, _eje_,
   {{0x154315d5,0x0ef40edf,0xe47600af,0xdcf80355}},	//   _жерм, ेन्स_, _фугэ, _devě,
   {{0x442d4c46,0x8ca300c0,0x78fb0070,0x69c7aad8}},	//   _gje_, _कमजो, יפצו, zeje,
   {{0x6d430448,0x69c71b68,0x00000000,0x00000000}},	//   _ayna, yeje, --, --,
   {{0x6e28aad9,0x7e63006d,0x6d432308,0x3cfe0453}},	//   undb, _cinp, _byna, tytv_,
   {{0x69c75cb2,0x6d4300e9,0xdb1d00b8,0xa3df00a1}},	//   veje, _cyna, desá, ताच_,
   {{0x236024b7,0x69ad00a1,0x200daada,0x7ee60037}},	//   žiju_, _जाही, chei_, _وكان,
   {{0x69c7aadb,0x7e630f0a,0x6e3a00b5,0x00000000}},	//   teje, _finp, potb, --,
   {{0x1fbc0083,0x7e63aadc,0x69d500ea,0xb5fb0098}},	//   _অফিস, _ginp, udze, _tuái,
   {{0x69c7aadd,0x2905aade,0x69d5aadf,0x6d43aae0}},	//   reje, ála_, rdze, _gyna,
   {{0x7c2d00f8,0x998300d8,0x69c7aae1,0x7e6301b7}},	//   _ujar, tojų_, seje, _zinp,
   {{0x70c614ab,0x356b315d,0xfaff0031,0x00000000}},	// [c650] लबुल, арен_, rcës_, --,
   {{0x7c3d012e,0x64401047,0x6b8d0037,0x78a70031}},	//   losr, _akmi, _heag, pujv,
   {{0x6b8d005d,0x443f03d0,0x5fbc1cce,0x00000000}},	//   _keag, _pku_, ्जाल, --,
   {{0xf65f008c,0x00000000,0x00000000,0x00000000}},	//   _spæd_, --, --, --,
   {{0x6b8d3036,0x2369008b,0x443f00d5,0x442d25ea}},	//   _meag, žajo_, _vku_, _vje_,
   {{0x34952070,0xbb3c0070,0x6b8daae2,0x7e6b00d8}},	//   _нагр, בעדי, _leag, _rugp,
   {{0xc5f2035e,0x442d02a2,0x7e6b06f7,0x00000000}},	//   _אדם_, _tje_, _sugp, --,
   {{0xd3e30164,0x443f79cb,0x6b8d2491,0x442daae3}},	//   _تقری, _uku_, _neag, _uje_,
   {{0xa3e8111b,0x6d43aae4,0x201f00d8,0x443d0067}},	//   बार_, _syna, riui_, mow_,
   {{0x443d0122,0xee360086,0xa3ab07b5,0x660501ef}},	//   low_, знь_, _खाँ_, nkhk,
   {{0xa7fb0083,0x443d008c,0x7e6343aa,0x6b8d09c1}},	//   _niño, oow_, _vinp, _beag,
   {{0x443daae5,0x6d43aae6,0x7e6b0159,0x6b8d0341}},	//   now_, _vyna, _tugp, _ceag,
   {{0x6d43004e,0x6b8d01a6,0xdee50de3,0xf1e0007c}},	//   _wyna, _deag, _холи, _गोड़_,
   {{0xddc30029,0x6d430051,0x00000000,0x00000000}},	//   _minū, _tyna, --, --,
   {{0xdb1d024e,0x443d5de1,0x6b8d8256,0x6e21aae7}},	//   resá, kow_, _feag, milb,
   {{0x443daae8,0x661caae9,0x27e6aaea,0xf1c70187}},	//   jow_, _smrk, ñon_, _hráč_,
   {{0x443da8f2,0x6fbd0ed1,0x00000000,0x00000000}},	// [c660] dow_, व्यू, --, --,
   {{0x6569027d,0x7bd6aaeb,0x6e2170cc,0x6d5c003e}},	//   _şehr, _hayu, nilb, ýrag,
   {{0x7bd687f3,0x6b8d08c3,0x14c800d1,0x628902d7}},	//   _kayu, _yeag, تهای_, _aweo,
   {{0x68e101b4,0x6e2113d0,0x68e3002a,0x443daaec}},	//   ælde, hilb, _ánda, gow_,
   {{0x7bd6aaed,0x26c20a4e,0x0ca80808,0x91fc0228}},	//   _mayu, _upko_, _कम्म, _diān,
   {{0x7bd600a7,0x00000000,0x00000000,0x00000000}},	//   _layu, --, --, --,
   {{0xddc200c7,0xbfa300e2,0x443daaee,0x3d050067}},	//   _nuoš, _tiề, bow_, शनों_,
   {{0x22be00ea,0x443daaef,0x7bd6759b,0x00000000}},	//   tākā_, cow_, _nayu, --,
   {{0x6b8daaf0,0x6e21097d,0xa2dd022e,0xda0c00b4}},	//   _reag, filb, पिण्, सघात_,
   {{0x6b8daaf1,0xddcb0723,0x7bd608dd,0xdd90103b}},	//   _seag, ğişt, _aayu, خود_,
   {{0x61e84d3e,0x6b8d00ab,0x7bd6759b,0x25ed0d2a}},	//   _indl, _peag, _bayu, घाती_,
   {{0x61faaaf2,0x1016028c,0x7bd60176,0xa7fb0453}},	//   _hotl, _عباد, _cayu, _riño,
   {{0x34c804bc,0x7bd60dc3,0x6b8d0553,0x81b30831}},	//   रबुद, _dayu, _veag, _জোট_,
   {{0xaa640d44,0xcf250372,0xa7fb0300,0xa2dd022e}},	//   етск, _ترمي, _piño, पित्,
   {{0x6b8d30d2,0x443d0107,0x7c3d22b2,0xab5b027b}},	//   _teag, yow_, posr, ndüz,
   {{0xb8e53914,0x7bd6aaf3,0x61fa0159,0x999800b8}},	//   _एह_, _gayu, _lotl, borů_,
   {{0x47341129,0x45d500af,0x5bc90067,0x00000000}},	// [c670] ентс, моас, िजीव, --,
   {{0x443d9e96,0x2d8e0033,0x61faaaf4,0x9f4f021d}},	//   wow_, _jefe_, _notl, _jogá_,
   {{0xf9fc00a5,0x443daaf5,0x2d8e0260,0x7bd618f9}},	//   _להזמ, tow_, _mefe_, _yayu,
   {{0xd0061026,0x61e8aaf6,0x4ab10581,0x9f4f07c0}},	//   _شل_, _andl, _जमाव, _logá_,
   {{0xe3b000bf,0x69d7aaf7,0x443d53fe,0x64591995}},	//   ارم_, _kaxe, row_, rmwi,
   {{0xa3dd065a,0xe819009a,0xa92501ba,0x443d0067}},	//   _थोर_, नोरा_, poľč, sow_,
   {{0x61fa5ffc,0x1dd7052f,0x99980355,0x00000000}},	//   _dotl, _भोगत, zorů_, --,
   {{0x443d0069,0xddc2010b,0x69d74f2e,0x61e806d1}},	//   qow_, _ruoš, _laxe, _endl,
   {{0x7bd6aaf8,0x3e720043,0x6e213dbe,0xef1902fb}},	//   _rayu, _cât_, tilb, юми_,
   {{0x7bd65589,0x61fa013c,0xc2c40365,0xddc200c7}},	//   _sayu, _gotl, _سيمي, _puoš,
   {{0x7bd606b3,0x2d8e013b,0x00000000,0x00000000}},	//   _payu, _defe_, --, --,
   {{0xea0101a5,0x6e21aaf9,0x999800b8,0x3c1a010b}},	//   _đạt_, silb, torů_, іўня_,
   {{0xa3ab1a75,0x81d00083,0x69d70065,0xed5800a0}},	//   _खाई_, ষার_, _baxe, deľu_,
   {{0x186a052c,0x7bd601cb,0x69d70952,0xae01046c}},	//   жави_, _wayu, _caxe, _लकिन_,
   {{0xd9436058,0x7bd6a62f,0x2d8520ac,0xa9670dde}},	//   вери, _tayu, mble_, дира_,
   {{0x7b0700b5,0x3f8f0409,0x00000000,0x00000000}},	//   örté, _jegu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c680] --, --, --, --,
   {{0x2d850c1f,0x2d8e0391,0x3f8f05ee,0x00000000}},	//   nble_, _xefe_, _legu_, --,
   {{0x61faaafa,0x2d850831,0xf24100d8,0x136a2860}},	//   _rotl, ible_, _якiя_, ошли_,
   {{0x2bc10026,0x3f8faafb,0x61fa9279,0x00000000}},	//   ष्पा, _negu_, _sotl, --,
   {{0xab5b02bf,0x61fa06e7,0xe297094f,0x00000000}},	//   rfüg, _potl, дач_, --,
   {{0xc5d500d8,0x3f8f00be,0x24980160,0xd2500413}},	//   _пісь, _aegu_, _tvrm_, دنت_,
   {{0x6d4700be,0x2d8e0260,0x61fa42f3,0x00000000}},	//   üjal, _refe_, _votl, --,
   {{0xa3ab2869,0xf8b30122,0x2d8502d7,0x660e0168}},	//   _खाए_, דשה_, eble_, _hlbk,
   {{0xf65f054e,0x3f8f8edd,0x660e00ee,0x9343aafc}},	//   _især_, _degu_, _klbk, _анте,
   {{0xdce30024,0x00000000,0x00000000,0x00000000}},	//   _senġ, --, --, --,
   {{0xb4bc0099,0xa3d20026,0xae1d04bc,0x628200ab}},	//   _अहो_, _वसा_, योधन_, lpoo,
   {{0x69d70523,0xb5fb0831,0x2d851691,0x6282034d}},	//   _saxe, _juár, able_, opoo,
   {{0xfc3f0037,0x2d85aafd,0xdddb00a8,0x1be400b4}},	//   roí_, bble_, qquş, गाजल_,
   {{0x7e7d124b,0x2d8e00f4,0x62820207,0x00000000}},	//   íspe, _uefe_, ipoo, --,
   {{0xa3deaafe,0x3a230223,0x00000000,0x00000000}},	//   तया_, rijp_, --, --,
   {{0x23dd02cb,0xa3b30d53,0x7b671e38,0x69d70f00}},	//   _नोंद, ज्ञ_, _отпе, _waxe,
   {{0x69d7aaff,0xa3e81db9,0x660e00fe,0x3a230051}},	// [c690] _taxe, बाई_, _blbk, pijp_,
   {{0x62820345,0xd50b0312,0x00000000,0x00000000}},	//   dpoo, يغان_, --, --,
   {{0x7995037b,0x41d90b35,0xd49b0217,0x00000000}},	//   mazw, _योगस, юра_, --,
   {{0x62840029,0xdcf80009,0x7995002f,0x69bb01d1}},	//   ģion, _jevđ, lazw, श्री,
   {{0x2bc12483,0x62840012,0xfbc106fe,0x3f8f05ca}},	//   ष्या, ţion, ष्यम, _regu_,
   {{0xa3ab0026,0x624d0042,0x3f8f1ea6,0x00000000}},	//   _खाक_, cúol, _segu_, --,
   {{0xab5b00a8,0x00000000,0x00000000,0x00000000}},	//   rdüy, --, --, --,
   {{0x2bc10ed1,0xb5fb00de,0xdb0d002a,0x79950371}},	//   ष्मा, _guár, _acaí, hazw,
   {{0x79952a13,0xe2350274,0x442f601c,0x00000000}},	//   kazw, _знањ, mng_, --,
   {{0x273e098b,0x272c00e8,0xac852682,0x442f2326}},	//   ững_, ếng_, нгол, lng_,
   {{0x442fab00,0x3f8fab01,0x00000000,0x00000000}},	//   ong_, _tegu_, --, --,
   {{0xfaa606d8,0x442fab02,0xf3f90160,0x00000000}},	//   намо, nng_, _biţi_, --,
   {{0x442fab03,0x200fab04,0xef0e0109,0x629901bf}},	//   ing_, _ilgi_, _см_, nswo,
   {{0x6f1d1be9,0x442f01a2,0x2fcdab05,0x799501d5}},	//   úscu, hng_, leeg_, gazw,
   {{0x3ead012f,0x00000000,0x00000000,0x00000000}},	//   luet_, --, --, --,
   {{0xad1a0122,0x2fcd006d,0x80a70785,0xf3f900af}},	//   _מוצר, neeg_, _घटने, _fiţi_,
   {{0xe7370086,0xd6cf006c,0x7bc40279,0x799501d5}},	// [c6a0] еет_, یقہ_, _ibiu, bazw,
   {{0x7ae40291,0x2bc105f7,0x442f05ca,0x6299271e}},	//   _irit, ष्ठा, eng_, dswo,
   {{0x7ae4009e,0xb5fb01ef,0x69dc09a2,0x25a60448}},	//   _hrit, _cuáq, mdre, ğol_,
   {{0x69ceab06,0x69dcab07,0x442f7658,0x248601ba}},	//   lebe, ldre, gng_, ďom_,
   {{0x2fcd0298,0x20d1013a,0x62990345,0x00000000}},	//   deeg_, _aši_, gswo, --,
   {{0x442f422d,0x69ceab08,0x200f0009,0x69dc409c}},	//   ang_, nebe, _algi_, ndre,
   {{0x62821c61,0x69dcab09,0x442f55ad,0x7c2f51c7}},	//   spoo, idre, bng_, yncr,
   {{0x69ce01ae,0x69dc00e9,0x628202ee,0x00000000}},	//   hebe, hdre, ppoo, --,
   {{0xcf260082,0x61eb0332,0x3eadab0a,0x69ceab0b}},	//   عربي, állí, guet_, kebe,
   {{0x4426ab0c,0x69ceab0d,0xa3e800ab,0x7bc49d1d}},	//   lio_, jebe, बाक_, _abiu,
   {{0x7ae4ab0e,0x26d200e9,0x7c26ab0f,0x934300af}},	//   _arit, hwyo_, fikr, _анӂе,
   {{0x1beb20d8,0x69dc3958,0x7995023c,0xf3f90139}},	//   टाइल_, edre, wazw, _piţi_,
   {{0xdfcf21a0,0x7ae4ab10,0x7c2f009e,0x79950848}},	//   _دين_, _crit, rncr, tazw,
   {{0x4426ab11,0x7ae4ab12,0x69ce09b0,0x69dcab13}},	//   hio_, _drit, gebe, gdre,
   {{0x7ae4ab14,0x4426ab15,0x442fab16,0xdcfa00ea}},	//   _erit, kio_, yng_, ratē,
   {{0x7ae4362b,0x44269e68,0x236905e2,0x67d4ab17}},	//   _frit, jio_, žaji_, лосу,
   {{0x44261651,0x7ae42deb,0x2bc1ab18,0xfbc100b4}},	// [c6b0] dio_, _grit, ष्णा, ष्णम,
   {{0x69ce0370,0x442f0297,0x35b41286,0x7bcfab19}},	//   cebe, wng_, лбур, lecu,
   {{0x4426ab1a,0xdcf80029,0x442f0159,0x629b07e5}},	//   fio_, _ievē, tng_, _svuo,
   {{0xf1d9114e,0x7ae403ad,0x7bddab1b,0xe7fb007c}},	//   _योजन, _yrit, ndsu, _एकटा_,
   {{0x6abd0a8c,0xed4602fd,0xa7fb0453,0xba3b0392}},	//   ntsf, _چپ_, _niñi, buït,
   {{0xc69200c2,0x7c2602d0,0x442f010d,0x62990051}},	//   _דאך_, zikr, sng_, rswo,
   {{0x6299ab1c,0x6280005f,0x442f0159,0x8c3d00d0}},	//   sswo, _etmo, png_, luğu,
   {{0x44260152,0x69ceab1d,0x80a207b5,0xa2d50066}},	//   cio_, zebe, _गिरे, _मैथ्,
   {{0x69dc0a8a,0x7bcfab1e,0x53341f39,0x2fcd0051}},	//   ydre, decu, _бетт, reeg_,
   {{0x2fcd01a9,0x7ae400da,0x7d090202,0x3ead6baa}},	//   seeg_, _rrit, дног_, ruet_,
   {{0x6d4a02c7,0x7ae400d8,0x7c2600d8,0xa2d509b8}},	//   _cyfa, _srit, tikr, _मैत्,
   {{0x6abdab1f,0x69ceab20,0x09ca1e18,0xab2a2327}},	//   ftsf, webe, ाज्य, дома_,
   {{0x69ceab21,0x7c26ab22,0x3ead5a85,0x139a016b}},	//   tebe, rikr, quet_, וברע,
   {{0x4426ab23,0x8c3d036a,0xbea21ec2,0x7c268cbe}},	//   zio_, duğu, _ташк, sikr,
   {{0x69ce1642,0x7ae40052,0x6d4a0297,0x69dc3fab}},	//   rebe, _writ, _gyfa, rdre,
   {{0x69ceab24,0xea0100e8,0x4426ab25,0x386bab26}},	//   sebe, _đất_, xio_, _cicr_,
   {{0x4426ab27,0xcf9200c2,0x7c24ab28,0x78bc103a}},	// [c6c0] vio_, יטן_, _imir, strv,
   {{0x4426001e,0x00000000,0x00000000,0x00000000}},	//   wio_, --, --, --,
   {{0x442615b7,0x00000000,0x00000000,0x00000000}},	//   tio_, --, --, --,
   {{0x03a60f88,0x64a3010b,0x8c3d01fb,0x00000000}},	//   тидо, раца, buğu, --,
   {{0xc7b302da,0x3860ab29,0x7c24007a,0x8c3d027d}},	//   _דבר_, mmir_, _mmir, cuğu,
   {{0x4426ab2a,0xa248132d,0x38600095,0xa1582313}},	//   sio_, ریال_, lmir_, налу_,
   {{0xa7fb01ed,0xa3dd0630,0x00000000,0x00000000}},	//   _siñi, _थोक_, --, --,
   {{0x4fd40423,0x4fc61c6b,0x7bcf0160,0x9f5d0118}},	//   ужит, тска, xecu, _kowè_,
   {{0x4424ab2b,0x09aa0083,0xdb06018d,0x00000000}},	//   _imm_, খ্যা, ngkä, --,
   {{0x7c24ab2c,0x602702e9,0x5fae00a1,0xacf8002d}},	//   _amir, _pèmè, _टाकल, еноу_,
   {{0x44240a4e,0x6f1d0098,0x2c7a013a,0x00000000}},	//   _kmm_, úscr, _bīda_, --,
   {{0xa3e80311,0x6abd0e6c,0xfde200b4,0xc0060279}},	//   बाट_, ttsf, _कोरस_, _шпек,
   {{0x7bcf00af,0x7c24007a,0x7a29010b,0x7bddab2d}},	//   recu, _dmir, ežta, rdsu,
   {{0x7c24ab2e,0x7bcfab2f,0x6abd039b,0xfcaa00b5}},	//   _emir, secu, rtsf, _قابو_,
   {{0xb4d11b8f,0x7bcf2dd3,0xef19004e,0x4424035f}},	//   _वने_, pecu, daży_, _omm_,
   {{0x3d0e018d,0x6e2800cd,0x2ee6023a,0x36d56c06}},	//   ानीं_, lidb, _krof_, лобр,
   {{0x67d4021d,0x291e1529,0x00000000,0x00000000}},	// [c6d0] шоту, útar_, --, --,
   {{0xa5670416,0x80b80083,0x6e28011c,0xf5954d1e}},	//   ندان, _আনন্, nidb, الاج,
   {{0xd3710ad9,0xdb0dab30,0x00000000,0x00000000}},	//   مها_, _ibañ, --, --,
   {{0x44240210,0x76400093,0xfbdf0132,0x60150355}},	//   _cmm_, _ímyn, ndê_, _káme,
   {{0x59c0065f,0xeabf07e5,0xa3e80534,0x00000000}},	//   श्वर, ntù_, बाज_, --,
   {{0x26d900c9,0x2fc6010d,0x2002ab31,0xddc30395}},	//   _isso_, _abog_, ökin_, _minţ,
   {{0x0467629e,0x74f700b5,0xfbab0033,0x00000000}},	//   _атам, _جہاز_, গ্যত, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f54093c,0xfe450370,0x601501ba,0x9f5d00bf}},	//   итьс, лнио, _náme, _kowé_,
   {{0x7c240d77,0xaded004e,0x8ca4073f,0x645b009e}},	//   _smir, जाइन_, _किशो, _hhui,
   {{0x2ee6099e,0x3860ab32,0xd00e0105,0x00000000}},	//   _erof_, ymir_, زلی_, --,
   {{0x23690496,0x6e950183,0x26d9449f,0x00000000}},	//   žaju_, _биду, _osso_, --,
   {{0x645b148b,0x8f9a0122,0xbea50fc5,0x00000000}},	//   _mhui, _ניסי, _салк, --,
   {{0x2fc60537,0xddc300af,0xad24042c,0x00000000}},	//   _zbog_, _dinţ, اریو, --,
   {{0x2fdd01a9,0x07a60cb5,0x38607dda,0xc7a617c8}},	//   _kawg_, лавн, tmir_, ливк,
   {{0x7c240496,0x2fdf011e,0x200d8d3e,0x26cb00f6}},	//   _umir, ndug_, nkei_, _bpco_,
   {{0x3860ab33,0x601502d7,0x6f09ab34,0xdc3b016b}},	// [c6e0] rmir_, _gáme, nyec, _רעפר,
   {{0x6b969fd4,0x244e00ac,0x00000000,0x00000000}},	//   _heyg, mými_, --, --,
   {{0x645b111c,0x26d902fb,0x6015024e,0x200dab35}},	//   _bhui, _esso_, _záme, kkei_,
   {{0x645b41f0,0x69deab36,0xaaa80380,0x290a010b}},	//   _chui, _hape, _कटाक, myba_,
   {{0x645b1093,0x244e05d3,0x14170037,0x2fdf0090}},	//   _dhui, nými_, دينة_, ddug_,
   {{0x27e0ab37,0x69deab38,0xa3e4111e,0x601501ef}},	//   ldin_, _jape, _भोर_, _námb,
   {{0x69deab39,0x645b0094,0x2fdd01e8,0x6e28011c}},	//   _mape, _fhui, _bawg_, vidb,
   {{0x27e0ab3a,0x69deab3b,0x244e024e,0x645b19fd}},	//   ndin_, _lape, kými_, _ghui,
   {{0x26c0ab3c,0xa06703fa,0x27e0ab3d,0x60e000c7}},	//   ntio_, ћања_, idin_, _žymė,
   {{0x69deab3e,0x601525ed,0x290a010b,0x27e000c3}},	//   _nape, _ráme, kyba_, hdin_,
   {{0x85f700c2,0x765c00e9,0x6b96ab3f,0xd5c61bc6}},	//   אציע_, _mhry, _beyg, र्यज,
   {{0x290a010b,0x2ee00009,0x60daa1cf,0x31570070}},	//   dyba_, _šifu_, _istm, _גיבן_,
   {{0x27e04a92,0x34d100c0,0x69de42b2,0x6f1b0035}},	//   ddin_, _सन्द, _bape, czuc,
   {{0xeabf0382,0x2fdd006d,0x27e0ab40,0x00000000}},	//   rtù_, _zawg_, edin_, --,
   {{0x2fdd0189,0x69de012f,0x7d7b0070,0x4d7b00a5}},	//   _yawg_, _dape, _אנוו, _ארוע,
   {{0x6d589bb7,0x6c83004f,0xf7730180,0x6015002a}},	//   _izva, _اليم, صار_, _táme,
   {{0x69de0279,0x7bdf0036,0x0a6b3466,0x645b009e}},	// [c6f0] _fape, _iaqu, _прои_, _rhui,
   {{0x6449ab41,0x645b009c,0x60da00ab,0xddc30009}},	//   _skei, _shui, _ostm, _kinš,
   {{0x645b00f1,0x6f1b0036,0xfba904bc,0x26c00421}},	//   _phui, zzuc, _कयाम, atio_,
   {{0xd564365f,0x69deab42,0x7bdfab43,0x1e0104eb}},	//   ступ, _zape, _jaqu, _लक्ष_,
   {{0x0cd10380,0x2fdd006d,0x04f50033,0x69de1413}},	//   _तन्म, _rawg_, চনের_, _yape,
   {{0x7bdf0248,0x6d582e6f,0xa7fb02d7,0x69deab44}},	//   _laqu, _ozva, _viñu, _xape,
   {{0x645bab45,0x3d0e004e,0x2fdd0189,0x80151578}},	//   _thui, ानों_, _pawg_, ифиц,
   {{0x3ebf7e68,0x7bdf0bc8,0x2fdd006d,0x645b0b4f}},	//   ttut_, _naqu, _qawg_, _uhui,
   {{0xddcb0080,0xee390374,0xcdf5021f,0xf1a771f4}},	//   _augš, кни_, ачны, _брен,
   {{0x3ebfab46,0x244e0076,0x6f1b0035,0x200d1877}},	//   rtut_, vými_, rzuc, skei_,
   {{0xd131004f,0x2fdd006f,0x22476753,0x6b96027d}},	//   _بما_, _tawg_, monk_, _peyg,
   {{0x69deab47,0x8c465e04,0x244e0187,0x7bdf0d9b}},	//   _sape, реме, tými_, _caqu,
   {{0x7bdf0bc8,0x63a40079,0x3f8d0c6f,0xddc30a09}},	//   _daqu, óini, mbeu_, _einš,
   {{0xc3320052,0x7bdf0069,0x244eab48,0x290a00d8}},	//   קום_, _eaqu, rými_, tyba_,
   {{0x69deab49,0x245c0187,0x7796052c,0x98a35fed}},	//   _vape, líme_, ијац, жисе,
   {{0x69de774e,0x6ca40df3,0x290a010b,0x27e07d08}},	//   _wape, _اصول, ryba_, udin_,
   {{0x18672846,0x27e0ab4a,0xdce10092,0xd7077f02}},	// [c700] рати_, rdin_, malı, анте_,
   {{0xe6174a6e,0x26c0ab4b,0xe5a6002d,0x63bb0371}},	//   аду_, rtio_, рижи, _acun,
   {{0x26c0ab4c,0x224702e9,0x3ead8621,0xb4c20f9c}},	//   stio_, donk_, hret_, ्बे_,
   {{0x3ead5c4d,0x7bdf002a,0xdce10644,0x27e00024}},	//   kret_, _xaqu, nalı, qdin_,
   {{0x3ead054e,0xdc370070,0x62663741,0x765c016e}},	//   jret_, סאנט_, авда, _thry,
   {{0x5bd30c57,0x2cac001e,0x245c0237,0xbbd3084b}},	//   _तस्व, yrdd_, díme_, _तस्क,
   {{0x64a34baf,0xd12f017e,0x3eadab4d,0xdce100d0}},	//   _мара, ومه_, eret_, kalı,
   {{0x6015053d,0x04430948,0x6d5c05ee,0x63bb0079}},	//   _rámc, _десн, ýram, _gcun,
   {{0x7bdf2a31,0x3ead00d4,0xdefa0f78,0x2cac001e}},	//   _raqu, gret_, тый_, wrdd_,
   {{0x7bdf04a5,0x59b20f19,0xb607009f,0x3e7b099e}},	//   _saqu, _जागर, _gaġġ, _dêt_,
   {{0x60da00d7,0xfc4000b8,0x057700a5,0xa17b100a}},	//   _ustm, čín_, יגים_, _סטאט,
   {{0x245c0187,0x3eadab4e,0xdcfa00ea,0x1b1f0831}},	//   bíme_, bret_, latī, _যুগে_,
   {{0x799c0297,0x00000000,0x00000000,0x00000000}},	//   farw, --, --, --,
   {{0x799cab4f,0x5a4701f1,0x5d840037,0xdcea009f}},	//   garw, рэма, _الغل, _nefħ,
   {{0x6d580029,0xb4c2319c,0x6e3d00b5,0x60150093}},	//   _uzva, ्बो_, ésbe, _háma,
   {{0xdce1027b,0x20d80019,0x601500d5,0x00000000}},	//   calı, _mũi_, _káma, --,
   {{0x799cab50,0x6b9dab51,0xdcfa00ea,0xb8fe23db}},	// [c710] barw, masg, katī, _दै_,
   {{0xb8dd0083,0x63bb0139,0x35f4002d,0x79a7511b}},	//   _ইন_, _scun, опур, _трие,
   {{0x69d5ab52,0x245c01c0,0x92d60083,0x6015063c}},	//   meze, zíme_, িমো_, _láma,
   {{0x3eadab53,0x25fb0907,0x6b9d00ea,0x225e0065}},	//   yret_, लॉजी_, nasg, _ahtk_,
   {{0xd24e05f5,0x1708006c,0x60150097,0xb6070069}},	//   کنو_, _پہلی_, _náma, _paġġ,
   {{0x245c0187,0x40951578,0x3ead3e80,0x0cb60066}},	//   víme_, брит, vret_, _अमूम,
   {{0xdce1037a,0x6b9dab54,0x22470b88,0x20d800e2}},	//   yalı, kasg, ronk_, _cũi_,
   {{0x69d5ab55,0x89380122,0x245c0097,0x293800a5}},	//   heze, ירוע_, tíme_, יאון_,
   {{0x60150f56,0x69d5006c,0x799c08c6,0xe1f30206}},	//   _cáma, keze, yarw, _وسط_,
   {{0x69d500b5,0x245c01ba,0xab5b02b1,0x3ead0b73}},	//   jeze, ríme_, rfül, rret_,
   {{0xeb9a5454,0x9d45010b,0x69d56bb4,0x245c053d}},	//   лин_, сенд, deze, síme_,
   {{0x61e1ab56,0x799c04c6,0x32053b19,0x3eadab57}},	//   _hall, warw, _holy_, pret_,
   {{0x61e1ab58,0x1ee704e8,0xdce100d0,0x8e85ab59}},	//   _kall, _خوشی_, ralı, _الته,
   {{0x61e1ab5a,0x32051786,0x81a90033,0x7d1000b5}},	//   _jall, _joly_, গ্র_, öksé,
   {{0x61e1ab5b,0x16d00084,0xfbdf0370,0x799c01d5}},	//   _mall, हब्ब, glês_, rarw,
   {{0x600e01a6,0x69c70051,0x7b070055,0x00000000}},	//   _cùmh, afje, ërtë, --,
   {{0x69d5ab5c,0x3f7a0070,0x799c00d1,0x600e01da}},	// [c720] beze, אָבע, parw, _dùmh,
   {{0x61e1ab5d,0xc1e10d41,0x00000000,0x00000000}},	//   _nall, पयोग, --, --,
   {{0xd91007e4,0xdcfa02d4,0xd05a013b,0x628b01bf}},	//   _غیر_, vatī, _ertə, epgo,
   {{0x61e1ab5e,0xad3602b5,0xdb1d006c,0xdb0d00ab}},	//   _aall, זנעס_, yesü, _ebaõ,
   {{0x6a6002c9,0xdcfa00ea,0x320500ee,0xe80d00b4}},	//   röff, tatī, _boly_, _िकता_,
   {{0x61e1ab5f,0x00000000,0x00000000,0x00000000}},	//   _call, --, --, --,
   {{0x3205007e,0x61e1ab60,0x859b0122,0x601501ef}},	//   _doly_, _dall, _תשלו, _sáma,
   {{0x61e19175,0x68e1221b,0x69d5ab61,0xdb1d00b5}},	//   _eall, ældi, zeze, tesü,
   {{0x69d518f4,0xdcfa00ea,0x00000000,0x00000000}},	//   yeze, patī, --, --,
   {{0x61e11f06,0x6ce30f8a,0xc27b011d,0x2d9800a0}},	//   _gall, गिंग_, _ערבי, úre_,
   {{0x69d5006c,0xab5b0531,0x50dc0577,0x20e70207}},	//   veze, rfüm, _मनिष, _gđi_,
   {{0x69d5ab62,0x61e1ab63,0xdb04002a,0x601500b5}},	//   weze, _zall, _aciñ, _táma,
   {{0x69d5ab64,0x6b9d40c2,0x7ae20009,0x61e14582}},	//   teze, rasg, _šotr, _yall,
   {{0x7f3b0070,0x61e1ab65,0x6b840183,0x20061192}},	//   _געדו, _xall, _efig, _hooi_,
   {{0x69d5ab66,0x5d9b0122,0x2d9eab67,0x27e2012f}},	//   reze, _גבוה, mate_, _bakn_,
   {{0xb9010c3e,0x69d5ab68,0x2d9eab69,0xfc650919}},	//   _धन_, seze, late_, _بختی,
   {{0x20060903,0x7c2fab6a,0x69d5ab6b,0xdb1dab6c}},	// [c730] _mooi_, micr, peze, resó,
   {{0x7aedab6d,0xdb0402c9,0x2d9eab6e,0x7c2f24ab}},	//   _irat, _heiß, nate_, licr,
   {{0x4d7b02b5,0xe4d506ca,0x93792aff,0x320500ee}},	//   ארבע, تقاد, абет_, _roly_,
   {{0x61e1ab6f,0x4cbb02b5,0x7c2f002a,0x2006053e}},	//   _sall, רמאג, nicr, _nooi_,
   {{0x81e20083,0x7bcd00e0,0x32050cdb,0xdb0402b1}},	//   ধান_, _mbau, _poly_, _meiß,
   {{0x2d9eab70,0x61e12b72,0x7aed2126,0x20c100b5}},	//   jate_, _qall, _mrat, tói_,
   {{0x61e1ab71,0xdcf80228,0x60190200,0x00000000}},	//   _vall, _devī, ицир_, --,
   {{0x7aedab72,0x20c146bb,0x61e1ab73,0x60093cee}},	//   _orat, rói_, _wall, рним_,
   {{0x61e1ab74,0xd5c60567,0x442fab75,0x6607006d}},	//   _tall, र्वज, mig_, _kojk,
   {{0x2d9eab76,0x442fab77,0x61e101a6,0xfc400187}},	//   gate_, lig_, _uall, čím_,
   {{0x63a400fb,0x7aedab78,0x6d4601d6,0x6607ab79}},	//   ðing, _arat, şkan, _mojk,
   {{0x7aed1deb,0x200611ad,0xae1d31d7,0x644bab7a}},	//   _brat, _gooi_, योजन_, nogi,
   {{0x2d9eab7b,0xab5b01ae,0x6da509cc,0x387a3c56}},	//   bate_, nfüh, _дила, _supr_,
   {{0x2d9eab7c,0x2d81007c,0xe81c0d00,0x442fab7d}},	//   cate_, _ühe_, नसभा_, hig_,
   {{0x63a9054e,0xa3b92e4f,0x442fab7e,0x7aedab7f}},	//   _oden, चला_, kig_, _erat,
   {{0x7aedab80,0x63a9ab81,0x442fab82,0x3ff90070}},	//   _frat, _nden, jig_, ספּע,
   {{0x442fab83,0xa3e400c4,0x644b001e,0x245c01ba}},	// [c740] dig_, _भोग_, dogi, jíma_,
   {{0x442f0392,0x00000000,0x00000000,0x00000000}},	//   eig_, --, --, --,
   {{0x442fab84,0x66071cc4,0x63a90009,0x2bc148cd}},	//   fig_, _dojk, _bden, ष्का,
   {{0x442fab85,0x2d9eab86,0x63a90051,0xab5b02b1}},	//   gig_, zate_, _cden, ffüh,
   {{0x2d9eab87,0x6aa80722,0x20060173,0x63a922a4}},	//   yate_, _कटोर, _rooi_, _dden,
   {{0xaab20953,0x63a9ab88,0x2d9e4031,0xfe6718dd}},	//   _जिनक, _eden, xate_, _زد_,
   {{0x442f03a2,0x2d9eab89,0xd01a18cd,0x644b6ef7}},	//   big_, vate_, ифи_, bogi,
   {{0x63a40093,0x644b0831,0x442f02c4,0xa2d50035}},	//   ðind, cogi, cig_, _मैक्,
   {{0x2d9eab8a,0x81cf0083,0x601c006c,0xdb04033b}},	//   tate_, ষয়_, _néme, _reiß,
   {{0x63a91075,0x70f60180,0x273700e2,0x7aed0055}},	//   _zden, _وسائ, ầng_, _rrat,
   {{0x2d9eab8b,0x7aed00f1,0xdca303e6,0xeb130d1f}},	//   rate_, _srat, маќи, डन्त_,
   {{0x2d9eab8c,0x00000000,0x00000000,0x00000000}},	//   sate_, --, --, --,
   {{0x1069004f,0x60150bca,0xaf360833,0x7aedab8d}},	//   _احلى_, _zámo, _برات, _qrat,
   {{0x7aed0496,0x442f0a75,0xdb0401ae,0x7c2fab8e}},	//   _vrat, zig_, _weiß, sicr,
   {{0x69c30723,0x644bab8f,0x442fab90,0x660700d5}},	//   _önem, yogi, yig_, _rojk,
   {{0x442fab91,0x9f4f0176,0x3ea62825,0x2d9c0044}},	//   xig_, _gogó_, _kvot_, _heve_,
   {{0x7c2d3d76,0x442fab92,0x6607ab93,0xda670079}},	// [c750] _imar, vig_, _pojk, _واخي,
   {{0x442fab94,0x644b00e9,0x2d9c5010,0xe29f008d}},	//   wig_, wogi, _jeve_, _æði_,
   {{0x442f2a3a,0x644b11fc,0x628900f1,0x660703c9}},	//   tig_, togi, _steo, _vojk,
   {{0x2d9cab95,0x245c008a,0x601c76b5,0xab5b033b}},	//   _leve_, tíma_, _lémb, tfüh,
   {{0x38690533,0x442fab96,0x7c2dab97,0x24581a0e}},	//   mmar_, rig_, _mmar, цаць_,
   {{0x442fab98,0x2d9cab99,0x386903c1,0xab5b01ae}},	//   sig_, _neve_, lmar_, rfüh,
   {{0xb882114d,0xe4a410e3,0x442fab9a,0xab5b02c9}},	//   žíva, _орто, pig_, sfüh,
   {{0x63a9054e,0x20193c0e,0xfc400bca,0x3eab02d7}},	//   _uden, ósi_, čík_, ácto_,
   {{0x442dab9b,0x2d9c027a,0x6d46027d,0x443f0b5b}},	//   _ime_, _beve_, şkal, _iju_,
   {{0x7c2dab9c,0x8c0800c8,0x60150332,0x443f0009}},	//   _amar, _লগইন_, _támo, _hju_,
   {{0x2d9c01b8,0x442d08dd,0x443f4a8a,0x386900d7}},	//   _deve_, _kme_, _kju_, kmar_,
   {{0xca2901f3,0x38690009,0x442d4b96,0x7c2d0207}},	//   _גם_, jmar_, _jme_, _cmar,
   {{0x442dab9d,0x386902a7,0x2d9c4fad,0x00000000}},	//   _mme_, dmar_, _feve_, --,
   {{0x443f082d,0x7c2d1ab5,0x7e68011e,0x00000000}},	//   _lju_, _emar, cmdp, --,
   {{0xfe701c04,0x34ba04eb,0x25a1ab9e,0x8dfa00a5}},	//   _شده_, _उमेद, dahl_, _להסת,
   {{0x443f3607,0xbb4600d8,0x06860804,0x7c2d008d}},	//   _nju_, _нейк, зган, _gmar,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c760] --, --, --, --,
   {{0x442dab9f,0xa3e40e04,0x2d85aba0,0x7c2d0035}},	//   _ame_, _भोज_, ncle_, _zmar,
   {{0x7c2d001e,0x442d354f,0x443f210c,0x00000000}},	//   _ymar, _bme_, _bju_, --,
   {{0x7c2daba1,0xe45206ca,0x442daba2,0x00000000}},	//   _xmar, رضا_, _cme_, --,
   {{0x2bc120ab,0xcfc300c8,0xfbc10a90,0x201f0054}},	//   ष्टा, ্যান, ष्टम, dhui_,
   {{0x64a60eb9,0x442daba3,0x59c00b35,0xf8b01b8f}},	//   _нага, _eme_, श्चर, _जटाय,
   {{0x67240223,0x2d9caba4,0x3ea60009,0x799e0107}},	//   lzij, _reve_, _svot_, _mepw,
   {{0xd010004f,0x2d9caba5,0x2eef0176,0x93a9186e}},	//   ئلة_, _seve_, _brgf_, _واقف_,
   {{0x67242997,0x644300f7,0x044303fa,0xe2974025}},	//   nzij, énie, _четн, _нат_,
   {{0xab5b0443,0x63a2aba6,0x443f02a7,0xa2d50067}},	//   ngüe, laon, _zju_, _मैट्,
   {{0x442d012f,0x38699215,0xcfaa11c0,0x2d9c01e9}},	//   _yme_, ymar_, _هاشم_, _veve_,
   {{0x63a22789,0x25a101ae,0xbb9400c3,0x00000000}},	//   naon, zahl_, нающ, --,
   {{0x2d9c0370,0xc9050826,0x6724aba7,0x601c01cb}},	//   _teve_, रह्म_, jzij, _témb,
   {{0x6724241d,0x63a2026e,0x26000141,0x58d501e0}},	//   dzij, haon, राफी_, могт,
   {{0x26000299,0x63a2aba8,0x799e021e,0x3d220118}},	//   रानी_, kaon, _depw, _déwé_,
   {{0x7c2daba9,0x25a1033b,0x63a2abaa,0x00000000}},	//   _umar, wahl_, jaon, --,
   {{0xdce80d6f,0xf77fabab,0x443f0009,0x25a1033b}},	// [c770] madı, _caça_, _rju_, tahl_,
   {{0x442d124b,0xdce8037a,0x443f1860,0x1dcf0ed1}},	//   _sme_, ladı, _sju_, त्पत,
   {{0xf6502e36,0x7c3dabac,0x442dabad,0x2d83011c}},	//   ائق_, onsr, _pme_, žjeg_,
   {{0xd37138b7,0xf77f0370,0x63a24022,0xdce800d0}},	//   نها_, _faça_, gaon, nadı,
   {{0x27e9abae,0x2d852954,0x91e5218b,0x94740118}},	//   mdan_, ycle_, доле, ردما,
   {{0x27e91202,0xdb1d01ff,0x3f9d00f8,0x00000000}},	//   ldan_, besö, _sewu_, --,
   {{0x94d41edd,0x63a2026f,0x442d1e89,0xa4d400d4}},	//   _порц, baon, _tme_, _порі,
   {{0x27e97a43,0x63a20284,0x442d01d7,0xef190328}},	//   ndan_, caon, _ume_, жми_,
   {{0x26c9abaf,0x0e6502ee,0x27e901a3,0xdce80644}},	//   ntao_, мкин, idan_, dadı,
   {{0x27e9004a,0x64594212,0x910700af,0x7c3d0051}},	//   hdan_, llwi, _нчед, ensr,
   {{0x6724003c,0x4d6500d4,0x799e02d0,0x1d090171}},	//   zzij, ьков, _repw, цени_,
   {{0x3f1508a6,0x443d001e,0x0ea61782,0x2d85abb0}},	//   _одес, nnw_, _खिचड, scle_,
   {{0x27e9abb1,0x2600051d,0x00000000,0x00000000}},	//   ddan_, रामी_, --, --,
   {{0xf77fabab,0x9e6401e0,0xce6b2a8a,0x7c3d1472}},	//   _raça_, _звід, _уред_, ansr,
   {{0x63a2abb2,0x69cd05fc,0x601c000d,0x27e90be2}},	//   yaon, द्धी, _héma, fdan_,
   {{0x27e9157e,0x6f16006a,0x998d044d,0x1dbd364c}},	//   gdan_, _życi, đeš_, ्भवत,
   {{0x63a2abb3,0x3d1b021a,0x00000000,0x00000000}},	// [c780] vaon, मनवे_, --, --,
   {{0x672405e2,0x27e97934,0x63a2000e,0x7ae42f75}},	//   rzij, adan_, waon, _isit,
   {{0x1dcf018d,0x63a2abb4,0xd946abb5,0x9f4201ba}},	//   त्यत, taon, _цени, ľké_,
   {{0x69dc317d,0x9f420187,0xf77f0279,0x69ce11ad}},	//   lere, žké_, _taça_, lfbe,
   {{0x926a2a63,0x98170580,0x00000000,0x00000000}},	//   орка_, _آبپا, --, --,
   {{0x201d0600,0x7ae4002f,0x66210067,0x1dcf012f}},	//   _alwi_, _msit, ązkó, त्मत,
   {{0x69dcabb6,0x63a2abb7,0x64430138,0xdce800c1}},	//   iere, paon, énic, yadı,
   {{0x69dcabb8,0x7ae4abb9,0x00000000,0x00000000}},	//   here, _osit, --, --,
   {{0x69dcabba,0x6015024e,0xdb04009e,0x7ae4073a}},	//   kere, _zámk, _ndià, _nsit,
   {{0x69dcabbb,0x27e910b1,0x601c02e1,0x6015004f}},	//   jere, zdan_, _déma, _lámh,
   {{0x27e9abbc,0x45b70122,0x7ae4abbd,0x61fa05c1}},	//   ydan_, ופיל_, _asit, _intl,
   {{0x61e8abbe,0x6280792a,0x63a0024e,0x320c00ac}},	//   _hadl, _kumo, _jemn, _hody_,
   {{0x69dcabbf,0xdce801c2,0x27e9abc0,0x63a0033e}},	//   fere, radı, vdan_, _memn,
   {{0x69dcabc1,0x63a000af,0x81b00083,0x62800027}},	//   gere, _lemn, ট্র_, _mumo,
   {{0x7ae4247d,0x6280abc2,0x27e90095,0x61e8abc3}},	//   _esit, _lumo, tdan_, _madl,
   {{0xb9071033,0x69dc71b3,0x7e7803c1,0xe61000fd}},	//   _मई_, aere, _hivp, یشل_,
   {{0x69dcabc4,0x27e9abc5,0xfc3f01c0,0x61fa03c4}},	// [c790] bere, rdan_, mní_, _ontl,
   {{0x69dcabc6,0xfc3f0311,0xea010028,0x27e9abc7}},	//   cere, lní_, _đặt_, sdan_,
   {{0x26c901cc,0x27e9abc8,0x69c5abc9,0xfa340037}},	//   stao_, pdan_, _iche, _جريد,
   {{0xfc3fabca,0x27e90095,0x68e5abcb,0x6280402b}},	//   nní_, qdan_, _ishd, _bumo,
   {{0x63a0abcc,0x320c10ae,0x64592ea2,0x7ae4011e}},	//   _demn, _body_, rlwi, _xsit,
   {{0xaab2004e,0x11d90037,0x63a00051,0x7bdd436b}},	//   _जिसक, سوعة_, _eemn, hesu,
   {{0x69c50657,0xe0d1006c,0x61e874d6,0x7bddabcd}},	//   _mche, ازت_, _dadl, kesu,
   {{0x69dcabce,0x61fa01ae,0xfc3f05d3,0x68e8008d}},	//   zere, _entl, jní_, æddi,
   {{0xfc3f0311,0x7a2202e1,0x69dcabcf,0x61e80c9a}},	//   dní_, _hôte, yere, _fadl,
   {{0x6cea0fd1,0x6d580c43,0x63a01352,0x7bc40036}},	//   टिंग_, _byva, _zemn, _sciu,
   {{0x60152b83,0x69dcabd0,0x628002d7,0x82340037}},	//   _lámi, vere, _zumo, _شركا,
   {{0x69c5abd1,0x8b264234,0xeb9703ad,0x601c727e}},	//   _ache, едме, нию_, _téma,
   {{0x81e20033,0x6015abd2,0x6d58045e,0x6d5c008d}},	//   ধার_, _námi, _eyva, ýrar,
   {{0x78bc02ee,0x69dcabd3,0x69c500ee,0xf77f021d}},	//   turv, uere, _cche, _baço_,
   {{0x69dcabd4,0xfc3f000c,0x7bddabd5,0xc2120122}},	//   rere, bní_, besu, נהל_,
   {{0x69dc465f,0x7bddabd6,0x7ae4007c,0xb908018d}},	//   sere, cesu, _tsit, _यन_,
   {{0x69dcabd7,0xb9071556,0x7ae42ce7,0x78bcabd8}},	// [c7a0] pere, _मै_, _usit, surv,
   {{0x63a00012,0xf77f03e6,0xba760698,0x6280abd9}},	//   _semn, _faço_, _ثابت, _rumo,
   {{0x6280abda,0x7a2200f7,0x320c0211,0xae070035}},	//   _sumo, _côte, _rody_, _वचनन_,
   {{0x1dcf012f,0x6280abdb,0x61e8abdc,0x00000000}},	//   त्तत, _pumo, _sadl, --,
   {{0x81e900c8,0x61e8abdd,0x087702b5,0x69cd06bc}},	//   যান_, _padl, _רעכט_, द्वी,
   {{0x7bdd4bfa,0xfc3f01c0,0x7d0e01b4,0x60e61362}},	//   zesu, zní_, øbsk, ециз,
   {{0x320c0076,0xe64300d4,0x63a03e39,0x7bddabde}},	//   _vody_, _серп, _temn, yesu,
   {{0x320c004e,0xfc3f00b8,0xefb200d1,0xaa0d01c0}},	//   _wody_, xní_, ایشگ, _सक्छ_,
   {{0xfc3f0311,0xc2460f8f,0x7bdd1f50,0x660e00d5}},	//   vní_, _знак, vesu, _kobk,
   {{0x660e5056,0x00000000,0x00000000,0x00000000}},	//   _jobk, --, --, --,
   {{0xfc3f0311,0xddc3023a,0xd622010b,0xaa7b00ac}},	//   tní_, _finž, нiка, jvýr,
   {{0x637606d0,0x69c539a6,0x6d580097,0x6abd3724}},	//   _günü, _sche, _vyva, tusf,
   {{0xfc3f000c,0x7bddabdf,0x69c55483,0x601c000d}},	//   rní_, resu, _pche, _hémo,
   {{0x7bddabe0,0xfc3f01c0,0x673b02c4,0xf77f0132}},	//   sesu, sní_, _žujo, _paço_,
   {{0xfc3f033a,0x248d022f,0xa3c2021a,0x7bddabe1}},	//   pní_, _čemo_, ्भा_, pesu,
   {{0x601c5072,0x36d55da8,0x7bdd0031,0x00000000}},	//   _mémo, кобр, qesu, --,
   {{0x2bc60517,0x69c502d0,0x660e00d5,0x601c01ef}},	// [c7b0] _वाता, _tche, _bobk, _lémo,
   {{0x69c59ace,0x63a4008a,0x163b0037,0x3915199d}},	//   _uche, ðinn, أسرة_, _амор,
   {{0xe1ff00e8,0x2cbe8542,0x4420004b,0x395a0345}},	//   _đó_, nutd_, гi_, _gyps_,
   {{0x69cd051d,0x9f5f008a,0x601501ef,0x00000000}},	//   द्री, kkuð_, _támi, --,
   {{0x2bd32095,0xfbd33d0a,0x8627010b,0x00000000}},	//   ध्या, ध्यम, _зьве, --,
   {{0x1a9c02b5,0xc8820160,0x601c534f,0x00000000}},	//   לידע, _fişă_, _bémo, --,
   {{0xf1a80118,0x2ee60173,0x62860118,0x8af0013b}},	//   راوه_, _asof_, _ékon, _ayəl,
   {{0x601c5015,0x8f751645,0x25a300fe,0x7f7501e0}},	//   _démo, купі, _hejl_, купц,
   {{0xdb0d148e,0x81d60033,0xd00e0098,0x25a3035f}},	//   _ocañ, িয়_, تلي_, _kejl_,
   {{0x273e0028,0xee36004b,0x25a30009,0x6b8dabe2}},	//   ắng_, кны_, _jejl_, _afag,
   {{0x9d4502c4,0x25a3abe3,0x2ee60176,0x2bc60099}},	//   тенд, _mejl_, _esof_, _वादा,
   {{0x3de10033,0x27eb009e,0x25a3035f,0x2a7a0107}},	//   বাইল, _nacn_, _lejl_, _sipb_,
   {{0x8af00250,0xdb060055,0x00000000,0x00000000}},	//   _azər, makë, --, --,
   {{0x3ebf012f,0xa96a2399,0xe3d50033,0xddc3035f}},	//   muut_, дига_, _সোমব, _jinż,
   {{0xe9a30089,0x3ebf11cc,0x5e5600b5,0x2600051d}},	//   расп, luut_, _جلوس_, रासी_,
   {{0xf7722086,0x200f006c,0x684326cf,0xab5b4fb1}},	//   لاء_, _jogi_, анса, rfür,
   {{0xe737657c,0x200f0279,0x3ebf03c4,0x7bd60010}},	// [c7c0] вет_, _mogi_, nuut_, _ibyu,
   {{0x200fabe4,0x64432eef,0xdb040132,0x25a300fe}},	//   _logi_, énin, _adiç, _cejl_,
   {{0x25a30009,0x68461f39,0x27eb0107,0xab5b3a5b}},	//   _dejl_, _анна, _facn_, ngün,
   {{0xb4d2004e,0x7af61298,0x200f6d53,0x68e8008d}},	//   _वही_, _kryt, _nogi_, æddu,
   {{0x27e0abe5,0x25a3054e,0x245c00b8,0x7bd6007b}},	//   mein_, _fejl_, ními_, _mbyu,
   {{0x27e0abe6,0xdb040370,0x80db00c8,0x2fc6046a}},	//   lein_, _ediç, ভিন্, _scog_,
   {{0x64a6abe7,0xa0a3005f,0x40341129,0x29189cde}},	//   _шава, ашыл, лекс, nyra_,
   {{0xaab200a1,0x27e0abe8,0x200f02d7,0x601c01ef}},	//   _जिंक, nein_, _cogi_, _vémo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4426051b,0x7c860e75,0x601c8337,0x27e0033b}},	//   lho_, куме, _témo, hein_,
   {{0x27e00086,0x9e030409,0x29180031,0x55bb00a5}},	//   kein_, рчыл, jyra_, ומיו,
   {{0x4426051b,0x64420086,0x7af6abe9,0x200f13a6}},	//   nho_, nnoi, _bryt, _gogi_,
   {{0x34df16f5,0x27e00211,0x3fcb04e8,0x41c92075}},	//   _नन्द, dein_, _آدمی_, _रामस,
   {{0x3eb9016f,0x7bd6018e,0x7af62a02,0x00000000}},	//   áste_, _ebyu, _dryt, --,
   {{0x4426abea,0x195810b0,0x64427b8d,0x59d20b35}},	//   kho_, вары_, knoi, द्धर,
   {{0x4426016f,0xe7ed007c,0x27e0abeb,0x7c26033b}},	//   jho_, _चोखा_, gein_, chkr,
   {{0x442600d1,0x26c0010d,0x7af601ff,0x245c0314}},	// [c7d0] dho_, guio_, _gryt, cími_,
   {{0xcfeb0083,0x2fdf02c9,0x4426016f,0x8b5800a5}},	//   কায়_, zeug_, eho_, _ביחס_,
   {{0x27e0abec,0xf96b5024,0x9f4f017b,0x00000000}},	//   bein_, _юрий_, _ingå_, --,
   {{0x4426026f,0x644200f7,0x00000000,0x00000000}},	//   gho_, gnoi, --, --,
   {{0x1dc20325,0x200fabed,0xab5b048f,0x674600a0}},	//   _शांत, _rogi_, zgün, čujú,
   {{0x78ba0a78,0x216938d0,0x00000000,0x00000000}},	//   štve, нили_, --, --,
   {{0x205500b6,0x4426009e,0x200f067f,0x26001782}},	//   лтир, bho_, _pogi_, रारी_,
   {{0x4426abee,0x63ad008a,0x3ebfabef,0x644201ef}},	//   cho_, ðand, tuut_, cnoi,
   {{0x69d71a71,0xdb060031,0x00000000,0x00000000}},	//   _obxe, rakë, --, --,
   {{0x27e006a2,0x7d0903fa,0x2c7b004b,0x00000000}},	//   zein_, еног_, _būdo_, --,
   {{0x7fd51bda,0x6cc500d8,0x61130355,0x06cf0033}},	//   _білі, ыйна, _dělá, রিটি,
   {{0x2d8e727d,0x9ef50037,0xab5babf0,0x245cabf1}},	//   _effe_, _مستش, rgün, tími_,
   {{0x765e00fe,0x00000000,0x00000000,0x00000000}},	//   ylpy, --, --, --,
   {{0x291801f4,0x7c2601f4,0x3ead2a4d,0x27e00110}},	//   tyra_, shkr, mset_, wein_,
   {{0x44260187,0x3eadabf2,0x291eabf3,0x245c008d}},	//   yho_, lset_, áta_, sími_,
   {{0x1dcf112b,0x3f8dabf4,0x7a340095,0x44260031}},	//   त्रत, nceu_, _mütə, xho_,
   {{0x291e0496,0x7c247f71,0x1db73100,0x27e0abf5}},	// [c7e0] šta_, _ilir, _आयात, rein_,
   {{0x27e0abf6,0x4426abf7,0x3ead0086,0xdb0640c8}},	//   sein_, who_, iset_, jaké,
   {{0x4426abf8,0xe3ba0274,0x37b00033,0x7c24abf9}},	//   tho_, ебе_, ঙ্গর, _klir,
   {{0x7bc62b63,0x3ead0d36,0x69c301d6,0x442600b8}},	//   ngku, kset_, _öner, uho_,
   {{0x4426abfa,0xf7720148,0x6442abfb,0x3860abfc}},	//   rho_, _داد_, rnoi, mlir_,
   {{0x44262067,0x3860abfd,0x7c241628,0xab5b033b}},	//   sho_, llir_, _llir, dgül,
   {{0x6015008a,0x44260fb2,0x2559002d,0x7c24001c}},	//   _náms, pho_, _артэ_, _olir,
   {{0x4fc699c3,0x44260189,0xb4fb0d85,0x321c00ac}},	//   уска, qho_, _אפלי, skvy_,
   {{0x4424007c,0x741303c7,0x670406bc,0xa3d100b4}},	//   _ilm_, _اوقا, रमिक_, वभर_,
   {{0x7c2450a2,0x4424abfe,0x7c360107,0x3cd4010b}},	//   _alir, _hlm_, _amyr, ажос,
   {{0x3860abff,0xd6570122,0x7c24009e,0x00000000}},	//   klir_, ריית_, _blir, --,
   {{0x6015024e,0x7c24ac00,0x00000000,0x00000000}},	//   _dáms, _clir, --, --,
   {{0x2bc60d2a,0x00000000,0x00000000,0x00000000}},	//   _वारा, --, --, --,
   {{0xa2cc0567,0x442400d7,0x7c2405f5,0x7c360409}},	//   _समन्, _llm_, _elir, _emyr,
   {{0x7c24ac01,0xbd5500bf,0x1959057a,0x00000000}},	//   _flir, _پروژ, тавы_, --,
   {{0x6e3aac02,0xb8ed0026,0x6d46027d,0x60153536}},	//   litb, _रम_, şkas, _hámr,
   {{0xd5bb2f82,0x9635ac03,0x245c0355,0x00000000}},	// [c7f0] есе_, анац, nímu_, --,
   {{0x4424ac04,0x00000000,0x00000000,0x00000000}},	//   _alm_, --, --, --,
   {{0x3860ac05,0x4424012f,0xb867006c,0x67d52987}},	//   blir_, _blm_, _ماحو, _кону,
   {{0x69c70044,0x14741301,0x3ead0dba,0x00000000}},	//   lgje, مانج, yset_, --,
   {{0x44240034,0x81e90083,0x81ae0033,0x9f46026e}},	//   _dlm_, যাস_, কলন_, _baoí_,
   {{0xd05a0669,0x44240095,0x69c7ac06,0x44e5001e}},	//   _istə, _elm_, ngje, _tŷ_,
   {{0x6e3aac07,0x4424ac08,0x2bf50066,0x00000000}},	//   ditb, _flm_, इयां_, --,
   {{0xe3b30071,0x3eadac09,0x4439ac0a,0xa3c2012f}},	//   _درس_, tset_, _ös_, ्भः_,
   {{0x533513a1,0x3f8dac0b,0x600610b0,0x6e3a008c}},	//   _теат, rceu_, рным_, fitb,
   {{0x63abac0c,0x3f8d03e6,0x7c3660d4,0x765700f6}},	//   lagn, sceu_, _smyr, noxy,
   {{0x3ead1e54,0xeb9a05f4,0x61e3ac0d,0xcb0902b8}},	//   sset_, кин_, menl, _קל_,
   {{0x61e39360,0x60c301dd,0x69c70051,0x63ab1292}},	//   lenl, munm, egje, nagn,
   {{0xbea5ac0e,0x20d101a5,0x60c3008f,0x501a0122}},	//   _талк, _hơi_, lunm, _שונו,
   {{0x672da435,0x7a2b1707,0x61e35989,0x8d872659}},	//   dzaj, _lütf, nenl, _судд,
   {{0x6d460be2,0x98a60036,0x63ab0cca,0x26093e6d}},	//   şkar, рибе, kagn, सानी_,
   {{0x63ab0254,0x7c2449d2,0x61e3033b,0xa3d70066}},	//   jagn, _ulir, henl, ़्म_,

   {{0x63ab02fb,0x6f1b0ac8,0x61e3ac0f,0x6b8484db}},	// [c800] dagn, nyuc, kenl, _igig,
   {{0x6306026b,0x645bac10,0x63ab681f,0x44248ecd}},	//   یوال, _akui, eagn, _slm_,
   {{0x20d10028,0x61e3ac11,0x38600310,0xb38601f1}},	//   _nơi_, denl, plir_, алел,
   {{0xe29a2214,0x63abac12,0x6aa401d5,0x59d20d60}},	//   вад_, gagn, _kwif, द्रर,
   {{0x998300d8,0xf1940086,0x672d004e,0x6b840159}},	//   cijų_, биль, czaj, _mgig,
   {{0x61e3ac13,0x20d10019,0x645b36ee,0x42562123}},	//   genl, _bơi_, _ekui, штет,
   {{0x63abac14,0x03a602ce,0x4424009e,0x15432bfc}},	//   bagn, _вибо, _tlm_, _дерм,
   {{0x3f8203d0,0xdfda01d3,0xdb0b01d6,0x27f26c21}},	//   øku_, тък_, _çiçe, ndyn_,
   {{0xe61f0019,0x61e3ac15,0xd47b00a5,0xde8800cc}},	//   _muôn_, benl, _יאלל, _bịa_,
   {{0xe61f0028,0x20d602ce,0x260906d9,0x394d027d}},	//   _luôn_, _відс, सायी_, şesi_,
   {{0x6e3aa4e0,0x6493007a,0x691e0024,0xac19291c}},	//   ritb, _għid, _jħeġ, гону_,
   {{0xa3a90084,0xdfd00079,0x6f090042,0x6aa4007b}},	//   _खड़ा_, _ريت_, bxec, _bwif,
   {{0x6e940082,0x7b674a82,0x27f20297,0x81e900c8}},	//   _التا, ртне, ddyn_, যার_,
   {{0x6b84ac16,0xdd9100b5,0x00000000,0x00000000}},	//   _egig, _ٹوٹ_, --, --,
   {{0x69c7ac17,0x97a7095d,0xe61f01a5,0x63abac18}},	//   rgje, ирал, _buôn_, yagn,
   {{0x61e30723,0x6b840103,0x5d7b011d,0xc2ff0033}},	//   zenl, _ggig, _באוק, ্নতি_,
   {{0xf77301ca,0x63abac19,0x61e3ac1a,0x7657596e}},	// [c810] زار_, vagn, yenl, toxy,
   {{0x6015ac1b,0x7aed3499,0x60c3ac1c,0x645b0173}},	//   _lámp, _isat, yunm, _skui,
   {{0x63abac1d,0x9983010b,0x672d0035,0x7657123d}},	//   tagn, sijų_, szaj, roxy,
   {{0x20d101a5,0x601c0248,0x7aed16ab,0x4d790070}},	//   _rơi_, _fémi, _ksat, אָנא,
   {{0x61e3ac1e,0xadf802cb,0x63ab6ccb,0x7bcdac1f}},	//   tenl, ्ञान_, ragn, _mcau,
   {{0x63abac20,0x7c3d011e,0x2ff800b5,0x7aed034d}},	//   sagn, hisr, یڈنگ_, _msat,
   {{0x26090429,0x63ab02e1,0x61e33ca1,0xa3cf0a44}},	//   साठी_, pagn, renl, _शाप_,
   {{0x7aedac21,0x7bcd0189,0x60c3ac22,0x601507a6}},	//   _osat, _ncau, runm, _cámp,
   {{0x6459004e,0x61e36a3e,0x2d8315d7,0x43941999}},	//   mowi, penl, žjem_, _фаус,
   {{0x6459ac23,0x443dac24,0x63a9ac25,0x201f010b}},	//   lowi, liw_, _heen, skui_,
   {{0x63a98361,0x30850082,0x90995445,0x7aed018e}},	//   _keen, _الصف, _свет_, _asat,
   {{0x6459006a,0x6281ac26,0x63a9ac27,0x1dd80963}},	//   nowi, _hilo, _jeen, ब्बत,
   {{0x7aed0332,0x63a9ac28,0xd00e4c7e,0x9f0b0037}},	//   _csat, _meen, _سلو_, _جزاك_,
   {{0x7aed0024,0x7c3d11d9,0xa3d70067,0x66150375}},	//   _dsat, aisr, ़्त_, _nozk,
   {{0x7aedac29,0xb4e60311,0x64590035,0x601cac2a}},	//   _esat, _भने_, kowi, _sémi,
   {{0x765cac2b,0x63a9ac2c,0x9ac50484,0xdb06006c}},	//   _skry, _neen, fiċċ, lakí,
   {{0x6459004e,0x6615ac2d,0x18676429,0x27f24c02}},	// [c820] dowi, _bozk, сати_, rdyn_,
   {{0x6281ac2e,0x81e90033,0x00000000,0x00000000}},	//   _nilo, যাঁ_, --, --,
   {{0x78a90129,0x63a9ac2f,0x2e3a02b5,0x0446ac30}},	//   ćevc, _been, נגענ, бежн,
   {{0x3ebf1257,0xdc190035,0x628100e5,0x443dac31}},	//   krut_, _błęd, _ailo, giw_,
   {{0x63a90d35,0x6d5c0187,0x63ad008d,0x2bda01d1}},	//   _deen, ýraz, ðana, य्या,
   {{0x6281ac32,0x59db2e99,0x765c1140,0xde88055c}},	//   _cilo, म्पर, _ukry, _bịn_,
   {{0x92e80083,0x63a90051,0x64590035,0x44f70024}},	//   যমে_, _feen, bowi, _għ_,
   {{0x63a939de,0x24b700a5,0x260000dc,0x661501a3}},	//   _geen, _להלן_, राकी_, _zozk,
   {{0x26c0021d,0x91fc009e,0x00000000,0x00000000}},	//   nrio_, _bhāt, --, --,
   {{0x62815483,0x7bcd002d,0x63a9ac33,0x81c800b5}},	//   _gilo, _scau, _zeen, _خطرہ_,
   {{0xa3cf0953,0xa3bc004e,0x9f4f02e9,0x63a9001c}},	//   _शाम_, _आया_, _lagè_, _yeen,
   {{0x7f860082,0x26c00a78,0x6281a233,0xb4fb0070}},	//   _الإن, krio_, _zilo, אפטי,
   {{0xd5a8060a,0x7c3d1b18,0x643b0070,0xe0430421}},	//   गराज, risr, רעכנ, _энци,
   {{0x6aa90084,0x26c000de,0x6459004e,0x628101ef}},	//   _कबीर, drio_, zowi, _xilo,
   {{0x66150f86,0xde880019,0x6459023c,0x00000000}},	//   _rozk, _xịn_, yowi, --,
   {{0x2c7b0ae0,0x7aed01a2,0x26c0ac34,0x3a3aac35}},	//   _līdz_, _tsat, frio_, _empp_,
   {{0x7aed01d3,0x5a351e26,0xdce300ea,0x98aa00ea}},	// [c830] _usat, _мнит, _iznā, ākās_,
   {{0x63a9ac36,0x09b30033,0xfc3f031d,0x45d44011}},	//   _seen, ঞ্জা, lií_, зофс,
   {{0x26c0ac37,0x6459aa91,0x443d067f,0x63a900ab}},	//   ario_, towi, tiw_, _peen,
   {{0x8cc009a8,0xaa7b0187,0x00000000,0x00000000}},	//   _विनो, jvýz, --, --,
   {{0x6459006a,0x248dac38,0x63a90d67,0x70e10d34}},	//   rowi, _čemu_, _veen, पब्ल,
   {{0x40954697,0x63a96220,0x56949415,0xf4870369}},	//   орит, _ween, _харт, _гуан,
   {{0x64590755,0x6281ac39,0x63a9ac3a,0x7a2b033b}},	//   powi, _vilo, _teen, _güte,
   {{0x682a01c0,0x6281012f,0x2eb513df,0xe0d6010b}},	//   _týde, _wilo, осос, івы_,
   {{0xdb1d00a6,0x6281ac3b,0xfc3f053d,0x91cb00b5}},	//   ngsä, _tilo, dií_, _مذاق_,
   {{0xee3917c2,0xfe4200d4,0x7fb900d1,0x3f860260}},	//   рно_, дньо, _چهار_, _egou_,
   {{0x16c60f39,0xfc3f024e,0x5f9500f0,0x50dd021a}},	//   _लम्ब, fií_, _диет, _महिष,
   {{0xfc3f0187,0x5f740609,0x00000000,0x00000000}},	//   gií_, _کامر, --, --,
   {{0xe80d0084,0x69db0009,0x627900a0,0x00000000}},	//   हाना_, đuen, _dňov, --,
   {{0xa2cc0266,0x5ebe0083,0xb0dd00a1,0x20dd00b8}},	//   _समस्, ্বশে, _महाग, _महाध,
   {{0x8cc00d43,0xfc320037,0x2d870a21,0x81ae0033}},	//   _वियो, _يحب_, _igne_, _কাম_,
   {{0x78ba0528,0xfc3f290b,0x59db00b8,0x601c3762}},	//   štvo, cií_, म्बर, _fému,
   {{0x32050052,0x78a90129,0x24980a66,0x9f4f0183}},	// [c840] _only_, ćeva, _strm_, _bagé_,
   {{0x8cc014ab,0xa3dc2064,0x26c056d8,0x55e311d0}},	//   _विमो, त्न_, rrio_, моуб,
   {{0xae560070,0xd3020e6f,0xdb0f0183,0x00000000}},	//   קסעס_, लम्ब_, jacê, --,
   {{0xf8b30052,0x26c00133,0x9cda0070,0xddd8023a}},	//   _קשר_, prio_, יקעפ, _mivš,
   {{0x8cc0046c,0x7a2b02b1,0x00000000,0x00000000}},	//   _विभो, _wüte, --, --,
   {{0x64a6262e,0x9f4f00e0,0x00000000,0x00000000}},	//   _мага, _gagé_, --, --,
   {{0x628f02e1,0x3ea613da,0x3f8602d7,0x00000000}},	//   _écon, _swot_, _pgou_, --,
   {{0xdfd02d7c,0x2d8725d3,0x44220345,0xdd9005f5}},	//   ريخ_, _agne_, _ôk_, کود_,
   {{0x63a4008d,0xe2971da6,0x59aa021a,0x00000000}},	//   ðinu, _мат_, करार, --,
   {{0xddd80496,0x63a2ac3c,0xdb1d9fe1,0x601c00f7}},	//   _bivš, lbon, ngså, _rému,
   {{0x81460332,0x627900d5,0xc27b00a5,0xfc3f00ac}},	//   _بنان, _pňov, _כרמי, tií_,
   {{0x2d8703db,0x9f440118,0x00000000,0x00000000}},	//   _egne_, hemé_, --, --,
   {{0xa3dc0ceb,0xfc3f024e,0x447b02b5,0x7a2b00c1}},	//   त्य_, rií_, ינטע, _rütb,
   {{0xfc3f00a0,0x2ca70090,0x00000000,0x00000000}},	//   sií_, _fwnd_, --, --,
   {{0x63a2ac3d,0x37ab2c93,0xdde90312,0x260e046c}},	//   kbon, итан_, _درنه_, ठानी_,
   {{0xa3dc0084,0x2484ac3e,0xd6db00af,0x7a300523}},	//   त्म_, _nimm_, итз_, _nätf,
   {{0x36d403ad,0x85b90036,0x63a2ac3f,0x2987002d}},	// [c850] мотр, йлас_, dbon, _мынг,
   {{0x63a25b18,0xcfc20033,0x00000000,0x00000000}},	//   ebon, ্জিন, --, --,
   {{0x89da006c,0x91c4007c,0x00000000,0x00000000}},	//   _اوپر_, _राजै, --, --,
   {{0x58fa0070,0x9f4f00e0,0x248445d3,0x00000000}},	//   _פּינ, _wagé_, _cimm_, --,
   {{0x27e9ac40,0x1b1d0033,0x43740009,0x00000000}},	//   mean_, _পেতে_, мушт, --,
   {{0x27e9ac41,0xa2cc0066,0xf6790070,0x95c80336}},	//   lean_, _समर्, _לאָמ, _муса_,
   {{0x2484008a,0x7d1c10db,0x91fc0211,0xd4980d9e}},	//   _fimm_, ørsl, _phār, _мрт_,
   {{0x27e9ac42,0x24840176,0x60090b3b,0xd62202a4}},	//   nean_, _gimm_, сним_, нiза,
   {{0xe29300bf,0xee39ac43,0x260000a1,0x63bb60b2}},	//   _آذر_, йни_, राची_, _idun,
   {{0x27e9004a,0x629b010d,0xf1d20785,0xdb0600d5}},	//   hean_, _ituo, _सायन, jaká,
   {{0xed592264,0x80a40082,0x27e9ac44,0x644bac45}},	//   сон_, _يمكن, kean_, ongi,
   {{0xf0f90953,0x644b63a4,0x27e9ac46,0x30f900b5}},	//   ्मीद_, nngi, jean_, _پوچھ_,
   {{0xf1d20325,0x27e9ac47,0x644bac48,0x63bb08c7}},	//   _सामन, dean_, ingi, _mdun,
   {{0x6fd71604,0x81e90033,0x63a2ac49,0x63bb9929}},	//   भ्रं, যাক_, zbon, _ldun,
   {{0x25ff0035,0x2bd401c0,0x27e9ac4a,0xa3bc3c8d}},	//   _रफ़ी_, _थापा, fean_, _आयल_,
   {{0x27e9ac4b,0x63bbac4c,0x2c7b010b,0x2fcd016e}},	//   gean_, _ndun, _būdu_, ngeg_,
   {{0x0cdb0e96,0x6f160035,0x995500b8,0x80f93b23}},	// [c860] _बहुम, _życz, _výši_, ्मुख_,
   {{0x63bb0b04,0x63a201a2,0x7ae4237c,0x24840553}},	//   _adun, wbon, _ipit, _simm_,
   {{0x27e90ccc,0x629b7976,0x3a3700a5,0x00000000}},	//   bean_, _atuo, _זרים_, --,
   {{0x69dcac4d,0x27e9ac4e,0x644bac4f,0x63a201e4}},	//   lfre, cean_, gngi, ubon,
   {{0x628f02e1,0x57fb0319,0x68310a8a,0x63bb01a8}},	//   _écol, _הלכו, _bådf, _ddun,
   {{0x69dcac50,0x7ae428f7,0x30a63b6e,0x7a2bac51}},	//   nfre, _mpit, прив, _küta,
   {{0x64a60c14,0x26090084,0x03a60674,0x765e010d}},	//   _хаба, सारी_, _ниво, mopy,
   {{0x6ebd045c,0x81e90083,0xb6030484,0x92c101d6}},	//   _शिशु, যাগ_, ġġet, üğün,
   {{0x4426ac52,0x69dcac53,0x64423493,0xb8010033}},	//   mko_, kfre, mioi, _একমত_,
   {{0x4426ac54,0x27e906a2,0x765e31dc,0x69dc241d}},	//   lko_, zean_, nopy, jfre,
   {{0x69dcac55,0x4426ac56,0x7ae4ac57,0xdb0f1111}},	//   dfre, oko_, _apit, macé,
   {{0x27e906a2,0x61ea008c,0xdb0f000d,0x6442ac58}},	//   xean_, lefl, lacé, nioi,
   {{0x69dcac59,0x44269442,0x27e900af,0xa2c40a44}},	//   ffre, iko_, vean_, _रिफ्,
   {{0x442601fe,0xa3dc20ab,0x61eaac5a,0xdb0400de}},	//   hko_, त्त_, nefl, _adió,
   {{0x7ae4ac5b,0x27e9ac42,0x4426ac5c,0x69ce00fa}},	//   _epit, tean_, kko_, _तारी,
   {{0xdc2b00d1,0x7c26191b,0x69dc0176,0x69ce0345}},	//   _دسته_, ckkr, afre, agbe,
   {{0x7c2dac5d,0x4426ac5e,0x6442ac5f,0x26090066}},	// [c870] _ilar, dko_, dioi, साली_,
   {{0x27e9ac60,0x4426ac61,0x8b670088,0xa3cf0d1f}},	//   sean_, eko_, _واکم, _शाह_,
   {{0x7c2d0b87,0xb83568be,0x7afd31cb,0x61ea027d}},	//   _klar, _женщ, lvst, defl,
   {{0xc95202b8,0x644b0511,0x6442ac62,0x7bcf4605}},	//   _ימי_, ungi, gioi, ngcu,
   {{0x3869036a,0x245800d8,0x6493009f,0xdb0fac63}},	//   mlar_, чаць_, _għin, facé,
   {{0x4426ac64,0xdd86211f,0x7c2d12c3,0x61ea0588}},	//   ako_, _لو_, _llar, gefl,
   {{0x7c2d08ca,0xe61f01a5,0x3869ac65,0x4426ac66}},	//   _olar, _nuôi_, olar_, bko_,
   {{0x386908d2,0x4426ac67,0xb69b02e1,0x7e680051}},	//   nlar_, cko_, _grâc, eldp,
   {{0x442dac68,0x38690a17,0x443f4a4c,0x69dc00e9}},	//   _ile_, ilar_, _imu_, yfre,
   {{0x3869045e,0x442d0221,0x61ea2b28,0x7a3018af}},	//   hlar_, _hle_, cefl, _käte,
   {{0x7ae4ac69,0x3869ac6a,0x442dac6b,0x1bea1761}},	//   _spit, klar_, _kle_, одни_,
   {{0x38690723,0xca290397,0x95ea0026,0xd5dd0edf}},	//   jlar_, _דם_, _ऑस्ट_, न्तज,
   {{0x3869ac6c,0xb0dd97c4,0x443f0103,0x69dcac6d}},	//   dlar_, _महँग, _mmu_, tfre,
   {{0x442603cb,0x68fc15d8,0x442dac6e,0xdee20043}},	//   zko_, tvrd, _lle_, _роши,
   {{0x442d9c26,0x443f09d6,0x3869ac6f,0x7a30013c}},	//   _ole_, _omu_, flar_, _näte,
   {{0x386903d0,0x69dc9361,0x3b00003c,0x81e90033}},	//   glar_, sfre, _triq_, যাট_,
   {{0x7ae403fd,0xf743ac70,0x2c560029,0x4426030a}},	// [c880] _upit, вето, gāde_, vko_,
   {{0x442dac71,0xb0dd0f9c,0xf1d2065f,0x443fac72}},	//   _ale_, _महंग, _साधन, _amu_,
   {{0x4426ac73,0x3869ac74,0x442d0a55,0x61ea0a8a}},	//   tko_, blar_, _ble_, vefl,
   {{0x442dac75,0x38690095,0x68315c1b,0x4426ac76}},	//   _cle_, clar_, _rådg, uko_,
   {{0x4426ac77,0x442d01c0,0x443fac78,0x61ea44c8}},	//   rko_, _dle_, _dmu_, tefl,
   {{0x442dac79,0x20ee000c,0x443f01a8,0x3860ac7a}},	//   _ele_, _při_, _emu_, loir_,
   {{0x44266ce4,0xc0e304bf,0xdb06194e,0x442dac7b}},	//   pko_, војк, lakä, _fle_,
   {{0xd0100514,0x68e302c9,0x661cac7c,0x442d2039}},	//   الة_, _ände, _hork, _gle_,
   {{0x661cac7d,0x5fbf045c,0x67240232,0x64404d24}},	//   _kork, _एयरल, nyij, _immi,
   {{0x386906d3,0x442d0bb8,0x20ee01c0,0x81dc0083}},	//   zlar_, _zle_, _tři_, _তোর_,
   {{0x3869ac7e,0x44fe00d8,0x442d0086,0x7c2d010d}},	//   ylar_, _jį_, _yle_, _plar,
   {{0xd00f01cb,0xdb040485,0x3869ac7f,0x26050354}},	//   _پله_, _adiñ, xlar_, _होनी_,
   {{0x6288ac80,0x3869ac81,0xe80d22a7,0x661c053e}},	//   _kido, vlar_, हासा_, _oork,
   {{0x683101b4,0x38690090,0x7afd2172,0x62880160}},	//   _måde, wlar_, rvst, _jido,
   {{0x38694f10,0x6440007a,0xe8000299,0x6288ac82}},	//   tlar_, _ommi, _लोहा_, _mido,
   {{0x6288ac83,0x6ce302ce,0x6f02ac84,0xc6a7015a}},	//   _lido, _ріше, _kroc, држи,
   {{0x3869ac85,0x78a22c3f,0x682a01c0,0x199501c8}},	// [c890] rlar_, _čove, _týdn, _папя,
   {{0x6440ac86,0x09c600c8,0x3869037a,0xdcfa06d0}},	//   _ammi, শ্বা, slar_, latı,
   {{0x442d12c3,0x386901d6,0x80dd02e4,0x2c7205f6}},	//   _ple_, plar_, _महें, láda_,
   {{0x386901c2,0xdcfa04d4,0x6aadac87,0x6288059c}},	//   qlar_, natı, _kwaf, _aido,
   {{0x661c177c,0x442d142f,0x6288ac88,0xe7840f08}},	//   _fork, _vle_, _bido, _ауро,
   {{0x661c16d7,0x863502b5,0x628801a2,0x6440ac89}},	//   _gork, _טאָג_, _cido, _emmi,
   {{0x62881034,0x69d70006,0x2249011c,0x442d6d53}},	//   _dido, _बानी, đak_, _tle_,
   {{0x6b8d00d1,0x442d000e,0x6288002a,0xef190d1b}},	//   _ngag, _ule_, _eido, зми_,
   {{0x3eb92d81,0x81ae0083,0x32552327,0xa3e500b4}},	//   ést_, _কার_, _звар, _बॉय_,
   {{0x6f020094,0x6b8d073a,0xb2743f6c,0x62887ad6}},	//   _droc, _agag, _алуш, _gido,
   {{0xa3dc0e6f,0x1d090de3,0x6f020009,0x6aad0195}},	//   त्व_, чени_, _eroc, _awaf,
   {{0x8cc00ac4,0x628805e2,0xce9501d3,0x6aad01a8}},	//   _विरो, _zido, _задъ, _bwaf,
   {{0x38601010,0xdee50c9f,0x3f8200c7,0x2c720097}},	//   voir_, _чоли, žkur_, gáda_,
   {{0xc33202b8,0x6b8d0103,0x6e28327c,0x00000000}},	//   רוך_, _egag, ckdb, --,
   {{0xdcfa00a8,0x3860578e,0x6aad61ce,0x27f90090}},	//   batı, toir_, _ewaf, _basn_,
   {{0x661cac8a,0x9f440355,0x682a00d5,0x6b8d030d}},	//   _sork, zemí_, _výdo, _ggag,
   {{0x661cac8b,0x7bd60010,0x7a2b2ceb,0x386000f7}},	// [c8a0] _pork, _icyu, _kütl, roir_,
   {{0x6831452e,0x7af600d7,0x3860000d,0x6b8d1cb0}},	//   _råde, _isyt, soir_, _zgag,
   {{0xf1c900c0,0x41c9131c,0x628802fb,0x661cac8c}},	//   _राजन, _राजस, _rido, _vork,
   {{0x6288ac8d,0x661c0052,0xe3b2250f,0x1e1cac8e}},	//   _sido, _work, ارا_, _पक्ष_,
   {{0x661cac8f,0xe80d08b6,0x7e6100d7,0x6288ac90}},	//   _tork, हारा_, kolp, _pido,
   {{0x8cc0035d,0x7d033340,0x00000000,0x00000000}},	//   _विलो, _orns, --, --,
   {{0xa2cc045c,0xdcfa06d0,0x6288602b,0xd5ad00b5}},	//   _समक्, yatı, _vido, _ذہن_,
   {{0x27e05eec,0x9f4f01f7,0xf1d2052f,0x6440ac91}},	//   nfin_, _bagà_, _सावन, _ummi,
   {{0x62889bda,0x7d034588,0x9cec0033,0x00000000}},	//   _tido, _arns, _ওপেন_, --,
   {{0xa3dc0ebd,0xd0100332,0x7e610453,0x43751e47}},	//   त्र_, الک_, golp, _руст,
   {{0x6f02ac92,0x9f4f021d,0x6aad023c,0xc04f0208}},	//   _wroc, _pagã_, _swaf, _бі_,
   {{0x6f02ac93,0x61faac94,0xd5cc0067,0x27e033b8}},	//   _troc, _hatl, ालुओ, jfin_,
   {{0x7d03320a,0xdcfa037a,0x61faac95,0x63ad0093}},	//   _erns, ratı, _katl, ðani,
   {{0x7e61539a,0xb69b00af,0x27e00069,0x2c72031d}},	//   colp, _brân, efin_, ráda_,
   {{0x61faac96,0xe80d0914,0xdb0fac97,0xdcfa027d}},	//   _matl, हाला_, mací, patı,
   {{0xb9090755,0x61fa013a,0x6aad0428,0xd7f8005f}},	//   _यह_, _latl, _twaf, нуу_,
   {{0xa2cc051d,0x2ba708b6,0x6aad2a13,0x0c740372}},	// [c8b0] _समग्, _क्या, _uwaf, _حدود,
   {{0xb69b0395,0x321e0e7d,0x27f900a5,0x81e50033}},	//   _frân, _noty_, _wasn_, _বোন_,
   {{0xbc6809b9,0x682300ab,0x599600a5,0x92ad0033}},	//   _زمین_, _sõdu, _בכתב_, _কমে_,
   {{0x320cac98,0xdb0f00d5,0x00000000,0x00000000}},	//   _andy_, hací, --, --,
   {{0x61fa0392,0x321e00b8,0xc98701cb,0x63a402d7}},	//   _batl, _boty_, _تشکي, ñina,
   {{0x61fa6577,0x321e9e69,0x21692c61,0x9f4f0036}},	//   _catl, _coty_, мили_, _ragà_,
   {{0x205547ea,0x9f42016f,0x61fa010d,0x7a3000ab}},	//   ктир, ľký_, _datl, _jäta,
   {{0x2605ac99,0x320c0159,0x7a300454,0x2c560228}},	//   _होती_, _endy_, _mäta, kāda_,
   {{0xf1a70c46,0x61fa813a,0x6458000d,0x7e61ac9a}},	//   _зрен, _fatl, évie, tolp,
   {{0xdb0fac9b,0x26c98e6f,0x00000000,0x00000000}},	//   gací, irao_, --, --,
   {{0x7e61ac9c,0x224700c7,0x02d15f2e,0x7a30017b}},	//   rolp, mink_, _समुन, _näta,
   {{0x8c46002d,0x61faac9d,0x7af6021d,0x7a22000d}},	//   теме, _zatl, _psyt, _nôtr,
   {{0x6d5802d7,0x12bf0033,0x00000000,0x00000000}},	//   _exva, _ইহুদ, --, --,
   {{0xa2c40e04,0xf2d20070,0x7d03ac9e,0xdb0f02d7}},	//   _रिस्, בעך_, _trns, cací,
   {{0x64d00953,0xa9671888,0xb866026b,0x00000000}},	//   _हमेश, вира_, نارو, --,
   {{0xde880019,0x2c080035,0x66e62b5b,0x3e7a00fe}},	//   _dịu_, षाओं_, коба, _eště_,
   {{0x18676bde,0x26c90254,0x7c3d0055,0x00000000}},	// [c8c0] тати_, grao_, ërre, --,
   {{0xa92689af,0xb69b0370,0x8ab700a5,0x66e311d0}},	//   _адол, _trân, _שהיו_, рофа,
   {{0xd49900d4,0x22470173,0x61faac9f,0x09b80033}},	//   ері_, dink_, _ratl, _জাপা,
   {{0xad1a02b5,0xfbdf01a5,0x26c9aca0,0x68e301ff}},	//   ווער, hiên_, brao_, _ända,
   {{0xe3631bfd,0xe8e20243,0xe297107a,0x61faaca1}},	//   акци, _पहुच, вач_, _patl,
   {{0x61faaca2,0x2c7200d5,0x00000000,0x00000000}},	//   _qatl, kádo_, --, --,
   {{0xdb0f0c18,0xd12f0c74,0x50b70118,0xe6430352}},	//   vací, يمه_, نديد_, _терп,
   {{0xc95300a5,0x240700af,0x7523033b,0x1ee602fd}},	//   ימו_, _инси_, änze, نوعی_,
   {{0x09b800c8,0x61faaca3,0x78a90254,0x9f4f1945}},	//   _জানা, _tatl, ćevi, _pagá_,
   {{0xde880023,0x0ef200b4,0x00000000,0x00000000}},	//   _nịt_, _अनीस_, --, --,
   {{0x683101ff,0xdb0f0097,0x00000000,0x00000000}},	//   _låda, rací, --, --,
   {{0xbbbf363d,0x8fa603d6,0x41d2111b,0x00000000}},	//   ्लेक, _раде, _साँस, --,
   {{0xde8800e2,0xdb0f00ac,0x6fd70099,0x78a20207}},	//   _bịt_, pací, _यातू, _čova,
   {{0x2c560029,0x00000000,0x00000000,0x00000000}},	//   rāda_, --, --, --,
   {{0x2905aca4,0x387907c0,0x00000000,0x00000000}},	//   íla_, _phsr_, --, --,
   {{0x26c90254,0x68310523,0xdb2300b5,0x00000000}},	//   trao_, _båda, _نوعی, --,
   {{0x7a2200f7,0x1bb82149,0xdb1d02b1,0x00000000}},	// [c8d0] _vôtr, _شايع_, ngsü, --,
   {{0x2ba7021a,0xdb0f0176,0x00000000,0x00000000}},	//   _क्ता, macà, --, --,
   {{0x2247aca5,0x26c90207,0x00000000,0x00000000}},	//   vink_, srao_, --, --,
   {{0xa2c40299,0x7a3000be,0xdb0f0183,0x00000000}},	//   _रिश्, _jätn, cacã, --,
   {{0x3e790248,0x7a3001ff,0x2247005f,0x69c10067}},	//   lète_, _mätn, tink_, ólew,
   {{0xde880023,0x69d5033b,0xd5f9016b,0x722b0421}},	//   _xịt_, ngze, _אפֿר, ьцев_,
   {{0x09b800c8,0xa069a1dc,0x3e790248,0x2247aca6}},	//   _জামা, нака_, nète_, rink_,
   {{0x2247aca7,0xd00e0098,0x00000000,0x00000000}},	//   sink_, كلى_, --, --,
   {{0x3e79000d,0x0e651e47,0x00000000,0x00000000}},	//   hète_, лкин, --, --,
   {{0x7c3f010b,0x63b9aca8,0x248d00e2,0x96d537e8}},	//   _įpra, lawn, _hiem_, यूयॉ,
   {{0x248d0019,0x705205f5,0xac861285,0xd7c30099}},	//   _kiem_, شنیا, лгол, षणाच,
   {{0x41df1d25,0x22990c1f,0xfaa6751e,0x248d81b1}},	//   प्रस, _kèk_, ламо, _jiem_,
   {{0xe4560070,0x200f008d,0x270d0099,0x2a7a00ee}},	//   רירט_, _ingi_, समोर_, _phpb_,
   {{0xed590f94,0x628f0248,0x248daca9,0xa3e522c7}},	//   _пол_, _écou, _liem_, _बॉस_,
   {{0x6831acaa,0x7d1c1b99,0xde880023,0x68fb0035}},	//   _såda, ørst, _vịt_, łudn,
   {{0xc2f900c8,0xf7725f8a,0x248dacab,0x18671566}},	//   _আপনি_, ماء_, _niem_, гаси_,
   {{0x63b9acac,0xdb0f0132,0x7bc40118,0x229900f8}},	// [c8e0] dawn, racã, _idiu, _nèk_,
   {{0x3e795bee,0x6aa41766,0xf1d20d4e,0xae16021a}},	//   bète_, _itif, _साइन, तायन_,
   {{0x200f573e,0x69db0009,0x63a402d7,0x682a0168}},	//   _ongi_, đuet, ñino, _lýdi,
   {{0x4420064b,0x2299021e,0xdb0f01ef,0x98160037}},	//   ði_, _bèk_, lacá, _إبدا,
   {{0xe7270036,0x248dacad,0x27f2099e,0xe2f800d4}},	//   _бояд_, _diem_, meyn_, телі_,
   {{0x26d2acae,0x366a00d8,0x200f02ce,0x22990118}},	//   muyo_, _чаго_, _angi_, _dèk_,
   {{0xc31c00c8,0x90e60413,0x63b90067,0x00000000}},	//   _দেখি_, استن, bawn, --,
   {{0x27f20107,0x229902d0,0xc0e70098,0x00000000}},	//   neyn_, _fèk_, افين_, --,
   {{0x26d2acaf,0x229900e0,0x6aa40371,0x00000000}},	//   nuyo_, _gèk_, _ntif, --,
   {{0x6fa40325,0x7bc4acb0,0xf29700a5,0xe297005f}},	//   _ग्रं, _adiu, _עכבר_, _саф_,
   {{0x519302e7,0x6aa424fc,0x515600af,0x7a3007c0}},	//   _المذ, _atif, _стау, _pätn,
   {{0xc0a90ef5,0xf0b1006c,0xfbdf0298,0x00000000}},	//   _شامل_, _بیٹھ, enêr_, --,
   {{0x27f20be2,0x2617111a,0x00000000,0x00000000}},	//   deyn_, नामी_, --, --,
   {{0xad2600bf,0x6935021d,0x7bc403d0,0x5a44002d}},	//   _مربو, ангу, _ediu, бэса,
   {{0x6cc6010b,0x6aa400e9,0x6f0400d5,0x684100fe}},	//   _сёле, _etif, _šich, _lídř,
   {{0x3e7900f7,0x1dd407b5,0xf65f0b3e,0xfbdf0183}},	//   rète_, _दाँत, _kvæg_, rnês_,
   {{0x35b52d59,0x248d0d35,0x26d23698,0xb69b4505}},	// [c8f0] ибар, _riem_, guyo_, _trâm,
   {{0x26c70888,0x7aedacb1,0x2d9e0043,0x3e79000d}},	//   čno_, _ipat, ncte_, pète_,
   {{0xfbdf0019,0x248d00ea,0x69c5acb2,0xe80001d1}},	//   hiêm_, _piem_, _idhe, _लोका_,
   {{0x26d286a7,0x81bc00ea,0x656e008c,0x7a3000be}},	//   buyo_, _slēp, _dybh, _lätl,
   {{0x63b9004e,0x248d01ba,0x64580132,0x26d202d7}},	//   rawn, _viem_, évia, cuyo_,
   {{0x65940c8a,0x248d004e,0x7aed5ba0,0xe2960ecf}},	//   _гару, _wiem_, _mpat, шаш_,
   {{0x248d0029,0x3b090430,0x90352fc1,0x00000000}},	//   _tiem_, _lraq_, ихич, --,
   {{0xaec520a6,0x7aedac67,0x63ad0caa,0x2ba70d91}},	//   абил, _opat, ñand, कुमा,
   {{0x644bacb3,0x200301c0,0xb3a90644,0x6831017b}},	//   migi, ěji_, ğıdı, _lådo,
   {{0x644bacb4,0x7d0903fa,0xcee80c74,0xb3a900c1}},	//   ligi, вног_, ارين_, şıdı,
   {{0xed590011,0x6aa4acb5,0x7aed41a3,0x68310a8a}},	//   тон_, _stif, _apat, _rådn,
   {{0x69c5acb6,0x644bacb7,0x200f003e,0x7a3000ee}},	//   _adhe, nigi, _ungi_, _päto,
   {{0x683800b8,0x628f000d,0x7c3d0055,0x00000000}},	//   _jíde, _écos, ërra, --,
   {{0xa2cd22a7,0x644bacb8,0xada506d8,0x260508a9}},	//   _सिन्, higi, _такл, _होली_,
   {{0x2ba706bc,0x644bacb9,0x7aedacba,0xa96a1517}},	//   _क्वा, kigi, _epat, тива_,
   {{0x644b018e,0xdb0f01dd,0x7a305f24,0x26d20f3a}},	//   jigi, sacá, _täto, tuyo_,
   {{0x6e23acbb,0x27f24a70,0xde880019,0x6aa4acbc}},	// [c900] _konb, reyn_, _kịp_, _utif,
   {{0x09e400c8,0x3ebf00c3,0x6e23393b,0x27f200a8}},	//   _ফোরা, isut_, _jonb, seyn_,
   {{0xbef2009a,0x37e61654,0x644b004f,0x7c240dba}},	//   _अन्न_, _конг, figi, _koir,
   {{0x644b0269,0x7aed00d8,0x26d21b82,0x13060432}},	//   gigi, _ypat, puyo_, изем,
   {{0x7c2400f1,0xa3e500b4,0x69c10093,0x41b60079}},	//   _moir, ब्ध_, ðleg, لمشر,
   {{0x7c24acbd,0x26c20009,0x6e2301a3,0xd04300a8}},	//   _loir, _ivko_, _nonb, munə,
   {{0x644b6b7d,0x26c0010b,0x7a300523,0x00000000}},	//   bigi, lsio_, _nätm, --,
   {{0x7c240248,0xa3e502e4,0x644b2502,0xb7bb00e2}},	//   _noir, ब्द_, cigi, _loãn,
   {{0xe29a1a6d,0xfba706bc,0x4424acbe,0x6e23acbf}},	//   _раз_, _क्षम, _iom_, _bonb,
   {{0x4424acc0,0x26c000e9,0x26c20124,0x7c244dbb}},	//   _hom_, isio_, _mvko_, _aoir,
   {{0x7aedacc1,0x4424acc2,0x3ebf081b,0x7c24239a}},	//   _spat, _kom_, asut_, _boir,
   {{0xdee62070,0x4424acc3,0x7c24acc4,0x7aedacc5}},	//   _води, _jom_, _coir, _ppat,
   {{0x7c2402a8,0x2f0f0093,0x4424024b,0x6e230107}},	//   _doir, rögð_, _mom_, _fonb,
   {{0xfba7142a,0x44240189,0x644bacc6,0x6e23acc7}},	//   _क्रम, _lom_, zigi, _gonb,
   {{0x7c24acc8,0x644b203d,0x44240173,0xeabf027a}},	//   _foir, yigi, _oom_, ssù_,
   {{0x4424acc9,0x7c240014,0x644b0183,0x59dc198f}},	//   _nom_, _goir, xigi, _बाथर,
   {{0x7aed0054,0x25b8008c,0xdb0f0132,0xd5bb0421}},	// [c910] _upat, _berl_, dacç, все_,
   {{0x69c501f4,0x44240211,0x7d0a0009,0x644bacca}},	//   _udhe, _aom_, _krfs, wigi,
   {{0x644baccb,0x4424accc,0x78a900cd,0x00000000}},	//   tigi, _bom_, ćevs, --,
   {{0x3ea61034,0x68381111,0x5bc500b4,0x2fc60118}},	//   _otot_, _píde, _वयोव, _ndog_,
   {{0x81ae00c8,0x3869012f,0x13a9006c,0xe80000be}},	//   _কাজ_, moar_, پنڈی_, _लोटा_,
   {{0x6838007e,0x644baccd,0x24980211,0xdb06031d}},	//   _víde, sigi, _furm_, jaký,
   {{0x644b3fb6,0x44240359,0xb7bb0183,0x628300f4}},	//   pigi, _fom_, _joão, rmno,
   {{0x2ba702b4,0x3ebfacce,0x6e23accf,0xf9580122}},	//   _क्ला, tsut_, _sonb, יסות_,
   {{0x672dacd0,0x3ebf0328,0x6449acd1,0x6006021f}},	//   nyaj, usut_, _imei, сным_,
   {{0x7c24a557,0xee3615eb,0x44240221,0x3ebf32be}},	//   _soir, йны_, _zom_, rsut_,
   {{0x2fd90071,0x4424006f,0x7c24acd2,0x3ebf8035}},	//   _مواد_, _yom_, _poir, ssut_,
   {{0xca2901f3,0x68310b3e,0x442400cc,0x672dacd3}},	//   _אם_, _bådm, _xom_, kyaj,
   {{0x6e230c1f,0x7c240248,0x201f002f,0x59dc29ad}},	//   _tonb, _voir, mjui_, _बादर,
   {{0x6e3a77aa,0xa2da0325,0x09b80083,0x98b400cd}},	//   chtb, _नमस्, _জাহা, _žeđi_,
   {{0x7c241093,0x6449002a,0x26c0016e,0x00000000}},	//   _toir, _omei, wsio_, --,
   {{0x5eee046c,0x81ae0083,0xdb1602d7,0xccf232e3}},	//   _अहम्_, _কাছ_, _leyé, _זכה_,
   {{0x4424acd4,0x7a303115,0x87b900c7,0x85ea00af}},	// [c920] _rom_, _jätk, руст_, лдав_,
   {{0x44243d8f,0x26c081ab,0x6449acd5,0xdb1602d0}},	//   _som_, rsio_, _amei, _reyè,
   {{0x44240d4b,0x26c01578,0xdcea011c,0x3869002a}},	//   _pom_, ssio_, čiće, boar_,
   {{0x442400d7,0x7e680bca,0xf4870647,0x26c00b5e}},	//   _qom_, zodp, مانی, psio_,
   {{0x4424acd6,0x2498acd7,0xdb0f0183,0x7a301ba3}},	//   _vom_, _wurm_, racç, _nätk,
   {{0x78a20280,0xc5d500d4,0x44240260,0x9f5d00d1}},	//   _čovj, _місь, _wom_, _gawé_,
   {{0xa2c4035d,0x4424acd8,0xa0a30409,0x6ab6016e}},	//   _रिक्, _tom_, пшыл, _lwyf,
   {{0x7a2b033b,0x50b71902,0x00000000,0x00000000}},	//   _hütt, حدود_, --, --,
   {{0x6443a8e2,0x7a2b00ab,0x41e00026,0xa0670274}},	//   ënie, _kütt, _नापस, љања_,
   {{0x2486201d,0x2a6aacd9,0x63a209e8,0x996307c0}},	//   lmom_, jobb_, lcon, _líši_,
   {{0x7a2bacda,0xdd9010ad,0x40960037,0x7c3d01f4}},	//   _mütt, بود_, _الصر, ërro,
   {{0x63a2acdb,0x7e6800b5,0x00000000,0x00000000}},	//   ncon, sodp, --, --,
   {{0x7e6807fc,0x3ea608dd,0x69de021d,0x68fe03d0}},	//   podp, _utot_, _bcpe, _aspd,
   {{0x2bdb0253,0x25ad0207,0x6ab600e5,0x00000000}},	//   _भावा, _đelo_, _dwyf, --,
   {{0x28d90cf1,0x4877004f,0x38690fde,0x63a20051}},	//   बंधि, مدرس, toar_, kcon,
   {{0x248611d7,0x672dacdc,0x98a5033e,0x2004acdd}},	//   jmom_, tyaj, çlı_, ndmi_,
   {{0xa2cd1cc3,0x386901ef,0xf7730180,0xf1c801d1}},	// [c930] _सिध्, roar_, سار_, रणान,
   {{0x7a300523,0x00000000,0x00000000,0x00000000}},	//   _näth, --, --, --,
   {{0x63a203d0,0x64930024,0x00000000,0x00000000}},	//   fcon, _rħis, --, --,
   {{0xa2cd0bdd,0x69d806d7,0x63a2250e,0x26170099}},	//   _सिद्, _över, gcon, नाही_,
   {{0x387e02e1,0x7a2b4cf0,0x27e90282,0x2be1073f}},	//   ître_, _fütt, mfan_, _कानू_,
   {{0x27e90297,0x63a2acde,0x644800c7,0x00000000}},	//   lfan_, acon, _įdie, --,
   {{0x2bbe0354,0x661502a7,0x92d90033,0x00851c87}},	//   ्णमा, _inzk, ়বে_, олко,
   {{0x63a201d3,0x26170d1f,0x2bdb20a3,0x27e902d0}},	//   ccon, नावी_, _भाषा, nfan_,
   {{0xee3943af,0xcdf53122,0x3255010b,0x00000000}},	//   ини_, очны, _двар, --,
   {{0xa6e2008a,0x7bdf7a82,0x63bb03bc,0x926b0274}},	//   æðin, _acqu, _heun, _срба_,
   {{0xcb096a92,0x63bb005d,0x6155006c,0x64590345}},	//   _של_, _keun, _بنائ, onwi,
   {{0x63bb1010,0x645902d0,0x59dc9ae0,0x200300ea}},	//   _jeun, nnwi, _बाहर, ējis_,
   {{0x63bb223a,0x62810107,0xa3e10f9f,0x27e900e9}},	//   _meun, _khlo, _दान_, dfan_,
   {{0x3ead8327,0x63bbacdf,0x68fe0176,0xaa7b0355}},	//   mpet_, _leun, _pspd, stýn,
   {{0x290cace0,0x160d0084,0x27e9ace1,0x6f093720}},	//   ída_, _सफ़र_, ffan_, lvec,
   {{0x59dc02e4,0x6ab6053e,0x63bb4404,0x670526c6}},	//   _बावर, _twyf, _neun, रिंक_,
   {{0xdb0d0279,0x464aace2,0x7a3000ab,0x2c5600ea}},	// [c940] _reaç, азан_, _läti, jādi_,
   {{0xe617ace3,0x683801f7,0x27e90284,0x00000000}},	//   оду_, _dída, afan_, --,
   {{0x69dcace4,0x7a300328,0x24860cc2,0x6d41ace5}},	//   mgre, _näti, tmom_, nzla,
   {{0x69dcace6,0x87d60642,0x6d41571c,0x6281009e}},	//   lgre, _بغدا, izla, _ahlo,
   {{0x6f092676,0x63bbace7,0x63ad112c,0x6281006b}},	//   jvec, _deun, ñana, _bhlo,
   {{0x6281ace8,0x24860254,0x63a20a1f,0xe1ef0079}},	//   _chlo, smom_, scon, نسى_,
   {{0x6ab70026,0x63a201e4,0x628127cc,0x2c7200ac}},	//   _अब्र, pcon, _dhlo, ládu_,
   {{0x212001cc,0x3ec61b0a,0x63bb01a3,0x3ae4ace9}},	//   ćih_, особ, _geun, köp_,
   {{0x2be10084,0x2ca90009,0xdb04002a,0x31690448}},	//   _काबू_, _čada_, _meió, ğaza_,
   {{0x6281006b,0xb69b0139,0x63bb0065,0x00000000}},	//   _ghlo, _grâu, _zeun, --,
   {{0xa3e10299,0xafe602ce,0x69dc13dc,0x27e9acea}},	//   _दाम_, _можл, dgre, yfan_,
   {{0x09d302cb,0x69dc0223,0x2c7200d5,0x1ee900f8}},	//   तल्य, egre, kádu_, جویی_,
   {{0x69dc3c20,0xfad802fb,0x00000000,0x00000000}},	//   fgre, одящ_, --, --,
   {{0x69dcaceb,0xa2cd10a6,0xfc460093,0xbef800b4}},	//   ggre, _सिस्, _þína_, ्टीन_,
   {{0x2605006a,0x7a3f01c0,0xf84b0104,0x19940382}},	//   _होगी_, vště, ачай_, даря,
   {{0x443d01e8,0xdc2b00f8,0x3b000069,0x648300be}},	//   xhw_, _خسته_, _fsiq_, mõig,
   {{0x27e94628,0x69dc0408,0x2c720097,0x648300be}},	// [c950] rfan_, bgre, gádu_, lõig,
   {{0x63bbacec,0x61f80c99,0x26050006,0x69dc2db0}},	//   _seun, jevl, _होखी_, cgre,
   {{0x61f877ff,0x682a0097,0x00000000,0x00000000}},	//   devl, _výdr, --, --,
   {{0x7bdd0053,0x2901aced,0x6281acee,0x2c5600ea}},	//   ngsu, _isha_, _shlo, tādi_,
   {{0x78a2025c,0x6281acef,0x68311e54,0x00000000}},	//   _čovi, _phlo, _rådh, --,
   {{0x2c5600ea,0xaad30240,0xddda00b8,0x960b010b}},	//   rādi_, _तिनक, potř, _тэма_,
   {{0x63bb2f4b,0x00000000,0x00000000,0x00000000}},	//   _teun, --, --, --,
   {{0x6f09013c,0x69dc0a18,0xddc10478,0x3ead00cc}},	//   tvec, zgre, dolš, tpet_,
   {{0x69dcacf0,0xed630355,0xfe790355,0xf1a70aec}},	//   ygre, _mužů_, stům_, _дрен,
   {{0xee394717,0x6f09acf1,0x7a3001ae,0x62810097}},	//   сно_, rvec, _täti, _uhlo,
   {{0x6f09acf2,0xddc10009,0x69dc15e4,0x29010371}},	//   svec, golš, vgre, _nsha_,
   {{0x3ead0bf3,0x32050097,0xaa7b00b8,0xfba70355}},	//   ppet_, _haly_, stýl, कुलम,
   {{0xc05200c2,0x69dcacf3,0x29015f0f,0x6838007e}},	//   _אזא_, tgre, _asha_, _bídn,
   {{0xc60a0084,0x00000000,0x00000000,0x00000000}},	//   _होंठ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a30013c,0xb8f40f9c,0xfc3f0079,0xb904020c}},	//   _nätv, _हट_, chí_, _नम_,
   {{0x61f800a8,0xfc5700a5,0x2901034d,0x00000000}},	// [c960] yevl, _מבקש_, _esha_, --,
   {{0xd6cf16e6,0x959a005f,0x2c7200d5,0x8ebd0831}},	//   اقل_, стау_, rádu_, _আমাগ,
   {{0xb3a906d0,0x399b0100,0x999b00a5,0xda6501cb}},	//   ğını, _לייד, _לביט, _تايي,
   {{0xb3a904d4,0x1459010b,0x260c07b5,0x2c7200d5}},	//   şını, ошчы_, _डोरी_, pádu_,
   {{0x81ad0033,0xd46781e6,0x00000000,0x00000000}},	//   _কয়_, чице_, --, --,
   {{0xd5b22087,0xa2cd0f9c,0x2fc01942,0x683108c8}},	//   _سفر_, _सिर्, _žig_, _rådi,
   {{0x490f3123,0x61f8acf4,0x463b0070,0x764e01d5}},	//   डियो_, revl, _פעלע, _imby,
   {{0x8f4601d3,0x61f8022f,0xf993011d,0x35fe0033}},	//   зход, sevl, ערה_, _উচিৎ_,
   {{0xbef806bc,0x141b00a5,0xb69b0395,0x09e30831}},	//   ्टेन_, _פומב, _urât, য়তা,
   {{0x7bc0008a,0x2d9802ce,0x68380300,0x00000000}},	//   ðmun, øre_, _oído, --,
   {{0xfc3f004f,0xe0d2006c,0x1ddd0253,0x245500d5}},	//   thí_, _سزا_, _मारत, sťme_,
   {{0x2fc000fb,0x2901012f,0x628a0523,0x2c5600ea}},	//   _þig_, _rsha_, lmfo, kādu_,
   {{0x7afd0a75,0x764e7477,0x648300ab,0xaa7b0187}},	//   uwst, _omby, sõig, stým,
   {{0x260c0066,0x00000000,0x00000000,0x00000000}},	//   _डोली_, --, --, --,
   {{0x7a300523,0x00000000,0x00000000,0x00000000}},	//   _nätu, --, --, --,
   {{0xa2cd05dc,0x764eacf5,0x940b167e,0x68310523}},	//   _सिल्, _amby, _सोंच_, _lådv,
   {{0x387e000d,0x7bcd01ed,0x00000000,0x00000000}},	// [c970] îtra_, _idau, --, --,
   {{0x2901006d,0x6aad0054,0x24847b11,0x20060098}},	//   _tsha_, _itaf, _ahmm_, _laoi_,
   {{0xdb04008a,0x29012d5f,0xa8a402fb,0x09e30033}},	//   _heið, _usha_, _пряк, য়দা,
   {{0x4429064b,0x628a053e,0x683800b8,0x200626c9}},	//   ða_, emfo, _jídl, _naoi_,
   {{0x6aad0024,0xfe7800c7,0xfbdf021d,0x7bcd034d}},	//   _jtaf, klį_, liês_, _mdau,
   {{0x6aad002f,0xd49b2cdd,0xdb04008d,0x00000000}},	//   _mtaf, _гра_, _meið, --,
   {{0x6f02acf6,0xdb0400fb,0x20890340,0x32050160}},	//   _asoc, _leið, ойки_, _valy_,
   {{0x7a3002c9,0x65940043,0xd00e0079,0x66076b29}},	//   _hätt, _часу, للى_, _hajk,
   {{0x7a30007c,0x2c210099,0x66071793,0x1f650d13}},	//   _kätt, यानं_, _kajk, ьким,
   {{0xf1a70ece,0x7bcd0012,0x7a30acf7,0x648300ab}},	//   _хран, _adau, _jätt, sõid,
   {{0x20060514,0x660701cc,0xd9e30083,0x63a4008a}},	//   _faoi_, _majk, য়াম, þing,
   {{0x7a30022a,0x6fd604d4,0xdb040093,0x00000000}},	//   _lätt, rücü, _beið, --,
   {{0xf1d10066,0x7bcd099e,0x8d770919,0x63a9034d}},	//   _सयान, _ddau, _کاشا, _mfen,
   {{0x66071ac4,0x7a301ab7,0x6838002a,0x00000000}},	//   _najk, _nätt, _pído, --,
   {{0x6f0daae6,0x00000000,0x00000000,0x00000000}},	//   _šach, --, --, --,
   {{0xf772500b,0x2fdf011e,0x00000000,0x00000000}},	//   ناء_, ngug_, --, --,
   {{0x7a3006d7,0x66077d3f,0x2fc0007c,0x59af00b8}},	// [c980] _bätt, _bajk, _õige_, _ज्वर,
   {{0x6607025c,0x63a90103,0xaad30099,0xb3a90448}},	//   _cajk, _afen, _तितक, şılı,
   {{0x29040029,0xca3700a5,0x888601af,0x6831008c}},	//   āmas_, _חניה_, _олож, _rådv,
   {{0x25fa006a,0x660701a3,0x68310b3e,0x3b120055}},	//   _उसकी_, _eajk, _bådu, _kryq_,
   {{0x59d22095,0x7c3d01f4,0x6607acf8,0xa2c10ed1}},	//   _तयार, ërri, _fajk, _रौद्,
   {{0x27e0acf9,0x63a9acfa,0x386d5a76,0x999a0355}},	//   lgin_, _efen, čere_, _popř_,
   {{0x2c0e006a,0x63a9acfb,0x0ef8111a,0x6abd074f}},	//   ियां_, _ffen, ्ट्स_, _्ट्र,
   {{0x27e0a7f7,0x6e2a393b,0x7af6148a,0x2484010d}},	//   ngin_, _sofb, _opyt, _uhmm_,
   {{0x6442004f,0x7a30194e,0x6d5501ef,0x7d0300ec}},	//   mhoi, _jäts, úzan, _asns,
   {{0x6838024e,0x442602c6,0xdb040093,0xddc80035}},	//   _sídl, ljo_, _reið, widł,
   {{0xb1430cd0,0x6aadacfc,0x4426010b,0x7af600c7}},	//   _инфл, _staf, ojo_, _apyt,
   {{0x4426acfd,0x3cdf004e,0x64420086,0x800b00b5}},	//   njo_, _कमरे_, nhoi, _ورنہ_,
   {{0xf0472292,0x8ae40210,0x4426acfe,0xa3e10a40}},	//   _تعلی, кірл, ijo_, _दास_,
   {{0xdb04008a,0x68310282,0x00000000,0x00000000}},	//   _veið, _lådt, --, --,
   {{0xdb1d008a,0x7a30022a,0x8c67075c,0x6d5c0037}},	//   masí, _rätt, _отид, úrad,
   {{0x7a30258a,0x27e0acff,0x6607040b,0x442601a8}},	//   _sätt, ggin_, _sajk, jjo_,
   {{0x4426ad00,0x6aadad01,0x290c013c,0x66072083}},	// [c990] djo_, _utaf, ådar_, _pajk,
   {{0xb3a9037a,0x44260409,0x7c2dad02,0x3e790176}},	//   ğımı, ejo_, _hoar, gèth_,
   {{0x7c2dad03,0xb3a9037a,0x2be601d1,0x68310a8c}},	//   _koar, şımı, _कामं_, _bådt,
   {{0x44262e62,0x30f800b4,0xdb160107,0x6831008c}},	//   gjo_, ंबईः_, _idyò, _pådu,
   {{0xe5c70948,0x7c2d0043,0x160a07ba,0x660703ab}},	//   _осво, _moar, _होकर_, _tajk,
   {{0xdd861dbf,0x7c2d2ff9,0x130801e0,0xa3e1046c}},	//   _مو_, _loar, ьній_, _दाव_,
   {{0x2eff00d7,0x442677ef,0x00000000,0x00000000}},	//   wwuf_, bjo_, --, --,
   {{0x7c2dad04,0x2c6401c2,0x6442ad05,0x2bdb00a1}},	//   _noar, kıda_, choi, _भागा,
   {{0x443fad06,0xe37402ee,0x26c9021d,0x7a300282}},	//   _ilu_, _алты, nsao_, _mätr,
   {{0x442d019c,0x26c9ad07,0x26cb0176,0x27e00225}},	//   _hoe_, isao_, _mvco_, zgin_,
   {{0x442d00d1,0x7c2d454a,0x7af6ad08,0x9f4f0453}},	//   _koe_, _boar, _spyt, _pagó_,
   {{0x442d6a09,0xcfe900d1,0x443f0118,0x644a00a2}},	//   _joe_, _رفته_, _jlu_, éfix,
   {{0x7c2d002d,0x442dad09,0x9f4f01f7,0x00000000}},	//   _doar, _moe_, _vagó_, --,
   {{0x442d0006,0x0f560122,0x7a303f67,0x443fad0a}},	//   _loe_, _אינם_, _räts, _llu_,
   {{0x7c2d0012,0x3da602ce,0x27e0ad0b,0x443f2ffd}},	//   _foar, _якщо_, tgin_, _olu_,
   {{0x7b0500c3,0x442d02ce,0x02df00c0,0x7c2d0074}},	//   ättä, _noe_, _नमून, _goar,
   {{0x7bc61cf5,0x27e008cd,0x06863537,0x442608b7}},	// [c9a0] maku, rgin_, еган, vjo_,
   {{0x7bc64f81,0x6b84ad0c,0x442d00cc,0x68310a8a}},	//   laku, _izig, _aoe_, _båds,
   {{0x443f0db2,0x6442004f,0x442dad0d,0x4426ad0e}},	//   _blu_, thoi, _boe_, tjo_,
   {{0x7bc6ad0f,0x4426ad10,0x14d1170c,0x443f0160}},	//   naku, ujo_, _हिरण, _clu_,
   {{0x68e306d7,0x4426ad11,0x38600093,0x77940416}},	//   _ändr, rjo_, mnir_, _شیطا,
   {{0x443f0006,0x6442ad12,0x6b840054,0x4426ad13}},	//   _elu_, shoi, _mzig, sjo_,
   {{0x7bc6ad14,0x443f49bf,0x64420037,0xc05a0210}},	//   kaku, _flu_, phoi, зіп_,
   {{0x386031a2,0x442d1c5d,0x2c64033e,0x68e3082b}},	//   nnir_, _goe_, yıda_, _ånde,
   {{0x64400abf,0x7bc6ad15,0xcee70274,0x09d80033}},	//   _ilmi, daku, едње_, দ্যা,
   {{0x7c2d6a67,0x443f00cd,0x00000000,0x00000000}},	//   _soar, _zlu_, --, --,
   {{0x7c2d002d,0x3860008a,0x6b844296,0x7bc601ec}},	//   _poar, knir_, _azig, faku,
   {{0x629a09ff,0x7bc6ad16,0x00000000,0x00000000}},	//   _hito, gaku, --, --,
   {{0x629aad17,0x7c2d1945,0x2aab392c,0x3eaf0023}},	//   _kito, _voar, ятно_, _gtgt_,
   {{0x629a68a5,0x2c6400d0,0x2aa60168,0x00000000}},	//   _jito, rıda_, _dôb_, --,
   {{0xa3e10006,0x7bc60c4f,0x6b84001c,0x7c2d7b5f}},	//   _दाल_, baku, _ezig, _toar,
   {{0x3860008a,0x629aad18,0xc6a73632,0x6d7b0122}},	//   gnir_, _lito, ержи, _מאוח,
   {{0xd6d11c2d,0x442dad19,0x644301f4,0x7c3d0031}},	// [c9b0] شقا_, _roe_, ënim, ërru,
   {{0x6440ad1a,0x629aad1b,0x442dad1c,0x443fad1d}},	//   _almi, _nito, _soe_, _slu_,
   {{0xdfc60919,0x442dad1e,0x69c7ad1f,0x443fad20}},	//   _پي_, _poe_, maje, _plu_,
   {{0x69c7ad21,0x629a681a,0x13a700bf,0xe3b30c26}},	//   laje, _aito, رنتی_, ارض_,
   {{0x629aad22,0x91e5ad23,0x443f0345,0x260c193c}},	//   _bito, воле, _vlu_, _डोकी_,
   {{0x69c7ad24,0x7bc601d5,0x6440ad25,0x443f0118}},	//   naje, zaku, _elmi, _wlu_,
   {{0xfa130b52,0xa2cd00dc,0x7bc618a6,0xd24e0088}},	//   _সকাল_, _सिक्, yaku, تنو_,
   {{0x62880086,0x443f85bc,0x6458000d,0x34941b81}},	//   _ehdo, _ulu_, évit, _баср,
   {{0x629a00da,0x69c7942e,0x7bc66c90,0x60061397}},	//   _fito, kaje, vaku, тным_,
   {{0x7bc65246,0x69c703c9,0x629aad26,0x7a30017b}},	//   waku, jaje, _gito, _nätp,
   {{0x7bc6ad27,0x0d82093c,0x69c75522,0x6b84006c}},	//   taku, ильн, daje, _szig,
   {{0x629aad28,0x00000000,0x00000000,0x00000000}},	//   _zito, --, --, --,
   {{0xde052ecf,0x38600107,0xdee55084,0xdb1d0132}},	//   _апли, vnir_, _роли, vasã,
   {{0xaad3009a,0xc3320052,0x7bc6ad29,0x69c7ad2a}},	//   _तिरक, סום_, saku, gaje,
   {{0x7bc6ad2b,0xa2c12483,0x3860008d,0x929d0067}},	//   paku, रीत्, tnir_, _osło,
   {{0x200d4efd,0x6443817f,0x3860008d,0x6b844c7a}},	//   ndei_, ūnij, unir_, _tzig,
   {{0x386000fb,0xe5a61c2e,0xe9f90028,0x69c7ad2c}},	// [c9c0] rnir_, визи, _quả_, baje,
   {{0x68380370,0x69c70a78,0x3860008d,0x00000000}},	//   _mídi, caje, snir_, --,
   {{0x69d900c2,0x629aad2d,0x26170a44,0x6838ad2e}},	//   _אַרו, _rito, नाजी_, _lídi,
   {{0x629aad2f,0x779403c5,0x6aa4ad30,0xdb1d0098}},	//   _sito, _میزا, _kuif, lasá,
   {{0x629aad31,0x200d0036,0x6aa400f7,0x2ba7178c}},	//   _pito, ddei_, _juif, कुटा,
   {{0x5333ad32,0xe283081b,0x7bc400ab,0x9c7d01a0}},	//   решт, алчи, _leiu, muče,
   {{0x629aad33,0x64580248,0x2bb50026,0x9c7d011c}},	//   _vito, évis, ंडमा, luče,
   {{0x69c7ad34,0xdfd0004f,0x629aad35,0x6d480bca}},	//   zaje, حية_, _wito, vzda,
   {{0x629a7958,0x26c70254,0x020600af,0x26170099}},	//   _tito, ćnog_, _изан, नाची_,
   {{0x437501c8,0x629a19c1,0x201d016e,0x200d00af}},	//   _суст, _uito, _enwi_, adei_,
   {{0x69c7ad36,0x6d48336f,0x7bc40395,0x27f20345}},	//   vaje, uzda, _beiu, kfyn_,
   {{0xa3ea26c6,0x26cf00b5,0x68380176,0x69c7ad37}},	//   _माफ_, ágok_, _fídi, waje,
   {{0xa3ea0e1d,0x9c7d02dd,0x69c73802,0xfe4605a1}},	//   _मान_, juče, taje, _индо,
   {{0xaa648662,0x6aa4ad38,0x6d4e01ef,0x00000000}},	//   атск, _duif, úbas, --,
   {{0x69c71851,0x27f2001e,0x320c0160,0x6831008c}},	//   raje, ffyn_, _mady_, _bådp,
   {{0x69c7412e,0x6ebf07ba,0x6aa40051,0x8aa70009}},	//   saje, लीवु, _fuif, _ирод,
   {{0x81cd00c8,0x09d800c8,0xf1b400b4,0xc6a40c98}},	// [c9d0] ষ্ট_, দ্ধা, ुरान, архи,
   {{0x7c3dad39,0x7aed0024,0x657c0090,0x00000000}},	//   lksr, _iqat, _byrh, --,
   {{0x69c50069,0x657c00e9,0x73d90183,0xfa340220}},	//   _iehe, _cyrh, едер_, _خريد,
   {{0x69c5ad3a,0xccf300c2,0x7a2b01ae,0x8d5b00a5}},	//   _hehe, יכע_, _nütz, וכבי,
   {{0x69c5005d,0x62350d9e,0x320c00fe,0x05230033}},	//   _kehe, леду, _bady_, পনের_,
   {{0x68380392,0x01650ef3,0x657c05a5,0x7aed0069}},	//   _rídi, лкло, _fyrh, _mqat,
   {{0x69c5ad3b,0x63a4ad3c,0x320c0260,0x3f860107}},	//   _mehe, žina, _dady_, _azou_,
   {{0x69c5ad3d,0xa3ea2fa9,0x4f0920c3,0xa2db0066}},	//   _lehe, _माय_, енин_, _निप्,
   {{0x200d4505,0xe8e100e2,0x7aed0024,0x00000000}},	//   rdei_, _ướp_, _nqat, --,
   {{0x69c5ad3e,0x41c70035,0x6459ad3f,0x7bc40065}},	//   _nehe, _रजिस, liwi, _seiu,
   {{0x6ed80387,0xdb1d00b5,0x00000000,0x00000000}},	//   _मिथु, vasá, --, --,
   {{0x9f050172,0x00000000,0x00000000,0x00000000}},	//   _موصو, --, --, --,
   {{0xa3e10006,0x69c5ad40,0xa2db05e7,0xeb970421}},	//   _दाई_, _behe, _निफ्, лию_,
   {{0xa2db11b5,0x9c7d00cd,0xfaa32ef5,0x69c50448}},	//   _निन्, vuče, саро, _cehe,
   {{0x69c5ad41,0xd9433ec2,0xa2ca0761,0xdb1d01ef}},	//   _dehe, бери, _सौन्, rasá,
   {{0x69c51292,0x7d7a0070,0x2c1a0035,0x2b5500d1}},	//   _eehe, _אנצו, धाओं_, ایید_,
   {{0x69c5ad42,0x6459ad43,0x27f2ad44,0xb8eb018d}},	// [c9e0] _fehe, diwi, rfyn_, _रौ_,
   {{0x69c5ad45,0x9c7d0097,0x1a06496c,0xceb200a5}},	//   _gehe, ruče, _спом, ציב_,
   {{0x320c1b66,0x991600d8,0xa2c17a51,0x2e3a016b}},	//   _rady_, _сьпі, रीस्, עגענ,
   {{0x320c0187,0xf7460009,0x25bf0009,0x43460714}},	//   _sady_, _бемо, _đule_, леев,
   {{0x4caa00c8,0x69c5ad46,0x00000000,0x00000000}},	//   _কিছু, _yehe, --, --,
   {{0x35a30036,0xe2972b6e,0x69c5ad47,0x2d8700f4}},	//   _гарг, гач_, _xehe, _ozne_,
   {{0x320c0097,0x69c10093,0xca7b016b,0x00000000}},	//   _vady_, ðlei, ענצט, --,
   {{0x660e05f5,0x04434db5,0xc03400ed,0xaa7b0093}},	//   _habk, _лесн, рниј, ntýr,
   {{0x320c01c0,0x627b0035,0x44ee031d,0x660e0027}},	//   _tady_, _słoń, lý_, _kabk,
   {{0x1ef7004f,0x660e00fe,0x9e061053,0x00000000}},	//   اعية_, _jabk, учил, --,
   {{0x69c5ad48,0x2d9879ea,0x44ee05d3,0x9c7d011c}},	//   _rehe, äre_, ný_, jučc,
   {{0x69c5ad49,0xa2db0567,0x660e00ea,0xa2c129ad}},	//   _sehe, _निम्, _labk, रीव्,
   {{0xe45702b5,0x44ee0237,0xa2ca2218,0x98aa010b}},	//   ריכט_, hý_, _सौम्, mybę_,
   {{0xdd9400c7,0x44ee0501,0x850401c0,0x64590067}},	//   _калы, ký_, रबाट_, ziwi,
   {{0x69c5ad4a,0x61f5027d,0x19954ee3,0x00000000}},	//   _vehe, _özle, равя, --,
   {{0x57b5ad4b,0x44ee0187,0x36d500c3,0x3ea60159}},	//   рбат, dý_, иобр, _kuot_,
   {{0x69c5ad4c,0xf9d500af,0x00000000,0x00000000}},	// [c9f0] _tehe, _копэ, --, --,
   {{0x81c200ea,0x00000000,0x00000000,0x00000000}},	//   šēja, --, --, --,
   {{0x6459053e,0x23b511cf,0xc66803e6,0x497400af}},	//   tiwi, لماس, уште_, _глэс,
   {{0xe3150274,0x611c0160,0xa3ea37e8,0x00000000}},	//   имењ, _mălă, _माण_, --,
   {{0x64591d86,0x660e0221,0x27eb0027,0x3a33026e}},	//   riwi, _fabk, _iccn_, _koxp_,
   {{0x6459ad4d,0xa2c10026,0xe80d000c,0x44ee0187}},	//   siwi, रीष्, ाएका_, bý_,
   {{0x90c28490,0xdb0d01ef,0x00000000,0x00000000}},	//   обще, _meañ, --, --,
   {{0x44d101c8,0x3ea6067f,0xc0a801b2,0xf77f0055}},	//   mą_, _buot_, داول_, _kyç_,
   {{0x41e71d05,0x44d13e96,0x534713f9,0xfe4503e6}},	//   _مساف, lą_, _схва, инио,
   {{0xee390afd,0xee3603ad,0x611c0139,0x3ea6004b}},	//   тно_, ины_, _bălă, _duot_,
   {{0x44d1ad4e,0x248d006d,0x216700d8,0x611c002d}},	//   ną_, _khem_, _стаг, _călă,
   {{0x5c561f08,0x2fc60159,0xed56311c,0x9b46028f}},	//   ртоф, _geog_, рою_, لنجو,
   {{0x2ca90009,0x4c6701fd,0xfaa63fe2,0x00000000}},	//   _čadu_, риян_, раго, --,
   {{0x200fad4f,0x44d100d8,0x7f84004f,0x00000000}},	//   _hagi_, ką_, _الهن, --,
   {{0x44d1ad50,0x5d7902b5,0x611c0395,0x98561126}},	//   ją_, _באַק, _gălă, аташ,
   {{0x44ee114d,0x44d13e96,0x09e30083,0x68430d8a}},	//   vý_, dą_, য়গা, онса,
   {{0xe73703ad,0x2ca79bca,0x237f006f,0x200fad51}},	// [ca00] ает_, _hund_, _nyuj_, _magi_,
   {{0x200f402e,0x44ee024e,0x248d0159,0xaa7b008d}},	//   _lagi_, tý_, _ahem_, stýr,
   {{0x89db0122,0x44d11383,0x4ca70033,0x9c7d011c}},	//   _בחיי, gą_, _কৌতু, luča,
   {{0x2ca7071f,0x44ee114d,0x66e6103e,0x04460202}},	//   _mund_, rý_, _кома, једн,
   {{0x63a45710,0x291a025c,0x2fc60932,0xddc1008b}},	//   žino, _hrpa_, _reog_, dolž,
   {{0x248dad52,0x291a040b,0x09d80033,0x44d1297a}},	//   _ehem_, _krpa_, দ্রা, bą_,
   {{0x200f120d,0x3ea60dc3,0x3d1f0035,0xd9ee007c}},	//   _bagi_, _suot_, यमों_, _जानत_,
   {{0x200f33a5,0x64a34991,0x63ad1111,0x3ea60159}},	//   _cagi_, _фата, ñant, _puot_,
   {{0x9c7d10ec,0x91e69351,0xb3a9027d,0xa0670274}},	//   juča, _возе, ğıtı, јања_,
   {{0xa2db0302,0x2ca77056,0x2c720187,0x9c7d011c}},	//   _नित्, _bund_, mády_, duča,
   {{0x2a780176,0x2c720097,0x00000000,0x00000000}},	//   dorb_, lády_, --, --,
   {{0x3ea6081b,0x200fad53,0xdb0600fd,0x00000000}},	//   _tuot_, _gagi_, bbkü, --,
   {{0xba770037,0xbf160df3,0xab870402,0x291a08d7}},	//   لاست, _خوشب, рунк, _arpa_,
   {{0x20041a66,0x6483007c,0x2ca700a5,0x2a780176}},	//   lemi_, võim, _fund_, gorb_,
   {{0x6cd404e8,0x228901ba,0xac950274,0x2ca70107}},	//   _اقبا, núka_, _лакш, _gund_,
   {{0xdff80084,0x61b4035d,0x2004ad54,0x9c7d13a6}},	//   ्जिद_, ुरुष, nemi_, buča,
   {{0x44d1004e,0xcf9302b5,0x7b190fa7,0x249f00f1}},	// [ca10] wą_, ַטע_, _сопр_, _rium_,
   {{0x44d11648,0x200400da,0xd9ee00ab,0xaae600fd}},	//   tą_, hemi_, _जायत_, _اسٹو,
   {{0x248d0189,0x2004ad55,0xd0410095,0xe7ef0567}},	//   _phem_, kemi_, _evlə, _छापा_,
   {{0xa2db0026,0x44d11648,0x2004ad56,0xdcef00cd}},	//   _निद्, rą_, jemi_, žeći,
   {{0x77640133,0x2c72024e,0x44d13e96,0x200f09e7}},	//   _държ, gády_, są_, _ragi_,
   {{0x44d13e96,0x216938d0,0xe81b00be,0x249f0345}},	//   pą_, лили_, _पोता_, _wium_,
   {{0x248dad57,0xd49b027a,0x200fad58,0x66050805}},	//   _them_, _ара_, _pagi_, mehk,
   {{0x27e90452,0x2ca702c9,0x66054367,0x600901f2}},	//   ngan_, _rund_, lehk, уним_,
   {{0x2ca7ad59,0x200f0310,0x27e9ad5a,0xf1e00066}},	//   _sund_, _vagi_, igan_, _नाचन,
   {{0x27e937a5,0xf1f8103b,0x63ad02c4,0x200fad5b}},	//   hgan_, _نعمت_, žand, _wagi_,
   {{0x200fad5c,0x802700b5,0x6ab60345,0x00000000}},	//   _tagi_, _پرام, _styf, --,
   {{0x200400b8,0x69d701dd,0x68380097,0xaadc046c}},	//   cemi_, _adxe, _lídr, _बिदक,
   {{0x660500d7,0xee2ead5d,0x70740037,0x3dc70107}},	//   kehk, _ен_, _بالذ, _tenw_,
   {{0x9c7d0c0a,0x3dcc011e,0x2ca7ad5e,0x2ca00b88}},	//   ruča, cadw_, _tund_, _wiid_,
   {{0xd94309d0,0x6e23ad5f,0xceb40095,0x9c7d011c}},	//   пери, _innb, _çər_, mučn,
   {{0x27e9ad60,0x2fcd099e,0x9c7d0207,0x25bf00f4}},	//   ggan_, naeg_, puča, _đula_,
   {{0x7c24067f,0x81df0033,0xe7ee00b8,0x644a0031}},	// [ca20] _inir, ধ্য_, ङ्गा_, ëfim,
   {{0x27e90014,0x7ae609e7,0x7c360a21,0xa3ea004e}},	//   agan_, mukt, _hoyr, _माह_,
   {{0x68fe06d7,0xeafa2588,0x7ae6ad61,0x69ce5b18}},	//   _uppd, _شرکت_, lukt, mabe,
   {{0x69ce0291,0x032645e0,0xe7ef00fa,0x2c210067}},	//   labe, йден, _छाया_, याएं_,
   {{0x06b20083,0x26cf006c,0x7ae6011e,0x82f700e0}},	//   _চিকি, ágot_, nukt, مروز_,
   {{0xfe670514,0x9c7d068b,0x66050feb,0xd2500037}},	//   _رد_, jučn, cehk, بنت_,
   {{0x2004ad62,0xb3a90716,0x1a9b0070,0x7c24ad63}},	//   temi_, ğırı, ניצע, _onir,
   {{0x62831c90,0x09e10083,0x69cead64,0xab5b033b}},	//   alno, ম্পা, habe, nbüc,
   {{0x69cead65,0x200447e5,0x44240088,0x26d22487}},	//   kabe, remi_, _inm_, nsyo_,
   {{0x2004ad66,0x27e9ad67,0x7c24ad68,0x07370122}},	//   semi_, zgan_, _anir, צאים_,
   {{0x667b00c2,0x69cead69,0x27e90a21,0x78bc00b8}},	//   רטיק, dabe, ygan_, jprv,
   {{0xdee60674,0x9c7d1bd8,0x44240107,0x64420421}},	//   _годи, krče, _jnm_, nkoi,
   {{0xf1ac22a3,0x7c2401ed,0xcf250312,0x644200c3}},	//   _चलान, _dnir, _ورهي, ikoi,
   {{0x69cead6a,0x7c24ad6b,0xa2db06bc,0x27e90008}},	//   gabe, _enir, _निस्, wgan_,
   {{0x27e900e9,0x44240223,0x644200c3,0x00000000}},	//   tgan_, _onm_, kkoi, --,
   {{0x4424009e,0x25eb007c,0x38ae0093,0x7ae65e5c}},	//   _nnm_, _चाही_, _dýr_, bukt,
   {{0x7bcf153c,0x69cead6c,0x27e9ad6d,0x9c7d0097}},	// [ca30] macu, babe, rgan_, lučo,
   {{0x7bcf7691,0x69ce0995,0x27e9ad6e,0x6b8d6feb}},	//   lacu, cabe, sgan_, _izag,
   {{0x6f09033b,0xdb0f021d,0x4424ad6f,0x00000000}},	//   zwec, racõ, _bnm_, --,
   {{0x26cf006c,0x7bcf974c,0xaa7b0501,0x61f80051}},	//   ágos_, nacu, brýc, efvl,
   {{0x3869ad70,0xa3ea020c,0x23291457,0x59bf022e}},	//   mnar_, _मार_, роли_, ्रपर,
   {{0x41e700d4,0xe2994a5b,0x442404a3,0x7a3002b1}},	//   сіда, шал_, _enm_, _sätz,
   {{0x3869ad71,0x7bcf007b,0x00000000,0x00000000}},	//   onar_, kacu, --, --,
   {{0x38692129,0x7ae6011e,0x28e10026,0x4424009e}},	//   nnar_, yukt, _फिनि, _gnm_,
   {{0x3869ad72,0x09e10083,0x2fcd00e5,0x69cead73}},	//   inar_, ম্যা, raeg_, yabe,
   {{0xc0cb3e87,0x3f830029,0x6f09033b,0x69cead74}},	//   _буде_, āju_, rwec, xabe,
   {{0x9c7d1342,0x644901e2,0x3207ad75,0x38697710}},	//   ručn, _klei, meny_, knar_,
   {{0x7bcfad76,0x32070d14,0x7ae601a2,0x69ce0a28}},	//   gacu, leny_, tukt, wabe,
   {{0x69cead77,0xe04202ce,0x3869ad78,0x00000000}},	//   tabe, _інши, dnar_, --,
   {{0x6449ad79,0x2caa0037,0x98a605c2,0x539a011d}},	//   _llei, úidí_, живе, יירו,
   {{0x6b8d0291,0x6449ad7a,0x3ce0004e,0xa3ea3138}},	//   _ezag, _olei, _किये_, _माल_,
   {{0x69cead7b,0x7c2468fb,0x1ae600af,0x3869ad7c}},	//   sabe, _unir, _доим, gnar_,
   {{0x63a4010b,0x35ca0274,0xab5b033b,0x29013dd6}},	// [ca40] žink, игао_, rbüc, _epha_,
   {{0x44241fed,0x645b0037,0x09e10083,0x26d21296}},	//   _snm_, _amui, ম্বা, rsyo_,
   {{0x6449ad7d,0x850600d1,0x25eb00ab,0x3207031d}},	//   _blei, توان, _चारी_, deny_,
   {{0x9c83016f,0x69ba0096,0x64494749,0x765ead7e}},	//   _účto, ्रवी, _clei, sipy,
   {{0x644203ad,0xc8b50d4f,0x4424ad7f,0x00000000}},	//   rkoi, _ولیک, _vnm_, --,
   {{0xa2db0567,0x6449ad80,0x3207ad81,0x6442a506}},	//   _निर्, _elei, geny_, skoi,
   {{0x64490bd1,0xf65f008a,0x00000000,0x00000000}},	//   _flei, _tvær_, --, --,
   {{0x6449ad82,0x09b705f7,0x442400e7,0x7521002a}},	//   _glei, _अभ्य, _unm_, _álza,
   {{0x3207ad83,0x7bcf0160,0x6b843729,0x63ad00f4}},	//   beny_, vacu, _nyig, žanc,
   {{0xa3ea0953,0x386d0bc6,0x24860044,0x3207ac71}},	//   _माँ_, čeri_, llom_, ceny_,
   {{0x644903ad,0x7bcf2278,0x386900a8,0x715a00af}},	//   _ylei, tacu, ynar_, _трас_,
   {{0xa2c1114e,0x9c7d0097,0xe1654d1e,0x6b8401d5}},	//   रीक्, ručo, _عدلي, _byig,
   {{0x38690207,0x7e7a011c,0x248600a0,0x25eb1ef5}},	//   vnar_, potp, ilom_, _चाली_,
   {{0x6f02093b,0x7bcf0453,0xda7b536e,0x3eb9574b}},	//   _ipoc, sacu, рям_, íste_,
   {{0xa3ea0f09,0x248619be,0x3869055b,0x7bcf0139}},	//   _मां_, klom_, tnar_, pacu,
   {{0x765c0297,0x2c210035,0x32070314,0x6e38029e}},	//   _amry, याओं_, zeny_, _hovb,
   {{0x3869ad84,0x248601ba,0x25ab0274,0x6b8d04fb}},	// [ca50] rnar_, dlom_, ађен_, _uzag,
   {{0xe81b0302,0xd5bb1517,0x6449ad85,0xf1bf0019}},	//   _पोरा_, рса_, _slei, _đáo_,
   {{0x6449ad86,0xd49b0272,0x38690364,0x32077797}},	//   _plei, ард_, pnar_, veny_,
   {{0x3cfb02b5,0x248605e2,0x6aadad87,0x44270037}},	//   שלאנ, glom_, _kuaf, غراف,
   {{0x320705d1,0x6449053e,0x069b00d1,0x7bcd00a2}},	//   teny_, _vlei, _نخست_, _meau,
   {{0x6aadad88,0x644900e9,0x6e38ad89,0xe6010421}},	//   _muaf, _wlei, _novb, ävää,
   {{0x2486ad8a,0x661501a3,0x768b027d,0x3207ad8b}},	//   blom_, _iazk, lüyo, reny_,
   {{0x3207ad8c,0xe45fad8d,0x644900af,0x661501d7}},	//   seny_, _öö_, _ulei, _hazk,
   {{0x63a9ad8e,0x661500d8,0x768b01d6,0xddc3042a}},	//   _igen, _kazk, nüyo, _ajnš,
   {{0x5bb60c03,0xfe71004f,0x661501ed,0x6b8404fb}},	//   ूर्व, عدة_, _jazk, _ryig,
   {{0x6615ad8f,0x7bcd0e15,0x3eb90029,0x63a90107}},	//   _mazk, _beau, ūst_, _kgen,
   {{0x7bcd002d,0x801400d4,0x661501a3,0x63a90069}},	//   _ceau, _офіц, _lazk, _jgen,
   {{0x7ff403c5,0x63a90054,0x7d1a006d,0xd5cb1579}},	//   _آسما, _mgen, avts, िराज,
   {{0xdb0f0082,0x25fd0e6f,0x661501a3,0xc33200a5}},	//   ódái, र्मी_, _nazk, תוך_,
   {{0x660a0669,0x929d006a,0x8c4600af,0x291ead90}},	//   _ölkə, _usłu, _неке, íta_,
   {{0x63a9ad91,0x63a45710,0x6aad009e,0x7bcd02a2}},	//   _ngen, žini, _fuaf, _geau,
   {{0x62810f44,0x38600103,0x661506a2,0x6d410768}},	// [ca60] _oklo, riir_, _bazk, lyla,
   {{0x3860ad92,0xa59600c3,0x00000000,0x00000000}},	//   siir_, прещ, --, --,
   {{0x6d41ad93,0xe9f901a5,0x2c2100a1,0x24867615}},	//   nyla, _huế_, याचं_, tlom_,
   {{0x3a3a4c13,0x6d5c0079,0x7e610051,0x00000000}},	//   _hopp_, úrai, hilp, --,
   {{0x3a3aad94,0x7e6100c3,0x937a1015,0x248600f4}},	//   _kopp_, kilp, حصار_, rlom_,
   {{0x26c0ad95,0x24860168,0x63a91e8b,0x6d41ad96}},	//   mpio_, slom_, _egen, kyla,
   {{0x6d418055,0x2bed00a1,0x40341583,0x6f02ad97}},	//   jyla, _झालं_, дейс, _spoc,
   {{0x6d410a8a,0x63a90103,0x3a3a01ff,0x00000000}},	//   dyla, _ggen, _lopp_, --,
   {{0x1be60437,0x9c7d0009,0x3a3a00d5,0x00000000}},	//   _काजल_, bučj, _oopp_, --,
   {{0x932500d1,0x7bcd4b31,0x63a9023a,0x00000000}},	//   _ترفن, _seau, _zgen, --,
   {{0xc04f00d4,0x44d80260,0x7bcd000d,0x41bb00a5}},	//   _зі_, nč_, _peau, _הצבע,
   {{0xf0440919,0x00000000,0x00000000,0x00000000}},	//   _تعطی, --, --, --,
   {{0xa3ea0ccf,0x9c7d3c4e,0x6aad046a,0x7e61ad98}},	//   _माई_, lučk, _quaf, bilp,
   {{0x59bf021a,0x8f9b00a5,0xadbc010b,0x00000000}},	//   ्रधर, _הידי, _такi, --,
   {{0x26c7011c,0x6615008b,0x23cc012f,0x8ca60035}},	//   ćnom_, _razk, ाराद, _घंटो,
   {{0xb9052afe,0xf1bf0019,0xe8e00019,0xb8f500b4}},	//   _नि_, _đám_, _giọt_, _हब_,
   {{0x2bc321b2,0xb8f40e1d,0x78a60345,0x661501b7}},	// [ca70] _व्या, _सौ_, _dikv, _pazk,
   {{0x929d004e,0x768b027d,0xddc80009,0xe2a300e2}},	//   _opła, rüyo, hodž, _chữ_,
   {{0x58d40086,0x9c7d536c,0x64430279,0x13f5010b}},	//   _поэт, jučk, ênio, дзея,
   {{0x9f9d00c9,0x628105e2,0x99750067,0x00000000}},	//   nção_, _sklo, _męża_, --,
   {{0x9f9d03e6,0xddc8022f,0x661500a0,0x6d411140}},	//   ição_, dodž, _tazk, zyla,
   {{0x386d003d,0x59bf112b,0xc244010b,0x00000000}},	//   čeru_, ्रिर, ннік, --,
   {{0x9c7d00cb,0x25fd0099,0x7e614182,0x628108b7}},	//   ručj, र्णी_, vilp, _vklo,
   {{0x63a9ad99,0xf9940070,0x78b800b5,0x1c1d007c}},	//   _ugen, ערק_, _évve, _बोलल_,
   {{0x25fd0517,0x59bf0253,0xf1a71403,0x64ac00a8}},	//   र्थी_, ्रार, _ерен, _eşid,
   {{0x3ebfad9a,0x6281326f,0x9c7d022f,0x00000000}},	//   rput_, _uklo, vrča, --,
   {{0xac0a6823,0x6f1b0207,0x3ebf0be2,0x00000000}},	//   онна_, svuc, sput_, --,
   {{0xd9c60084,0x9c7d0254,0x09c6022e,0x26c7011c}},	//   वर्ट, trča, वर्य, ćnoj_,
   {{0x6d41ad9b,0xe9f90023,0xa2c10099,0x3a3aa1e2}},	//   syla, _quế_, रीच्, _popp_,
   {{0x9f9d0370,0xb69b0139,0x00000000,0x00000000}},	//   ação_, _spân, --, --,
   {{0xad2505f5,0xfaa3488b,0xed59002d,0x00000000}},	//   _زرغو, таро, _фой_, --,
   {{0x9f9d0370,0x68e105ee,0x00000000,0x00000000}},	//   cção_, álda, --, --,
   {{0x3a3aad9c,0x18670279,0xd7ef0037,0xb8d513a0}},	// [ca80] _topp_, фати_, شكل_, _छू_,
   {{0xa5f70202,0x26c0ad9d,0x2fcf0044,0xb9c600ad}},	//   међу_, rpio_, _legg_, _تقدي,
   {{0x78a6011c,0xf8d200ab,0x26c00124,0x291c00fd}},	//   _tikv, _तबिय, spio_, _éva_,
   {{0x26c01d13,0x2d87053e,0x3ce00354,0x00000000}},	//   ppio_, _myne_, _किसे_, --,
   {{0xd12f00f8,0x2d8703bc,0x648300be,0x929d0067}},	//   یمه_, _lyne_, võit, _spła,
   {{0x2d8b0755,0xd36f0079,0x25fd00b4,0x934301d3}},	//   ęcej_, جهه_, र्दी_, ънче,
   {{0xd5ad0332,0xa6b00083,0x2fcf009e,0x20d30079}},	//   _اہم_, _ছবিট, _begg_, نتيج,
   {{0x8f46ad9e,0x3ea7ad9f,0x9c7d00c5,0x3eaf0b3e}},	//   дход, _aint_, ručk, _bugt_,
   {{0x3ea7ada0,0xdefa00d8,0x69de08b7,0x929d0035}},	//   _bint_, цый_, _odpe, _wpła,
   {{0x3eb92587,0x9c7d0ab0,0x648300ab,0x3ea70282}},	//   ísta_, muči, sõit, _cint_,
   {{0x9c7d01cc,0x59bf0355,0x260f0067,0x00000000}},	//   luči, ्रसर, ड़ती_, --,
   {{0x2d8752f3,0x3eaf0b3e,0xcf4600af,0xdb160260}},	//   _dyne_, _fugt_, _оней, _reyò,
   {{0xccf8000c,0x3ea74409,0x9f9d03e6,0x9c7d00d8}},	//   stě_, _fint_, rção_, nuči,
   {{0x69a001d1,0x2d870345,0x00000000,0x00000000}},	//   _गृही, _fyne_, --, --,
   {{0x9f9d03e6,0x628a00d7,0xd83f01ba,0x00000000}},	//   pção_, ilfo, áčov_, --,
   {{0x9c7d1001,0xa3ea000c,0x3ea70051,0x764e016e}},	//   kuči, _माग_, _zint_, _alby,
   {{0x9c7d0496,0x81e60083,0xa03b0070,0xd83f0009}},	// [ca90] juči, য্য_, קעמפ, ščov_,
   {{0x9c7d0bc5,0xa56708cf,0x2ca90098,0x00000000}},	//   duči, ودان, _hiad_, --,
   {{0xdcf80080,0x69d5ada1,0x67d504bf,0x69c701f4}},	//   _izvē, maze, _пону, mbje,
   {{0x442956d8,0x25eb0302,0x59bf0066,0x6483007c}},	//   ña_, _चाकी_, ्रवर, võis,
   {{0xba7400d1,0x38b50b87,0x9c7dada2,0x932737a4}},	//   _سایت, _hår_, guči, بران,
   {{0x7bdf0211,0x02e00380,0x69d5ada3,0x611300a8}},	//   _ldqu, _निरभ, naze, _hələ,
   {{0xa2db0f0d,0x3ea7009e,0x2fcf023a,0xd13101b2}},	//   _निक्, _rint_, _pegg_, امع_,
   {{0x3ea73b9e,0x659454b8,0x2ca9006d,0x9c7d010b}},	//   _sint_, _расу, _niad_, buči,
   {{0x69d50393,0xdb160093,0x63bb1596,0x2d87ada4}},	//   kaze, _neyð, _ifun, _syne_,
   {{0x69d5ada5,0xd9ee007c,0x3eaf0051,0x2d870298}},	//   jaze, _जाइत_, _vugt_, _pyne_,
   {{0x38b50b41,0x3ea7ada6,0x63a400d8,0x69c70a8a}},	//   _når_, _vint_, žint, dbje,
   {{0x3ea7ada7,0x2ca900f1,0x6e2a0107,0x6113013b}},	//   _wint_, _ciad_, _enfb, _nələ,
   {{0x63bb5ba0,0xe7e3111a,0x69d53815,0xf092016b}},	//   _mfun, गणना_, faze, _ענד_,
   {{0x69d5ada8,0xdb1605ee,0x200d01d7,0xaa7b0097}},	//   gaze, _deyð, leei_, brým,
   {{0x61130095,0x63bb018e,0x9c83008b,0x00000000}},	//   _bələ, _ofun, ščaj, --,
   {{0x25fd13a0,0x160232b1,0x63bb018e,0xf7720037}},	//   र्सी_, र्नर_, _nfun, هاء_,
   {{0x2c00065a,0xc0520317,0x69da1459,0x69d5ada9}},	// [caa0] ष्णू_, אזן_, ótes, baze,
   {{0x38b51e74,0x63bb0ce7,0xe617adaa,0xd91004e8}},	//   _får_, _afun, нду_, _پیر_,
   {{0x38b50c7d,0x24840a4e,0x044610b0,0x611300a8}},	//   _går_, _pkmm_, нежн, _fələ,
   {{0x611301c2,0x293702b5,0x2ba70066,0x00000000}},	//   _gələ, _נאכן_, _गणमा, --,
   {{0x25fd009a,0xbb3b02b5,0x200d01d7,0xa2ca00e7}},	//   र्ही_, ּעצי, deei_, _सौख्,
   {{0x63bb001c,0x387f0207,0xb4250647,0x00000000}},	//   _efun, čure_, _یعقو, --,
   {{0x63bb35db,0x00000000,0x00000000,0x00000000}},	//   _ffun, --, --, --,
   {{0x64a37386,0xdfd0004f,0x69c70254,0x9c7dadab}},	//   _баса, جية_, zbje, puči,
   {{0x64ac0723,0x25fd143a,0x2ca9adac,0x7bdfadad}},	//   _eğit, र्वी_, _riad_, _rdqu,
   {{0x2ca90082,0x28e10006,0x63a402c6,0xdb16003e}},	//   _siad_, _फिलि, žins, _reyð,
   {{0x9e03004b,0x82770070,0xdb16008d,0x4d9801e0}},	//   учыл, _טעמע_, _seyð, ькою_,
   {{0xf1bf00e2,0x38b50044,0x2ca90069,0x00000000}},	//   _đái_, _rår_, _qiad_, --,
   {{0xdb1d00b5,0x6254009e,0x38b5362b,0x00000000}},	//   vasó, _càog, _sår_, --,
   {{0x63ad4f85,0x79a70dec,0x6d5c0042,0x160202b4}},	//   ñanz, ербе, úras, र्मर_,
   {{0x69d5adae,0x2db700a5,0xdb1d0079,0x67d5311c}},	//   raze, _אלון_, tasó, кову,
   {{0x38b59cd4,0x61130095,0x69d5adaf,0x62540211}},	//   _vår_, _qələ, saze, _fàog,
   {{0x8aa70b3a,0xdb1d0037,0x69d50279,0x16020240}},	// [cab0] _прод, rasó, paze, र्भर_,
   {{0xb71400c3,0xd9ee00ab,0x00000000,0x00000000}},	//   ыдущ, _जाएत_, --, --,
   {{0x611301c2,0x7afd721c,0x7c2dadb0,0x63bb3224}},	//   _tələ, ltst, _knar, _pfun,
   {{0xe3b01301,0x7afd0136,0x7af200b8,0x9fb50355}},	//   مره_, otst, šetř, třík_,
   {{0x14741062,0x7c2d0cdf,0xdd8603fc,0x7c3f009f}},	//   دالج, _mnar, _چو_, _moqr,
   {{0xdd86064e,0x25fd0af9,0x98be010b,0x7afdadb1}},	//   _نو_, र्शी_, štą_, itst,
   {{0x7c2dadb2,0x65940aec,0x9c7d011c,0x7afd1167}},	//   _onar, _бару, luču, htst,
   {{0x63bb2f59,0x7afd057f,0x712405f5,0x00000000}},	//   _ufun, ktst, ارول, --,
   {{0xe80302cb,0x442dadb3,0x1e951353,0x52150949}},	//   ऱ्या_, _ine_, крор, _идат,
   {{0x7aefadb4,0x443f12b0,0x7afd4793,0x338400d8}},	//   duct, _hou_, dtst, _сусв,
   {{0x443f0c1f,0xed590109,0x2bc302cb,0x7afd01bf}},	//   _kou_, фон_, _व्हा, etst,
   {{0x443fadb5,0x442d0d4c,0x7afd3af4,0x7c2d009e}},	//   _jou_, _jne_, ftst, _cnar,
   {{0x7afd1736,0x443fadb6,0x442d024e,0x160234c0}},	//   gtst, _mou_, _mne_, र्डर_,
   {{0x443fadb7,0x62834018,0x442d7575,0x00000000}},	//   _lou_, nono, _lne_, --,
   {{0x442d01f3,0x7afd939d,0x7c3f009f,0x443f0107}},	//   _one_, atst, _foqr, _oou_,
   {{0x443fadb8,0x442d000e,0x63ad1851,0x6283adb9}},	//   _nou_, _nne_, žanj, hono,
   {{0xe61a0036,0x98a30f94,0xa68605c2,0x68ee012f}},	// [cac0] мда_, рите, влад, subd,
   {{0x442dadba,0x6283278a,0xfaa62147,0x443fadbb}},	//   _ane_, jono, _шапо, _aou_,
   {{0x443fadbc,0x25ba00ea,0x64a60402,0x00000000}},	//   _bou_, rcpl_, важа, --,
   {{0x3d19004e,0xb6090029,0x443fadbd,0x999a0359}},	//   _बनने_, _atšķ, _cou_, _rapň_,
   {{0x6283adbe,0x04430202,0x442d16dc,0xd36f004f}},	//   fono, јечн, _dne_, يهم_,
   {{0xfe6717bd,0xf5061578,0x26c2025c,0x00000000}},	//   _ضد_, _изго, _itko_, --,
   {{0x443fadbf,0xd46a258d,0xd1300037,0x320e0067}},	//   _fou_, _живе_, صمة_, refy_,
   {{0x44fcadc0,0x661cadc1,0x443fadc2,0x442d0284}},	//   mí_, _hark, _gou_, _gne_,
   {{0x44fcadc3,0x661cadc4,0x7afd013c,0xd007015a}},	//   lí_, _kark, xtst, тење_,
   {{0x7c2d0557,0x443f04ce,0x6283adc5,0xd9ee0302}},	//   _snar, _zou_, cono, _जागत_,
   {{0x443f35d9,0x6440a6bf,0x44fcadc6,0x442d0031}},	//   _you_, _komi, ní_, _yne_,
   {{0x7afd02ce,0x98aa00d8,0x644000c7,0x443f0176}},	//   ttst, mybė_, _jomi, _xou_,
   {{0xee3a0036,0x7b640370,0x44fc00a0,0x7afd2fe4}},	//   _онд_, атре, hí_, utst,
   {{0x661cadc7,0x7aefadc8,0x7afd479d,0x64402a99}},	//   _nark, ruct, rtst, _lomi,
   {{0x44fc000c,0x7aef01a2,0x7afdadc9,0x2b4d6646}},	//   jí_, suct, stst, šec_,
   {{0x44fcadca,0x6440adcb,0x7afdadcc,0x7c2dadcd}},	//   dí_, _nomi, ptst, _unar,
   {{0x661cadce,0xa3e602e4,0x443fadcf,0x62839dd1}},	// [cad0] _bark, पणन_, _rou_, yono,
   {{0x443fadd0,0x6b8d007b,0x9c7d0690,0x6283add1}},	//   _sou_, _iyag, ruču, xono,
   {{0x443f3285,0xd9d90083,0x6440add2,0x442d8a8f}},	//   _pou_, _তাপম, _bomi, _pne_,
   {{0x6283ac87,0x661c01ed,0x6b8d018e,0x6d5a0b9b}},	//   wono, _eark, _kyag, izta,
   {{0x661cadd3,0x443fadd4,0xfaff00da,0x91e50370}},	//   _fark, _vou_, ntë_, голе,
   {{0x443fadd5,0x3869add6,0x44fc0bca,0x20063bd6}},	//   _wou_, liar_, bí_, _aboi_,
   {{0xfaff08e3,0x443f142f,0x44fcadd7,0x64ac0463}},	//   htë_, _tou_, cí_, _işin,
   {{0x442dadd8,0x6440add9,0xef194b02,0xae1b13ab}},	//   _une_, _gomi, еми_, _भोजन_,
   {{0xfaff00da,0x6b8d01d5,0x6d5aadda,0xd5a70ac4}},	//   jtë_, _nyag, ezta, _कृतज,
   {{0x91ca0067,0xc0cb002d,0x260602b4,0x00000000}},	//   _स्पै, _жуде_, स्पी_, --,
   {{0x6b8d0273,0x8c4632dc,0x644002d7,0xdfd10079}},	//   _ayag, гене, _yomi, _هيا_,
   {{0xfaff00da,0x80d00083,0x6b8d01d0,0x7d180160}},	//   ftë_, সংখ্, _byag, _dsvs,
   {{0xdee509d0,0x3869ad71,0x44fc033a,0x6d5a06a2}},	//   _соли, diar_, zí_, azta,
   {{0x6a8600af,0x64b702c4,0x6b8d021e,0x201d034d}},	//   улга, _aćim, _dyag, _hawi_,
   {{0x7c2f004f,0x610a0095,0x201d00f8,0x3869addb}},	//   áirí, _gəld, _kawi_, fiar_,
   {{0x44fc033a,0x201d00bf,0x3869addc,0x70d106d9}},	//   ví_, _jawi_, giar_, _सबैल,
   {{0x290501d6,0x201d325b,0x9c7d0187,0x5baa01e0}},	// [cae0] çlar_, _mawi_, ručt, _яким_,
   {{0x44fc114d,0x6440addd,0xe5a612a2,0x661c01f4}},	//   tí_, _somi, гизи, _qark,
   {{0xd94620a6,0x44fc03e6,0x7bd600d7,0x13ea0012}},	//   _сени, uí_, _keyu, емей_,
   {{0x44fcadde,0x629a00da,0x661caddf,0x201d2bd6}},	//   rí_, _shto, _wark, _nawi_,
   {{0x661cade0,0x44fcade1,0x6d480035,0x7bd60103}},	//   _tark, sí_, zyda, _meyu,
   {{0x5b7b0070,0x661c422c,0x44fcadc3,0x98aa010b}},	//   ערסא, _uark, pí_, tybė_,
   {{0x6440ade2,0x201dade3,0x05270b3a,0x291a013a}},	//   _tomi, _bawi_, _йорк_, _jspa_,
   {{0x644002fb,0x6d484e20,0x00000000,0x00000000}},	//   _uomi, vyda, --, --,
   {{0x6d4800e9,0x61f60037,0x8bfa0831,0xd2590260}},	//   wyda, _مساء, ইজান_, _twņp_,
   {{0x715a4c14,0x386901a3,0x6d48ade4,0x9c7d0506}},	//   _прес_, ziar_, tyda, mrči,
   {{0x5c7508ce,0xdd9400d8,0x127b0070,0x6b8d0345}},	//   илот, раны, _טאמע, _syag,
   {{0x6d48ade5,0xdd970409,0x09bf3010,0x201d129d}},	//   ryda, ышы_, ्र्य, _gawi_,
   {{0x38699472,0x6d5aade6,0x672402c4,0x3cfe023a}},	//   viar_, szta, jvij, sttv_,
   {{0xfaff01d2,0x28b600dc,0xc98702f3,0x2486006d}},	//   rtë_, _आंशि, губи, hoom_,
   {{0xfaff00da,0x67240029,0xaa7b0187,0x321e05a6}},	//   stë_, evij, krýv, _maty_,
   {{0x6b8d010d,0x3d1922c7,0x610a013b,0xfaff0055}},	//   _tyag, _बनते_, _kəlb, ptë_,
   {{0x38690044,0xfaff01f4,0x291a8169,0x2486081b}},	// [caf0] riar_, qtë_, _espa_, doom_,
   {{0xd01d00c8,0x386909e7,0x7bd60103,0x00000000}},	//   থায়_, siar_, _zeyu, --,
   {{0x6f040139,0x00000000,0x00000000,0x00000000}},	//   _ţicl, --, --, --,
   {{0xc4350580,0xe78706cd,0x59bf01d1,0x69d7ade7}},	//   جکست, _буго, ्रकर, _hexe,
   {{0x201d046a,0xb7da00a5,0x69d78a9a,0x67240207}},	//   _rawi_, _בקרי, _kexe, cvij,
   {{0x26c90c99,0x21690036,0x61fa002a,0x201d2637}},	//   mpao_, кили_, _cctl, _sawi_,
   {{0x2486541f,0x69d792ba,0x321e5c7a,0x20550adb}},	//   boom_, _mexe, _daty_, итир,
   {{0x69d7076c,0xdb1d00ab,0x7e780160,0x00000000}},	//   _lexe, lasõ, _ajvp, --,
   {{0x7bd6ade8,0x00000000,0x00000000,0x00000000}},	//   _reyu, --, --, --,
   {{0x0e651d32,0x3eae17d5,0x9e65027a,0xdb1d00be}},	//   ркон, _cift_, рвод, nasõ,
   {{0xa3e9021a,0xa115006c,0x67241851,0x201d002f}},	//   _मया_, _خوات, zvij, _tawi_,
   {{0x8b26010b,0x291a009e,0x7d040207,0x00000000}},	//   адме, _rspa_, _ćist, --,
   {{0x3084004f,0x20d30043,0xe8e00019,0x543a0070}},	//   _النف, lţi_, _kiệt_, דערא,
   {{0x2486ade9,0x6da5034b,0x3eae293a,0x2ba70127}},	//   zoom_, _кила, _gift_, _गणरा,
   {{0x290cada6,0x20d30043,0x69d7adea,0x2486022e}},	//   ïda_, nţi_, _dexe, yoom_,
   {{0x67240ae0,0x7ae90254,0xe8e00019,0x20d300af}},	//   tvij, šeta, _liệt_, iţi_,
   {{0x09e6244d,0x1666576e,0x248602c4,0x00000000}},	// [cb00] _копн, авам, voom_, --,
   {{0x67240029,0xdb9b00a5,0xd5eb00e2,0x9adb025a}},	//   rvij, _בספר, _địn, _שחיט,
   {{0x6724025c,0x321e0067,0xa2d806fe,0x00000000}},	//   svij, _raty_, नीन्, --,
   {{0x03260439,0x69dcadeb,0x69d7012f,0x321e148a}},	//   иден, lare, _zexe, _saty_,
   {{0xe8e00028,0x321eadec,0x59da000c,0x69dc01d7}},	//   _biệt_, _paty_, _बजार, oare,
   {{0x69dcaded,0x2eed001e,0x2486adee,0x6ce50826}},	//   nare, dref_, soom_, _किंग_,
   {{0xe8e00019,0xdb1f3203,0x69dc0f01,0xddc8010b}},	//   _diệt_, _seqü, iare, sidū,
   {{0x6459188f,0xc0340202,0x38bcadef,0xf1064068}},	//   chwi, сниј, _mír_, _शहीद_,
   {{0x25fd1db1,0x610a0095,0x321e2a65,0x20d300af}},	//   र्की_, _qəlb, _taty_, aţi_,
   {{0x69dcadf0,0x38bcadf1,0xeda605c7,0x62720067}},	//   jare, _oír_, ишно, dłog,
   {{0x69d7043f,0x45b702b5,0xc04f368f,0x00000000}},	//   _rexe, יפיל_, _ді_, --,
   {{0x26060302,0x98be000c,0x69d7adf2,0x4cb80083}},	//   स्ती_, ště_, _sexe, _আবদু,
   {{0x69dcadf3,0x69d740e7,0x38bc099e,0x6ef300d5}},	//   fare, _pexe, _aír_, ržbá,
   {{0x69dcadf4,0xdb1d00b5,0x3b00009f,0x5ef30099}},	//   gare, ncsé, _dqiq_, ंढर्_,
   {{0x69d70391,0x7e7d00de,0x5e570070,0x6e3c013c}},	//   _vexe, éspe, _דיגע_, örbu,
   {{0x26c902c4,0x085401e0,0x00000000,0x00000000}},	//   tpao_, овсю, --, --,
   {{0x7bdd0f1a,0x69d70223,0x57a702fb,0x00000000}},	// [cb10] masu, _texe, ршва, --,
   {{0x69dcadf5,0x26c90207,0x78a400be,0x00000000}},	//   care, rpao_, amiv, --,
   {{0xe4a7adf6,0x25fd0246,0x6459233c,0xd5b83821}},	//   ардо, र्गी_, thwi, рсу_,
   {{0x68f500d0,0xd0060079,0x64ac0139,0x00000000}},	//   muzd, _عل_, _uşil, --,
   {{0xda0437e8,0x00000000,0x00000000,0x00000000}},	//   श्वत_, --, --, --,
   {{0xf20708a6,0x6459adf7,0x00000000,0x00000000}},	//   рядо, shwi, --, --,
   {{0xe8e000e8,0x7bddadf8,0x2a580122,0x2903006c}},	//   _việt_, kasu, שבון_, ntja_,
   {{0x2eed3cce,0x69dcadf9,0x20d30043,0x260f0084}},	//   tref_, zare, rţi_, ड़की_,
   {{0x69dcadfa,0x7bdd4e33,0xe8e000e2,0x999a0260}},	//   yare, dasu, _tiệt_, _rapō_,
   {{0xee3903fa,0x98c60506,0xa3ca021a,0x00000000}},	//   уно_, _žuči_, ोरथ_, --,
   {{0x4c8665e1,0x249f30bc,0x2901006d,0x2903adfb}},	//   йлов, _khum_, _nqha_, jtja_,
   {{0x7bddadfc,0x28e104bc,0x2245037d,0xed5601e0}},	//   gasu, _फिजि, _holk_, сою_,
   {{0x2245adfd,0x249f0118,0x00000000,0x00000000}},	//   _kolk_, _mhum_, --, --,
   {{0x610a00a8,0x00000000,0x00000000,0x00000000}},	//   _həla, --, --, --,
   {{0x69dcadfe,0x7bdd3742,0x7d1c0093,0x22450116}},	//   rare, basu, ærst, _molk_,
   {{0x69dc1024,0xa3c90066,0x2245008c,0x00000000}},	//   sare, लुम_, _lolk_, --,
   {{0x66e6052a,0xe73718c4,0x78a4adff,0xfc5700a5}},	// [cb20] соза, бет_, rmiv, _לבקש_,
   {{0xcf9200c2,0x38bc004f,0x69dc00a8,0x249f0051}},	//   לטן_, _tír_, qare, _ahum_,
   {{0xf1bf0028,0x25fe0722,0xab5b00a8,0x186aae00}},	//   _đáp_, _लाठी_, bbüs, _бани_,
   {{0x249f09bb,0x7ae40044,0x981621a0,0x60dc03d0}},	//   _chum_, _kvit, _ابدا, _ærmi,
   {{0xf772004f,0x31cf0033,0x00000000,0x00000000}},	//   _راح_, _রাজশ, --, --,
   {{0x94160095,0x46a300d4,0x7bddae01,0x38cb00f8}},	//   _əgər_, _наяв, zasu, _جایی_,
   {{0x29360070,0x7bdd2973,0x2245ae02,0xab5b02b1}},	//   מאַן_, yasu, _dolk_, nbür,
   {{0xc5631ac5,0x7ae4068f,0x8cd20266,0xd1380067}},	//   _экск, _ovit, _भौगो, _rząd_,
   {{0x64a30804,0x68f500f4,0x934305a1,0x2245521d}},	//   _хата, zuzd, _енте, _folk_,
   {{0x7bdd699a,0x6729082d,0x29030093,0x7bc4030d}},	//   wasu, _šejk, ytja_, _afiu,
   {{0x25fd00c0,0x7bdd03cb,0x2ca0009e,0x610a013b}},	//   र्टी_, tasu, _bhid_, _fəla,
   {{0x628aae03,0x2ca088d2,0x00000000,0x00000000}},	//   lofo, _chid_, --, --,
   {{0x7ae4022f,0x3f6700c3,0xab8753b7,0x2ca0034d}},	//   _cvit, _лицо_, сунк, _dhid_,
   {{0x7bdda3df,0x2903ae04,0x09d90083,0x7ae40409}},	//   sasu, ttja_, _তাহা, _dvit,
   {{0x7bdd5d02,0xa3ca00c4,0x195800d8,0x00000000}},	//   pasu, ोरा_, бары_, --,
   {{0x2ca0002d,0x2903ae05,0x4cf732e3,0x2d9c6fc9}},	//   _ghid_, rtja_, _הזהב_, _izve_,
   {{0x2903ae06,0x95d914a1,0x61e84827,0x249f00a2}},	// [cb30] stja_, идат_, _oddl, _rhum_,
   {{0x3a7512dc,0x249f00da,0x68f50207,0x95d80421}},	//   _флор, _shum_, puzd, йдут_,
   {{0x628a01a2,0x04c80bf5,0x7ae436a5,0x69c50024}},	//   dofo, مولي_, _zvit, _ifhe,
   {{0x25fd02b4,0x3cfb02b5,0xd3710c26,0x00000000}},	//   र्जी_, רלאנ, وها_, --,
   {{0x9239ae07,0x212c0031,0x00000000,0x00000000}},	//   ичку_, _ardh_, --, --,
   {{0x610a00a8,0x2d9c00ac,0x628a03d0,0xa4d5010b}},	//   _səla, _ozve_, gofo, _могі,
   {{0x22456d4e,0x249f006d,0xa1560274,0x00000000}},	//   _volk_, _thum_, жају_, --,
   {{0xe2c90088,0x237f0189,0xaec511a7,0xdb2101ba}},	//   _نورو_, _txuj_, обил, _štýl,
   {{0x260600a1,0x91ca0d34,0x2245ae08,0x212c0055}},	//   स्वी_, _स्वै, _tolk_, _erdh_,
   {{0x63ad10ec,0x13de0083,0x7d090274,0x00000000}},	//   žans, _ডায়, аног_, --,
   {{0xc5f202b8,0x7ae4ae09,0xdca64a35,0x1d09117a}},	//   ודי_, _svit, жани, шени_,
   {{0x69c5ae0a,0xb4fa011d,0x00000000,0x00000000}},	//   _afhe, ספרי, --, --,
   {{0x12d70033,0xf1c602b4,0xcf270413,0x69c50312}},	//   _সমুদ, रुवन, _دراي, _bfhe,
   {{0xfc3f0300,0x769000c3,0x2fdf8d1d,0x00000000}},	//   rmía_, näyt, laug_, --,
   {{0x8c460fc5,0x81ab0033,0xd8266195,0x66170065}},	//   _меке, কুর_, одви, dexk,
   {{0x6e23ae0b,0x628a0168,0x2fdf0159,0xab5bae0c}},	//   _hanb, zofo, naug_, rbür,
   {{0xaa7b008d,0x6e23ae0d,0x09d90083,0x769000c3}},	// [cb40] msýn, _kanb, _তারা, käyt,
   {{0x7c2411be,0x6e230359,0xb6a3002d,0x7c2661e8}},	//   _hair, _janb, диул, ldkr,
   {{0x7c24ae0e,0x6e230260,0x628aa90c,0xe3ba15c0}},	//   _kair, _manb, vofo, абе_,
   {{0x6e23ae0f,0x7c261788,0x7c24254a,0xdb0401da}},	//   _lanb, ndkr, _jair, _sgiù,
   {{0x7c24102c,0x2fdf82d0,0xe286141d,0x00000000}},	//   _mair, daug_, олди, --,
   {{0x27e0ae10,0xa90500d1,0x7c24ae11,0x7aeb01b4}},	//   lain_, _ببین, _lair, _ægte,
   {{0x61e8027a,0x12d70033,0x00000000,0x00000000}},	//   _vddl, _সমৃদ, --, --,
   {{0x6e2306ba,0x27e0ae12,0x628a0485,0x7c24ae13}},	//   _aanb, nain_, sofo, _nair,
   {{0x6e23ae14,0x81ab0083,0x44260409,0x00000000}},	//   _banb, কুল_, mdo_, --,
   {{0x4424ae15,0x27e0ae16,0x073700a5,0x00000000}},	//   _ham_, hain_, קאים_, --,
   {{0x4424ae17,0x6e23ae18,0x7c24964f,0x27e0ae19}},	//   _kam_, _danb, _bair, kain_,
   {{0x44262e65,0x4424ae1a,0x7c24ae1b,0x6442ae1c}},	//   ndo_, _jam_, _cair, njoi,
   {{0x4424ae1d,0x7c24ae1e,0x4426ae1f,0x27e0ae20}},	//   _mam_, _dair, ido_, dain_,
   {{0x4424ae21,0x4426ae22,0x64420086,0xfe6f0037}},	//   _lam_, hdo_, hjoi, _لدى_,
   {{0x4426ae23,0x7c246f9a,0x27e034cb,0x00000000}},	//   kdo_, _fair, fain_, --,
   {{0x4424ae24,0x7c240a3e,0x27e0ae25,0x69cb035d}},	//   _nam_, _gair, gain_, _त्री,
   {{0x4426ae26,0xd5bbae27,0xb90200b1,0xf7700037}},	// [cb50] ddo_, асе_, _नौ_, ناك_,
   {{0x4426ae28,0x7c244583,0x2fdf4360,0xe6130037}},	//   edo_, _zair, zaug_, بشر_,
   {{0x7c2447e7,0x2fc60282,0x661701ed,0x00000000}},	//   _yair, _ofog_, rexk, --,
   {{0x27e0ae29,0x44260409,0xfc3fae2a,0x660e01b7}},	//   cain_, gdo_, zmín_, _ebbk,
   {{0x083a0070,0x883a011d,0x769000c3,0x2329081b}},	//   _הערל, _התרו, täyt, соли_,
   {{0x44261423,0x76ba00a5,0xc244010b,0x660e01ed}},	//   ado_, _למשפ, мнік, _gbbk,
   {{0x6e23ae2b,0x4426ae2c,0x2fdf006d,0xa3d50274}},	//   _ranb, bdo_, taug_, _новч,
   {{0x7cc10080,0x4424ae2d,0x6e2302e9,0x397c02b5}},	//   _bērn, _gam_, _sanb, יטונ,
   {{0x610a0095,0x7c2401ef,0xdbd9008a,0x6e23043d}},	//   _həll, _rair, væði, _panb,
   {{0x4424994b,0x7c240086,0x27e006a2,0x2fdf006d}},	//   _zam_, _sair, zain_, saug_,
   {{0x44240d4b,0xfc3f024e,0xdbd9008a,0x645b0b0d}},	//   _yam_, rmín_, tæði, _klui,
   {{0x4424006f,0xf1cf0026,0x160b1db9,0x6e23ae2e}},	//   _xam_, _स्तन, स्तर_, _wanb,
   {{0x7c24ae2f,0x64490903,0xdbd900fb,0xdb080463}},	//   _vair, _moei, ræði, _ölüm,
   {{0x44263980,0x27e0ae30,0xd019004e,0x645b12c3}},	//   zdo_, wain_, leń_, _llui,
   {{0x7c240a24,0x44265a3f,0x27e0ae31,0x26cb01ef}},	//   _tair, ydo_, tain_, _atco_,
   {{0x7c24148b,0xb3422f80,0x00000000,0x00000000}},	//   _uair, şçil, --, --,
   {{0x27e0ae32,0x4426219c,0x00000000,0x00000000}},	// [cb60] rain_, vdo_, --, --,
   {{0x17790a55,0x27e0ae33,0x442423e8,0x4426ae34}},	//   ість_, sain_, _sam_, wdo_,
   {{0x27e0ae35,0x4424ae36,0x69deae37,0x4426999f}},	//   pain_, _pam_, _iepe, tdo_,
   {{0x645b04d6,0x4426ae38,0x4424184b,0x746900d4}},	//   _clui, udo_, _qam_, орів_,
   {{0x4424ae39,0x64420d36,0x69de1b0f,0x3860184f}},	//   _vam_, rjoi, _kepe, mhir_,
   {{0xf7880095,0x69de01f4,0x44240035,0x442601e9}},	//   _neçə_, _jepe, _wam_, sdo_,
   {{0x69de47e7,0x64490345,0x00000000,0x00000000}},	//   _mepe, _foei, --, --,
   {{0xdb160332,0x64490626,0x09b902cb,0x6b84ae3a}},	//   _egyé, _goei, _आल्य, _oxig,
   {{0x09e20083,0xa41106d3,0x2d9a0009,0x59be01c0}},	//   _বানা, lığı_, _špe_, ्डार,
   {{0x69deae3b,0x7ae90a78,0x3ebd0223,0x64490183}},	//   _nepe, šetk, _duwt_, _zoei,
   {{0x38600f1a,0x64b702c4,0xfbe10033,0xcfdb0033}},	//   khir_, _ućit, _ভাবত, _ধারন,
   {{0x6ab52c29,0x00bb0122,0x09c500a1,0x629812ca}},	//   ंद्र, _המאמ, वड्य, llvo,
   {{0x69deae3c,0x386019fd,0x7ac73943,0xcfaa0033}},	//   _bepe, dhir_, ясне, _গ্রন,
   {{0x69deae3d,0xbd010391,0x1aef0033,0x00000000}},	//   _cepe, ñéce, _চঙদে_, --,
   {{0x195800c7,0x69de15b7,0xdd9300d8,0x62980051}},	//   пары_, _depe, _пашы, ilvo,
   {{0xa4110d6f,0x386058df,0xfbc100b4,0x69de1fb2}},	//   dığı_, ghir_, _एलिम, _eepe,
   {{0xf7731b31,0x69de021d,0x644919c1,0x06b702fd}},	// [cb70] رار_, _fepe, _roei, سناک_,
   {{0x645b0903,0x13d50c03,0x69deae3e,0xd019004e}},	//   _slui, दर्भ, _gepe, zeń_,
   {{0x3860004a,0x645bae3f,0x8c200033,0x6449ae40}},	//   bhir_, _plui, ধারন_, _poei,
   {{0x3860ae41,0x7bdf072c,0x765c030d,0x69d502b1}},	//   chir_, _jequ, _elry, lbze,
   {{0x7bdf0176,0x69de0138,0x6ab70024,0x00000000}},	//   _mequ, _yepe, _kixf, --,
   {{0x672dae42,0x7bdf0248,0xc29300f8,0x00000000}},	//   mvaj, _lequ, ریاب, --,
   {{0x672dae43,0xe80a021a,0x644900e2,0x6ed50066}},	//   lvaj, ह्वा_, _toei, _मौजु,
   {{0x7bdf054b,0x610a0095,0x1ec91d30,0x92f20225}},	//   _nequ, _gəlm, олии_, üğüm,
   {{0x2d98190c,0x672d0c06,0x63bb08c7,0x00000000}},	//   üren_, nvaj, _igun, --,
   {{0x69c70124,0x6ab70024,0x00000000,0x00000000}},	//   jcje, _nixf, --, --,
   {{0x61e37015,0x7bdfae44,0x160220a3,0x6abf0069}},	//   manl, _bequ, र्टर_, _auqf,
   {{0x69de120d,0x9ce70332,0xeb9a1d67,0x61e35726}},	//   _sepe, _ہوتے_, жим_, lanl,
   {{0x69de1581,0xe8e001a5,0x25fe04bc,0x09e20083}},	//   _pepe, _thịt_, _लाली_, _বাবা,
   {{0x672d02dd,0x61e36d6c,0xed5951be,0xeab200b5}},	//   dvaj, nanl, _мол_, ئٹس_,
   {{0x3860ae45,0x63bb001c,0x942300a8,0x672d00a0}},	//   thir_, _ogun, şvət_, evaj,
   {{0x6f0961b1,0x63bbae46,0xb8f60006,0x69d5006d}},	//   otec, _ngun, _हऽ_, abze,
   {{0x6f09061b,0x61e33a0c,0x69de3bc8,0x6ab70024}},	// [cb80] ntec, kanl, _tepe, _fixf,
   {{0x63bb1b0f,0x3860ae47,0xa411027d,0x62810118}},	//   _agun, shir_, tığı_, _njlo,
   {{0x044600d8,0x61e3ae48,0x67290124,0x6f09623b}},	//   межн, danl, _šejt, htec,
   {{0x6f09ae49,0x16022450,0x68fcae4a,0xe73a1456}},	//   ktec, र्जर_, murd, _дем_,
   {{0x672d0009,0x61e3ae4b,0x00000000,0x00000000}},	//   cvaj, fanl, --, --,
   {{0x63bb03cb,0x5333002d,0x61e3ae4c,0x23ce0026}},	//   _egun, тешт, ganl, _ह्रद,
   {{0xe8e000e2,0x68fcae4d,0x00000000,0x00000000}},	//   _kiốt_, nurd, --, --,
   {{0xdfd00082,0x2002007c,0x7ae98d3d,0xf1b80069}},	//   دية_, üki_, šeti, _maġi_,
   {{0x7bdf2ac2,0x41cf05f7,0x61e3ae4e,0xb6070024}},	//   _requ, _स्वस, banl, _feġġ,
   {{0x3f980080,0x7bdf1655,0x64ac0644,0x61e300c1}},	//   āru_, _sequ, _eşit, canl,
   {{0x7bdf1423,0xab5b0644,0x85f70070,0x672d08b7}},	//   _pequ, rcüm, וציע_, zvaj,
   {{0x68fc0297,0x3d1e0084,0xfbad0083,0x83fd006c}},	//   durd, _बनीं_, _ক্ষত, _előf,
   {{0x3a3a0159,0x92bc0033,0x6f0900ec,0x69c7ae4f}},	//   _bnpp_, _আবু_, ctec, tcje,
   {{0x8f9b00a5,0x321cae50,0x00000000,0x00000000}},	//   _וידי, nevy_, --, --,
   {{0x199401d3,0x69c701f4,0x68fc9b43,0x00000000}},	//   варя, rcje, gurd, --,
   {{0x61e300c1,0x69c70124,0x672d00f4,0x81ab0033}},	//   zanl, scje, tvaj, কুক_,
   {{0x61e306d3,0x59d00b7a,0x610a00a8,0xe89400c3}},	// [cb90] yanl, _त्वर, _bəlk, тать,
   {{0x7afd22a5,0x68fc01b7,0x09d90033,0x61e300a8}},	//   must, burd, _তাকা, xanl,
   {{0x3de30083,0xb8f40083,0xe8eb0118,0x61e3ae51}},	//   _মামল, _হয়_, _برخو_, vanl,
   {{0x8c1c0070,0xddc80009,0x6f092b6d,0x36d50c95}},	//   ַווי, jndž, ytec, _помр,
   {{0x61e3ae52,0x78ad0c75,0x09e20033,0x6f0900fe}},	//   tanl, mmav, _বাতা, xtec,
   {{0x78ad8ef3,0x62720067,0xfe0e00e2,0x00000000}},	//   lmav, słon, _sững_, --,
   {{0x61e3ae53,0x7afdae54,0x8557006c,0x6f090223}},	//   ranl, hust, _تیار_, wtec,
   {{0x7afdae42,0x61e306a8,0x63bbae55,0xff2576c0}},	//   kust, sanl, _ugun, емио,
   {{0xef160086,0xc6220083,0xfe0e0019,0xe81100a1}},	//   емы_, নারা_, _vững_, ड्या_,
   {{0x6f09ae56,0x61e30095,0x68fc0644,0x78adae57}},	//   rtec, qanl, yurd, hmav,
   {{0x6f09ae58,0xc6920122,0x68fc07f0,0x6459023c}},	//   stec, ראי_, xurd, okwi,
   {{0x6459ae59,0x68fc082b,0xf1bf0023,0x6f09ae5a}},	//   nkwi, vurd, _đáy_, ptec,
   {{0x60c10a2d,0x200a0095,0x00000000,0x00000000}},	//   _hulm, əbi_, --, --,
   {{0x60c1ae5b,0x61e1006c,0xf2d202b5,0x3e6002e9}},	//   _kulm, _jell, רעם_, _pòte_,
   {{0x61e103d0,0xdb1d00b5,0x60c166bd,0x7afd4716}},	//   _mell, rcsá, _julm, aust,
   {{0xfbda0083,0x21250118,0x68fc242d,0x60c1462c}},	//   _থাকত, _mslh_, rurd, _mulm,
   {{0x7afd2f03,0xa5da0037,0x1867ae5c,0xdb1d00fd}},	// [cba0] cust, كبار_, хати_, pcsá,
   {{0x61e10021,0x78ad07e5,0xa92600d8,0x68fcae5d}},	//   _nell, amav, _здол, purd,
   {{0x3ea701ef,0x89db011d,0xb60600d5,0xc6220831}},	//   _mhnt_, _מחיי, jváž, নালা_,
   {{0x5ed50083,0xb60600d5,0x00000000,0x00000000}},	//   _দিনে, dváž, --, --,
   {{0x61e109e8,0x2c05012f,0xe29a05c2,0x160b00b4}},	//   _bell, ष्टं_, пад_, _सॉकर_,
   {{0x61e13104,0x60c101d6,0x6726009f,0x26c201ed}},	//   _cell, _bulm, _iskj, _iuko_,
   {{0x61e1a996,0xe5a3027a,0x35a32dfa,0x26c20657}},	//   _dell, _бири, _барг, _huko_,
   {{0x26c2070b,0x60c10349,0x661e3788,0x764e0088}},	//   _kuko_, _dulm, lepk, _hoby,
   {{0x7afdae5e,0x61e13926,0x3ea7055c,0x00000000}},	//   xust, _fell, _bhnt_, --,
   {{0x61e10297,0x3eb8aa83,0x7afd0f67,0x60c1027a}},	//   _gell, ört_, vust, _fulm,
   {{0x60c1ae5f,0x2d980c61,0x7afd11cc,0x764eae60}},	//   _gulm, ære_, wust, _moby,
   {{0x7afd247d,0x61e1ae61,0x3d11007c,0xdb0401ed}},	//   tust, _zell, _तहरे_, _agiñ,
   {{0x26c20232,0x61e1ae62,0x291e0225,0x60c10471}},	//   _nuko_, _yell, çtan_, _zulm,
   {{0x7afda1d9,0x61e1003c,0x764e300c,0x27e201b7}},	//   rust, _xell, _noby, _aekn_,
   {{0x7afd194e,0x29880145,0x26c2010d,0xdff4007c}},	//   sust, есто_, _auko_, _इयाद_,
   {{0x7afd0121,0xbca5017e,0x26c24734,0xdb0401b7}},	//   pust, _جمعي, _buko_, _egiñ,
   {{0x78adae63,0x26c2012f,0x7bcd00d5,0x610a00a8}},	// [cbb0] rmav, _cuko_, _ifau, _dəli,
   {{0xb8f70083,0x4b7c0122,0x7aed0027,0x26cf00ea}},	//   _সি_, _מאחו, _ivat, īgo_,
   {{0x7aed8f0a,0x61e1865d,0x764e0187,0x2ca90051}},	//   _hvat, _rell, _doby, _khad_,
   {{0x610a01c2,0x61e1ae64,0x43753b0c,0x999a01c0}},	//   _gəli, _sell, култ, _např_,
   {{0x60c100da,0x6459ae65,0x4429016f,0x7cc100ea}},	//   _sulm, rkwi, ľa_, _pērk,
   {{0x442902b2,0x60c1ae66,0x61e100da,0x764e300c}},	//   ža_, _pulm, _qell, _goby,
   {{0x26c20027,0x637300b5,0x00000000,0x00000000}},	//   _zuko_, _bűnö, --, --,
   {{0x26c23069,0x7aed6af4,0x61e108f8,0x610a00a8}},	//   _yuko_, _ovat, _well, _xəli,
   {{0x61e1ae67,0x09e20083,0xef1900d4,0x60c10051}},	//   _tell, _বাসা, ємо_, _wulm,
   {{0xed590036,0x2ca9ae68,0x9f5f8b45,0x61e10c6f}},	//   доо_, _ahad_, ngué_, _uell,
   {{0x423602b5,0x2ca90284,0x7aed0d19,0x91ca0067}},	//   _שנעל_, _bhad_, _avat, _स्टै,
   {{0xed5600d4,0x905559c7,0x6e2a0211,0x91fc00ea}},	//   тою_, _швец, _eafb, _glāb,
   {{0x7aed025c,0x6e2a0036,0x2ca901da,0x00000000}},	//   _cvat, _fafb, _dhad_, --,
   {{0x09e20033,0xfaa6ae69,0x610a013b,0x00000000}},	//   _বাহা, таго, _səli, --,
   {{0xfbe100c8,0x2f0b1f8b,0x2ca909c3,0x09b50083}},	//   _ভারত, løg_, _fhad_, _জ্বা,
   {{0x249d01a9,0x764e0cca,0x26c2012e,0x2ca9ae6a}},	//   jlwm_, _soby, _puko_, _ghad_,
   {{0x764e1b66,0x7aed082d,0x2bd801c0,0x661e7764}},	// [cbc0] _poby, _gvat, _भ्या, tepk,
   {{0x787b03ad,0x7ae90484,0x26c20207,0xd099013b}},	//   tävä, ġett, _vuko_, rçən,
   {{0x7aed003a,0x610a00a8,0x661e0220,0x09f700a5}},	//   _zvat, _təli, repk, _במים_,
   {{0x26c2002f,0x97da0037,0x624f008c,0x00000000}},	//   _tuko_, _تبدأ_, _søop, --,
   {{0x27fd0035,0x77830382,0x00000000,0x00000000}},	//   ówne_, _вляз, --, --,
   {{0x291a00d7,0xd24f0365,0x00000000,0x00000000}},	//   _kppa_, ينن_, --, --,
   {{0x672401e4,0x15431ade,0x9f4402d7,0x3e600211}},	//   lwij, _керм, mamé_, _nòta_,
   {{0xc9530052,0x628f363b,0x83fd00b5,0x6e2a00e9}},	//   שמה_, _ícon, _előb, _safb,
   {{0xb2260674,0xa49100bf,0x2ca9001e,0x67240120}},	//   _имал, _اینت, _rhad_, nwij,
   {{0x7aed003d,0x291aae6b,0x00000000,0x00000000}},	//   _rvat, _oppa_, --, --,
   {{0x7aedae6c,0x3e600211,0xa3c901c0,0xe0460a7c}},	//   _svat, _còta_, लुक_, _инжи,
   {{0x0179016b,0x00000000,0x00000000,0x00000000}},	//   _אָנל, --, --, --,
   {{0x291a0392,0xfb87005f,0xba770118,0x00000000}},	//   _appa_, тынн, ناست, --,
   {{0x25fe7f73,0x672401e4,0x6e2a0a8a,0x00000000}},	//   _लागी_, dwij, _uafb, --,
   {{0x2ca9ae6d,0x67240223,0x00000000,0x00000000}},	//   _thad_, ewij, --, --,
   {{0x9c7d010b,0x4e0e000c,0x291a0260,0xc864002d}},	//   ksči, त्रै_, _dppa_, атуи,
   {{0x7aed012e,0x6724ae6e,0xec380070,0x2d9cae6f}},	// [cbd0] _uvat, gwij, _יאהר_, _hyve_,
   {{0x7c2d50e9,0x7cc100ea,0x07081902,0x00000000}},	//   _haar, _sēri, ئيلي_, --,
   {{0x7c2dae70,0x9f5f8b96,0x00000000,0x00000000}},	//   _kaar, rgué_, --, --,
   {{0x7c2d152b,0x6f0011c2,0x67240371,0x00000000}},	//   _jaar, kumc, bwij, --,
   {{0x27e9ae71,0x610a0669,0x81e70033,0x2d9c11cb}},	//   maan_, _məlu, _ভাব_, _lyve_,
   {{0xdd860514,0x27e9ae72,0x2c62024e,0x7c2dae73}},	//   _هو_, laan_, _móda_, _laar,
   {{0xc6920052,0x78bd00fd,0x00000000,0x00000000}},	//   _האם_, _kisv, --, --,
   {{0x27e9247e,0x7c2d1a6a,0x34953fe2,0x850400fd}},	//   naan_, _naar, _сабр, _خوفن,
   {{0xdd2e00b8,0x78bd183a,0x442dae74,0xe3b30ca8}},	//   měře, _misv, _iae_, _ضرر_,
   {{0x27e9ae75,0x83520332,0x442d0086,0xbe650698}},	//   haan_, _دھما, _hae_, اهدي,
   {{0x27e9ae76,0x442d00d1,0xed590a6a,0x2f0b054e}},	//   kaan_, _kae_, хон_, søg_,
   {{0x27e99c7e,0x7c2d021d,0x442d00cc,0x78bd0116}},	//   jaan_, _caar, _jae_, _nisv,
   {{0x442d1973,0x7c2d019c,0x443f023a,0xb1110093}},	//   _mae_, _daar, _mnu_, óðfé,
   {{0x7c2f0602,0x442dae77,0x78bd005f,0x00000000}},	//   adcr, _lae_, _aisv, --,
   {{0xc95529d6,0x443fae78,0x7c2d16b6,0x8cca0355}},	//   атты, _onu_, _faar, _संयो,
   {{0x27e93afd,0x7c2d23f4,0x442dae79,0x6724ae7a}},	//   gaan_, _gaar, _nae_, twij,
   {{0x98a30e75,0x78bd0036,0x7ae901ba,0xf7430259}},	// [cbe0] сите, _disv, šetr, бето,
   {{0x443fae7b,0x672425cb,0x3a2600c3,0x7c2dae7c}},	//   _anu_, rwij, _смог, _zaar,
   {{0x69dcae7d,0x442dae7e,0x27e9ae7f,0x6724ae80}},	//   mbre, _bae_, baan_, swij,
   {{0x27e9005d,0x442d9c5b,0xe4d702fd,0x6e21502d}},	//   caan_, _cae_, اونت_, helb,
   {{0x442d0173,0x68e3054e,0x443f030a,0xcec80019}},	//   _dae_, _ændr, _dnu_, _mộc_,
   {{0x69dcae81,0xcec80019,0x115407b0,0x442d01d7}},	//   nbre, _lộc_, иклю, _eae_,
   {{0x6e21ae82,0x442d0090,0xc0e30d6e,0x96634c81}},	//   delb, _fae_, бојк, _укре,
   {{0x6283ae83,0x2ef41126,0x442dae84,0x786300ab}},	//   anno, азир, _gae_, _kõva,
   {{0xd467051b,0x6440ae85,0x160b1e79,0x7de61bda}},	//   _сите_, _inmi, स्कर_, лінд,
   {{0x7c2dae86,0x6e21ae87,0x27e9ae88,0x5c140083}},	//   _saar, gelb, zaan_, িযোগ_,
   {{0x27e92c04,0xa3e80e1d,0x7c2dae89,0x06970d85}},	//   yaan_, _मजा_, _paar, רדים_,
   {{0x26140bc1,0xdee61b52,0x61ea0093,0xf77f021d}},	//   न्ती_, _боди, lafl, _leça_,
   {{0x7c2dae8a,0x78bdae8b,0x27e973e8,0xeb0700c3}},	//   _vaar, _risv, vaan_, ычно,
   {{0x7c2d6f79,0x27e92f91,0x69dcae8c,0x7d011b84}},	//   _waar, waan_, gbre, buls,
   {{0x27e9ae8d,0x7c2d0657,0x6440152b,0x48abae8e}},	//   taan_, _taar, _onmi, етам_,
   {{0x20ca0019,0x69dc021d,0x765e0345,0x00000000}},	//   _mùi_, abre, ekpy, --,
   {{0x27e9776a,0x62837e27,0x6d5a8232,0x78bdae8f}},	// [cbf0] raan_, ynno, lyta, _visv,
   {{0x27e9ae90,0x442dae91,0x443fae92,0x6440ae93}},	//   saan_, _sae_, _snu_, _anmi,
   {{0x7bcf02fb,0x6d5a00b5,0x27e9ae94,0x261406d9}},	//   occu, nyta, paan_, न्धी_,
   {{0x29033f8b,0x628808b7,0x7afdae95,0x6abeae96}},	//   muja_, _ajdo, orst, _zipf,
   {{0x38690a32,0x29030086,0x291106a2,0x7e7a0034}},	//   mhar_, luja_, ltza_, kitp,
   {{0x261427bd,0x442d01ca,0x38690370,0x6440ae97}},	//   न्दी_, _wae_, lhar_, _enmi,
   {{0x291103cb,0x442dae98,0x2903ae99,0x83fd006c}},	//   ntza_, _tae_, nuja_, _előa,
   {{0x443fae9a,0x3869ae9b,0x291106a2,0x7afd5ffc}},	//   _unu_, nhar_, itza_, krst,
   {{0xf8bf0033,0x2fcdae9c,0x6e21ae9d,0x7bdd028b}},	//   _mié_, rceg_, telb, dbsu,
   {{0x63a903cb,0xee36ae9e,0x2903ae9f,0x62720035}},	//   _izen, ань_, kuja_, dłow,
   {{0xc05b02ce,0x6da54cf3,0x7afdaea0,0x4c86095d}},	//   _під_, рина, erst, илов,
   {{0x6e21aea1,0x814c0070,0x3ef900af,0xf8bf2de6}},	//   selb, _רעאַ, _андэ_, _nié_,
   {{0xdee503fa,0x69dcaea2,0x6e21aea3,0x3869aea4}},	//   _толи, tbre, pelb, dhar_,
   {{0x7d010f4f,0x6d5a8eaf,0x4a7502ee,0x20d1009f}},	//   puls, byta, быст, _iġib_,
   {{0xdca603ad,0x69dc479d,0xcec801a5,0xde9407f8}},	//   _каки, rbre, _tộc_, _اجنب,
   {{0x8cca0e1d,0x3869a0aa,0xad1a0122,0x63a9aea5}},	//   _संतो, ghar_, _יוצר, _ozen,

   {{0x27fd006a,0xf8bf0173,0xf77f64df,0x929d004e}},	// [cc00] ówna_, _dié_, _peça_, _wpły,
   {{0x7df3162b,0x45d60fdd,0x2903aea6,0x7ae40069}},	//   _आयोग_, рцат, buja_, _iwit,
   {{0x38691093,0xa526002d,0x98a6aea7,0xd94616c0}},	//   bhar_, рмед, _вине, _тени,
   {{0x38694dbb,0x1d1600c2,0x7ae40232,0x20ca0019}},	//   char_, יקער_, _kwit, _rùi_,
   {{0x61eaaea8,0xcfe90033,0x6d5a4d2b,0x00000000}},	//   tafl, _গাঢ়_, zyta, --,
   {{0x7ae416fe,0x6458004e,0x63a902d4,0xe28306e4}},	//   _mwit, _ścią, _dzen, олчи,
   {{0x61eaaea9,0x63a9aeaa,0x361b0070,0x05aa07b5}},	//   rafl, _ezen, _שולד, _करिब,
   {{0x14d70bed,0x6440aeab,0x3860022e,0x20ca00e2}},	//   _כולל_, _unmi, nkir_, _vùi_,
   {{0x7e7a1697,0x24862ba3,0x32cb0185,0x00000000}},	//   titp, mnom_, _gøy_, --,
   {{0x7afd03ab,0x24860af1,0x3869aeac,0x7bc4009f}},	//   vrst, lnom_, zhar_, _agiu,
   {{0x160b0fd1,0x7ae4aead,0xdd9400c7,0x3860a464}},	//   स्टर_, _awit, саны, kkir_,
   {{0x629875b4,0x2903aeae,0x6d5aaeaf,0x24860044}},	//   lovo, vuja_, ryta, nnom_,
   {{0x20110095,0x6d5aaeb0,0x2486067f,0x7afd19c1}},	//   əzi_, syta, inom_, urst,
   {{0x38690069,0x7ae4046a,0x61e8aeb1,0x6d5a004e}},	//   whar_, _dwit, _jedl, pyta,
   {{0x61e80307,0x3869003b,0x2bd806fe,0x6ce60044}},	//   _medl, thar_, _भ्वा, _тіле,
   {{0x7cc10080,0x2903028b,0x62980926,0x24863ce5}},	//   _vērt, ruja_, hovo, jnom_,
   {{0x2486287d,0x62980a0b,0xab5b01c2,0x38690159}},	// [cc10] dnom_, kovo, rcüs, rhar_,
   {{0x1a65006c,0x629800ac,0x61e80bf3,0x29034856}},	//   _ایسی_, jovo, _nedl, puja_,
   {{0x63a9aeb2,0x6298552b,0x91fc0080,0xd5bb0c06}},	//   _szen, dovo, _plān, тса_,
   {{0xef1f01d6,0x2486aeb3,0x83fd00b5,0x00000000}},	//   çük_, gnom_, _előn, --,
   {{0x28c00299,0x26140cc5,0x8c380070,0x96f800af}},	//   _शूटि, न्ही_, יטאס_, _кеят_,
   {{0x629802dd,0x5ed50083,0xb60400af,0x95cb32a6}},	//   govo, _দিলে, _мяск, _шума_,
   {{0x24861ed1,0x25a5006c,0x69c50069,0x00000000}},	//   bnom_, _áll_, _mghe, --,
   {{0x24864922,0x6add0033,0x32cb03d0,0x00000000}},	//   cnom_, _বিনো, _tøy_, --,
   {{0x62980187,0x61e85fd5,0x60c80211,0x63a9aeb4}},	//   bovo, _fedl, _eudm, _uzen,
   {{0x69c5aeb5,0x629800d5,0x765530a5,0x0e6503b2}},	//   _nghe, covo, _jozy, скон,
   {{0x7ae4aeb6,0x60c8aeb7,0xfaff0055,0x00000000}},	//   _swit, _gudm, erë_, --,
   {{0x69c50160,0x00000000,0x00000000,0x00000000}},	//   _aghe, --, --, --,
   {{0x2a6aa27c,0x2fdf00f8,0x00000000,0x00000000}},	//   thbb_, mbug_, --, --,
   {{0x2bd80bdd,0xfbd809b1,0x24861f3d,0x00000000}},	//   _भ्रा, _भ्रम, znom_, --,
   {{0x291e0443,0xa967029f,0x7cc100ea,0x28b4021a}},	//   ïta_, бира_, _vērs, ंगलि,
   {{0x62982168,0x7afbada2,0xfc3f0187,0xb8d04e4b}},	//   zovo, šuta, smír_, _ओठ_,
   {{0x24860912,0xe61a07fa,0x3860aeb8,0xcec80023}},	// [cc20] vnom_, лда_, rkir_, _lộn_,
   {{0x3860008d,0x9a2a0086,0x1a0618ea,0x7c26aeb9}},	//   skir_, _сооб_, _упом, lekr,
   {{0x24863ce5,0xd9100416,0x00000000,0x00000000}},	//   tnom_, _تیز_, --, --,
   {{0x61e85098,0xd49900d4,0x24860a2d,0x00000000}},	//   _sedl, арі_, unom_, --,
   {{0xa3c90953,0x24863ce5,0x27e0aeba,0x4df9000c}},	//   ोड़_, rnom_, mbin_, ूलाई_,
   {{0x2486aebb,0xf2c503d0,0x27e0aebc,0xe297010b}},	//   snom_, ісін, lbin_, бач_,
   {{0x61e8a28c,0x867b0070,0x2486287d,0x64a600d8}},	//   _vedl, _ערלו, pnom_, _гава,
   {{0x741603c7,0x78a40187,0x27e03288,0x61e83e5c}},	//   _دورا, nliv, nbin_, _wedl,
   {{0x33660131,0x7c26aebd,0x8f3425ef,0x00000000}},	//   _уваг, dekr, цепц, --,
   {{0x4426aebe,0x2baf06bb,0x78a47a11,0x60c80207}},	//   leo_, _घरबा, hliv, _tudm,
   {{0xe0da0500,0x78a4aebf,0x00000000,0x00000000}},	//   _све_, kliv, --, --,
   {{0x4426aec0,0x7c26aec1,0x8c67141d,0x7cd3002d}},	//   neo_, gekr, стод, _bărb,
   {{0x78a4024e,0x28be08b0,0xddc8022f,0x27e00510}},	//   dliv, ्दनि, midž, dbin_,
   {{0xfaff01d2,0x60c2004f,0x69c801ba,0x4426aec2}},	//   rrë_, _hiom, žden, heo_,
   {{0x44260657,0x7cd3002d,0xf77f0279,0xe73100a8}},	//   keo_, _păre, _peço_, _köçü,
   {{0x4426aec3,0x27e035df,0x660e01ed,0xc7d90c14}},	//   jeo_, gbin_, _acbk, рмах_,
   {{0x7655004e,0x9f4401f7,0x00000000,0x00000000}},	// [cc30] _pozy, namà_, --, --,
   {{0x27e000d7,0xe133012e,0x60c20719,0x9f5f0132}},	//   abin_, ščić_, _liom, nguá_,
   {{0x81e70b52,0x4426896d,0x00000000,0x00000000}},	//   _ভাল_, feo_, --, --,
   {{0x78a4aec4,0xcec80023,0x2419021f,0x60c214cb}},	//   cliv, _rộn_, роды_, _niom,
   {{0x7cc800fe,0x59d00067,0x00000000,0x00000000}},	//   _děri, तुकर, --, --,
   {{0x672f025c,0x7c262e2f,0x60c2135c,0x00000000}},	//   _iscj, zekr, _aiom, --,
   {{0x26cb01ed,0x7cd30395,0x00000000,0x00000000}},	//   _huco_, _mărc, --, --,
   {{0x26c30033,0x4426aec5,0x661c0506,0x60c20211}},	//   _hijo_, ceo_, _zbrk, _ciom,
   {{0x60c2aec6,0x53474ee6,0x248d0118,0x62720067}},	//   _diom, _ухва, _ijem_, głos,
   {{0x8cca09a8,0x26c300d7,0x78a405ed,0x248d10db}},	//   _संशो, _jijo_, zliv, _hjem_,
   {{0x26c30506,0x7cd3002d,0xddc80009,0xf3f900af}},	//   _mijo_, _sărb, bidž, _alţi_,
   {{0x60c24218,0x26d9aec7,0x161920c1,0xe7311008}},	//   _giom, _otso_, न्तर_, _göçü,
   {{0xef0e081b,0x26d901e8,0xeb970ea7,0x09c50033}},	//   _юм_, _ntso_, жия_, ্রনা,
   {{0xfce506c2,0x7c26aec8,0x4426aec9,0x0dcb1ade}},	//   _доко, sekr, zeo_, _суди_,
   {{0x78a40076,0x44260159,0x9f4402d7,0x26d950e1}},	//   tliv, yeo_, mamá_, _atso_,
   {{0x26cbaeca,0x44261111,0x248d008b,0xdb0d01a3}},	//   _buco_, xeo_, _njem_, _egañ,
   {{0x4426aecb,0x07a3ace3,0x2ca00159,0x26cb0138}},	// [cc40] veo_, датн, _ikid_, _cuco_,
   {{0x9f445605,0x78a40c7d,0x249f0160,0x4426aecc}},	//   namá_, sliv, _akum_, weo_,
   {{0x26c300c8,0x4426aecd,0x78a46caa,0x78b63b37}},	//   _dijo_, teo_, pliv, pmyv,
   {{0xf746717b,0xa5da1db9,0x00000000,0x00000000}},	//   _демо, _प्रौ, --, --,
   {{0x26c30831,0x60c21c8b,0xe7372f44,0x8c1b0d85}},	//   _fijo_, _riom, _дея_, שוני,
   {{0x4426aece,0x366a01c8,0x161900b1,0x60c2aecf}},	//   seo_, _таго_, न्दर_, _siom,
   {{0x44263e47,0x35a310da,0x60c20382,0xe5a332a6}},	//   peo_, _жарг, _piom, _жири,
   {{0x3ea53e7e,0x656301b4,0x9f5401e0,0x2ee60107}},	//   ellt_, ønhe, звич, _pwof_,
   {{0x25aa05dc,0xf8b30bed,0xddc8aed0,0xc47700fd}},	//   _करुण, ושה_, ridž, _بینچ_,
   {{0xb5e80033,0x5be3022e,0xbbe3074f,0x7bd6034d}},	//   _পাঁচ, पर्व, पर्क, _afyu,
   {{0x200f008c,0x60c20a32,0xa06aaed1,0x7af6aed2}},	//   _fcgi_, _tiom, _кажа_, _avyt,
   {{0x60da0069,0x2cb200e5,0x00000000,0x00000000}},	//   _ittm, _chyd_, --, --,
   {{0x09e20083,0x628a00d7,0xfc3f0042,0x00000000}},	//   _বাজা, onfo, glía_, --,
   {{0x32d00019,0x25aa00b4,0x628a2421,0x00000000}},	//   _mày_, _करूण, nnfo, --,
   {{0x58d42839,0x6e28aed3,0x628aaed4,0x26cb2314}},	//   дост, medb, info, _suco_,
   {{0x81ac0033,0x00000000,0x00000000,0x00000000}},	//   _গলা_, --, --, --,
   {{0x32d0098b,0xa3de04bc,0x61fa0e42,0x7cd30139}},	// [cc50] _này_, _द्ध_, _odtl, _tărc,
   {{0xa56700f3,0x6e280187,0x26cb0124,0x3a75059d}},	//   يدان, nedb, _vuco_, _хлор,
   {{0x7d086bd5,0x69d50067,0x1bf2074f,0x5fca1e82}},	//   nuds, mcze, _अजमल_, ाखाल,
   {{0x81e700c8,0x32d001a5,0x69d55855,0x26d9023a}},	//   _ভাই_, _bày_, lcze, _ttso_,
   {{0x4c3c00c2,0x3ea5aed5,0x32d00023,0x60da09b3}},	//   יגאצ, yllt_, _cày_, _attm,
   {{0x32d00019,0x6e28aed6,0x60da0176,0x999100b5}},	//   _dày_, jedb, _bttm, lező_,
   {{0xd24e004f,0x8234004f,0x7d088953,0x7647007b}},	//   انى_, برنا, juds, _injy,
   {{0x786a00ac,0x09e20033,0x249f00f8,0x00000000}},	//   _kýva, _বাছা, _ukum_, --,
   {{0xd2590228,0x00000000,0x00000000,0x00000000}},	//   _suņu_, --, --, --,
   {{0x31354e67,0x670c052f,0x69d50067,0x00000000}},	//   _незр, िंतक_, jcze, --,
   {{0xcb090052,0xdca65a7e,0x69d50035,0xb65c0070}},	//   _תל_, зани, dcze, ידזש,
   {{0x69d5006a,0x7cd30139,0xfaff0031,0x672daed7}},	//   ecze, _căra, jzës_, kwaj,
   {{0x70526f76,0x20d10023,0x5b350043,0x786a008e}},	//   _سنوا, _hái_, мэру, _nýva,
   {{0x7d087815,0x09e20083,0xad25820c,0x20d100e2}},	//   buds, _বাঙা, _فرعو, _kái_,
   {{0xd94319f0,0x6e1601cb,0x6da21c5e,0xa9670dbf}},	//   нери, _رييس_, _пиша, пира_,
   {{0x786a1840,0x20d101a5,0xfc3f364b,0x7d2600b5}},	//   _býva, _mái_, llín_, őrsé,
   {{0x20d101a5,0x3e6002e9,0x83fd00b5,0x29035a3d}},	// [cc60] _lái_, _sòti_, _elők, arja_,
   {{0x7c36027d,0x20d100e2,0x00000000,0x00000000}},	//   _hayr, _oái_, --, --,
   {{0x4a5b0122,0xfc3f0037,0xa9a607fa,0x18a61180}},	//   _הדיו, ilín_, _хинд, _наом,
   {{0xc20e0953,0x136a01e0,0x00000000,0x00000000}},	//   _साहब_, йшли_, --, --,
   {{0x7c360269,0x62346a67,0x290a7259,0x1b1a0083}},	//   _mayr, делу, luba_, দিকে_,
   {{0x27f269ed,0x20d10019,0x628a1111,0x7c360176}},	//   layn_, _bái_, unfo, _layr,
   {{0x20d100e8,0x6e28aed8,0x290a0371,0x628a05aa}},	//   _cái_, vedb, nuba_, rnfo,
   {{0x64a30970,0x69d5aed9,0xf8be11b5,0x7d080044}},	//   _заса, zcze, ्दिय, vuds,
   {{0x213e02c7,0x69d50035,0x6f0902d7,0x741308cf}},	//   _wrth_, ycze, guec, _سولا,
   {{0x290a010f,0x29033e8d,0x20d10093,0x7cd300af}},	//   kuba_, yrja_, _fái_, _săra,
   {{0x7c360dac,0x20d10028,0x6e280496,0x291801ba}},	//   _bayr, _gái_, redb, jtra_,
   {{0x7d08035b,0x290a01ed,0xe50d0066,0x7c36021d}},	//   ruds, duba_, ांति_, _cayr,
   {{0x7c360160,0xfc3fa272,0x27f202ee,0x2b408df1}},	//   _dayr, blín_, dayn_, _cric_,
   {{0x7c3603bc,0xfe6f0037,0x2918aeda,0x00000000}},	//   _eayr, _مدى_, ftra_, --,
   {{0x290aaedb,0x8bec0083,0x2bafaedc,0x69d52e2f}},	//   guba_, _কারন_, _घरवा, rcze,
   {{0x27f2011e,0x290301f4,0x7c36027d,0x672d01d5}},	//   gayn_, rrja_, _gayr, twaj,
   {{0xcc34017e,0xe7ee0067,0x7bc000f4,0x2b400207}},	// [cc70] _سريع, _ज़रा_, žmur, _gric_,
   {{0x672daedd,0x290a18f9,0x786a00ac,0x00000000}},	//   rwaj, buba_, _výva, --,
   {{0x27f20159,0x290aaede,0xddc30139,0x7863018d}},	//   bayn_, cuba_, _monş, _lõvi,
   {{0x7c361505,0x09c50033,0xc4b901c0,0x00000000}},	//   _xayr, ্রদা, ेदेख, --,
   {{0x9f5904d4,0xe3b011c0,0x786a00d5,0x00000000}},	//   üsü_, هره_, _kývn, --,
   {{0xa0210225,0xddc30160,0x2002008d,0x3f980448}},	//   _çöze, _nonş, ókin_, ğrul_,
   {{0x65940f23,0xe1f00c26,0xd12e1902,0x90b50274}},	//   _зару, اسه_, لمو_, мљиш,
   {{0x4277014a,0x260b0067,0x00000000,0x00000000}},	//   _کارآ, ालवी_, --, --,
   {{0x521508f1,0x290a0010,0x200d32c6,0x7afb0124}},	//   _одат, zuba_, rgei_, šutj,
   {{0x20d10019,0xda1f13ab,0x4d65aedf,0xddc300af}},	//   _tái_, म्मत_, дков, _conş,
   {{0x2918aee0,0xfc3faee1,0x90e700bf,0x628333e6}},	//   xtra_, rlín_, _رسان, mino,
   {{0x645b1f3c,0x25b10051,0x00000000,0x00000000}},	//   _joui, _mzzl_, --, --,
   {{0x20180669,0x6f09aee2,0x25aa1bb5,0x7c36aee3}},	//   əri_, quec, _कर्ण, _vayr,
   {{0x290aaee4,0x2918aee5,0x27f2081b,0x645b50ea}},	//   tuba_, ttra_, wayn_, _loui,
   {{0x644957e9,0x27f20159,0xb86600b5,0x291801ef}},	//   _onei, tayn_, وارو, utra_,
   {{0x290aaee6,0x6add0083,0x2b4001a6,0x2918aee7}},	//   ruba_, _বিরো, _tric_, rtra_,
   {{0x6283aee8,0x2b40aee9,0x98a30ae6,0x27f2081b}},	// [cc80] kino, _uric_, тите, rayn_,
   {{0x6449aeea,0x628300cd,0x27f2258c,0x461a010b}},	//   _anei, jino, sayn_, ўцаў_,
   {{0x6283aa5a,0x645baeeb,0x00000000,0x00000000}},	//   dino, _boui, --, --,
   {{0x81e70083,0x645b000d,0x64490090,0xed56016b}},	//   _ভাগ_, _coui, _cnei, ובער_,
   {{0x6283aeec,0x645b000d,0x93cb00b5,0x87ba62a2}},	//   fino, _doui, زانہ_, _фунт_,
   {{0xfe6701ca,0xe7da0026,0x645b009e,0xa3de3b29}},	//   _شد_, युरप, _eoui, _द्र_,
   {{0xe5a617a3,0x65c300d8,0x645b00f7,0x2ba500c0}},	//   _циви, _абра, _foui, _गुना,
   {{0xcec800e8,0x2c620187,0x765caeed,0x645b000d}},	//   _hội_, _kódu_, _hory, _goui,
   {{0x09b50083,0xd42600a8,0x2c6200d5,0x00000000}},	//   _জ্ঞা, ışdı_, _jódu_, --,
   {{0x6283aeee,0x7cd300af,0xddc300a8,0xe2460413}},	//   cino, _căro, _qonş, _تخري,
   {{0x645b0159,0x765c0090,0x78710282,0x91fc00ec}},	//   _youi, _mory, _håve, _blāv,
   {{0xcec80023,0xfc3f01ef,0x765c0f38,0x78710282}},	//   _lội_, rlío_, _lory, _kåve,
   {{0xa6db0093,0x8cca0e04,0x66ed0066,0x765c0345}},	//   _orða, _संको, _चौंक_, _oory,
   {{0x7f420088,0x995801c0,0xe7e10066,0xb06103a6}},	//   _iroq, láře_, गुना_, _ääre,
   {{0xcec800e8,0xf77300b5,0x78710044,0x00000000}},	//   _nội_, ھار_, _låve, --,
   {{0x6283aeef,0xb8d7056a,0x6e388a18,0x995800b8}},	//   zino, _छठ_, _havb, náře_,
   {{0xb8d633f0,0x7bcd0029,0x645b000d,0x6e38aef0}},	// [cc90] _ची_, _igau, _roui, _kavb,
   {{0xb9050083,0x7aed95c7,0x628301dd,0xcec80023}},	//   _নি_, _iwat, xino, _bội_,
   {{0xd49b12f3,0x645b000d,0xcec800e2,0x25de0066}},	//   орд_, _poui, _cội_, गड़ी_,
   {{0xd5df0e96,0x05df23f0,0x7aedaef1,0xcec80023}},	//   _प्रज, _प्रब, _kwat, _dội_,
   {{0xe8df0028,0xb7da0d85,0x2ba501c0,0x765caef2}},	//   _khỏe_, _מקרי, _गुमा, _fory,
   {{0x6e38aef3,0x3869aef4,0x7aed9a54,0x765caef5}},	//   _navb, lkar_, _mwat, _gory,
   {{0x6283a459,0x23690888,0x442b855a,0xcec80023}},	//   rino, šaj_, _ºc_, _gội_,
   {{0x7bcd3c37,0x6449aef6,0x38690533,0x442b0019}},	//   _ngau, _unei, nkar_, _úc_,
   {{0x3869704d,0x7f421db3,0x78710044,0x00000000}},	//   ikar_, _croq, _gåve, --,
   {{0x02cb00e7,0x7bcd3f66,0x38692f80,0x52cb00b8}},	//   ादीन, _agau, hkar_, ादीस,
   {{0xd01104e8,0x7aed01a8,0x38692129,0x26141856}},	//   _ملا_, _awat, kkar_, न्टी_,
   {{0xeb9aaef7,0x3e69016f,0x7aed2107,0x63a901a8}},	//   зим_, _túto_, _bwat, _kyen,
   {{0x386909e1,0x63a9007b,0xbf6711c0,0x66150067}},	//   dkar_, _jyen, _تداو, _oczk,
   {{0x427902b5,0x7aed0260,0x63a9007b,0x7cd30160}},	//   לאָג, _dwat, _myen, _hărm,
   {{0xae7800d8,0x48b65150,0x765c08c7,0x7aed0103}},	//   _ўсіх_, ещат, _rory, _ewat,
   {{0x786a0076,0xeb9a10a4,0x63a9aef8,0x38690fef}},	//   _vývo, _ний_, _oyen, gkar_,
   {{0x63a9aef9,0x7c240232,0x62810355,0x2d1f0380}},	// [cca0] _nyen, _ibir, _omlo, _बहुल_,
   {{0xba7600bf,0xdb9b02b8,0x920e0066,0x787103d0}},	//   _ساخت, _מספר, _साइज_, _råve,
   {{0x38720298,0x7c240484,0x63a9073a,0x7871035b}},	//   phyr_, _kbir, _ayen, _såve,
   {{0x3869022a,0x66e64717,0xcec80019,0x78710533}},	//   ckar_, _пома, _vội_, _påve,
   {{0x3a3aaefa,0x7c241939,0x7cc200ea,0x3e72000d}},	//   _kapp_, _mbir, _bērz, _hâte_,
   {{0xcec801a5,0x63a9aefb,0x3a3a01ff,0x6d4311f0}},	//   _tội_, _dyen, _japp_, _orna,
   {{0xfd0703c7,0x63a9001c,0x7c24aefc,0x3a3a017b}},	//   _حج_, _eyen, _obir, _mapp_,
   {{0x7f4201c2,0xc95300a5,0x26ca023a,0x63a9aefd}},	//   _proq, רמה_, _hibo_, _fyen,
   {{0x630618dd,0x63a92e98,0x91fc009e,0xdb1d00b5}},	//   _سوال, _gyen, _blāt, lcsö,
   {{0x7c24262a,0xdbfb04cc,0xe0ce0033,0x7aed01d5}},	//   _abir, ्ल्ड_, _রবীন, _rwat,
   {{0xdd941023,0xfc3f024e,0xdb16006c,0x6d43011c}},	//   таны, slím_, _együ, _crna,
   {{0x26ca300c,0x7f42897e,0x24860067,0xe8e000e2}},	//   _libo_, _troq, niom_, _nhốt_,
   {{0x6d43aefe,0x2fc0009e,0x00000000,0x00000000}},	//   _erna, _àig_, --, --,
   {{0x2ba50c03,0x7c2409d6,0x26ca01d5,0x6e380044}},	//   _गुणा, _ebir, _nibo_, _uavb,
   {{0x7aed012f,0x3e72002d,0x386922ca,0x7bcd099e}},	//   _wwat, _câte_, tkar_, _tgau,
   {{0x7aed2506,0xe8e00023,0x4424021d,0x26ca03d0}},	//   _twat, _chốt_, _nbm_, _aibo_,
   {{0x5bb96305,0x7c2f12c3,0x38690343,0x77980259}},	// [ccb0] _юлия_, mecr, rkar_, ектр_,
   {{0x3869aeff,0x7c2402dd,0x26ca0382,0x7c2fa277}},	//   skar_, _zbir, _cibo_, lecr,
   {{0x9419263d,0x44240703,0xf77f0248,0x63a9043d}},	//   джет_, _bbm_, _reçu_, _syen,
   {{0x7c3d1bd3,0x628101c0,0x6f1b0035,0x3a3a0139}},	//   ndsr, _smlo, ytuc, _zapp_,
   {{0xa7fb3612,0x27e901df,0x26190437,0xe787021d}},	//   _coñe, mban_, _पापी_, _чуно,
   {{0x78adaf00,0x7cc90035,0x27e910ab,0x63a90054}},	//   llav, _ośro, lban_, _vyen,
   {{0x69c80c99,0x40951056,0x5694af01,0x00000000}},	//   ždev, крит, _сарт, --,
   {{0x27e90332,0x6f1b19aa,0x63a9008c,0x00000000}},	//   nban_, ttuc, _tyen, --,
   {{0x442faf02,0x8ccb0437,0x7c2f008c,0x6d5c6590}},	//   meg_, _संजो, decr, äran,
   {{0x442f03d0,0x83fd0332,0x6f1b58d4,0x78ad033a}},	//   leg_, _előt, rtuc, hlav,
   {{0x26190c57,0x27e90332,0x78adaf03,0x442400d7}},	//   _पानी_, kban_, klav, _ybm_,
   {{0x442faf04,0x3a3a028b,0x7c2f0a8a,0x200300c7}},	//   neg_, _sapp_, gecr, ėjis_,
   {{0x207a02b5,0x3a3a88ab,0x907a00a5,0x27e900b5}},	//   _קאנא, _papp_, _קטני, dban_,
   {{0x6d43016f,0x442faf05,0x2486004e,0x6f090a8d}},	//   _trna, heg_, ziom_, mrec,
   {{0xc212035e,0x78adaf06,0x6f09af07,0xe8e00023}},	//   יהם_, flav, lrec, _phốt_,
   {{0x442f0537,0x78ad1851,0x290411d7,0x27e9006c}},	//   jeg_, glav, čma_, gban_,
   {{0x442faf08,0xbc1b0122,0x6f097121,0xae180066}},	// [ccc0] deg_, _חופש, nrec, _दामन_,
   {{0xa3e4065a,0x6d410200,0x34ca060a,0x00000000}},	//   पुन_, ovla, िद्द, --,
   {{0x27e90332,0x26ca07e5,0x6f0901ae,0xe8e000e2}},	//   bban_, _vibo_, hrec, _thốt_,
   {{0x254101c8,0x78adaf09,0xa7fb043f,0x442f00ce}},	//   _dėl_, clav, _poñe, geg_,
   {{0x2486af0a,0x26ca0f5d,0x2c1a0380,0x00000000}},	//   riom_, _tibo_, _भानू_, --,
   {{0x5b7b02b5,0x6f09af0b,0x442f00ab,0xd04c00a8}},	//   ורנא, drec, aeg_, əhət,
   {{0xcec8098b,0x442faf0c,0x44240279,0x60cbaf0d}},	//   _một_, beg_, _tbm_, _bigm,
   {{0x442f012e,0x753702b5,0x6f09af0e,0xf99300a5}},	//   ceg_, _באלד_, frec, ירו_,
   {{0x83fd006c,0x60cb0dc3,0x6f09af0f,0x221605a1}},	//   _elős, _digm, grec, _афер,
   {{0xa80606d3,0x27e900b5,0x91ba0ae7,0x00000000}},	//   ldığ, zban_, _قطار_, --,
   {{0x6f090043,0x27e900b5,0x69dc008c,0x3ea70345}},	//   arec, yban_, dcre, _dknt_,
   {{0x6f09af10,0xa80606d3,0x59d5000c,0x9ffa036b}},	//   brec, ndığ, _दलहर, _آراء_,
   {{0x6f09af11,0xcec80019,0x9b5802fb,0x7c3d362b}},	//   crec, _bột_, вият_, rdsr,
   {{0x2be30755,0x442f5a40,0xcec80019,0xc6080083}},	//   _क्रं_, zeg_, _cột_, র্তা_,
   {{0x27e90332,0x442faf12,0x2ba500ab,0xd7fb081b}},	//   tban_, yeg_, _गँवा, дуз_,
   {{0x27e9af13,0x60cb0282,0x764eaf14,0x00000000}},	//   uban_, _xigm, _anby, --,
   {{0x442faf15,0x2ca90c0a,0x78adaf16,0x76b928a4}},	// [ccd0] veg_, _ikad_, rlav, елар_,
   {{0x61f802dd,0x78adaf17,0x442f089c,0x27e9006c}},	//   javl, slav, weg_, sban_,
   {{0x442faf18,0x2619009a,0x61f80009,0xb4cd1604}},	//   teg_, _पाठी_, davl, रदे_,
   {{0xfc3faf19,0xb4bf0722,0x254100d8,0x2911af1a}},	//   ndí_, ीदे_, _vėl_, muza_,
   {{0x7afd039b,0x442f0044,0x29119adf,0xfc3f0037}},	//   nsst, reg_, luza_, idí_,
   {{0x442faf1b,0x6f09af1c,0x7afd3b72,0xf6790070}},	//   seg_, vrec, isst, _טאָמ,
   {{0x2911af1d,0x6f0904f4,0x68e20035,0x00000000}},	//   nuza_, wrec, _łodz, --,
   {{0x6f09af1e,0x83fd006c,0x7afd45c4,0xa3ce25de}},	//   trec, _előr, ksst, रशः_,
   {{0x61f80496,0xb4bf11b5,0x29110010,0x2f5400d8}},	//   bavl, ँगी_, huza_, атэс,
   {{0x7afd02df,0x6f093ec3,0x2911af1f,0x2ca92970}},	//   dsst, rrec, kuza_, _akad_,
   {{0x6f09af20,0x60cb043d,0x29117b18,0x7afd72d0}},	//   srec, _tigm, juza_, esst,
   {{0x67030f8a,0x6d413102,0x2ba50fbf,0x6f0906b5}},	//   _लिंक_, rvla, _गुहा, prec,
   {{0x6d414723,0x7afd5750,0x7cd3002d,0x4c83af21}},	//   svla, gsst, _mări, сляв,
   {{0x2911af22,0xa80604d4,0x787110fa,0x8d840118}},	//   fuza_, zdığ, _råva, اشین,
   {{0x69dcaf23,0x29112107,0xa806027b,0x3e690168}},	//   rcre, guza_, ydığ, _núti_,
   {{0x69dc2d74,0x7afd4793,0x61f80b67,0x2ba522c7}},	//   scre, bsst, zavl, _गुवा,
   {{0xcec800e2,0x3ea50176,0x00000000,0x00000000}},	// [cce0] _tột_, oolt_, --, --,
   {{0xe6176245,0x261902cb,0x2911af24,0x7ae474c2}},	//   лду_, _पाणी_, buza_, _itit,
   {{0x0446af25,0xa80600a8,0x186a0e60,0x291104fb}},	//   лежн, tdığ, _зани_, cuza_,
   {{0x7ae401f2,0x3ea5af26,0x32d90107,0x00000000}},	//   _ktit, holt_, _bèy_, --,
   {{0x61f80888,0xa80604d4,0x7cd30160,0x57fb00a5}},	//   tavl, rdığ, _dări, _אלכו,
   {{0xd13a1d13,0x32d9021e,0xfc3f031d,0x7ae4034d}},	//   ехи_, _dèy_, zdí_, _mtit,
   {{0x61f802dd,0x26190992,0x38620116,0x00000000}},	//   ravl, _पाती_, _kokr_, --,
   {{0x64a618d3,0x32d902d0,0x61f8318e,0x6d5c00ab}},	//   _саба, _fèy_, savl, äram,
   {{0x7ae40010,0x291101d5,0xa3e40246,0x61f800cd}},	//   _ntit, zuza_, पुण_, pavl,
   {{0x6ce60da3,0x7afd0f7f,0x07370d85,0xd5b83100}},	//   ліме, vsst, נאים_, _अराज,
   {{0x7ae4af27,0x628a13dc,0xa1960214,0x3e720160}},	//   _atit, mifo, _сјај, _câta_,
   {{0x628a0624,0x7afd40d1,0x291101d5,0x7ae40118}},	//   lifo, tsst, vuza_, _btit,
   {{0xfc3faf28,0x2f1800aa,0x3ea5af29,0x7afd0b94}},	//   rdí_, _роль_, bolt_, usst,
   {{0x628a09b3,0x7afdaf2a,0x2911018c,0x7ae411d9}},	//   nifo, rsst, tuza_, _dtit,
   {{0x7ae408dd,0x2ba51856,0xd5eb00e2,0x00000000}},	//   _etit, _गुरा, _đìn, --,
   {{0x2911af2b,0x628a0036,0xda1700be,0x7ae40024}},	//   ruza_, hifo, _तावत_, _ftit,
   {{0x35f51283,0xa8981bda,0xa7fb1725,0x628aaf2c}},	// [ccf0] ипар, укту_, _coña, kifo,
   {{0x32d902e9,0x2b494f7d,0xa7fb02d7,0x070811cf}},	//   _rèy_, _irac_, _doña, ايلي_,
   {{0xceb3168d,0x7cd30043,0x69c8011c,0x2b490168}},	//   ציע_, _pări, žder, _hrac_,
   {{0xd3710082,0xb4bf0084,0xf48500b5,0x7c3f035f}},	//   يها_, ँगे_, جائی, _jaqr,
   {{0x7c3f0069,0x81e60083,0x6fcb00a8,0x6d5c1130}},	//   _maqr, _ভয়_, _möcü, äraj,
   {{0x2bc700b4,0x45d4079d,0xeaf300be,0x01650a22}},	//   रेया, _горс, _अबैत_, икло,
   {{0xc6920122,0x7cd300af,0x00000000,0x00000000}},	//   _ואם_, _tări, --, --,
   {{0x201900be,0xfaff0031,0x628a0298,0x7c3f035f}},	//   üsi_, ksë_, aifo, _naqr,
   {{0x2ba50e1d,0x443faf2d,0xcf8e00bf,0x628a0023}},	//   _गुला, _iau_, وژه_, bifo,
   {{0x443faf2e,0x628a1814,0xddca0260,0xa2b30099}},	//   _hau_, cifo, _enfō, ेगळ्,
   {{0x443f39f6,0x7ae4af2f,0xb0350086,0x3ea500b5}},	//   _kau_, _stit, _внеш, rolt_,
   {{0x443f68fe,0xdca61a1c,0xcb6a07c1,0x7ae47452}},	//   _jau_, рами, ваме_, _ptit,
   {{0x443f1d86,0x386201a2,0x6d5c0185,0xe7b00033}},	//   _mau_, _rokr_, ørar, _কল্য,
   {{0x443faf30,0x17ee0084,0x2b49af31,0x00000000}},	//   _lau_, जर्व_, _drac_, --,
   {{0xa7fb4f85,0x2eff01d1,0x38622e37,0x00000000}},	//   _soña, lsuf_, _pokr_, --,
   {{0x2b497d6f,0x443faf32,0xcec801a5,0xa7fb0042}},	//   _frac_, _nau_, _hộp_, _poña,
   {{0x7e63af33,0x06862211,0x78780370,0xa6860409}},	// [cd00] _konp, аган, _níve, алад,
   {{0x6140006c,0xf5e70043,0x443faf34,0x8afb00a5}},	//   nálá, имул_, _aau_, _שהיי,
   {{0x443f62ff,0x7e63af35,0x1dab052f,0x78713fd5}},	//   _bau_, _monp, _घुमत, _gåvo,
   {{0x499b1899,0x443faf36,0x0af701df,0x00000000}},	//   _ישיב, _cau_, _حفیظ_, --,
   {{0x443f1ba6,0x78780279,0xe7e10099,0x00000000}},	//   _dau_, _cíve, गुळा_, --,
   {{0x443f02e1,0xcec80019,0x623419d9,0x7e63af37}},	//   _eau_, _nộp_, секу, _nonp,
   {{0xd1300082,0x628aaf38,0x527503fa,0x98480510}},	//   سمة_, rifo, ључу, lğı_,
   {{0x74160df3,0x443faf39,0x628aaf3a,0x205401d3}},	//   _خورا, _gau_, sifo, ския,
   {{0x27e014d8,0x7cd30395,0x98481505,0x6440034d}},	//   icin_, _măru, nğı_, _iami,
   {{0x443faf3b,0x644201a3,0xd33700a5,0x00000000}},	//   _zau_, ldoi, _דרמה_, --,
   {{0x64409d8f,0x443f006f,0x44260036,0xf8c601c0}},	//   _kami, _yau_, ofo_, लगाय,
   {{0x64400657,0x443faf3c,0x4fa600c3,0x2b4912ad}},	//   _jami, _xau_, _киев, _prac_,
   {{0x7b6457f7,0xfbdf0183,0x00000000,0x00000000}},	//   отре, rcê_, --, --,
   {{0x6440af3d,0x28db10a6,0x4efb011d,0x2b494051}},	//   _lami, _मंदि, _יהדו, _vrac_,
   {{0x7c3f035f,0x00000000,0x00000000,0x00000000}},	//   _taqr, --, --, --,
   {{0x6440af3e,0x7cd3002d,0x6d4a52e2,0x6f020207}},	//   _nami, _căru, _irfa, _kvoc,
   {{0x443f1020,0xcc3410ab,0xd6d10098,0x628808c8}},	// [cd10] _rau_, _ذريع, سقا_, _omdo,
   {{0x443faf3f,0x64402f33,0xe6130ca8,0x7a390adb}},	//   _sau_, _aami, تشر_, _спор_,
   {{0x443faf40,0xf8b10357,0x6440af41,0x44264b9f}},	//   _pau_, _فکر_, _bami, ffo_,
   {{0x293600c2,0x6f02024e,0x443f5a08,0x614000b5}},	//   _פארן_, _ovoc, _qau_, zálá,
   {{0x6440af42,0xa6db00fb,0x443faf43,0x91e50e60}},	//   _dami, _orði, _vau_, боле,
   {{0x443f00d1,0xe80f007c,0x78780300,0x644201ef}},	//   _wau_, िलका_, _víve, adoi,
   {{0x443f1020,0x65949c91,0x26d9af44,0x2bc720c1}},	//   _tau_, _дару, _huso_, रेता,
   {{0x6440af45,0x26d18d58,0xfc3f0037,0x7cd300af}},	//   _gami, _hizo_, ilís_, _mărt,
   {{0x6d4a001e,0x7e63af46,0x3375af47,0x20060090}},	//   _arfa, _ponp, _угар, _ddoi_,
   {{0x6440af48,0x7e550970,0x6f02016f,0x26d90036}},	//   _zami, стиц, _dvoc, _muso_,
   {{0x41b50071,0x6440af49,0x26d908cb,0x27e0359d}},	//   _امار, _yami, _luso_, ycin_,
   {{0xf8bf0028,0x672f004e,0xfc320037,0x06e80033}},	//   _nhé_, _opcj, أحد_, _পিসি,
   {{0x6d4a7ac5,0x9f4000fb,0xe7a71bc6,0x2d8b0067}},	//   _erfa, _þið_, _कुलप, ńce_,
   {{0x7e7aaf4a,0x63bb0054,0x26d1251e,0x09e3174b}},	//   chtp, _mzun, _nizo_, зорн,
   {{0x5ef90083,0x6a6b04d4,0x673d0069,0x0dc80274}},	//   _আমিও_, _nüfu, _assj, _кући_,
   {{0xf8bfaf4b,0x26d9af4c,0xfc3f01ef,0xbc930dec}},	//   _ché_, _buso_, noíl_, _најј,
   {{0x44f5016f,0x7bd63b53,0x27e0af4d,0x2bc700ab}},	// [cd20] eť_, _igyu, rcin_, रेदा,
   {{0x6440af4e,0x77c71958,0x26d97cc4,0x00000000}},	//   _sami, слуг_, _duso_, --,
   {{0x6440af4f,0xa96a9a36,0x98a60f36,0x261919b7}},	//   _pami, _сина_, _гине, _पारी_,
   {{0x26d9af50,0xf8bf0019,0x26d1af51,0x7af603bc}},	//   _fuso_, _ghé_, _eizo_, _kwyt,
   {{0x8c1b0bed,0x28b502e4,0x6442af52,0x44f500a0}},	//   רוני, ंतरि, rdoi, ať_,
   {{0x66e301d3,0x8b06004e,0x64400054,0xbb3b100a}},	//   _хора, częś, _wami, טעני,
   {{0x6724af53,0x2ee677f3,0x44260010,0x63bb0103}},	//   ltij, _stof_, pfo_, _ezun,
   {{0x0496211f,0x386004f6,0x6440002f,0x28db01c0}},	//   _الرح, njir_, _uami, _मंसि,
   {{0x6724af54,0x421a1015,0x6d4a023a,0x00000000}},	//   ntij, _مزاج_, _srfa, --,
   {{0xa3e400b1,0x6265004f,0xdbf10026,0x9f4f01f7}},	//   पुर_, _والق, चर्ड_, _degà_,
   {{0x6724af55,0x321eaf56,0x6a6b01fb,0x00000000}},	//   htij, _icty_, _müft, --,
   {{0x6724af57,0x7af6001e,0x6a6b033b,0xac190d13}},	//   ktij, _bwyt, _lüft, шому_,
   {{0xa7fb0042,0x26190af9,0x0b8b224a,0x67240051}},	//   _soño, _पाली_, усни_, jtij,
   {{0x26d9af58,0xb69b002d,0x62982179,0x25b80026}},	//   _ruso_, _avân, nnvo, _अरूण,
   {{0x61faaf59,0xdd9301c8,0x26d9121e,0x6d4a0471}},	//   _metl, _нашы, _suso_, _urfa,
   {{0x26d90269,0x67240a75,0x5b152374,0x61fa2cdc}},	//   _puso_, ftij, _дмит, _letl,
   {{0x7c2daf5a,0x67240051,0x00000000,0x00000000}},	// [cd30] _ibar, gtij, --, --,
   {{0x32f60067,0xfc3f0176,0x00000000,0x00000000}},	//   dły_, plís_, --, --,
   {{0xd5bb12fb,0xf8bf00f7,0x6724af5b,0x38740300}},	//   уса_, _thé_, atij, ñará_,
   {{0x26d97ad4,0x62981192,0x00000000,0x00000000}},	//   _tuso_, envo, --, --,
   {{0xe784140e,0x7c2daf5c,0x44f5124b,0x32f60035}},	//   _еуро, _mbar, sť_, gły_,
   {{0xe2c80118,0xf99002fd,0x6d4600ea,0xe2990d6e}},	//   مونو_, _آبی_, ākaj, јак_,
   {{0x32f60035,0x2c1a0066,0x61faaf5d,0x161e00ab}},	//   ały_, _भालू_, _detl, _पातर_,
   {{0x4f0932a6,0x61fa2069,0x62980298,0x00000000}},	//   анин_, _eetl, anvo, --,
   {{0x63bb04d4,0x442d7abf,0x61fa0044,0xc0c80200}},	//   _uzun, _ibe_, _fetl, љује_,
   {{0x7c2daf5e,0x61fa2f97,0x76451f2c,0x2903046c}},	//   _abar, _getl, ndhy, ksja_,
   {{0x7c2d009e,0x7878007e,0x00000000,0x00000000}},	//   _bbar, _líva, --, --,
   {{0x7f750043,0x6f0e0457,0x00000000,0x00000000}},	//   _мулц, üncü, --, --,
   {{0xc61100c8,0x543a02b5,0x442d3ff4,0x643a0070}},	//   স্যা_, בערא, _mbe_, בערנ,
   {{0x3e7b00f7,0x7c2d6e5a,0x6a7002b1,0x442d00ec}},	//   _bête_, _ebar, _käfi, _lbe_,
   {{0x442d041a,0xd943af5f,0x76450282,0x32f60067}},	//   _obe_, мери, ddhy, zły_,
   {{0x57eaa892,0x6724af60,0xf7723345,0x7c2daf61}},	//   рдам_, ttij, واء_, _gbar,
   {{0x16663e3d,0x38600093,0xa6db0093,0xd5b800ea}},	// [cd40] овам, rjir_, _orðu, _šā_,
   {{0x6724af62,0x442daf63,0x3e7b0248,0x7c2daf64}},	//   rtij, _abe_, _fête_, _zbar,
   {{0x6724af65,0x7c2d08dd,0x61fa029e,0xfe210d2a}},	//   stij, _ybar, _retl, _मानस_,
   {{0x2918af66,0x61faaf67,0x2bc755f5,0x67245016}},	//   mura_, _setl, रेवा, ptij,
   {{0x29180484,0x833614ac,0x1dab00b4,0x7c2b0225}},	//   lura_, تراض, _घुसत, _ögre,
   {{0x442daf68,0x629802c4,0x60da0051,0xa6e20093}},	//   _ebe_, unvo, _putm, áðun,
   {{0x29180232,0x61faaf69,0x69c30831,0x442d6ad1}},	//   nura_, _vetl, _únet, _fbe_,
   {{0x61fa081f,0xb4d6004e,0x442d00fe,0x3a3801e4}},	//   _wetl, सदी_, _gbe_, herp_,
   {{0x2918af6a,0x6306042c,0x1fa300af,0x6d480221}},	//   hura_, _ذوال, дрэг, wvda,
   {{0x2918af6b,0x35af0b4a,0x60da0463,0x7c2daf6c}},	//   kura_, _जुड़, _tutm, _sbar,
   {{0x29180eae,0x2b4001ed,0x98ba021e,0x3a38021d}},	//   jura_, _asic_, _aspč_, derp_,
   {{0x2c620097,0x20c10098,0x00000000,0x00000000}},	//   _kódy_, góid_, --, --,
   {{0x2b401f51,0xa09b00a5,0x8ae401e0,0x60c27d08}},	//   _csic_, _דיאט, дісл, _ihom,
   {{0x2918af6d,0x29110035,0x2c620097,0x28bf0355}},	//   fura_, trza_, _módy_, ्षभि,
   {{0x2918af6e,0x60c2af6f,0x7c2d009e,0x2905af70}},	//   gura_, _khom, _tbar, éla_,
   {{0xda171163,0x29037082,0x7c2daf71,0x1a6500b5}},	//   _ताकत_, rsja_, _ubar, _کیسی_,
   {{0x59a70785,0xb6c900b5,0x60c20211,0x00000000}},	// [cd50] _गडकर, مائے_, _mhom, --,
   {{0x3e7b02e1,0x29180232,0x454b0eb1,0x60c200f6}},	//   _tête_, bura_, ичем_, _lhom,
   {{0x2918af72,0xe4a7af73,0xf3f90395,0x76451124}},	//   cura_, ордо, _hoţi_, rdhy,
   {{0xe7870274,0x00000000,0x00000000,0x00000000}},	//   _дуго, --, --, --,
   {{0xa85a00a5,0x91e55f77,0x442d0409,0x00000000}},	//   _הדרכ, поле, _vbe_, --,
   {{0x69c301dd,0x60c27d08,0xf3f90160,0xcec3007e}},	//   _únes, _ahom, _moţi_, _keřů_,
   {{0x999a023a,0x60c2af74,0x00000000,0x00000000}},	//   _kapš_, _bhom, --, --,
   {{0x60c2295c,0xd12e22c4,0x442daf75,0xa99c00a5}},	//   _chom, امي_, _ube_, יבור,
   {{0x60c25aaa,0x2918af76,0x57b90afa,0x248d023a}},	//   _dhom, zura_, _आरोह, _imem_,
   {{0x249f0009,0x29180010,0x52771ee1,0xc332025a}},	//   _hjum_, yura_, _بارز, _אומ_,
   {{0xc61100c8,0x3eb90029,0x291801d7,0x60c20098}},	//   স্থা_, ēst_, xura_, _fhom,
   {{0x29180010,0x22450742,0x60c20024,0x3a380b0d}},	//   vura_, _halk_, _ghom, werp_,
   {{0xeb97af77,0xf0920122,0x20c10037,0x3a38026e}},	//   зия_, _אנא_, róid_, terp_,
   {{0x60c9027d,0xc6110033,0xa96a02c8,0x20c10079}},	//   lmem, স্তা_, бига_, sóid_,
   {{0x6d5c007c,0xfaa345e5,0xf1cb06fe,0x20c10098}},	//   ärat, харо, ाधिन, póid_,
   {{0x291810a2,0x83fd0332,0x60c9af78,0xa3d70099}},	//   rura_, _előz, nmem, _सलग_,
   {{0x27f20297,0x6016008f,0xe7ba0083,0x186754e1}},	// [cd60] rbyn_, lümü, ংখ্য, чати_,
   {{0x29181b0f,0xf1cb0aad,0x248daf79,0xe9d700af}},	//   pura_, ाधान, _amem_, _нкь_,
   {{0x89db02b8,0x601600d0,0x78b601ba,0x29180055}},	//   _לחיי, nümü, plyv, qura_,
   {{0x60c9238b,0x161e22a3,0x18a62f44,0xe8e000e2}},	//   jmem, _पावर_, _хамм, _nhứt_,
   {{0x60c2022e,0x2245af7a,0x6d4600ea,0x442000ea}},	//   _rhom, _balk_, ākai, ļi_,
   {{0x44200484,0x60c2af7b,0x2508042c,0x60c90051}},	//   żi_, _shom, _ورزی_, emem,
   {{0x22450626,0x29360070,0x60c200cc,0x21670200}},	//   _dalk_, לאַן_, _phom, зији_,
   {{0x044306b6,0x859b011d,0x787103db,0x60c911e9}},	//   _песн, _השלו, _påvi, gmem,
   {{0x2245038e,0x64a30036,0xe7be012f,0x6568009e}},	//   _falk_, _чата, ्धिप, _àdhb,
   {{0x6146af7c,0xd09101c2,0xf3f90395,0xe2450079}},	//   _неза, _müəl, _roţi_, _يخلي,
   {{0x70f62e36,0x60c2af7d,0x2ba50d4e,0xf3f90139}},	//   _رسائ, _thom, _गुजा, _soţi_,
   {{0xef19003c,0xf3f9002d,0x85970070,0x60c20371}},	//   buż_, _poţi_, לדיג_, _uhom,
   {{0x606311c0,0x7680af7e,0x00000000,0x00000000}},	//   _سهول, _köyd, --, --,
   {{0xaa640ea0,0x6d5c00ab,0x60160225,0x00000000}},	//   нтск, äras, bümü, --,
   {{0x79a4271c,0x78ad8db3,0x39a410b4,0x00000000}},	//   ерте, toav, ештв, --,
   {{0x7d1a0010,0x2db70122,0xf3f9002d,0x76800086}},	//   muts, _מלון_, _toţi_, _löyd,
   {{0x7d1aaf7f,0x7af00187,0x9773010b,0x78ad66a7}},	// [cd70] luts, čitý, лiся_, roav,
   {{0xfbd00082,0x7aedaf80,0xf7700206,0x60c90af3}},	//   _حتى_, _itat, داف_, zmem,
   {{0x9475064e,0x7d1a01d5,0x60c910ff,0x00000000}},	//   وگرا, nuts, ymem, --,
   {{0x61e8028b,0xe3b00df3,0x2245023a,0x7e6a0a81}},	//   _afdl, گرم_, _salk_, _lofp,
   {{0x7d1a01d5,0x2245af81,0x6e3a0345,0x601600c1}},	//   huts, _palk_, ketb, zümü,
   {{0x7d1aaf82,0x7aed023c,0x60c9055c,0x601601fb}},	//   kuts, _mtat, wmem, yümü,
   {{0xc619045c,0x7aed02c4,0x2245af83,0xa1560274}},	//   दलीय_, _ltat, _valk_, дају_,
   {{0x44390955,0x6a700301,0xf8bf00dc,0x7aed7326}},	//   _ús_, _häft, ्षिय, _otat,
   {{0x60c9af84,0x2245af85,0xaec5002d,0x7aed0979}},	//   rmem, _talk_, мбил, _ntat,
   {{0x3e8900d4,0x60c9af86,0xfe710037,0x4df410be}},	//   ійно_, smem, ئدة_, няют,
   {{0xdca617c2,0x7aedaf87,0x7d1aaf88,0xa2aa00b4}},	//   дани, _atat, guts, टवर्,
   {{0xa0c40037,0x60160448,0xa1340118,0x00000000}},	//   _كيلو, rümü, _سرمش, --,
   {{0x6d5c0454,0x9f4f7477,0x3af62e1b,0xa7fb0065}},	//   ärar, _begå_, ьянс, _goñi,
   {{0x7d1a0232,0x201f0443,0x68fb00cb,0xaec400d4}},	//   buts, lgui_, ćudn, _збіл,
   {{0x7aedaf89,0x2d9402fb,0x7d1a0371,0x00000000}},	//   _etat, _пръс, cuts, --,
   {{0x201f0443,0xb9060324,0xeb9a0043,0xa3cd0067}},	//   ngui_, _पढ_, _мий_, रधा_,
   {{0x76470010,0x26190d43,0x7c2404fb,0x78a102d7}},	// [cd80] _bajy, _पाखी_, _icir, élva,
   {{0x78a902c6,0xb4d601c0,0x00000000,0x00000000}},	//   čeva, सद्_, --, --,
   {{0x186a03fa,0x290500b5,0xddca021e,0xf65100b5}},	//   _дани_, álat_, _enfņ, ھئے_,
   {{0x6f1b046a,0xf48700d1,0x6e3a006c,0xd24f132d}},	//   kuuc, وانی, zetb, ینن_,
   {{0x63be0035,0x778300af,0x768000c3,0x80fa0831}},	//   ępno, _аляз, _pöyd, _ইমেজ_,
   {{0xe5a6034b,0x7d1a04fb,0xfbc00033,0x00000000}},	//   _жиги, yuts, _ইলাত, --,
   {{0x28c3006a,0xfd07006c,0x26d8af8a,0x00000000}},	//   _वीडि, _جج_, _iiro_, --,
   {{0x7d1a01d5,0x9e3c00d5,0x7647007b,0x05572b7d}},	//   vuts, hoďt, _zajy, _تلفظ_,
   {{0x6e230176,0xe29a1402,0x26d8289d,0x7647af8b}},	//   _bcnb, _даа_, _kiro_, _yajy,
   {{0x7d1aaf8c,0x44240028,0x26d8055c,0x7c24af8d}},	//   tuts, _hcm_, _jiro_, _acir,
   {{0xb80e04cc,0x6e3aaf8e,0x00000000,0x00000000}},	//   िणाम_, retb, --, --,
   {{0x7d1aaf8f,0xdefa00d8,0x26d8030d,0x00000000}},	//   ruts, _дык_, _liro_, --,
   {{0xc0a916e6,0x44245173,0x7d1aaf90,0x6d43af91}},	//   _عامل_, _mcm_, suts, _esna,
   {{0x26d80487,0x442400e2,0x7c240345,0x00000000}},	//   _niro_, _lcm_, _ecir, --,
   {{0x7647695c,0x6ca7002d,0x442400cc,0xead400af}},	//   _rajy, _ориж, _ocm_, торь,
   {{0x030e1033,0x787800b5,0xd5f400e2,0x00000000}},	//   _सिंह_, _hívj, _đán, --,
   {{0x26d85fb3,0x7c3daf92,0x7aed0054,0xf1de00e7}},	// [cd90] _biro_, mesr, _utat, मशान,
   {{0x2004af93,0xd5bbaf94,0x7c3d4478,0x442411f0}},	//   hami_, осе_, lesr, _acm_,
   {{0x20041359,0x26d80036,0x25b80118,0x80da0e6f}},	//   kami_, _diro_, _cyrl_, _पंगे,
   {{0x442442fc,0x2004af95,0x26d800ea,0x764704fb}},	//   _ccm_, jami_, _eiro_, _wajy,
   {{0x2004af96,0x27e9af97,0xf8b21804,0x92950499}},	//   dami_, mcan_, _תשכ_, надц,
   {{0x26d8af98,0x27e9af99,0x4424a277,0x6595af9a}},	//   _giro_, lcan_, _ecm_, _загу,
   {{0x6605005d,0x4424af9b,0xf20401e0,0x00000000}},	//   mahk, _fcm_, тячо, --,
   {{0x4094247f,0x66050d1c,0x60090b3b,0x201f010b}},	//   крыт, lahk, чним_, ugui_,
   {{0x443d0024,0xd426027d,0x201f0e95,0x64a403e6}},	//   mew_, ıştı_, rgui_, _раѓа,
   {{0x443daf9c,0x26d801dd,0x4d650f08,0x644b0cfd}},	//   lew_, _xiro_, еков, ldgi,
   {{0x506707b0,0xed59021d,0x645b0051,0x2fd90647}},	//   _отда, чон_, _knui, _فواد_,
   {{0x443daf9d,0x2004af9e,0x7c3daf9f,0x2d850207}},	//   new_, cami_, gesr, rzle_,
   {{0x6605128f,0xa3e40026,0x00000000,0x00000000}},	//   kahk, पुट_, --, --,
   {{0xddc30043,0x6605028b,0x6f090160,0x645b009e}},	//   _conţ, jahk, msec, _lnui,
   {{0x66051096,0x6d43afa0,0x443dafa1,0x19b900d4}},	//   dahk, _usna, kew_, дуть_,
   {{0x26d8afa2,0x46eaa027,0x443dafa3,0x7c3d0051}},	//   _siro_, здан_, jew_, cesr,
   {{0x6f0954cf,0x443dafa4,0xfd650019,0xe7371036}},	// [cda0] nsec, dew_, _nhuậ, нет_,
   {{0x27e97979,0x2004afa5,0x98c004d4,0x7bc4005f}},	//   acan_, zami_, ırır_, _iziu,
   {{0x26d86351,0x2004afa6,0x27e900ee,0xa49401cb}},	//   _viro_, yami_, bcan_, نیست,
   {{0x73e600d8,0x645b0284,0x3d01018d,0x64490952}},	//   ходз, _cnui, वीये_, _caei,
   {{0x20040bcc,0xf4840118,0x258600b8,0x6449005f}},	//   vami_, _یاری, _bílé_, _daei,
   {{0x66050ec0,0x200419d1,0x6f092181,0xc69402b5}},	//   cahk, wami_, dsec, _יאָ_,
   {{0x46a300c7,0x200405d1,0xe5a6002d,0x645b0345}},	//   _сарв, tami_, _чиви, _fnui,
   {{0x64490082,0x291894a4,0x4424afa7,0x645b01da}},	//   _gaei, irra_, _ucm_, _gnui,
   {{0x2004afa8,0x03a3957f,0x200f01f7,0x60d9099e}},	//   rami_, _бито, _ddgi_, _diwm,
   {{0x2004afa9,0x27e9afaa,0x29180055,0x00000000}},	//   sami_, zcan_, krra_, --,
   {{0x27e90250,0x6d41001e,0x2004afab,0x787806fe}},	//   ycan_, gwla, pami_, _cívk,
   {{0x00ca0c28,0x6605046a,0x69de009e,0x787800b8}},	//   _элек_, zahk, _agpe, _dívk,
   {{0x9f492ea0,0x2918afac,0x66050034,0x7c3dafad}},	//   _það_, erra_, yahk, resr,
   {{0x7bc44fac,0x443dafae,0x00000000,0x00000000}},	//   _dziu, zew_, --, --,
   {{0x19580104,0x98c70e9f,0x443d021e,0x7bc40409}},	//   нары_, есал, yew_, _eziu,
   {{0x6605012f,0x78a900cd,0x00000000,0x00000000}},	//   wahk, čevo, --, --,
   {{0x66050ce8,0x27e90381,0x2bd00084,0x2918afaf}},	// [cdb0] tahk, rcan_, सेदा, arra_,
   {{0x27e9afb0,0x64490029,0xdb9c0122,0x06b70416}},	//   scan_, _saei, _מסחר, رناک_,
   {{0x66050f1a,0xddc301ba,0xd0060df3,0x443dafb1}},	//   rahk, _konš, _پل_, tew_,
   {{0x66050f1a,0x765c012f,0x6f0902d7,0x756800b5}},	//   sahk, _enry, ysec, ریقہ_,
   {{0x62830297,0x387e000d,0x20c10079,0x644b017b}},	//   thno, être_, fóin_, rdgi,
   {{0x3869afb2,0x6605012f,0x672dafb3,0x3e7200f6}},	//   ljar_, qahk, mtaj, _mâts_,
   {{0x672dafb4,0x6f090223,0x443d035f,0x00000000}},	//   ltaj, wsec, pew_, --,
   {{0xfd6500e8,0x3869afb5,0xd9de00c4,0x6f090981}},	//   _thuậ, njar_, _मल्ट, tsec,
   {{0x672dafb6,0xfc3f0187,0x00000000,0x00000000}},	//   ntaj, deí_, --, --,
   {{0x6f0930a8,0x63bb4fbf,0xd011006c,0x672daeae}},	//   rsec, _iyun, _چلا_, itaj,
   {{0x6281afb7,0x3207afb8,0xfa270083,0x672d0f67}},	//   _illo, many_, য়াল_, htaj,
   {{0xeb9aafb9,0x32072555,0x3869035f,0x672dafba}},	//   дим_, lany_, jjar_, ktaj,
   {{0xc4d200c2,0x28db0299,0x78a90009,0x3869afbb}},	//   יגט_, _मंजि, čevl, djar_,
   {{0x3207afbc,0x62810176,0x386901f7,0x00000000}},	//   nany_, _jllo, ejar_, --,
   {{0x23e10099,0x9d450217,0x00000000,0x00000000}},	//   _फलंद, _рейд, --, --,
   {{0x63bb2024,0x32070987,0x38693049,0xbb86004f}},	//   _oyun, hany_, gjar_, _للبي,
   {{0xb8e90953,0x62810391,0x63bb348f,0x32070096}},	// [cdc0] _ली_, _ollo, _nyun, kany_,
   {{0x32070865,0xe8e00023,0xa68301f2,0x3869021d}},	//   jany_, _chợt_, алуд, ajar_,
   {{0x63a90391,0x63bbafbd,0x7878afbe,0x7ae4afbf}},	//   _axen, _ayun, _lívi, _huit,
   {{0x74135f8a,0x7ae441a2,0x62810db7,0xd7060896}},	//   لوما, _kuit, _allo, _изми,
   {{0x628101f4,0x7ae4afc0,0xfe210a40,0x3207afc1}},	//   _bllo, _juit, _मांस_, fany_,
   {{0x7ae4afc2,0xc7b30052,0x3207afc3,0x09d60033}},	//   _muit, _כבר_, gany_, _ত্যা,
   {{0xa3d30b39,0x4a9b02b5,0x30a648b9,0x1a9b02b5}},	//   हेब_, ויסג, крив, ויסע,
   {{0x62810083,0xd010004f,0x23710055,0x2eba021a}},	//   _ello, حلة_, ënjë_, उत्त,
   {{0x787811fa,0xa2e602ce,0x7ae4afc4,0x63bb0159}},	//   _cívi, _розд, _nuit, _gyun,
   {{0x78780279,0x24860484,0xb0610086,0x3207ac71}},	//   _dívi, lhom_, _ääne, cany_,
   {{0x7e7a77aa,0xfe6f0082,0x629802c6,0x361b1804}},	//   rktp, تدي_, mivo, וויד,
   {{0x7ae4afc5,0x62984d7f,0x6aab00e7,0x2486007a}},	//   _buit, livo, चक्र, nhom_,
   {{0x7ae4afc6,0xfc3f0132,0x00000000,0x00000000}},	//   _cuit, reí_, --, --,
   {{0x7ae450f9,0x00000000,0x00000000,0x00000000}},	//   _duit, --, --, --,
   {{0x3869afc7,0xfce303fa,0x7ae4009e,0x6d341403}},	//   tjar_, _којо, _euit, _сейф,
   {{0x672d03ad,0xf8bf3779,0x3207088d,0x7ae4afc8}},	//   ttaj, ्षेप, zany_, _fuit,
   {{0x38697710,0x7ae40fe4,0x2486003c,0x6298afc9}},	// [cdd0] rjar_, _guit, dhom_, kivo,
   {{0x62980888,0xd04b01c2,0x2b490160,0x63bb0371}},	//   jivo, _digə, _isac_, _ryun,
   {{0x32070187,0xdc4300b8,0x00000000,0x00000000}},	//   vany_, _léčb, --, --,
   {{0x3207006a,0x672dafca,0xb4bf018d,0x628101f4}},	//   wany_, ptaj, ुगे_, _sllo,
   {{0x3207afcb,0x7d1a033b,0x862502fd,0x00000000}},	//   tany_, hrts, _مکال, --,
   {{0x62980526,0xe2c80312,0x2b1b00ab,0x00000000}},	//   givo, نونو_, _बिनु_, --,
   {{0xd5b802ee,0x320715db,0x7cd40160,0x00000000}},	//   _аст_, rany_, _vărz, --,
   {{0xd174005f,0x32070035,0x24861086,0xdf491403}},	//   рышы, sany_, chom_, езид_,
   {{0x99bf00c8,0xe3b800af,0x32071c7b,0x00000000}},	//   _আলোক, _алтч_, pany_, --,
   {{0xa3c8009a,0x628107a6,0x7ae4afcc,0x7878171c}},	//   _उरत_, _ullo, _ruit, _vívi,
   {{0x7ae4afcd,0x78a908b7,0x68e300e0,0x00000000}},	//   _suit, čevj, _éndh, --,
   {{0x3205006c,0x2b4900d7,0x7ae4afce,0xdb0d01ef}},	//   _hely_, _bsac_, _puit, _azañ,
   {{0x3205005f,0x7ae48d52,0x7d1a0fdb,0x00000000}},	//   _kely_, _quit, arts, --,
   {{0xbf9a0317,0x1e8412ea,0x8f9a1804,0x320500fe}},	//   _אינש, _клім, _איני, _jely_,
   {{0x63be004e,0xb6060187,0x3205006c,0x00000000}},	//   ępni, ntáž, _mely_, --,
   {{0x7ae4afcf,0x629805e2,0x32050051,0xb6030097}},	//   _tuit, zivo, _lely_, hráč,
   {{0x9b460bdf,0xb60300d5,0x00000000,0x00000000}},	// [cde0] _صندو, kráč, --, --,
   {{0x4a4657d9,0x2486035f,0xb60600d5,0x00000000}},	//   _снов, whom_, ktáž, --,
   {{0x2486afd0,0x629800d5,0x295601d3,0x3cef0160}},	//   thom_, vivo, _съпр, _învă_,
   {{0x7c2661f5,0x2366006d,0x6f1b00d5,0xb3860421}},	//   ngkr, txoj_, kruc, ллел,
   {{0xe29a1f7e,0x62982140,0x2486afd1,0x3205053e}},	//   над_, tivo, rhom_, _bely_,
   {{0x55e310d4,0x6f1b6894,0x2486035f,0x32050bca}},	//   _горб, druc, shom_, _cely_,
   {{0x64a60de2,0x00000000,0x00000000,0x00000000}},	//   _бава, --, --, --,
   {{0x764e3069,0x62982dea,0xfe210026,0x78a46552}},	//   _haby, sivo, _माउस_, nniv,
   {{0x4426043d,0x764eafd2,0x64420037,0x629800fe}},	//   mgo_, _kaby, meoi, pivo,
   {{0x4426afd3,0x225e046a,0x64420037,0x3205afd4}},	//   lgo_, _untk_, leoi, _gely_,
   {{0x5275285d,0x4426027a,0x2d8100ab,0x764e50d1}},	//   _туту, ogo_, _ühel_, _maby,
   {{0x4426afd5,0x64420037,0x6f1bafd6,0x5b2740b4}},	//   ngo_, neoi, bruc, льга,
   {{0x442602b3,0x6f1bacf6,0x78a4afd7,0xdfd20037}},	//   igo_, cruc, dniv, _ايش_,
   {{0x764eafd8,0x64420315,0x68e500c3,0x7c260223}},	//   _naby, heoi, _puhd, agkr,
   {{0x82770070,0xd9182e1b,0x00000000,0x00000000}},	//   נעלע_, льт_, --, --,
   {{0x6d4aafd9,0x6d58141d,0x57f51f1b,0x6f029927}},	//   _isfa, _irva, рпат, _kwoc,
   {{0x6d580877,0x6442afda,0x44260168,0x00000000}},	// [cdf0] _hrva, deoi, dgo_, --,
   {{0x4426006a,0x6d580496,0x5f1c00be,0x200601ed}},	//   ego_, _krva, _मिन्_, _leoi_,
   {{0x290c6107,0x764e0088,0x3cea00ab,0xfc3f178f}},	//   ádat_, _daby, _घूमे_, cníc_,
   {{0x4426afdb,0xd5b85a00,0x6442afdc,0x6f020035}},	//   ggo_, усу_, geoi, _owoc,
   {{0xd5af07a8,0x7680027d,0x442900ea,0x00000000}},	//   _کہا_, _köyl, ļa_, --,
   {{0x442635d4,0x4429afdd,0x764e25e4,0x272f00c1}},	//   ago_, ża_, _gaby, mün_,
   {{0x20190132,0x272f0448,0xfa7800a5,0x4426afde}},	//   ósio_, lün_, רעות_, bgo_,
   {{0x69c80035,0xb6060187,0x764eafdf,0x6f02021e}},	//   żdeg, rtáž, _zaby, _bwoc,
   {{0x6d580ccf,0x272f06d0,0x8fa500d8,0xf7720070}},	//   _arva, nün_, рапе, ַקט_,
   {{0x6f1bafe0,0x78a4008b,0x2ca900be,0xf1ca00ac}},	//   rruc, zniv, _ajad_, _stáž_,
   {{0x6607afe1,0x26c10183,0x7e54010b,0x00000000}},	//   _mejk, ilho_, стыц, --,
   {{0x6d583c1a,0x673dafe2,0x66070478,0x6f1b01ae}},	//   _drva, _opsj, _lejk, pruc,
   {{0x6d5806ba,0x76800723,0x984801c2,0x69c1027d}},	//   _erva, _böyl, xşı_, ülen,
   {{0x4426afe3,0x660700b8,0x00000000,0x00000000}},	//   zgo_, _nejk, --, --,
   {{0xd9460165,0x4426099e,0x78a4afe4,0xc8960dec}},	//   шеви, ygo_, tniv, арањ,
   {{0x7d560122,0x7d1cafe5,0x78a4afe6,0x764e8fab}},	//   _כיצד_, árse, univ, _saby,
   {{0x753c006a,0x272f1a68,0x66071345,0xa76600c7}},	// [ce00] _sprz, gün_, _bejk, шкад,
   {{0x98480dac,0xe7370185,0x764e1505,0x290c0037}},	//   rşı_, реф_, _qaby, ádas_,
   {{0x6442004f,0x6607023a,0x92020228,0x00000000}},	//   teoi, _dejk, šāka, --,
   {{0x4426afe7,0x764e0979,0x00000000,0x00000000}},	//   ugo_, _waby, --, --,
   {{0x6442004f,0x660740f5,0x764e6819,0xc24600af}},	//   reoi, _fejk, _taby, индк,
   {{0x4426afe8,0x8b5702b5,0x644292f7,0xc2b60274}},	//   sgo_, יינס_, seoi, шљењ,
   {{0xe5a3049f,0x753c0035,0x200601ed,0x00000000}},	//   _дири, _uprz, _peoi_, --,
   {{0x64a63869,0x6f0202e9,0x9f4f00de,0x395a0176}},	//   _таба, _pwoc, _negó_, _mrps_,
   {{0x08770070,0x25c605f8,0xae21021a,0x00000000}},	//   שעפט_, _वरुण, _माखन_, --,
   {{0x6d581851,0x78a90496,0xd73700a5,0x00000000}},	//   _prva, čevi, סטית_, --,
   {{0x272f037a,0x395a0051,0x7d0300e5,0x2a730107}},	//   zün_, _nrps_, _cwns, _roxb_,
   {{0x76800d6f,0xb17b00c2,0xc19b0122,0xa17b02b5}},	//   _söyl, _שטאר, _בשבי, _שטאט,
   {{0x395a00e0,0x9fe51301,0xdef4010b,0x00000000}},	//   _arps_, _اسمه, _уплы, --,
   {{0x6d581840,0x8af00095,0x38620107,0x79a70036}},	//   _trva, _irəl, _ankr_, арбе,
   {{0xdd9300d8,0xa3b80084,0x6d58afe9,0xfc3f0300}},	//   _машы, _घुस_, _urva, anía_,
   {{0x272f3410,0xa56701cb,0x673d00e0,0x00000000}},	//   tün_, یدان, _ppsj, --,
   {{0x7c2dafea,0x213e012f,0x35e7afeb,0x00000000}},	// [ce10] _icar, _lpth_, ацев, --,
   {{0xbebd3bc2,0xc61f0083,0x272fafec,0x7c2dafed}},	//   ltūr, ন্না_, rün_, _hcar,
   {{0x19ab03e6,0xf3f902fb,0xceb3011d,0x272f01fb}},	//   _штип_, гнеш_, קיע_, sün_,
   {{0xdd8607a8,0xbebd26e3,0x5dd90070,0xe4a401e0}},	//   _ہو_, ntūr, אַנס, орчо,
   {{0xb4c70084,0x66070031,0xa8020042,0x00000000}},	//   _उठी_, _tejk, óñen, --,
   {{0xa5f8afee,0xdd864e87,0xa2291482,0x00000000}},	//   _веру_, _فو_, ужка_, --,
   {{0xbebd1638,0x9877013b,0x00000000,0x00000000}},	//   ktūr, lçı_, --, --,
   {{0x1dba0066,0xfbdf0132,0xd7f80023,0x40490200}},	//   _उड़त, ndês_, _đăk_, упио_,
   {{0x442d4f91,0x9877013b,0x00000000,0x00000000}},	//   _ice_, nçı_, --, --,
   {{0xe1f0afef,0x7c2d272d,0x628aaff0,0x52740037}},	//   _قسم_, _acar, chfo, _والز,
   {{0xa3d37d77,0x7af60093,0xc21200a5,0x5f130387}},	//   हेर_, _styt, _זהב_, _दिक्_,
   {{0xa2c501d1,0x987700c1,0xcb6a2746,0x249d00e9}},	//   ितव्, kçı_, гаме_, niwm_,
   {{0x442d053e,0x929d0035,0x395a8a8f,0xc61f0831}},	//   _mce_, _zwła, _srps_, ন্যা_,
   {{0x7c2daff1,0x442d00d7,0x6eed00ee,0x00000000}},	//   _ecar, _lce_, _hĺbo, --,
   {{0x6da20c98,0x442daff2,0xada26a4a,0xbcf50180}},	//   _ниша, _oce_, _нашл, _استغ,
   {{0x442d006f,0x7c2d0079,0x00000000,0x00000000}},	//   _nce_, _gcar, --, --,
   {{0x249d00e9,0xa686263b,0xddd800ee,0x00000000}},	// [ce20] diwm_, блад, _dovŕ, --,
   {{0x59863425,0x49ba02e7,0x442d441c,0x7ebd0392}},	//   _глоб, _ماجد_, _ace_, cèpt,
   {{0xa3da0af9,0x09d60033,0x64a601e0,0x7ebd0176}},	//   डेन_, _ত্রা, бажа, lèps,
   {{0xa5070ea6,0x186a0e60,0xe1ff0023,0x986a00af}},	//   сеца_, _сами_, _đóa_, _симб_,
   {{0xe8e000cc,0x00000000,0x00000000,0x00000000}},	//   _chụt_, --, --, --,
   {{0x461600f5,0x925803b2,0xbb3b0070,0x00000000}},	//   _دوسر, ракт_, רעסי, --,
   {{0x442d0096,0x41b401df,0x00000000,0x00000000}},	//   _fce_, غمبر, --, --,
   {{0x442d422c,0xb4e4021a,0x2b40aff3,0x2ef41e9c}},	//   _gce_, नदी_, _opic_, озир,
   {{0x3f820355,0x93aa00fd,0x7e63055c,0x999a0409}},	//   áku_, _صارف_, _bnnp, _kapų_,
   {{0x7c2d4215,0x6e663312,0x00000000,0x00000000}},	//   _scar, стиж, --, --,
   {{0xb6bb00c2,0x2b400176,0x628801a3,0xa2c506fe}},	//   רציי, _apic_, _ildo, ितर्,
   {{0x320e012f,0x69c1aff4,0x7e630103,0xdfd25cfa}},	//   lafy_, ülem, _ennp, _فيض_,
   {{0x29110067,0x00000000,0x00000000,0x00000000}},	//   wsza_, --, --, --,
   {{0xa3da3e72,0x00000000,0x00000000,0x00000000}},	//   डेय_, --, --, --,
   {{0xc61f0033,0x2b400147,0x7c2d009e,0x00000000}},	//   ন্ডা_, _epic_, _tcar, --,
   {{0xc4c4040d,0xb4c70c3e,0x9877037a,0xdca40bfe}},	//   _سے_, _उठे_, tçı_, _наји,
   {{0x29110332,0xe7300c74,0x6288aff5,0xd7f84c7b}},	// [ce30] ssza_, فصل_, _oldo, сус_,
   {{0xf77021a0,0x7afdaff6,0x29110035,0x7bcd00ea}},	//   راق_, mpst, psza_, _izau,
   {{0x7afdaff7,0x2cfb016b,0x00000000,0x00000000}},	//   lpst, ָלדא, --, --,
   {{0xccf302b5,0x3aef0471,0x7afdaff8,0x291e00cd}},	//   לכע_, _küp_, opst, štac_,
   {{0xa3d30b4a,0xe3b3004f,0x00000000,0x00000000}},	//   हें_, أرض_, --, --,
   {{0x65950409,0xd9fb4068,0x9119002d,0x7afd0345}},	//   _дагу, ्रित_, ациу_, ipst,
   {{0x442d98df,0xdcf500ea,0x85573c96,0x00000000}},	//   _tce_, ēcīg, _دیار_, --,
   {{0xef195431,0x2eb3074f,0xf43400af,0xe8e000e2}},	//   ами_, ुत्त, _несэ, _thụt_,
   {{0xd9fb00a1,0x70760037,0x62880260,0x335800af}},	//   ्रात_, تميز_, _fldo, _латэ_,
   {{0x273b002d,0xee362e1b,0x2b4000ee,0x00000000}},	//   mână_, онь_, _rpic_, --,
   {{0x7afdaff9,0xf8bf9599,0x8c465a04,0xd01911c0}},	//   epst, _oké_, оене, _نقاش_,
   {{0x2d8b004e,0x62830051,0x7d1c00b5,0x2247a918}},	//   ące_, lkno, ársa, lenk_,
   {{0x25c60ac4,0x2d8333c7,0x6eed00ee,0x00000000}},	//   _वर्ण, šje_, _kĺbm, --,
   {{0xc61f0083,0xf8bf01ba,0xefb300d1,0x66cb01fb}},	//   ন্তা_, _aké_, _ویژگ, yüka,
   {{0x38c80148,0x7bcd06a2,0x21270124,0x7afd0d35}},	//   ماری_, _ezau, nunh_, apst,
   {{0x2247affa,0xa3da1856,0x00000000,0x00000000}},	//   henk_, डेड_, --, --,
   {{0xe1ff01a5,0x2b400176,0x68fc0124,0x62830223}},	// [ce40] _đón_, _upic_, sprd, kkno,
   {{0xd6260037,0x00000000,0x00000000,0x00000000}},	//   تعري, --, --, --,
   {{0x37e62682,0x224732c5,0xa96a692c,0x00000000}},	//   _монг, denk_, _тина_, --,
   {{0x629a023a,0x6abcaffb,0x00000000,0x00000000}},	//   _smto, lorf, --, --,
   {{0x1339006c,0x926aaffc,0x00000000,0x00000000}},	//   متوں_, ирка_, --, --,
   {{0x2734affd,0xda0a0b7a,0xdce900b8,0x00000000}},	//   män_, वरित_, íněn, --,
   {{0x273400c3,0xa08a0036,0x320e189a,0xe57a0274}},	//   län_, исиз_, rafy_, _тзв_,
   {{0xb97b02b5,0xc05a0044,0xc61f0033,0xf8bf0036}},	//   ינצי, рік_, ন্দা_, _xké_,
   {{0x7bc4046a,0xeeaa00d4,0x273400c3,0x03a3a616}},	//   _nyiu, иток_, nän_, _жито,
   {{0x62830602,0xe29700af,0x6146005f,0xb2230043}},	//   ckno, _дау_, _меза, _омул,
   {{0x273403ad,0xd00f1334,0x3c5900af,0x00000000}},	//   hän_, _оф_, бинэ_, --,
   {{0x27340328,0xdee60214,0x656801f7,0x00000000}},	//   kän_, _доди, _àdhu, --,
   {{0x27340086,0x320c016f,0x09e300e7,0x6abc082b}},	//   jän_, _kedy_, पश्य, forf,
   {{0x273403ad,0x7afdaffe,0x320cafff,0x6abc016e}},	//   dän_, rpst, _jedy_, gorf,
   {{0xfc3f00b8,0x00000000,0x00000000,0x00000000}},	//   lním_, --, --, --,
   {{0x7afd0343,0x5b150431,0x3aef0225,0x320c0af9}},	//   ppst, _емит, _tüp_, _ledy_,
   {{0x6d5ab000,0x02ca05f8,0x00000000,0x00000000}},	// [ce50] lvta, िताभ, --, --,
   {{0xaad204aa,0x693500af,0xe8eb05f5,0x00000000}},	//   _दीपक, _еноу, _پردو_, --,
   {{0x7aed5cb5,0xea000019,0x00000000,0x00000000}},	//   _huat, _hiếu_, --, --,
   {{0x78a9b001,0x7aed7e8a,0xe3b30e3a,0x76010160}},	//   čevs, _kuat, ورش_, _bâzâ,
   {{0x6d5e007e,0x2bde01c0,0xeab00919,0x1304010b}},	//   _špal, नेपा, _سعی_, дзім,
   {{0x09df0b52,0x7aed0ec0,0xe1f109b9,0xfc3f01c0}},	//   _ব্যা, _muat, رست_, dním_,
   {{0x7aedb002,0x91e27314,0x62830e54,0x320c012f}},	//   _luat, ноше, rkno, _dedy_,
   {{0x7ae50006,0x628301c0,0x76550345,0x7aedb003}},	//   _liht, skno, _hazy, _ouat,
   {{0x443f0452,0x600615eb,0x66d01ab7,0x7655b004}},	//   _ibu_, чным_, säke, _kazy,
   {{0x76550076,0x320c1808,0x6eed00a0,0x00000000}},	//   _jazy, _gedy_, _hĺbk, --,
   {{0x69c51b41,0x7f4200a2,0x765500c7,0x443f52f3}},	//   _nyhe, _epoq, _mazy, _kbu_,
   {{0x7aedb005,0xfc3f0355,0x6ab40ed1,0x6abc033b}},	//   _buat, bním_, ंक्र, worf,
   {{0x7aed0083,0x6abcb006,0x443f25b4,0x7ae50448}},	//   _cuat, torf, _mbu_, _biht,
   {{0x2734b007,0x76550035,0xfe350070,0xddc800ea}},	//   vän_, _nazy, _זאַך_, ņoša,
   {{0x186a0ea6,0x6d460035,0x443f1c95,0x69d10ea3}},	//   бави_, łkar, _obu_, _धरणी,
   {{0x38660f56,0x2734112d,0x7aedb008,0x6d430159}},	//   ñor_, tän_, _fuat, _ipna,
   {{0x7aed0b68,0x7ae502c4,0xa68603e6,0xf7432d2b}},	// [ce60] _guat, _fiht, плад, нето,
   {{0x2734b009,0x4cd10033,0x6736b00a,0x7ae500f4}},	//   rän_, _সংযু, rtyj, _giht,
   {{0x273400c3,0x67360104,0x20c10079,0x443f0103}},	//   sän_, styj, nóis_, _bbu_,
   {{0x66e61499,0x7655008c,0xd49901e0,0x00000000}},	//   _нома, _eazy, орі_, --,
   {{0x443f0a8a,0x833a00c3,0x69c00225,0x2a7a0116}},	//   _dbu_, счет_, şmed, _kopb_,
   {{0x6d43b00b,0xfc3f01c0,0x6724007a,0x443fa08d}},	//   _opna, vním_, mrij, _ebu_,
   {{0x15434dcc,0xa3da0324,0x320c01ba,0x672402a2}},	//   _перм, डे़_, _vedy_, lrij,
   {{0xfc3f00b8,0x660e00ac,0x7e78b00c,0x672400f4}},	//   tním_, _hebk, _sovp, orij,
   {{0xaed40009,0x320c01c0,0x248602b2,0x7e7802c6}},	//   моиш, _tedy_, mkom_, _povp,
   {{0x2486b00d,0x660e0029,0xddc304d9,0x46be051d}},	//   lkom_, _jebk, _donž, ्तिह,
   {{0x7aed1201,0x672404ce,0x7ae5b00e,0x2d820124}},	//   _suat, hrij, _riht, _očeš_,
   {{0x68e60076,0x7ae503a6,0x7aed00d7,0x660e14f0}},	//   _nikd, _siht, _puat, _lebk,
   {{0x60c2a495,0x46be0edf,0x7b642d4d,0x2a7a01f7}},	//   _ikom, ्ताह, нтре, _bopb_,
   {{0x6724b00f,0xdfa50082,0x34a90722,0x248615ce}},	//   drij, _تحمي, _कद्द, hkom_,
   {{0xfc3f016f,0x7ae51b43,0x672400be,0x60c24629}},	//   nník_, _viht, erij, _kkom,
   {{0x7aed0014,0x98c400af,0x24860254,0x3ebe00b5}},	//   _tuat, есул, jkom_, lott_,
   {{0x6724b010,0x2486b011,0x443f028b,0x473500d8}},	// [ce70] grij, dkom_, _rbu_, ьнас,
   {{0xcb1201f3,0x20c10037,0x443f198d,0x3ebeb012}},	//   _שלי_, nóir_, _sbu_, nott_,
   {{0x60c24c29,0x6d5e0168,0x63a46331,0xfc3f0097}},	//   _okom, _špaj, úinn, jník_,
   {{0x20c1004f,0xfc3f024e,0x672401a0,0x60c2b013}},	//   hóir_, dník_, brij, _nkom,
   {{0x2fc60189,0x78ad1a43,0x3ebeb014,0x00000000}},	//   _nyog_, mnav, kott_, --,
   {{0x60c2b015,0x78adb016,0x6145002d,0xa1c5b017}},	//   _akom, lnav, дека, мблд,
   {{0x3ebeb018,0x20c10037,0x78adb019,0x443f009e}},	//   dott_, dóir_, onav, _tbu_,
   {{0x2486b01a,0x443f070b,0x78adb01b,0x8af000a8}},	//   ckom_, _ubu_, nnav, _irəv,
   {{0x644bb01c,0x66cb00d0,0x66d01cb5,0x00000000}},	//   megi, yükl, läka, --,
   {{0x644bb01d,0x6459b01e,0x20c1004f,0x3ebeb01f}},	//   legi, ldwi, góir_, gott_,
   {{0x6724b020,0x248d0a81,0xfc3f0097,0x78ad05ee}},	//   zrij, _klem_, cník_, knav,
   {{0x6459b021,0x644bb022,0x442f179a,0x20c117db}},	//   ndwi, negi, ngg_, róis_,
   {{0xee2e116b,0xeb976341,0x3ebeb023,0x60db0be0}},	//   _ин_, дия_, bott_, mmum,
   {{0x60c9b024,0x6724b025,0x2486b026,0x20c10079}},	//   llem, vrij, zkom_, cóir_,
   {{0xb9b501d3,0x644b2d7d,0x2486b027,0x66cb0448}},	//   естъ, kegi, ykom_, rükl,
   {{0x6724b028,0x768003ad,0x60c9b029,0x291e0254}},	//   trij, _löyt, nlem, štao_,
   {{0xe7370011,0x248625ff,0x07a313f9,0x644bb02a}},	// [ce80] мет_, vkom_, ватн, degi,
   {{0x200fb02b,0x6724b02c,0x2d8100ab,0x248db02d}},	//   _legi_, rrij, _ühes_, _alem_,
   {{0x24860af1,0x60c9b02e,0x78ad0223,0x60db00d7}},	//   tkom_, klem, bnav, kmum,
   {{0x3ebe0332,0xfc3f0076,0x644bb02f,0x200fb030}},	//   zott_, vník_, gegi, _negi_,
   {{0x2486b031,0x60c90b87,0x69c100be,0x228b0185}},	//   rkom_, dlem, ülev, _søka_,
   {{0x24863ce5,0x60c2b032,0xfc3f0187,0x248d00fd}},	//   skom_, _skom, tník_, _elem_,
   {{0x644b8949,0x248603c9,0x200f01d7,0x21670274}},	//   begi, pkom_, _begi_, дији_,
   {{0x60c9b033,0x2120068b,0x9f542bfa,0xfc3f0187}},	//   glem, čih_, евич, rník_,
   {{0x3ebe0332,0x200f0093,0x20c10037,0x3cfc0223}},	//   tott_, _degi_, tóir_, _stvv_,
   {{0x78ad02dd,0x60c9b034,0x78a400be,0x00000000}},	//   znav, alem, hiiv, --,
   {{0x3ebeb035,0x20c10037,0x3eac0523,0xa3da01c0}},	//   rott_, róir_, rndt_, डेर_,
   {{0x60c23069,0x10160a86,0xc0aa27f6,0x20c10079}},	//   _ukom, _آباد, _باطل_, sóir_,
   {{0x3ebe006c,0x78ad02c6,0x2fc6011e,0x7c3d008d}},	//   pott_, vnav, _uyog_, rfsr,
   {{0x60c0b036,0x644bb037,0x8d760079,0x00000000}},	//   lomm, zegi, _ياغا, --,
   {{0x78adb038,0x442f1281,0x768000c3,0x19581482}},	//   tnav, ygg_, _löys, мары_,
   {{0x58d4b039,0x60c0b03a,0x31570070,0x7bc12f80}},	//   вост, nomm, וילן_, ğlub,
   {{0x644b0093,0x442f058d,0x3f84b03b,0x6d5e00f4}},	// [ce90] vegi, vgg_, nymu_, _špah,
   {{0x3ce90221,0x644b02e6,0x248db03c,0x60c9ac0a}},	//   _hiav_, wegi, _slem_, zlem,
   {{0x644bb03d,0x60c0b03e,0x3ce901e8,0x78ad75e0}},	//   tegi, komm, _kiav_, pnav,
   {{0x52b91371,0x94040118,0x947500d1,0x3f8400c7}},	//   ेत्स, نومه, رگزا, kymu_,
   {{0x200fb03f,0x6459b040,0x60c0b041,0xa3da1bb5}},	//   _regi_, rdwi, domm, डेल_,
   {{0x200fb042,0x644b01d7,0x672d5671,0x00000000}},	//   _segi_, segi, muaj, --,
   {{0x34950d44,0x60c907cd,0xa3d304bc,0x26c10118}},	//   _завр, tlem, हेज_, moho_,
   {{0x45d40d36,0x249f1cad,0x3ce9006d,0x9f4f01ef}},	//   _росс, _umum_, _niav_, _afgá_,
   {{0x60c94a6c,0x200fb043,0x00000000,0x00000000}},	//   rlem, _vegi_, --, --,
   {{0xee392afc,0xfe710082,0x26c100a0,0x60c9b044}},	//   чно_, ادة_, noho_, slem,
   {{0x200f007c,0xa2bc00b4,0x60c00051,0x2ca06721}},	//   _tegi_, शकर्, bomm, _pmid_,
   {{0x60c09dff,0x3ce90221,0x26c10a04,0x672db045}},	//   comm, _ciav_, hoho_, kuaj,
   {{0x3ce901e8,0x26c1024e,0x68fe00e7,0xdd8e0609}},	//   _diav_, koho_, _stpd, لوی_,
   {{0x291e003a,0x3f7a0070,0x00000000,0x00000000}},	//   štam_, _מאנס, --, --,
   {{0xd943010e,0x78a42efa,0xdca613f8,0x3ea900b8}},	//   лери, tiiv, _паки, čitě_,
   {{0x2ca00510,0x3ea500be,0xb4b901c0,0x00000000}},	//   _umid_, lilt_, घको_, --,
   {{0x6843002d,0x672db046,0xdbd200be,0x00000000}},	// [cea0] ынта, guaj, nüüm, --,
   {{0x78bb0a78,0x86c611cf,0x78a40303,0x3ea500be}},	//   čuva, ريان, siiv, nilt_,
   {{0x1a9b0779,0x69c10332,0x4a9b0070,0x2d8521e8}},	//   _זייע, ület, _זייג, nyle_,
   {{0x3ce90221,0x3ea5b047,0x00000000,0x00000000}},	//   _xiav_, hilt_, --, --,
   {{0x3ea5b048,0x26c10a04,0xa3da0066,0x623400af}},	//   kilt_, boho_, डें_, велу,
   {{0x7d1cb049,0x3326258e,0x00000000,0x00000000}},	//   ársk, rrox_, --, --,
   {{0xd5b20fab,0x60c0b04a,0x3ea519b9,0x5637016b}},	//   _صفر_, tomm, dilt_, _ראלע_,
   {{0x653b0070,0x3f8400c7,0x33262e65,0xd0100079}},	//   _מעלד, tymu_, prox_, جلة_,
   {{0x60c0b04b,0x4ea60969,0x3ce900e2,0x66d01c52}},	//   romm, ерна, _riav_, näko,
   {{0x60c0b04c,0x3ce90221,0xaca7006c,0x3ea5b04d}},	//   somm, _siav_, کھتے_, gilt_,
   {{0x291e0a78,0xc6930122,0x3ce90189,0x60c0b04e}},	//   štaj_, ראת_, _piav_, pomm,
   {{0xe1ff0023,0x628a0124,0x66cbb04f,0x3ea5009e}},	//   _đói_, lkfo, tükk, ailt_,
   {{0x3ce901e8,0x3ea50557,0x9f3400d4,0xab872659}},	//   _viav_, bilt_, _релі, хунк,
   {{0x628a53a2,0xdfcf004f,0x2d857772,0x00000000}},	//   nkfo, _ايه_, byle_, --,
   {{0x3cea006a,0x3ce90189,0xdd8f75ea,0x9e6500b5}},	//   _घंटे_, _tiav_, _сш_, _جانن,
   {{0x672db050,0x00000000,0x00000000,0x00000000}},	//   tuaj, --, --, --,
   {{0x66d0013c,0x16be0067,0x00000000,0x00000000}},	// [ceb0] räkn, ्तूब, --, --,
   {{0xc13b0019,0x26d80211,0x672d0031,0x69c1b04f}},	//   _cướp_, _chro_, ruaj, üles,
   {{0x09df0083,0x7d1a712f,0x26c10054,0x672d002f}},	//   _ব্রা, nsts, roho_, suaj,
   {{0xe4e400ef,0x2bde0378,0x6aa701e4,0x672db051}},	//   гічн, नेवा, lijf, puaj,
   {{0x69d801ba,0x672d01f4,0xdd0100cd,0x00000000}},	//   _úver, quaj, _čučn, --,
   {{0x7d1a00d4,0x00000000,0x00000000,0x00000000}},	//   ksts, --, --, --,
   {{0xd49b9753,0x45d402fb,0x7d1a0051,0x00000000}},	//   _ера_, _борс, jsts, --,
   {{0x42d100c8,0xa4d50131,0x44f7008f,0x6aa702a2}},	//   াদেশ, _робі, _iç_, hijf,
   {{0x1ea800e0,0x3f8b01ba,0x3ea5b052,0x34940b5e}},	//   کايي_, ácu_, tilt_, _сатр,
   {{0x4d652f19,0x81e60033,0x645b3491,0x01e30033}},	//   вков, পড়_, _haui, নুষদ,
   {{0xc5f20bed,0x7d1a00ea,0x3f8b011c,0x2b4939a9}},	//   ידי_, gsts, šcu_, _apac_,
   {{0xdca61578,0x291e00f4,0x3ea57baf,0x00000000}},	//   тами, štak_, silt_, --,
   {{0x2901b053,0x3ea500ab,0x59df0380,0xaf370118}},	//   _atha_, pilt_, फेसर, _سرشت,
   {{0xc3320070,0x2b490027,0x66d000c3,0x6f1b02b1}},	//   בוך_, _dpac_, väko, msuc,
   {{0x6f1ba063,0x78bb0124,0x00000000,0x00000000}},	//   lsuc, čuvn, --, --,
   {{0xa2a10e61,0x645b0409,0xab661402,0x00000000}},	//   कोत्, _naui, _авил, --,
   {{0x6f1b01ae,0x69c1027d,0x44f7033e,0x8a060382}},	// [cec0] nsuc, üler, _aç_, _изпе,
   {{0x6aa701e4,0x06b50033,0x661701b7,0x00000000}},	//   cijf, _জীবি, gaxk, --,
   {{0x6f1b01ae,0xd8260370,0x98ad027d,0x00000000}},	//   hsuc, _идни, _çoğu_, --,
   {{0x52ca04e9,0x2b4900c7,0xb3860009,0xe475010b}},	//   ित्स, _ypac_, клел, лучэ,
   {{0xe29a07fa,0xe3b208cf,0x26d80090,0x00000000}},	//   мад_, جرا_, _thro_, --,
   {{0xe1ef0098,0x66031303,0x00000000,0x00000000}},	//   يسى_, _впра, --, --,
   {{0x628ab054,0x645b0211,0x91f500e2,0x00000000}},	//   rkfo, _faui, _sác, --,
   {{0x765cb055,0x518370a5,0x855700a5,0x60d9016e}},	//   _hary, руша, _בשלב_, _chwm,
   {{0x765c1581,0xa3d64ae7,0xb4c00e61,0xaab20067}},	//   _kary, _हरि_, ुती_, ँचाक,
   {{0xd337011d,0x6e943fec,0x66cb00be,0x765cb056}},	//   _ברמה_, الدا, tüki, _jary,
   {{0xf29700a5,0x765cb057,0x00000000,0x00000000}},	//   _שכבר_, _mary, --, --,
   {{0x4fc61bfd,0x6abd0026,0x7d1a1167,0x644201ef}},	//   _исла, ोत्र, rsts, nfoi,
   {{0x7d1ab058,0x98a30067,0x2bde00b8,0x00000000}},	//   ssts, nują_, नेला, --,
   {{0x765cb059,0xbea3b05a,0x6f020024,0x00000000}},	//   _nary, _качк, _itoc, --,
   {{0x66d00282,0x63be0035,0x3ed90070,0x69c00225}},	//   räkl, ępny, _אַקא, şmen,
   {{0x2aad025c,0x6d58010b,0x98a30067,0x6d4a0027}},	//   džbe_, _isva, kują_, _ipfa,
   {{0x765cb05b,0xd7d50274,0xd7f8a387,0x00000000}},	// [ced0] _bary, ужањ, тус_, --,
   {{0xba552b9e,0x79a71e26,0x765c00e5,0x98a30067}},	//   _свој, _арме, _cary, dują_,
   {{0x765c00d8,0x645b8df1,0x9c6401cb,0xa2c606fe}},	//   _dary, _paui, _صهیو, िवन्,
   {{0x7bcd0103,0x6f02b05c,0x00000000,0x00000000}},	//   _kyau, _otoc, --, --,
   {{0x765c0fe2,0x4c9c025a,0x6d5d0228,0x00000000}},	//   _fary, ובאו, āsai, --,
   {{0x6d5805e2,0x6d4a01b4,0x765c187a,0xfb16016b}},	//   _osva, _opfa, _gary, אַקט_,
   {{0x81cb00c8,0xc6920070,0x6f02016e,0x10a51622}},	//   রেন_, _פאל_, _atoc, ликн,
   {{0x6615b05d,0x765cb05e,0x30190037,0x6f1b0110}},	//   _hezk, _zary, رتبة_, tsuc,
   {{0x765c04fb,0x661501d7,0x7bcdb05f,0x6d4a0371}},	//   _yary, _kezk, _nyau, _apfa,
   {{0x6f1b02c9,0xf1a71c89,0x82d8002d,0x228b03d0}},	//   rsuc, _ирен, _адус_, _møkk_,
   {{0x273d0019,0xd0110037,0x6f1b033b,0x66152d7d}},	//   hìn_, _هلا_, ssuc, _mezk,
   {{0x6281b060,0xab2a0c06,0xe8170066,0x7bc105f9}},	//   _holo, нома_, तरफा_, ğlun,
   {{0x6281b061,0xf1a70006,0x4fa402ce,0x6d586ee9}},	//   _kolo, _केतन, _київ, _esva,
   {{0x62810a4e,0x6615b062,0xc332016b,0x00000000}},	//   _jolo, _nezk, זוך_, --,
   {{0x6281007a,0x291e570d,0x98b8a50e,0x98a30035}},	//   _molo, éta_, strč_, zują_,
   {{0x48c400c8,0x63bb0095,0x6281a98f,0x88e6052c}},	//   ্দ্র, _oxun, _lolo, ужбе,
   {{0x7c240082,0x765cb063,0x9998010b,0xeef6016b}},	// [cee0] _idir, _pary, terų_, ָמער_,
   {{0x6281b064,0xa3c70084,0xa6830227,0xa6ca6f4e}},	//   _nolo, _उड़_, блуд, روال_,
   {{0x765cb065,0x98a6002d,0x7cfe013a,0x661501ed}},	//   _vary, _бине, _tīre, _dezk,
   {{0xe3ba1ad4,0xb4c0007c,0xa8560798,0x765cb066}},	//   нбе_, ुते_, _стој, _wary,
   {{0x6281093d,0x3860b067,0x765cb068,0x6442b069}},	//   _bolo, mdir_, _tary, rfoi,
   {{0x628115b7,0x386055f6,0x7c24013a,0xc692006c}},	//   _colo, ldir_, _ldir, _اِس_,
   {{0x6281b06a,0x6f02b06b,0xddc3000d,0x98a30067}},	//   _dolo, _stoc, _manœ, sują_,
   {{0x3860b06c,0x9958024e,0x7c242973,0xf993011d}},	//   ndir_, káže_, _ndir, מרו_,
   {{0xa3cb07b5,0x62810012,0x3860b06d,0x442414c1}},	//   _रुप_, _folo, idir_, _idm_,
   {{0x62813c5d,0xa2e6425d,0x7c24b06e,0x00000000}},	//   _golo, _созд, _adir, --,
   {{0x38602f80,0x44240a4e,0x7bcd012f,0x64bc02c4}},	//   kdir_, _kdm_, _syau, pčid,
   {{0xd00f1d6c,0xfbcd0033,0x00000000,0x00000000}},	//   _فلم_, রেফত, --, --,
   {{0x3860b06f,0x69c001d6,0x7c24123f,0x628101ed}},	//   ddir_, şmel, _ddir, _yolo,
   {{0x8f9b0779,0x7c240ec4,0x2eb10bad,0x6d5867f6}},	//   _אידי, _edir, ीकृत, _tsva,
   {{0x6d58b070,0x99281b60,0x44249553,0x661502a7}},	//   _usva, люта_, _odm_, _rezk,
   {{0x694701cc,0x395a011e,0xb4c00355,0x00000000}},	//   jčeš, _dsps_, ुतो_, --,
   {{0x3a3a0176,0x2eee00a2,0x00000000,0x00000000}},	// [cef0] _fcpp_, _kiff_, --, --,
   {{0xd5bbac03,0x00000000,0x00000000,0x00000000}},	//   нсе_, --, --, --,
   {{0x62816948,0x386000a8,0x442471d3,0xf4872c93}},	//   _rolo, bdir_, _bdm_, лудн,
   {{0x6281b071,0xe4cb3181,0xa7fb548d,0x297a0070}},	//   _solo, ربان_, _bañe, _סטרא,
   {{0x6281b072,0x8625006c,0xa7fb0300,0x6615b073}},	//   _polo, _نکال, _cañe, _tezk,
   {{0xe8e00028,0x8afc02b5,0xd0190035,0x62810510}},	//   _đức_, עהוי, wań_, _qolo,
   {{0x6281b074,0xd17502ee,0x40953047,0x442408c8}},	//   _volo, рылы, ирит, _fdm_,
   {{0x708516b6,0x6281b075,0x5f750833,0x2eee00e5}},	//   ргиз, _wolo, لاخر, _aiff_,
   {{0xef1610b0,0x62817471,0x98b800ea,0x2eee0282}},	//   амы_, _tolo, ntrā_, _biff_,
   {{0x9998006c,0x386004d4,0x629801ae,0x672d01a0}},	//   zerű_, zdir_, chvo, iraj,
   {{0x672d024e,0x9d450009,0x6d5e0612,0x3860045e}},	//   hraj, шенд, _špar, ydir_,
   {{0x672d1577,0x7f59006d,0x68ef515c,0x9f5d0260}},	//   kraj, _tswq, _nicd, _dewò_,
   {{0x64490082,0x7ff4146d,0x5f7703c7,0x1dd10026}},	//   _mbei, _اسما, _حاضر, _हरकत,
   {{0xa3da0d1f,0x6f090181,0x8f9a00a5,0x672db076}},	//   डेट_, mpec, _ביני, draj,
   {{0x64bc0506,0x38600095,0x09e62264,0x99580187}},	//   nčic, tdir_, ровн, sáže_,
   {{0xf7720082,0x2eeeb077,0x7c24053b,0x6d4101ff}},	//   ياء_, _ziff_, _udir, mtla,
   {{0x3860b078,0x672db079,0x6d41b07a,0xdd9100b5}},	// [cf00] rdir_, graj, ltla, _دوں_,
   {{0x4424022e,0xaa462d4d,0x6449b07b,0x3860b07c}},	//   _sdm_, _теол, _abei, sdir_,
   {{0x6d41b07d,0x2baa06bb,0x38605556,0x395a0602}},	//   ntla, _चेता, pdir_, _usps_,
   {{0x04462896,0x672d1b86,0x3860013b,0x6449009e}},	//   редн, braj, qdir_, _cbei,
   {{0x6d4100ab,0x68e4b07e,0x442400f6,0x3aef0069}},	//   htla, mmid, _vdm_, _mżpn_,
   {{0x6d41b07f,0xd36f004f,0x68e4b080,0xb50600fd}},	//   ktla, بهه_, lmid, _نظرو,
   {{0x5bd309b8,0x64930d6f,0xbbd3111a,0xddc80035}},	//   _सर्व, _için, _सर्क, zedł,
   {{0x8f461728,0x506627ac,0x6d4119f6,0x68e48100}},	//   аход, ртка, dtla, nmid,
   {{0xa0670431,0x6d410035,0x68e4009e,0xdce400cd}},	//   рања_, etla, imid, _crnč,
   {{0x68e4b081,0x26c701cc,0x6d41b082,0x998700a0}},	//   hmid, čnog_, ftla, _čiže_,
   {{0x6d413e84,0x2484b083,0x85f70070,0xddd80116}},	//   gtla, _komm_, יציע_, _bovš,
   {{0xa2da018d,0xdb040391,0x2aad022f,0x321c0187}},	//   _पीत्, _axiñ, džba_, lavy_,
   {{0x6d417745,0xdce401f2,0xa3da0099,0x68e412ba}},	//   atla, _grnč, डेच_, dmid,
   {{0x672d0160,0x68e400ab,0x24840051,0x321c148a}},	//   vraj, emid, _lomm_, navy_,
   {{0x2bd304aa,0xa8a73072,0x3eac049a,0x298854b8}},	//   _सरका, арак, midt_, асто_,
   {{0x672d05e2,0x14100c57,0x23660254,0x88940086}},	//   traj, ारोह_, kvoj_, оисх,
   {{0xaa8903c7,0x321c00ee,0x76b90009,0x68ef045e}},	// [cf10] _منظم_, kavy_, глар_, _vicd,
   {{0x672d0291,0x68e400be,0x2607b084,0x00000000}},	//   rraj, amid, рчаг, --,
   {{0x6f090097,0x98b800ea,0xbdf80033,0x2d9e02b1}},	//   zpec, strā_, _আজাদ_, nzte_,
   {{0x672db085,0x64bc1321,0xb4c100ab,0x2bde0355}},	//   praj, včic, ँवे_, नेका,
   {{0xe3b000ad,0x087602b5,0x291e011c,0x6f0932ca}},	//   وره_, _הערט_, štat_, xpec,
   {{0x6d41b086,0x78ad00d8,0x2fcf15ed,0x984f0225}},	//   ytla, liav, _rygg_, _işık_,
   {{0xb5e500c8,0xf595004f,0x2a61028b,0x6d4100a8}},	//   _প্রচ, _الأج, _mahb_, xtla,
   {{0x19b80122,0xf3f9002d,0xb8170026,0x64bc0c7f}},	//   יפור_, _faţa_, तरिम_, rčic,
   {{0x200db087,0x321c0187,0x63a40037,0xf1a70067}},	//   rbei_, bavy_, úint, _केरन,
   {{0x6f09005d,0x78adb088,0x6d4145c4,0x66d000c3}},	//   rpec, hiav, ttla, täki,
   {{0x7cfe00ec,0x2d910355,0x78adb089,0xb69b0160}},	//   _pīra, áze_, kiav, _ntâm,
   {{0x6d41b08a,0xc18c02b5,0x3b0a03e6,0x22990107}},	//   rtla, _שטאָ, лемо_, _dèke_,
   {{0x6d41b08b,0x64bcb08c,0x78ad1be5,0xe4560070}},	//   stla, nčia, diav, זירט_,
   {{0x64bc00d8,0x2ca9b08d,0xd37a016b,0x2bde00be}},	//   ičia, _emad_, ארשט, नेगा,
   {{0xfce624df,0x2366552b,0xf2d20d85,0xfaa30112}},	//   _локо, zvoj_, פעל_, чаро,
   {{0x60c90244,0x2aad0187,0x98a3b08e,0x78adb08f}},	//   noem, ržba_, писе, giav,
   {{0xac971b15,0x3f8db090,0xd70a002d,0x64bc01ba}},	// [cf20] _دنيا_, nyeu_, унзе_, jčia,
   {{0x68e4b091,0xe617272f,0x60c903bc,0x2484b092}},	//   smid, йду_, hoem, _somm_,
   {{0x3ce001e8,0x64bc010b,0x452a2dfa,0xb87b0098}},	//   _khiv_, ečia, ужен_, _dhíb,
   {{0x291e01c8,0x64b70026,0xb6060097,0x23660207}},	//   štas_, _अदृश, dráž, tvoj_,
   {{0x321c0187,0x60c9b093,0xcc3b0070,0x64930225}},	//   tavy_, doem, רענט, _içil,
   {{0x6d170066,0xd9fa5f2e,0x236601e9,0xa30b00b5}},	//   _दबंग_, ्डित_, rvoj_, ارنے_,
   {{0x321c1840,0x60c90453,0x81cb0033,0x2d8c4090}},	//   ravy_, foem, রেস_, xyde_,
   {{0x831a2499,0x2ed0319c,0x321c005f,0x63a40079}},	//   _مقرر_, हत्त, savy_, úins,
   {{0xdfd00514,0x08770070,0x38620160,0x93590200}},	//   بية_, מעקט_, _makr_, _врху_,
   {{0xa7fb0083,0x2d9e02c9,0xb87b0019,0x78adb094}},	//   _maña, tzte_, _khíc, ziav,
   {{0xa2c53100,0x3eac0c71,0x60c941d6,0x98c8046c}},	//   ाकर्, ridt_, boem, लवाए,
   {{0x3ce00189,0xb87b0037,0xd12f0312,0x2d8cb095}},	//   _chiv_, _mhíc, _سمه_, ryde_,
   {{0x661e005d,0xd90f00fd,0x78ad0553,0x2f181ad4}},	//   kapk, کیج_, viav, _толь_,
   {{0xdd941397,0xdb0a003e,0x64930448,0x00000000}},	//   _малы, ðnám, _açil, --,
   {{0x78adb096,0x661e0ac8,0x66d00086,0xb87b00e2}},	//   tiav, dapk, näku, _nhíc,
   {{0xa7fb0a95,0x2ca90118,0x64bc00c7,0xb71502fb}},	//   _baña, _umad_, yčia, ждащ,
   {{0x78adb097,0xa7fb548d,0x386200fe,0x291e261b}},	// [cf30] riav, _caña, _dakr_, átar_,
   {{0x661e028b,0xa7fb0831,0x6c3502fd,0x78ad1ad4}},	//   gapk, _daña, _افکا, siav,
   {{0x291e1942,0xb87bb098,0x78ad8704,0xa2d706fe}},	//   štar_, _chíc, piav, यतस्,
   {{0xb87b0079,0x00000000,0x00000000,0x00000000}},	//   _dhíc, --, --, --,
   {{0xa7fb043f,0x1dcf0299,0x083a02b5,0x98b8002d}},	//   _gaña, _सुनत, _דערל, stră_,
   {{0x661e0ce8,0x64bc6545,0x2be108b0,0x161d0035}},	//   capk, rčia, _नरना, _फ़िर_,
   {{0x91e26266,0x64bcb099,0xb4950274,0x00000000}},	//   моше, mčin, _дивљ, --,
   {{0x3f42008a,0xaf05737f,0x64bc15e2,0x2019b09a}},	//   fðu_, опил, lčin, úsi_,
   {{0xb4d50035,0x60c909a6,0x3f420093,0x81c700ea}},	//   हती_, roem, gðu_, dzēš,
   {{0x64bc4475,0x60c907ee,0x92b7097f,0xa2cb00af}},	//   nčin, soem, _احرا, _субз_,
   {{0xa2c600c0,0x3ce0006d,0x226400b8,0x66d001ff}},	//   िवर्, _phiv_, řská_, mäkt,
   {{0x25e10299,0xceb80067,0x1bea001f,0x80b50033}},	//   _करनी_, anę_, идни_, ুষঙ্,
   {{0xe79c0225,0x00000000,0x00000000,0x00000000}},	//   düğü, --, --, --,
   {{0x201fb09b,0x64bcb09c,0xa7fb0042,0x00000000}},	//   laui_, jčin, _raña, --,
   {{0x81cb0b52,0xada50994,0x443f0254,0x3ce00221}},	//   রের_, _файл, _ocu_, _thiv_,
   {{0x443f01e8,0xa7fb00de,0x661e00d7,0x7d050160}},	//   _ncu_, _paña, wapk, _cîrţ,
   {{0xe61a81e6,0xe73a3634,0x7e63b09d,0x661e0f1a}},	// [cf40] ида_, рез_, _kanp, tapk,
   {{0x443f0082,0x6f040098,0xb87b00cc,0xd62a0421}},	//   _acu_, _éice, _phíc, роже_,
   {{0x661e005d,0x1fc622a7,0x201f0a4e,0x00000000}},	//   rapk, _लड्ड, kaui_, --,
   {{0xe73a00c3,0x7e6306a2,0x236d02c4,0x443f0160}},	//   _кем_, _lanp, _brej_, _ccu_,
   {{0x66e600d8,0x6609027d,0xe8170026,0xd7de018d}},	//   _мома, _şeke, तररा_, _मरिच,
   {{0xb87b0028,0x7e630359,0xe5a60786,0x67240124}},	//   _thíc, _nanp, _диги, msij,
   {{0xca7b0319,0xd1300037,0x052700af,0x00000000}},	//   ינסט, رمة_, _морк_, --,
   {{0x661c75b8,0x7e630244,0x66090009,0x228b0185}},	//   _herk, _aanp, _đeki, _søkt_,
   {{0x661cb09e,0x6724b09f,0x81cb0083,0x66d00086}},	//   _kerk, nsij, রেল_, säku,
   {{0x3f42008a,0x661cb0a0,0x63a2b0a1,0x69de0036}},	//   rðu_, _jerk, mzon, _ozpe,
   {{0x63a2b0a2,0x64bc00d8,0x81e40083,0x7e631316}},	//   lzon, nčio, ভুজ_, _danp,
   {{0x62880d1f,0x06de0083,0x6724b0a3,0xceb817a9}},	//   _hodo, _ভূমি, ksij, snę_,
   {{0x63a2b0a4,0x69de01d7,0x6724011c,0x64404e8b}},	//   nzon, _azpe, jsij, _mcmi,
   {{0x656e009e,0x661cb0a5,0x67240207,0x00000000}},	//   _orbh, _nerk, dsij, --,
   {{0x6288b0a6,0x64bc18a8,0x2d8301b4,0x48ab1102}},	//   _modo, včin, øjet_, атам_,
   {{0x63a20051,0x7e63b0a7,0x6288b0a8,0x00000000}},	//   kzon, _zanp, _lodo, --,
   {{0x661c0464,0x64bc391c,0x63a20a75,0x656e006b}},	// [cf50] _berk, tčin, jzon, _arbh,
   {{0x6288b0a9,0x63a2004e,0x7bdf28c1,0x661cb0aa}},	//   _nodo, dzon, _izqu, _cerk,
   {{0x64bc19be,0x661cb0ab,0x00000000,0x00000000}},	//   rčin, _derk, --, --,
   {{0x236db0ac,0xb4d54069,0x18350070,0x629a11f0}},	//   _prej_, हते_, _צאָל_, _alto,
   {{0x6288b0ad,0x64bcb0ae,0x66d001ff,0x9cd800a5}},	//   _bodo, mčil, täkt, קודה_,
   {{0x661cb0af,0xa7fb01ed,0x64bc00d5,0x00000000}},	//   _gerk, _kaño, lčil, --,
   {{0x6288b0b0,0x7e630c1f,0x443fb0b1,0x45d40402}},	//   _dodo, _ranp, _tcu_, _жорс,
   {{0x64bc0e6a,0x63a2b0b2,0xa7fb02d7,0x661cb0b3}},	//   nčil, bzon, _maño, _zerk,
   {{0x63a2006a,0x7e63b0b4,0x6288b0b5,0x661c0471}},	//   czon, _panp, _fodo, _yerk,
   {{0x6459b0b6,0x479c00a5,0x35d007b5,0x661c01ed}},	//   lewi, ייחס, _तुड़, _xerk,
   {{0x7e63b0b7,0xdc6a021d,0xfbc9011d,0xf8bd07df}},	//   _vanp, банд_, _עת_, ्काय,
   {{0x62830496,0x645900e9,0x7e6332c5,0x443d0371}},	//   ljno, newi, _wanp, ngw_,
   {{0x7e632090,0x6288b0b8,0xee2e40e0,0xaff60037}},	//   _tanp, _yodo, _пн_, _عفوا_,
   {{0xa7fb4e5c,0x64bc010b,0x9e6401e0,0x00000000}},	//   _baño, yčio, _овід, --,
   {{0xdd8e6202,0x63a268d5,0xa7fb42ae,0xe7f82b6d}},	//   _موو_, zzon, _caño, ंखला_,
   {{0xa7fb0831,0x6e21301c,0x661cb0b9,0x26d10051}},	//   _daño, lalb, _serk, _akzo_,
   {{0x98a30dbf,0x6459b0ba,0x00000000,0x00000000}},	// [cf60] хите, dewi, --, --,
   {{0x6724b0bb,0x6e211ae5,0xddc1006c,0x66d00086}},	//   rsij, nalb, lelő, väks,
   {{0x6288b0bc,0x6724b0bd,0xa7fb043f,0xf9fb00a5}},	//   _rodo, ssij, _gaño, _להימ,
   {{0x661c3953,0x64598640,0x6288b0be,0x63a2b0bf}},	//   _werk, gewi, _sodo, tzon,
   {{0x661c1201,0xd7f2004f,0x6e2100d8,0x67240484}},	//   _terk, _سكس_, kalb, qsij,
   {{0x63a2b0c0,0xf6550421,0x00000000,0x00000000}},	//   rzon, _отсю, --, --,
   {{0x63a240a2,0x81d400c8,0x66d003ad,0xa97a02b5}},	//   szon, সেন_, säks, מאַכ,
   {{0x25e1004e,0x6459b0c1,0x63a25ad3,0x55bb00a5}},	//   _करती_, cewi, pzon, _המלו,
   {{0x62882140,0x201d3cb7,0x14c9057c,0xa87b0070}},	//   _todo, _dewi_, िकरण, מאקר,
   {{0x6e2101c8,0x81cb0033,0x00000000,0x00000000}},	//   galb, রেই_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1970122,0x2d82011c,0xddc100b5,0xa7fb01ef}},	//   _מכבי_, ćke_, gelő, _raño,
   {{0x6e21b0c2,0xa0c90037,0x2d8308c8,0xb87b026e}},	//   balb, _بذلك_, øjer_, _bhín,
   {{0xb87b00e8,0x64590035,0x9d1800af,0xa7fb0453}},	//   _chín, zewi, _докт_, _paño,
   {{0x321e05a6,0xb89500b5,0x58d50279,0xa9c40104}},	//   _mety_, وارڈ, довт, естк,
   {{0x64bcb0c3,0x50cc0099,0x321eb0c4,0x20cc07df}},	//   učil, ाविष, _lety_, ाविध,
   {{0xb9040e1d,0x7c2d4450,0x00000000,0x00000000}},	// [cf70] _पी_, _idar, --, --,
   {{0x6595002d,0xb4d51cce,0x00000000,0x00000000}},	//   мазу, हत्_, --, --,
   {{0x6d4814d4,0x64bc008b,0x660502b1,0x6459b0c5}},	//   ntda, mčij, rchk, tewi,
   {{0x6605b0c6,0xc4350ef2,0xfbe10761,0x6d480051}},	//   schk, بکست, _नराम, itda,
   {{0x3869b06c,0x8cb600dc,0x201d00e5,0x321eb0c7}},	//   mdar_, _उदघो, _rewi_, _bety_,
   {{0x3869b0c8,0x7af7003c,0x6283006d,0x66d0013c}},	//   ldar_, _jixt, ujno, säkr,
   {{0x776d01dd,0x7af7a956,0x6e21b0c9,0xbebd013a}},	//   lvax, _mixt, valb, drūp,
   {{0x3869b0ca,0x7c2db0cb,0x1dd00354,0x7af7b0cc}},	//   ndar_, _ndar, _हड़त, _lixt,
   {{0x64bc044d,0x53340800,0x38690044,0xe454005f}},	//   kčij, _петт, idar_, _якты,
   {{0x7c2db0cd,0xdd1b0187,0x386900f1,0x7af7003c}},	//   _adar, _váže, hdar_, _nixt,
   {{0x6d48008c,0x442d086d,0x6da50948,0x6e216246}},	//   gtda, _kde_, фина, ralb,
   {{0x442d01c0,0x6ac60026,0xb87b0037,0x7c3a010b}},	//   _jde_, लक्र, _shín, ėtro,
   {{0x7c2d0297,0x3869b0ce,0xfeb804cd,0x7af701ed}},	//   _ddar, ddar_, _کانت_, _bixt,
   {{0xb87b004f,0x7c2db0cf,0xddc100b5,0x64bc0207}},	//   _bhío, _edar, selő, gčij,
   {{0x442db0d0,0xd94318cd,0xa3d497c4,0x6d480051}},	//   _ode_, кери, _सुन_, ctda,
   {{0xb87b004f,0x442db0d1,0x7f490443,0x38692bb9}},	//   _dhío, _nde_, oteq, gdar_,
   {{0x4b2600d8,0x7f49b0d2,0xb87b00e2,0x7af7b0d3}},	// [cf80] _ўмов, nteq, _thín, _fixt,
   {{0x7c2d3dfa,0x4422063b,0xb87b0037,0x64b81ede}},	//   _zdar, _žk_, _fhío, ेक्श,
   {{0x321e034d,0x69c00225,0x00000000,0x00000000}},	//   _rety_, ğmes, --, --,
   {{0x69c001d6,0x321e4a9c,0x00000000,0x00000000}},	//   şmes, _sety_, --, --,
   {{0x442db0d4,0xb87b0079,0x82a60949,0xb3470069}},	//   _dde_, _mhíl, мадж, _nuħħ,
   {{0x442d0c1f,0x6d48013b,0x7d07005f,0x00000000}},	//   _ede_, ytda, _kūrę, --,
   {{0x6d48b0d5,0x64bcb0d6,0x00000000,0x00000000}},	//   xtda, nčik, --, --,
   {{0x442d0202,0xb89b016b,0xd0100037,0x00000000}},	//   _gde_, ַביש, دلة_, --,
   {{0x321e00ac,0xc24600ed,0x2ef41172,0x7d0d07e7}},	//   _tety_, _онак, нзир, _časa,
   {{0x442d000c,0x24860a78,0xb347009f,0x24660409}},	//   _zde_, ljom_, _duħħ, _dūmų_,
   {{0x2d98016f,0x3869b0d7,0x442d08c8,0x600a1eb9}},	//   áre_, ydar_, _yde_, _днем_,
   {{0x2486b0d8,0xa2c60963,0xb3470024,0x15e3198f}},	//   njom_, िवक्, _fuħħ, केटर_,
   {{0xfc3f004f,0x7af700ee,0xb87b0079,0x38690044}},	//   rgí_, _pixt, _shío, vdar_,
   {{0x6298095a,0xb87b0079,0xda7b1645,0x00000000}},	//   nkvo, _phío, цям_, --,
   {{0xa2b10b4a,0x64bc08b7,0x59f8002d,0x3869013b}},	//   _अगस्, rčij, деря_, tdar_,
   {{0x7c2db0d9,0xdd8e0332,0x386900f1,0x81cb0033}},	//   _udar, _موڈ_, udar_, রেক_,
   {{0x3869b0da,0x7af70484,0x60c2002f,0x24860207}},	// [cf90] rdar_, _tixt, _mjom, djom_,
   {{0x76d50082,0x69c501a9,0xb87b004f,0x442db0db}},	//   رياض, _txhe, _thío, _sde_,
   {{0x7cfe00ec,0x00000000,0x00000000,0x00000000}},	//   _bīri, --, --, --,
   {{0x2aad012e,0xb69b00af,0x64c905a6,0x62982069}},	//   džbi_, _atât, िकेश, ekvo,
   {{0x442d4212,0xf1b8009f,0x00000000,0x00000000}},	//   _vde_, _reġa_, --, --,
   {{0x68edb0dc,0x2901b0dd,0x91e58d30,0x21690d13}},	//   lmad, _kuha_, ноле, зики_,
   {{0x241900d8,0x2901b0de,0x68edb0df,0x00000000}},	//   _новы_, _juha_, omad, --,
   {{0x442d054e,0x68edb0e0,0x290194a0,0x2ec7022e}},	//   _ude_, nmad, _muha_, रक्त,
   {{0x69d60026,0x68ed0f84,0x29010c86,0xda1f00a1}},	//   _मुनी, imad, _luha_, भरात_,
   {{0x68edb0e1,0x0d85031a,0x6298033b,0x249f009e}},	//   hmad, елон, ckvo, _hlum_,
   {{0x68edb0e2,0xa6e20093,0xf652016b,0x00000000}},	//   kmad, íðin, נצט_, --,
   {{0x859a0397,0x802700d1,0x6736b0e3,0x1eea00b5}},	//   פשרו, _آرام, yryj, _ہونی_,
   {{0x68ed00fe,0x1dcf55f5,0xf3f90160,0x00000000}},	//   dmad, _सुरत, _baţi_, --,
   {{0x60dbad5e,0x249fb0e4,0x2901b0e5,0x68ed00b9}},	//   llum, _llum_, _buha_, emad,
   {{0xf3f900af,0x00000000,0x00000000,0x00000000}},	//   _daţi_, --, --, --,
   {{0x2901b0e6,0x68ed3ee2,0x248d1516,0xd5b700cc}},	//   _duha_, gmad, _noem_, _ứng_,
   {{0x7c26b0e7,0x60db0763,0x9876013a,0x00000000}},	// [cfa0] makr, ilum, _aļģu_, --,
   {{0xe5a601b8,0x249f596e,0x7c26b0e8,0x68ed8d68}},	//   низи, _alum_, lakr, amad,
   {{0x60db2a37,0x249f0408,0x290101d5,0x7d0b00af}},	//   klum, _blum_, _guha_, _însă,
   {{0x64a31954,0x248d0036,0x24071a1c,0x661b0207}},	//   лаха, _coem_, енци_, _đuke,
   {{0x7cfe0029,0x248db0e9,0x22450069,0xe3b23b94}},	//   _vīri, _doem_, _bclk_, درا_,
   {{0x7d0d02f6,0x7c260553,0x00000000,0x00000000}},	//   _časn, hakr, --, --,
   {{0x55e30674,0x2ca0007c,0x64a6742b,0x1dcf0035}},	//   _борб, _olid_, _зава, _सुलत,
   {{0x60dbb0ea,0xa3cb0084,0x6298b0eb,0x7c26b0ec}},	//   glum, _रुक_, skvo, jakr,
   {{0x59d2255b,0xb4cc2203,0xb4be045c,0x64a30ddc}},	//   _दुसर, रकी_, ीकी_, _сата,
   {{0x44267c80,0xddd800b8,0x2ef8008a,0xe35700a5}},	//   lao_, _zavř, örf_, _אשמח_,
   {{0xb63702b5,0xa3d400be,0x01365b16,0x2ca00a8c}},	//   ערטס_, _सुत_, _سعاد, _blid_,
   {{0x4426b0ed,0x2fc60d4b,0x64427db6,0x7b67107b}},	//   nao_, _txog_, ngoi, нтге,
   {{0x2901b0ee,0xc3140033,0x78a401e9,0x7ac727de}},	//   _suha_, _সিডি_, dhiv, есве,
   {{0x4426b0ef,0x81cb0033,0x59d2046c,0x2901b0f0}},	//   hao_, রেও_, _दुहर, _puha_,
   {{0x44267953,0x2ca00a8a,0x68edb0f1,0x7cfe00c7}},	//   kao_, _flid_, tmad, _būre,
   {{0x442601cc,0x26c73ce5,0x7c264946,0x68edb0f2}},	//   jao_, čnom_, cakr, umad,
   {{0x4426b0d8,0x3d060026,0x248d4631,0x36d500af}},	// [cfb0] dao_, _संडे_, _roem_, воар,
   {{0x2901012f,0xa3d40324,0xe8e00023,0x81cb0033}},	//   _tuha_, _सुध_, _đục_, রেট_,
   {{0x3ce9006f,0xceb30100,0x4426002f,0x68edb0f3}},	//   _khav_, ניע_, fao_, pmad,
   {{0x44260537,0x78a4b0f4,0xf48415df,0x00000000}},	//   gao_, chiv, лучн, --,
   {{0xa3cb3123,0x69e300cd,0x6f028919,0x290e0055}},	//   _रुख_, šteć, _nuoc, _çfar_,
   {{0xc61b00c8,0x6d58b0f5,0x1db20963,0x00000000}},	//   _ঢাকা_, _opva, ुपात, --,
   {{0x4426b0f6,0x7d0d0bcc,0xa15603fa,0x60dbb0f7}},	//   bao_, _časo, вају_, tlum,
   {{0x4426b0f8,0x26d301dd,0x249f1ea7,0x6f02099e}},	//   cao_, loxo_, _ulum_, _buoc,
   {{0x70820aeb,0xc62400c8,0x60db0a7e,0x6f02b0f9}},	//   ргыз, _পাতা_, rlum, _cuoc,
   {{0x82370ca8,0xf1a71362,0x2ca079dc,0x60dbb0fa}},	//   _سرطا, _прен, _slid_, slum,
   {{0xdca60338,0x60db2c7c,0x4df4093c,0x7c26b0fb}},	//   вани, plum, ляют, takr,
   {{0x7d04184e,0x3ce90189,0x6f0202fb,0x660901d6}},	//   _čist, _chav_, _fuoc, _şekl,
   {{0x26c73b12,0x7c26b0fc,0xab63010b,0x00000000}},	//   čnoj_, rakr, авял, --,
   {{0xd0260b52,0x442626f1,0x7c26b0fd,0xa7fb01ed}},	//   _যায়_, zao_, sakr, _gañi,
   {{0x44260468,0xada5021d,0x26d30a54,0x7cfe00ec}},	//   yao_, _шакл, doxo_, _pūre,
   {{0x2aad022f,0x6e2374f9,0x4426b0fe,0x7cfe02d4}},	//   džbu_, _henb, xao_, _cīru,
   {{0x44260537,0x7d03b0ff,0x6e230c1f,0x26d301ef}},	// [cfc0] vao_, _huns, _kenb, foxo_,
   {{0x78a4b100,0x442608c7,0xb6cb00b5,0xb69b0395}},	//   shiv, wao_, والے_, _stâr,
   {{0x4426b101,0x7d03b102,0xa2b707df,0x7cfe02d4}},	//   tao_, _juns, ्चन्, _tūre,
   {{0x7d030a74,0xe3ba0fb4,0xb4be0035,0x7d0d02c4}},	//   _muns, мбе_, ीके_, _časl,
   {{0x7c24b103,0x44260537,0x93431283,0x7d03b104}},	//   _meir, rao_, инце, _luns,
   {{0x44260537,0xe8e00028,0x386001a6,0x6f020036}},	//   sao_, _độc_, leir_, _ruoc,
   {{0x24f60409,0x44260a78,0x6f02093d,0x7d03b105}},	//   _ачар, pao_, _suoc, _nuns,
   {{0xe0cf00ad,0xf9930397,0xf8e20066,0x70cc007c}},	//   يزي_, שרה_, पतिय, ावेल,
   {{0xf8b30052,0x4424b106,0x6f02b107,0x7d03009e}},	//   ישה_, _iem_, _quoc, _auns,
   {{0x15e60fd1,0x7d03b108,0x33d500d8,0x3860739a}},	//   _करार_, _buns, _сіст, heir_,
   {{0x7c2400e5,0x6e2306a2,0x4424b109,0x06970122}},	//   _beir, _denb, _kem_, דדים_,
   {{0x80e000c8,0x6e2312a9,0x4424b10a,0x7c24b10b}},	//   _পূর্, _eenb, _jem_, _ceir,
   {{0x7c24a708,0x4424b10c,0xd0070370,0x395ab10d}},	//   _deir, _mem_, _рече_, _apps_,
   {{0x4424b10e,0x6e23b10f,0x0f57011d,0x5eff00b4}},	//   _lem_, _genb, _סיום_, रदर्_,
   {{0x7c24b110,0x81d400c8,0x3ce9006d,0x6d58325f}},	//   _feir, সের_, _thav_, _upva,
   {{0x442407a8,0x6e230291,0xb4cc0311,0xb4be0311}},	//   _nem_, _zenb, रको_, ीको_,
   {{0xf773036b,0x64bc00d8,0x3d06018d,0xa775005f}},	// [cfd0] جاز_, nčiu, _सूते_, ылач,
   {{0xed4d07a8,0xd6280202,0xceb8004e,0x64bc00d8}},	//   _بھی_, кође_, nię_, ičiu,
   {{0x442400c9,0xa9c44bc6,0x950500b5,0xa9790070}},	//   _bem_, _всяк, اہرے_, _װאָכ,
   {{0x4424b111,0x6ba8027d,0x2aad0097,0x7c24002a}},	//   _cem_, _örgü, ržbu_, _xeir,
   {{0x4424b112,0xe7840423,0xd7f8002d,0x4734010b}},	//   _dem_, _куро, _аур_, _княс,
   {{0xdce40355,0x672d023c,0x98b80228,0x00000000}},	//   _brně, msaj, murā_, --,
   {{0x2bda0567,0x672d01ff,0xddc30160,0x6e230044}},	//   _युना, lsaj, _manţ, _renb,
   {{0x6e23166e,0x4424b113,0x657a2ac4,0x7d0300c3}},	//   _senb, _gem_, _átha, _runs,
   {{0x672d0b52,0x7c240138,0x68fd1516,0x81d40033}},	//   nsaj, _reir, _misd, সেল_,
   {{0x7c24b114,0x44240077,0x68fd2b0b,0x76450f5d}},	//   _seir, _zem_, _lisd, nghy,
   {{0xd00e0d4f,0x4424b115,0xb1157920,0x7c24b116}},	//   غلی_, _yem_, _смеш, _peir,
   {{0x4424098b,0x672db117,0x6e230345,0x00000000}},	//   _xem_, ksaj, _wenb, --,
   {{0x7d0301ae,0xef0e01f1,0xceb80035,0x64bc0b67}},	//   _wuns, _ым_, bię_, mčit,
   {{0x68fd01da,0xa96a1f39,0xd9460ece,0xdc1400a8}},	//   _aisd, нига_, леги, rğız,
   {{0x7c24913d,0x68fdb118,0x38604f7d,0x7e6132c5}},	//   _teir, _bisd, teir_, melp,
   {{0x6d419e82,0x1c462f26,0x1867015a,0x7764035f}},	//   mula, _сним, ласи_, twix,
   {{0xe7371578,0xe7c400c8,0x68fdb119,0xeb9a3537}},	// [cfe0] лет_, ্ধ্য, _disd, _чип_,
   {{0x4424b11a,0x64491417,0xda661d36,0x68fd0284}},	//   _sem_, _acei, _свои, _eisd,
   {{0x6d41b11b,0x4424006f,0x6723011c,0x64bc0207}},	//   nula, _pem_, ćnja, kčit,
   {{0x29187b0e,0x7e61b11c,0x672d003c,0x7cfe1772}},	//   mpra_, help, bsaj, _jūra,
   {{0x6d41b11d,0x4424b11e,0x7e61b11f,0xa7fb7b43}},	//   hula, _vem_, kelp, _bañu,
   {{0x6d41b120,0x6ffb0029,0x93cb00b5,0x4424b121}},	//   kula, _mācī, رانہ_, _wem_,
   {{0x4424b122,0xa3d40992,0x6d41b123,0x249d006d}},	//   _tem_, _सुर_, jula, bkwm_,
   {{0x6449004f,0x7afe62a8,0xa4f804e8,0xceb80035}},	//   _gcei, _lipt, _شکار_, wię_,
   {{0x69d60084,0x6e28104e,0x29180055,0x7e6156ec}},	//   _मुसी, tadb, hpra_, felp,
   {{0x05d90302,0x6e98150d,0x7e61b124,0xe3b70b00}},	//   _बुडब, твор_, gelp, _сбу_,
   {{0xac19b125,0x6e28b126,0xceb80035,0x64bc010b}},	//   кону_, radb, rię_, sčiu,
   {{0x6e2800ac,0xbd8700d1,0x459b0070,0x61e502b1}},	//   sadb, چنین_, גסטע, ühle,
   {{0x7e6119ea,0x68fd6dcb,0xceb80035,0x7cfe013a}},	//   belp, _risd, pię_, _dūra,
   {{0x7afe0452,0x6d4144a7,0x68fd0036,0xb3d10033}},	//   _cipt, bula, _sisd, ়েকজ,
   {{0x1958061c,0x35d9007c,0x69deb127,0xc27b0070}},	//   лары_, _बुढ़, _cype, ערלי,
   {{0x672d0282,0x8afb00a8,0x69de0044,0x00000000}},	//   tsaj, fiəç, _dype, --,
   {{0x68fdb128,0x00000000,0x00000000,0x00000000}},	// [cff0] _visd, --, --, --,
   {{0x6449004f,0x672db129,0xba55052c,0x00000000}},	//   _scei, rsaj, _твој, --,
   {{0x68fd022a,0x672db12a,0xa7fb01ef,0x7d0d00f4}},	//   _tisd, ssaj, _rañu, _čask,
   {{0xc8675b1f,0x48670133,0xb4c10006,0xddc3008b}},	//   _стои, _съоб, ुवे_, _janš,
   {{0x6d41b12b,0xa7fb00de,0x64bc0116,0xddc3068f}},	//   zula, _pañu, včit, _manš,
   {{0x6d410644,0x823718dd,0x7bdf09ba,0xddc306fe}},	//   yula, ارشا, _myqu, _lanš,
   {{0x65940144,0x21a50185,0x00000000,0x00000000}},	//   _лару, рийм, --, --,
   {{0x6d41b12c,0x27e6004e,0x64bc0620,0x644901ef}},	//   vula, żone_, učit, _ucei,
   {{0x6d412536,0x2d980c61,0x64bc0252,0xfc3f0079}},	//   wula, øren_, rčit, thín_,
   {{0xcdf50086,0x6ea700fd,0x00000000,0x00000000}},	//   ичны, اندہ_, --, --,
   {{0x6281b12d,0x7afe0088,0x64bc0207,0x611100ec}},	//   _inlo, _ript, pčit, _bāle,
   {{0x6d41b12e,0xeb9a609f,0x7cff005f,0x7afe0207}},	//   rula, вим_, _pūra, _sipt,
   {{0x6d41b12f,0xe0d00a72,0xddc302a7,0xd00e6f4e}},	//   sula, _عزم_, _danš, _غلو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfce60af5,0x7bcd1dfd,0x610300b5,0x48b61172}},	//   _коко, _exau, _főle, ащат,
   {{0xb4c100ab,0x69de00ac,0x05d900b8,0x291801f7}},	//   ुवो_, _vype, _बुधब, rpra_,

   {{0x6281b130,0x7afeb131,0x98a302f3,0xd7070043}},	// [d000] _onlo, _tipt, ците, инте_,
   {{0x69deb132,0x611100ea,0xe6179c2e,0xddc3023a}},	//   _type, _zāle, иду_, _zanš,
   {{0x05663a11,0x98b800af,0x05d900be,0x00000000}},	//   рвен, gură_, _बुदब, --,
   {{0xed5602b5,0x6a7c0523,0x261602b4,0x00000000}},	//   יבער_, _fåfä, _प्री_, --,
   {{0x78a300af,0x3358002d,0x00000000,0x00000000}},	//   _înva, уалэ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5186021d,0xe2970370,0xc44800d1,0x121900d8}},	//   рула, рај_, _میان_, уючы_,
   {{0xc05a0185,0x38720c7d,0x62812deb,0xea000019}},	//   тік_, ndyr_, _enlo, _giấu_,
   {{0x66090723,0xdb240118,0x00000000,0x00000000}},	//   _şeki, _èsèn, --, --,
   {{0xddc30009,0x628101da,0x00000000,0x00000000}},	//   _sanš, _gnlo, --, --,
   {{0xa0a603ad,0x69d600a1,0x38720d51,0x00000000}},	//   _кажд, _मुली, kdyr_, --,
   {{0xd00f1d05,0x1c390409,0x00000000,0x00000000}},	//   _قلم_, ызмы_, --, --,
   {{0xdfd200f8,0x7c36016e,0x00000000,0x00000000}},	//   _بيش_, _ddyr, --, --,
   {{0x635a00ec,0x799c001e,0x8f9b011d,0x290700e0}},	//   mānā, fyrw, _בידי, _énak_,
   {{0x610300fd,0x00000000,0x00000000,0x00000000}},	//   _tőle, --, --, --,
   {{0x7bcd01a9,0xab6800ec,0x00000000,0x00000000}},	//   _txau, _baļļ, --, --,
   {{0x28f803ad,0x7d0d08b7,0x00000000,0x00000000}},	// [d010] реть_, _časi, --, --,
   {{0x98b80043,0xd0b200a8,0xc7c400d4,0x6b9d00e9}},	//   tură_, rşən, істи, mysg,
   {{0xa2b7175f,0x7cff00d8,0xb87b0079,0x00000000}},	//   ्चस्, _jūro, _bhít, --,
   {{0xe43c0355,0xb87b0312,0x00000000,0x00000000}},	//   bříč, _chít, --, --,
   {{0xd7fb0836,0xb87b0037,0x98b8002d,0x6b9d00e9}},	//   _јун_, _dhít, sură_, nysg,
   {{0xd51701df,0x00000000,0x00000000,0x00000000}},	//   _نظرب, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c7024e,0xe4a70798,0x7ea4009e,0x00000000}},	//   čnou_, _трго, _ròpa, --,
   {{0xa9e401c0,0x00000000,0x00000000,0x00000000}},	//   _गर्छ_, --, --, --,
   {{0x6281b133,0x26e50380,0x6b9d001e,0x00000000}},	//   _unlo, _कठोर_, dysg, --,
   {{0x3872099e,0xdce4013a,0x00000000,0x00000000}},	//   ydyr_, _asnā, --, --,
   {{0x6b9d001e,0x50f50200,0x31ba024b,0x00000000}},	//   fysg, _узет, _גזענ, --,
   {{0x61e1b134,0x6abc0093,0xbf670e3a,0x201fa0b5}},	//   _hyll, tirf, _خداو, mbui_,
   {{0x61e1b135,0x6f1b0023,0x236d0069,0x00000000}},	//   _kyll, mpuc, _msej_, --,
   {{0x61e101b4,0x395e0443,0x09e6496c,0x499900d4}},	//   _jyll, ïts_, совн, аття_,
   {{0xa9280237,0x61e1b136,0x4806010b,0x09c70033}},	//   _nižš, _myll, спав, _এরশা,
   {{0x38720a8c,0x57eab137,0xa2630168,0x2905003e}},	// [d020] rdyr_, удам_, _krôč, ílar_,
   {{0x645b0afc,0x00000000,0x00000000,0x00000000}},	//   _abui, --, --, --,
   {{0xd707002d,0x61e10282,0x00000000,0x00000000}},	//   инӂе_, _nyll, --, --,
   {{0x04468b32,0x645b0211,0xb87b0098,0x00000000}},	//   седн, _cbui, _dhís, --,
   {{0xe29ab138,0x61e10138,0x645b0211,0x68e4b139}},	//   лад_, _ayll, _dbui, mlid,
   {{0x2902b13a,0x7d1a0097,0x61e15d4b,0xb87b0098}},	//   _hika_, ypts, _byll, _fhís,
   {{0x2902b13b,0x61e1001e,0xa6c70e3a,0x68e400be}},	//   _kika_, _cyll, _اوّل_, olid,
   {{0x290249c2,0x03a60210,0x50668cda,0x26daa98f}},	//   _jika_, _либо, стка, lopo_,
   {{0x68e4b13c,0x7e2a2327,0x43750f88,0xa0670200}},	//   ilid, ліна_, _муфт, сања_,
   {{0x61e15854,0x2902b13d,0x69c0027d,0x00000000}},	//   _fyll, _lika_, şmey, --,
   {{0xa2b70ed1,0x61e1b13e,0x68e4b13f,0xe0d61eb9}},	//   ्चर्, _gyll, klid, _людь,
   {{0xb5fb02b5,0x00000000,0x00000000,0x00000000}},	//   טליכ, --, --, --,
   {{0x26da870f,0xdd39002d,0x5f941159,0x9e342753}},	//   kopo_, tăţe, _филт, _делч,
   {{0x290203ad,0x0db90332,0x7cff02d4,0xcef600ed}},	//   _aika_, ائیں_, _tūro, _учењ,
   {{0x2902114f,0x6111013a,0xc98417d0,0x4c950c5a}},	//   _bika_, _kāla, пути, _микс,
   {{0x25ef0e04,0x3ebeb140,0x2bda0632,0x6e2ab141}},	//   _अरबी_, litt_, _युवा, _hefb,
   {{0x2d9eb142,0x7cff0029,0x41df0355,0x2902b143}},	// [d030] lyte_, _jūrm, _पुनस, _dika_,
   {{0x68e4b144,0x2ca928f9,0x3ebeb145,0x7d0a02b1}},	//   alid, _hlad_, nitt_, _kufs,
   {{0xb87b0037,0x2902b146,0x68e4b147,0x78a30139}},	//   _dhír, _fika_, blid, _învo,
   {{0x3ebeb148,0x2902b149,0x27e60035,0x200600e2}},	//   hitt_, _gika_, żona_, _ngoi_,
   {{0x2ca90bc6,0x6eef01b4,0xb87b0037,0x78bf0055}},	//   _mlad_, løbe, _fhír, miqv,
   {{0x78ad17ad,0x26dab14a,0x61e1b14b,0x236d08b7}},	//   lhav, copo_, _pyll, _vsej_,
   {{0xd9f90755,0xa2d20082,0xa28200b5,0x6a9c0070}},	//   ंधित_, بيوت, ظیمو, רשונ,
   {{0x78ad0022,0x7f5900c9,0x60099df2,0x54370118}},	//   nhav, ајот_, шним_, _درسر,
   {{0xfa010b52,0x442fb14c,0x7d0a02c9,0x3ebeb14d}},	//   ্রিল_, mag_, _aufs, fitt_,
   {{0x61e1b14e,0x20060065,0x3ebe02ce,0x32050f00}},	//   _tyll, _egoi_, gitt_, _ugly_,
   {{0xed591fff,0x2ca902db,0xf1a70fc5,0x6f1b1394}},	//   шон_, _blad_, _уран, spuc,
   {{0x644b0ad6,0x442fb14f,0x2299a701,0x6f1bb150}},	//   nggi, nag_, _tèks_, ppuc,
   {{0xee2e6a4a,0x2902b151,0x7cd20029,0x26da0054}},	//   _он_, _rika_, vārd, yopo_,
   {{0x6da505c2,0xe8e001a5,0x60c9a921,0x29023f2c}},	//   _мила, _đốc_, lnem, _sika_,
   {{0x1ae34b02,0x2902b152,0x442f02b3,0x68e4b153}},	//   форм, _pika_, kag_, tlid,
   {{0x60c9b154,0x02b60518,0x78ad1736,0x6f03b155}},	//   nnem, _अग्न, ghav, _hinc,
   {{0x60c90248,0x2902b156,0x6f03b157,0x26da0b3d}},	// [d040] inem, _vika_, _kinc, topo_,
   {{0x68e41bc5,0x29020269,0x60c93879,0xc96652bc}},	//   slid, _wika_, hnem, _двой,
   {{0xa2d80567,0x29020080,0x78ad0a8a,0x7d04b158}},	//   यवस्, _tika_, bhav, _kiis,
   {{0x26da026f,0x60c9076e,0x5c370070,0x00000000}},	//   sopo_, jnem, ַרצן_, --,
   {{0xa3d40437,0x7d040553,0x26da942e,0x60db011c}},	//   _सुख_, _miis, popo_, doum,
   {{0x6f030332,0x644b02fb,0x7d046b4c,0x7c2f027a}},	//   _ninc, aggi, _liis, zacr,
   {{0x6e2a45df,0x4034a4ca,0x3ebeb159,0x81e20083}},	//   _refb, пейс, vitt_, নেন_,
   {{0x442fb15a,0x60c9b15b,0x7d041246,0x2240037a}},	//   cag_, gnem, _niis, şik_,
   {{0x7d0a053e,0x4911007c,0x6d4108f3,0x7bc00183}},	//   _sufs, _दूनो_, erla, úmul,
   {{0x6f03b15c,0xbdb40d6e,0x00000000,0x00000000}},	//   _cinc, збој, --, --,
   {{0x3ebeb15d,0x6f03b15e,0x78a4005b,0x867b0317}},	//   ritt_, _dinc, kkiv, בריו,
   {{0x7d0d0076,0x6b820029,0x60c927fc,0x6f030938}},	//   _čast, _šoga, cnem, _einc,
   {{0xfe6f0e3a,0x80a300e0,0x7c2f0831,0x2ca93df8}},	//   ردی_, _زمون, racr, _vlad_,
   {{0x60c0b15f,0x7c2f095e,0x2ca9001e,0x442fa4ef}},	//   limm, sacr, _wlad_, zag_,
   {{0x644b200b,0x442fb160,0x59db02e4,0x78adb161}},	//   yggi, yag_, _मुशर, thav,
   {{0x6d48b162,0xa3aa004e,0x60c04cdf,0xa3bf045c}},	//   muda, खना_, nimm, ुपम_,
   {{0x6d48b163,0x78ad0a8c,0x6f030103,0x442fb164}},	// [d050] luda, rhav, _yinc, vag_,
   {{0x442f8409,0x60c0b165,0x7c2d44b9,0x8aa7150e}},	//   wag_, himm, _hear, _фрид,
   {{0x442fb166,0x7c2db167,0x6d48b168,0xd6d82659}},	//   tag_, _kear, nuda, іту_,
   {{0xb4d5004e,0x5fca00a1,0x7e680118,0x7c2d0260}},	//   सके_, ापाल, hedp, _jear,
   {{0x442f7aa7,0xdfc60082,0x7c2db169,0x3869b16a}},	//   rag_, _أي_, _mear, mear_,
   {{0x3869b16b,0x7c2db16c,0x442fb16d,0x6d48008a}},	//   lear_, _lear, sag_, kuda,
   {{0x6f03b16e,0x442f134c,0x6d48b16f,0x60c9b170}},	//   _rinc, pag_, juda, tnem,
   {{0x3869b171,0x6f03b172,0x7c2db173,0x6d41b174}},	//   near_, _sinc, _near, vrla,
   {{0x60c9b175,0x7d04b176,0xea000019,0xddc100b8}},	//   rnem, _riis, _phẫu_, telů,
   {{0x386909bb,0x0ea903ad,0x7d041c55,0x26c17124}},	//   hear_, ской_, _siis, niho_,
   {{0x442db177,0x7d043115,0x6d48b178,0x7c2db179}},	//   _kee_, _piis, guda, _bear,
   {{0x7c2db17a,0x5f9518e0,0x6d41013c,0x386900de}},	//   _cear, _ниет, rrla, jear_,
   {{0x442d0261,0x7c2d04d6,0x7d040d4c,0xdd8e064e}},	//   _mee_, _dear, _viis, نوی_,
   {{0x7d040088,0x442d3b06,0x7c2d009e,0x00000000}},	//   _wiis, _lee_, _eear, --,
   {{0xea000028,0x3869004f,0x7d045d46,0xada50036}},	//   _khẩu_, fear_, _tiis, _хайл,
   {{0x7c2d003b,0x442d0903,0x386909bb,0xb4d54e96}},	//   _gear, _nee_, gear_, सको_,
   {{0xe73a002d,0x237f0221,0x684300d8,0x78a4b17b}},	// [d060] сез_, _nruj_, энта, rkiv,
   {{0x78a4b17c,0x60c001ae,0x6b7b0319,0x442db17d}},	//   skiv, zimm, _פרינ, _aee_,
   {{0x7c2d9b0f,0x6abeb17e,0x6a9b00a5,0x186a03e6}},	//   _year, _impf, _השינ, _лани_,
   {{0x38695eb2,0xb4d608b0,0x6abe0118,0x0d3a0070}},	//   cear_, हवे_, _hmpf, מגעב,
   {{0x60c00421,0x6d483e0d,0x1ddd0099,0x03a30200}},	//   vimm, zuda, _नुसत, ницо,
   {{0x3f8000d8,0x6d48001c,0x60c060fa,0x00000000}},	//   _šiuo_, yuda, wimm, --,
   {{0xa2cd021a,0x8233006c,0x39580080,0x60c0b17f}},	//   _तदर्, رروا, ntrs_, timm,
   {{0x442d0626,0x25ae01d6,0x6d48b180,0x661b00cd}},	//   _gee_, ıklı_, vuda, _đuki,
   {{0x7e680088,0x60c0b181,0x7c2db182,0x00000000}},	//   tedp, rimm, _rear, --,
   {{0x7c2db183,0x6d48b184,0x60c003ad,0x442d04f4}},	//   _sear, tuda, simm, _zee_,
   {{0x7c2d1093,0x442db185,0x63a2b186,0x6288b187}},	//   _pear, _yee_, lyon, _indo,
   {{0x629a053d,0x6d48acd5,0x0cab06c2,0x7cff00d8}},	//   _hoto, ruda, стои_, _kūri,
   {{0x6d488ab5,0x629ab188,0x7ead609a,0x38690453}},	//   suda, _koto, _súpe, vear_,
   {{0x7c2d024b,0x629a5671,0x00000000,0x00000000}},	//   _wear, _joto, --, --,
   {{0x38690082,0x7c2d44b9,0x6288034d,0x63a20118}},	//   tear_, _tear, _mndo, hyon,
   {{0x6abe02bf,0xe89401c8,0x25e007ba,0x629a05dc}},	//   _empf, нась, _कड़ी_, _loto,
   {{0x628803cb,0x3869b189,0x4c3c0122,0x26c107e7}},	// [d070] _ondo, rear_, _התחב, tiho_,
   {{0x442d4b3f,0x7cd202d4,0x38690341,0xcb1402b5}},	//   _see_, māra, sear_, _אלץ_,
   {{0x3869b18a,0x442db18b,0x26c1041b,0xdbd70421}},	//   pear_, _pee_, riho_, sääm,
   {{0x6288b18c,0x442d0189,0x63a208c7,0x7cff00c7}},	//   _ando, _qee_, fyon, _būri,
   {{0x629ab18d,0x442db18e,0xc5de0033,0x26c1043d}},	//   _boto, _vee_, ভেলপ, piho_,
   {{0xfc3f2abc,0x91e507b0,0xd0570095,0x00000000}},	//   chív_, моле, əcəy, --,
   {{0x442d3517,0x629a1297,0x241900d8,0x63a2b18f}},	//   _tee_, _doto, _мовы_, ayon,
   {{0xef190d1b,0x7cd202d4,0x92bf0083,0x6288b190}},	//   оми_, kāra, ীতে_, _endo,
   {{0x2d9815e5,0x32550c5a,0x63a2007b,0x7ead021d}},	//   ären_, _овар, cyon, _núpc,
   {{0xddc823c6,0x6da52d7a,0x6b820124,0x4ca50033}},	//   cedū, диоа, _šogo, খোমু,
   {{0x8c46275d,0x7d0701cb,0x00000000,0x00000000}},	//   мене, dèrè, --, --,
   {{0xa2b70b35,0x629ab191,0xe45f00be,0x00000000}},	//   ्चक्, _zoto, _ööd_, --,
   {{0x2a6a026b,0x629a33e5,0xbbc8258f,0x69d600b4}},	//   tebb_, _yoto, रपेक, _मुजी,
   {{0xddc5b192,0x394a0069,0xf8bf02d7,0x7d070118}},	//   _обли, tubs_, _amé_, gèrè,
   {{0x09e34ae8,0x63a2b193,0x00000000,0x00000000}},	//   ворн, zyon, --, --,
   {{0x2a6a0332,0xa2bd0066,0x00000000,0x00000000}},	//   sebb_, वोत्, --, --,
   {{0x395800ea,0x65690009,0x995800d5,0x00000000}},	// [d080] strs_, _ćeha, _dáša_, --,
   {{0x290c1ec0,0x63a2002f,0xe5a60192,0x44380067}},	//   ídas_, vyon, мизи, _śr_,
   {{0xd826093c,0x7cff00c7,0x98b800ec,0x6e3c01ef}},	//   _одни, _sūri, ntrī_, órbi,
   {{0x629ab194,0x2eaa0141,0x63a20359,0x7cff013a}},	//   _soto, _छत्त, tyon, _pūri,
   {{0x41c30fd1,0x4ad208b0,0x6f0d0079,0x3d0700be}},	//   _वेबस, _सदाव, _éach, _संघे_,
   {{0x629a2b72,0x63a2b195,0x68e30031,0x00000000}},	//   _qoto, ryon, _ëndr, --,
   {{0x63a2b196,0x5bbb009a,0x660300d8,0x7cf60042}},	//   syon, _उध्व, _апра, cárg,
   {{0x7cff0080,0xc9530d85,0x63a20239,0x1fa63cef}},	//   _tūri, דמה_, pyon, дрог,
   {{0x4426af1f,0x629ab197,0x20021130,0xb4bc00a1}},	//   mbo_, _toto, äki_, ेची_,
   {{0x7e98004f,0x44269572,0x6288b198,0x00000000}},	//   سنجر_, lbo_, _undo, --,
   {{0xfeb71301,0x00000000,0x00000000,0x00000000}},	//   بايت_, --, --, --,
   {{0x4426b199,0x7cd200ea,0x4fc654d4,0xf5371804}},	//   nbo_, tāra, _осла, ונטי_,
   {{0x78a3002d,0x9be401e0,0x00000000,0x00000000}},	//   _învi, вірк, --, --,
   {{0xe7e21163,0x7cd200ec,0xc33300a5,0x6f1d01ef}},	//   _खड़ा_, rāra, כוש_, ísce,
   {{0x442627f9,0x7cd2013a,0x00000000,0x00000000}},	//   kbo_, sāra, --, --,
   {{0x2d580248,0x61e80865,0x6d5a028b,0x44264b96}},	//   mée_, _mydl, mtta, jbo_,
   {{0x2d5802e1,0x442602c6,0x6d5ab19a,0x2ca401ff}},	// [d090] lée_, dbo_, ltta, ömde_,
   {{0x44261f2d,0x7ead01ba,0x49756f95,0x7c3b008d}},	//   ebo_, _kúpa, _злос, ðurf,
   {{0x2d581010,0x7ae507ee,0x6d5ab19b,0x7ea40443}},	//   née_, _ikht, ntta, _còpi,
   {{0x6d5a0d36,0x4426b19c,0x7e780249,0x7cf61dad}},	//   itta, gbo_, _lavp, cárd,
   {{0x2d5800f7,0x6265b19d,0x7ead0168,0x00000000}},	//   hée_, евла, _lúpa, --,
   {{0x61e80076,0x4426001c,0x7e7827be,0x6d5a960e}},	//   _bydl, abo_, _navp, ktta,
   {{0x91e200ed,0xdbfc051d,0x6d5a38e2,0x38a700be}},	//   лоше, _एण्ड_, jtta, _nõrk_,
   {{0x2d5800f7,0x2aad0097,0x00000000,0x00000000}},	//   dée_, ržby_, --, --,
   {{0x443f0a78,0x6d5a083e,0xf1df00ab,0x06c40033}},	//   _idu_, etta, _पुरन, ্তরি,
   {{0xf1a70d13,0x6d250009,0x2bda0ec5,0x2d58000d}},	//   _орен, ндоз, _युगा, fée_,
   {{0x2d580248,0x6cc600d8,0x6d5a08c8,0x443f2dad}},	//   gée_, ейна, gtta, _kdu_,
   {{0x7cf60501,0x443f0355,0xb87b003e,0x30840079}},	//   káre, _jdu_, _skín, _للمف,
   {{0x6d5a16c9,0x7655004e,0x443f7041,0x69d76465}},	//   atta, _oczy, _mdu_, _axxe,
   {{0x442608b7,0x7cf60501,0x6ee60093,0x2d5800a2}},	//   zbo_, dáre, fðbu, bée_,
   {{0x442669e6,0x2d580248,0x291e0031,0xddc3003d}},	//   ybo_, cée_, ëta_, _hanž,
   {{0x291e00ea,0x7afc030a,0xddc100ea,0x7e78023a}},	//   īta_, smrt, celš, _zavp,
   {{0x0686141d,0x2b46004f,0xdb080079,0xf7432fd1}},	// [d0a0] нган, _íoc_, úlói, лето,
   {{0xddc30076,0x443f8219,0xfc3f0037,0x45d64717}},	//   _manž, _adu_, bhís_, нцет,
   {{0xe5a305a1,0x7e6300d7,0x7f5b0031,0xca570070}},	//   лифи, _mbnp, htuq, _אייז_,
   {{0x6b840bf3,0xb4bc00a1,0x443fb19e,0x7cf6014c}},	//   _krig, ेचे_, _cdu_, báre,
   {{0x07a31c4d,0x2d583762,0x442608a3,0x443f016e}},	//   _баян, zée_, rbo_, _ddu_,
   {{0x67241577,0x4426b19f,0x6d5a0343,0x2d5800f7}},	//   mpij, sbo_, ytta, yée_,
   {{0xf1c3074f,0x044600d4,0x2d58000d,0x443f007b}},	//   _वेदन, _певн, xée_, _fdu_,
   {{0x2d5802e1,0x67240c99,0xea000023,0x61e800ac}},	//   vée_, opij, _nhậu_, _vydl,
   {{0x3f82b1a0,0x68e312c3,0xb35500b5,0xa34600f8}},	//   íku_, _índe, _لینا_, _سپاه,
   {{0x2d5802e1,0x61e8b1a1,0x433b016b,0x7ead0168}},	//   tée_, _tydl, _מעמב, _púpa,
   {{0x6b844411,0xa00a0037,0x6d5a00c3,0x614330dd}},	//   _arig, _فقال_, utta, _беха,
   {{0x2d581010,0x6d5ab1a2,0x61e401d6,0xea000023}},	//   rée_, rtta, ğild, _chậu_,
   {{0x2d581010,0x7b640603,0xbea600d8,0x69c8b1a3}},	//   sée_, лтре, _падк, úden,
   {{0x6b842cbc,0x2d5800f7,0x7cf60097,0x2d9803db}},	//   _drig, pée_, váre, øres_,
   {{0x81e20b52,0x6440b1a4,0x6b84018e,0x38600b77}},	//   নের_, _odmi, _erig, ffir_,
   {{0x6b8403d0,0x61e5033b,0x661c0345,0xb4da0761}},	//   _frig, ühli, _afrk, ठको_,
   {{0x6b843f57,0xf7730a86,0x443f01a2,0x60c2b1a5}},	// [d0b0] _grig, داز_, _rdu_, _mmom,
   {{0xf1b0aafe,0x443f0b3e,0x6d484b9c,0x7cf600ac}},	//   जनान, _sdu_, orda, ráre,
   {{0x60c20107,0x387901ba,0x15a802fb,0x2bc5018d}},	//   _omom, _tasr_, нъци_, _लेता,
   {{0x6b840138,0x7cf6002a,0x00000000,0x00000000}},	//   _yrig, márc, --, --,
   {{0x889a02da,0x68edb1a6,0xc886033b,0x00000000}},	//   _חברי, mlad, ößen_, --,
   {{0x03a200af,0x216910be,0xd6e20035,0x76550035}},	//   ришо, дики_, _całą_, _uczy,
   {{0x68ed066a,0xa2b200b4,0x823416e6,0xfa7800a5}},	//   olad, _अतर्, ارها, געות_,
   {{0xd00e0079,0x68edb1a7,0xb7f5020c,0xd6c40033}},	//   يلى_, nlad, _आराम_, ্তৃপ,
   {{0x290bb1a8,0x68edb1a9,0x6d48b1aa,0x999100b8}},	//   _mica_, ilad, erda, kazů_,
   {{0x68edb1ab,0x290b0a78,0x38b544ed,0x7ec6000d}},	//   hlad, _lica_, _hård_, _répè,
   {{0x68ed114d,0x249f0107,0x90550043,0x09c60033}},	//   klad, _koum_, _авец, _শুনা,
   {{0x6b8417d1,0x68edb1ac,0x249f0107,0xa2bd07df}},	//   _prig, jlad, _joum_, वोर्,
   {{0xeb9742c2,0x6d48b1ad,0x2d98177c,0x200f046a}},	//   вия_, arda, ører_, _iggi_,
   {{0xc3320122,0x61e401d6,0x290b0036,0x6f0a0176}},	//   שום_, şile, _aica_, _gifc,
   {{0x29130391,0x09e6046e,0x6cda0945,0x98560819}},	//   _cuxa_, товн, _офис_, кташ,
   {{0x290bb1ae,0x29130176,0x7a3f027d,0x3b860c95}},	//   _cica_, _duxa_, _açtı, _алиг,
   {{0xe7375fa5,0x290bb1af,0x3860b1b0,0x96ba004f}},	// [d0c0] кет_, _dica_, rfir_, وائز_,
   {{0x68ed4758,0x248db1b1,0xe6100095,0x7cf601ef}},	//   alad, _anem_, _düşə, bárc,
   {{0x200f0133,0x290bb1b2,0x67249eca,0xe45a22cc}},	//   _oggi_, _fica_, spij, дже_,
   {{0x68ed532a,0x6724b1b3,0xb734006c,0x290b974c}},	//   clad, ppij, _مہرب, _gica_,
   {{0x2bc800a1,0x29003367,0x68e4b1b4,0x248d69e8}},	//   रपटा, mmia_, moid, _dnem_,
   {{0xe7370202,0x248db1b5,0x29000086,0x290bb1b6}},	//   _јер_, _enem_, lmia_, _zica_,
   {{0x2913072c,0x290b04fb,0x2ab402b1,0x00000000}},	//   _xuxa_, _yica_, _gäbe_, --,
   {{0x68e4b1b7,0x64a30e60,0x7f49345d,0x38b510fa}},	//   noid, _каса, freq, _gård_,
   {{0x64a3479a,0x1306081b,0x730600d8,0xa06703fa}},	//   _тата, _азам, _апаз, тања_,
   {{0x3c32098b,0x68e4127d,0x200fb1b8,0xd357011d}},	//   _được_, hoid, _eggi_, _בימי_,
   {{0x68ed0471,0x68e4a506,0x6ef40176,0x7f4901ed}},	//   ylad, koid, gàba, areq,
   {{0x7f498df1,0x9e03004b,0x68e400c3,0x38b50532}},	//   breq, шчыл, joid, _kåre_,
   {{0xe0b700c2,0x68ed0888,0x290bb1b9,0x59db04bc}},	//   _בלאט_, vlad, _rica_, _मुजर,
   {{0x68ed00e9,0x2900b1ba,0x1ddd00a1,0x291308cb}},	//   wlad, emia_, _नुकत, _puxa_,
   {{0x79a409ce,0x68edb1bb,0x3f860097,0x1ea90037}},	//   арте, tlad, _hrou_, _ثاني_,
   {{0x3f860009,0x2ca04dbb,0x68e4271f,0xdc550dec}},	//   _krou_, _goid_, goid, _свињ,
   {{0x68edb1bc,0x57f52e34,0x249f0260,0x36d50012}},	// [d0d0] rlad, упат, _roum_, гоар,
   {{0x68ed2eae,0x7d0d20fb,0xd51a00e2,0x249f0118}},	//   slad, _hias, _bằn, _soum_,
   {{0x68edb1bd,0x7d0d0657,0xceb302b5,0xe7e3000c}},	//   plad, _kias, סיע_, _कुरा_,
   {{0x73d912da,0x68e4b1be,0x78b601c8,0x321e0d14}},	//   ндер_, coid, chyv, _afty_,
   {{0x7d0d006a,0xe3b00ad9,0x64db018d,0x38b5013c}},	//   _mias, يره_, यकौश, _vård_,
   {{0x7ead004f,0x78ad1023,0x7d0d0345,0xe1f93a49}},	//   _cúpl, lkav, _lias, нгл_,
   {{0x26020bc1,0x7ead21db,0xe5341ac5,0x1a9c0070}},	//   वेदी_, _dúpl, _весь, ויגע,
   {{0x78adb1bf,0x3f86b1c0,0x2249027d,0x28c6175f}},	//   nkav, _brou_, şak_, रोपि,
   {{0x2ca0009e,0xf1bf00b8,0x7cf600b5,0x0fca0066}},	//   _roid_, _řád_, jára, ापगढ,
   {{0x68e4287e,0x63a40086,0x81e20083,0x7cf601ef}},	//   zoid, äine, নেই_, dára,
   {{0x3cca17e3,0x3a380093,0x60550125,0x78adb1c1}},	//   елно_, varp_, _مناط, kkav,
   {{0x7d0db1c2,0x78ad0506,0x61e502b1,0x00000000}},	//   _cias, jkav, ühlu, --,
   {{0x60c9b1c3,0x3f86138f,0x68e4b1c4,0x6ee60093}},	//   miem, _grou_, void, rðbr,
   {{0x60c98674,0x28c6021a,0x00000000,0x00000000}},	//   liem, रोनि, --, --,
   {{0xdb06006c,0x1a660e3a,0x68e41e7b,0xa9671e46}},	//   nyké, نیکی_, toid, лира_,
   {{0x7d0d657a,0x60c9b1c5,0x290014dc,0x00000000}},	//   _gias, niem, umia_, --,
   {{0x68e4b1c6,0xb8dc00dc,0x7cf6002a,0x38cb00d1}},	// [d0e0] roid, _अत_, cára, رافی_,
   {{0x7c36b1c7,0x68e40328,0xd70200d8,0x2b400051}},	//   _heyr, soid, пiса, _ivic_,
   {{0xa9a60eee,0x60c9b1c8,0x7c36008a,0x7d0d01e8}},	//   _синд, kiem, _keyr, _yias,
   {{0x78adb1c9,0x7ead171c,0x00000000,0x00000000}},	//   ckav, _súpl, --, --,
   {{0x04430896,0x43941574,0x00000000,0x00000000}},	//   сечн, ралс, --, --,
   {{0x2d87000d,0x261a1cc3,0x38b502ce,0xe297b1ca}},	//   _orne_, मुखी_, _våre_, лач_,
   {{0x35a3002d,0xe5a305ac,0xb42621b6,0x00000000}},	//   _ларг, _лири, _معذو, --,
   {{0x3f8612c3,0x893702b5,0x60c9b1cb,0x7c361202}},	//   _prou_, ארקע_, giem, _neyr,
   {{0x2d87038d,0x7d0db1cc,0xdfd0004f,0x46a80084}},	//   _arne_, _rias, تية_, _गवाह,
   {{0x7d0d3dc2,0x3f860626,0x7cf62c0e,0x2d8700ac}},	//   _sias, _vrou_, vára, _brne_,
   {{0x2d870a78,0x7d0db1cd,0x7cfd014c,0x7c36b1ce}},	//   _crne_, _pias, nérg, _beyr,
   {{0x60c9b1cf,0x3f86b1d0,0xab5b00b5,0x7c3622ca}},	//   ciem, _trou_, nzüg, _ceyr,
   {{0x2d87b1d1,0x9990003a,0x7c3600e9,0x9f3403d0}},	//   _erne_, _čaše_, _deyr, _телі,
   {{0xbda618dd,0xdb2400fd,0x5b140dec,0x00000000}},	//   _محبو, ásáb, смрт, --,
   {{0x7d0d2580,0x7cf6031d,0x78ad136b,0x6e3ab1d2}},	//   _tias, márn, tkav, matb,
   {{0x6e3a006c,0x7cf667f2,0x00000000,0x00000000}},	//   latb, pára, --, --,
   {{0x96352632,0x00000000,0x00000000,0x00000000}},	// [d0f0] инац, --, --, --,
   {{0x78adb1d3,0x7cf628f6,0xda190fbf,0x60c90035}},	//   skav, nárn, _दलित_, ziem,
   {{0x7ae703fd,0x5575081e,0x78ad0228,0x600b0448}},	//   mojt, ргет, pkav, _kömü,
   {{0x81cd0b52,0x7c3600a8,0x60c911b8,0x6e3a0051}},	//   রথম_, _xeyr, xiem, hatb,
   {{0x60c9b1d4,0xa85602b8,0x7cf6024e,0x083a0070}},	//   viem, _דירה_, kárn, _בערל,
   {{0xddda0332,0x46b90f17,0xae0423f0,0x38a700ab}},	//   hető, _इतिह, रधान_, _võru_,
   {{0x60c9b1d5,0xa5f81f39,0x746b0b00,0x7cf60187}},	//   tiem, _беру_, _прав_, dárn,
   {{0xe18805f5,0xcf450036,0x2d87021d,0x00000000}},	//   ائون_, аний, _rrne_, --,
   {{0x60c9b1d6,0x229502fd,0x2d8701a0,0xc87f033b}},	//   riem, _پلاس, _srne_, _maß_,
   {{0x60c9b1d7,0x4d65135d,0x7c36033e,0x0ea90421}},	//   siem, аков, _seyr, ткой_,
   {{0x60c90228,0x7c369375,0xed590274,0xcc8a00d1}},	//   piem, _peyr, њом_, ننده_,
   {{0x7c360095,0xfce6af73,0x1607364c,0x2d8708b7}},	//   _qeyr, ромо, वेयर_, _vrne_,
   {{0x6e3ab1d8,0x7c29b1d9,0x7cd200ea,0x7cc400b5}},	//   batb, ñera, nāri, nőri,
   {{0xceb8004e,0xab270de2,0x6eef01b4,0x00000000}},	//   chę_, рора_, købi, --,
   {{0x81130033,0x7c3600e9,0x68fd00f6,0x00000000}},	//   _সবুজ_, _teyr, _bhsd, --,
   {{0x6b8202c4,0x7cd200ec,0xf1b20070,0x7cf6b1da}},	//   _šogu, kāri, קסן_, máro,
   {{0xe8014bdd,0xc87f02c9,0xa7a710d7,0x7cf6b1db}},	// [d100] लेला_, _daß_, акта_, láro,
   {{0x63ab013c,0xda66b1dc,0x00000000,0x00000000}},	//   dygn, _твои, --, --,
   {{0x7cf61df9,0x00000000,0x00000000,0x00000000}},	//   náro, --, --, --,
   {{0x232a05f2,0x6e3ab1dd,0xe45f00be,0x1c030387}},	//   води_, zatb, _ööl_, रेवल_,
   {{0xf7460500,0x9377004f,0xe29a03fa,0xab5b033b}},	//   _њего, لصور_, кад_, rzüg,
   {{0xddda006c,0x7cf62c0e,0x7cfd00b5,0xea0000e2}},	//   zető, káro, mére, _chầu_,
   {{0xe5a60e9f,0x7cf67797,0x7cfd52d5,0x6e3ab1de}},	//   _тиви, várn, lére, vatb,
   {{0x645b0082,0x63ab01b4,0x92d60083,0x7cf6b1df}},	//   _gcui, bygn, সতে_, dáro,
   {{0x7cf61d8a,0x7cfdb1e0,0xddda00b5,0x6e3a01e0}},	//   tárn, nére, vető, tatb,
   {{0x1be10a90,0x600b0225,0x00000000,0x00000000}},	//   _गुगल_, _sömü, --, --,
   {{0x7cf6b1e1,0x7cfd1fe2,0x6d4702c4,0x6e3a5322}},	//   rárn, hére, šjan, ratb,
   {{0x557702b5,0x13aa0083,0x7cf600b5,0x00000000}},	//   בעטן_, _খেয়, sárn, --,
   {{0xa2bd021a,0x00bb00a5,0xbbd155f5,0x38b50523}},	//   वोक्, _במאמ, सपेक, _nåra_,
   {{0x7cfdb1e2,0x6b4c0093,0xc87f02b1,0x7cf60098}},	//   dére, _sögð, _saß_, lárl,
   {{0x7ae700da,0x7cf601dd,0x63ab0035,0x98c732a6}},	//   rojt, cáro, zygn, асал,
   {{0x7cfd02e1,0x290f312a,0x48157753,0x00000000}},	//   fére, öga_, смас, --,
   {{0x69de3bbe,0x28c60026,0x7d18006d,0xb8cf00be}},	// [d110] _expe, रोधि, _huvs, _कव_,
   {{0x94e800a8,0x645bb1e3,0x7c3d43fe,0x7cd20228}},	//   _işə_, _scui, lasr, vāri,
   {{0x68e30300,0x64150037,0xaadc00a5,0x260205a2}},	//   _índo, مواط, _בחזר, वेली_,
   {{0x7cfd52d5,0x7cd20228,0x00000000,0x00000000}},	//   bére, tāri, --, --,
   {{0x7cf6b1e4,0x61fa02d7,0x4abb0246,0x7bdf00e2}},	//   záro, _aztl, _उताव, _jxqu,
   {{0x7c3d02ee,0x65950c7e,0x00000000,0x00000000}},	//   hasr, _лагу, --, --,
   {{0xc6920070,0x45d428ea,0x7cf6002a,0xab5b02b1}},	//   _צאל_, _дорс, xáro, nzüb,
   {{0x260200a1,0x7cf68e3d,0x00000000,0x00000000}},	//   वेळी_, váro, --, --,
   {{0xb4e30f39,0x443db1e5,0xea000019,0x201f0036}},	//   नकी_, maw_, _thầu_, rcui_,
   {{0x443daa75,0xe8e00028,0x7cf60332,0x7ead016f}},	//   law_, _đọc_, táro, _kúpi,
   {{0xea000019,0x7ead7601,0xd011004f,0x7d0a03fa}},	//   _khấu_, _júpi, _فلا_, лног_,
   {{0x6281097e,0x6459b1e6,0x443db1e7,0x7cf6b1e8}},	//   _halo, ngwi, naw_, ráro,
   {{0x6281b1e9,0x7cf6b1ea,0xee2e00c7,0x00000000}},	//   _kalo, sáro, _нн_, --,
   {{0x443db1eb,0x6281b1ec,0x7cf6a68a,0x6283b1ed}},	//   haw_, _jalo, páro, ndno,
   {{0x62810cc1,0x443db1e5,0x62830c99,0x7bdf1114}},	//   _malo, kaw_, idno, _exqu,
   {{0x7cfdb1ee,0x628100a7,0x443d003c,0x6d41b1ef}},	//   tére, _lalo, jaw_, msla,
   {{0x443db1f0,0x98a31578,0xcc5700a5,0x7afe00cc}},	// [d120] daw_, чите, _הספק_, _thpt,
   {{0x628103ab,0x38b506d7,0x81e20083,0xfbd300a5}},	//   _nalo, _våra_, নেট_, _מתח_,
   {{0x99860082,0xdb063a5f,0x2e3a0070,0x6d41b1f1}},	//   _الجو, szkó, רגענ, nsla,
   {{0x7cfdb1f2,0x443db1f3,0x62810dc3,0x99980355}},	//   mérc, gaw_, _aalo, larů_,
   {{0x6281b1f4,0xb80106bb,0x291a6515,0x6d410bf7}},	//   _balo, लेआम_, _hupa_, hsla,
   {{0x248015b5,0x291ab1f5,0x6d413a95,0x3a3a038e}},	//   žim_, _kupa_, ksla, _jepp_,
   {{0x443db1f6,0x6281b1f7,0x91860037,0x7764002a}},	//   baw_, _dalo, إجتم, ltix,
   {{0x6d411e54,0x23690484,0x61e471c5,0x6ab40fd0}},	//   dsla, ħajr_, şilo, ँसुर,
   {{0x291ab1f8,0x6281b1f9,0x6d41b1fa,0x1b1e0033}},	//   _lupa_, _falo, esla, বীতে_,
   {{0x6d411d8d,0x7cf6006c,0x877b0070,0x291a053e}},	//   fsla, sárl, נאיי, _oupa_,
   {{0xdceb0ba8,0x7c294e5c,0x2d8a0132,0x98a70009}},	//   žiča, ñero, íbe_, _žiča_,
   {{0x62811061,0x6ae10355,0x6f1900e5,0x00000000}},	//   _zalo, पक्र, _fuwc, --,
   {{0x6281581b,0x61110029,0x7c3db1fb,0x291a01a3}},	//   _yalo, _tālr, rasr, _aupa_,
   {{0x6281ab44,0x7c3d022e,0x7c24013b,0x291a008c}},	//   _xalo, sasr, _efir, _bupa_,
   {{0xdd8f081b,0x443d1c3f,0x4424b1fc,0x291ab1fd}},	//   _эш_, yaw_, _ofm_, _cupa_,
   {{0x291a0012,0x473500d8,0x26cab1fe,0xddc30090}},	//   _dupa_, жнас, _ambo_, _canŵ,
   {{0xfc3f004f,0x7bda01d6,0x443d003c,0xdd90006c}},	// [d130] maí_, ştur, vaw_, _روک_,
   {{0xfc3f0082,0x6b8d5878,0xd5bb02c4,0x7cfd1d2b}},	//   laí_, _irag, лсе_, bérc,
   {{0x443db1ff,0x7c2400fb,0x62810260,0x28c6258f}},	//   taw_, _yfir, _ralo, रोहि,
   {{0xfc3f0514,0x6b8db200,0xb4e31282,0x81d70831}},	//   naí_, _krag, नके_, _সরল_,
   {{0x6281b201,0xf3673d17,0x20d3002d,0x291ab202}},	//   _palo, стен, nţie_, _zupa_,
   {{0xfc3f0082,0x443db203,0x672db204,0x291a046a}},	//   haí_, saw_, mpaj, _yupa_,
   {{0x6d41029e,0x443db205,0x628347ff,0xea000023}},	//   xsla, paw_, rdno, _thấu_,
   {{0x3869004f,0x7c3b0093,0xfc3f0279,0x6b8d23bb}},	//   nfar_, ðurl, jaí_, _orag,
   {{0x628103ad,0xfc3f004f,0x6449b206,0xdbf201c0}},	//   _talo, daí_, _idei, _přír,
   {{0x82340ef5,0x6d4139df,0xee39449f,0x672db207}},	//   _فرما, tsla, шно_, ipaj,
   {{0x6b8db208,0x7cd20080,0x6da50227,0xfc3f0037}},	//   _arag, kārt, цина, faí_,
   {{0x6b8db209,0x291a1034,0xfc3f0037,0x3a3ab20a}},	//   _brag, _rupa_, gaí_, _sepp_,
   {{0x6d410c80,0x291ab20b,0x2d98013c,0x38690037}},	//   ssla, _supa_, ärer_, dfar_,
   {{0x6b8d1116,0x6d416824,0x38bc0098,0x00000000}},	//   _drag, psla, _míre_, --,
   {{0xed59b20c,0x6b8d0291,0x78a617ee,0x3869b20d}},	//   _той_, _erag, _pokv, ffar_,
   {{0xb4e30311,0x6b8d567f,0x3ea7b20e,0xfc3f0fe0}},	//   नको_, _frag, _hont_, caí_,
   {{0x3ea7b20f,0xc31f0083,0x20d30043,0x6b8db210}},	// [d140] _kont_, নীতি_, cţie_, _grag,
   {{0x64490297,0x291ab211,0x7cfdb212,0xb87b0093}},	//   _adei, _tupa_, méra, _skít,
   {{0x3ea7b213,0x77640391,0x7cfd00f7,0x291a0d6c}},	//   _mont_, stix, léra, _uupa_,
   {{0x39580029,0x672d006d,0x38690037,0x78a601a0}},	//   murs_, bpaj, cfar_, _uokv,
   {{0x7cfd1010,0x395801f7,0xf48702fd,0x644900e9}},	//   néra, lurs_, تالی, _ddei,
   {{0x68f6b214,0x26ca002f,0xe7372123,0x6449016e}},	//   llyd, _umbo_, _фер_, _edei,
   {{0x1a9b0070,0x7cfdb215,0x68f600e9,0x00000000}},	//   ייסע, héra, olyd, --,
   {{0xddd8024e,0x8f4681b8,0x4422b216,0xe80101c0}},	//   _navš, оход, _ük_, लेका_,
   {{0x2486043d,0x629e0086,0x1eaa11c0,0x3ea700e9}},	//   mdom_, öpos, لادي_, _bont_,
   {{0x7cfdb217,0x3ea70043,0x3eb80ab7,0x24840110}},	//   déra, _cont_, órt_, _hamm_,
   {{0xfc3f0514,0x3ea7b218,0x23660009,0xdd9002de}},	//   taí_, _dont_, ltoj_, روح_,
   {{0x24860ddf,0xe5710070,0x3958b219,0x672d0221}},	//   ndom_, ײַט_, durs_, ypaj,
   {{0x3ea7b21a,0x2366b21b,0xfc3f0082,0x39580248}},	//   _font_, ntoj_, raí_, eurs_,
   {{0x6b8d04ce,0xfc3f0082,0x3ea7023a,0x2484b21c}},	//   _vrag, saí_, _gont_, _lamm_,
   {{0x298809c2,0x7ead1d2b,0x24868094,0xfc3f0037}},	//   осто_, _cúpu, kdom_, paí_,
   {{0x7cfd69eb,0x23660031,0x28c6084b,0x23bc04e9}},	//   béra, ktoj_, रोलि, ्छाद,
   {{0x236601f4,0x3869b21d,0x7cfdb21e,0x00000000}},	// [d150] jtoj_, rfar_, céra, --,
   {{0x612701d6,0x672d022e,0xe8010461,0x2486b21f}},	//   _yıld, rpaj, लेगा_, edom_,
   {{0x38691bd7,0x39584d3f,0x672d47e0,0x7cd20228}},	//   pfar_, curs_, spaj, pārt,
   {{0x24861e54,0xa87902b5,0xa97a0070,0x2458010b}},	//   gdom_, _פאָר, _פארכ, жаць_,
   {{0x889a0122,0x2484b220,0x290900c3,0x68ed1e2e}},	//   _הברי, _damm_, mmaa_, moad,
   {{0x290900c3,0x2ca9b221,0x2d8e0176,0x684600b5}},	//   lmaa_, _load_, _orfe_, _védő,
   {{0x3ea70a8b,0x24840107,0x00000000,0x00000000}},	//   _ront_, _famm_, --, --,
   {{0x3ea7105d,0x38bc0037,0x237f006f,0x68ed0160}},	//   _sont_, _tíre_, _tsuj_, noad,
   {{0x3ea7b222,0x2d8e099e,0x7cfd002a,0xd040013b}},	//   _pont_, _arfe_, xéra, nimə,
   {{0x92b70a86,0x7cf6b223,0x7cfd01ef,0xddd8023a}},	//   _بحرا, mári, véra, _savš,
   {{0x7cf6b224,0x3ea7b225,0xf6520070,0xddd839e9}},	//   lári, _vont_, עצט_, _pavš,
   {{0x7cfdb226,0x2a7801ae,0x7cff010b,0x01fa00a5}},	//   téra, werb_, _kūry, _הפעל,
   {{0x7cf600c9,0x60db03d0,0x3ea7018d,0x68ed0183}},	//   nári, mnum, _tont_, doad,
   {{0x3958b227,0x60dbb228,0x7529011c,0xdd0100ea}},	//   turs_, lnum, _čezn, ītāj,
   {{0x2902012f,0x7cfd00a2,0xda79010b,0x00000000}},	//   _phka_, séra, цяў_, --,
   {{0x7cfdb229,0xb87b0093,0x98a39cb4,0x29090345}},	//   péra, _skír, нисе, gmaa_,
   {{0x3958b22a,0x68f6b22b,0x248600f4,0x7d04007b}},	// [d160] surs_, rlyd, vdom_, _ihis,
   {{0x7cf695a6,0x248400be,0x29090328,0x69c801ef}},	//   dári, _samm_, amaa_, údes,
   {{0x68ed0391,0xa4940088,0x3f8f0345,0x7d04023a}},	//   boad, ویست, _lrgu_, _khis,
   {{0xeab2006c,0xa5076b65,0x7cf6b22c,0x04570037}},	//   _آٹھ_, пеха_, fári, كلمة_,
   {{0x2486b22d,0x7d0409c3,0x24840107,0x33f60037}},	//   rdom_, _mhis, _vamm_, أساس,
   {{0x78a41851,0x23663a73,0x60db01e4,0xa3a500b8}},	//   ljiv, rtoj_, enum, nářů_,
   {{0x386b004f,0x248400be,0x7c3b008a,0x60dbb22e}},	//   _éirí_, _tamm_, ðurk, fnum,
   {{0x78a40a78,0xfaff01f4,0x236601f4,0x5f940be8}},	//   njiv, jtën_, ptoj_, диит,
   {{0x4426b22f,0x2ca90122,0x7cf60f84,0x289b0070}},	//   mco_, _road_, cári, מיקא,
   {{0x7d160260,0x64420719,0x7d046ead,0x68ed002a}},	//   _aiys, laoi, _ahis, zoad,
   {{0xfaff01f4,0x4426027a,0x7d040118,0xd6be0033}},	//   ftën_, oco_, _bhis, _আদায,
   {{0x7d04b230,0x44260147,0x6442b231,0x00000000}},	//   _chis, nco_, naoi, --,
   {{0x7d0400bf,0x68e31430,0x78a4022f,0x68ed0132}},	//   _dhis, _índi, djiv, voad,
   {{0x644209c3,0x7d04009e,0x00000000,0x00000000}},	//   haoi, _ehis, --, --,
   {{0x68edb232,0x44264565,0x7d040098,0x6442023c}},	//   toad, kco_, _fhis, kaoi,
   {{0x6d5ab233,0x7cfd0248,0x9ddb0122,0xe8b501d6}},	//   muta, méro, _לקוח, _dışı,
   {{0x68edb234,0x20d3002d,0x64420315,0x2909b235}},	// [d170] road, nţia_, daoi, rmaa_,
   {{0x7cf61d85,0x290988c8,0x60c0010d,0x6d5a7272}},	//   vári, smaa_, hhmm, outa,
   {{0x6d5ab236,0xf57914ac,0x7cfd00a2,0x60dbb237}},	//   nuta, تماع_, néro, ynum,
   {{0xdd8604e8,0x7cf6b238,0x437518e2,0x7c3f009f}},	//   _یو_, tári, дукт, _jeqr,
   {{0x6d5ab239,0x7e7a0282,0x60db03d0,0x7c3f009f}},	//   huta, ketp, vnum, _meqr,
   {{0x7cf600c9,0x6d5ab23a,0xe2962f26,0x44261c11}},	//   rári, kuta, даш_, aco_,
   {{0x6d5ab23b,0x7cf69bd9,0x60db3309,0x10a51172}},	//   juta, sári, tnum, дийн,
   {{0x4426b23c,0x6d5a96c4,0x7cfdb23d,0x64420874}},	//   cco_, duta, déro, caoi,
   {{0x443f0160,0x60dbb23e,0x6d4e01dd,0xaf05174b}},	//   _ieu_, rnum, ában, мпил,
   {{0x443f12c3,0x7d04b23f,0x60dbb240,0x6d5a1ebf}},	//   _heu_, _shis, snum, futa,
   {{0x6d5ab241,0x443f5ab9,0x1d0a02f3,0xfce608ce}},	//   guta, _keu_, жени_, доно,
   {{0x443f1010,0x3f8f02dd,0xa3b8006c,0x7d0400d7}},	//   _jeu_, _trgu_, _باہر_, _qhis,
   {{0x443fb242,0x20d30043,0xfaff0031,0x3f8300ea}},	//   _meu_, cţia_, rtën_, ājus_,
   {{0x6d5a5372,0x443fb243,0x4426b244,0x66c02f79}},	//   buta, _leu_, zco_, _köke,
   {{0x7d04b245,0x3f8d335b,0x7cfdb246,0x1987002d}},	//   _this, lveu_, céro, мбри_,
   {{0x443fb247,0xe8fa0560,0x7d045ba0,0x5dd8010b}},	//   _neu_, іла_, _uhis, _эфір_,
   {{0x2ab40006,0x26d30b9f,0xa6860279,0x310e07df}},	// [d180] _läbi_, fixo_, млад, ागतः_,
   {{0x6b84b248,0x61e4033e,0x257e00b8,0x38bc06fe}},	//   _isig, şili, _půl_, _díra_,
   {{0x44264ede,0xf1c3010b,0x443f99a6,0x1a9b00a5}},	//   tco_, nešė_, _beu_, _וייע,
   {{0x4426b249,0x69da000d,0x38b5008c,0x00000000}},	//   uco_, ûteu, _nårh_, --,
   {{0x44260f1f,0x7c3b008a,0x443f2ce4,0x6442009d}},	//   rco_, ðuri, _deu_, raoi,
   {{0x442640d4,0x6d5ab24a,0x38600093,0x443f053e}},	//   sco_, yuta, lgir_, _eeu_,
   {{0x443f2c5e,0x7cfd0391,0x00000000,0x00000000}},	//   _feu_, xéro, --, --,
   {{0x6b84b24b,0x3860b24c,0x2724013c,0x6d5a007c}},	//   _osig, ngir_, _kön_, vuta,
   {{0x2724006c,0x7e630176,0x3f142ef5,0x4fc6021f}},	//   _jön_, _bcnp, ндис, ьска,
   {{0x6d5ab24d,0x41b609e9,0x443fb24e,0x7cfdb24f}},	//   tuta, _осет, _zeu_, téro,
   {{0x629a0c10,0x6b84b250,0x867b0397,0x443f0019}},	//   _into, _asig, חריו, _yeu_,
   {{0x6d5ab251,0x628a16a8,0xe57102b5,0x7e7a0ea5}},	//   ruta, ldfo, אַך_, setp,
   {{0x6d5a0ccf,0x64402cba,0x62882b99,0x63a201f7}},	//   suta, _memi, _kado, nxon,
   {{0x6440b252,0xdd900e6b,0x63a268ff,0x7cfd000d}},	//   _lemi, _موت_, ixon, péro,
   {{0x6b84b253,0xaf070037,0x6127027d,0x2be10066}},	//   _esig, _تقوم_, _kıla, _पखवा,
   {{0x62880473,0xfb1a006c,0x38600093,0x6d4803d0}},	//   _lado, _کريں_, ggir_, msda,
   {{0x6d485447,0x443f0051,0x2b490009,0x76b90009}},	// [d190] lsda, _reu_, _uvac_, плар_,
   {{0x443f7caa,0x2724033e,0xceb8297a,0x644003d0}},	//   _seu_, _dön_, nkę_, _aemi,
   {{0x443f04b9,0x6d486b70,0x644009a6,0x628a001e}},	//   _peu_, nsda, _bemi, ddfo,
   {{0x629a7e89,0x6440b254,0x443f1f51,0x79854583}},	//   _anto, _cemi, _qeu_, _ishw,
   {{0x66c0022a,0x443fb255,0x6288b256,0x291900a7}},	//   _söke, _veu_, _bado, _iisa_,
   {{0x628862b4,0x2919000e,0x6d48b257,0x7cfd0a20}},	//   _cado, _hisa_, ksda, dérm,
   {{0x443f1544,0x6288b258,0x2919b259,0xceb80067}},	//   _teu_, _dado, _kisa_, dkę_,
   {{0x629ab25a,0x6440b25b,0x764502c2,0x2724278e}},	//   _ento, _gemi, lahy, _yön_,
   {{0xb275117a,0x6d4a15ed,0x6d489657,0xa14600ec}},	//   _плаш, _avfa, esda, _alķī,
   {{0x628800ea,0x6440b25c,0x7ce80095,0x29197a6f}},	//   _gado, _zemi, zırd, _lisa_,
   {{0xab5b0332,0xf8bf7601,0x6440b25d,0x7cf600b5}},	//   szül, _olé_, _yemi, kárt,
   {{0x6288b25e,0x2919b25f,0x0fd000a1,0x76450159}},	//   _zado, _nisa_, _तेवढ, hahy,
   {{0x7985b260,0x2bba0037,0x628825db,0x6d480284}},	//   _ashw, ساحة_, _yado, asda,
   {{0xc3325c8e,0xdbcd05ee,0x29196a41,0x00000000}},	//   רום_, róðr, _aisa_, --,
   {{0x2919b261,0x2724013c,0xf8bf00f7,0x7ce800c1}},	//   _bisa_, _sön_, _blé_, tırd,
   {{0xf8bf2c27,0x6f1828da,0x291912ee,0xad1a0070}},	//   _clé_, _zivc, _cisa_, _צופר,
   {{0x291901d2,0x3860008a,0x27e602e1,0x6440b262}},	// [d1a0] _disa_, rgir_, çon_, _remi,
   {{0x291901a2,0x291e0519,0xf8bf00b5,0x63a202d7}},	//   _eisa_, ítas_, _elé_, vxon,
   {{0x62880936,0x64400464,0x2919b263,0xf51a0118}},	//   _rado, _pemi, _fisa_, ستاش_,
   {{0x2919b264,0x63a2b265,0xf8bf0341,0x59d60067}},	//   _gisa_, txon, _glé_, _डेयर,
   {{0x6288b266,0x7cf601ba,0x644053d6,0xceb80067}},	//   _pado, lárs, _vemi, ykę_,
   {{0x764e01b4,0x64400103,0xf8bf0bca,0x2919b267}},	//   _udby, _wemi, _zlé_, _zisa_,
   {{0x66e369f7,0x62888587,0x644001d6,0x7cf6b268}},	//   _сора, _vado, _temi, nárs,
   {{0x62880a56,0xd5b901c8,0x6d4e05c9,0xceb80035}},	//   _wado, _ўсё_, ábam, wkę_,
   {{0x93aa0642,0x62884291,0xdfd001b2,0xceb80035}},	//   _عارف_, _tado, شيد_, tkę_,
   {{0x6d48b269,0x7cf601ba,0xc7b300a5,0x59b200b4}},	//   tsda, kárs, טבח_, ीनार,
   {{0x7cf61db5,0xceb82854,0x6d48004b,0x61db0d41}},	//   járs, rkę_, usda, यपृष,
   {{0x7cf6016f,0xdd12037a,0x6d487978,0x27e60035}},	//   dárs, rüşl, rsda, żony_,
   {{0x2919b26a,0x6d48b26b,0xceb80067,0x00000000}},	//   _risa_, ssda, pkę_, --,
   {{0x29190464,0xfd7400af,0xe3e20033,0x61fa00fe}},	//   _sisa_, _алкэ, _বরাব, _kytl,
   {{0xa2b300a9,0x2919b26c,0xf8bf004f,0x7cf61e13}},	//   _अवस्, _pisa_, _plé_, tárt,
   {{0x76450ac8,0xc4c4006c,0x69c701e9,0x3f860107}},	//   wahy, _طے_, rzje, _ksou_,
   {{0x2919b26d,0x3f860311,0x48152bfc,0xddc8b26e}},	// [d1b0] _visa_, _jsou_, тмас, nedž,
   {{0x798501a9,0x65953cee,0x35e71303,0x1a6500b5}},	//   _tshw, казу, нцев, _جیسی_,
   {{0x7645022e,0x2919b26f,0x7cf6b270,0x3eae0139}},	//   rahy, _tisa_, cárs, _moft_,
   {{0x3eae7276,0x3f8600ac,0x00000000,0x00000000}},	//   _loft_, _osou_, --, --,
   {{0x80a402b4,0x45180416,0xd7fb021d,0x7c2d6637}},	//   काने, رآمد_, _хун_, _mfar,
   {{0x2489b271,0x213e099e,0x00000000,0x00000000}},	//   žam_, _bwth_, --, --,
   {{0x3f8698ed,0x776d8cf4,0x7cfd00fd,0x61fa099e}},	//   _asou_, ltax, gérk, _cytl,
   {{0x23d225d8,0xa99c025a,0x712401cb,0x00000000}},	//   _देवद, לבור, درول, --,
   {{0x776d043f,0x78af0207,0x66c00282,0x248000be}},	//   ntax, _mocv, _höka, õime_,
   {{0x7c2db272,0x1e950192,0x7f490be2,0x31c738ea}},	//   _afar, трир, rseq, _псев,
   {{0x7f490036,0x213e009e,0x3eae017b,0x224701b7}},	//   sseq, _gwth_, _doft_, mank_,
   {{0x7c2d00da,0x2247b273,0x7f753f6c,0x442d008e}},	//   _cfar, lank_, _аукц, _jfe_,
   {{0x30d80070,0x66c00523,0x3b83010b,0x2b3a00af}},	//   _אַװע, _löka, аляг, ьянэ_,
   {{0x3eae006d,0x7cf6b274,0x2d950ddc,0x442d081b}},	//   _goft_, társ, _арис, _lfe_,
   {{0x78af02c4,0xaa430d13,0xd9431eba,0xa96708ce}},	//   _bocv, ресл, иери, кира_,
   {{0x442d2de2,0x7cf6b275,0x7c29002a,0x00000000}},	//   _nfe_, rárs, ñert, --,
   {{0x91fc013a,0x00000000,0x00000000,0x00000000}},	// [d1c0] _acāl, --, --, --,
   {{0x442db276,0xa9264b34,0x36c31ec2,0x2d87023a}},	//   _afe_, _идол, абуг, _ksne_,
   {{0x05660afd,0x2247053e,0x546a1482,0x00000000}},	//   твен, dank_, даем_, --,
   {{0x6b9603bc,0x442db277,0x2b400185,0x00000000}},	//   _kryg, _cfe_, _kwic_, --,
   {{0xa2b30808,0x7cf6b278,0x61ed00d0,0xdceb0207}},	//   _अवश्, nárq, şall, žića,
   {{0x626303fa,0x61fab279,0x66e63072,0xe297493b}},	//   авља, _pytl, _рога, кач_,
   {{0xe5a373a8,0xe297395d,0x442d0273,0x5186b27a}},	//   _кири, тај_, _ffe_, тула,
   {{0x61fa016f,0x6b96004e,0x3eae2bf9,0x660300b5}},	//   _vytl, _oryg, _soft_, ünke,
   {{0xb4be0067,0x2d87013a,0x7cfd00ac,0x00000000}},	//   इसी_, _asne_, sérk, --,
   {{0x7cfda979,0x7c2d002d,0x38b5013c,0x3eae0055}},	//   méri, _sfar, _hårt_, _qoft_,
   {{0x7cfd4b1d,0x7c2d033b,0x61e4027d,0x865b00a5}},	//   léri, _pfar, ğils, ודיי,
   {{0x6b96038d,0x776d0095,0xc5f300a5,0x7c2d0031}},	//   _bryg, ytax, ידת_, _qfar,
   {{0x3f860f84,0x2d87b27b,0x7cf60138,0xde584747}},	//   _usou_, _esne_, gárq, _залі_,
   {{0x6b96b27c,0x00000000,0x00000000,0x00000000}},	//   _dryg, --, --, --,
   {{0x7c3b008a,0x60c2b27d,0x7c2901dd,0x7cfd1ab6}},	//   ðurs, _klom, ñers, héri,
   {{0x7c2d3218,0x3872001e,0x6b9601b4,0x00000000}},	//   _ufar, gfyr_, _fryg, --,
   {{0x442db27e,0x66c0013c,0x7cf60138,0x00000000}},	// [d1d0] _rfe_, _söka, párr, --,
   {{0x776d3762,0x60c24151,0x7cfdb27f,0xe3b300f8}},	//   rtax, _llom, déri, یرش_,
   {{0x776d0391,0x60c201c0,0x7af57676,0x00000000}},	//   stax, _olom, mozt, --,
   {{0x6d5a0044,0xde15016b,0x00000000,0x00000000}},	//   irta, אַנץ_, --, --,
   {{0x7cfd67f7,0x6ec5018d,0x42d512ea,0x6d5a02b1}},	//   géri, िसमु, ліку, hrta,
   {{0x91e51457,0xf990103b,0x61ed01fb,0x00000000}},	//   лоле, _ابی_, şalm, --,
   {{0xfa7801f3,0x60c20532,0x36d400c3,0xd24e11cf}},	//   דעות_, _blom, _торр, سني_,
   {{0x7cfdb280,0x6fd407b5,0x442d034d,0x00000000}},	//   béri, _बेहू, _ufe_, --,
   {{0x7af5006c,0x7cfd2cad,0x6d5a6278,0x62351174}},	//   kozt, céri, erta, _безу,
   {{0x612701d6,0x52740a86,0x7ce80448,0x5fd900ab}},	//   _yıll, _نامز, dıra, _बइठल,
   {{0x3075b281,0x8c461b96,0x60c21cbd,0x61270225}},	//   _булс, лене, _flom, _kılm,
   {{0x7cf60132,0x6b96008c,0x5576016b,0x00000000}},	//   tárq, _pryg, נערן_, --,
   {{0xeb97392c,0x6d5ab282,0x20240038,0xfc470b4c}},	//   гия_, arta, ásiť_, ñías_,
   {{0x60c28c65,0x7cc4006c,0x7cf6061b,0x6b96053e}},	//   _zlom, nőrz, rárq, _vryg,
   {{0x2d870c0a,0x5d7902b5,0x6d5a0254,0x2245b283}},	//   _usne_, _טאַק, crta, _melk_,
   {{0x6b96b0c8,0xbc662503,0x249f008c,0x4dfa016b}},	//   _tryg, _свик, _nnum_, _אפצא,
   {{0x2ca0009e,0xc7a30200,0x2d000099,0xa8061954}},	// [d1e0] _inid_, битк, ईतील_, узал,
   {{0xe5a63804,0x8c1b00a5,0x7cfd7f65,0x00000000}},	//   лизи, _אופי, véri, --,
   {{0xd9460a2b,0xe45ab284,0x96f9010b,0x7cd20228}},	//   _щени, еже_, тэту_, dārz,
   {{0x7cfdb285,0xa34a12fb,0x18a6584e,0x98a61a1c}},	//   téri, езда_, _самм, _симе,
   {{0x38b5370d,0xcc3b0070,0x60c2009e,0x68e4b286}},	//   _vårt_, גענט, _rlom, mnid,
   {{0x2900b287,0x60c20a16,0x249f03d0,0x88c60033}},	//   llia_, _slom, _enum_, _এদিক,
   {{0x60c2b288,0x7cfdb289,0x68e400ab,0x2ca0016e}},	//   _plom, séri, onid, _onid_,
   {{0x7cfd02e1,0x92e400c8,0x68e4b28a,0x26da000e}},	//   péri, নতে_, nnid, lipo_,
   {{0x68e4001e,0x2900b28b,0x60c20116,0x7ce8013b}},	//   inid, ilia_, _vlom, xıra,
   {{0x6726046a,0x26da0159,0x22450024,0xe3eb016b}},	//   _mukj, nipo_, _gelk_, _אַבֿ,
   {{0xd6db011d,0x29000054,0x6127027d,0x2b9100a0}},	//   תחיל, klia_, _yılm, _môcť_,
   {{0x6d5a09bb,0x60c2b28c,0x25dc007c,0x7ce800d0}},	//   rrta, _ulom, _गइनी_, tıra,
   {{0x2900b28d,0x6d5a00cd,0x7af5b28e,0x212b00d5}},	//   dlia_, srta, tozt, _čchi_,
   {{0x66c0022a,0x2900099e,0x2ca0099e,0xc98738d0}},	//   _sökn, elia_, _enid_, луби,
   {{0x68e4001e,0x7af51e5c,0x26da0036,0x67260051}},	//   fnid, rozt, dipo_, _aukj,
   {{0x29000133,0x68e42dea,0x38359dee,0x7ebf0298}},	//   glia_, gnid, рнар, _lêpl,
   {{0x96f903e6,0xe89400c3,0xb8dd35d1,0x672602a7}},	// [d1f0] веат_, щать, _अव_, _cukj,
   {{0x2900b28f,0x68e4b290,0x248d0132,0x67260031}},	//   alia_, anid, _saem_, _dukj,
   {{0x2900b291,0x7d0d128f,0x00000000,0x00000000}},	//   blia_, _khas, --, --,
   {{0x63b9004e,0xddc8016f,0x29000310,0xf8c900ab}},	//   tywn, radň, clia_, _रतिय,
   {{0x03a50012,0x66c0045e,0x7d0db292,0xddd80097}},	//   рило, _kökl, _mhas, _navž,
   {{0x26da33c4,0x7cfd01ef,0xb7da00a5,0x7e6a02a7}},	//   cipo_, cérv, _יקרי, _ncfp,
   {{0x02c50099,0x63b90067,0xd12ea42a,0xe2c903fc}},	//   _वतीन, sywn, ومو_, _یورو_,
   {{0x78ad18b0,0x22450120,0xb97c0070,0x75350024}},	//   njav, _welk_, גנהי, _itzz,
   {{0x644bb293,0x09d202cb,0x20d30043,0x4f250370}},	//   magi, _सध्य, nţii_, јдоб,
   {{0x644bb294,0x7f5b7fa3,0x2eb50af5,0x7d0db295}},	//   lagi, rruq, рсис, _ahas,
   {{0x7d0db296,0x2900101b,0x00000000,0x00000000}},	//   _bhas, ylia_, --, --,
   {{0x644bb297,0x386b002f,0x30e4010b,0x764773e7}},	//   nagi, _nccr_, _лічб, _lejy,
   {{0x7d0db298,0x3ceb0187,0x60db3921,0xee2eb299}},	//   _dhas, _živé_, mium, _мн_,
   {{0x644bb29a,0x62836d4b,0x13ba0070,0xfc0300d4}},	//   hagi, neno, דזשע, іпро,
   {{0x66c0013c,0x644bb29b,0xd9460212,0x2ca00453}},	//   _söko, kagi, реби, _tnid_,
   {{0x6283b29c,0x7d0db29d,0x60c98e2c,0x644bb29e}},	//   heno, _ghas, nhem, jagi,
   {{0x644bb29f,0x68e4b2a0,0x6283b2a1,0x4a7609eb}},	// [d200] dagi, rnid, keno, _кынт,
   {{0x62830121,0xfd4c0028,0xdcf900b8,0x60db07e5}},	//   jeno, _nhiệ, _osvě, hium,
   {{0x14262846,0x4a5b0122,0x6283a9d3,0x2900b2a2}},	//   адем, _בדיו, deno, plia_,
   {{0x644b7a10,0x7cfd5293,0x26da002f,0x6e2d8bef}},	//   gagi, sérv, sipo_, _şabl,
   {{0x66c000a8,0x20d3002d,0xd46764d9,0xe286081b}},	//   _hökm, cţii_, риче_, илди,
   {{0x628309ad,0x6d43081b,0xfd4c00e2,0x00000000}},	//   geno, _owna, _chiệ, --,
   {{0x644bb2a3,0x6d5505fa,0x22420023,0x69ceb2a4}},	//   bagi, ázal, _đkkd_, nzbe,
   {{0x7c24b2a5,0x92c80033,0x60db05f5,0x60c967f6}},	//   _ngir, োকে_, gium, ghem,
   {{0x6283b2a6,0x4ea65ae1,0x7527006d,0x232a2d1e}},	//   beno, арна, _zujz, _рози_,
   {{0x62330202,0x6283b2a7,0x7d0d0774,0x7c24b2a8}},	//   _међу, ceno, _shas, _agir,
   {{0x06970122,0x7d0db2a9,0x7cfd006c,0x4c952344}},	//   בדים_, _phas, kért, бинс,
   {{0x60db0160,0xa0a30336,0xddd802a7,0x7eb600f6}},	//   cium, _махд, _tavž, _câpr,
   {{0xd0d30594,0xdee61e96,0x00000000,0x00000000}},	//   _بينظ, _коди, --, --,
   {{0x80a4009a,0x644b6feb,0x7ce800c1,0x7c24b2aa}},	//   कावे, zagi, lırl, _egir,
   {{0x1fe80083,0x7d0db2ab,0x644bb2ac,0x764702d0}},	//   _পরিস, _thas, yagi, _rejy,
   {{0x6283b2ad,0x31570070,0x7ce800d0,0x75209906}},	//   zeno, יילן_, nırl, _nimz,
   {{0x78adb2ae,0x644b125e,0x628301e4,0x2f0b08c8}},	// [d210] rjav, vagi, yeno, søge_,
   {{0xed4d00f5,0x644b7751,0x628301dd,0x20d3002d}},	//   _تھی_, wagi, xeno, rţii_,
   {{0x6283b2af,0x644b251e,0xb995004f,0x78adb2b0}},	//   veno, tagi, _الجب, pjav,
   {{0x77640443,0x7cfd00b5,0xfaff0055,0x6b8d1491}},	//   buix, mérs, atët_, _ksag,
   {{0x6283b2b1,0x644b7067,0x76470221,0x7ce80644}},	//   teno, ragi, _tejy, dırl,
   {{0x644bb2b2,0x6b8d023c,0x00000000,0x00000000}},	//   sagi, _msag, --, --,
   {{0x644bb2b3,0x6283116d,0x349528fb,0x81bc0228}},	//   pagi, reno, _лавр, _sfēr,
   {{0x38696ea0,0x6283b2b4,0x6b8d01d7,0x4424034d}},	//   ngar_, seno, _osag, _ggm_,
   {{0xfd4c00e8,0x62830274,0x60dbb2b5,0xfaff0055}},	//   _thiệ, peno, rium, ntës_,
   {{0x60c9b2b6,0x2fcd01ef,0x60dbb2b7,0x752002f6}},	//   shem, rzeg_, sium, _zimz,
   {{0x60c901a2,0x6b8db2b8,0xa29401e0,0x64490211}},	//   phem, _asag, _фахі, _keei,
   {{0xfce6002d,0x20ca009e,0xe1f01015,0x00000000}},	//   сомо, _cùid_, _غسل_, --,
   {{0x80a414ab,0xfaff01f4,0x38696041,0x66c0b2b9}},	//   कारे, jtës_, dgar_, _sökm,
   {{0xa96a2028,0xa3af25d8,0x6d5c4a05,0x69ce033b}},	//   лига_, _ओपन_, árac, tzbe,
   {{0xcd3500bf,0x6b8db2ba,0x7c290eac,0x7cfd00fd}},	//   _ارتب, _esag, žera, tért,
   {{0x38697710,0xfaff00da,0x7c24035a,0x69ce033b}},	//   ggar_, ftës_, _ugir, rzbe,
   {{0x03e20083,0x4424012f,0xdc3b0070,0xc7a30945}},	// [d220] _বর্ণ, _rgm_, _געפר, питк,
   {{0x7ce80dac,0x44240118,0x38690079,0x7cfd4509}},	//   zırl, _sgm_, agar_, sért,
   {{0xb8ce0083,0x644901ae,0x98b81505,0x7ce8037a}},	//   _কত_, _beei, strı_, yırl,
   {{0xed5602b5,0xfaff00da,0x64490176,0x232a6d1d}},	//   מבער_, stët_, _ceei, годи_,
   {{0x87ba0043,0xa8050042,0x00000000,0x00000000}},	//   _сунт_, ruñé, --, --,
   {{0x26d80a78,0xd6270b46,0x954a250f,0xd54a2499}},	//   _umro_, _горе_, _مشرق_, _مجرم_,
   {{0x7ce806d0,0x80a40803,0xfc3f00b8,0x59c821b2}},	//   tırl, काले, ybí_, रनिर,
   {{0x644901ae,0x442416ab,0x03260c8a,0x399b0070}},	//   _geei, _ugm_, _гдан, ריקד,
   {{0xd9a50026,0xdbf10355,0x30770037,0x7ce8027b}},	//   _ऑप्ट, _příc, صحية_, rırl,
   {{0x66fa0967,0x3869b2bb,0xa29f166b,0x7ce80225}},	//   ्तिक_, zgar_, _गोप्, sırl,
   {{0xd24f29fe,0x6b8d001c,0x00000000,0x00000000}},	//   _سنن_, _ssag, --, --,
   {{0x7cfdb2bc,0xac190200,0x7bcf02d7,0x24860124}},	//   vérs, иону_, tzcu, neom_,
   {{0x06fa06bc,0xc4d300a5,0xfc3f5459,0x00000000}},	//   ्ताव_, פגש_, rbí_, --,
   {{0x6d4e0391,0x7cfd0187,0x38bc00b8,0x3e1800af}},	//   ábas, térs, _míru_, _колэ_,
   {{0x38690159,0xf8bf00f7,0xa803027d,0x24860207}},	//   tgar_, _liée_, ğıms, keom_,
   {{0x58d43b8b,0x320c0187,0x52c50ed1,0x24860009}},	//   пост, _mzdy_, _वत्स, jeom_,
   {{0x3869b2bd,0xf7700082,0xb8d10026,0x2cf700a1}},	// [d230] rgar_, فال_, _टच_, ीतील_,
   {{0x3869515c,0x6efd0248,0xfaff0031,0xc6270033}},	//   sgar_, lèbr, rtës_, যর্থ_,
   {{0x64492ea2,0x9865006c,0xfaff01f4,0xf60b1a15}},	//   _peei, _ویسے_, stës_, ухай_,
   {{0xe61000b5,0x6efd000d,0xc5fb00b4,0x20ca00f1}},	//   رشل_, nèbr, _्रीय_, _lùib_,
   {{0x672d0024,0x69d80093,0x00000000,0x00000000}},	//   qqaj, _þver, --, --,
   {{0x04fb0033,0x38bc007e,0x64490118,0x00000000}},	//   েদের_, _díru_, _weei, --,
   {{0x96080a93,0x644928dc,0x6eac1cce,0x32cb0185}},	//   _гэта_, _teei, जानु, _nøye_,
   {{0x7ce804d4,0xf8c900dc,0x00000000,0x00000000}},	//   tırm, रसिय, --, --,
   {{0x2d9c69fe,0x00000000,0x00000000,0x00000000}},	//   _arve_, --, --, --,
   {{0x20030029,0xd2510a72,0x32cb03d0,0x6d460207}},	//   āji_, _آنا_, _bøye_, ćkan,
   {{0xdb060067,0x2d9c00f4,0xb03502fb,0xf8c901d1}},	//   zykó, _crve_, _днеш, रसाय,
   {{0x7c290e5e,0x236001a0,0xc0ab2402,0x6efd00a2}},	//   žern, šije_, _حائل_, gèbr,
   {{0xab2a18d9,0xb4fa0070,0x2d9c0051,0xe7e40033}},	//   рога_, שפרי, _erve_, _মর্য,
   {{0x81cc0083,0x2bab04bc,0x66c001fb,0xc33200a5}},	//   রপর_, _चपरा, _gökh, ווך_,
   {{0x5d69027a,0x2d9802df,0x200b00f4,0x7ce80225}},	//   _тийм_, året_, škić_, nırk,
   {{0xdb060035,0x00000000,0x00000000,0x00000000}},	//   tykó, --, --, --,
   {{0xe8f700d4,0xfaff01f4,0x464a066d,0x24860cc2}},	// [d240] ілу_, rtër_, изан_, veom_,
   {{0x2be0009a,0xfaff01f4,0x7ce80225,0x00000000}},	//   _पेया, stër_, kırk, --,
   {{0x7afc08f8,0x248600f4,0xa2b30808,0x4aa7018d}},	//   mort, teom_, _अवज्, खारव,
   {{0x2d9a0c6e,0x66c00421,0xdce20207,0x00000000}},	//   _špek_, _möki, kulč, --,
   {{0x78a6b2be,0x248600f4,0x00000000,0x00000000}},	//   _inkv, reom_, --, --,
   {{0x7afcb2bf,0x7cf600fd,0x00000000,0x00000000}},	//   nort, gárz, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x320c0bca,0x32cb03d0,0x00000000,0x00000000}},	//   _vzdy_, _røye_, --, --,
   {{0x7afcb2c0,0x2002008a,0x95ec0033,0x98b300f4}},	//   kort, æki_, _করিম_, žeće_,
   {{0x2d9c66b9,0x7afc33d4,0x66c00523,0x64420176}},	//   _prve_, jort, _böki, lboi,
   {{0xa2b90d34,0xa2a70f17,0x7afc24c4,0xdcf900ec}},	//   ्सर्, चार्, dort, _apvā,
   {{0x64424a4f,0x61ed00c1,0xff0a0033,0x2d9c0207}},	//   nboi, ğalt, রদেশ_, _vrve_,
   {{0xdb1db2c1,0x7afc5a52,0x9998010b,0xd0070274}},	//   lysé, fort, karų_, _деце_,
   {{0x7afc1c01,0x70da07b5,0xb4b700b4,0x7c36099e}},	//   gort, _बगुल, _चक्_, _efyr,
   {{0x28bf2203,0xdb1d006c,0x7c36001e,0x09940dec}},	//   _एकदि, nysé, _ffyr, марџ,
   {{0x34b906bb,0x26cab2c2,0x47350ef7,0x115b0070}},	//   _आवेद, _albo_, знас, ידלע,
   {{0x7afcb2c3,0x26ca00ee,0x7ce8013b,0x00000000}},	// [d250] bort, _blbo_, zırk, --,
   {{0x501b00a5,0x78a6023a,0x7afc0147,0x00000000}},	//   שומו, _enkv, cort, --,
   {{0x63b60421,0x00000000,0x00000000,0x00000000}},	//   äynn, --, --, --,
   {{0xf9fa00a5,0x224c0065,0x26ca008c,0x00000000}},	//   _להתמ, _aedk_, _elbo_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77ba0122,0x02c502cb,0x1dca143a,0x67ba00a5}},	//   _המשח, वसेन, ानात, _המשק,
   {{0xca7c0319,0x200900ea,0x5558002d,0xdb1d00b5}},	//   ינגט, _šai_, _маря_, gysé,
   {{0x25755c1b,0x6577006d,0x7afcb2c4,0xadfe0066}},	//   mål_, mtxh, zort, _उड़न_,
   {{0xb4e700a1,0x34c70324,0x6d5cb2c5,0xf07600b5}},	//   यची_, लसीद, áran, سیوں_,
   {{0xf19501e0,0x4d65a892,0x00000000,0x00000000}},	//   _низь, пков, --, --,
   {{0x7cfd3207,0x6da554e1,0x7afcb2c6,0xe3bd0033}},	//   térp, чина, vort, _অধিব,
   {{0x7afc02c9,0xa29f0026,0xdb0d01ba,0xbfb700bc}},	//   wort, _गोत्, ľkýc, _وحشت,
   {{0x7afcb2c7,0xa2d20632,0x7f1900d8,0x53bd074f}},	//   tort, भोक्, _ліку_, ्निश,
   {{0x25dc007c,0x6442002d,0x8f9a0317,0x8d551a0b}},	//   _गइली_, zboi, _ליני, _етич,
   {{0x7d110332,0x7afc04ff,0x657701e8,0x3ea7b2c8}},	//   üksé, rort, jtxh, _innt_,
   {{0x23bd021a,0xa3ab01c0,0x7afcb2c9,0x645b0098}},	//   ्नाद, गमा_, sort, _ndui,
   {{0xe81f00b4,0x00000000,0x00000000,0x00000000}},	// [d260] _मृदा_, --, --, --,
   {{0x6b842a13,0x00000000,0x00000000,0x00000000}},	//   _ipig, --, --, --,
   {{0x6577006d,0x3abb011d,0x7abb00a5,0xe3b201df}},	//   gtxh, _המינ, _הציו, کرا_,
   {{0x27ed01cc,0x212c009e,0x00000000,0x00000000}},	//   _žene_, _rudh_, --, --,
   {{0x29020006,0x64427377,0xa3fc0033,0x934324d8}},	//   _ikka_, rboi, েশ্য_, енче,
   {{0x320501c0,0x657701e8,0x6b84b2ca,0x26ca0159}},	//   _byly_, btxh, _mpig, _ulbo_,
   {{0xb90901a5,0x0446087b,0x987c00ee,0xa2d200b8}},	//   _nghỉ_, _невн, _míľ_, भोग्,
   {{0x3ea7b2c8,0xf4840919,0x764e009e,0xc1040037}},	//   _annt_, _تاسی, _heby, بوعي,
   {{0xdd1f0355,0x764e0168,0x6d4600f4,0x00000000}},	//   tížn, _keby, ćkam, --,
   {{0x3f130409,0x3ea7009e,0xeeaa7e78,0x00000000}},	//   ндыс, _cnnt_, стик_, --,
   {{0x4ab000b4,0xaab00518,0x6b84002f,0xd23b00a5}},	//   ञानव, ञानक, _apig, _הגבל,
   {{0x62980479,0x764e0103,0x63a03c56,0x00000000}},	//   ldvo, _leby, _krmn, --,
   {{0x66c00095,0xde581958,0x00000000,0x00000000}},	//   _höku, _далі_, --, --,
   {{0x765c071f,0x753c004e,0x2902b2cb,0x764e01c0}},	//   _ndry, _otrz, _akka_, _neby,
   {{0x25dc00a1,0xc98402bb,0x4e7b00a5,0x66c0008d}},	//   _गेली_, нути, _האוצ, _jöku,
   {{0x628a08c8,0x02d91cce,0x7764b2cc,0xd7fb02ee}},	//   hefo, _भग्न, frix, буз_,
   {{0xf773211b,0x628a56bd,0x76b90009,0x764e78de}},	// [d270] عار_, kefo, олар_, _beby,
   {{0x2902001c,0xeaf800b4,0x628a0b41,0x28bf00e7}},	//   _ekka_, ंकृत_, jefo, _एकवि,
   {{0x3915002d,0x764e001e,0x765c016e,0x00000000}},	//   _омор, _deby, _ddry, --,
   {{0x765c0297,0xb4e700a1,0x24581a0e,0x764e0103}},	//   _edry, यचे_, заць_, _eeby,
   {{0x68edb2cd,0x63a00009,0x6d4a001e,0x889a00a5}},	//   mnad, _crmn, _lwfa, _וברי,
   {{0x628a6024,0x03a2b2ce,0x29090421,0x764eb2cf}},	//   gefo, тишо, llaa_, _geby,
   {{0x68ed1fca,0xd5b84ea4,0x23600484,0x95c50037}},	//   onad, _ест_, ġija_, _غيره,
   {{0x7f5900c9,0x236005e2,0x6727b2d0,0x62983f94}},	//   ојот_, šija_, _hijj, advo,
   {{0x6d58b2d1,0x68ed0279,0xa22700d1,0x628ab2d2}},	//   _avva, inad, _فراه, befo,
   {{0x68ed515c,0x628a312b,0x2ca9b2d3,0x854300c7}},	//   hnad, cefo, _anad_, _įėji,
   {{0x68edb2be,0x6b84027a,0x62810298,0x693c0506}},	//   knad, _spig, _iblo, _ičeg,
   {{0x81b60033,0x6727001c,0x00000000,0x00000000}},	//   _চেক_, _lijj, --, --,
   {{0x68edb2d4,0x6d584ce3,0xdce200ea,0x00000000}},	//   dnad, _evva, gulā, --,
   {{0x7d070248,0x68ed1dad,0x3200027d,0x6281021d}},	//   térê, enad, şiye_, _jblo,
   {{0x764e0159,0x6281b2d5,0x20ca009e,0x9cf601f2}},	//   _reby, _mblo, _mùin_, _очиш,
   {{0x7764b2d6,0x629801a0,0xa29f23e3,0x764e18f9}},	//   trix, zdvo, _गोस्, _seby,
   {{0x6281193b,0x7d049f1f,0x753c004e,0x752e0139}},	// [d280] _oblo, _ikis, _strz, _subz,
   {{0x68ed09bb,0x77645ac2,0x2909b2d7,0x69da002a}},	//   anad, rrix, alaa_, útes,
   {{0x6d41b2d8,0x628a9a8f,0x7e7e022a,0x00000000}},	//   npla, vefo, _öppe, --,
   {{0xcdb600a5,0x62813be1,0x7d04009f,0x6d410345}},	//   ופעה_, _ablo, _jkis, ipla,
   {{0x628ab2d9,0x764e5472,0x62810024,0x6d41345d}},	//   tefo, _teby, _bblo, hpla,
   {{0xd13a36c3,0x68e43784,0x290001d7,0x6281009e}},	//   охи_, liid, loia_, _cblo,
   {{0x6281780e,0x753c0035,0x62980b0d,0xf8d20fd0}},	//   _dblo, _utrz, rdvo, _सताय,
   {{0x6d41b2da,0x62810107,0x628a36a2,0x68e4b2db}},	//   dpla, _eblo, sefo, niid,
   {{0x6d41b2dc,0x628a0223,0x7c290d5c,0x00000000}},	//   epla, pefo, žerk, --,
   {{0x7d0405ba,0x2ca901c0,0x68e414e7,0x290001b7}},	//   _akis, _snad_, hiid, hoia_,
   {{0x6d412eab,0x6f0850c8,0x290001a3,0x68edb2dd}},	//   gpla, rldc, koia_, ynad,
   {{0x7d16b2de,0xbfc601d3,0x66c0b2b9,0x6281023a}},	//   _chys, _обек, _köks, _zblo,
   {{0x68e400be,0xf8bf0453,0x68ed2433,0x711b0070}},	//   diid, _bién_, vnad, _וואפ,
   {{0x7d0409d6,0x00000000,0x00000000,0x00000000}},	//   _ekis, --, --, --,
   {{0x6d55006c,0x68edb2df,0x29000065,0x66c00282}},	//   ázat, tnad, foia_, _löks,
   {{0x8d83005f,0xdce20029,0x68edb2e0,0x23660207}},	//   _рушд, pulā, unad, kroj_,
   {{0x7c2db2e1,0x9715002d,0x00000000,0x00000000}},	// [d290] _igar, емац, --, --,
   {{0x68ed00f1,0x23660b43,0x7c2d0069,0x66e40200}},	//   snad, droj_, _hgar, вођа,
   {{0xa29f2064,0xe3b000d1,0x68ed3ee4,0x20ca01da}},	//   _गोष्, یره_, pnad, _rùin_,
   {{0x6281b2e2,0x66c01d0d,0x68e4013a,0x809e051d}},	//   _sblo, _sökt, ciid, _खोले,
   {{0x6d41067b,0x9cd8011d,0x673d0044,0x00000000}},	//   zpla, וואה_, _utsj, --,
   {{0x6d412e92,0x7c2d01f7,0xa29f021a,0x2bd00e11}},	//   ypla, _lgar, _गोश्, हनता,
   {{0x4ab007df,0x7c2d0096,0x00000000,0x00000000}},	//   ञातव, _ogar, --, --,
   {{0x7c2db2e3,0x2366003a,0x1fb51654,0x6d412ce0}},	//   _ngar, broj_, есор, vpla,
   {{0x6d41598f,0x20ca00f1,0x78bdaeda,0x81f901df}},	//   wpla, _iùil_, _mosv, _کفار_,
   {{0x6d41b2e4,0x7c2db2e5,0x1dca00a1,0x7d04b2e6}},	//   tpla, _agar, ानंत, _skis,
   {{0x7d1689e4,0x75290a75,0x1d0a547d,0x3f860107}},	//   _phys, _kiez, зени_, _epou_,
   {{0x55da02b5,0xeafa44d2,0x425300fd,0xa2b90167}},	//   פֿינ, ृत्त_, _سنچر, ्सक्,
   {{0x6d41b2e7,0x7529b2e8,0x442d2717,0x2900b2e9}},	//   spla, _miez, _mge_, voia_,
   {{0x6d415800,0x60c9b2ea,0x7529b2eb,0x7c2db2ec}},	//   ppla, lkem, _liez, _egar,
   {{0x442d00f1,0x2cab004f,0xfce6257f,0x13bd000c}},	//   _oge_, áidí_, _поко, ्नुभ,
   {{0x7529006a,0x26fa0266,0x442db2ed,0x7d042f6f}},	//   _niez, ्त्र_, _nge_, _ukis,
   {{0xfaa60e8b,0xb6a66305,0x68e4b2ee,0x2900b2ef}},	// [d2a0] _запо, ниал, riid, roia_,
   {{0x7c2d4776,0x442d7f64,0x60c92acd,0x68e4b2f0}},	//   _zgar, _age_, hkem, siid,
   {{0x7529b2f1,0x60c9b2f2,0x7bc6b2f3,0x290009c5}},	//   _biez, kkem, lyku, poia_,
   {{0x236615c2,0x20ca0284,0xe45221b6,0x2b400069}},	//   troj_, _cùil_, اضا_, _ktic_,
   {{0x7529b2f4,0x6abe01ae,0xf1d80461,0x439400c3}},	//   _diez, _kopf, _भेजन, талс,
   {{0x442d027d,0x23660031,0x236008b7,0x213e0023}},	//   _ege_, rroj_, šijo_, _ptth_,
   {{0x6ec30311,0x6f01027a,0x7ce800d0,0x00000000}},	//   ाउनु, dolc, nırs, --,
   {{0x2b400124,0x23660055,0x00000000,0x00000000}},	//   _otic_, proj_, --, --,
   {{0xb4be0240,0x6abe0345,0xfaff0055,0x2b4000a2}},	//   ेसी_, _oopf, drën_, _ntic_,
   {{0x7c2db2f5,0xfaff0055,0x75295eb8,0x2736008c}},	//   _sgar, erën_, _ziez, _mæn_,
   {{0x8ffa026b,0x2736008c,0x00000000,0x00000000}},	//   _کرار_, _læn_, --, --,
   {{0x629a5aef,0x60c903c1,0xe3a700b5,0x00000000}},	//   _hato, ckem, _تشہی, --,
   {{0x629ab2f6,0x9b580133,0x2b400176,0xddcb011c}},	//   _kato, ният_, _ctic_, ćišt,
   {{0x2f970122,0x629a06a2,0xd00f017e,0x2b404ede}},	//   _נכון_, _jato, _اله_, _dtic_,
   {{0x78bd0888,0x629ab2f7,0x3a2506d7,0x2b401ae2}},	//   _posv, _mato, älp_, _etic_,
   {{0x629ab2f8,0x6d5a3858,0x7c2db2f9,0x776d002a}},	//   _lato, msta, _ugar, tuax,
   {{0xe81c009a,0x7c840086,0xe733517b,0x67d40210}},	// [d2b0] पेला_, _суще, اصر_, готу,
   {{0x629ab2fa,0x6d5a030a,0x442d0211,0x66c0013c}},	//   _nato, osta, _sge_, _sökr,
   {{0x7529b2fb,0x6c6a0332,0xeef702b5,0x00000000}},	//   _piez, _علیہ_, עמבר_, --,
   {{0x7ae70124,0xe50700f8,0x629a023f,0x00000000}},	//   lijt, رباي, _aato, --,
   {{0xdfc61a95,0x75296db9,0x00000000,0x00000000}},	//   _ئي_, _viez, --, --,
   {{0x629ab2fc,0x6d5a15d6,0x91e57fdb,0x39410282}},	//   _cato, ksta, коле, _kths_,
   {{0xf8bf00e0,0x60c9b2fd,0x75295d50,0x00000000}},	//   _koé_, tkem, _tiez, --,
   {{0x629ab2fe,0x442d054e,0xceb80035,0x10a500af}},	//   _eato, _uge_, eję_, тиин,
   {{0x60c9247e,0x6d5ab2ff,0x629ab300,0xa28300d1}},	//   rkem, esta, _fato, _میشو,
   {{0x6d5a09ef,0x37e30083,0xa3ce0026,0xfbd70033}},	//   fsta, _মডার, शनर_, সপাত,
   {{0xdc6a2c4c,0xfaff01f4,0x2d9a0009,0xd1b24574}},	//   манд_, trën_, _šper_, _نیوک,
   {{0x7bc6006a,0x83fd00b5,0x249d016e,0x2b400116}},	//   tyku, _időb, ndwm_, _ptic_,
   {{0x6d5ab301,0x629a18a6,0x7ae70031,0x6f01b302}},	//   asta, _yato, fijt, polc,
   {{0x3d123e72,0xceb8006a,0x629a01f7,0x6d5ab303}},	//   _धीरे_, cję_, _xato, bsta,
   {{0xab273cf6,0x6d5ab304,0xfaff0031,0x29190118}},	//   тора_, csta, prën_, _bhsa_,
   {{0x09e10083,0x26d138c0,0x201800a8,0x7bc6005f}},	//   _মুহা, _alzo_, ərib_, pyku,
   {{0xc05202b5,0x7ae7007e,0x97c34d7e,0x00000000}},	// [d2c0] יזן_, bijt, айте, --,
   {{0xb8c90006,0x20ca0211,0x00000000,0x00000000}},	//   _गो_, _rùim_, --, --,
   {{0xbebc0228,0x20ca0211,0xd9463367,0x00000000}},	//   smīg, _sùim_, _шени, --,
   {{0x6d5c0082,0x629a75fa,0x09f702b8,0xa3ce10aa}},	//   árai, _sato, _ימים_, शनल_,
   {{0x693c024e,0x6d5a67bf,0x9393004f,0x7c290009}},	//   _učeb, zsta, لجوا, žerv,
   {{0x6d5ab305,0x629a0c6f,0x66d2008c,0xf8bfb306}},	//   ysta, _qato, _dækc, _zoé_,
   {{0x66e34b34,0xdb040051,0x6d5a542a,0xdb1d00b5}},	//   _тора, _arië, xsta, nysá,
   {{0x629a0657,0x2eca0785,0x6d5ab307,0x237606ee}},	//   _wato, िस्त, vsta, _لائح,
   {{0x6d5a004e,0x24070cd0,0x69c7004e,0x629a14bc}},	//   wsta, _анти_, zyje, _tato,
   {{0x4ea6218b,0x00000000,0x00000000,0x00000000}},	//   триа, --, --, --,
   {{0x6d5a061c,0x63a2b308,0xdb040023,0x42d500d8}},	//   usta, lvon, _triê, _сіту,
   {{0x13c60083,0x2369011c,0xceb80035,0x61fa02d7}},	//   _শেয়, šaje_, sję_, _ixtl,
   {{0x3f980029,0x00000000,0x00000000,0x00000000}},	//   ārus_, --, --, --,
   {{0x6d5ab309,0xaa640374,0x00000000,0x00000000}},	//   psta, итск, --, --,
   {{0x6d5a035f,0xa9c41397,0x7ae7b30a,0xdb1d00fd}},	//   qsta, астк, rijt, gysá,
   {{0x257c00b8,0xa3b201c0,0x98f40037,0x00000000}},	//   díl_, टमा_, لثقا, --,
   {{0x7ae764f4,0xf7701902,0x09e10033,0x00000000}},	// [d2d0] pijt, قال_, _মুশা, --,
   {{0x257c0037,0x63a20e82,0x00000000,0x00000000}},	//   fíl_, dvon, --, --,
   {{0x5694083e,0x1bab00b5,0x69c4021a,0x00000000}},	//   рахт, _راکٹ_, रहणी, --,
   {{0xe7de06d9,0xb87bb30b,0xe791027d,0xdb04000d}},	//   _नेकप, _zmín, _göğü, _ariè,
   {{0x2f19000d,0x628400cd,0xdb0400a2,0x25e300b4}},	//   lège_, đion, _briè, _टेरी_,
   {{0xe3b01d05,0x257c008d,0x00000000,0x00000000}},	//   ترم_, bíl_, --, --,
   {{0xa3e30ccf,0x45d50086,0x63a20223,0x2f1900a2}},	//   _फेर_, _совс, avon, nège_,
   {{0xd6c50083,0x320c016e,0x00000000,0x00000000}},	//   _এগিয, _dydy_, --, --,
   {{0x6459b30c,0x61fa03da,0x93f51ca4,0x443d0132}},	//   mawi, _extl, _спац, mcw_,
   {{0x0ccc057c,0x645927dc,0x1e95095d,0x20a30067}},	//   ास्म, lawi, урир, _खोरध,
   {{0x443f0009,0xacea1461,0x254a005f,0x00000000}},	//   _kfu_, емна_, _gėlę_, --,
   {{0x7e7e022a,0x7535b30d,0x6459b30e,0x00000000}},	//   _öppn, _muzz, nawi, --,
   {{0x7535b30f,0x31a3027d,0x443f1b68,0x66d20b3e}},	//   _luzz, _hız_, _mfu_, _læka,
   {{0x31a301d6,0x2d9504bf,0x6459288a,0x1c1a00b4}},	//   _kız_, _брис, hawi, नेगल_,
   {{0x6459b310,0x443fb311,0x63a21e85,0x75350036}},	//   kawi, _ofu_, zvon, _nuzz,
   {{0x6459004e,0x63a20987,0xddc80355,0x443f7728}},	//   jawi, yvon, jadř, _nfu_,
   {{0x0686081b,0x9d1b0d85,0xad1b0317,0xe8f707e5}},	// [d2e0] лган, _אוקט, _אוקר, улт_,
   {{0x7d06b312,0xdb04002a,0x443fb313,0x69130225}},	//   loks, _orié, _afu_, lçel,
   {{0x765502e9,0x4a7b02b5,0x64a67a34,0x7535b314}},	//   _dezy, _אריב, лажа, _cuzz,
   {{0x257c27ff,0x6459b315,0x443fb316,0x7d06b317}},	//   ríl_, gawi, _cfu_, noks,
   {{0x2ba70437,0xdb0400f7,0x443f0a8a,0x63a2b318}},	//   खिया, _priè, _dfu_, uvon,
   {{0x75357701,0x2d510a78,0x63a28f3f,0x05140033}},	//   _fuzz, kše_, rvon, িদের_,
   {{0x2d51108a,0x9186004f,0x69130225,0x7d0600c3}},	//   jše_, اجتم, kçel, koks,
   {{0x645900e0,0xc95300a5,0x00000000,0x00000000}},	//   cawi, זמה_, --, --,
   {{0x7d06b319,0x6d4300d8,0x03a34b4f,0x324630cc}},	//   doks, _atna, _лито, _безг,
   {{0x672e011e,0xb77b0070,0xb87b0952,0x752200fd}},	//   _jibj, עאיש, _amíl, lmoz,
   {{0x3d01009a,0x672e035f,0x408603c6,0x69dc00f4}},	//   रवले_, _mibj, _булб, jzre,
   {{0x672e009f,0x00000000,0x00000000,0x00000000}},	//   _libj, --, --, --,
   {{0x2a7a0168,0x3cdb073f,0x60c200f6,0x00000000}},	//   _bcpb_, खोगे_, _ioom, --,
   {{0x945d004e,0x64590035,0x7b190171,0x2f19000d}},	//   _końc, zawi, тогр_, tège_,
   {{0x48ab8408,0x7d06b31a,0x60c2b31b,0x76550035}},	//   нтам_, boks, _koom, _rezy,
   {{0x753552a2,0xa2a6021a,0x00000000,0x00000000}},	//   _ruzz, _टोस्, --, --,
   {{0x6288308b,0x672e0069,0x443f01ef,0x466b05e8}},	// [d2f0] _obdo, _bibj, _rfu_, ерем_,
   {{0x60c20006,0x6b8d0d0d,0x7c290690,0x693c02c4}},	//   _loom, _ipag, žers, _ičen,
   {{0x64597e45,0x85470012,0x81c90033,0x3197013b}},	//   tawi, уэзе, _লেন_, _təzə_,
   {{0xd50b0088,0xfc3f73dc,0x5c380070,0x60c2525a}},	//   رغان_, ncí_, ָרגן_, _noom,
   {{0x6459006a,0x20d8004f,0xdc3c0070,0xa85a00a5}},	//   rawi, _méid_, געדר, _בדרכ,
   {{0x6459010d,0x21691dd6,0x6b8d1815,0x20d10079}},	//   sawi, вики_, _mpag, _cáin_,
   {{0xfc3f00b8,0x31a30095,0x62830009,0x26c3005f}},	//   kcí_, _qız_, rfno, _iojo_,
   {{0x6b8d0036,0x2d5110ec,0x90c5081b,0x62880107}},	//   _opag, vše_, рбие, _ebdo,
   {{0xddda0187,0x98a500c7,0x7d06b31c,0x63b60421}},	//   latň, ūlė_, voks, äynt,
   {{0x63a9b31d,0x66d2008a,0x249f0189,0x0d850ffd}},	//   _iren, _lækn, _haum_, алон,
   {{0x249fb31e,0x7d0603ad,0x60c2006d,0x693c0009}},	//   _kaum_, toks, _foom, _ačen,
   {{0x63a92f6e,0x2d5171c6,0xe1f00bdf,0xce1800d8}},	//   _kren, rše_, _عسل_, ыцыі_,
   {{0x249f0221,0x9f6b01d3,0x2d98082b,0xc1040118}},	//   _maum_, _чрез_, ærer_, _اوني,
   {{0x212f0052,0x63a9b31f,0x249f49f2,0x776d0042}},	//   _high_, _mren, _laum_, drax,
   {{0x6d43b320,0x6b8d2ade,0x212f0211,0x69130381}},	//   _utna, _epag, _kigh_, pçel,
   {{0xfc320fab,0x249fb321,0x776d01dd,0x236000cd}},	//   _بحث_, _naum_, frax, šiji_,
   {{0x26c3b322,0xe7370382,0xa6e63821,0x66d208c8}},	// [d300] _bojo_, иет_, ажал, _dækn,
   {{0x2ca0b323,0x26c30453,0x00000000,0x00000000}},	//   _haid_, _cojo_, --, --,
   {{0x63a9b324,0x249f1f36,0xae0b0b54,0x212f0211}},	//   _aren, _baum_, _सुमन_, _oigh_,
   {{0x63a9b325,0x98a650f1,0x249f006f,0x776d0042}},	//   _bren, _тиме, _caum_, brax,
   {{0x249fb326,0x63a9b327,0x24070674,0xcc3b0070}},	//   _daum_, _cren, анци_, דענט,
   {{0x60c20006,0x63a9b328,0x809e0939,0x59ba021a}},	//   _soom, _dren, _खोजे, _उपार,
   {{0x63a9b329,0xd5b200b5,0x212f01da,0x249f009e}},	//   _eren, _ظفر_, _bigh_, _faum_,
   {{0x68f6001e,0x63a9ab7b,0x23690254,0x859b0d85}},	//   nnyd, _fren, šaja_, _בשלו,
   {{0x68f6001e,0x1eaa0037,0x212f009e,0x9998008b}},	//   inyd, نادي_, _digh_, jbrž_,
   {{0xeeaa0132,0x249f01a9,0x68f60260,0x212f01da}},	//   ттик_, _zaum_, hnyd, _eigh_,
   {{0x6b8db32a,0x63a90c99,0x60c2007c,0x249f0221}},	//   _spag, _zren, _toom, _yaum_,
   {{0x20180669,0x249f01e8,0x9b95b32b,0xfc3f0355}},	//   ərin_, _xaum_, бимц, ucí_,
   {{0xd01000d1,0x2912011e,0xfb870409,0x2ca03a23}},	//   _علت_, dlya_, шынн, _daid_,
   {{0xa3d70084,0xfc3f0037,0x0ead0253,0x6d5cb32c}},	//   ानत_, scí_, _झोपड, áras,
   {{0xdd8f026e,0x68f602c7,0x26c3b32d,0x39450173}},	//   _يوه_, fnyd, _rojo_, ëls_,
   {{0x776d0391,0xfce4015a,0x225c0009,0x2ca00211}},	//   trax, _мојо, havk_, _gaid_,
   {{0x7d0d03cb,0x693c02b2,0x249f2863,0x6135010b}},	// [d310] _ikas, _učen, _raum_, _išle,
   {{0x249f0189,0x776d1fdc,0x2ca0b32e,0xf647081b}},	//   _saum_, rrax, _zaid_, рхан,
   {{0x249f006d,0x66d2008a,0x63a900f8,0x2912ac18}},	//   _paum_, _tækn, _sren, blya_,
   {{0x249f006f,0x69c4000c,0x20d10037,0x776d02b1}},	//   _qaum_, रहरी, _cáil_, prax,
   {{0x68ed2651,0x03a5b32f,0x26c3b330,0x212f00f1}},	//   miad, сило, _tojo_, _righ_,
   {{0x68edb331,0x05770105,0x1308093e,0x69130225}},	//   liad, _پاسد, аній_, kçek,
   {{0x20d10082,0x7d0db332,0x70130083,0xf99402b5}},	//   _fáil_, _okas, _হলেও_, ַרץ_,
   {{0x68edb333,0x59ba035d,0x7d0db334,0x09f8011d}},	//   niad, _उपसर, _nkas, ימום_,
   {{0x92672abf,0x693c0009,0x63a9b335,0xc0c80274}},	//   _ندام, _ačel, _uren, рује_,
   {{0x7d0db336,0x2ca0b337,0x68ed001e,0x2eb5081b}},	//   _akas, _said_, hiad, ссис,
   {{0x68f60297,0xdca60923,0x212f0874,0x2ca000a5}},	//   ynyd, бани, _tigh_, _paid_,
   {{0x32d90107,0x212f01da,0x00000000,0x00000000}},	//   _dèye_, _uigh_, --, --,
   {{0x68edb338,0xa3d71bc6,0x2ca00006,0x8f6a006c}},	//   diad, ानि_, _vaid_, _ملنے_,
   {{0x644900a8,0x3ce90176,0xdde80118,0x7d0d36af}},	//   əmiş, _emav_, اریه_, _ekas,
   {{0x68ed0297,0x80db06d9,0x186a0272,0x00000000}},	//   fiad, _बताइ, лави_, --,
   {{0xa3d71db9,0x68edb339,0x60db03e6,0x68f600e9}},	//   ाना_, giad, nhum, unyd,
   {{0xbb860082,0x2fdf033b,0x386f0079,0x2fcd00b5}},	// [d320] _الخي, nzug_, ógra_, nyeg_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x94120095,0x1a9b02b5,0x68eda3db,0x60dbb33a}},	//   ədən_, _גייע, biad, khum,
   {{0x68ed1423,0x045a02de,0x69ce010b,0xa26600ee}},	//   ciad, اجات_, mybe, _mpôž,
   {{0x69ceb33b,0x60db002f,0xa3d20722,0x3f9d0051}},	//   lybe, dhum, हैं_, _nswu_,
   {{0x78a4b33c,0xf7430431,0xd5d61397,0x27e00009}},	//   ldiv, _херо, _любы, mzin_,
   {{0x6f080334,0x69ceb33b,0x765e081b,0x693c00f4}},	//   vodc, nybe, mapy, _očem,
   {{0x78a4b33d,0x27ed0bc6,0x60db043d,0x765e010b}},	//   ndiv, _ženi_, ghum, lapy,
   {{0x9ed8002d,0xd0100037,0xa9260097,0x00000000}},	//   имит_, بلة_, mažď, --,
   {{0x68edb33e,0x693c0254,0x68fb05e2,0x7d0db33f}},	//   ziad, _pčel, čudi, _skas,
   {{0xb80000c8,0xc04f1112,0x60db022e,0x6f0800d5}},	//   ্ধিত_, _ні_, bhum, rodc,
   {{0x6442b340,0x69130723,0x60dbb341,0x68ed0391}},	//   ncoi, rçek, chum, xiad,
   {{0x68ed1430,0x78a4a538,0x6f0800ac,0x10167407}},	//   viad, ddiv, podc, _اباد,
   {{0x68edb342,0x27e0004e,0x7c36006c,0x66d2008c}},	//   wiad, dzin_, _egyr, _bækm,
   {{0x68edb343,0x6ce71645,0x1959004b,0x27e05eb8}},	//   tiad, _гіпе, рабы_, ezin_,
   {{0x7d0db344,0x26d80139,0xf8bf0051,0x98c40432}},	//   _ukas, _alro_, _niét_, псул,
   {{0x68edb345,0x799e02d0,0x27e00051,0xaad10387}},	// [d330] riad, _espw, gzin_, _सकपक,
   {{0x68ed96c1,0xa3ac08a9,0x69ce8f33,0xd04000a8}},	//   siad, गिन_, bybe, rkmə,
   {{0x78a4518f,0x68ed0995,0x69ce0120,0x98be00ec}},	//   bdiv, piad, cybe, ūtā_,
   {{0x76490644,0x60db01e9,0xd1264dc0,0x00000000}},	//   _şeyd, xhum, _زم_, --,
   {{0xd00614ac,0x987a02b5,0x7cef02d0,0xf8bf0168}},	//   _آل_, _דארט, _zòrè, _diét_,
   {{0x2369008b,0x00000000,0x00000000,0x00000000}},	//   šajo_, --, --, --,
   {{0xa4d500d4,0x68fd0345,0xe5c40153,0x00000000}},	//   _дові, _kjsd, _есто, --,
   {{0x2b490a78,0x00c90b25,0x20d10037,0xdce200ea}},	//   _otac_, рлик_, _táim_, rtlī,
   {{0xdc2900ee,0x2b49023c,0x00000000,0x00000000}},	//   _bôči, _ntac_, --, --,
   {{0x60dbb346,0x4d65b347,0x59c904e9,0xdb040453}},	//   shum, оков, रहार, _prií,
   {{0xed5903fa,0x78a428c3,0x27e02461,0x2b49b348}},	//   јом_, ydiv, zzin_, _atac_,
   {{0x7fd51728,0x69ceb349,0x1d0a48b9,0x00000000}},	//   _мілі, vybe, реми_, --,
   {{0x78a40187,0xf8bf0248,0xf8b800cc,0x00000000}},	//   vdiv, _liés_, _đĩ_, --,
   {{0x645b009e,0x69ce00c7,0x201d04fb,0x00000000}},	//   _leui, tybe, _izwi_, --,
   {{0x7c3b0506,0x78a400ec,0x19b928fa,0xde021d77}},	//   žura, tdiv, буть_, _опши,
   {{0x27e0b34a,0x645bb34b,0x7aee006d,0x69cea09a}},	//   tzin_, _neui, sibt, rybe,
   {{0xeb9a0423,0x46ea2142,0x78a4b34c,0x69ce0409}},	// [d340] _тип_, адан_, rdiv, sybe,
   {{0x78a4008c,0x320001fb,0x273f099e,0x00000000}},	//   sdiv, şiyi_, _dîn_, --,
   {{0x765e05ae,0x66d2008a,0xfc3f0b4c,0xdb040132}},	//   rapy, _hækk, ldía_, _triâ,
   {{0x645b0211,0x83fd00b5,0x66d2008c,0xf8bf0312}},	//   _ceui, _időj, _kækk, _chéd_,
   {{0x693c3479,0xfc3f0caa,0x3860b34d,0x645b4373}},	//   _oček, ndía_, mair_, _deui,
   {{0x3860b34e,0x644235c9,0x248d0051,0xfc3f0042}},	//   lair_, scoi, _ebem_, idía_,
   {{0xd2590560,0x645bb34f,0x66d27fdd,0x201d007b}},	//   сці_, _feui, _lækk, _azwi_,
   {{0x3860b350,0xf48600b5,0x645b32c5,0xf8bf0345}},	//   nair_, _گاڑی, _geui, _hiér_,
   {{0x60f700d8,0xb60200b8,0x20ca009e,0x7764002a}},	//   ўныя_, řádn, _bùir_, nsix,
   {{0x3860006e,0x66d2008a,0x69c100b9,0x610100ea}},	//   hair_, _sækj, älek, vēle,
   {{0xf8bf00de,0x765cb351,0x6298b352,0x25a500b5}},	//   _miér_, _mery, mevo, _állt_,
   {{0x628a00e9,0x66d20b3e,0xa6db008d,0x753c0abe}},	//   lffo, _bækk, _guðf, _murz,
   {{0x3860b353,0xd0f902b5,0x613500d8,0x753c01a3}},	//   dair_, _פּער, _išla, _lurz,
   {{0x66d201b4,0x765cb354,0x32cb0185,0x2d854c19}},	//   _dækk, _nery, _høyr_, btle_,
   {{0x273f016e,0x09e10033,0x32cb0044,0x66d2008d}},	//   _sîn_, _মুজা, _køyr_, _tækj,
   {{0x3860b355,0x765c0260,0x6b840024,0x66d2008d}},	//   gair_, _aery, _fqig, _fækk,
   {{0x14ab0266,0x765cb356,0xb8e300b4,0x66d2008c}},	// [d350] _घोषण, _bery, _एच_, _gækk,
   {{0x62981002,0x645b00f7,0x765c016e,0x628a02a2}},	//   jevo, _seui, _cery, jffo,
   {{0x753cb357,0x6298b358,0xc56b0105,0x3860b359}},	//   _curz, devo, شحال_, bair_,
   {{0x3860b35a,0x628a0051,0xf8bf0183,0x00000000}},	//   cair_, effo, _viés_, --,
   {{0x645b02e1,0x6aa5046a,0xd7f80c90,0x765cb35b}},	//   _veui, _kahf, _дур_, _fery,
   {{0x62980d26,0x95cb0854,0xe29921d7,0xdb9c0070}},	//   gevo, _куба_, сак_, יסדר,
   {{0x645b00e0,0x6aa557fc,0x248d91ea,0x6d4a0024}},	//   _teui, _mahf, _tbem_, _ntfa,
   {{0x673db35c,0x00000000,0x00000000,0x00000000}},	//   _kusj, --, --, --,
   {{0xa2a600dc,0x73d90e05,0x6298b35d,0x66d2008c}},	//   _टोक्, _удар_, bevo, _bækh,
   {{0x76450602,0x2d850052,0xd2510082,0x6298b35e}},	//   nchy, ttle_, _أنا_, cevo,
   {{0xdca66058,0x3860046a,0x673d0051,0xb0350012}},	//   пани, yair_, _lusj, _енеш,
   {{0xd48f0044,0x7c3b2cf6,0x38600069,0xeb9ab35f}},	//   ерi_, žurn, xair_, бим_,
   {{0x386001f7,0x2d85b360,0xf3f90139,0x239d0107}},	//   vair_, stle_, _feţe_, _jňj_,
   {{0xa3ac22a7,0xfc3f1111,0xfaff01f4,0x673546da}},	//   गित_, rdía_, drës_, _nizj,
   {{0x3860b361,0x6281b362,0x7e61623b,0x764500ac}},	//   tair_, _mclo, malp, dchy,
   {{0x765cb363,0x673d6b11,0x7645016e,0xe2070067}},	//   _sery, _busj, echy, ciół_,
   {{0x3860b364,0x765cb365,0x96960652,0x6735518c}},	// [d360] rair_, _pery, зреш, _bizj,
   {{0x386009c3,0x7e61b366,0xfc3f8405,0x673d0044}},	//   sair_, nalp, ndín_, _dusj,
   {{0x80db0e1d,0x1dcb0266,0x765ca09a,0x2a570122}},	//   बसाइ, ाहित, _very, _מבין_,
   {{0xa3d70099,0x765cb367,0x19bb00a5,0xfaff0055}},	//   ानं_, _wery, _המטב, brës_,
   {{0x7e610080,0x6298b368,0x753c033b,0x765c1c95}},	//   kalp, tevo, _wurz, _tery,
   {{0x753cb369,0x6281009e,0x2541005f,0x00000000}},	//   _turz, _cclo, _gėlo_, --,
   {{0x78a6326f,0x6298b36a,0x628a0297,0x2905008a}},	//   _kakv, revo, rffo, élag_,
   {{0x64a39222,0x4034b36b,0x318e00a8,0x00000000}},	//   _паса, мейс, _cəza_, --,
   {{0x20d80514,0x6298b36c,0x20020095,0xa3d7b36d}},	//   _féin_, pevo, çki_, ानः_,
   {{0xe8040035,0x7e61b36e,0x62810079,0x6125008d}},	//   _रखना_, galp, _gclo, jólf,
   {{0x2019003e,0x5d630043,0x00000000,0x00000000}},	//   ýsir_, нтяз, --, --,
   {{0x78a600c7,0x98ab00af,0x225e00be,0xed4d00fd}},	//   _nakv, _mică_, _hetk_, جھو_,
   {{0x6b9d01e4,0x66d3027d,0x98ab0160,0x23660c6f}},	//   uwsg, _yıkı, _lică_, nsoj_,
   {{0x7e6102d7,0x8f9b011d,0x61250093,0x673d023a}},	//   calp, _לידי, gólf, _rusj,
   {{0x673d0c21,0x78a629fc,0xbd875b16,0x98ab0160}},	//   _susj, _bakv, _فنون_, _nică_,
   {{0x23660031,0xfaff0031,0x00000000,0x00000000}},	//   ksoj_, trës_, --, --,
   {{0x213e0ac8,0x76450107,0x473500d8,0x6aa500d7}},	// [d370] _luth_, tchy, днас, _tahf,
   {{0xdb0407a6,0xfaff01f4,0x26ca01cb,0x1a650088}},	//   _triá, rrës_, _cobo_, _زیری_,
   {{0x7645001e,0xfc3f0138,0x213e0223,0x98ab0395}},	//   rchy, ndío_, _nuth_, _cică_,
   {{0x66d301d6,0x661500b8,0xe4e41958,0x764501ff}},	//   _sıkı, _vyzk, нічн, schy,
   {{0xa7fb01ed,0x20d8009e,0x90d500cc,0x00000000}},	//   _beñe, _péin_, _bùn, --,
   {{0x41b50210,0xf2c71385,0xb87b002a,0x213e01da}},	//   дсит, ясен, _emít, _buth_,
   {{0x26fb0c57,0x6594b36f,0x7e61b370,0xc69232e3}},	//   ्वीर_, _пару, valp, _שאל_,
   {{0x213e009e,0xb46500f8,0x2ed507df,0x318e00a8}},	//   _duth_, _آگاه, धस्त, _qəza_,
   {{0x7e61b371,0xb87b021d,0x98ab0139,0x00000000}},	//   talp, _ilíd, _zică_, --,
   {{0xef160086,0xe3b005bc,0xb87b00b8,0x7e610009}},	//   ммы_, _حرف_, _hlíd, ualp,
   {{0xfc3fb372,0x213e09c3,0x7e614f5d,0xb87b00d5}},	//   rdín_, _guth_, ralp, _klíd,
   {{0x2d671269,0x7e61b373,0xe3e40033,0xa7fb0065}},	//   rđe_, salp, _ফুটব, _zeñe,
   {{0xef0e09eb,0x7e61010d,0x78a6007c,0x6913027d}},	//   _ам_, palp, _rakv, hçes,
   {{0xed590202,0x69130225,0x66d2008a,0xb4ba1140}},	//   _док_, kçes, _tæki, _अच्_,
   {{0x26cab374,0x78a6010b,0x644903d0,0x7d0f00fd}},	//   _robo_, _pakv, _ofei, bocs,
   {{0x3ea70009,0x693c0254,0x80c00066,0x26cab375}},	//   _hant_, _očev, वाये, _sobo_,
   {{0xf7720082,0x3ea70fdb,0x59ba004e,0x26ca043f}},	// [d380] ضاء_, _kant_, _उपकर, _pobo_,
   {{0x60cb0b3e,0x64491bea,0x61250093,0xa3ac0066}},	//   _logm, _afei, bólg, गिस_,
   {{0x78a65317,0x60cb2069,0xa92654d0,0x3ea70107}},	//   _takv, _oogm, _одол, _mant_,
   {{0x26ca0c1f,0x60cb28e9,0xb87b0176,0x3ea7b2fc}},	//   _wobo_, _nogm, _clíd, _lant_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64490370,0xd24f026e,0x3ea700e9,0x610100ea}},	//   _efei, لنه_, _nant_, vēla,
   {{0x60cbb376,0x6449001e,0xa7fb01dd,0xdb0401f7}},	//   _bogm, _ffei, _veñe, _eriç,
   {{0x3ea70051,0xa6db0093,0x20d8021d,0x00000000}},	//   _aant_, _guðb, _véio_, --,
   {{0xa7fb1a71,0x60cbb377,0xe2920bdf,0x3ea7b378}},	//   _teñe, _dogm, _لذا_, _bant_,
   {{0x20180080,0x03230043,0x3ea72954,0x00000000}},	//   āri_, _адун, _cant_, --,
   {{0x3ea700e5,0x8af700a8,0x6b9600c7,0x69c8b379}},	//   _dant_, şəka, _apyg, ädel,
   {{0xfc3f20d9,0x60cb005f,0x00000000,0x00000000}},	//   rdío_, _gogm, --, --,
   {{0x9b5802fb,0x800800b5,0x3ea7b37a,0xc5f80228}},	//   мият_, _عرصہ_, _fant_, _žēl_,
   {{0x3ea7b37b,0x5f930210,0x00000000,0x00000000}},	//   _gant_, _ришт, --, --,
   {{0xa2d6012f,0x20d8004f,0xdb0d00f7,0xdce200ea}},	//   _भवन्, _léim_, _fraî, gulē,
   {{0x25f497c4,0x23690ce9,0xe894010b,0x00000000}},	//   ्पनी_, šaji_, кась, --,
   {{0x2126009e,0x290200fe,0xfc3f00d5,0x00000000}},	// [d390] _mhoh_, _djka_, ndím_, --,
   {{0x4a5500d4,0xfc3f00b8,0x20d10079,0x21260118}},	//   _якос, zdíl_, _háit_, _lhoh_,
   {{0xa2c20edf,0x6449033b,0xaaa800ab,0x2ca9b37c}},	//   लान्, _pfei, _छोटक, _kaad_,
   {{0x245801c8,0x20d80037,0x00000000,0x00000000}},	//   даць_, _béim_, --, --,
   {{0xe667117a,0x20d80037,0x2ca900be,0x69d58235}},	//   _отво, _céim_, _maad_, lyze,
   {{0x2ca97153,0x66d20093,0xe8040067,0x39410103}},	//   _laad_, _bæku, _रखता_, _kuhs_,
   {{0xb87b01c0,0x00000000,0x00000000,0x00000000}},	//   _umís, --, --, --,
   {{0x3a380052,0x3ea7b37d,0x212600d7,0xdbc70225}},	//   ורום_, _sant_, _choh_, _göçm,
   {{0x43750312,0x00000000,0x00000000,0x00000000}},	//   _سهار, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d72218,0x3ea7b37e,0x2ca9023c,0xc6920070}},	//   ानक_, _vant_, _baad_, נאט_,
   {{0x3ea70052,0x98ac00ea,0xeb9a538c,0xa15600a5}},	//   _want_, īdī_, пим_, _נבנה_,
   {{0x3ea7b37f,0x2ca9b380,0xaed50328,0x00000000}},	//   _tant_, _daad_, _подш, --,
   {{0xbea2b381,0x693c008b,0x7af5107f,0x00000000}},	//   _башк, _očet, gizt, --,
   {{0x09e62846,0xc5fa0083,0x682a006c,0xf2d20070}},	//   ховн, _অর্থ_, ködé, נעל_,
   {{0x98a30e9f,0xf53900ee,0x00000000,0x00000000}},	//   лисе, _niť_, --, --,
   {{0x31106ff9,0xcb6a00f8,0xc5fa0d34,0x7d0404fb}},	// [d3a0] ावतः_, _عمده_, ्थ्य_, _ijis,
   {{0x3ce0006d,0xa3b30fbf,0x7c24b382,0x20d80079}},	//   _hliv_, टिन_, _izir, _réim_,
   {{0x69c100ab,0xe7f000dc,0x610100ea,0xf5390168}},	//   älet, _घेरा_, vēln, _biť_,
   {{0x20d14a07,0xe73a00c3,0x290202c4,0x00000000}},	//   _máis_, _нем_, _ujka_, --,
   {{0x883b0122,0xc1c80355,0x98160c9e,0x28a90084}},	//   _מתכו, िङ्ग, _سبحا, _चोटि,
   {{0xf1a6431b,0x68e4b383,0x212601f4,0x29002130}},	//   ерин, lhid, _shoh_, lnia_,
   {{0x049600d8,0x3ce00359,0x613502c4,0x29002119}},	//   _праў, _oliv_, _išlj, onia_,
   {{0x7c2402c6,0x2900b384,0xb87b1430,0x71f70037}},	//   _ozir, nnia_, _ilíc, عروس_,
   {{0xd252004f,0x7c243d10,0x2ca90136,0x2900b385}},	//   _منذ_, _nzir, _raad_, inia_,
   {{0x15f40d55,0x2ca9b386,0x7d04b387,0x610801c0}},	//   _आधार_, _saad_, _ajis, děle,
   {{0x29120103,0x20d600d4,0x3ce0054e,0x68e400d7}},	//   koya_, _підс, _bliv_, khid,
   {{0xa7fb0138,0x21260345,0x00000000,0x00000000}},	//   _leña, _uhoh_, --, --,
   {{0x29002510,0x68e4a290,0x63a2b388,0x29123ad3}},	//   dnia_, dhid, nwon, doya_,
   {{0x2900006a,0x7c240029,0xf8bf0023,0x83fd00b5}},	//   enia_, _dzir, _chén_, _időt,
   {{0x20d10037,0x2900008c,0x7de652d5,0x7c2401a8}},	//   _gáis_, fnia_, _désé, _ezir,
   {{0xa3e00380,0x2900b389,0x63a2b38a,0x68e4184f}},	//   दना_, gnia_, kwon, ghid,
   {{0xb87b01f7,0xa7fb01a3,0x7c240024,0x44240207}},	// [d3b0] _alíc, _beña, _gzir, _nzm_,
   {{0x2900b38b,0x7d1daeff,0x7d0401c0,0x68e4002f}},	//   ania_, llss, _zjis, ahid,
   {{0x68e4b38c,0x63a2ada7,0x66d20093,0xf53907c0}},	//   bhid, ewon, _rækt, _piť_,
   {{0x693c01c0,0xdb040107,0x68e4b38d,0x63a20051}},	//   _včet, _asiè, chid, fwon,
   {{0x03a5294d,0xd414010b,0x00000000,0x00000000}},	//   тило, льшы, --, --,
   {{0x78adb38e,0xe296075c,0xf8bf0019,0x66d20b3e}},	//   ldav, ваш_, _khéo_, _dæks,
   {{0x27e90024,0xb87b002a,0x693c008b,0x80aa0033}},	//   lzan_, _glíc, _hčer, কান্,
   {{0x78adb38f,0x63a2010a,0x27e900f4,0x693c0207}},	//   ndav, bwon, ozan_, _kčer,
   {{0x443f023a,0x27e9b390,0x64590010,0x600901e0}},	//   _igu_, nzan_, mbwi, ьним_,
   {{0x7d16b391,0x59b30d91,0x2900b392,0x3ce00478}},	//   _skys, ुमार, znia_, _sliv_,
   {{0x1d0a16fb,0xfce678bd,0x3ce0006d,0x29002200}},	//   дени_, воно, _pliv_, ynia_,
   {{0x23690a78,0x764906d3,0xdb0d0079,0xcb6a0dee}},	//   šaju_, _şeyl, _draí, маме_,
   {{0x83fd006c,0x60db002f,0x6283011e,0x3ce000b8}},	//   _idős, mkum, ogno, _vliv_,
   {{0x68e4b393,0x78bd0b87,0x60c9b394,0x29000035}},	//   whid, _ansv, ljem, wnia_,
   {{0x68e40874,0x3f8db395,0x29002e2f,0x29123d13}},	//   thid, lteu_, tnia_, toya_,
   {{0xa7fb0083,0x60db1487,0x14dd00dc,0x443fb396}},	//   _seña, nkum, _मतगण, _ngu_,
   {{0xa6860c14,0x6d43b333,0x2912b397,0x3f8d0310}},	// [d3c0] клад, _huna, roya_, nteu_,
   {{0x6d43b398,0x68e4b399,0x5b7b02b8,0x39460086}},	//   _kuna, shid, _קריא, _иног,
   {{0x60dbb39a,0x64a62351,0x7e6301d7,0x7ce601ef}},	//   kkum, кажа, _menp, _córg,
   {{0x6d43b39b,0x385a006c,0x443f2c6b,0x63a2a56c}},	//   _muna, _تشدد_, _cgu_, twon,
   {{0x6d43b39c,0x31da0632,0xd467551f,0xa7fb0391}},	//   _luna, बन्ध, тиче_, _teña,
   {{0x7e630c1f,0x63a2b39d,0x66d201b4,0xb87b002a}},	//   _nenp, rwon, _væks, _ilía,
   {{0x693cb39e,0x63a212ba,0x753b021d,0x00000000}},	//   _učes, swon, _fiuz, --,
   {{0x7529b39f,0x7c3b011c,0x63a2b3a0,0x60db2326}},	//   _ghez, žuri, pwon, gkum,
   {{0x673c9c26,0x7f4201ef,0x03a322a9,0x68e3002d}},	//   _kirj, _quoq, _кито, _înde,
   {{0x6d43b3a1,0x78ad0bc5,0x661c01bc,0x7f8300b5}},	//   _buna, zdav, _kyrk, گلین,
   {{0x27e91ba3,0x867b0122,0x60db028b,0x6d4401ba}},	//   zzan_, וריו, bkum, _čias,
   {{0x6d430b04,0x7ce6b278,0x661c52ff,0x60db1e2e}},	//   _duna, _nórd, _myrk, ckum,
   {{0x7d1d029b,0x78ad616f,0x1eca02ee,0x6d4301ed}},	//   rlss, vdav, _олди_, _euna,
   {{0xdb0d2de1,0x67da0029,0x7e63008c,0x39a300ee}},	//   _traí, _mājā, _genp, _pŕs_,
   {{0x6d438ec9,0xb87b002a,0x661c0421,0x00000000}},	//   _guna, _alía, _nyrk, --,
   {{0x7ce6b3a2,0x27e906a2,0x20180095,0x673c0069}},	//   _córd, tzan_, ərir_, _airj,
   {{0x78ad5616,0x6d4302c6,0x673cb3a3,0x61250079}},	// [d3d0] rdav, _zuna, _birj, nóla,
   {{0xe71900ad,0x443fb3a4,0x60db00b8,0xfd1f0036}},	//   ريات_, _sgu_, zkum, llì_,
   {{0x693c1834,0x673c00e7,0xcfd60033,0xb87b6188}},	//   _včer, _dirj, _তেমন, _elía,
   {{0x6125008a,0x661c03db,0xa6db0093,0x00000000}},	//   kóla, _dyrk, _guðn, --,
   {{0xdfc62e63,0xf8bf016f,0x38690c7c,0x753b0036}},	//   _اي_, _iné_, maar_, _viuz,
   {{0x38690903,0x9f9c008a,0x6135010b,0x673c0069}},	//   laar_, _ræða_, _išli, _girj,
   {{0x7e6802d7,0x628303d0,0x7e6383fe,0x60db6f5e}},	//   dadp, rgno, _renp, tkum,
   {{0x443f026e,0x6d43b3a5,0x38690903,0x7e630913}},	//   _ugu_, _runa, naar_, _senp,
   {{0x6d4365fc,0x60c90388,0x776d0391,0x60dbb3a6}},	//   _suna, rjem, nsax, rkum,
   {{0x6d43b3a7,0x63a9b3a8,0xfe71004f,0x3f8db3a9}},	//   _puna, _isen, حدة_, rteu_,
   {{0x38690d26,0x26d127c2,0x3f8d0d99,0x4155052c}},	//   kaar_, _mozo_, steu_, _свес,
   {{0x386909a6,0x7e630298,0x6d4300f4,0x5596016b}},	//   jaar_, _wenp, _vuna, נדרע_,
   {{0xd1100127,0xf8bf0019,0x7e6301d7,0x38690fdb}},	//   ावरण_, _chém_, _tenp, daar_,
   {{0x6d43774f,0xf8bf23e2,0x7ce6171c,0x63a9034d}},	//   _tuna, _ané_, _sórd, _msen,
   {{0x09e305c2,0x6d4308dd,0x00000000,0x00000000}},	//   борн, _uuna, --, --,
   {{0x673cb3aa,0x4c8605e8,0x63a9b3ab,0x386901bf}},	//   _sirj, _слив, _osen, gaar_,
   {{0x63a9b3ac,0x673cb3ad,0xdd0400ea,0xb8dc0354}},	// [d3e0] _nsen, _pirj, šsēd, _आफ_,
   {{0x661c00c3,0x00000000,0x00000000,0x00000000}},	//   _pyrk, --, --, --,
   {{0x63a9b3ae,0x38690a45,0x44220e9d,0xa2c28344}},	//   _asen, baar_, _šk_, लास्,
   {{0x98ba0012,0x938a0ece,0xf8bf0037,0xe97b0070}},	//   _după_, еска_, _gné_, _אנטש,
   {{0x667403c5,0x673c3ed9,0x63a900b5,0x62880132}},	//   _نگار, _tirj, _csen, _pcdo,
   {{0x610800b8,0x661c7e8b,0x37cd0033,0x63a90044}},	//   děla, _tyrk, _রেকর, _dsen,
   {{0x87072aa5,0xd62701f2,0x7e682586,0x00000000}},	//   _серв_, _боре_, vadp, --,
   {{0x2edc000c,0x6ad10e6f,0x1f7401af,0x26d10260}},	//   यस्त, _सक्र, алия, _zozo_,
   {{0xdfd00c74,0x8406010b,0x00000000,0x00000000}},	//   زيد_, _спаж, --, --,
   {{0x539b0122,0x83fd006c,0x2a6a00b5,0x612500b5}},	//   _אימו, _időp, jabb_, róla,
   {{0xdd9400c7,0xa3ac111a,0x02d54c16,0x067b016b}},	//   шаны, गिक_, _тютю, ענטל,
   {{0xd00f00e0,0x13d800c8,0xc5f300a5,0xb87b0132}},	//   _کله_, _দেয়, מדת_, _alín,
   {{0x38691516,0xfd1f0382,0x7e6808dd,0x00000000}},	//   vaar_, rlì_, padp, --,
   {{0xa7fb09ab,0x3869152b,0x0ed800fd,0x32d9021e}},	//   _seño, waar_, _جاؤں_, _pèyi_,
   {{0x3869b3af,0x318e0095,0x6b8f011e,0xa7fb02d7}},	//   taar_, _bəzi_, stcg, _peño,
   {{0x3eaeb3b0,0x98ba0139,0x26d100ee,0x00000000}},	//   _haft_, _rupă_, _sozo_, --,
   {{0x3869152b,0x26d11111,0x25aab3b1,0xf7700037}},	// [d3f0] raar_, _pozo_, _asbl_, كال_,
   {{0x776d0024,0xa3b30fcf,0x386900ab,0x63a90009}},	//   rsax, टिस_, saar_, _rsen,
   {{0x80ba009a,0x63a90273,0x07082d82,0x00000000}},	//   _शोभे, _ssen, ديلي_, --,
   {{0xb87b00b8,0xa8a71583,0xdb160107,0xddc100af}},	//   _zlín, _срок, _aryè, lalţ,
   {{0x3cfd0299,0xd7fb1309,0x62650210,0xb4640185}},	//   _लगने_, _чун_, авла, скіл,
   {{0xe299b3b2,0x321e024e,0x6125004e,0x877a0070}},	//   так_, _byty_, góln, _באשי,
   {{0xd49b0a93,0x00000000,0x00000000,0x00000000}},	//   _пра_, --, --, --,
   {{0xdfd10082,0x63a9b3b3,0x2a6a00b5,0x7ce60079}},	//   قيع_, _tsen, zabb_, _mórc,
   {{0x6d4eafe5,0x828721a0,0x00000000,0x00000000}},	//   íban, _مجال, --, --,
   {{0x0cde022e,0x877c0070,0x273800a8,0x00000000}},	//   मस्म, גאזי, tünə_, --,
   {{0xa2c20ebd,0x6cc67543,0xf2c41172,0xe81c046c}},	//   लार्, айна, _устн, _भुना_,
   {{0x6125b278,0x78af00ac,0x00000000,0x00000000}},	//   mólo, _nacv, --, --,
   {{0xb87b51ac,0x612520d9,0x00000000,0x00000000}},	//   _plín, lólo, --, --,
   {{0xab2a0f27,0x00000000,0x00000000,0x00000000}},	//   тога_, --, --, --,
   {{0x61250995,0xb87b0098,0x78af0207,0x00000000}},	//   nólo, _clío, _bacv, --,
   {{0x2a6a006c,0xb87b0079,0x00000000,0x00000000}},	//   sabb_, _dlío, --, --,

   {{0xb8fe103f,0x974800b5,0x966600c3,0x1666408d}},	// [d400] _तक_, اثرہ_, икае, ивам,
   {{0xe9da1761,0x61350409,0xf6564747,0x00000000}},	//   _ако_, _išlu, ртаю, --,
   {{0xa6db008a,0x7afcb3b4,0x546a7ce3,0x7a7b0317}},	//   _guðm, mirt, ваем_, _בריס,
   {{0x7afc0723,0x612502d7,0x00000000,0x00000000}},	//   lirt, dólo, --, --,
   {{0x2486b3b5,0x33f603e6,0x69dc72e9,0x68e300af}},	//   rgom_, јчес, lyre, _înda,
   {{0x66e601b8,0x78a400d8,0x05260033,0x00000000}},	//   _тога, leiv, যদের_, --,
   {{0x64a60760,0x69dc27c3,0x20000139,0x00000000}},	//   _кава, nyre, _ţii_, --,
   {{0xc9531899,0xa3b31343,0x21102095,0x00000000}},	//   חמה_, टिश_, ावेश_, --,
   {{0x6125004e,0x7afcb3b6,0x69dc2f39,0x764900c1}},	//   póln, kirt, hyre, _şeyi,
   {{0x7522b3b7,0xa3b33211,0x69dc0065,0x00000000}},	//   lloz, टिर_, kyre, --,
   {{0x61257397,0x7afcb3b8,0x10a63cc0,0x752200f4}},	//   cólo, dirt, _виен, oloz,
   {{0x69dcb3b9,0x75220223,0x00000000,0x00000000}},	//   dyre, nloz, --, --,
   {{0x60c2b3ba,0x8f540ca8,0x78a4005f,0x799e0160}},	//   _inom, _انتش, deiv, _appw,
   {{0x3f84b3bb,0x6e9414ac,0x7afcb3bc,0x610100ea}},	//   mumu_, _طلبا, girt, vēli,
   {{0x5d840082,0x3f84b3bd,0x7522b3be,0x00000000}},	//   _العل, lumu_, kloz, --,
   {{0x6d5a2c5e,0x7afc02a8,0xdb0d0279,0x91fc00ea}},	//   mpta, airt, _oraç, _reāl,
   {{0x7afcb3bf,0x3f84b3c0,0x752200cd,0x6d5a0139}},	// [d410] birt, numu_, dloz, lpta,
   {{0xc9871283,0x7afcb3c1,0x4545004f,0x69dc082b}},	//   _куми, cirt, منطق, byre,
   {{0xdb0d01d6,0x60c22e5b,0xc50b006c,0x3f84b3c2}},	//   _araç, _onom, پتال_, humu_,
   {{0x3f84b3c3,0x451802ce,0x78a49eb5,0xdb0db3c4}},	//   kumu_, ація_, ceiv, _braç,
   {{0x3f840ae0,0x889a0397,0x07a400d8,0x7bddb3c5}},	//   jumu_, _גברי, _даўн, nysu,
   {{0x60c2b3c6,0x3f84b3c7,0x61251111,0xa3ac046c}},	//   _anom, dumu_, tólo, गिज_,
   {{0xd24e0037,0xe0570e3a,0x4429016f,0xfa78011d}},	//   رني_, لیات_, ťa_, בעות_,
   {{0x27ed0076,0x61250300,0xdb0d2e38,0x850500b5}},	//   _ženy_, rólo, _fraç, _اورن,
   {{0x3f84b3c8,0xef1901d3,0xdb0d03e6,0xfc3f0079}},	//   gumu_, лми_, _graç, idís_,
   {{0x0d85020a,0x63bbb3c9,0x60c2942e,0x81890ae7}},	//   блон, _irun, _enom, _منطق_,
   {{0x7afcb3ca,0xdc6a0948,0xbbd006fe,0x290b0067}},	//   virt, ланд_, सङ्क, _ojca_,
   {{0x63bb641e,0x3f84b3cb,0x7afc01ae,0x2b410107}},	//   _krun, bumu_, wirt, _aihc_,
   {{0x7ce6004f,0x7afc3b84,0xdd8e0088,0x3f84b3cc}},	//   _córa, tirt, ووی_, cumu_,
   {{0x69dcb3cd,0x75221321,0x7c2800a8,0x63bb034d}},	//   tyre, zloz, ədrl, _mrun,
   {{0xf2d200c2,0x7afc00fb,0x3ea58cf5,0x09e30dbf}},	//   לעך_, rirt, melt_, порн,
   {{0x7ce60514,0x2d85b3ce,0x63bb030d,0x26c30279}},	//   _fóra, mule_, _orun, _anjo_,
   {{0x7afcb3cf,0x78a46164,0x69dc0075,0x3cfd0461}},	// [d420] pirt, reiv, syre, _लगते_,
   {{0x3ea5b3d0,0x69dc03d0,0x69c8b3d1,0x78a4026b}},	//   nelt_, pyre, ädes, seiv,
   {{0x2d857259,0x63bb0144,0xfad70070,0x41a60035}},	//   nule_, _arun, _הויך_, _कैंस,
   {{0x20d80082,0xdb0d03e6,0x3ea5b3d2,0x26c30118}},	//   _léir_, _praç, helt_, _enjo_,
   {{0x2d85b3d3,0x38602ed3,0xd91b0122,0x3ea527fe}},	//   hule_, mbir_, _תוכל, kelt_,
   {{0x2d85b3d4,0x3f84b3d5,0x6d5ab3d6,0x39b8034a}},	//   kule_, vumu_, ypta, _kčs_,
   {{0xd13000f5,0x63bb030d,0x3ea5961a,0x216703fa}},	//   ومت_, _erun, delt_, бији_,
   {{0x3f84b3d7,0x63bbb3d8,0xdb0db3d9,0x9f5415dd}},	//   tumu_, _frun, _traç, ович,
   {{0x63bb1923,0x3942007c,0x3ea549b5,0x38600183}},	//   _grun, _miks_, felt_, ibir_,
   {{0x3ea5b3da,0x3f84b3db,0xd36f004f,0x3942b3dc}},	//   gelt_, rumu_, _أهل_, _liks_,
   {{0x2d851994,0x3860b3dd,0x3f84b3de,0x171b0070}},	//   gule_, kbir_, sumu_, רויע,
   {{0x394262f9,0x6d5a26e3,0xdb0478a1,0xf1b30d85}},	//   _niks_, rpta, _asià, _מסע_,
   {{0x3ea5038d,0x3860b3df,0xddc1b3e0,0x6b86046a}},	//   belt_, dbir_, ralš, gukg,
   {{0x628a54b2,0x2d858ec9,0xde581112,0x3ea50029}},	//   ngfo, bule_, _такі_, celt_,
   {{0x2d85b3e1,0x13c30083,0xf3f9002d,0x1e9700a5}},	//   cule_, ্নয়, _veţi_, _הכול_,
   {{0xdb040042,0xa3d80266,0x6f1a081b,0x25bf07e7}},	//   _brió, ाहा_, lotc, _čul_,
   {{0x6bda006c,0x6d4a0054,0x69c83f3b,0xdb04002a}},	// [d430] _نوٹس_, _hufa, äder, _crió,
   {{0x6d4a19c6,0x3ce9b3e2,0x7c2db3e3,0xdb0d0282}},	//   _kufa, _hlav_, _izar, _braå,
   {{0x3942b3e4,0x3860035f,0xbb3c0070,0xd5bb323d}},	//   _fiks_, bbir_, _געזי, ыса_,
   {{0x6d4a3729,0x3ea5868b,0xa63401e0,0x7c2d0069}},	//   _mufa, zelt_, їнці, _kzar,
   {{0xd37b44d9,0x68edb3e5,0x2d85b3e6,0x7d0d08c7}},	//   уче_, mhad, zule_, _mjas,
   {{0x68edae9b,0x6d580a78,0x926b081b,0x7d0d0009}},	//   lhad, _otva, урда_, _ljas,
   {{0x20d80082,0x23600029,0x290900c3,0x3ce9b3e7}},	//   _réir_, ģija_, onaa_, _olav_,
   {{0x68edb3e8,0x3ea501ae,0x63bb4f73,0xfbdf0279}},	//   nhad, welt_, _trun, ncês_,
   {{0x4439b3e9,0x3ea5b3ea,0x6d582686,0x63ad0279}},	//   _às_, telt_, _atva, çand,
   {{0x2d85b3eb,0x6d4ab3ec,0x7ce61d2b,0x7d0d127d}},	//   tule_, _bufa, _córn, _ajas,
   {{0x3cca0b46,0x7c2db3ed,0x3ea53f99,0x70790a86}},	//   ално_, _azar, relt_, _نماز_,
   {{0x3ea50ccf,0x2d85b3ee,0x6d4ab3ef,0x8f6a00b5}},	//   selt_, rule_, _dufa, _چلنے_,
   {{0xa3e90387,0xdb043207,0x7c2d004e,0x68edb3f0}},	//   मनि_, _asiá, _czar, dhad,
   {{0x764701f4,0x2d85b3f1,0x6f1a009e,0x7ce60035}},	//   _ngjy, pule_, cotc, _górn,
   {{0xaa431403,0x7c2d0291,0x6d4a0232,0x442d01c0}},	//   дерл, _ezar, _gufa, _lze_,
   {{0x2909011e,0xa3e9035d,0x68ed111c,0x7d0d01f4}},	//   gnaa_, मना_, ghad, _gjas,
   {{0x442d0273,0x6ecd0026,0x6d4ab3f2,0x272f0225}},	// [d440] _nze_, तापु, _zufa, züne_,
   {{0x61250093,0x29095153,0x98b900ea,0x7f43035f}},	//   fólk, anaa_, _visā_, _jinq,
   {{0x68ed0094,0x1dc90099,0x39420029,0x442d9aaa}},	//   bhad, िमित, _tiks_, _aze_,
   {{0x68ed060e,0xe3ba0a80,0x76490644,0x7f43b3f3}},	//   chad, ибе_, _şeyt, _linq,
   {{0x442d0035,0xf772028c,0x00000000,0x00000000}},	//   _cze_, _تاج_, --, --,
   {{0x6d440f67,0x1dc99b65,0x272f027d,0xe57100b5}},	//   _liia, िमात, tüne_, بطے_,
   {{0x6ecd0026,0x7c2402d7,0xa7fb02d7,0x7e6a0312}},	//   तानु, _lyir, _reñi, _refp,
   {{0x26d80284,0x6d4a7b01,0x68e4b3f4,0x98a00693}},	//   _horo_, _rufa, nkid, klič_,
   {{0x6d580496,0x7c240895,0xb87b008a,0x26d8b3f5}},	//   _stva, _nyir, _slík, _koro_,
   {{0x6f0879dc,0x232a0133,0x7f43b3f6,0x68ed0168}},	//   undc, _този_, _cinq, zhad,
   {{0x7c2d392f,0xf6530122,0x7c24455b,0x68e4b3f7}},	//   _szar, וצת_, _ayir, kkid,
   {{0x26d8b3f8,0x442407c0,0x7c24007b,0xa2c207df}},	//   _loro_, _kym_, _byir, लाक्,
   {{0xa7fb0453,0x7f430392,0x7ce60042,0x6f1a02a7}},	//   _teñi, _finq, _tórn, potc,
   {{0x6d4ab3f9,0x7ce6785a,0x26d8b3fa,0xdb0401ed}},	//   _tufa, _fóro, _noro_, _briñ,
   {{0x68edb3fb,0x5b1402ce,0x6d58053c,0x286b03fa}},	//   thad, ємст, _utva, ирао_,
   {{0x02b70311,0x2bcb02e4,0x7d0d0054,0x7c2d6b06}},	//   _आफ्न, ामदा, _ujas, _tzar,
   {{0x68ed3635,0x290902ee,0x7d1db3fc,0x4424165a}},	// [d450] rhad, rnaa_, moss, _nym_,
   {{0xd5bb4af7,0x7d1db3fd,0x26d81d4e,0x290900e0}},	//   исе_, loss, _coro_, snaa_,
   {{0x25480716,0x4424b3fe,0xdb040ddb,0x68ed7a30}},	//   _oğlu_, _aym_, _griñ, phad,
   {{0x7d1db3ff,0xd12602de,0x44240035,0xe4e41958}},	//   noss, _سم_, _bym_, мічн,
   {{0x26d800c8,0xa3a71b15,0x27f20035,0x6ee41da5}},	//   _foro_, تحان, czyn_, _pòbl,
   {{0x6d022088,0xa6db00fb,0xdb0d0a39,0x26d8b400}},	//   _लगभग_, _auðv, _araú, _goro_,
   {{0x7d1d5e13,0xddc3002d,0x1a9c0070,0xdb0d021d}},	//   koss, _menţ, ייגע, _braú,
   {{0x7f4301f4,0xf8bf0019,0x54554e91,0x442db401}},	//   _sinq, _ghét_, _хват, _tze_,
   {{0x6d02009a,0x7d1d03fe,0x442db402,0x6d4400be}},	//   _लगबग_, doss, _uze_, _riia,
   {{0xa3d804bc,0x68e401d7,0x6d4400ab,0x7ce600ac}},	//   ाहर_, zkid, _siia, _póro,
   {{0x7c240ac8,0xa3b30d1f,0x6125b403,0x7d1d7ac1}},	//   _syir, टिक_, hóli, foss,
   {{0x692c01ae,0x7d1db404,0x6eedb405,0xdb0d021d}},	//   eßen, goss, _súbd, _graú,
   {{0xeb970945,0x6d4400be,0x6e230b88,0x00000000}},	//   пия_, _viia, _wynb, --,
   {{0x273400ab,0xddc30160,0x00000000,0x00000000}},	//   mäng_, _cenţ, --, --,
   {{0xf1bd0808,0xc3320122,0x7ced00f7,0x6f014590}},	//   ्मिन, גום_, _sûre, milc,
   {{0xf1b202b5,0x26d8b406,0x6125b407,0x7d1db408}},	//   עסן_, _soro_, fóli, coss,
   {{0xdb04008a,0x26d800f8,0x68e4b409,0x07a32519}},	// [d460] _frið, _poro_, rkid, натн,
   {{0x68e4b40a,0x41bd0275,0x7cf623c6,0x44245628}},	//   skid, ्मास, ršru, _rym_,
   {{0x4424a5de,0x27f20035,0x27e600f4,0xf8bf00cc}},	//   _sym_, szyn_, šon_, _phét_,
   {{0x61253207,0xf746204b,0xed5602b5,0x249f009e}},	//   bóli, _немо, לבער_, _cbum_,
   {{0x612501dd,0xd8d70070,0x38720137,0xe8d700a5}},	//   cóli, _זוכט_, mayr_, _זוכר_,
   {{0xe73701d3,0xd0460095,0x644931bc,0x249f00fe}},	//   _нея_, əməl, _egei, _ebum_,
   {{0x7ce601ef,0xe5a30ef3,0xf8bf00e2,0x3cfd00ab}},	//   _pórl, _пири, _thét_, _लगले_,
   {{0x44243d3f,0x2ca0009f,0x00000000,0x00000000}},	//   _tym_, _nbid_, --, --,
   {{0x40530082,0x7d1db40b,0x6d5501ef,0x4424030d}},	//   رئيس, voss, ízan, _uym_,
   {{0xd24f004f,0x2ca01505,0xb23a0037,0x620700fd}},	//   _منك_, _abid_, _هكذا_, árlá,
   {{0x7d1db40c,0x10a60352,0x64490448,0x069700a5}},	//   toss, _нижн, şmiş, הדים_,
   {{0x7ce62cad,0x7afe053e,0x239e00ea,0xb87b007e}},	//   _fórm, _ampt, pājā_, _hlív,
   {{0xe81c0174,0x00bb00a5,0x6eed3c0f,0x00000000}},	//   _भुला_, _למאמ, _súbe, --,
   {{0x3f7b0070,0x68fd0051,0x2ca00409,0x00000000}},	//   _פאוס, _smsd, _ebid_, --,
   {{0xd30800e8,0x3a250022,0x0e9b0122,0x5e9b00a5}},	//   yện_, ælp_, _השול, _הבוק,
   {{0x58d499ad,0x61251423,0xb87b01f7,0x7afe024b}},	//   ност, tóli, _llív, _empt,
   {{0x7b15002d,0x5b1500af,0xc64b0037,0x290700f4}},	// [d470] _одих, _омит, مجال_, đna_,
   {{0x1db0009a,0xac99006c,0xddc30009,0x3f520023}},	//   _जनात, _اچھا_, _henš, _mâu_,
   {{0x3f5201a5,0x61252de1,0x38721775,0x94d50402}},	//   _lâu_, sóli, bayr_, можц,
   {{0x2ea9164f,0x6f010a66,0x61253a62,0x2cab008c}},	//   _कस्त, zilc, póli, necd_,
   {{0xa6db008a,0xddc3024e,0xb87b008e,0x3f520023}},	//   _suðu, _menš, _blív, _nâu_,
   {{0xf8bf00a2,0xceb80067,0x00000000,0x00000000}},	//   _thés_, jdę_, --, --,
   {{0x6f01b40d,0x9508006c,0xf48700af,0xa2c206bc}},	//   vilc, _کہنے_, _нуан, लाज्,
   {{0x6ab70523,0x3f52055c,0x10a500af,0x00000000}},	//   _laxf, _bâu_, фиин, --,
   {{0x3f520028,0xb4e90864,0x6f013dfc,0x442b0019}},	//   _câu_, यसी_, tilc, _ác_,
   {{0x6006342d,0x0ecd004e,0x3f520019,0x0ea90421}},	//   ьным_, ़ाधड, _dâu_, цкой_,
   {{0x81bc00ea,0x6f01b40e,0xdb0d02b1,0x00000000}},	//   _dzēs, rilc, _spaß, --,
   {{0x13e100c8,0xeb9a0086,0x6f01008b,0xc10500bc}},	//   _মেয়, оим_, silc, _توصي,
   {{0x28d100b4,0x800900b5,0x273402b1,0xe86800ee}},	//   हानि, _براہ_, läne_, _nášľ,
   {{0xfe710a86,0x63a4037a,0x3f98002d,0x00000000}},	//   _شدت_, çini, ărut_, --,
   {{0xa3b4000c,0xbb430d0b,0x611300af,0x00000000}},	//   _छैन_, терк, călc, --,
   {{0x52da0f39,0xb87b0093,0x200e0124,0x2d8501a0}},	//   _बक्स, _olíu, šmiš_, mrle_,
   {{0x48fd018d,0x3cf90031,0x403a016b,0x3f5200cc}},	// [d480] रोधो_, ërve_, ַגעג, _xâu_,
   {{0xe7370009,0x6c680332,0x61e30173,0xc9aa037c}},	//   деу_, _بلکہ_, kynl, _двое_,
   {{0x2734013c,0x6ee40211,0x00000000,0x00000000}},	//   vänd_, _dòbh, --, --,
   {{0x2d8541e3,0x2d530370,0x9dd60070,0xd46703fa}},	//   irle_, _mãe_, וועק_, дице_,
   {{0xe3af0088,0xb4ae00dc,0x25ad0009,0x00000000}},	//   لرو_, _कसी_, _ćele_, --,
   {{0x98b900d8,0x3f52b40f,0x6ee40211,0x24920067}},	//   _visą_, _râu_, _gòbh, żym_,
   {{0x3f5201a5,0x05661958,0x249d006d,0xf8bf0023}},	//   _sâu_, _іван, bfwm_, _khép_,
   {{0xf9930122,0xceb8004e,0xa2c206fe,0x00000000}},	//   דרה_, wdę_, लाङ्, --,
   {{0xb7db02b5,0x2d8515a2,0xa3e907df,0xee8600af}},	//   ַקטי, erle_, मनः_, мыно,
   {{0x81bc00ea,0x7ce6007e,0x91fc00ec,0x00000000}},	//   _dzēr, _fórk, _beāt, --,
   {{0x7ce600b5,0x612509ca,0xdb2100b5,0xcfdf0033}},	//   _kórh, vólv, _ítél, _বেদন,
   {{0x6ee412c3,0xa3b5007c,0x0fb60324,0xf8bf0023}},	//   _mòbi, _जनम_, _अनपढ, _nhép_,
   {{0x69dab410,0x2d856f84,0x57c8021a,0x5eda0033}},	//   äten, arle_, रमोह, যোগে,
   {{0x1eaa006c,0x00000000,0x00000000,0x00000000}},	//   _ذاتي_, --, --, --,
   {{0x391507c1,0x26cd0019,0x1994b411,0xbea31a55}},	//   емвр, _đeo_, каря, _рајк,
   {{0xf8bf0019,0xdb0d41e1,0x6125002a,0x2d8cb412}},	//   _chép_, _isaí, sólv, mude_,
   {{0x2d8cb413,0xf7701dbf,0xb90700b4,0x4735b414}},	// [d490] lude_, لال_, _बक_, енас,
   {{0x6ee401f7,0x00000000,0x00000000,0x00000000}},	//   _bòbi, --, --, --,
   {{0x2d8cb415,0x885900af,0x00000000,0x00000000}},	//   nude_, _нинс_, --, --,
   {{0xf8bf0019,0xb4e9022e,0xb87b0138,0x00000000}},	//   _ghép_, यसे_, _clít, --,
   {{0xb87b0037,0x00000000,0x00000000,0x00000000}},	//   _dlít, --, --, --,
   {{0x65955288,0x6ee401f7,0x78ad00be,0x41b503d6}},	//   _пагу, _fòbi, leav, есит,
   {{0x56940009,0xa3b306bb,0x2d8cb416,0xe803046c}},	//   _шарт, टिङ_, jude_, _रेता_,
   {{0x2d8c2638,0xa6db0093,0xfa0d0023,0x2eeeb417}},	//   dude_, _guðr, _đầu_, _alff_,
   {{0xf076006c,0x61e30c61,0x2d8c0298,0x00000000}},	//   ریوں_, synl, eude_, --,
   {{0x4d650c9f,0x00000000,0x00000000,0x00000000}},	//   нков, --, --, --,
   {{0x2d8c00ab,0x00000000,0x00000000,0x00000000}},	//   gude_, --, --, --,
   {{0x998d004e,0x6eed0079,0x3156016b,0x1c0100ab}},	//   łeś_, _dúba, _װיסן_, _लेहल_,
   {{0xb87b0015,0x78ad0f00,0x00000000,0x00000000}},	//   _moíd, deav, --, --,
   {{0x2d8c0076,0x91fc0029,0x7ff40416,0x26180066}},	//   bude_, _teāt, _جسما, _बुझी_,
   {{0xf8bf0028,0x7ce601ef,0x2d8c02d7,0x09ce0033}},	//   _phép_, _lóri, cude_, রন্থ,
   {{0xa3cf09b4,0xb4ae00a1,0x395e0029,0x68462682}},	//   षमा_, _कसे_, īts_, енба,
   {{0xb9081746,0xf7720037,0x5eb20033,0xca7600af}},	// [d4a0] _भव_, طاء_, জারে, _пуны,
   {{0x7d06b418,0x8c1b0122,0xa6db05ee,0xd82300af}},	//   liks, _מופי, _suðr, удуи,
   {{0xc4863539,0xf8bf0019,0x645b0312,0x00000000}},	//   елек, _thép_, _bfui, --,
   {{0x78ad002d,0x7d06b419,0x798e3c4c,0x7ce600ee}},	//   ceav, niks, mubw, _bóri,
   {{0xdce2013b,0xd3260352,0xa2940eb9,0x2bc30d4e}},	//   ntlı, ньки, валі, शिया,
   {{0x60cb01a2,0xd24f45fd,0x7bcb0952,0x7d060dfa}},	//   _angm, منه_, _águe, hiks,
   {{0xe737b411,0xe3d80033,0xb87b01ef,0x7d0600c3}},	//   _чер_, _দেখব, _ilír, kiks,
   {{0xd37200bf,0x859b0122,0x7bc49d83,0x673e0120}},	//   _مهر_, _משלו, _oriu, lmpj,
   {{0x7d060c1f,0x3eac191b,0x3f8d0443,0x7522001c}},	//   diks, tedt_, gueu_, mooz,
   {{0x2d8cb41a,0x798e1526,0x7522018e,0x60cb0523}},	//   tude_, kubw, looz, _engm,
   {{0x7bc4b41b,0x69da00c3,0x3eacb41c,0xa3d80266}},	//   _ariu, ätel, redt_, ाहक_,
   {{0x2d820bc6,0x2d8cb41d,0xb87b0310,0x7bc4b41e}},	//   čke_, rude_, _llír, _briu,
   {{0xdee67b96,0x2d8cb415,0x7bc4b41f,0xddd800fd}},	//   _поди, sude_, _criu, _vevő,
   {{0x657c022f,0x2902b420,0x673e0051,0x2be20354}},	//   _ovrh, _amka_, jmpj, _पथरा,
   {{0x98c713ba,0x78adb421,0xc98401ee,0x7d06b422}},	//   нсал, teav, лути, biks,
   {{0x7bc402fb,0x61f5006c,0x28d10099,0x765c0067}},	//   _friu, _üzle, हाधि, _afry,
   {{0x78ad09b3,0x1bd500af,0x7bc49ac8,0x00000000}},	// [d4b0] reav, _ропя, _griu, --,
   {{0x7f4a0069,0xb4e907df,0x798e0027,0x00000000}},	//   _jifq, यस्_, bubw, --,
   {{0xd91500d8,0x610800b8,0x6b9d033b,0x236d0067}},	//   _адны, něls, ltsg, _swej_,
   {{0xa8790070,0x69c5009e,0x673e0223,0xdc9c016b}},	//   _קאָר, _irhe, ampj, ּיגל,
   {{0x98ab0035,0x6e2a0345,0x765c016e,0x00000000}},	//   _chcą_, _lyfb, _ffry, --,
   {{0x7d06b423,0x2126010d,0x6b9d033b,0x38694f3a}},	//   ziks, _akoh_, itsg, lbar_,
   {{0x75220273,0x61bd012f,0x00000000,0x00000000}},	//   booz, ्मेष, --, --,
   {{0x3869b424,0x610800b8,0x9f520187,0x629c01ff}},	//   nbar_, děls, ždým_, _öron,
   {{0x386900d7,0x7d06b425,0x6ee40176,0x657c0a69}},	//   ibar_, viks, _lòbu, _zvrh,
   {{0x3f8302dd,0x3869b426,0x7d060260,0x394b5a89}},	//   čju_, hbar_, wiks, _lics_,
   {{0xee393634,0x7d06a590,0xcc8a00d1,0x386915e4}},	//   ьно_, tiks, ونده_, kbar_,
   {{0x7bc4b427,0xa3b5000c,0x60cb78d2,0x63a90118}},	//   _priu, _जना_, _ungm, _kpen,
   {{0x3f8d0443,0x3869079a,0x2ef50786,0xde1600d1}},	//   queu_, dbar_, _издр, فقیت_,
   {{0xe8ca00b8,0x7d06b428,0x212d411b,0x2d6e01c0}},	//   ाञ्च, siks, lleh_, bře_,
   {{0x6b9d29a4,0x394b01ef,0xb87b0132,0x6281189a}},	//   atsg, _bics_, _alíq, _mdlo,
   {{0x63a9b429,0x00000000,0x00000000,0x00000000}},	//   _open, --, --, --,
   {{0x6281108a,0x7d040232,0x657c0a78,0x69c501ae}},	// [d4c0] _odlo, _imis, _svrh, _erhe,
   {{0x752209d6,0x7ce601ef,0x62810858,0x80a107df}},	//   wooz, _córv, _ndlo, क्ते,
   {{0x63a9478a,0x3869b42a,0x394b014c,0xceb2011d}},	//   _apen, bbar_, _fics_, שיב_,
   {{0x80a10e1d,0x628100e9,0x7d04003c,0xd4d5010b}},	//   _कॉले, _adlo, _jmis, лічэ,
   {{0x29121201,0xc1da06fe,0x3940b42b,0x7d04034d}},	//   mnya_, यङ्ग, mmis_, _mmis,
   {{0x29123635,0x3940846b,0x68f645cd,0x7d04019d}},	//   lnya_, lmis_, lhyd, _lmis,
   {{0x7d040086,0x63a901ef,0x29126020,0x7f4a00d7}},	//   _omis, _epen, onya_, _rifq,
   {{0x2912b42c,0x64a64238,0x0f1a0026,0x68f65133}},	//   nnya_, _шаба, नक्स_, nhyd,
   {{0xb4261c73,0x2912005d,0xb4ae0461,0xa8e00023}},	//   _شعرو, inya_, क़ी_, _độn,
   {{0x29121201,0x7d04b42d,0xf77300a5,0x3869647b}},	//   hnya_, _amis, סקת_, zbar_,
   {{0x29123635,0x3869b42e,0x80a60312,0xfdd00083}},	//   knya_, ybar_, _لمان, ান্ড,
   {{0x25aa00d7,0x2912028b,0x6b9d7a13,0x00000000}},	//   _mpbl_, jnya_, ttsg, --,
   {{0x3869b42f,0x2912005d,0xa3d80299,0x394b0392}},	//   vbar_, dnya_, ाहट_, _rics_,
   {{0x7d04b430,0xd00f00f8,0x2912018e,0x38690159}},	//   _emis, _بله_, enya_, wbar_,
   {{0x394bb431,0x29120ec0,0x386916ad,0x28c4020c}},	//   _pics_, fnya_, tbar_, _लोहि,
   {{0x7d1600da,0x291222be,0x2fc6b432,0x6f082c67}},	//   _gjys, gnya_, _krog_, lidc,
   {{0x383507c2,0x386940d1,0x38660b4c,0xb8030066}},	// [d4d0] унар, rbar_, ñora_, _रेशम_,
   {{0x2d9e09a6,0xb87b0a20,0x291219ba,0xb6f40274}},	//   otte_, _elíp, anya_, азуј,
   {{0x69c5b433,0x7d04081b,0x29120ec0,0x3869037d}},	//   _urhe, _ymis, bnya_, pbar_,
   {{0x7ce6b434,0x291200d7,0xdb16a2c4,0x7c2d0c2f}},	//   _fóru, cnya_, _asyè, _kyar,
   {{0x2fc60d4b,0xd2a91c1b,0xc484005f,0x6d4d2be4}},	//   _nrog_, екле_, рлік, _miaa,
   {{0xe29600c9,0x68edb435,0x27e9b436,0x7c2d0bf7}},	//   гаш_, lkad, myan_, _myar,
   {{0x78bd087a,0x6eed016f,0x10a50382,0xd49b0012}},	//   _kasv, _súbo, гийн, _ора_,
   {{0x6d4d043d,0x272f006c,0x7c2d02d7,0x3d020066}},	//   _niaa, künk_, _oyar, _लगें_,
   {{0x27e9b437,0x7c2d2591,0x63a9000e,0x2d9e3ed8}},	//   nyan_, _nyar, _upen, ette_,
   {{0x7d041851,0x2fc6b438,0x442d007b,0x2912104e}},	//   _smis, _drog_, _iye_, znya_,
   {{0x7c2d01d6,0xde053f0a,0x442db439,0x291200d7}},	//   _ayar, упни, _hye_, ynya_,
   {{0x7c2d0232,0x78bd108a,0x442d09d6,0x27e9b43a}},	//   _byar, _nasv, _kye_, kyan_,
   {{0xbea50dc8,0x8edf00c8,0xdb0db43b,0x7c2d0010}},	//   _балк, যোগগ, _arañ, _cyar,
   {{0x68ed02a2,0x27e9b43c,0x7c2db43d,0xdb0d20d9}},	//   ekad, dyan_, _dyar, _brañ,
   {{0xada502ee,0x29123635,0x442d6391,0x7d04009f}},	//   _сайл, tnya_, _lye_, _tmis,
   {{0x60dbb43e,0x442db43f,0x7d04b440,0x7ce60042}},	//   njum, _oye_, _umis, _córt,
   {{0x29121201,0x27e9b441,0x3940b442,0x442d1953}},	// [d4e0] rnya_, gyan_, rmis_, _nye_,
   {{0x29121201,0x7bcb03e6,0x8ca0021a,0x68f600a2}},	//   snya_, _água, ग्रो, shyd,
   {{0x4a9b00c2,0x29120f1a,0x1a9b02b5,0x80b8021a}},	//   _אייג, pnya_, _אייע, ्यमे,
   {{0x442db443,0x68ed022a,0xdb0d008a,0x78bd2af3}},	//   _bye_, ckad, _hrað, _gasv,
   {{0xf487006c,0x28d1111b,0x442d0010,0x98a00067}},	//   طانی, हारि, _cye_, elić_,
   {{0x78bd03e0,0x2d9e0c61,0x68e3002d,0x442d33e6}},	//   _zasv, ytte_, _îndr, _dye_,
   {{0x6abe93f0,0x442d00a5,0x272f00b5,0x98a000cd}},	//   _mapf, _eye_, zünk_, glić_,
   {{0x2fc6b444,0x442d021e,0x7df300a8,0x3ea70132}},	//   _prog_, _fye_, cəsə, _abnt_,
   {{0x2ef4692c,0x442d09d6,0x98ab0035,0x6d4d03bc}},	//   изир, _gye_, _chcę_, _riaa,
   {{0x7c2d0010,0x68edb445,0x98a00124,0x979b016b}},	//   _ryar, zkad, blić_, עשיק,
   {{0x9e340714,0x7c2d0b0e,0x6d4d011e,0x236000ea}},	//   ренч, _syar, _piaa, ģiju_,
   {{0x272f006c,0x61e501ae,0x98a901ba,0x2d9eb446}},	//   tünk_, ähle, tlač_, rtte_,
   {{0x78bd2119,0x9b580382,0x6abe0010,0x2d9eb447}},	//   _rasv, лият_, _bapf, stte_,
   {{0x78bd0a78,0xbebc0080,0x7ce6004f,0x6abe01f7}},	//   _sasv, glīt, _sórt, _capf,
   {{0xc3330052,0x7ce67c80,0x78bd010b,0x68edb448}},	//   מוש_, _pórt, _pasv, tkad,
   {{0xd7fb0132,0x7e7ab449,0x00000000,0x00000000}},	//   нуз_, latp, --, --,
   {{0x68edb44a,0x7c2d01d6,0x629a1121,0xd79501d3}},	// [d4f0] rkad, _uyar, _octo, ризъ,
   {{0x68edb44b,0x27e9b44c,0x442db44d,0x2d8c1516}},	//   skad, ryan_, _rye_, orde_,
   {{0x35b54b34,0x27e9b44e,0x54551ca9,0x2bc300a1}},	//   рбер, syan_, авет, शिवा,
   {{0x442d0c1f,0xf79501c8,0x7e7a23dc,0x2d8c0037}},	//   _pye_, _камэ, hatp, irde_,
   {{0xe2992b8e,0x6abe01d5,0x672500c3,0x7df3013b}},	//   вал_, _yapf, pohj, rəsə,
   {{0x442d02e9,0x98a01b86,0x00000000,0x00000000}},	//   _vye_, tlić_, --, --,
   {{0x442db44f,0x7ce601ef,0x92922123,0xf8bf01cb}},	//   _wye_, _mórr, цајц, _kaé_,
   {{0x442d0173,0x00e5002d,0x0cc00033,0x3f9f0086}},	//   _tye_, ржин, _উক্ত, ttuu_,
   {{0x80a109b1,0x2d8c0a45,0x60dbb450,0xef19021d}},	//   क्षे, erde_, rjum, кми_,
   {{0x2ca90464,0x26c100f8,0x63bbb451,0x98a02af4}},	//   _abad_, ndho_, _isun, plić_,
   {{0x6da50adb,0xe80c1bc6,0xee362a34,0x3f9f0086}},	//   шина, _सेना_, инь_, stuu_,
   {{0xdfd10698,0x8c4601fd,0x80a1021a,0x6abeb452}},	//   _ويا_, иене, क्शे, _sapf,
   {{0x2d8cb453,0x7ce6002a,0x63ad0132,0x5fa901c0}},	//   arde_, _bórr, çanh, _कहिल,
   {{0x7ce6af40,0x80a10d1f,0xcb67002d,0x7a4000b5}},	//   _córr, क्रे, раре_, játé,
   {{0xf8bf01cb,0xb87b01ef,0x2be20099,0x00000000}},	//   _baé_, _soía, _पथका, --,
   {{0x78661401,0xc95545d7,0x3f5b0019,0xb4c107df}},	//   рказ, стры, _kêu_, ्ञो_,
   {{0xb8de1ea2,0x80b800e7,0xdb0d05ee,0x63bb0103}},	// [d500] _इस_, ्यते, _trað, _nsun,
   {{0x8ca7006a,0x657e01ae,0xdd1d005f,0x00000000}},	//   ट्ठो, tsph, _iššs, --,
   {{0x63bb7a3d,0x98a68f4c,0xd9100416,0x23640118}},	//   _asun, _кине, _فیس_, _stmj_,
   {{0x64a624da,0x26d1b454,0x938a6af8,0x61ee033b}},	//   рада, _enzo_, вска_, _übli,
   {{0x93464b34,0xe3b205bc,0x26c100e0,0x3f5b0019}},	//   анде, ترا_, bdho_, _nêu_,
   {{0x3f8d0443,0xfc3f0300,0x6d5a01f4,0x2d8b0035}},	//   dreu_, nfía_, yqta, ącej_,
   {{0x7e7a8f18,0x00000000,0x00000000,0x00000000}},	//   vatp, --, --, --,
   {{0x80a10026,0x3f8d0a39,0x2d8c3c8e,0x55bb00a5}},	//   क्ले, freu_, vrde_, _במלו,
   {{0xdfd000ad,0x7e7a0392,0x7649013b,0x00000000}},	//   سيد_, tatp, _şeyx, --,
   {{0x9ed803e6,0xe4650093,0x629ab455,0x00000000}},	//   умот_, _þörf_, _ucto, --,
   {{0x80b800be,0x07370122,0x667b02b5,0x2d8c11cc}},	//   ्यदे, שאים_, כטיק, urde_,
   {{0xa06a1797,0x3f8db456,0xa5d9016b,0x00000000}},	//   _рада_, breu_, אַשי, --,
   {{0x63a2b457,0x92d80083,0x81c700ea,0x9d181172}},	//   nton, াসী_, rtēš, роят_,
   {{0x6298b458,0xdce2010b,0x39b80260,0x81c700ea}},	//   ngvo, kslė, _bōs_, stēš,
   {{0xed57051b,0x58d5029f,0x7c871e38,0x25480a21}},	//   _кој_, бовт, _купе, _eşli_,
   {{0x3f5b00e8,0x63a2b459,0xa3d608b6,0xa8551692}},	//   _yêu_, kton, िमा_, скач,
   {{0xddda8afc,0x63a2b45a,0xfb8500d1,0x6d58b45b}},	// [d510] katū, jton, _ادبی, _huva,
   {{0x6d58b45c,0x63a203be,0xf8bf00d1,0x39b8021e}},	//   _kuva, dton, _waé_, _fōs_,
   {{0xdfc60332,0x245521a0,0x63a2018f,0x63bb0103}},	//   _کي_, مناس, eton, _ssun,
   {{0x63a2b45d,0x6d58b45e,0xf4870212,0x31650223}},	//   fton, _muva, ружн, _rtlz_,
   {{0x7ae5136d,0xd3080028,0xe7848497,0x63a218ad}},	//   _koht, yệt_, _муро, gton,
   {{0x7ae503ad,0x3f5b00e2,0x63bb00d5,0x7e783f5d}},	//   _joht, _rêu_, _vsun, _nevp,
   {{0x6d58b45f,0x63a214e7,0x256c0359,0x00000000}},	//   _nuva, aton, _vòlò_, --,
   {{0x3f8db460,0x212b07c0,0x5a18011d,0x34940132}},	//   treu_, ôch_, יקון_, _маср,
   {{0x63bb004e,0x3de40033,0xd37100f8,0x00000000}},	//   _usun, _ফেলল, _رها_, --,
   {{0x3f8d29cf,0x6d58b461,0x79950054,0xdb0401ef}},	//   rreu_, _buva, kuzw, _opiá,
   {{0x6d58b462,0x69c7003a,0x4acb021a,0x6eed014c}},	//   _cuva, jvje, ायनव, _júbi,
   {{0x6d5872d6,0x69c7025c,0xf1c300d8,0x70590132}},	//   _duva, dvje, rašė_, _садр_,
   {{0x705218dd,0x21c70023,0x6f650c74,0x7ae56eed}},	//   _عنوا, _hđh_, _اهتم, _boht,
   {{0x543a02b5,0x6113002d,0x80d5012f,0x6d5800fd}},	//   טערא, dăli, भावे, _fuva,
   {{0x5d850082,0xc33202b8,0x63a2006c,0x8d95004f}},	//   _البل, פול_, zton, _العش,
   {{0x28d800b4,0x97da0421,0x38790312,0x00000000}},	//   डाधि, льзу_, _cesr_, --,
   {{0x38602ddc,0xfc3fb463,0xddc30355,0x63a200b9}},	// [d520] rcir_, lfín_, _jenž, xton,
   {{0x065601c8,0x6d5800d0,0xf65638df,0x63a2082d}},	//   стаў, _yuva, стаю, vton,
   {{0x2a570122,0x2734013c,0x38790036,0x463a0945}},	//   _לבין_, länk_, _fesr_, учая_,
   {{0x6723039a,0x63a2b464,0x6eed0391,0xb0a600a1}},	//   čnja, tton, _dúbi, _कॉंग,
   {{0x80b8022e,0x63a2013e,0x240a00af,0x00000000}},	//   ्यसे, uton, ынди_, --,
   {{0x04fa0033,0xf8bf00e0,0x21c700e2,0x00000000}},	//   েকের_, _akéh_, _bđh_, --,
   {{0xc05a291f,0xddda1638,0x68e600e0,0x00000000}},	//   ліп_, ratū, _kokd, --,
   {{0x64a34237,0x63a2b465,0x92d80083,0x6d584604}},	//   _наса, pton, াসে_, _ruva,
   {{0x6d58b466,0x69c73485,0x00000000,0x00000000}},	//   _suva, zvje, --, --,
   {{0x3f8a0187,0x395a00a2,0x6d586893,0x00000000}},	//   čbu_, _oups_, _puva, --,
   {{0x62880b77,0x7ae5b467,0x00000000,0x00000000}},	//   _iddo, _roht, --, --,
   {{0xa1570122,0x79950010,0xdc3d0069,0xb146002d}},	//   _הבאה_, vuzw, _aġġr, _унел,
   {{0x7ae50421,0x6ab500a2,0x00000000,0x00000000}},	//   _poht, tezf, --, --,
   {{0x6d58b468,0x6b84b469,0x6d465e55,0x6b89011c}},	//   _tuva, _dvig, amka, šego,
   {{0x6b8410fa,0x6ab500d5,0xb6c900b5,0x60c2034d}},	//   _evig, rezf, یائے_, _kaom,
   {{0x3e4e0095,0x79951596,0x611300af,0x6eed2df0}},	//   mət_, ruzw, tăli, _rúbi,
   {{0x69c70c0a,0x7ae5b46a,0x60c2000e,0x6eed0473}},	// [d530] svje, _toht, _maom, _súbi,
   {{0x7bcd06a2,0x7d0fb46b,0x60c20341,0x00000000}},	//   _irau, lics, _laom, --,
   {{0x3e4e0095,0x7bcd0093,0x69da0421,0x00000000}},	//   nət_, _hrau, ätet, --,
   {{0x60c2b46c,0x7bcdb46d,0x6288b46e,0xfc3f1725}},	//   _naom, _krau, _addo, nfío_,
   {{0x889a035e,0x3e4e00a8,0xddc802c4,0x31a10067}},	//   _דברי, hət_, jadž, wóz_,
   {{0x3e4e00a8,0xddc80009,0x4b7c0070,0x776d0042}},	//   kət_, dadž, נאוו, mpax,
   {{0x6aaa02bf,0x6a9c0052,0xa3b5b46f,0x65940426}},	//   _öffe, אשונ, _जनक_, _нару,
   {{0x7a400093,0x60c226c9,0x62880273,0x6f650947}},	//   _hátí, _caom, _eddo, овиз,
   {{0x7bcd01a9,0xb87b053d,0x7b090097,0xc447006c}},	//   _nrau, _blíz, ržuj, _ایشن_,
   {{0x0d8535b8,0x3e4e0095,0xe4500037,0x776d002a}},	//   олон, fət_, _أضف_, ipax,
   {{0x7bcd0291,0x26c3b470,0xc6920122,0x6b84b471}},	//   _arau, _majo_, ואי_, _svig,
   {{0x7bcdb472,0x395a6191,0x2d8b00b8,0xddc80009}},	//   _brau, _rups_, čce_, badž,
   {{0x7bcd01a2,0xb87b01ef,0x6d46b473,0x28c40b4d}},	//   _crau, _coím, rmka, _लोगि,
   {{0x7bcd68fe,0x3e4e0095,0x7d0f009e,0x00000000}},	//   _drau, bət_, aics, --,
   {{0x7bcd01a3,0x39e70009,0x60c208c7,0x00000000}},	//   _erau, одро_, _yaom, --,
   {{0x7bcd06d1,0x6fcd09b4,0x28d10387,0x00000000}},	//   _frau, तिपू, हागि, --,
   {{0x7bcdb474,0x26c30083,0x07a32dfa,0x6b8401ef}},	// [d540] _grau, _bajo_, матн, _uvig,
   {{0x249f0012,0xeb9102b5,0x57ba000c,0x69c80364}},	//   _acum_, _אָט_, _उनीह, ådes,
   {{0xe45a195a,0xa2dd0761,0x249f0176,0x26c308b7}},	//   аже_, पान्, _bcum_, _dajo_,
   {{0xa3d600dc,0x136a0923,0x00000000,0x00000000}},	//   िमल_, ашки_, --, --,
   {{0xf74630ca,0x4420b475,0x249f008c,0xa34a04d9}},	//   _мемо, çi_, _dcum_, азда_,
   {{0x3e4e01c2,0x26c3b476,0xddc30069,0xe73700af}},	//   yət_, _gajo_, _benż, _мея_,
   {{0xe61700af,0xd24f00ce,0xaacb01c0,0x00000000}},	//   _ддр_, ننه_, ायतक, --,
   {{0x89db0122,0xc0ca03fa,0x3e4e00a8,0xf4870088}},	//   שחקי, руке_, vət_, _واقی,
   {{0x63ad00da,0xe29a9c5a,0x00000000,0x00000000}},	//   çant, _ваз_, --, --,
   {{0x20180043,0x2ca0b477,0xddc819be,0x60c2002f}},	//   ări_, _acid_, radž, _waom,
   {{0xb65b02b5,0x60c21a07,0xaade00b8,0x7bcd010b}},	//   ידיש, _taom, मानक, _srau,
   {{0x3e4e01c2,0xcd0702ce,0x7bcdb478,0x0ed800b5}},	//   rət_, ічни, _prau, _گاؤں_,
   {{0x3e4e01c2,0xdcfb0029,0x7ac72264,0xa3ea1140}},	//   sət_, gstā, осве, महि_,
   {{0xb0a60387,0xe7c906fe,0x00000000,0x00000000}},	//   क्रग, रिसप, --, --,
   {{0x7d0f01e4,0x0e7500a0,0x3e4e00a8,0x80a10354}},	//   pics, äčší, qət_, क्के,
   {{0x58d40f9e,0x7bcdb479,0x5c750421,0x00000000}},	//   мост, _trau, _элит, --,
   {{0x7cff01d2,0x6fbc0907,0x7d0db47a,0x26c3b47b}},	// [d550] _përf, ्टिं, _imas, _pajo_,
   {{0x8ca70d00,0xc66b00d8,0x00000000,0x00000000}},	//   ट्रो, ршае_, --, --,
   {{0x2aba0122,0x2bc32f41,0x44b502c8,0x3aba00a5}},	//   _המתא, शिका, збес, _המתנ,
   {{0xe80c0e6f,0x7cff01d2,0x26c30ac8,0xf9920319}},	//   _सेवा_, _dërg, _wajo_, _ארט_,
   {{0x3949b47c,0x26c35f1b,0x7d0d023c,0x00000000}},	//   mmas_, _tajo_, _mmas, --,
   {{0x3949b47d,0x850504cd,0x1fd00083,0x7d0d0471}},	//   lmas_, _کورن, িহাস, _lmas,
   {{0x39491721,0x2d8ab47e,0xd49b0370,0x7d0d18af}},	//   omas_, ábel_, _врз_, _omas,
   {{0x39490260,0x69cc00a1,0x6b4b0024,0x6eed0098}},	//   nmas_, हिती, _iżgu, _lúbt,
   {{0x44391a71,0x3cdf00a1,0x394900ea,0xdcfb010b}},	//   _ás_, गाने_, imas_, lutė,
   {{0x7d0d1810,0x3f8601c0,0xb87b002a,0x443f48f9}},	//   _amas, _dvou_, _elíx, _izu_,
   {{0xdcfb01c8,0xcee800d1,0x3f8600d5,0x8cd8164f}},	//   nutė, ترين_, _evou_, यालो,
   {{0xcb09011d,0x7d0d0211,0x80a207b5,0xdcfb0228}},	//   _גל_, _cmas, _गाये, tstā,
   {{0x2fc90079,0x2bba0079,0x00000000,0x00000000}},	//   _éag_, حاجة_, --, --,
   {{0xdcfb0029,0x7d0d2759,0xbf3700fd,0x00000000}},	//   rstā, _emas, _برصغ, --,
   {{0x78af00cc,0x00000000,0x00000000,0x00000000}},	//   _bbcv, --, --, --,
   {{0x2ca00139,0x7d0d021d,0x00000000,0x00000000}},	//   _ucid_, _gmas, --, --,
   {{0x81b100c8,0x6d56b47f,0x4c9b0d85,0x443f0010}},	// [d560] টটি_, _iiya, _השפע, _nzu_,
   {{0x7cff01d2,0x6d56b480,0x3949010b,0xaa4684b6}},	//   _përg, _hiya, amas_, _непл,
   {{0x6d440189,0xb0bd112b,0x7e7e007c,0x20bd0ebd}},	//   _khia, ्याग, _õppe, ्याध,
   {{0x6d566791,0x7cff01f4,0x39492984,0x2d8514a0}},	//   _jiya, _gërd, cmas_, isle_,
   {{0x6d56b481,0x2912b482,0x6d4409c3,0x68e4012f}},	//   _miya, miya_, _mhia, mjid,
   {{0x2912b483,0x6d5600bf,0x6ef60248,0x1ddb0099}},	//   liya_, _liya, _câbl, यमात,
   {{0x3f8601c0,0x6d44380c,0x27f200c3,0x443f008c}},	//   _svou_, _ohia, lyyn_, _ezu_,
   {{0x2912b484,0x6d56b485,0x290003e6,0x361b0122}},	//   niya_, _niya, nhia_, _הולד,
   {{0x2d870009,0x4256027a,0x7c240031,0x7d0d0185}},	//   _avne_, _етет, _nxir, _rmas,
   {{0x64406c64,0x2912149b,0x394900d8,0x7bcb1430}},	//   _izmi, hiya_, zmas_, _águi,
   {{0x6d56b486,0x2912b487,0x394900d8,0x6d440874}},	//   _biya, kiya_, ymas_, _bhia,
   {{0x6d44b488,0x6d56095f,0x660101d6,0x29120371}},	//   _chia, _ciya, _ülke, jiya_,
   {{0x6d56b489,0x29000a56,0x703a00d1,0x6d44b48a}},	//   _diya, dhia_, _اساس_, _dhia,
   {{0xdee3010e,0x195900d8,0x3f82010b,0x44240069}},	//   _почи, жавы_, škus_, _mxm_,
   {{0xa2dd0a44,0x7cff01d2,0x6d560723,0x6569b48b}},	//   पात्, _përd, _fiya, _čeho,
   {{0x98c45451,0x2912b48c,0x7d0d2606,0x6d44b48d}},	//   нсул, giya_, _umas, _ghia,
   {{0xb8e504cc,0x80a10026,0xade500b5,0x00000000}},	// [d570] _एस_, क्टे, _فہیم_, --,
   {{0x6d5606a8,0x4b7c00a5,0xaade01c0,0x98b200ea}},	//   _ziya, _האזו, माणक, ībās_,
   {{0x2912b48e,0x7d1db48f,0x6d5601d5,0x2d540395}},	//   biya_, onss, _yiya, _oţel_,
   {{0x7d1dad5f,0x291200ae,0x6d56013b,0xdb16008d}},	//   nnss, ciya_, _xiya, _hryð,
   {{0x78ad012f,0x7d1d008d,0x27e000e2,0x00000000}},	//   mfav, inss, cxin_, --,
   {{0x2d8501ba,0xa2dd021a,0x7d1d0523,0x00000000}},	//   ysle_, पाध्, hnss, --,
   {{0x74f900af,0xb45701df,0x00000000,0x00000000}},	//   _девр_, _فیاض_, --, --,
   {{0x7d1d0051,0x00000000,0x00000000,0x00000000}},	//   jnss, --, --, --,
   {{0x6d56b490,0x443f007a,0x6d44b491,0xa2dd00e7}},	//   _riya, _uzu_, _rhia, पाद्,
   {{0x6d56b492,0x2912b493,0x6d44521a,0xdd89051a}},	//   _siya, ziya_, _shia, обод_,
   {{0x57ba0141,0x6d440189,0x6d56b494,0x112b093c}},	//   _उन्ह, _phia, _piya, _люди_,
   {{0x6283b495,0xd00e0ef5,0x6d56b496,0x6d4401e8}},	//   lano, الی_, _qiya, _qhia,
   {{0x6eed00a0,0xbea5218b,0x79950051,0x2912b497}},	//   _dúbr, _жалк, erzw, viya_,
   {{0x6283b498,0x6d561e20,0x29120b65,0x00000000}},	//   nano, _wiya, wiya_, --,
   {{0x6d441020,0x6d56b499,0xc3320122,0x2900b49a}},	//   _thia, _tiya, דום_, thia_,
   {{0xb4bc0429,0x62830297,0x7c2401d7,0x248d0118}},	//   _असे_, hano, _txir, _ndem_,
   {{0x2912b49b,0x236d01a9,0x46ea095d,0x3af400c3}},	// [d580] riya_, _ntej_, одан_, _läpi_,
   {{0x29120669,0x68e40ac8,0x29003eb0,0x628305e2}},	//   siya_, sjid, shia_, jano,
   {{0x6283b49c,0x29123fb0,0x64cf0099,0x7a4700a2}},	//   dano, piya_, _सोहळ, rété,
   {{0x60c93788,0x6abcb49d,0x799c01d5,0x00000000}},	//   jdem, lerf, murw, --,
   {{0x628328a2,0x60c901a8,0x69ceb49e,0x9f520355}},	//   fano, ddem, lvbe, ždém_,
   {{0x416a03fa,0x7cff01f4,0x645bb49f,0x248db4a0}},	//   ојим_, _kërc, _egui, _edem_,
   {{0x65c30a80,0xbebc0029,0x799c713a,0x60c90345}},	//   _ибра, lnīg, nurw, fdem,
   {{0xe6433c49,0x6abcb4a1,0x645b030d,0x00000000}},	//   _респ, herf, _ggui, --,
   {{0x6440029d,0x6abc008a,0x61fd00a8,0x799cb4a2}},	//   _uzmi, kerf, _əsli, hurw,
   {{0x62831423,0x799c01d5,0x7ce60067,0x00000000}},	//   cano, kurw, _górz, --,
   {{0x06970122,0xd12f3835,0xecd00354,0x00000000}},	//   ודים_, _ах_, _तोहफ, --,
   {{0xb4bc00a1,0x799c7d96,0x7afe0ab9,0x7cff0055}},	//   _असो_, durw, _alpt, _sërb,
   {{0x7cff01d2,0x6abc0110,0x00000000,0x00000000}},	//   _përb, ferf, --, --,
   {{0xe6c820af,0x6abc3afe,0xdbdc008d,0x73f90070}},	//   रयोज, gerf, ráðg, פּרו,
   {{0x799c0010,0x98c70009,0x00000000,0x00000000}},	//   gurw, мсал, --, --,
   {{0x6aaa02c9,0x7e6d022f,0x69d800d5,0x00000000}},	//   _öffn, _đapi, _švec, --,
   {{0x78adb4a3,0x6283b4a4,0x6abcb4a5,0x657c099e}},	// [d590] rfav, yano, berf, _awrh,
   {{0x628334c8,0x6b9d4a1c,0x60c9b4a6,0x645b00f1}},	//   xano, musg, zdem, _sgui,
   {{0x6283b4a7,0x60c9985f,0x6b9db4a8,0x273401ff}},	//   vano, ydem, lusg, vänt_,
   {{0x26c70bcc,0xf77302ed,0x69c5b4a9,0x765c099e}},	//   žno_, _لاس_, _ishe, _egry,
   {{0xdb0d00be,0x3cf90051,0x7e6a01bc,0x38691c5d}},	//   _osaü, iksv_, _offp, mcar_,
   {{0x38696f31,0x3959b4aa,0x877a0317,0x8c1c00a5}},	//   lcar_, _hiss_, _מאשי, חודי,
   {{0x6b9db4ab,0x3959b4ac,0x613e0055,0x00000000}},	//   husg, _kiss_, gëlo, --,
   {{0x628375fa,0x6b9db4ad,0x69c5a7c1,0x7c22008d}},	//   sano, kusg, _mshe, _þorg,
   {{0x6283b4ae,0x3959666e,0xa3d0021a,0x00000000}},	//   pano, _miss_, षिण_, --,
   {{0x69c5001c,0x799c04fb,0x0ea91667,0xb44400af}},	//   _oshe, yurw, чкой_, _рэск,
   {{0xdca61c20,0x628100ea,0xee3910a4,0x40591015}},	//   нани, _ielo, яно_, _فلاح_,
   {{0x6abc06d1,0xfce601e0,0x6e3c1c28,0x00000000}},	//   werf, хомо, ürba, --,
   {{0x6281b4af,0x69c50147,0x00000000,0x00000000}},	//   _kelo, _ashe, --, --,
   {{0xa3d00d00,0x7cff00da,0x628101a0,0xb4bc00b4}},	//   षित_, _përc, _jelo, _अस्_,
   {{0x3959048c,0x6abc0da2,0x4efa00a5,0x443a0023}},	//   _biss_, rerf, _מהסו, ́p_,
   {{0x6abc9b83,0x6281b4b0,0x799c0010,0x0d8201d3}},	//   serf, _lelo, rurw, _слън,
   {{0x36960036,0x69c5b4b1,0x6abc3430,0x62810298}},	// [d5a0] ешес, _eshe, perf, _oelo,
   {{0xf1c501a5,0x69c500da,0x00000000,0x00000000}},	//   _đáng_, _fshe, --, --,
   {{0x3959007a,0xeef60070,0x1a9b016b,0x8a7b00a5}},	//   _fiss_, עמער_, _ציטע, _מאית,
   {{0x62810297,0x3869b4b2,0xe81100a1,0x1426019e}},	//   _aelo, ccar_, _ठेवा_, ндем,
   {{0x6281b4b3,0xe3af27f6,0x234800e0,0x00000000}},	//   _belo, مرو_, وستی_, --,
   {{0x6281b4b4,0x31c63471,0xddda0097,0x00000000}},	//   _celo, есив, hatš, --,
   {{0x6281b4b5,0x26ca0103,0x70bd021a,0x00000000}},	//   _delo, _iabo_, ्यूल, --,
   {{0x6d5e00f7,0x26ca0282,0xf99300a5,0x6281018d}},	//   _épai, _habo_, ארה_, _eelo,
   {{0x6281b4b6,0x925a00d1,0x26ca6a58,0x032658e4}},	//   _felo, _فشار_, _kabo_, _здан,
   {{0x1ddb0821,0x62810b0d,0xfaff0031,0x26ca0371}},	//   यमंत, _gelo, hpër_, _jabo_,
   {{0x3207006a,0xa2dd0567,0x7bcf01e8,0x2d8a00b5}},	//   czny_, पार्, wvcu, ébe_,
   {{0x26cab4b7,0x628172f8,0x6b9db4b8,0xac1912ea}},	//   _labo_, _zelo, tusg, дому_,
   {{0xd12f0332,0xc4d300a5,0x6281b4b9,0x6aa50044}},	//   _امن_, אגר_, _yelo, _pchf,
   {{0x26ca203d,0x2fc60159,0xb51c00b4,0x69c50055}},	//   _nabo_, _isog_, पचुप_, _pshe,
   {{0x6b4002c9,0x318c00b8,0x945d0107,0x317e002f}},	//   mögl, něz_, _dańj, _jwtz_,
   {{0x3ebeb4ba,0x2eee2413,0x26ca0103,0x2d9eb4bb}},	//   lett_, _hoff_, _aabo_, mute_,
   {{0xf7701168,0x38692c35,0x2d9eb4bc,0x39591769}},	// [d5b0] مال_, rcar_, lute_, _viss_,
   {{0x3869b4bd,0x69c501a9,0x26ca1423,0x3ebe851f}},	//   scar_, _tshe, _cabo_, nett_,
   {{0x6281b4be,0x26ca3df6,0xa2a40edf,0x2d9e1116}},	//   _relo, _dabo_, च्छ्, nute_,
   {{0x6281b4bf,0xd4e4225d,0xd04600a8,0xe4e412ea}},	//   _selo, лючи, şməl, лічн,
   {{0x6281b4c0,0x3ebe20be,0x26ca00ee,0x2d9e22db}},	//   _pelo, kett_, _fabo_, hute_,
   {{0x2d9eb4c1,0xa2d40026,0x26ca2cc0,0x6b8d0027}},	//   kute_, _योद्, _gabo_, _mvag,
   {{0x3ebe394e,0x00000000,0x00000000,0x00000000}},	//   dett_, --, --, --,
   {{0x2d9eb4c2,0x26ca0010,0x6281b4c3,0xed63031d}},	//   dute_, _zabo_, _welo, _leží_,
   {{0x26ca0232,0x3ebeb4c4,0x2eee021d,0x13b428c0}},	//   _yabo_, fett_, _boff_, _مصلح,
   {{0x2d9e7f2c,0x2eee0036,0x6eff0132,0x2fc6008c}},	//   fute_, _coff_, _bêba, _dsog_,
   {{0x2d9eb4c5,0x6b8da0ac,0x00000000,0x00000000}},	//   gute_, _avag, --, --,
   {{0x7cff0031,0x00000000,0x00000000,0x00000000}},	//   _përa, --, --, --,
   {{0x3ebeb4c6,0xed6307c0,0xe811167e,0xd9ca08b0}},	//   bett_, _beží_, _ठेला_, ाट्ट,
   {{0x2eee0024,0x2d9e1229,0x60cb0cd9,0x00000000}},	//   _goff_, bute_, _hagm, --,
   {{0x26cab4c7,0x19b92698,0x6b4001ff,0x2d9e1116}},	//   _rabo_, нуть_, sögo, cute_,
   {{0x26cab4c8,0x2eee329b,0x60cb005f,0xa3e101c0}},	//   _sabo_, _zoff_, _jagm, धमा_,
   {{0x60cbb4c9,0xccf30122,0xf7722e36,0x3cdf021a}},	// [d5c0] _magm, _ככה_, شاء_, गारे_,
   {{0x60cbb4ca,0x2eee00d7,0xbebc00ea,0xe9da00af}},	//   _lagm, _xoff_, mnīc, _жко_,
   {{0xd6cf2087,0xc486b4cb,0xdb1601ef,0xd5d5010b}},	//   تقل_, влек, _npyé, люцы,
   {{0x3ebe0332,0x60cbb4cc,0x26ca0010,0x225e012f}},	//   zett_, _nagm, _wabo_, _sgtk_,
   {{0xa3b41728,0x2d9eb4cd,0x64a3b4ce,0x26cab4cf}},	//   ублі, zute_, рача, _tabo_,
   {{0x93435195,0x78a4b4d0,0x7afc03c9,0x318c0355}},	//   анче, lgiv, nkrt, těz_,
   {{0x55e31a8e,0x3ebeb4d1,0x60cb0b3e,0xab5b02b1}},	//   _корб, vett_, _bagm, kwün,
   {{0x78a44f61,0x3ebe0005,0x2d9eb4d2,0xddd81efc}},	//   ngiv, wett_, vute_, _nevš,
   {{0x3ebe0332,0xa3b6018d,0x656900ea,0x3ce637e8}},	//   tett_, _जहि_, _čehi, टाने_,
   {{0x2484048c,0x2d9eb4d3,0x629e0a20,0x7522b4d4}},	//   _hemm_, tute_, ópod, lnoz,
   {{0x6b8db4d5,0x24840484,0x69d801c8,0xe2a90919}},	//   _svag, _kemm_, _šven, _سالن_,
   {{0x3ebeb4d6,0xa3b61a75,0x2fc60221,0x60cb02b3}},	//   sett_, _जहा_, _tsog_, _gagm,
   {{0x5f06022c,0xaade02e4,0x78a40c66,0x6d4f0392}},	//   _изда, मांक, dgiv, rmca,
   {{0x68ef0409,0x2d9eb4d7,0x9b4500f8,0x52c019b7}},	//   _socd, pute_, انسو, _एसोस,
   {{0x3eab0bca,0xd90f00b5,0xdbdd0298,0x60cbb4d8}},	//   žitý_, قید_, _dáár, _yagm,
   {{0x78a40036,0x60c0b4d9,0x00000000,0x00000000}},	//   ggiv, nemm, --, --,
   {{0x7522113c,0x5884010b,0x613e0345,0x00000000}},	// [d5d0] dnoz, рыса, eëlk, --,
   {{0x60c0b4da,0x24840159,0xb87b00b8,0x00000000}},	//   hemm, _aemm_, _sníd, --,
   {{0x60c0b4db,0x2d8c0a81,0x95c800af,0x68ef00cc}},	//   kemm, nsde_, куца_, _tocd,
   {{0x60c0b4dc,0x212601f4,0x6d5e00f7,0xb86702fd}},	//   jemm, _njoh_, _épau, _جادو,
   {{0x44293a51,0x24580a93,0x60c0b4dd,0x289a0100}},	//   ça_, ваць_, demm, _אירא,
   {{0x05130083,0x4429003c,0x60cb03bc,0x00000000}},	//   িকের_, ħa_, _sagm, --,
   {{0x60cb8409,0x60c0b4de,0xbebc00ea,0x28aa00b8}},	//   _pagm, femm, znīc, ङ्कि,
   {{0x50457bff,0x7522027a,0x26c1b4df,0xb87b01ef}},	//   лейб, cnoz, leho_, _uníd,
   {{0x3f42008a,0x7cffb4e0,0xddd80116,0x2d8c2069}},	//   rðun_, _përn, _revš, esde_,
   {{0x26c1b4e1,0x63bb5d02,0xe8e00066,0xfde93c45}},	//   neho_, _ipun, _पच्च, едок_,
   {{0xef16002d,0x00000000,0x00000000,0x00000000}},	//   умэ_, --, --, --,
   {{0xeb9aa3d3,0xe0d018dd,0x60c000f7,0x61e502b1}},	//   ним_, _وزن_, cemm, ählu,
   {{0x8ca50240,0x69d7b4e2,0x6fb70026,0x5fb70311}},	//   _कारो, _arxe, _अहिं, _अहिल,
   {{0x6da5002d,0x63bb1cf5,0x26c10010,0x6f920037}},	//   _бика, _mpun, jeho_, _الوض,
   {{0xceb20052,0xbebc0080,0x660900b8,0x26c100d5}},	//   _היו_, snīc, _řekn, deho_,
   {{0x63bbb4e3,0xb87b2dea,0x52c000b4,0xbebc0228}},	//   _opun, _aníb, _एस्स, pnīc,
   {{0xd9431e56,0x7d04b4e4,0x6b89042a,0x28aa06fe}},	// [d5e0] сети, _ilis, šegr, ङ्गि,
   {{0x78a4b4e5,0x7d040034,0x4b7b0d85,0x75221140}},	//   sgiv, _hlis, _ראיו, wnoz,
   {{0x63bb3d46,0x5efa0070,0x3ce00075,0x6d5e00a2}},	//   _apun, עפעד, _kniv_, _épat,
   {{0x7d040069,0xd76600fd,0x63bb026e,0x00000000}},	//   _jlis, _ماسٹ, _bpun, --,
   {{0x26c1010a,0x7d04023c,0x60c00421,0x00000000}},	//   beho_, _mlis, vemm, --,
   {{0x3940b4e6,0x7d040955,0x26c1016f,0x31650160}},	//   llis_, _llis, ceho_, _bulz_,
   {{0x7d0403ad,0x8ca50240,0x2f000107,0x80d5021a}},	//   _olis, _कालो, _bògn_, _मोहे,
   {{0xb87b00c9,0x7643004e,0x63bb0069,0x752200a8}},	//   _iníc, żnyc, _fpun, qnoz,
   {{0x60c00f9e,0x7dea0095,0x69d800c7,0x3940b4e7}},	//   remm, məsi, _švel, ilis_,
   {{0x7d04b4e8,0xd24f00bf,0x7dea0095,0x60c0b4e9}},	//   _alis, _کنم_, ləsi, semm,
   {{0x3940b4ea,0x073702b8,0x2126022e,0xf1a90c74}},	//   klis_, ראים_, _tjoh_, _لانه_,
   {{0x39401d11,0x628ab4eb,0x26c10010,0x7d04a503}},	//   jlis_, lafo, zeho_, _clis,
   {{0x26c10232,0x63a2b4ec,0x8ff701b2,0x7d040098}},	//   yeho_, nuon, _مرور_, _dlis,
   {{0xe1f10332,0x7dea01c2,0xc6bf0083,0x628ab4ed}},	//   _اسے_, həsi, _উচ্চ, nafo,
   {{0x63a2b4ee,0x7d04b4ef,0x1efb0070,0x26c18205}},	//   huon, _flis, _אלגע, veho_,
   {{0x6f1a5ecc,0x7d04b4f0,0x394066d7,0x63a2b4f1}},	//   litc, _glis, glis_, kuon,
   {{0x6c7807f6,0x6d4d01a2,0x7dea0095,0x628a51f7}},	// [d5f0] _صحيح_, _ihaa, dəsi, kafo,
   {{0x3940b4f2,0x6d4d006d,0x7d1601ba,0x63a2b4f3}},	//   alis_, _hhaa, _zmys, duon,
   {{0x63bb0012,0x26c1b4f4,0x394b0019,0x6d4d034d}},	//   _spun, reho_, _thcs_, _khaa,
   {{0x26c1b4f5,0x297a0319,0x3940b4f6,0x6f1a0345}},	//   seho_, _שטרא, clis_, hitc,
   {{0xdfc622c4,0x63a25e0c,0x6d5f00d7,0xe28502ee}},	//   _بي_, guon, _miqa, алли,
   {{0x68edb4f7,0xdd860f98,0xa3b60299,0x628ab4f8}},	//   ljad, _وو_, _जहर_, gafo,
   {{0x6f1a01e4,0x7dea0095,0xf075006c,0x6b9d0137}},	//   ditc, bəsi, لیاں_, hrsg,
   {{0x68ed203f,0x7dea0095,0xe0d914a1,0x657506ab}},	//   njad, cəsi, тви_, _itzh,
   {{0x63bb0054,0xaf05116b,0x63a212ec,0x753b9ca8}},	//   _upun, ипил, cuon, _ikuz,
   {{0x6d4d195d,0x518700d8,0x628a01f7,0x7d1600b8}},	//   _ahaa, _буда, cafo, _smys,
   {{0x7d04b4f9,0x1d0a0b46,0x245a027d,0x6b9d0051}},	//   _plis, вени_, _tümü_, ersg,
   {{0x443fb4fa,0xcb6a5d99,0x68edb4fb,0x7fd50823}},	//   _kyu_, каме_, jjad, _вікі,
   {{0x29090657,0x6d4d1413,0xdee50b3b,0x7d04b4fc}},	//   dhaa_, _dhaa, _воли, _vlis,
   {{0x7dea00a8,0x68ed02d7,0x6d4d01b7,0xbea2010b}},	//   zəsi, ejad, _ehaa, _дашк,
   {{0xfc3f0033,0xada50df8,0x7d040069,0x6d5f00d7}},	//   rgía_, _тайл, _tlis, _fiqa,
   {{0x7529029d,0x7d040ce0,0x613e01f4,0x3940b4fd}},	//   _njez, _ulis, tëli, ulis_,
   {{0x3940b4fe,0xa68601e0,0x07a670a5,0x7dea0095}},	// [d600] rlis_, илад, разн, vəsi,
   {{0x3940b4ff,0x753bb500,0x6d5f00f7,0x5a961888}},	//   slis_, _akuz, _épar, _триф,
   {{0x394002e9,0x7dea0095,0x09e67bfa,0xd946b501}},	//   plis_, təsi, _тонн, _вени,
   {{0x63a2b502,0x6b840232,0x443fb503,0x290908c7}},	//   tuon, _kwig, _byu_, chaa_,
   {{0xb6070029,0x7dea0095,0xf86302ce,0x2900002f}},	//   ekšē, rəsi, _євро, mkia_,
   {{0x2900b504,0x6b840848,0x7dea00a8,0x611300af}},	//   lkia_, _mwig, səsi, călz,
   {{0xe81a0bc1,0x64493658,0x63a2b505,0x69d80791}},	//   _नेता_, _ezei, suon, _švej,
   {{0x7cff01d2,0x64a3b506,0x3f4200fb,0x628ab507}},	//   _përm, _маса, rðum_, safo,
   {{0x63a22939,0x2900b508,0x00000000,0x00000000}},	//   quon, ikia_, --, --,
   {{0x6d4db509,0x3eb80093,0x65600024,0x6d5f00a8}},	//   _shaa, ýrt_, _himh, _siqa,
   {{0xb6d902b5,0x29000086,0x68ed012f,0x628800ea}},	//   אַרט, kkia_, yjad, _iedo,
   {{0x6b8401d5,0x7cff0031,0x215a15dc,0x443f0103}},	//   _bwig, _tërm, _شجاع_, _yyu_,
   {{0x62886338,0x6f1a0124,0xdb040138,0x442d488c}},	//   _kedo, pitc, _apiñ, _xxe_,
   {{0x7cff01d2,0x6288b50a,0x6560b50b,0x6d4db50c}},	//   _kërk, _jedo, _limh, _whaa,
   {{0x6b8489b5,0x8d94004f,0x6da30798,0x68ed0443}},	//   _ewig, _البش, _дија, tjad,
   {{0x7c2d06a2,0x628843fa,0x7cff0031,0x27e901b7}},	//   _txar, _ledo, _mërk, txan_,
   {{0x68edb50d,0x76b90328,0xf7731c51,0x19581ac5}},	// [d610] rjad, ллар_, تاز_, раты_,
   {{0x290911c2,0x753bb50e,0x6560006b,0x7bcd005f}},	//   shaa_, _skuz, _aimh, _isau,
   {{0x443f0ac8,0x59f900af,0x200d1783,0x35b5174b}},	//   _syu_, _сеня_, zzei_, сбер,
   {{0x7d1db50f,0xd12606ca,0x81bc0083,0x64400b3e}},	//   niss, _رم_, ইটা_, _bymi,
   {{0x62880a45,0x7cff00da,0xe2991517,0x2d9e01ae}},	//   _bedo, _përj, гал_, hrte_,
   {{0x7d1db510,0x6288027a,0x05776f4e,0x65600211}},	//   hiss, _cedo, _نارد, _eimh,
   {{0x7d1db511,0x3201031d,0xf42600c3,0x94d5005c}},	//   kiss, áhy_, _ääni_, _ловц,
   {{0x1dd50efa,0x753b10a2,0x7d1db512,0x16c7046c}},	//   धिसत, _ukuz, jiss, _रघुब,
   {{0x6288b513,0x7d1d145d,0x2d9eb514,0x443f0232}},	//   _fedo, diss, erte_, _uyu_,
   {{0x628812b0,0xaf052839,0x29004248,0x26d101b7}},	//   _gedo, спол, zkia_, _jazo_,
   {{0x7d1db515,0x7bcd010d,0x26d102d4,0x2900563f}},	//   fiss, _asau, _mazo_, ykia_,
   {{0x7d1dac1d,0x62880526,0x26d11594,0x4155b516}},	//   giss, _zedo, _lazo_, _увес,
   {{0x38c80e3a,0x2d9e1908,0x8fc70a72,0x613e0031}},	//   یاری_, arte_, _خزان, gëlu,
   {{0x20a70299,0x26d115c4,0x63a401a6,0xcb67002d}},	//   _गाँध, _nazo_, àini, саре_,
   {{0x7d1d14e7,0x7bcd0382,0x2d9e00cd,0x29000421}},	//   biss, _esau, crte_, tkia_,
   {{0x7d1d4165,0x6b841596,0x7d7639e6,0x7866b517}},	//   ciss, _twig, _امير_, сказ,
   {{0x6903007c,0x2900b518,0x3cf10187,0x26d1b519}},	// [d620] _tõen, rkia_, žová_, _bazo_,
   {{0x3ce6065a,0xb8ff1fb4,0x2900b51a,0x65601f2c}},	//   टावे_, _धो_, skia_, _simh,
   {{0x20a70821,0xf992500b,0xb0a70d2a,0x6440b51b}},	//   _गांध, _عبد_, _गांग, _symi,
   {{0x6288b51c,0xe76a0e0c,0x64a61006,0x690300be}},	//   _sedo, _محسن_, сада, _jõel,
   {{0x6903007c,0xb87bac97,0x26d10116,0x7dea00a8}},	//   _mõel, _unía, _fazo_, ləst,
   {{0x7cff01d2,0x26d1b51d,0x3872021d,0x00000000}},	//   _përk, _gazo_, lcyr_, --,
   {{0x6440006a,0x6288a089,0x7e7e007c,0xd13a2701}},	//   _wymi, _vedo, _õppi, лхи_,
   {{0x1f7400af,0x65600a32,0x7d1db51e,0x628800d1}},	//   олия, _uimh, xiss, _wedo,
   {{0x7d1db51f,0x6b400093,0x26d104fb,0x00000000}},	//   viss, lögu, _yazo_, --,
   {{0x7d1db520,0xdce409ed,0x613e0298,0x00000000}},	//   wiss, _dunč, eëlt, --,
   {{0x7d1d1e42,0x200204c3,0xa3d009b1,0x00000000}},	//   tiss, ški_, षिक_, --,
   {{0x7f8301df,0xa06a03fa,0xc5f30122,0x2d9eb521}},	//   _کلون, _сада_, לדת_, rrte_,
   {{0x7d1db40c,0x70561c51,0x30e51140,0xd0e50931}},	//   riss, _انشا, कारः_, कारण_,
   {{0x7d1db522,0xde580a93,0x00000000,0x00000000}},	//   siss, _калі_, --, --,
   {{0x7d1d059c,0xaa590424,0x00000000,0x00000000}},	//   piss, риву_, --, --,
   {{0x7bcd01a9,0xa3e8000c,0x6b40008d,0xe81a198f}},	//   _tsau, यमा_, dögu, _नेहा_,
   {{0xc1b5159b,0x02fa0302,0x26d10391,0x7bcd011e}},	// [d630] _अङ्ग, ्साह_, _pazo_, _usau,
   {{0xa80201ef,0x00000000,0x00000000,0x00000000}},	//   úñan, --, --, --,
   {{0x7cff01f4,0x947713cf,0x26d194c3,0x7e6d0225}},	//   _përh, مدشا, _vazo_, _şapk,
   {{0xa8a759c4,0x26d12f10,0xb87b0037,0x2e3b0070}},	//   _урок, _wazo_, _inío, נגאנ,
   {{0x62655674,0x7af701ed,0x00000000,0x00000000}},	//   овла, _koxt, --, --,
   {{0xaaad06fe,0x69d8123c,0x00000000,0x00000000}},	//   ञ्चक, _švei, --, --,
   {{0x945d004e,0xdce40a78,0x7cff01f4,0x8afc0070}},	//   _pańs, _sunč, _tërh, רהוי,
   {{0xdce4b523,0x7af70345,0xdca50067,0x1fd20831}},	//   _punč, _loxt, _कागज़, ়মনস,
   {{0x4f09141d,0x00000000,0x00000000,0x00000000}},	//   инин_, --, --, --,
   {{0xdcc206bb,0xef1908ce,0x00000000,0x00000000}},	//   षज्ञ, рмо_, --, --,
   {{0xaceab524,0x3ce6045c,0x6b52054e,0x7cff0031}},	//   амна_, टाले_, lægg, _zëri,
   {{0xa3ad0722,0x7ae50023,0x00000000,0x00000000}},	//   _कमा_, _anht, --, --,
   {{0x3fc900f8,0x7af70051,0x1b4a019e,0xb87b0079}},	//   _خدای_, _boxt, изми_, _anío,
   {{0x613e0055,0x15f900be,0x00000000,0x00000000}},	//   bëls, ंहार_, --, --,
   {{0xfd12004f,0x690300ab,0xab190746,0x00000000}},	//   _يجب_, _tõel, сцях_, --,
   {{0x186702bb,0x65680118,0x00000000,0x00000000}},	//   жати_, _édhi, --, --,
   {{0x9aa50ef2,0x2d87009e,0x00000000,0x00000000}},	// [d640] _کمپو, _hwne_, --, --,
   {{0x6d4600da,0xb87b0042,0x4ded00b4,0x00000000}},	//   llka, _unín, _छपाई_, --,
   {{0xb87b0082,0xa2d40f9f,0xe61a0370,0x7cff01f4}},	//   _gnío, _योग्, јде_, _sëri,
   {{0xd9461edd,0x69de07e5,0xec360070,0x2d870260}},	//   _феми, _irpe, ֿאַר_, _mwne_,
   {{0x6d4605eb,0xfbca0e6f,0x69de003d,0x6b400093}},	//   ilka, िबिम, _hrpe, sögu,
   {{0x2ae30035,0x69de2df4,0x6d4602b1,0xb0620421}},	//   खाएँ_, _krpe, hlka, äämi,
   {{0xaab29f50,0x4ab20299,0x00000000,0x00000000}},	//   _जानक, _जानव, --, --,
   {{0xa2ba02e4,0xd1300037,0x00000000,0x00000000}},	//   _शॉर्, عمة_, --, --,
   {{0xc9530122,0x5ed30083,0xe4d729fe,0x00000000}},	//   ומה_, তানে, _بوقت_, --,
   {{0x7b1002c9,0x69deb525,0x6d460479,0xeeb700d8}},	//   _häuf, _orpe, elka, ольш_,
   {{0x7b10033b,0x63a20345,0x6b4001ff,0x00000000}},	//   _käuf, lron, högs, --,
   {{0x3f8602d0,0x00000000,0x00000000,0x00000000}},	//   _twou_, --, --, --,
   {{0x9f4601ae,0xbec5013a,0x00000000,0x00000000}},	//   _groß_, _brūč, --, --,
   {{0x6d469e5a,0x7b1001ae,0x68e60282,0xbd6a3cc0}},	//   alka, _läuf, _ankd, _крие_,
   {{0x63a27cca,0x59ce4e29,0x2d910355,0xdd07013b}},	//   hron, _हैदर, ázet_, şqır,
   {{0x8d180206,0x63a236ee,0x2f000211,0xdc3f00d5}},	//   _وزير_, kron, _sògh_, líčo,
   {{0x63a200d1,0xf7700ca8,0xfcaa0070,0x466b1353}},	// [d650] jron, نال_, _היפּ, арем_,
   {{0x3f7b02b5,0x629ea372,0x7cff0055,0x00000000}},	//   יאמס, ópol, _cërv, --,
   {{0x63a2b526,0x7e7e00be,0xb0bc02b4,0x6903018d}},	//   eron, _õppu, ्जाग, _jõek,
   {{0x63a2b527,0xf9da02b5,0x629a3120,0x613e01f4}},	//   fron, _פֿיל, _adto, këlq,
   {{0x63a2b528,0x2bde23e3,0x316c013a,0x00000000}},	//   gron, मिया, _audz_, --,
   {{0x78ad0029,0x6595005f,0xe738010b,0xc8ab073f}},	//   lgav, _нагу, _меў_, _छाँट,
   {{0x63a2141b,0x6d4600fe,0x00000000,0x00000000}},	//   aron, ylka, --, --,
   {{0x78adb529,0xddc80067,0x00000000,0x00000000}},	//   ngav, łośn, --, --,
   {{0x63a2b52a,0x8ca50026,0x6b5208c8,0xf8bf0118}},	//   cron, _काजो, læge, _mbé_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdfabf4,0x248d006d,0xb87b20d9,0x9d460009}},	//   _arqu, _keem_, _aním, зенд,
   {{0x6d462bd6,0x71d6011d,0x78ad0051,0xac83002d}},	//   ulka, _מועד_, jgav, нгюл,
   {{0x80270082,0x248d0189,0x69de00b8,0x60c901a8}},	//   _برام, _meem_, _srpe, meem,
   {{0x63a4b52b,0x3d02004e,0x60c93f60,0x2fcd0a8d}},	//   šing, _mówi_, leem, mweg_,
   {{0x2fcd939d,0xed5a19d9,0x2365b52c,0x6f1800b5}},	//   lweg_, _лок_, _milj_, _بزنس_,
   {{0x248d0d26,0x63a2b52d,0x60c9b52e,0x78adb52f}},	//   _neem_, yron, neem, ggav,
   {{0x7cff00da,0x2fcdb530,0x8cbc0ed1,0xb87b0098}},	// [d660] _përv, nweg_, ष्णो, _gním,
   {{0x69de0e42,0x63a200f7,0x60c936a1,0x00000000}},	//   _trpe, vron, heem, --,
   {{0x60c91e7b,0x69deb265,0x2fcd02b1,0x00000000}},	//   keem, _urpe, hweg_, --,
   {{0x248d0221,0x290b01ef,0x2fcd0223,0x00000000}},	//   _ceem_, _glca_, kweg_, --,
   {{0x248db531,0xe7940580,0x69dc0557,0x645d031d}},	//   _deem_, _تاجک, lvre, _úsil,
   {{0x23651848,0xa3ad0084,0x752b012f,0xb3e902e7}},	//   _cilj_, _कमर_, angz, تعمل_,
   {{0x5186005f,0x248d0189,0x69dc0298,0xd24f39e5}},	//   чула, _feem_, nvre, هنه_,
   {{0x63a2b532,0x859b0122,0xe01d0035,0x1fa62a21}},	//   pron, _לשלו, _बेहद_, прог,
   {{0x03a302d6,0x2fcd0b0d,0x00000000,0x00000000}},	//   _пито, gweg_, --, --,
   {{0x78ad0169,0xdce40029,0x248d0221,0x0dca0610}},	//   zgav, _runā, _zeem_, буми_,
   {{0x248d01a9,0x908a004f,0x127b02b5,0xb87b053d}},	//   _yeem_, _هناك_, _האבע, _sním,
   {{0x248d0189,0x673e0051,0x69dc0345,0x613e0055}},	//   _xeem_, hopj, dvre, pëlq,
   {{0x656e0dc3,0x673eb533,0x8ae701e0,0x80d500b4}},	//   _lubh, kopj, півл, _मोटे,
   {{0x7b6400c9,0xa2bf021a,0xb87b0187,0x4ab200a1}},	//   етсе, ल्प्, _vním, _जाणव,
   {{0x7cff01f4,0xceb30319,0x78adb534,0x69dc0345}},	//   _bërt, _ניק_, tgav, gvre,
   {{0x8e47004f,0x6b5201b4,0xa3ad19b7,0x7cff0031}},	//   _عليك_, væge, _कमल_, _përu,
   {{0x38344a4e,0x78adb535,0x7bdf2b01,0x248d011e}},	// [d670] ентр, rgav, _urqu, _reem_,
   {{0x7d0d0076,0x3ce9006f,0x04f90083,0x248d94ab}},	//   _hlas, _hnav_, _আগের_, _seem_,
   {{0x28f92830,0x248d01e8,0x78ad03db,0x656e01da}},	//   _день_, _peem_, pgav, _cubh,
   {{0x69c50176,0x656e09c3,0x752201a0,0xf6500079}},	//   _iphe, _dubh, gioz, ائك_,
   {{0x3949b536,0x656e01da,0xe28e02a4,0x7d0d0160}},	//   mlas_, _eubh, ка_, _mlas,
   {{0x49b800bf,0x2bde0517,0x3949449a,0x7d0d2f8b}},	//   _باید_, मिता, llas_, _llas,
   {{0x248d006f,0x7d0db537,0x60c9b538,0x3949b539}},	//   _teem_, _olas, teem, olas_,
   {{0x7c3a004e,0x2fcd320a,0x600902bb,0xa1560274}},	//   ętrz, tweg_, жним_, мају_,
   {{0x3949b53a,0xa2b501d3,0x60c9ac3a,0xa3e8022e}},	//   ilas_, _обач, reem, यमः_,
   {{0x2fcd6d57,0x69c5b53b,0x60c9b53c,0x394949ff}},	//   rweg_, _ophe, seem, hlas_,
   {{0xdca600ca,0x3949b53d,0x2fcdb53e,0x7bc40031}},	//   мани, klas_, sweg_, _spiu,
   {{0x63a400f4,0x69dc02c4,0x3ce900f6,0x00000000}},	//   šine, vvre, _cnav_, --,
   {{0x63ab0159,0x2bd5018d,0x00000000,0x00000000}},	//   nugn, दिगा, --, --,
   {{0x3949b53f,0xada1016f,0x752201a3,0xdce400af}},	//   elas_, ľúbe, zioz, _bună,
   {{0x63ab4523,0x7cff01f4,0x5ed30033,0xb87b00a0}},	//   hugn, _përt, তাদে, _kníh,
   {{0x3949b540,0x7d0d56fa,0xdce400af,0x69dcb541}},	//   glas_, _glas, _dună, rvre,
   {{0x69c5271d,0x7cff01d2,0x657c0097,0x6d44b542}},	// [d680] _ephe, _vërt, _strh, _ikia,
   {{0x3949b543,0x7d0d008b,0xa2bf0437,0x61e100e9}},	//   alas_, _zlas, ल्म्, _orll,
   {{0x3949b544,0x186a12a2,0x673eb545,0x7cff0055}},	//   blas_, _мани_, ropj, _gërs,
   {{0x100d0d2a,0x657c00ac,0x63ab02b1,0x00000000}},	//   िनाश_, _vtrh, fugn, --,
   {{0x75225d52,0x31c600df,0x63ab5b01,0x394023bb}},	//   rioz, लब्ध, gugn, mois_,
   {{0x394000a2,0x7522b546,0x656e009e,0x00000000}},	//   lois_, sioz, _tubh, --,
   {{0xaac00567,0x657c00ac,0x966384cc,0x00000000}},	//   श्यक, _utrh, _акре, --,
   {{0x3940b547,0x6d4401e8,0x63ab0430,0x399b011d}},	//   nois_, _nkia, bugn, קיפד,
   {{0x26d801ca,0x8fa31c56,0x6e94167d,0x63ab0036}},	//   _karo_, вање, нипу, cugn,
   {{0x26d80d14,0x2486b548,0x39403762,0x6d44b549}},	//   _jaro_, lbom_, hois_, _akia,
   {{0x7d0db54a,0x26d8b54b,0x2d98b54c,0x39492a8e}},	//   _plas, _maro_, ére_, ylas_,
   {{0x26d800a7,0x6d56011e,0x7e6d00af,0x3f420093}},	//   _laro_, _chya, _şapt, gður_,
   {{0x29120fde,0x6d563347,0x39491884,0x28df0d1f}},	//   dhya_, _dhya, vlas_, _पोषि,
   {{0x7cff01d2,0x6d4401d7,0x21240037,0x7d0d0035}},	//   _përs, _ekia, limh_, _wlas,
   {{0x39400248,0x69d800cd,0x3eb900a8,0xcda70833}},	//   fois_, _šver, əst_, _قهوه_,
   {{0x7d0d1f8a,0x21240315,0x6d44009e,0x7cff0031}},	//   _ulas, nimh_, _gkia, _vërs,
   {{0x3949b54d,0x2004324f,0x2486247c,0x8bd400d8}},	// [d690] rlas_, nymi_, dbom_, _ажыц,
   {{0xb9060311,0x3949b54e,0x26d84e3d,0x08540086}},	//   _यो_, slas_, _caro_, твую,
   {{0x26d8b54f,0xb0ae02e4,0x39400fce,0x60c20168}},	//   _daro_, _टांग, bois_, _obom,
   {{0x63ab897b,0x6b8db550,0xdc3f00d5,0x39404135}},	//   tugn, _kwag, _líčk, cois_,
   {{0xc86419fa,0x2fc6006f,0x2124006b,0xc3cb1062}},	//   _атри, _npog_, dimh_, تظام_,
   {{0x29090421,0x60c238d3,0x6b8d2506,0x26d80197}},	//   lkaa_, _abom, _mwag, _garo_,
   {{0x2fc6010d,0x3f42008d,0x6145136a,0x63abb551}},	//   _apog_, yður_, нека, sugn,
   {{0x63abb552,0x26d80009,0x290902ee,0x60c2009e}},	//   pugn, _zaro_, nkaa_, _cbom,
   {{0x83351728,0x26d80027,0x249f0024,0x68fd72d9}},	//   _знах, _yaro_, _idum_, _mosd,
   {{0x6d44b553,0x6d5601d5,0x68fd0176,0xb354199d}},	//   _skia, _shya, _losd, _акуш,
   {{0x290903ad,0xd12e0df3,0x6b8d3736,0x65690421}},	//   kkaa_, شمی_, _awag, _kieh,
   {{0x28df02cb,0xfd120180,0x6b8d0b69,0x249f007a}},	//   _पोलि, اجد_, _bwag, _jdum_,
   {{0xeb97a1d7,0x3f42064b,0x65690086,0x60db02b3}},	//   ния_, rður_, _mieh, mdum,
   {{0x3b0a03ad,0x60dbb554,0x2486022f,0x68fd006b}},	//   чего_, ldum, zbom_, _aosd,
   {{0xf2d202b5,0x1d0a03fa,0xc3320d85,0x7f4142ae}},	//   װען_, _неки_, אום_, molq,
   {{0x60db352c,0x65692202,0x6d440054,0x68fd0211}},	//   ndum, _nieh, _ukia, _cosd,
   {{0x237f0d4b,0x07a32490,0x26d8b555,0x6b8d1494}},	// [d6a0] _ntuj_, латн, _paro_, _gwag,
   {{0x60d93a1e,0x29120232,0x7bd6067f,0x2a7a0183}},	//   _lawm, shya_, _isyu, _ufpb_,
   {{0x394000c9,0x26d8aa98,0x60db0159,0x68fdb556}},	//   pois_, _varo_, kdum, _fosd,
   {{0xb0ae11b5,0x2ca000d7,0x64490103,0x98a0b557}},	//   _टाइग, _jdid_, _byei, dnić_,
   {{0x6569243d,0x26d8b558,0x7afe4a8e,0x248600cd}},	//   _dieh, _taro_, _kopt, rbom_,
   {{0x65690345,0xbcfb000d,0xeb930070,0x00000000}},	//   _eieh, mmée, אָק_, --,
   {{0x2004004e,0x64a600d8,0x98a00009,0x2fc603bc}},	//   wymi_, _пава, gnić_, _spog_,
   {{0x7afe2296,0x80bc02e4,0x60d9006d,0x60db03be}},	//   _lopt, ्जें, _cawm, gdum,
   {{0x21240037,0x25af0035,0x7afe0298,0x00000000}},	//   rimh_, ągle_, _oopt, --,
   {{0x6569a911,0x2ca00107,0x6d5d006d,0x6b8d01d5}},	//   _zieh, _adid_, wmsa, _rwag,
   {{0x6b8d10c3,0x7bd610cd,0x80bd0099,0x27e061f7}},	//   _swag, _asyu, व्हे, hvin_,
   {{0x7cff01f4,0x614649a8,0x60c2034d,0x27e01626}},	//   _përq, _џеда, _ubom, kvin_,
   {{0x6d5d6b75,0x7afe0090,0x00000000,0x00000000}},	//   rmsa, _bopt, --, --,
   {{0x27e031bb,0xdcfb010b,0x7b1002b1,0x00000000}},	//   dvin_, ystė, _räuc, --,
   {{0x60d901e8,0x29090086,0x68fdb559,0xb9250037}},	//   _yawm, tkaa_, _posd, نفسي,
   {{0x58d425a0,0x6b8d01d0,0x290f0037,0x2ca0007a}},	//   лост, _twag, óga_, _gdid_,
   {{0x29090421,0x6b8da955,0x6934097a,0xbcfb1498}},	// [d6b0] rkaa_, _uwag, унту, rméd,
   {{0x656902c9,0x81d70083,0x290900c3,0x6b5201b4}},	//   _sieh, ামত_, skaa_, lægn,
   {{0x64490ec0,0xfb1c00a5,0x3ce6252b,0x68fd0211}},	//   _syei, _מוזמ, _जोडे_, _tosd,
   {{0x48ab03ad,0x237f008b,0xf773b55a,0xbcfb00b5}},	//   _этом_, _ptuj_, _ماس_, lméb,
   {{0xc6a71c56,0x65695d91,0x98a00067,0x00000000}},	//   _први, _vieh, wnić_, --,
   {{0x8c1c0122,0x6569035f,0x130801e0,0x98a07afd}},	//   הודי, _wieh, нній_, tnić_,
   {{0x15a801d3,0x00000000,0x00000000,0x00000000}},	//   _пъти_, --, --, --,
   {{0xf9941899,0x60d9009f,0x98a0012e,0x25fe00be}},	//   ארק_, _qawm, rnić_, लहरी_,
   {{0x200b033a,0x60dbb55b,0xe0d61db7,0x98a000cd}},	//   áci_, rdum, твы_, snić_,
   {{0xaf050279,0x00000000,0x00000000,0x00000000}},	//   тпол, --, --, --,
   {{0x7cff01d2,0x200b0944,0x60d9006d,0x690300be}},	//   _përp, šci_, _tawm, _jões,
   {{0x2bde045c,0xeb9a761c,0x7afeb55c,0x00000000}},	//   मिला, мим_, _sopt, --,
   {{0x7afe01c0,0x00000000,0x00000000,0x00000000}},	//   _popt, --, --, --,
   {{0xa3e20d00,0xe8ff0248,0x395900ee,0x05d1021a}},	//   धित_, _aoû_, _ahss_, सबाब,
   {{0xcb6744d9,0x00000000,0x00000000,0x00000000}},	//   таре_, --, --, --,
   {{0x2d8504b0,0x27e06de5,0xf772026b,0x00000000}},	//   mple_, tvin_, لائ_, --,
   {{0xa6960274,0x81d70033,0x27e000f6,0xf0920277}},	// [d6c0] вреј, ামি_, uvin_, ינן_,
   {{0x3207b55d,0xbcfb000d,0x637f0139,0x00000000}},	//   kyny_, rmée, _mână, --,
   {{0x27e05c94,0x2d8578c1,0xdbe3000d,0xceb80067}},	//   svin_, nple_, _rééc, więk_,
   {{0xd826411f,0x64a6af47,0x77940609,0x7c220093}},	//   _адми, тада, _میرا, _þors,
   {{0x6903007c,0x290c0029,0xd467b55e,0x00000000}},	//   _võet, ūdas_, вице_, --,
   {{0x8c1b011d,0x814305f5,0x00000000,0x00000000}},	//   ווני, ینون, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf9930052,0x31ba00da,0x6603b55f,0x00000000}},	//   ברה_, rëz_, änke, --,
   {{0xa2bf00a1,0x2d852f97,0x248902d7,0x04461403}},	//   ल्ह्, eple_, ñame_, _реан,
   {{0x2ef40d46,0x9df803e6,0x00000000,0x00000000}},	//   узор, енот_, --, --,
   {{0x6298024e,0x4c9508bb,0x32070067,0xdcf9013a}},	//   mavo, линс, cyny_, _atvā,
   {{0x629892b5,0x60262447,0xd0261d13,0x4fc678bd}},	//   lavo, _идеа, _имей, _аска,
   {{0xdcfb0080,0xd00f004f,0x7ff333cc,0x00000000}},	//   lstī, _ولم_, _نسوا, --,
   {{0x6298b560,0xb3450370,0x5b2701e0,0xda7b0421}},	//   navo, moçã, тьма, ьям_,
   {{0x1db60fd1,0x00000000,0x00000000,0x00000000}},	//   _अमित, --, --, --,
   {{0x0dc73471,0xc9840009,0x6934b561,0x67d50424}},	//   _руши_, рури, ансу, лобу,
   {{0x80be0033,0xdce40124,0xb8db0387,0x32070067}},	// [d6d0] ্যপ্, _sunć, _घा_, zyny_,
   {{0xdcfb0080,0x62981ac4,0x6d4f3f34,0x1db606fe}},	//   kstī, javo, llca, _अमात,
   {{0x63a4004f,0x6298b562,0x36d4005f,0x057411cf}},	//   áinn, davo, рохр, لاند,
   {{0x5884086c,0x394d0484,0xf48702bb,0x00000000}},	//   _выра, ċess_, тужн, --,
   {{0xad1c0779,0x4ac000b1,0xaac00f0d,0x9d1c0070}},	//   וואר, श्वव, श्वक, וואט,
   {{0x6298b563,0x6903007c,0x3207b564,0xe7e0157d}},	//   gavo, _tões, tyny_, निरप,
   {{0x80be00c8,0xd5b8b565,0xb59402fb,0x00000000}},	//   ্যন্, _ист_, _висш, --,
   {{0x3207b566,0xdfd1004f,0x657a00a2,0x00000000}},	//   ryny_, ميع_, _étha, --,
   {{0x62980187,0x32074206,0xb87b0042,0x65750024}},	//   bavo, syny_, _uníu, _huzh,
   {{0x65750031,0x637f00af,0x00000000,0x00000000}},	//   _kuzh, _vână, --, --,
   {{0xd2510082,0x4d66262e,0xd1b8186e,0x00000000}},	//   _انا_, лков, _لانا_, --,
   {{0x637f002d,0xdb061ca0,0x2d8559e5,0xb87b0168}},	//   _tână, stkü, rple_, _mnís,
   {{0xbebc00ea,0x4fa51888,0x00000000,0x00000000}},	//   rnīr, _силв, --, --,
   {{0x8f9a0779,0xe45602b5,0x63ab0079,0xa3bb0067}},	//   _װיקי, טירט_, irgn, _अमन_,
   {{0xfce60185,0x00000000,0x00000000,0x00000000}},	//   _бойо, --, --, --,
   {{0x62982e11,0x00000000,0x00000000,0x00000000}},	//   zavo, --, --, --,
   {{0x46ea1a90,0x6d46b567,0x27e60082,0xb87b0183}},	// [d6e0] ндан_, moka, íon_, _anís,
   {{0x6b84b568,0x00000000,0x00000000,0x00000000}},	//   _itig, --, --, --,
   {{0x693703fd,0xa3b60099,0x6b84009f,0x3abb0277}},	//   mćen, चून_, _htig, _אמינ,
   {{0xb87b0f56,0xd91004cd,0x4ac0012f,0x2db60070}},	//   _caíd, _بیر_, श्रव, טלען_,
   {{0x629875a5,0x44200028,0x06cf0033,0x00000000}},	//   tavo, ài_, রাজি, --,
   {{0x6d46b569,0x533404bf,0x65750024,0xbcfb0079}},	//   hoka, јект, _fuzh, iméa,
   {{0x6298114d,0x2902b56a,0x6d46b56b,0x88d70083}},	//   ravo, _koka_, koka, হারক,
   {{0x29020d36,0xf9930122,0x6d46b56c,0x415403e6}},	//   _joka_, זרה_, joka, јвис,
   {{0xe2920514,0x2902b56d,0x62980093,0x35ba0084}},	//   _هذا_, _moka_, pavo, _उमड़,
   {{0x2902b56e,0x65620055,0x3eb84fb1,0x00000000}},	//   _loka_, lmoh, ürt_, --,
   {{0x6b8404fb,0x6d46b56f,0x46c61cce,0x10a638c7}},	//   _atig, foka, र्यह, _биен,
   {{0x6d46b570,0x290201e0,0xeb0d018d,0xdb0f0055}},	//   goka, _noka_, हस्त_, pucë,
   {{0xdb1d006c,0xc62137dd,0xb87b01ef,0x61e80097}},	//   ltsé, _मध्य_, _onír, _hrdl,
   {{0x501b0052,0xf1b8363d,0x65620055,0x46c60ed1}},	//   _אודו, _इमान, hmoh, र्मह,
   {{0x13cd00c8,0x6d46b571,0x29027744,0x19950144}},	//   লিয়, boka, _boka_, рабя,
   {{0x2d9eb572,0x6d46b573,0x93c700af,0x6b520093}},	//   mste_, coka, ltăţ, nægj,
   {{0x76b90210,0x2d9e7b08,0x65750024,0xab5b02b1}},	// [d6f0] клар_, lste_, _suzh, rtüb,
   {{0xb87b0bc8,0x61e8039b,0x7bcd0c47,0x63ab00cd}},	//   _saíd, _ordl, _ipau, vrgn,
   {{0x2d9e06c3,0x2902b574,0xeb9f0a8a,0x442703fc}},	//   nste_, _foka_, lsø_, گراف,
   {{0x2d9eb575,0x39a101c8,0x01ba0083,0x63ab0506}},	//   iste_, mės_, ংবাদ, trgn,
   {{0x39a101c8,0x24580d8a,0x61e80079,0x889a00a5}},	//   lės_, гаць_, _ardl, _בברי,
   {{0x6b7c02b5,0x2d9eb576,0x6d46b577,0x21260118}},	//   ערונ, kste_, zoka, _amoh_,
   {{0x39a17bcb,0x2d9eb578,0x6d46b579,0xda050f17}},	//   nės_, jste_, yoka, रहित_,
   {{0x2d9eb57a,0x26d38a27,0xd1310ad9,0xb0f30033}},	//   dste_, lexo_, تمع_, জস্ব_,
   {{0x2d9eb57b,0x7bcd0189,0x02a7075c,0x00000000}},	//   este_, _npau, _брем, --,
   {{0x39a101c8,0x26d30042,0x2d9eb380,0xff250ecd}},	//   kės_, nexo_, fste_, рмоо,
   {{0x6d46b57c,0x2d9e8211,0x798501e8,0x7bcd5a75}},	//   toka, gste_, _nthw, _apau,
   {{0x39a100d8,0x00000000,0x00000000,0x00000000}},	//   dės_, --, --, --,
   {{0x2902016f,0x2d9eb57d,0xdceb0160,0x00000000}},	//   _roka_, aste_, _sufă, --,
   {{0x6d46b57e,0x2902b57f,0xbcfb399b,0x5f740413}},	//   soka, _soka_, rméa, _طاهر,
   {{0x6d46b580,0xc89609ea,0x6f03004f,0x29022e16}},	//   poka, ирањ, _ionc, _poka_,
   {{0x776e006d,0xbcfb006c,0xdb060225,0x00000000}},	//   _sibx, lmén, kukç, --,
   {{0xa96705a3,0xfaa61b17,0x69370124,0x3f9f0421}},	// [d700] рита_, _капо, pćen, nsuu_,
   {{0x39a101c8,0x3ce00189,0xdb06027d,0x6f03b581}},	//   bės_, _haiv_, dukç, _jonc,
   {{0x2902b582,0xab5b02c9,0x2bde0af9,0x690300be}},	//   _toka_, stüc, मिका, _tõep,
   {{0x6281b583,0x7d040086,0x660331ea,0x69370009}},	//   _aflo, _jois, änka, nćel,
   {{0x3ce00189,0x6562b584,0x237704cd,0x60c401ed}},	//   _maiv_, rmoh, لمند_, _ñimi,
   {{0x0cd30b35,0xf1a6384b,0x7d04b585,0x6f036b6d}},	//   _तस्म, арин, _lois, _nonc,
   {{0xbcfb006c,0x316f0009,0xe5a30a87,0x602800ea}},	//   dmén, _bigz_, _мири, zīmī,
   {{0x7d04b586,0xf1a70035,0x62810336,0xbcfb002a}},	//   _nois, _गिरन, _eflo, emén,
   {{0x39a100d8,0x6f03b587,0x60f700d8,0x628100e5}},	//   zės_, _bonc, рныя_, _fflo,
   {{0x2d9e201e,0x7b10033b,0x7d0426c9,0x61e800d5}},	//   tste_, _bäum, _aois, _trdl,
   {{0x7bcd01c8,0x6f0312c3,0x7d04b588,0xf1a90088}},	//   _spau, _donc, _bois, _مانه_,
   {{0x7d04b589,0x39a101c8,0x3ce0006f,0xf8bf0d2e}},	//   _cois, vės_, _caiv_, _amén_,
   {{0x6f031010,0x7d0421fc,0x2d9eb58a,0x3ce0006d}},	//   _fonc, _dois, sste_, _daiv_,
   {{0x6e940082,0x39a10a93,0x8f9b00c2,0x2d9e0a81}},	//   _الثا, tės_, _יידי, pste_,
   {{0x7d048e1d,0x7d16b58b,0x7cff0031,0x5edc0033}},	//   _fois, _flys, _mërz, বাদে,
   {{0x39a100d8,0x987563fa,0x6f030036,0x26ca0223}},	//   rės_, слац, _zonc, _abbo_,
   {{0x6d4db58c,0x39a101c8,0x63a428c2,0x26d301ef}},	// [d710] _ikaa, sės_, šinj, texo_,
   {{0x39a100d8,0x67ca0029,0x1dda0035,0xceb8010b}},	//   pės_, dējā, _बनात, ngę_,
   {{0x09f90082,0x3ce0006d,0x5fd80246,0x26d30042}},	//   _صفحة_, _yaiv_, _बैसल, rexo_,
   {{0x3ce00189,0xbcfb006c,0x26d301dd,0x3f860359}},	//   _xaiv_, zmén, sexo_, _otou_,
   {{0x8cbc0fbf,0x3949002a,0x6d4d08c7,0xd7f89c91}},	//   ष्टो, moas_, _mkaa, _кур_,
   {{0xc3240131,0x973502fd,0xe2960804,0x00000000}},	//   омік, _اکرا, баш_, --,
   {{0x758200d1,0x20020086,0x3f860107,0xa0a5094f}},	//   _فیلم, äkin_, _atou_, байд,
   {{0xeb04083f,0x6f03008b,0x7b1001ae,0x394908cb}},	//   _रक्त_, _sonc, _räum, noas_,
   {{0xa3e207df,0x6f03b58d,0x7d04b58e,0xbcfb006c}},	//   धिः_, _ponc, _rois, tmén,
   {{0x6d4d6289,0x7d0401a6,0x753b0009,0x7d16b58f}},	//   _akaa, _sois, _hjuz, _slys,
   {{0x7d160f0f,0x3ce0006d,0x7d042b2f,0xb6da0070}},	//   _plys, _paiv_, _pois, אַכט,
   {{0xcb0901f3,0xa3ae0026,0x98b001ba,0xd25600a5}},	//   _אל_, _किम_, _šaľa_, _השעה_,
   {{0x7d04b590,0x7f85004f,0x753bb591,0x853a0317}},	//   _vois, _التن, _mjuz, רגרי,
   {{0x6f1ab592,0x6d4d02ea,0x249d006f,0x81bc0033}},	//   chtc, _ekaa, hawm_, েটর_,
   {{0x7d04b593,0x752901c0,0x249d006d,0x00000000}},	//   _tois, _omez, kawm_, --,
   {{0x394982d2,0xb87b0b4c,0xe6d000dc,0x443f00a8}},	//   goas_, _raíc, सज्ज, _oxu_,
   {{0x667621a0,0x37560594,0xf8bf0118,0x3952b594}},	// [d720] مدار, مپرس, _imél_, rlys_,
   {{0xe64602ce,0x7529b595,0x63a400ac,0x39520d57}},	//   безп, _amez, šink, slys_,
   {{0x394901dd,0x645bb596,0xd9463534,0x00000000}},	//   boas_, _azui, _гени, --,
   {{0x69deb597,0x443f0024,0x394902d7,0xab5bb598}},	//   _ispe, _bxu_, coas_, ntün,
   {{0x7cff01f4,0x68e4027d,0x5eaf0033,0x290008c7}},	//   _përz, mdid, জ্যে, mjia_,
   {{0x752918f9,0x67ca00ea,0x68e4b599,0x00000000}},	//   _emez, rējā, ldid, --,
   {{0xa4f8026b,0x443fb59a,0x80be0033,0x68e4018d}},	//   _پکار_, _exu_, ্যস্, odid,
   {{0xd130004f,0x2900b59b,0x443f007a,0x00000000}},	//   ظمة_, njia_, _fxu_, --,
   {{0xc6000083,0x3dce0132,0x200d00b5,0x8afb00a8}},	//   _এইটা_, _spfw_, gyei_, ngəç,
   {{0x6d4d0173,0x69deb59c,0x63ad03c9,0xb7db0317}},	//   _skaa, _ospe, šanc, נקיי,
   {{0x63a2b59d,0x00000000,0x00000000,0x00000000}},	//   lson, --, --, --,
   {{0x629a62bd,0x3949002a,0x6b96099e,0x0db900fd}},	//   _heto, xoas_, _bwyg, گئیں_,
   {{0x63a2b59e,0x68e4b59f,0x629a00bf,0x69de187d}},	//   nson, ddid, _keto, _aspe,
   {{0x629a01d2,0xf1dc02e4,0xdd9000d2,0x63a200f7}},	//   _jeto, _मनान, _قوت_, ison,
   {{0xa8a70036,0x80db0033,0xc33300a5,0x127b0070}},	//   йрак, ভার্, לוש_, ראלע,
   {{0x629ab5a0,0x99550131,0x290001f4,0xb87b002a}},	//   _leto, ікац, gjia_, _baía,
   {{0xdb0f0b4c,0x2ca90159,0x39492314,0xb87b0138}},	// [d730] lucí, _idad_, roas_, _caía,
   {{0x629ab5a1,0x291b0be2,0x63a2b5a2,0x68e4018d}},	//   _neto, shqa_, dson, adid,
   {{0x6eca0587,0x249d01e8,0x41d722a7,0x24890138}},	//   त्यु, tawm_, _भैंस, ñamo_,
   {{0x545501d3,0x629ab5a3,0xa3b900b2,0x63a20b88}},	//   овет, _aeto, لاتر_, fson,
   {{0xe2991126,0x03a50043,0x63a21a89,0x2bdf0461}},	//   аал_, цило, gson, _पैमा,
   {{0x629a1c02,0x249d006d,0x6595010b,0xab5b00fd}},	//   _ceto, sawm_, _магу, ztün,
   {{0x56940009,0x63a2b5a4,0x6440972c,0x7bdf0298}},	//   _хаст, ason, _exmi, _lsqu,
   {{0xdb0fb5a5,0x753b0054,0x7529b5a6,0x443f0065}},	//   ducí, _ujuz, _umez, _txu_,
   {{0xef19046e,0x63a2006c,0x27e954f2,0x6006021f}},	//   ими_, cson, nvan_, жным_,
   {{0x629a0244,0xc34b01c8,0x2ca9b5a7,0x27e902ee}},	//   _geto, _сябе_, _adad_, ivan_,
   {{0x291906d0,0x7bdf0181,0xab5b00b5,0xf8bf0183}},	//   _olsa_, _asqu, ttün, _amém_,
   {{0x2fdd006d,0x629a6d2e,0xdced00ee,0x69de0107}},	//   _tswg_, _zeto, _fiač, _rspe,
   {{0x2d5900f7,0xab5b2d61,0x814c016b,0x2ca9099e}},	//   péen_, rtün, _געאַ, _ddad_,
   {{0x2ca97b8c,0x63a40082,0x3f8db5a8,0xab5bb5a9}},	//   _edad_, áini, mpeu_, stün,
   {{0x7bdf6ee9,0x6ee40957,0xb87b1945,0x27e90168}},	//   _esqu, _رسول, _saía, evan_,
   {{0x63a40e3c,0x63a2b5aa,0x088a004b,0x7d1d10c0}},	//   šini, yson, рбай_, chss,
   {{0x68e42140,0x27e900b5,0x98a90035,0xb86601df}},	// [d740] rdid, gvan_, znać_, زارو,
   {{0xab5b1707,0x6560009e,0x00000000,0x00000000}},	//   ntül, _shmh, --, --,
   {{0x39460445,0x69de4d49,0x8c3b01ae,0x27e900c3}},	//   _мног, _uspe, raße, avan_,
   {{0x63a2b5ab,0x629ab5ac,0x938a174b,0xa92806fe}},	//   tson, _seto, аска_, _dožá,
   {{0x934610a4,0xd40300c3,0x63a2b5ad,0x03a3021d}},	//   онде, дящи, uson, дичо,
   {{0x47d902b5,0x37d902b5,0xa3bbb5ae,0xfbb20035}},	//   _פֿרײ, _פֿרע, _अमर_, _जिनम,
   {{0x65c32b42,0x629ab5af,0x60c90f0a,0x63a22e0f}},	//   _обра, _veto, ffem, sson,
   {{0x63ad0ae0,0x60f80382,0x1fa62581,0x629a01cb}},	//   šana, сния_, орог, _weto,
   {{0x629aa79e,0x4aca09b4,0xdfd00c26,0x50b700d1}},	//   _teto, िभाव, ريد_, زديد_,
   {{0xcf26004f,0xbcfb00f7,0x7bdf0027,0x51f60eea}},	//   تربي, rmém, _rsqu, _وسار,
   {{0x27e9a09f,0xa3e209b1,0x667b0319,0x657c00d7}},	//   zvan_, धिक_, יטיק, _jurh,
   {{0x27e900d0,0xbfa30023,0x657cb5b0,0x6d46008d}},	//   yvan_, _kiế, _murh, _íhal,
   {{0x1ae400c8,0xdee62d38,0xa06a03fa,0x4ae701c8}},	//   খানে_, _моди, _тада_, оўва,
   {{0xdce402c4,0xb87b002a,0xdb0f00d5,0x00000000}},	//   _dunđ, _caín, pucí, --,
   {{0x7bc6104e,0x00000000,0x00000000,0x00000000}},	//   atku, --, --, --,
   {{0xa3bb0084,0x27e92898,0x2ca9b5b1,0x00000000}},	//   _अमल_, tvan_, _udad_, --,
   {{0x2bb222a7,0xdce40506,0x00000000,0x00000000}},	// [d750] _जिया, _gunđ, --, --,
   {{0x27e9b5b2,0x368b4054,0xa92800b8,0x657cb5b3}},	//   rvan_, рсан_, _požá, _burh,
   {{0xab5b033b,0x657c00e0,0x7af7009f,0x7ae50139}},	//   ntüm, _curh, _inxt, _iaht,
   {{0xbfa300e2,0x6eca012f,0x00000000,0x00000000}},	//   _biế, त्तु, --, --,
   {{0x7ae51c55,0x78fa0122,0x69c7b5b4,0x00000000}},	//   _kaht, _הפרו, ltje, --,
   {{0x7ae5b5b5,0x657c0118,0x20e700e2,0x7d1d0055}},	//   _jaht, _furh, _ối_, ërsj,
   {{0x34950011,0x69c7b5b6,0x9445006c,0x464800d8}},	//   _навр, ntje, _کھان, _дзён_,
   {{0x7ae51c55,0x212b02e9,0x04c91902,0xb87b0098}},	//   _laht, òch_, _دوري_, _maío,
   {{0x69c7b5b7,0x60c90a53,0xe3e901df,0x78fc00a5}},	//   htje, rfem, _دکان_, שפחו,
   {{0xa2b43d35,0xef190674,0x76550044,0x7ae55999}},	//   _обуч, смо_, _kyzy, _naht,
   {{0x69c700da,0x69c5006d,0xdce402c4,0xb87b0079}},	//   jtje, _nqhe, _sunđ, _naío,
   {{0xb87b01dd,0x61e101ef,0x8c460279,0xab5b00fd}},	//   _saín, _isll, земе, stül,
   {{0x2bdf11b5,0x69c70120,0x00000000,0x00000000}},	//   _पैदा, etje, --, --,
   {{0xa3ae004e,0xdee5034b,0x692c027d,0x28ce1140}},	//   _किस_, _хоки, rşem, ह्नि,
   {{0xa3e20066,0x7bc6af7f,0x7ae50124,0xab27b5b8}},	//   _फैन_, stku, _daht, чора_,
   {{0x657a00f7,0x00000000,0x00000000,0x00000000}},	//   _éthi, --, --, --,
   {{0x6843b5b9,0x69c701e4,0x186702bb,0xb87b01ef}},	// [d760] ента, atje, зати_, _taín,
   {{0x63b90223,0x00000000,0x00000000,0x00000000}},	//   duwn, --, --, --,
   {{0xfebd0033,0x00000000,0x00000000,0x00000000}},	//   _অসাধ, --, --, --,
   {{0x7ae502dd,0xd94600ed,0x00000000,0x00000000}},	//   _zaht, _хеми, --, --,
   {{0xf8b302da,0x2d980b4c,0xdb1d00b5,0x61e10055}},	//   _אשר_, árez_, ltsá, _asll,
   {{0x657c0086,0x3f820093,0xbfa30023,0x68e60a21}},	//   _turh, íkum_, _viế, _hakd,
   {{0x7d1d053e,0x6b5208c8,0x672e0024,0x00000000}},	//   ërsk, lægs, _imbj, --,
   {{0xe1ef7407,0xbcfb0332,0xbfa30023,0x61dc2478}},	//   اسو_, rmék, _tiế, _मनीष,
   {{0x248635e2,0x61e101f7,0xa2c4164f,0x00000000}},	//   mcom_, _esll, _राप्, --,
   {{0x2486b5ba,0x61e10024,0x69c7b5bb,0x91e6b5bc}},	//   lcom_, _fsll, ytje, _нозе,
   {{0x2d98105d,0xac990312,0xbcfb0183,0x68e6271e}},	//   ère_, يندا_, lméi, _oakd,
   {{0x2486b5bd,0x68e6b5be,0x7ae5b5bf,0xf99300b5}},	//   ncom_, _nakd, _saht, ہبر_,
   {{0x61dc0026,0xab5bb5c0,0x672e0044,0x7ae500b9}},	//   _मनुष, stüm, _ombj, _paht,
   {{0x26da029d,0xbcfb004f,0x7ae500d7,0x81cf0033}},	//   jepo_, iméi, _qaht, শির_,
   {{0x2486b5c1,0xb87b01ef,0x68e6b5c2,0x7ae51b43}},	//   kcom_, _faíl, _bakd, _vaht,
   {{0x672e03bb,0x69c7b091,0x76550035,0x24865abf}},	//   _ambj, rtje, _ryzy, jcom_,
   {{0x69c70047,0x5ba401c8,0x7ae5b5c3,0x2486b5c4}},	// [d770] stje, _прэз, _taht, dcom_,
   {{0x6b8d0e58,0x2bb206bc,0xec3800a5,0xf7700698}},	//   _itag, _जिता, _מאחר_, هال_,
   {{0x692c027d,0x00000000,0x00000000,0x00000000}},	//   kşeh, --, --, --,
   {{0x7d1d00da,0x2486b5c5,0x62880d35,0x32cf027d}},	//   ërsh, gcom_, _afdo, zıyı_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ad31c9,0x6d4f0037,0x290b0225,0x6b8d08c7}},	//   šano, hoca, _hoca_, _mtag,
   {{0x6d4fb5c6,0x248615d8,0x290b0225,0xdb2400b5}},	//   koca, bcom_, _koca_, éséb,
   {{0x6eca0ea3,0x2d830187,0x290b034b,0x6b8db5c7}},	//   त्सु, íjem_, _joca_, _otag,
   {{0x63a40082,0xd0a8004f,0x6b8d08bd,0xb4b90ca1}},	//   áint, سطين_, _ntag, चली_,
   {{0xee395963,0x290b2e1a,0x3f8b00ea,0x249f009e}},	//   жно_, _loca_, īcu_, _heum_,
   {{0x9d4618c3,0x6d4703c9,0x6b8d018c,0x63a90093}},	//   денд, čkan, _atag, _hven,
   {{0x60c20082,0x63a9008a,0x6d4f25e4,0x301500d4}},	//   _gcom, _kven, goca, _одер,
   {{0x249f0107,0xeb9788f0,0xa2c4000c,0x60db08c7}},	//   _meum_, мия_, _राम्, meum,
   {{0x6b8d0037,0xdb1d006c,0x60dbb5c8,0x249f01a6}},	//   _dtag, ttsá, leum, _leum_,
   {{0x290b0033,0x68e600f8,0x00000000,0x00000000}},	//   _boca_, _pakd, --, --,
   {{0x63a9177c,0x26da000e,0x249f201d,0xa3ae020c}},	//   _oven, wepo_, _neum_, _किल_,
   {{0xcece0019,0x248600a0,0x290b021d,0x07a3b5c9}},	// [d780] _mộng_, vcom_, _doca_, катн,
   {{0x2ca032c5,0xcece0023,0x363600f8,0x00000000}},	//   _heid_, _lộng_, وراس, --,
   {{0x26dab5ca,0x68e6b5cb,0x249f0211,0x8afb32e3}},	//   repo_, _takd, _beum_, _והיי,
   {{0x249f00f1,0x290b0055,0xe45a27b9,0x9e3c00ac}},	//   _ceum_, _goca_, оже_, naďa,
   {{0xc3da00bf,0x60db01dd,0x2ca00d67,0x136a052c}},	//   تباط_, deum, _meid_, ошки_,
   {{0x60c202fb,0xbcfb026e,0x6d4f19cd,0x317eb5cc}},	//   _scom, rméi, zoca, _putz_,
   {{0x249f01a6,0x7b1001ae,0x4b3700a5,0xda0e00b8}},	//   _feum_, _häus, ורסל_, सहित_,
   {{0xcece0028,0x2ca00006,0x78a40359,0x290b69d3}},	//   _cộng_, _neid_, naiv, _xoca_,
   {{0x27e00024,0x64a32a2d,0x692c0225,0xcece00cc}},	//   nwin_, _шата, rşeh, _dộng_,
   {{0x63a4b5cd,0x4426000e,0x22164a10,0x3d940bfe}},	//   šins, mzo_, _офер, ниор,
   {{0x1d351728,0x27e002c2,0x6b8d0dc5,0x442607e5}},	//   ення, hwin_, _stag, lzo_,
   {{0x6603112d,0x60db2fba,0x2ca000e5,0xd1750409}},	//   änki, ceum, _ceid_, _зычы,
   {{0x4426b5ce,0x290b48ba,0x10161d05,0x2ca001da}},	//   nzo_, _roca_, _تباد, _deid_,
   {{0x394298fa,0xbec8013a,0x00000000,0x00000000}},	//   _ajks_, _brūž, --, --,
   {{0x290bb5cf,0xd90f00bf,0x6d4f2b24,0xf77f027d}},	//   _poca_, لید_, poca, _suç_,
   {{0xa3ae022e,0x58d4172a,0x6eca00b8,0xa3de0066}},	//   _किं_, кост, त्रु, तबा_,
   {{0x3fbc0083,0x6b8db5d0,0x5884004b,0x290b3794}},	// [d790] _অনুষ, _utag, тыса, _voca_,
   {{0x4426b5d1,0x60dbb5d2,0x63a903d0,0x00000000}},	//   dzo_, zeum, _rven, --,
   {{0xb8e500c8,0x63a91e74,0x78a400d7,0x44b5081b}},	//   _এস_, _sven, baiv, ебес,
   {{0xb4b9009a,0x7d0db5d3,0x00000000,0x00000000}},	//   चले_, _joas, --, --,
   {{0x7d0d9d11,0xcece01a5,0xdb1d01b4,0x947400f8}},	//   _moas, _rộng_, rtsæ, ندها,
   {{0xfbb2004e,0x316691cf,0x00000000,0x00000000}},	//   _जिसम, _ahoz_, --, --,
   {{0xe5c424b6,0x24800254,0x4426b5d4,0xd3780207}},	//   _исто, žima_, azo_, _dić_,
   {{0x7d0d0043,0xfa780bed,0x7522b5d5,0x3fe50dbf}},	//   _noas, ועות_, choz, ежив,
   {{0x61f80038,0x63a9b5d6,0x2019006c,0xe45401c8}},	//   _ďalš, _uven, ási_, _акты,
   {{0x60dbb5d7,0x2ca0b5d8,0xc4320ef2,0x26c1b5d9}},	//   seum, _seid_, _حکمت, ngho_,
   {{0xa2c45c40,0xed5a5486,0xee360043,0x3eae0211}},	//   _रात्, зон_, енэ_, _ddft_,
   {{0x7c2680ef,0x7d0db5da,0xdb061dab,0x00000000}},	//   tzkr, _coas, mské, --,
   {{0xdb060187,0x2ee70260,0x78a45a36,0x09a80099}},	//   lské, _tanf_, vaiv, गळ्य,
   {{0xada51d41,0x316d027d,0xdee20210,0x7b100a63}},	//   _закл, lmez_, _боши, _räus,
   {{0x44260021,0x3ea5b5db,0xdb060076,0x27e01628}},	//   zzo_, malt_, nské, wwin_,
   {{0x3ea5b5dc,0x316d027d,0x00000000,0x00000000}},	//   lalt_, nmez_, --, --,
   {{0x63ad068b,0x81d50083,0x5975005f,0x78a4b5dd}},	// [d7a0] šanj, িটি_, тыру, raiv,
   {{0xff7a02b5,0x3ea53f9a,0x4426b5de,0x00000000}},	//   פטעמ, nalt_, vzo_, --,
   {{0x3ce9006d,0xdb060187,0x316db5df,0xba9b32e3}},	//   _yaav_, jské, kmez_, _מסיי,
   {{0x3ea5b5e0,0x3ce901e8,0x81d50083,0x4426b5e1}},	//   halt_, _xaav_, িটা_, tzo_,
   {{0x3940b5e2,0x3ea593bf,0x693700f4,0x987b016b}},	//   mnis_, kalt_, rćet, _מאכט,
   {{0x4426896d,0xf65100f5,0x3ea5007c,0x3940b5e3}},	//   rzo_, ائے_, jalt_, lnis_,
   {{0x8cc1004e,0x3940b5e4,0x3ea58cf5,0x6d564e57}},	//   _वालो, onis_, dalt_, _okya,
   {{0x3940b5e5,0x6d44002f,0x6d56018e,0x00000000}},	//   nnis_, _njia, _nkya, --,
   {{0x9346b5e6,0x93c80332,0xbcfbb2c1,0x7d0d0f00}},	//   _знае, _تازہ_, llég, _roas,
   {{0x394001ae,0x8017004f,0x6d44b5e7,0x6d56b5e8}},	//   hnis_, عزيز_, _ajia, _akya,
   {{0xd36f0bdf,0x394067d2,0xf1d40006,0x073700a5}},	//   _اهل_, knis_, _दहिन, תאים_,
   {{0x27240093,0x39520f00,0x00000000,0x00000000}},	//   _hönd_, joys_, --, --,
   {{0x7d0d002d,0x3ea5b5e9,0x3940b5ea,0x6d440107}},	//   _voas, balt_, dnis_, _djia,
   {{0x3940053e,0x6d560273,0x628a00a2,0x3f7b0070}},	//   enis_, _ekya, ncfo, _זאגס,
   {{0xcf570122,0x3940b5eb,0x9967066d,0x799e016e}},	//   _רבות_, fnis_, етал, _cwpw,
   {{0x0e5b0122,0x3940b5ec,0x6e2e008d,0x9e3c00d5}},	//   _מדוב, gnis_, úbbu, laďo,
   {{0xb909000c,0xdb1d1193,0x00000000,0x00000000}},	// [d7b0] _यस_, ttsä, --, --,
   {{0x6d5db5ed,0x394000be,0x466b0012,0xfc3f01ef}},	//   llsa, anis_, прем_, caía_,
   {{0x39525188,0xdb1d022a,0x394002c9,0x00000000}},	//   boys_, rtsä, bnis_, --,
   {{0xdb06024e,0x39521c7f,0x00000000,0x00000000}},	//   vské, coys_, --, --,
   {{0xdb1d033b,0x81d50033,0x68ed0448,0x00000000}},	//   ptsä, িয়া_, mdad, --,
   {{0x68edb5ee,0xdb060187,0x6aa701f2,0x2909b5ef}},	//   ldad, tské, najf, ljaa_,
   {{0x3ea50006,0x9f4bade1,0x68ed01a6,0x316d027d}},	//   valt_, ící_, odad, tmez_,
   {{0x68edb5f0,0xdb06024e,0x3ea55580,0x2bb20035}},	//   ndad, rské, walt_, _जिला,
   {{0xa3ae006a,0xf8bf006c,0x3ea50bf3,0x3156004f}},	//   _किए_, _elég_, talt_, خليج_,
   {{0x3940b5f1,0x6569b5f2,0x68ed004a,0xbcfb00b8}},	//   znis_, _hheh, hdad, hléd,
   {{0xa3e906bc,0x68fdb5f3,0x3ea53f99,0xdc34016f}},	//   यिक_, _onsd, ralt_, rúča,
   {{0x3ea50006,0xe804000c,0x408701d3,0x6aca0efa}},	//   salt_, रममा_, _чужб, िभ्र,
   {{0x68edb5f4,0x3ea5b5f5,0x00000000,0x00000000}},	//   ddad, palt_, --, --,
   {{0x68ed03e6,0x6d5db092,0x68fd0260,0x806401e0}},	//   edad, alsa, _ansd, _свіж,
   {{0xa2c40953,0xfaa32b34,0x3940b5f6,0xdb040279}},	//   _रास्, расо, tnis_, _aviã,
   {{0x6d440464,0x68edb5f7,0xf1b202b5,0xdcf900ea}},	//   _ujia, gdad, יסל_, _tuvā,
   {{0x3940b5f8,0x2fcdb5f9,0xf8bf0176,0xfc3f0079}},	// [d7c0] rnis_, nteg_, _amés_, laín_,
   {{0x3940b5fa,0x66760e3a,0x656908dd,0x68edb5fb}},	//   snis_, ندار, _aheh, adad,
   {{0x64490391,0x6b84b5fc,0x66e3005f,0x394023ed}},	//   _axei, _huig, роха, pnis_,
   {{0x6b84b5fd,0x63b900e9,0xbcfb00b5,0x69ce033b}},	//   _kuig, frwn, lmér, mtbe,
   {{0x0fbc0083,0xf8bf0176,0x232a03d0,0x3d1a018d}},	//   _অন্ধ, _emés_, моди_, _पवने_,
   {{0x6569b5fe,0x6b8401a6,0x645b0159,0xe3630036}},	//   _eheh, _muig, _dyui, акчи,
   {{0xf1a3010b,0xe5a30500,0x6b84b5ff,0xbcfb00f7}},	//   арын, _виси, _luig, llée,
   {{0x69370009,0x00000000,0x00000000,0x00000000}},	//   nćep, --, --, --,
   {{0x3f660036,0x42ca0279,0x7413132d,0x00000000}},	//   ктоб, _оган_, _پولا, --,
   {{0xdcdb012f,0x69ce40d1,0xa3e70456,0x777c0069}},	//   यज्ञ, ktbe, _बनत_, _jirx,
   {{0x68ed00a8,0x41bf0026,0xc0e700b5,0x425600af}},	//   ydad, _एमएस, رفین_, _ртат,
   {{0x6b8419c1,0x200200ab,0x65690031,0x69ce37e9}},	//   _buig, äkis_, _xheh, dtbe,
   {{0x02c9007c,0xaed4156c,0x6d5d0069,0x6b840341}},	//   _रामभ, _болш, rlsa, _cuig,
   {{0x6b840284,0x81d50033,0x69ce626d,0x00000000}},	//   _duig, িটর_, ftbe, --,
   {{0x987e0723,0xaad201c0,0x4ad204cc,0xaa580274}},	//   _açık_, द्धक, द्धव, виру_,
   {{0xbcfb7a56,0x68ed6dd6,0x290f003e,0x6b84239a}},	//   rmés, udad, ðga_, _fuig,
   {{0x68ed21a4,0x1958325e,0xdcf90009,0x6b841db3}},	// [d7d0] rdad, таты_, _utvđ, _guig,
   {{0xa2c40567,0x6569b600,0x68edb601,0xaad2021a}},	//   _राष्, _sheh, sdad, द्दक,
   {{0x6b8401e4,0xfdfb073f,0x69ce02a2,0x27ff003d}},	//   _zuig, एमएस_, ctbe, _šund_,
   {{0x99f60052,0x2d5900f7,0x7d1d00be,0x68ed00a8}},	//   _עזרה_, mées_, nkss, qdad,
   {{0xd0062d7c,0x63a00297,0x2d590248,0x7bcf0392}},	//   _ال_, _cwmn, lées_, ntcu,
   {{0x56940131,0xdb1d00a2,0x79850103,0xdcf60107}},	//   _варт, fusé, _kuhw, _riyč,
   {{0x2d5902e1,0x2d8a01dd,0x00000000,0x00000000}},	//   nées_, íbel_, --, --,
   {{0x00e51129,0x2fcd0987,0x069700b5,0x4fe90279}},	//   ужин, tteg_, _ساڑھ, емин_,
   {{0x7bcd006d,0x7ff50c26,0x63a0001e,0x2d5900f7}},	//   _nqau, اسبا, _gwmn, hées_,
   {{0xd24e05f5,0x6b840014,0x8e09b602,0x272402b1}},	//   _کچه_, _ruig, енов_, _töne_,
   {{0xdca60426,0x6b843b09,0x2fcdb603,0x69ce4df9}},	//   лани, _suig, steg_, xtbe,
   {{0xa3e71db6,0x27200096,0x6b840443,0x2d910029}},	//   _बना_, _यत्र_, _puig, īze_,
   {{0xdcf90029,0xdb04021d,0x00000000,0x00000000}},	//   _atvē, _aviá, --, --,
   {{0x69ce47e2,0x6fb218dd,0x79850b13,0x7d1d0345}},	//   ttbe, _اموا, _buhw, akss,
   {{0x2d5900f7,0xc33200a5,0x00000000,0x00000000}},	//   gées_, מוך_, --, --,
   {{0x6b844304,0x79850027,0x7d1db604,0xa2d500b4}},	//   _tuig, _duhw, ckss, _मॉस्,
   {{0x69ce7d65,0x969605c2,0x6eca1140,0x5b3600af}},	// [d7e0] stbe, греш, त्कु, _бэну,
   {{0x613e0029,0x62819758,0xbcfb00a2,0x69ce8a87}},	//   rīli, _nglo, rlée, ptbe,
   {{0x777c0391,0x2d5900f7,0x692c00af,0x7985007b}},	//   _virx, cées_, uşes, _guhw,
   {{0x14260bfe,0x291e00ea,0xab5b033b,0x765c00d5}},	//   лдем, ītas_, stüt, _vyry,
   {{0xbd2d00c2,0x628f002d,0x98a90035,0x00000000}},	//   וואָ, _şcoa, wiać_, --,
   {{0xab5b01d6,0x7cfb0421,0x00000000,0x00000000}},	//   ltür, _kärä, --, --,
   {{0x26ca0069,0x26d80c6f,0x15460279,0x78a60409}},	//   _icbo_, _ibro_, _бевм, _kekv,
   {{0x62810107,0x60f802fb,0x681a0228,0xab5bb605}},	//   _eglo, тния_, _tādā, ntür,
   {{0xa3ae0127,0x00000000,0x00000000,0x00000000}},	//   _किट_, --, --, --,
   {{0x2bdf0084,0x2d59000d,0x7ee600af,0x00000000}},	//   _पैगा, yées_, уцие, --,
   {{0xab5b82a7,0x2d59000d,0xe29b00a5,0x7bcd0069}},	//   ktür, xées_, _נשאר, _sqau,
   {{0x2d590248,0xac190ebb,0x62811b86,0x3e67004b}},	//   vées_, вому_, _zglo, ышын_,
   {{0xddcb971d,0x26d801f7,0x7d1db606,0xbcfb1111}},	//   čišt, _obro_, rkss, eléc,
   {{0x2d590248,0xbcfb00f7,0x3ced03ab,0xce9401d3}},	//   tées_, fléc, žev_, _такъ,
   {{0xa3ab0953,0x78a60557,0x237e0176,0xaa5914f8}},	//   _कौन_, _bekv, _mitj_, тиву_,
   {{0x2d590248,0xc9840043,0x26d82278,0x2eee008e}},	//   rées_, сури, _abro_, _haff_,
   {{0x2d5902e1,0x47352b33,0x78a60051,0x00000000}},	// [d7f0] sées_, анас, _dekv, --,
   {{0x291e00da,0xbcfb01dd,0x2d5900f7,0xe7330d93}},	//   ëtar_, bléc, pées_, حصر_,
   {{0xdc560987,0x3f8601ef,0x78a600fd,0x00000000}},	//   _مریک, _luou_, _fekv, --,
   {{0x057403c5,0x26d809c6,0xb87b01ef,0x2e3b016b}},	//   ماند, _ebro_, _saíu, עגאנ,
   {{0xab5b0095,0x00000000,0x00000000,0x00000000}},	//   rrüf, --, --, --,
   {{0x77ba0122,0x883a00a5,0x41b5386a,0x67ba00a5}},	//   _במשח, _יתרו, асит, _במשק,
   {{0xab5b01ae,0x636d002a,0x224902fb,0x00000000}},	//   prüf, húng, ъпки_, --,
   {{0x2bb60026,0x5eaf0033,0x00000000,0x00000000}},	//   _अटला, জ্ঞে, --, --,
   {{0x68efb607,0xa2cd0567,0x2eee0107,0x93790036}},	//   _macd, _साप्, _baff_, _абат_,
   {{0xe80d0bc1,0x62810b16,0x00000000,0x00000000}},	//   _सपना_, _uglo, --, --,
   {{0x52840082,0x60b50a86,0xd1b80754,0x3f820093}},	//   _المك, _نمائ, _مانا_, íkur_,
   {{0x2d520453,0x68ef099e,0x2cab00e0,0x00000000}},	//   láez_, _nacd, gacd_, --,
   {{0xa09a00c2,0x8fa54baf,0x2eee0069,0x27240523}},	//   _סיסט, _тале, _faff_, _löna_,
   {{0x5e8700d8,0xfaa338c7,0xeb9710b4,0x00000000}},	//   _судз, жаро, рир_, --,
   {{0xa2cd057c,0xc332011d,0x636d01ef,0x2d5900a2}},	//   _सान्, קול_, múnd, réer_,
   {{0x3ea73e88,0x2d870160,0x00000000,0x00000000}},	//   _hent_, _iune_, --, --,

   {{0xb8ee2e4f,0x2d87008c,0xab5bb608,0x00000000}},	// [d800] _रा_, _hune_, rtür, --,
   {{0xf7720c9e,0xab5b064c,0x3ea70107,0x27240523}},	//   زاء_, stür, _jent_, _böna_,
   {{0x2d870122,0x3ea704da,0xc4860217,0x3abb0277}},	//   _june_, _ment_, алек, _במינ,
   {{0x4ad20569,0xaad200a9,0x69de003c,0x63640443}},	//   द्रव, द्रक, _ippe, tòno,
   {{0x68e4b609,0x29020010,0x44200019,0x2d873e80}},	//   meid, _inka_, ái_, _lune_,
   {{0x68e4b60a,0x8c1b0122,0x60cb009e,0x21ce00a8}},	//   leid, כוני, _acgm, _məhv_,
   {{0x442049aa,0x1bed0b4a,0xe73714d0,0xb87b0015}},	//   ši_, _चैनल_, _тер_, _faís,
   {{0x68e4b60b,0x6d46b60c,0x2eeeb60d,0x3ea7099e}},	//   neid, jnka, _saff_, _aent_,
   {{0x42ea03fa,0x8f460328,0xff06010b,0x2d870210}},	//   _имао_, иход, аянн, _aune_,
   {{0x68e4b60e,0x69deb60f,0x656200da,0x2d870043}},	//   heid, _oppe, lloh, _bune_,
   {{0x68e4b610,0x3ea7b611,0x2d870009,0x171b0070}},	//   keid, _dent_, _cune_, דויע,
   {{0xb87b0183,0x65622348,0x459b016b,0x00000000}},	//   _maír, nloh, כסטע, --,
   {{0x69de7dd8,0x3ea76a93,0xa2cd4eee,0x2eee419c}},	//   _appe, _fent_, _साम्, _taff_,
   {{0x3ea70955,0x2d870036,0x6d466859,0x2d800211}},	//   _gent_, _fune_, anka, _eiie_,
   {{0x68e4004f,0x2d8701d7,0x6d46006d,0x656200d7}},	//   feid, _gune_, bnka, kloh,
   {{0xa3e70006,0x68e4b612,0x1d0803fa,0xdb1d0314}},	//   _बनल_, geid, _већи_, musí,
   {{0x69deb613,0xbcfbb614,0xe7960ef2,0x65620097}},	// [d810] _eppe, cléa, مالک, dloh,
   {{0x30770122,0x2ca950ce,0xb87b0015,0x321c00ac}},	//   שתמש_, _head_, _saís, kyvy_,
   {{0xb87bb615,0xa3c900a1,0x68e40a55,0x2d8a01ba}},	//   _país, लून_, beid, íbeh_,
   {{0x67050d00,0x5e79016b,0x458401e0,0x00000000}},	//   राहक_, אָנד, ігів, --,
   {{0xc651006c,0x37e400d8,0x61fa0185,0xdd0200f4}},	//   _کہاک, _доўг, _artl, šući,
   {{0x972504e8,0x2ca900a5,0x78ad0421,0x00000000}},	//   _افسو, _lead_, laav, --,
   {{0x27e9012f,0x3495b616,0x3ea700a5,0x6d460096}},	//   lwan_, _габр, _rent_, ynka,
   {{0x3ea7b617,0x65620852,0x78adb618,0x2ca91a07}},	//   _sent_, cloh, naav, _nead_,
   {{0x3ea7b619,0x2d87b61a,0x27e90312,0x67270103}},	//   _pent_, _sune_, nwan_, _kljj,
   {{0x2d87b61b,0x63ad0009,0x27e9067f,0x53340e9f}},	//   _pune_, šans, iwan_, _деут,
   {{0x2ca9b61c,0x27e9128f,0x7997006f,0x6b96b61d}},	//   _bead_, hwan_, _ntxw, _styg,
   {{0xeb9a1962,0x2ca9111c,0x6d46b61e,0x3ea700a5}},	//   лим_, _cead_, unka, _went_,
   {{0xef0e12f3,0x68e40080,0x2ca9b61f,0x2d8000ab}},	//   _ем_, veid, _dead_, _viie_,
   {{0x60c9b620,0x6e95004f,0x27e91a99,0x68e4b621}},	//   lgem, _الغا, dwan_, weid,
   {{0x68e4b622,0x656202b3,0x2ca90608,0x3f8d0031}},	//   teid, yloh, _fead_, lqeu_,
   {{0x628f002d,0x78ad0103,0xbcfbb623,0x6ed33010}},	//   _şcol, gaav, llén, ब्रु,
   {{0x7d04b624,0xa3c91163,0x68e431bc,0x636402e9}},	// [d820] _inis, लूम_, reid, wònm,
   {{0x7bc6024c,0x7d1602d7,0x7d0400ac,0x00000000}},	//   muku, _hoys, _hnis, --,
   {{0x7bc6b625,0x27e905ca,0x7d04003c,0x69deb626}},	//   luku, awan_, _knis, _uppe,
   {{0x2ee55e54,0xab5b06d0,0xdcf9010b,0x29f8023a}},	//   helf_, crüb, _buvę, _iča_,
   {{0x7d1638c6,0x7d04b627,0x60c9293c,0x27e90345}},	//   _moys, _mnis, dgem, cwan_,
   {{0x81e100c8,0x7d16081b,0x61fa04c3,0xff470609}},	//   দিন_, _loys, _prtl, _رخ_,
   {{0x7bc628b3,0xdb1d03e6,0xd62a294d,0x24891321}},	//   huku, lusã, _сове_, žama_,
   {{0x7bc6b628,0xf8ba08b6,0xa2c40e9b,0xa4910a86}},	//   kuku, ेलिय, _राक्, _قیمت,
   {{0x2ca9b629,0x3eaca911,0x7bc6b62a,0x60f7010b}},	//   _read_, tadt_, juku, сныя_,
   {{0x75220332,0x60c9046a,0x2ca9b62b,0x63b30355}},	//   lkoz, agem, _sead_, ření,
   {{0xa2cdb62c,0x27e900d7,0x2ca9007c,0x3eac006c}},	//   _सात्, zwan_, _pead_, radt_,
   {{0xf8bf0391,0x7bc624ed,0x27e90159,0x7522b62d}},	//   _alén_, fuku, ywan_, nkoz,
   {{0x7d0401ef,0x7bc6ad16,0x673e0207,0x78ad4466}},	//   _dnis, guku, kipj, vaav,
   {{0xab5b033b,0x00000000,0x00000000,0x00000000}},	//   drüc, --, --, --,
   {{0x78adb62e,0x2ca900be,0xdb0f0079,0xc3390355}},	//   taav, _tead_, nscé, _říká,
   {{0x7bc60b69,0xdb1d0279,0x7c970413,0x27e901c1}},	//   buku, fusã, _اشغا, twan_,
   {{0xc8677314,0x78ad03ad,0x636d64df,0x69d8013c}},	// [d830] стви, raav, núnc, _även,
   {{0x78ad20a8,0xa2cd10aa,0x27e92b63,0x7d040035}},	//   saav, _साध्, rwan_, _znis,
   {{0xa3ab0907,0x75220051,0x78ad0421,0x00000000}},	//   कीन_, fkoz, paav, --,
   {{0x7ae7b62f,0x2ee50a75,0xab5b033b,0x00000000}},	//   lejt, zelf_, brüc, --,
   {{0xdfc611c0,0x69d503cb,0x39490523,0xa2c4000c}},	//   _تي_, ltze, mnas_, _राख्,
   {{0xdd862489,0xa3aa13a0,0x3949025f,0x69d501a3}},	//   _يو_, _खबर_, lnas_, otze,
   {{0x69d503cb,0x3495578a,0x5ea70083,0x3949b630}},	//   ntze, _мавр, _খালে, onas_,
   {{0x3949b631,0x69d506a2,0x7ae700b8,0x8cd900b4}},	//   nnas_, itze, hejt, _फॉलो,
   {{0x60c9b632,0x69c7565f,0x7ae70187,0x69d5033b}},	//   rgem, huje, kejt, htze,
   {{0x69c74907,0x60c92b87,0x7d040009,0x6d4d145d}},	//   kuje, sgem, _snis, _ajaa,
   {{0xf1dd3e8a,0x69c70620,0x7ae701c0,0x3949022a}},	//   _महिन, juje, dejt, knas_,
   {{0xed5ab633,0x7bc6b634,0x69c70a3c,0x7d160be2}},	//   ром_, tuku, duje, _qoys,
   {{0xdbf4045c,0x75290054,0xbcfbb635,0xc17816e6}},	//   इटेड_, _mlez, plén, _اصلا_,
   {{0x41dd09b1,0xf1dd0567,0x7bc60e83,0x39492791}},	//   _महास, _महान, ruku, enas_,
   {{0x69c7b636,0x6d4713a6,0x7d160a8a,0x753b01a8}},	//   guje, čkar, _toys, _omuz,
   {{0x7d04b637,0x7bc6b638,0xaadb111b,0x799c00e9}},	//   _unis, puku, म्बक, rprw,
   {{0x69d506a2,0x200d01ef,0xecb00033,0x2b8f013b}},	// [d840] atze, nxei_, _কাপড, _güc_,
   {{0x69c72018,0x753b9efe,0x869a002d,0xab5b033b}},	//   buje, _amuz, ртат_, rrüc,
   {{0x75220332,0x39494360,0xed4f05f5,0x753b0103}},	//   tkoz, bnas_, _سپی_, _bmuz,
   {{0xab5b033b,0x7e630345,0x63640310,0xd57601e0}},	//   prüc, _mynp, mòni, цузь,
   {{0x63640443,0xaadf02b4,0x3940b639,0x2e0e00a8}},	//   lòni, _पॉडक, miis_, rəfi_,
   {{0x7529b63a,0xd36f0098,0x394096cc,0x673e0031}},	//   _elez, نهن_, liis_, qipj,
   {{0xdb1d000d,0x745400b5,0x63640310,0x00000000}},	//   ursé, _کھائ, nòni, --,
   {{0x3940010d,0x68f62854,0x75292644,0x1bea0461}},	//   niis_, ndyd, _glez, टबाल_,
   {{0x68f600e9,0xd00700ed,0x00000000,0x00000000}},	//   idyd, жење_, --, --,
   {{0xa3df004e,0x394973c0,0x6d4d213d,0x752902a7}},	//   _तहत_, znas_, _sjaa, _zlez,
   {{0x7ae7b63b,0x46cf00dc,0x3949b63c,0xc69300a5}},	//   vejt, स्टह, ynas_, ואת_,
   {{0x69c7b63d,0x248039c0,0xc0c740f3,0x63640392}},	//   vuje, žimu_, _душе_, dòni,
   {{0x39407bb5,0x7ae700b8,0x68f6016e,0xdfcf0037}},	//   diis_, tejt, ddyd, _لين_,
   {{0x4f5705bc,0x6b9d66ed,0x7e630298,0x63640310}},	//   _وجود_, rpsg, _fynp, fòni,
   {{0x3a25008a,0x7ae7b63e,0x636d0037,0x69d501d7}},	//   álp_, rejt, núna, utze,
   {{0x69d5a7a1,0x2d9eb63f,0x69c7b640,0xdc2b00bf}},	//   rtze, mpte_, ruje, _نسخه_,
   {{0x3949b641,0x8d740ef2,0x76b9005f,0x7ae700da}},	// [d850] rnas_, _تاوا, йлар_, pejt,
   {{0x6d5db642,0x75290184,0x07050461,0x8f9b00a5}},	//   losa, _slez, राइव_, יימי,
   {{0xa2c425d8,0x7529b643,0x3949b644,0x6b8d3af3}},	//   _राज्, _plez, pnas_, _huag,
   {{0x636d0037,0x6f1801a0,0x6b8d04be,0xa2cd142a}},	//   dúna, _lovc, _kuag, _साह्,
   {{0xe2990dfc,0x3cfc0317,0x291900f1,0x2489023a}},	//   бал_, ילאנ, _iosa_, žamo_,
   {{0x6f180a78,0x6b8d009b,0xe3b00987,0x6d5db645}},	//   _novc, _muag, ئرن_, hosa,
   {{0x2919b646,0x6d5db647,0x6b8d011e,0xf62801e0}},	//   _kosa_, kosa, _luag, _діти_,
   {{0x6d5d96fa,0x753b0010,0x291901f7,0x3cf50067}},	//   josa, _umuz, _josa_, इयों_,
   {{0x6d5d00d1,0x6b8d0248,0x7e63013c,0x42550609}},	//   dosa, _nuag, _synp, _کنار,
   {{0x2919b648,0x636d008a,0x7e630298,0x91f70037}},	//   _losa_, búna, _pynp, _وأضا,
   {{0xf8bf00c9,0x68f6001e,0x98cb0035,0x6d5d03d0}},	//   _além_, ydyd, िलाए, fosa,
   {{0x63a91f18,0xbcfb152f,0x2919b649,0x6d5d4ac1}},	//   _kwen, blém, _nosa_, gosa,
   {{0x63a9142f,0x0c236b47,0x6b8d009e,0x3940018d}},	//   _jwen, емян, _cuag, viis_,
   {{0x63a969a0,0x3b0a0086,0x699600d4,0x207a100a}},	//   _mwen, щего_, зрах, _פאסא,
   {{0x3940b64a,0x63a9001c,0xa3ab00a1,0x00000000}},	//   tiis_, _lwen, कीत_, --,
   {{0x2919b64b,0x6d5d1f02,0x63640955,0x9e3c0187}},	//   _cosa_, cosa, ròni, raďt,
   {{0x8ca2006a,0x394000be,0x68f60297,0x29191034}},	// [d860] _क्यो, riis_, rdyd, _dosa_,
   {{0x3940361b,0x4bfb0070,0x63640392,0x00000000}},	//   siis_, _פליס, pòni, --,
   {{0xceb20122,0xa3c90084,0x29190138,0x63a9b64c}},	//   גיב_, लूस_, _fosa_, _awen,
   {{0x63a9b64d,0x6b8d006d,0x80db0033,0x6e3c0132}},	//   _bwen, _yuag, _মোস্, úrbi,
   {{0xa3e606d9,0xb4bc05e7,0x63a90118,0x00000000}},	//   यौं_, _आयी_, _cwen, --,
   {{0xf1a6b64e,0x2d9eb64f,0x63a9010d,0x6d5d002f}},	//   прин, ypte_, _dwen, zosa,
   {{0xa2cd0266,0x79863f1f,0x64a60560,0x6d5db650}},	//   _सार्, _kikw, _нава, yosa,
   {{0x6d5d0042,0x636db651,0x63a90260,0x26190066}},	//   xosa, rúna, _fwen, पहरी_,
   {{0x63a94499,0x6d5d4e84,0x7986b652,0x636d0037}},	//   _gwen, vosa, _mikw, súna,
   {{0x539b02da,0x7986b653,0xb4bc22a3,0xd1380067}},	//   _לימו, _likw, _आयु_, _stąd_,
   {{0x6d5db654,0x2baf0aad,0x63a90223,0x00000000}},	//   tosa, जीना, _zwen, --,
   {{0xab5b01ae,0x6b8d006d,0xbcfbb655,0x79867d19}},	//   grün, _puag, plém, _nikw,
   {{0x6d5db656,0x6b8db657,0xbcfb006c,0xd1091fc3}},	//   rosa, _quag, llék, वारण_,
   {{0x291917d9,0x6b8d006d,0x6d5db658,0x7986009e}},	//   _sosa_, _vuag, sosa, _aikw,
   {{0x2919b659,0x6edb00a5,0x58d503d0,0x6d5db65a}},	//   _posa_, _החופ, мовт, posa,
   {{0x6b8d0608,0x3eae3b72,0x79860027,0x99640036}},	//   _tuag, _heft_, _cikw, етул,
   {{0x2919002a,0x79860173,0x00000000,0x00000000}},	// [d870] _vosa_, _dikw, --, --,
   {{0x9f4db65b,0xc9870043,0x63a93729,0x00000000}},	//   rveç_, _нуми, _rwen, --,
   {{0x63a9b65c,0x25aa016e,0x38c800fd,0xcb12024b}},	//   _swen, _cwbl_, _کاپی_, _סלט_,
   {{0xe8eb00f5,0x3eae0122,0xd1260413,0x63a902d0}},	//   _اردو_, _left_, _شم_, _pwen,
   {{0xdb06013c,0xfc3f01ef,0xbfa300cc,0x3359002d}},	//   rrkö, maís_, _chế, оадэ_,
   {{0x3eae01c2,0xa2d200a1,0xc2c40037,0x7986251e}},	//   _neft_, _ठाण्, فيهي, _zikw,
   {{0x29d7b65d,0xdce4025c,0x25aa00e9,0x00000000}},	//   nça_, _uhić, _gwbl_, --,
   {{0x212b004e,0x63a940bb,0x850511c0,0x29d7021d}},	//   óch_, _twen, _تورن, iça_,
   {{0xab5b00a8,0x63a90e85,0x3eae0c6f,0x00000000}},	//   vrün, _uwen, _beft_, --,
   {{0x29d701d6,0x6d4f01ef,0xa2940746,0x78a400f4}},	//   kça_, éban, _зафі, zbiv,
   {{0xc3320122,0x78bd03ab,0x3eae0069,0x60db04fb}},	//   _שוב_, _odsv, _deft_, pfum,
   {{0x80db0033,0x23d107df,0x78af00d5,0x3f9f00c3}},	//   _মোর্, _समाद, _necv, ppuu_,
   {{0x7af7b65e,0x798662c7,0x29d7021d,0x00000000}},	//   _baxt, _rikw, eça_, --,
   {{0x1dc51649,0x09e60b46,0x7986b65f,0x7af7002a}},	//   _विपत, могн, _sikw, _caxt,
   {{0x3f8f0371,0x79860260,0x00000000,0x00000000}},	//   _hugu_, _pikw, --, --,
   {{0x3f8fb660,0xb4bc00fa,0x3f870093,0x00000000}},	//   _kugu_, _आये_, _hinu_, --,
   {{0x3f8f3416,0x1867709a,0x29d70279,0x79860054}},	// [d880] _jugu_, дати_, aça_, _vikw,
   {{0x3f8f005f,0x8c4301ae,0xe6a80722,0x7af701ed}},	//   _mugu_, ößer, गरेज, _gaxt,
   {{0x3f870006,0x3f8fb661,0x3ea100be,0x79866cfa}},	//   _minu_, _lugu_, _õhtu_, _tikw,
   {{0xe5a3167d,0x61fc00fd,0x1dc5046c,0x480a002d}},	//   тици, _árli, _विनत, _демн_,
   {{0x394db662,0xf8b3011d,0xa3ab00be,0x00000000}},	//   čest_, _בשר_, _कौआ_, --,
   {{0x3f8715c8,0x80db0033,0xae0d0ca1,0x00000000}},	//   _ninu_, _মোল্, िमान_, --,
   {{0x3f8fb663,0x91e303fa,0x20190421,0x00000000}},	//   _augu_, воје, äsin_, --,
   {{0x92ae0083,0x3f87b664,0x2d9c0d2e,0x660301b4}},	//   কলে_, _ainu_, _rtve_, ænke,
   {{0x3f870d46,0x1eaa5b76,0x3f8f022f,0x2d9c00d5}},	//   _binu_, يادي_, _cugu_, _stve_,
   {{0x3f8f0291,0x692c027d,0x3f8700ee,0x8e140d6e}},	//   _dugu_, rşey, _cinu_, едоц,
   {{0xbcfb0098,0x3f8700af,0x63a2b665,0x6ecf074f}},	//   lléi, _dinu_, lpon, _दारु,
   {{0x3f87008a,0xa00a004f,0x7af700a8,0xb4bc00b8}},	//   _einu_, _وقال_, _saxt, _आयो_,
   {{0x7af70069,0x7b6700aa,0x63a206a2,0x3f8f872b}},	//   _paxt, дтве, npon, _gugu_,
   {{0xf047064e,0x3f870009,0xbcfb0079,0x63a24354}},	//   _تعمی, _ginu_, iléi, ipon,
   {{0x7af701c2,0xb3450132,0xbcfb026e,0x386d02c4}},	//   _vaxt, liçã, hléi, _šer_,
   {{0x29d7b666,0x63765342,0x3f8700ea,0x257e00fe}},	//   rça_, lând, _zinu_, _kůlu_,
   {{0xb8f70953,0xc9840012,0xb34503e6,0x63a20cc1}},	// [d890] _सा_, тури, niçã, jpon,
   {{0x466b020a,0xda674d1e,0x29d7b667,0xb882002a}},	//   орем_, _يادي, pça_, ñían,
   {{0x6d4f594a,0xfc3f0831,0x00000000,0x00000000}},	//   onca, país_, --, --,
   {{0x629a022a,0x6d4f1c8b,0x4d7c016b,0x00000000}},	//   _afto, nnca, ַרגע, --,
   {{0x68ed335b,0xe2991283,0x290b0043,0x63a2b668}},	//   mead, пал_, _inca_, gpon,
   {{0xe299b669,0x68ed009c,0xb34503e6,0x69c801ef}},	//   чак_, lead, diçã, ádeg,
   {{0x442929cd,0xe0d1004f,0x3f8fb66a,0x9f590037}},	//   ša_, هزة_, _sugu_, ísí_,
   {{0x3f870006,0x68ed4dbb,0x636d0453,0x6d4f0453}},	//   _sinu_, nead, múnm, ébal,
   {{0xdb0605ee,0x39952bf2,0x3f870490,0x63760183}},	//   rskú, _lås_, _pinu_, fând,
   {{0x68edb66b,0x27e406d7,0xee390eb4,0x809f0fcf}},	//   head, _ämne_, зно_, _ग्रे,
   {{0x3f87434b,0x68edb66c,0x69c70207,0x39951e8b}},	//   _vinu_, kead, jrje, _nås_,
   {{0xb3450279,0x68ed2278,0x63764505,0x3f870118}},	//   biçã, jead, tâng, _winu_,
   {{0x68edb66d,0x69c1024e,0x3f87b66e,0x637600af}},	//   dead, álen, _tinu_, bând,
   {{0x643a02b5,0x290bb66f,0x63761765,0x2be10324}},	//   לערנ, _anca_, când, _फहरा,
   {{0x68ed0037,0x63a2006c,0x69c100b8,0x13e80033}},	//   fead, zpon, šlen, পিয়,
   {{0x68edb670,0x63760043,0x63bbb671,0x248d010d}},	//   gead, mâne, _ovun, _ngem_,
   {{0x69c77f71,0x63a2b672,0x27e6016e,0xfc3f01ef}},	// [d8a0] arje, xpon, ïon_, saír_,
   {{0x3cdc09b4,0x39952e19,0x248db673,0x290b023a}},	//   ग्रे_, _fås_, _agem_, _enca_,
   {{0xfad70779,0x63bbb674,0x02c93421,0x612e009e}},	//   _אויך_, _avun, _राजभ, _lùla,
   {{0x69dcb675,0x68ed09c3,0x6135008a,0x938a0b64}},	//   mtre, cead, _hálf, пска_,
   {{0x69dcb676,0x69ceb677,0x63a20159,0xe2f801e0}},	//   ltre, lube, upon, делі_,
   {{0x6d469d7c,0xbcfb0079,0x69dc0298,0xa1aa27fb}},	//   hika, rléi, otre, птиз_,
   {{0x69dcb678,0x27f2b679,0x61350093,0xbcfb0079}},	//   ntre, lwyn_, _málf, sléi,
   {{0x6d4626fb,0x63a2b67a,0xb34503e6,0x31ba0029}},	//   jika, ppon, tiçã, rīz_,
   {{0xb4cc2fa9,0x6d466dd0,0x20020093,0x6562012f}},	//   लली_, dika, íki_, mooh,
   {{0xb3450370,0x4426b67b,0x69ceb67c,0x2d8907e5}},	//   riçã, myo_, kube, _siae_,
   {{0x4426b67d,0xb3450370,0xa0a60cac,0x2d44006c}},	//   lyo_, siçã, _заед, rűen_,
   {{0x6d46b67e,0x44260103,0x68ed1111,0x65620008}},	//   gika, oyo_, xead, nooh,
   {{0x4426b67f,0x48fb0f8a,0x69ce0298,0x8fa30664}},	//   nyo_, _लोगो_, eube, _баче,
   {{0x4426a3e1,0x6f0a028b,0x69dc711b,0xa3e80c57}},	//   iyo_, _unfc, ftre, _बहन_,
   {{0xdb040caa,0x68ed2858,0x44260088,0x998500b8}},	//   _avió, tead, hyo_, álů_,
   {{0x44260273,0x69c700da,0x7bda002d,0x6d460afe}},	//   kyo_, rrje, ătur, cika,
   {{0x68edb173,0x69dcb680,0x7d0db681,0x3cf8381f}},	// [d8b0] read, atre, _inas, _سعيد_,
   {{0x68edb682,0x4426b683,0x69c7003c,0x69dcb684}},	//   sead, dyo_, prje, btre,
   {{0xceb3168d,0x6ed81782,0x7d0db685,0x69dc004f}},	//   ריע_, _मानु, _knas, ctre,
   {{0xa56700d1,0x290b435f,0x7bdd00be,0x00000000}},	//   ردان, _unca_, otsu, --,
   {{0x7bddb686,0x4426b687,0x7bcf027d,0xa3ab0066}},	//   ntsu, gyo_, nucu, कीं_,
   {{0x6d46b688,0x7bddb689,0x316602d0,0xe3b00413}},	//   zika, itsu, _akoz_, صره_,
   {{0x44260b0a,0x95c803fa,0x1a9c02b5,0x7bdd00ab}},	//   ayo_, _пута_, ליגע, htsu,
   {{0xa2cd0275,0x44260b55,0x25be00fb,0xd24e0079}},	//   _साक्, byo_, _ætla_, تنى_,
   {{0x44260232,0x8ca20246,0xb87b0037,0x439501d3}},	//   cyo_, _क्षो, _mbío, _разс,
   {{0x7d0db68a,0xd2f70332,0x6d46aead,0x63760279}},	//   _anas, _سکتا_, wika, tâne,
   {{0xed5a2d7a,0x6ea70332,0xdca60192,0x69dcb68b}},	//   дон_, ونکہ_, кани, xtre,
   {{0x2cb201c2,0x63760279,0x7bdd0f0a,0xd24e00d1}},	//   _qeyd_, râne, ftsu, _بچه_,
   {{0x317f0723,0x7aee00d7,0x7bcfb0e5,0x61350215}},	//   mmuz_, tebt, gucu, _pálf,
   {{0x69dcb68c,0x8ca213ab,0x316d511a,0x7d0d9d4c}},	//   ttre, _क्रो, llez_, _enas,
   {{0x637603e6,0xf2d202b5,0xaad3143a,0x21fc0355}},	//   lânc, יעם_, _तारक, máhá_,
   {{0x69dcb68d,0xdb0f004f,0x7d0d9859,0x6c060d46}},	//   rtre, rscá, _gnas, _азиз,
   {{0x7bdd00d7,0x7bcf046d,0x637612b9,0x2cee0066}},	// [d8c0] ctsu, cucu, nânc, ज़ील_,
   {{0x442619c6,0x3ce3004e,0x9bb70122,0x27f200e9}},	//   vyo_, ट्ठे_, _שהיה_, rwyn_,
   {{0x6562043d,0x4426b68e,0x00000000,0x00000000}},	//   tooh, wyo_, --, --,
   {{0x4426203d,0xb4cc1e82,0x03a615ae,0x81ea0033}},	//   tyo_, लले_, видо, মিম_,
   {{0xd8430187,0x3205b68f,0x00000000,0x00000000}},	//   ročí_, _arly_, --, --,
   {{0x44265ca7,0xcc3b016b,0x316608b7,0x04431f7c}},	//   ryo_, וענט, _skoz_, шечн,
   {{0x44267396,0xf74313f8,0x7bdd02b1,0x0fc30831}},	//   syo_, _теро, ztsu, ্বোধ,
   {{0x44260dc3,0x63760279,0x39526def,0x6d5601d5}},	//   pyo_, fânc, nnys_, _njya,
   {{0xe8050324,0xb386002d,0xb113081b,0x05552e02}},	//   रिया_, _алал, рмыш, _стря,
   {{0x7d0db690,0x21ce0095,0x7bdd01e8,0xbcfb00f7}},	//   _snas, _məhz_, vtsu, hlét,
   {{0xb87b0183,0x27240523,0x316db691,0x00000000}},	//   _abíl, _höns_, blez_, --,
   {{0x5d640fa7,0x7bddb692,0xa0a6005f,0x27240282}},	//   итяз, ttsu, _радд, _köns_,
   {{0x60c2773c,0xdb0401ef,0xad26026b,0x63760132}},	//   _idom, _aviñ, ارپو, cânc,
   {{0x752001e8,0x7bcfb693,0x7bdd1235,0x69c10187}},	//   _lomz, rucu, rtsu, šlem,
   {{0x2736054e,0xa92301ba,0x7bddb694,0x99670210}},	//   _mænd_, áľov, stsu, втал,
   {{0x7d0d0054,0x7bcf3016,0x613502d7,0xdb061dab}},	//   _unas, pucu, _gáld, mský,
   {{0xdb060314,0x6aa2b695,0x60c2002f,0x9875117a}},	// [d8d0] lský, _şofe, _mdom, улац,
   {{0x6d44004e,0x47340409,0x00000000,0x00000000}},	//   _zmia, анус, --, --,
   {{0xdb060076,0x60c2b696,0x75202b26,0x00000000}},	//   nský, _odom, _bomz, --,
   {{0x60c2b697,0xe79501df,0x200601ed,0x00000000}},	//   _ndom, _ماسک, _oroi_, --,
   {{0x3949659c,0xd103364c,0xbcfb0320,0xfbdf0183}},	//   mias_, _शोषण_, llés, ntê_,
   {{0x6135b698,0x63760279,0x60c223a8,0x68fd156b}},	//   _mále, vânc, _adom, _hasd,
   {{0x216910a9,0x6145b699,0x68fd010b,0xdb060187}},	//   ники_, лека, _kasd, jský,
   {{0x637603e6,0xdb060187,0x00000000,0x00000000}},	//   tânc, dský, --, --,
   {{0x6135024e,0x68fda9f8,0x1c0707ba,0x5455b69a}},	//   _nále, _masd, शिफल_, _сват,
   {{0x60c2b69b,0x63760279,0x3949b69c,0x6d44027e}},	//   _edom, rânc, hias_, _smia,
   {{0x0d861bdc,0x3949010b,0x2006093b,0xe8050026}},	//   ллон, kias_, _eroi_, रिडा_,
   {{0x02df2218,0x39490453,0x60c2009e,0x40940fb4}},	//   प्रभ, jias_, _gdom, _кршт,
   {{0xeb9779af,0x394904da,0x518400af,0xdee52695}},	//   лия_, dias_, _туфа, _боли,
   {{0xdd8e0088,0x2d910279,0xdb060097,0x543a016b}},	//   _کوي_, ízes_, bský, געשא,
   {{0xa2db1b8f,0x3949b69d,0xbcfb12c3,0x06b20083}},	//   _नान्, fias_, glés, _চালি,
   {{0x3949365e,0x6d4409fa,0x81b50033,0x6d56007b}},	//   gias_, _umia, _জমা_, _ujya,
   {{0x752000d7,0x2fdfb69e,0xa6e60036,0x7d7b0317}},	// [d8e0] _romz, ntug_, лжал, _אנקו,
   {{0x81ea0083,0x657b010d,0x6569b69f,0x06cc0033}},	//   মিত_, _ahuh, _akeh, র্নি,
   {{0xf8bf0248,0x6135ab48,0x6b961859,0x645b002a}},	//   _clés_, _zále, _huyg, _axui,
   {{0x3949b6a0,0x68fd38b4,0x7afeb6a1,0x27e6048e}},	//   cias_, _gasd, _hapt, çons_,
   {{0xbef302cb,0x7afe2845,0x9cd70122,0x31170067}},	//   _असून_, _kapt, רונה_, थानः_,
   {{0x08fc00c8,0xf7460086,0x29000291,0x6ed802e4}},	//   _একটু_, _сего, ldia_, _माधु,
   {{0x27e0b6a2,0x41e60c74,0xf1a300c7,0x75207abe}},	//   ltin_, استف, брын, _tomz,
   {{0xd010004f,0xdb061b66,0x7afeb6a3,0x68e41691}},	//   قلب_, vský, _lapt, nfid,
   {{0x29000054,0x2fdf0430,0xa3e800be,0xf8bf0118}},	//   idia_, gtug_, _बहि_, _klér_,
   {{0x4ad3045c,0x138a004f,0xe8050d00,0xdb062c8b}},	//   _ताइव, _أخرى_, रिता_, tský,
   {{0x22930514,0x9f4f0176,0x27e027e6,0x32930079}},	//   _المس, _argó_, htin_, _المأ,
   {{0x3949b6a4,0x27e0a691,0xdb06b6a5,0x60c2b6a6}},	//   xias_, ktin_, rský, _udom,
   {{0x39492dea,0xa2db0930,0x27e0b6a7,0x2ca00371}},	//   vias_, _नाम्, jtin_, _dfid_,
   {{0x6b9601d6,0x613500b8,0xdb060355,0x2900b6a8}},	//   _duyg, _vále, pský, edia_,
   {{0x13d110b7,0x3949b6a9,0x7afe00e0,0x68e4b6aa}},	//   _सम्भ, tias_, _dapt, ffid,
   {{0x27e0b6ab,0x06cc0033,0xbcfb00b5,0x68e40098}},	//   ftin_, র্মি, rlés, gfid,
   {{0x39490aca,0x7afe0043,0x3f8e0103,0x68fd0298}},	// [d8f0] rias_, _fapt, _kifu_, _vasd,
   {{0x3949b6ac,0x657bb6ad,0xaadc00a1,0x68fdb6ae}},	//   sias_, _shuh, _बायक, _wasd,
   {{0x394912d1,0x68fdb6af,0x06cc0033,0xa2c3012f}},	//   pias_, _tasd, র্ভি, रणस्,
   {{0xc56b250f,0xa2cd164f,0x68e40079,0x7afeb6b0}},	//   رحال_, _साङ्, cfid, _zapt,
   {{0x7afe0723,0x61fa01ed,0x78adb6b1,0x00000000}},	//   _yapt, _astl, mbav, --,
   {{0x06cc0033,0x59ac00b4,0x798f0371,0x657b0118}},	//   র্বি, टीकर, _hicw, _whuh,
   {{0x657b00da,0x798f001c,0x00000000,0x00000000}},	//   _thuh, _kicw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f5517a3,0x61fa03c1,0x3f8e08c7,0x00000000}},	//   итос, _estl, _bifu_, --,
   {{0x80d700a1,0x69cb00ea,0x3ce9021d,0x00000000}},	//   _यावे, _āgen, _abav_, --,
   {{0xd2511168,0x7bdf0176,0x613508c0,0x6285024e}},	//   _بنا_, _aqqu, _cálc, ýhod,
   {{0xeb9a4cc1,0xd0110082,0x7afeb6b2,0x7ff5128d}},	//   ким_, _ولا_, _sapt, _نستا,
   {{0xed57094f,0x7afe51f1,0x98a000f4,0x00000000}},	//   роя_, _papt, lkić_, --,
   {{0xa3e800b1,0x3f8e0027,0x2d5200cd,0x00000000}},	//   _बहस_, _gifu_, kšeg_, --,
   {{0xc3320122,0x798fb6b3,0x98a000cd,0x395931fc}},	//   חום_, _bicw, nkić_, _bjss_,
   {{0x27e0b6b4,0x7afeb6b5,0xab5b02b1,0x00000000}},	//   ttin_, _wapt, gsüb, --,
   {{0x2900b6b6,0x7afe12ea,0x5746290a,0x27e0b6b7}},	// [d900] rdia_, _tapt, анаб, utin_,
   {{0x68e4b6b8,0xdb060093,0x4a4600c3,0xbcfb00b5}},	//   sfid, rskó, _внов, llép,
   {{0x27e0b6b9,0x48e63626,0xdb2400bf,0xdb060093}},	//   stin_, _конв, _نوکی, sskó,
   {{0xc56629d6,0x27e0b6ba,0xb4c2000c,0x84e61958}},	//   шкек, ptin_, ूले_, родж,
   {{0x63860009,0x00000000,0x00000000,0x00000000}},	//   агда, --, --, --,
   {{0x69ce04ce,0x31c66cac,0x6abc008a,0x798f0371}},	//   orbe, асив, narf, _zicw,
   {{0xd24f2e63,0x23270274,0x798f007b,0xe2970200}},	//   ونه_, роји_, _yicw, шај_,
   {{0xbcfb00b8,0x6abcb6bb,0x6ed81b8f,0x2fcd1808}},	//   jlép, harf, _माहु, freg_,
   {{0xd0e2b6bc,0x30e2022e,0x2fcd0088,0x69ce033b}},	//   क्षण_, क्षः_, greg_, hrbe,
   {{0x80a600dc,0x2575022a,0x3ce90036,0x6abc0093}},	//   _ट्रे, håll_, _sbav_, jarf,
   {{0x6abc3695,0xa2db0099,0x61fa00d5,0x6fc20067}},	//   darf, _नात्, _ustl, _शिकं,
   {{0x2fcdb6bd,0x61350355,0x00000000,0x00000000}},	//   breg_, _válc, --, --,
   {{0x6abc0297,0x69ceb53e,0x69c8b6be,0x00000000}},	//   farf, erbe, áden, --,
   {{0x6d5d00f7,0xa3ab0099,0x6abcb6bf,0x98a90a66}},	//   érab, कीट_, garf, rkač_,
   {{0xff7b0070,0x6135b6c0,0x00000000,0x00000000}},	//   _שטומ, _hála, --, --,
   {{0x2d520254,0x636d0079,0xe6af021a,0x613500fe}},	//   všeg_, lúnt, टर्ज, _kála,
   {{0xdb040279,0x69ce3af4,0x58871397,0x78adb6c1}},	// [d910] _aviõ, arbe, рыва, rbav,
   {{0x6135b6c2,0x9b44026e,0x399c0079,0x798f0027}},	//   _mála, _ونيو, _fís_, _wicw,
   {{0xd0060357,0x04950037,0xe80508b0,0x00000000}},	//   _کل_, ملاح, रिहा_, --,
   {{0x7af5b6c3,0x00000000,0x00000000,0x00000000}},	//   lezt, --, --, --,
   {{0xfc3f00b8,0x69d5b6c4,0x61351055,0x00000000}},	//   nzí_, luze, _nála, --,
   {{0xf3675795,0x257c0187,0x2d52012e,0x7af5107f}},	//   штен, víle_, pšeg_, nezt,
   {{0xa3ab0026,0xe805021a,0x236791d0,0x69d501ed}},	//   कीज_, रिवा_, ronj_, nuze,
   {{0x06cc0033,0x2fcdb6c5,0x98a00506,0x257c0098}},	//   র্দি, treg_, rkić_, tíle_,
   {{0x613501ef,0x7af500b5,0xdee52746,0xc4d2011d}},	//   _cála, kezt, бопи, _מגן_,
   {{0x2fcd7f8e,0xef1900af,0x41e700d8,0x636d1111}},	//   rreg_, умо_, _віда, gúnt,
   {{0x6ed810aa,0x02a40043,0x4d662725,0x7af5b6c6}},	//   _मारु, _фрум, йков, dezt,
   {{0x69d501cc,0x6135b6c7,0xee360f92,0x40950037}},	//   duze, _fála, сню_, _الإر,
   {{0x6abc008a,0x30850037,0xdbf40026,0x00000000}},	//   tarf, _الشف, ेटेड_, --,
   {{0xfaa3578a,0x69d50af3,0x7af5b28e,0x81ea0033}},	//   заро, fuze, gezt, মির_,
   {{0xbb431f08,0x69d5b6c8,0x613c01ef,0x23d100c0}},	//   черк, guze, _délf, _समझद,
   {{0x399c003e,0x6abcb6c9,0x3a25013c,0xa3e82493}},	//   _vís_, sarf, älpa_, _बहल_,
   {{0x3d150e04,0xc6960037,0x06ea0390,0x28b9002d}},	// [d920] धारे_, مشاع, лмак_, русэ_,
   {{0xf7720037,0xdb1d00a2,0x00000000,0x00000000}},	//   ساء_, yssé, --, --,
   {{0xd0f94eb8,0x30f90efa,0x234800f8,0x319500ea}},	//   ्याण_, ्याः_, یستی_, _kāzu_,
   {{0xd91000bf,0x5a17011d,0x2d92021e,0x93aa0037}},	//   _تیر_, _הקטן_, _jiye_, هاتف_,
   {{0x6ed822a7,0x232a14d0,0x68f62ef1,0x2d9208c7}},	//   _मालु, лоди_, meyd, _miye_,
   {{0x2902b6ca,0xf6d500d4,0x2d92021e,0x68f6438e}},	//   _haka_, _міся, _liye_, leyd,
   {{0x290225d1,0xb0dc0084,0x6135003e,0xdb1d00f7}},	//   _kaka_, _यादग, _sála, ussé,
   {{0xf9930d85,0x2902b6cb,0x68f67ccb,0x2d9200d0}},	//   הרה_, _jaka_, neyd, _niye_,
   {{0x3d1c0429,0x29027e62,0x74540332,0x7af500b5}},	//   याने_, _maka_, _بھائ, yezt,
   {{0x613500f5,0x2902b6cc,0x11d6093e,0x68f62a8d}},	//   _vála, _laka_, _гідр, heyd,
   {{0x2d98053e,0x2d800159,0x2d92021e,0x614602d5}},	//   êre_, _bhie_, _biye_, _лежа,
   {{0xd7fe00e8,0x2902383a,0xd6de0083,0x63a4002d}},	//   _đăng_, _naka_, ড়িয, ţinu,
   {{0x2d920723,0x7165004f,0x68f61008,0x7af53b51}},	//   _diye_, _بالك, deyd, tezt,
   {{0x637f0279,0x613c9bea,0x2126010d,0x69d5b6cd}},	//   cênd, _bélg, _hooh_, tuze,
   {{0x2902b6ce,0xa2db20af,0xd6de0033,0x68f600e9}},	//   _baka_, _नास्, ড়ায, feyd,
   {{0x3ebeb6cf,0x29021e89,0x497500d8,0x57b50800}},	//   latt_, _caka_, ілас, жбат,
   {{0x76b90f08,0x6d4fb6d0,0x290701c0,0x212600e0}},	// [d930] илар_, mica, ěna_, _mooh_,
   {{0xec380052,0x06cc0033,0x613c0093,0x21260858}},	//   _לאחר_, র্সি, _héld, _looh_,
   {{0x290201ed,0xa3db00a1,0xab5b033b,0x88950d6e}},	//   _faka_, ढून_, srüs, _минх,
   {{0x3d1c0387,0x29020107,0x2126023f,0xab5b0225}},	//   याये_, _gaka_, _nooh_, prüs,
   {{0x320c012f,0x3ebe9a13,0x5ed00033,0x394b023a}},	//   _ardy_, katt_, ত্যে, _imcs_,
   {{0xdcb60d00,0x55bb00d1,0x85bb0c26,0x2902b6d1}},	//   _अज्ञ, _مطرح_, _مارس_, _zaka_,
   {{0x6d4fb6d2,0x3d1c018d,0x7aea033b,0x613500b8}},	//   kica, यामे_, _öfte, _dáln,
   {{0x6d4f9dcc,0x21263b80,0x67270523,0x81ea0033}},	//   jica, _cooh_, _hojj, মিং_,
   {{0x200b0076,0x320c010d,0x3cef00b4,0x3f9900e2}},	//   íci_, _erdy_, ेजने_, êsu_,
   {{0x63a9b6d3,0x656b5936,0x2d92b6d4,0x672740f5}},	//   _iten, logh, _siye_, _jojj,
   {{0x63a90009,0x2d92b6d5,0x637f0132,0x442fb6d6}},	//   _hten, _piye_, gêne, lyg_,
   {{0x6d4fb6d7,0xac0a0036,0xdb0601ff,0x656bb6d8}},	//   gica, анма_, nskö, nogh,
   {{0x2cadb6d9,0x3ebeb6da,0xae170148,0xeb9a0009}},	//   ñeda_, batt_, _گذشت, риг_,
   {{0x290201ca,0x3b0a0086,0x6d4f6f1f,0x63a90054}},	//   _saka_, шего_, ébar, _mten,
   {{0x290294eb,0x68f60086,0x6f0300af,0xdb0601ff}},	//   _paka_, teyd, _ianc, kskö,
   {{0x60db2f75,0x6f033187,0x63a902f4,0x6d4fb6db}},	//   ngum, _hanc, _oten, cica,
   {{0x6f03b6dc,0x29025209,0x63a91642,0x574a5e64}},	// [d940] _kanc, _vaka_, _nten, азам_,
   {{0x2902b6dd,0xaded0066,0x68f6b6de,0x00000000}},	//   _waka_, _जहान_, seyd, --,
   {{0x2902b6df,0x7d160298,0x3ce10914,0x613500d5}},	//   _taka_, _knys, _कामे_, _nálo,
   {{0x7d0401a3,0x186a0352,0xd6b20033,0x00000000}},	//   _jais, _вами_, _চাওয, --,
   {{0x7d04b6e0,0x63a901ef,0x25ad0187,0x69c10314}},	//   _mais, _cten, _čele_, šlet,
   {{0x7d04b6e1,0x6d4fb6e2,0x60db0029,0xf1a61956}},	//   _lais, zica, egum, орин,
   {{0x63a9b6e3,0x1dc501c0,0xa2db0127,0xd13a00c3}},	//   _eten, _विगत, _नार्, ихи_,
   {{0x7d04b6e4,0x442f001e,0x26c701ba,0x6d4f6c0a}},	//   _nais, byg_, ónov_, xica,
   {{0x6f030897,0x6d4f13a6,0x3ebe01e0,0x00000000}},	//   _banc, vica, tatt_, --,
   {{0x6f03449a,0x6d4fb6e5,0x21260159,0x7d16b6e6}},	//   _canc, wica, _wooh_, _anys,
   {{0x6d4f0fe4,0x7d04b6e7,0x613c006c,0x3ebeb6e8}},	//   tica, _bais, _péld, ratt_,
   {{0x7d04175e,0x3ebe30f6,0x75220107,0x6f030284}},	//   _cais, satt_, njoz, _eanc,
   {{0x6d4f0dbb,0xe13301c8,0x6135b6e9,0x6442021e}},	//   rica, _іншы, _zálo, nzoi,
   {{0x60c0b6ea,0x613cb6eb,0x2d9801ef,0x78a4021d}},	//   lamm, _déle, íres_, eciv,
   {{0x7d04b6ec,0x637f0370,0xd90f00bf,0x9e6603c5}},	//   _fais, lênc, نید_, _باشن,
   {{0x7d04b6ed,0x60c0b6ee,0x6f03027a,0x9f5d02d0}},	//   _gais, namm, _zanc, _aswè_,
   {{0x6d4db6ef,0x637f0279,0xd7fb0409,0x2d9c018d}},	// [d950] _imaa, nênc, шув_, _huve_,
   {{0x7d040af1,0xb87b002a,0x6f03b6f0,0x00000000}},	//   _zais, _acíc, _xanc, --,
   {{0x2d9cb6f1,0x442fb6f2,0x7d1600e9,0x7d0408c7}},	//   _juve_, wyg_, _ynys, _yais,
   {{0x2fc601cc,0x442f06d7,0xf8b105f5,0x60c0b6f3}},	//   _ovog_, tyg_, _سکر_, jamm,
   {{0x183500c2,0x6135b6f4,0x3d1c0387,0xdb06b6f5}},	//   _זאָל_, _dáll, याते_, rskö,
   {{0x637f0370,0x2d9cb6f6,0x257c01ba,0x442fb6f7}},	//   dênc, _ouve_, ríla_, ryg_,
   {{0x6d4d0196,0xe5c47d69,0x26c104fb,0x6f03b6f8}},	//   _omaa, _осто, maho_, _ranc,
   {{0x26c108dd,0xda5c00a5,0x613500b5,0x63a91289}},	//   laho_, יכול, _válo, _tten,
   {{0x6f0300bf,0x63a9b6f9,0xaadc60fb,0x637f03e6}},	//   _panc, _uten, _बालक, gênc,
   {{0x7d04b6fa,0x6d4d09d6,0xb4bb0006,0xfe4507b0}},	//   _sais, _amaa, _आजु_, зноо,
   {{0x613c02e1,0xe80202e4,0x2fc60009,0x1d0a1362}},	//   _séle, _रैना_, _evog_, бени_,
   {{0x78bd1abc,0xed5a219f,0x6f0300f8,0xc104004f}},	//   _nesv, сом_, _wanc, _يولي,
   {{0x7d04b6fb,0x6f03b6fc,0x26320009,0x637f0279}},	//   _vais, _tanc, _iđoš_, cênc,
   {{0x613c0332,0x200f00d8,0xdb0601ba,0x6d4d0103}},	//   _véle, _irgi_, jskô, _emaa,
   {{0x7d04b6fd,0x78bd0c66,0xd35600a5,0x64420714}},	//   _tais, _besv, לישי_, zzoi,
   {{0x7d0409c3,0x613c6be0,0x3f9d027c,0x78bdb6fe}},	//   _uais, _téle, _kuwu_, _cesv,
   {{0x78a46df9,0xeaaf006c,0xaa8a0416,0xf8bf01ef}},	// [d960] rciv, ئٹہ_, _گندم_, _toén_,
   {{0x78a4b6ff,0x2b1d004e,0x869ab700,0x26c10010}},	//   sciv, माणु_, стат_, gaho_,
   {{0x1a9b00c2,0x4a9b02b5,0x7bc63d64,0x3f9d0ac8}},	//   _לייע, _לייג, lsku, _luwu_,
   {{0x63760012,0xdb0d008a,0x2bd302e4,0xc4860ff6}},	//   mâni, _hvað, _तिमा, плек,
   {{0x26c167ed,0x61350332,0x7bc62cf7,0x75290051}},	//   baho_, _váll, nsku, _doez,
   {{0xfc3f2b83,0x637f0279,0x61351d2b,0x273f00af}},	//   ncía_, vênc, _dálm, _cînd_,
   {{0x2fc601cc,0x60c0b701,0x200fb702,0xa50a01d3}},	//   _svog_, tamm, _argi_, _лева_,
   {{0xd1300082,0x637f03e6,0xb0c60437,0x30140036}},	//   ئمة_, tênc, रृंग, ддир,
   {{0x60c0b703,0x3940012f,0x7bc635b9,0xa4f10448}},	//   ramm, ihis_, jsku, lışı_,
   {{0x60c0b704,0x637f00c9,0x6d4db60f,0x75290054}},	//   samm, rênc, _smaa, _zoez,
   {{0x637f03e6,0x2cad20d9,0x6d4d011e,0x7bc601ba}},	//   sênc, ñedo_, _pmaa, esku,
   {{0x2fc6044d,0x26c1041b,0xc27b0317,0x612e0211}},	//   _tvog_, zaho_, _פראי, _cùlt,
   {{0x78bd4f93,0xdfcf0037,0x7bc617ad,0x39400c6f}},	//   _resv, _مين_, gsku, dhis_,
   {{0x2d9cb705,0x6ffb0122,0x78bd025c,0xab5b00b5}},	//   _tuve_, _להדפ, _sesv, csül,
   {{0x26c10010,0x63760279,0x81ea0033,0xde5700d4}},	//   vaho_, gâni, মিক_, _наші_,
   {{0x6d4d3664,0x3940184f,0xdff351ba,0x26c104fb}},	//   _umaa, ghis_, _अहमद_, waho_,
   {{0xb9055cd1,0x26c1018c,0x27060033,0x2ca9b706}},	// [d970] _ना_, taho_, রানো_, _ifad_,
   {{0xc6a4135d,0x629a011e,0x6abe033b,0x6fcf0099}},	//   ерци, _ngto, _gepf, _दिसू,
   {{0x7529b707,0x26c1070b,0x6d5db708,0x637603e6}},	//   _poez, raho_, onsa, câni,
   {{0x6d5d004a,0x3940b709,0xdced00cd,0xbfa500e2}},	//   nnsa, chis_, _okač, _biệ,
   {{0xdfc621a0,0x29190043,0x2d5202c6,0xdce600ea}},	//   _جي_, _insa_, kšen_, nokā,
   {{0xe3b00372,0x27e90f3a,0x68ed67f9,0x69c7b70a}},	//   ارن_, mtan_, lfad, osje,
   {{0xe8050fbf,0x69c7b70b,0x752901e4,0x27e91425}},	//   रिका_, nsje, _toez, ltan_,
   {{0x56946ca3,0x7bc6b70c,0x2909000e,0xc8dd0066}},	//   _част, ysku, ndaa_, यलिट,
   {{0x69d502c9,0x3d1c0066,0x6006021f,0xdb1db70d}},	//   hrze, यासे_, дным_, lusõ,
   {{0x69c7426a,0x27e9281a,0x33390148,0x02a70d73}},	//   ksje, itan_, _بزرگ_, _храм,
   {{0x69d50035,0x69c7241d,0xbae30033,0x22590037}},	//   jrze, jsje, য়াছ, _بلاد_,
   {{0x69c7b70e,0x628105e2,0x27e9b70f,0x69d5004e}},	//   dsje, _izlo, ktan_, drze,
   {{0x68ed004f,0x7bc6b710,0x3d1e00ab,0x27e95e9f}},	//   dfad, usku, _बचीं_, jtan_,
   {{0x7bc601ad,0x6d5db711,0x2919b712,0x63760279}},	//   rsku, ansa, _ansa_, tâni,
   {{0x27e90291,0x3940b713,0xfc3f249a,0x2919010d}},	//   etan_, this_, rcía_, _bnsa_,
   {{0x27e9b714,0x63760132,0x29190284,0xdb1d00be}},	//   ftan_, râni, _cnsa_, dusõ,
   {{0x27e902b3,0xb8f60311,0x69c70223,0x69d57987}},	// [d980] gtan_, _सय_, asje, arze,
   {{0x39400221,0x613c0248,0xa4f1037a,0x69d50035}},	//   shis_, _méla, tışı_, brze,
   {{0x7afcb715,0x27e90f1a,0xd9460b32,0x63bb4ac8}},	//   mert, atan_, _жени, _awun,
   {{0x7afc1747,0x27e902b3,0x69dcb716,0x61351231}},	//   lert, btan_, mure, _dálk,
   {{0x27e9b717,0x0edd00a1,0x03a30352,0x938a0011}},	//   ctan_, _मांड, вичо, оска_,
   {{0x7afcb718,0xbfa50019,0x00000000,0x00000000}},	//   nert, _việ, --, --,
   {{0xdcedb719,0x3cf200d5,0x6d5d008d,0x63bbb71a}},	//   _skač, _obyv_, ynsa, _ewun,
   {{0xab5b00a8,0x6fbf018d,0x613cb71b,0xdb0f0176}},	//   vsüm, लीभू, _béla, nscò,
   {{0xbcfb02e1,0x69dcb71c,0x6d5db71d,0x613c0118}},	//   nnée, hure, éram, _céla,
   {{0xb38300af,0x3ce10ccf,0x613c0248,0x7afcb71e}},	//   _алул, _काहे_, _déla, jert,
   {{0x2d52042a,0x68ed01d6,0x27e901a3,0x63a001e9}},	//   ršen_, yfad, ztan_, _humn,
   {{0x613c00fb,0xdced0009,0x63a0002f,0x27e9b71f}},	//   _féla, _tkač, _kumn, ytan_,
   {{0x7afcb720,0x2d520b16,0x613c00a2,0x61ea10c0}},	//   fert, pšen_, _géla, ltfl,
   {{0x69d5006a,0x69c738b9,0xc4c40332,0x7afc01b7}},	//   trze, tsje, _ھے_, gert,
   {{0x69dcb721,0xda78392c,0x63a05154,0xc4c400fd}},	//   gure, дят_, _lumn, _پے_,
   {{0x69c77984,0x78b60298,0x00000000,0x00000000}},	//   rsje, gbyv, --, --,
   {{0x6b97009f,0x68edb722,0x27e913b5,0xbcfb00f7}},	// [d990] _tixg, rfad, utan_, gnée,
   {{0x27e9b723,0x69d5006a,0x7bdd840d,0x69dcb724}},	//   rtan_, prze, musu, bure,
   {{0x7bdd5c3f,0x69dc1170,0xa2af00e7,0x9f9a0421}},	//   lusu, cure, ुरस्, lään_,
   {{0x27e9b725,0x29190b04,0x613500b8,0x00000000}},	//   ptan_, _unsa_, _válk, --,
   {{0x7bdd2c20,0x9f9a03ad,0x798d0069,0x628100b5}},	//   nusu, nään_, mmaw, _szlo,
   {{0x63a00012,0x613c0118,0xc2c50037,0x2904008d}},	//   _dumn, _réla, ريبي, _ómar_,
   {{0xe1f11c0c,0xa4d502ce,0xe2960370,0xa0a52286}},	//   است_, _пові, наш_, найд,
   {{0x7afc107f,0x7bddb726,0x9f9a0086,0x3d1e0066}},	//   zert, kusu, kään_, _बचें_,
   {{0x7ae5b727,0x7afcb728,0x9f9a00c3,0x63bb437e}},	//   _ocht, yert, jään_, _uwun,
   {{0x6135008a,0x200db729,0x7bddb72a,0x69dc89e0}},	//   _máli, rvei_, dusu, yure,
   {{0x7afc2212,0x06cc00c8,0x06d50083,0xfce61b50}},	//   vert, র্কি, স্থি, ноно,
   {{0x7ae5b72b,0x7afc4e02,0x463a0070,0xc0e900d1}},	//   _acht, wert, פערע, _رفتن_,
   {{0x7afcb72c,0x7bddb72d,0x3ce10a44,0x69dc41a6}},	//   tert, gusu, _कारे_, wure,
   {{0x69dcb72e,0x06d50083,0x7afc1bc9,0xdbd200be}},	//   ture, স্তি, uert, müüj,
   {{0x7afcb72f,0x6376453e,0x2cab0079,0xf2d21804}},	//   rert, mânt, éidí_, טעם_,
   {{0x7ae51e0f,0x69dcb730,0x63760279,0x7bddb731}},	//   _echt, rure, lânt, busu,
   {{0x7afcb732,0x8b962afc,0x69dc9f22,0x61357b06}},	// [d9a0] pert, _проч, sure, _cáli,
   {{0xe2050028,0x38660484,0xbcfb00f7,0x98c500ea}},	//   _đóng_, ħor_, rnée, ētās_,
   {{0x63a00a78,0x1f360319,0x00000000,0x00000000}},	//   _sumn, ערער_, --, --,
   {{0x80be004e,0x63a000af,0x2d5200f4,0x89360079}},	//   _एजें, _pumn, kšem_, _أعدا,
   {{0x3ce10084,0x61350168,0x00000000,0x00000000}},	//   कलते_, _gáli, --, --,
   {{0x49080311,0xae1f0d91,0x620600af,0xa27800af}},	//   ाएको_, यमान_, ечиз, мблу_,
   {{0x3ce10035,0x61350187,0xe7e1046c,0xbcfb01ef}},	//   _काले_, _záli, गूठा_, pléx,
   {{0x61eab733,0xab5b018d,0x00000000,0x00000000}},	//   rtfl, tsük, --, --,
   {{0x2d520009,0xe81307b5,0x98a90067,0x00000000}},	//   ršel_, ठिया_, skać_, --,
   {{0x798d0035,0x9f9a00c3,0x672e0a8a,0x6e9400af}},	//   zmaw, vään_, _jobj, кипу,
   {{0x2bd300c0,0xb1e50037,0x11d62149,0x00000000}},	//   _तिहा, _لأنه, _ستاد, --,
   {{0x9f9a0d36,0x8fa6257f,0x3ce10099,0x7ae500f6}},	//   tään_, _заде, _काळे_, _scht,
   {{0x3c4600a2,0x613c00f6,0x00000000,0x00000000}},	//   _rêvé_, _hélo, --, --,
   {{0x7bddb734,0xf8b801a5,0x60c22b0c,0x6376819d}},	//   rusu, _đĩa_, _heom, cânt,
   {{0x2bd3056a,0x0a681578,0x25ad00cd,0x798d022e}},	//   _तिवा, ерти_, _čelo_, tmaw,
   {{0x99980346,0x9f9a0086,0x798d1ea7,0x6135b735}},	//   екст_, sään_, umaw, _páli,
   {{0x671c017a,0x798d8aed,0xa7750274,0x60c2b736}},	// [d9b0] नांक_, rmaw, влач, _meom,
   {{0x65c7006c,0x78a2016f,0x7ae50098,0x4de400fa}},	//   _néhá, ľova, _ucht, _कमाई_,
   {{0x78a21c8e,0x2d5201ba,0xb60600ea,0x672eb737}},	//   žova, dšej_, jušā, _dobj,
   {{0x613505ee,0x60c20a0b,0xa4d501e0,0x05740118}},	//   _hálv, _neom, тоді, هاند,
   {{0x672e0069,0x290b0139,0x00000000,0x00000000}},	//   _fobj, _iaca_, --, --,
   {{0x69da00de,0x2d520ce9,0x613c0088,0x672e0069}},	//   áteg, všem_, _bélo, _gobj,
   {{0x290b01ca,0x6376002d,0x6135008d,0x613c00b5}},	//   _kaca_, vânt, _málv, _célo,
   {{0x290b0124,0x613c000d,0x672e0116,0x00000000}},	//   _jaca_, _délo, _zobj, --,
   {{0x33f42e36,0x290bb738,0x60c296fb,0x63b40187}},	//   _مسلس, _maca_, _deom, čený,
   {{0xee39717b,0xddd800d8,0x2cb909b3,0xa2db09b8}},	//   дно_, _gyvū, ebsd_, _नाट्,
   {{0x0d862447,0x60c2002a,0x27f9002a,0x7bcd00c3}},	//   клон, _feom, _lpsn_, _avau,
   {{0x60c23e47,0x70520416,0xd14b004f,0x661500d5}},	//   _geom, انیا, _عشان_, _mrzk,
   {{0x06cc0083,0xd009b739,0x00000000,0x00000000}},	//   র্টি, _целе_, --, --,
   {{0xd5d10302,0xeb970133,0x2bd30380,0xbea2695e}},	//   _हिंज, кия_, _तिरा, _кашк,
   {{0x290b69ca,0xeb9716b6,0x2d5208b7,0x672e0176}},	//   _baca_, тир_, nšek_, _robj,
   {{0x60c201dd,0xa3d200b4,0xbcfb01ef,0x00000000}},	//   _xeom, _विल_, rnéc, --,
   {{0x672e0470,0x290b09eb,0x26c301cb,0xdd8f0a42}},	// [d9c0] _pobj, _daca_, _bejo_, _بوي_,
   {{0x249fb73a,0x6fd40035,0x5fd400a1,0x61351725}},	//   _agum_, _दिसं, _दिसल, _gálv,
   {{0xe7fe2088,0x26c3b73b,0x290bb73c,0x83fd00b5}},	//   _उनका_, _dejo_, _faca_, _győz,
   {{0x290b0add,0x661500fe,0x00000000,0x00000000}},	//   _gaca_, _drzk, --, --,
   {{0x29004172,0x6d5d1f3c,0x5ed90033,0x69da011c}},	//   meia_, érai, ব্যে, šted,
   {{0x60c2b73d,0x290034db,0x61350093,0x68e4b73e}},	//   _seom, leia_, _málu, lgid,
   {{0x44200012,0x5fd40006,0x212f009e,0x6d46046a}},	//   ţi_, _दिहल, _bogh_, khka,
   {{0x68e4b73f,0x29000d99,0x613cb740,0xfbd3046c}},	//   ngid, neia_, _vélo, _तिलम,
   {{0x60c23b12,0xc95302da,0x53a61d6b,0x613500b5}},	//   _veom, ימה_, _разб, _nálu,
   {{0x29006947,0x0dca0044,0x00000000,0x00000000}},	//   heia_, муми_, --, --,
   {{0x212f08c8,0x29000345,0xceb81627,0x60c2b741}},	//   _fogh_, keia_, rbę_, _teom,
   {{0x09b10083,0x27e0b742,0x61352dea,0xc8e100b4}},	//   _ছিলা, kuin_, _sálv, _फाइट,
   {{0x4426b743,0x2900b744,0x290bb745,0x6f0a034d}},	//   nxo_, deia_, _raca_, _tafc,
   {{0x44268a7b,0x6d460ac8,0x290b1bea,0x27e0b746}},	//   ixo_, ahka, _saca_, duin_,
   {{0x4f9b0052,0x61351fca,0x2ba50084,0x290bb747}},	//   _קבוצ, _válv, _गंवा, _paca_,
   {{0x6d87006c,0x6d468639,0x29000183,0x23d200b4}},	//   _جمعہ_, chka, geia_, _सिंद,
   {{0x27e012c3,0x656200b8,0x481500d8,0xdb1d01ff}},	// [d9d0] guin_, dnoh, ымас, tssä,
   {{0x7d0db748,0x4ab706bc,0x290b01cb,0xa6cc0033}},	//   _haas, _अभिव, _waca_, র্ঘট,
   {{0x7d0d1eca,0x26c3b749,0x290bb74a,0x4426002a}},	//   _kaas, _vejo_, _taca_, exo_,
   {{0x27e0010d,0x2d5208b7,0x7d0d02d4,0xb33c0024}},	//   buin_, všek_, _jaas, _jiħf,
   {{0x7d0db74b,0x4ab7052b,0x6135b74c,0x26c3b74d}},	//   _maas, _अभाव, _mált, _tejo_,
   {{0x7d0d0626,0x78adaa8d,0x799d0027,0x00000000}},	//   _laas, lcav, _hisw, --,
   {{0x799d0657,0x51f51902,0x656200d5,0x00000000}},	//   _kisw, استر, bnoh, --,
   {{0x600945c8,0x7d0d9de7,0x78adb74e,0x3ce901e8}},	//   еним_, _naas, ncav, _ncav_,
   {{0x34940274,0x799d1b68,0x00000000,0x00000000}},	//   _ватр, _misw, --, --,
   {{0x257c053d,0x48160070,0x5f450172,0x212f0118}},	//   víli_, אַטן_, اندل, _wogh_,
   {{0x7d0d3904,0x6135002a,0x3f9cb74f,0x6d460c6f}},	//   _baas, _bált, _divu_, thka,
   {{0x7d0d021d,0x6d4624eb,0x27e0010d,0x799d0107}},	//   _caas, uhka, yuin_, _nisw,
   {{0x29000a4f,0x60c9018d,0xbad6010b,0x68e4048f}},	//   veia_, maem, лівы, vgid,
   {{0x6d46b750,0x60c94844,0xa03a0070,0x3ce900ee}},	//   shka, laem, _רעספ, _ecav_,
   {{0x7d0d1e7b,0xaa4302c4,0x2900819d,0xed5a0009}},	//   _faas, берл, teia_, _пок_,
   {{0x7d0db751,0x27e0b752,0x60c900be,0x2bdc02b4}},	//   _gaas, tuin_, naem, _बिपा,
   {{0x6d560232,0x6d44b753,0x2900b754,0x44260036}},	// [d9e0] _imya, _ilia, reia_, xxo_,
   {{0x60c9046a,0x27e0b755,0x613c00b5,0x68e4b756}},	//   haem, ruin_, _célj, sgid,
   {{0x7d0da748,0x2900b757,0x6d4456a1,0x799d0103}},	//   _yaas, peia_, _klia, _fisw,
   {{0x6135008a,0x44260b53,0x69ce7df1,0x78adb758}},	//   _máls, txo_, msbe, ccav,
   {{0x6562b759,0x442601dd,0x6d44b75a,0x6f0101e9}},	//   rnoh, uxo_, _mlia, kelc,
   {{0x44265988,0x6f01025c,0x46a3923f,0x2d99002a}},	//   rxo_, jelc, _гарв, írez_,
   {{0x69ce58e7,0x6d44b75b,0x3f9c51fc,0x267900af}},	//   nsbe, _olia, _rivu_, _астэ_,
   {{0x3d0e0755,0x69ceb75c,0x4fd401f0,0x3f9c0086}},	//   ियों_, isbe, ажит, _sivu_,
   {{0x7d0d136b,0x3f9cb75d,0xddcf06cc,0x3d18018d}},	//   _raas, _pivu_, _češn, _बोधे_,
   {{0x69ceb75e,0x7d0d1d2c,0x4376b75f,0x8ff70037}},	//   ksbe, _saas, _субт, ارير_,
   {{0x6d44003b,0x7d0d9b41,0x60c90103,0x3f820080}},	//   _blia, _paas, baem, ēku_,
   {{0x6d44066a,0x62880029,0x3d1c018d,0x60c90015}},	//   _clia, _izdo, यागे_, caem,
   {{0x61350332,0x799d012f,0x69dcb760,0x7d0db761}},	//   _vált, _risw, erre, _vaas,
   {{0x6d443f05,0x799d54d2,0x7d0db762,0x6d560273}},	//   _elia, _sisw, _waas, _emya,
   {{0x7d0db763,0x69ceb764,0x613c0332,0x6d44b765}},	//   _taas, gsbe, _nélk, _flia,
   {{0x6d44b766,0xeab0006c,0x62880187,0x78ad00cd}},	//   _glia, قعہ_, _mzdo, ucav,
   {{0xd6db2f4c,0x78adb767,0x2bdc5f12,0x23c60808}},	// [d9f0] ете_, rcav, _बिया, रीमद,
   {{0x78adb768,0x62880e7c,0xb33c0069,0x799db769}},	//   scav, _ozdo, _jiħd, _wisw,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8b109b9,0x613c01c0,0x637f0132,0x00000000}},	//   _ذکر_, _délk, mêni, --,
   {{0xd0061629,0x394909c3,0x7bcf358d,0x02c52e02}},	//   _بل_, mhas_, nscu, айло,
   {{0x39490370,0x9732006c,0x2fcd0124,0x00000000}},	//   lhas_, _وکلا, vseg_, --,
   {{0x628800ee,0xe1252746,0x7bdd02b1,0x20020225}},	//   _czdo, имки, hrsu, çkin_,
   {{0x3949130f,0xb4f902b5,0x2fcd019f,0x6f01033b}},	//   nhas_, _שפּי, tseg_, welc,
   {{0x60c96075,0x657b011e,0xbcfb00b5,0xdb0d021d}},	//   raem, _ikuh, tnén, _ataí,
   {{0xff51036b,0x6d44b76a,0x69dcb76b,0x69ceb76c}},	//   تخب_, _slia, yrre, ysbe,
   {{0x6d44b76d,0x32673c29,0x6f01b76e,0x2fcdb76f}},	//   _plia, _став, relc, sseg_,
   {{0xed5a01f6,0xa2af0266,0x8d5600c3,0x613500b5}},	//   том_, ुरक्, рточ, _váls,
   {{0x65692296,0xff510088,0x212d025c,0x913a016b}},	//   _mjeh, _وخت_, mjeh_, _שענק,
   {{0x69ce09af,0x212d0124,0x23ab008c,0x00000000}},	//   tsbe, ljeh_, _møj_, --,
   {{0x61e30463,0x7e7902b5,0x4e7902b5,0x637f0279}},	//   nunl, _באַז, _באַצ, gêni,
   {{0x6d5d02e1,0x98a31501,0x39490a32,0x656901f4}},	//   érat, жите, ghas_, _njeh,
   {{0x69ceb770,0xf99f0b88,0x6b9e0051,0x37e603d0}},	// [da00] ssbe, _diè_, _tipg, розг,
   {{0x61e300a8,0xe6c50037,0xdc370070,0x657b4583}},	//   kunl, متمي, _כאפט_, _akuh,
   {{0x39490094,0x2d68042a,0xaadb0397,0x65690207}},	//   bhas_, nđeo_, _בחיר, _bjeh,
   {{0x3949b771,0x23ab008c,0x00000000,0x00000000}},	//   chas_, _bøj_, --, --,
   {{0xe3af1062,0x212d022f,0xb6a600d4,0x00000000}},	//   ورو_, djeh_, _вигл, --,
   {{0x68f6001e,0x657b023a,0x4aaf01c0,0x2d820408}},	//   lfyd, _ekuh, _ज्ञव, hlke_,
   {{0x668400f8,0x613cb772,0xf8aa0387,0xe80e258f}},	//   _ایال, _héli, _कलाय, सिका_,
   {{0x213f20fb,0x3940b773,0x23ab054e,0x2912030d}},	//   gkuh_, nkis_, _føj_, ndya_,
   {{0x27f2001e,0xa2e6248c,0x29370070,0x00000000}},	//   ntyn_, _возд, שאפן_, --,
   {{0x613c000d,0x00000000,0x00000000,0x00000000}},	//   _méli, --, --, --,
   {{0x628800ea,0x39401b43,0x2d6800cd,0x3e610160}},	//   _uzdo, kkis_, rđen_, _cγt_,
   {{0x491600b4,0x00000000,0x00000000,0x00000000}},	//   _पोलो_, --, --, --,
   {{0x2d850029,0x7bcf0952,0xed5800d8,0x613c021d}},	//   ēle_, uscu, роў_, _néli,
   {{0x5f73026e,0xbcfb0097,0x00000000,0x00000000}},	//   _واور, mném, --, --,
   {{0x3949b774,0x7bcf0118,0x98c713f9,0x68f600e9}},	//   thas_, sscu, исал, ffyd,
   {{0x613c2b9f,0x3ce1238a,0x3940836e,0x5e9b00a5}},	//   _béli, _काटे_, gkis_, _בבוק,
   {{0xf09300c2,0x613cb775,0x61e300d0,0xe80204aa}},	// [da10] ַנע_, _céli, zunl, रौला_,
   {{0x6d5d3d7f,0xf7700206,0x613c0248,0x657b2163}},	//   lisa, وال_, _déli, _skuh,
   {{0x3d1c0429,0x39400221,0xab5b00ab,0x98a90506}},	//   याचे_, bkis_, ssüs, ljač_,
   {{0x6d5db776,0x613cb777,0x3940b778,0x23ab0a8a}},	//   nisa, _féli, ckis_, _pøj_,
   {{0x39590453,0x98a905e2,0x212d0207,0x270f0033}},	//   _imss_, njač_, vjeh_, সাবো_,
   {{0xdb040082,0xfbb80122,0xbcfbb779,0x61e3b77a}},	//   _stiú, ספות_, dném, tunl,
   {{0x3ce80429,0xdb040083,0x45d45451,0x61e3010d}},	//   _झाले_, _quié, _морс, uunl,
   {{0x61e301d6,0x6b4b006c,0x657b55fa,0x6d5db77b}},	//   runl, _függ, _ukuh, jisa,
   {{0x6d5db77c,0x673504c3,0x20194d59,0x61e3027b}},	//   disa, _kozj, ísi_, sunl,
   {{0xdb040211,0x917100cc,0x43850079,0x00000000}},	//   _ftiù, _mở_, _الطق, --,
   {{0x212d124d,0x63a9000e,0x6d5db77d,0x394000c7}},	//   pjeh_, _huen, fisa, ykis_,
   {{0x6d5db77e,0x63a90657,0x6aa50024,0x200b01b4}},	//   gisa, _kuen, _aghf, æcis_,
   {{0x814c0779,0x5174004f,0x4174004f,0x6281289b}},	//   _בעאַ, _بالأ, _بالس, _hylo,
   {{0x7fb40a86,0x98a0003a,0x63a9b77f,0x6d5db780}},	//   _بلوچ, ljić_, _muen, érar,
   {{0x6d5db781,0x63a90421,0xaa431c89,0x00000000}},	//   bisa, _luen, перл, --,
   {{0xccc607b0,0x63a9053e,0x98a00254,0x420507df}},	//   _убий, _ouen, njić_, _शनैः_,
   {{0x8cbe00b4,0x3940b782,0x7d060086,0x67350e5e}},	// [da20] _व्यो, rkis_, meks, _bozj,
   {{0x3940b783,0xdb0e0086,0x27f2096d,0xaa4609a5}},	//   skis_, äkär, rtyn_, _геол,
   {{0xb8ee00c8,0x27f2b784,0x2f5a0070,0x39590183}},	//   _রা_, styn_, נדענ, _fmss_,
   {{0x63a900c8,0xdff90084,0x2fdfb785,0xa8b9002d}},	//   _buen, ्बाद_, krug_, _вырф_,
   {{0x63a900c8,0xdb04004a,0x63a117ad,0x6ba101fb}},	//   _cuen, _stiù, _biln, _üzgü,
   {{0x63a90291,0x6d5db786,0x7d06b787,0x27e0b788}},	//   _duen, zisa, heks, mrin_,
   {{0x6d5db789,0x63a10031,0x613560fd,0x26d8b78a}},	//   yisa, _diln, _pálp, _idro_,
   {{0x63a90083,0x3d183e72,0x463b00c2,0x7d062a73}},	//   _fuen, _बोले_, _געלע, jeks,
   {{0x7d06b78b,0xe8e00019,0x26cab78c,0x63a101e0}},	//   deks, _ngọt_, _kebo_, _filn,
   {{0x6d5da8ff,0x26ca025c,0x9df80370,0x63a10345}},	//   wisa, _jebo_, анот_, _giln,
   {{0x6d5db78d,0x877b0100,0xa3e40ca1,0x5286004f}},	//   tisa, ראיי, पूर_, _الاك,
   {{0x26ca016f,0x27e0b78e,0x26000006,0x63a1002d}},	//   _lebo_, krin_, _रहनी_, _ziln,
   {{0x40960082,0x79840035,0x703a16a4,0x69dab78f}},	//   _الشر, dliw, _حساس_, áten,
   {{0x26ca0311,0x6d5db790,0x27e0b791,0x3fc500b5}},	//   _nebo_, sisa, drin_, _بگٹی_,
   {{0x69da0537,0x6ce700d8,0x673526e1,0x27e0b792}},	//   šten, _ліпе, _rozj, erin_,
   {{0x8e830082,0x1958081b,0x7d06027d,0x26d8002a}},	//   _عليه, басы_, ceks, _adro_,
   {{0x47352a9a,0x588700c3,0x26ca38d1,0xe8940421}},	// [da30] онас, сыва, _bebo_, зать,
   {{0x6b4b02b1,0x2b5a2803,0x00000000,0x00000000}},	//   _büge, _gmpc_, --, --,
   {{0x63a9b43f,0x26cab793,0x65790d9a,0x27e0b794}},	//   _suen, _debo_, towh, arin_,
   {{0x63a14a84,0x63a905c9,0x27e001f4,0x25aa02c4}},	//   _siln, _puen, brin_, _dubl_,
   {{0x63a1b795,0x63a9b796,0x25ad9839,0x6579b797}},	//   _piln, _quen, _čelu_, rowh,
   {{0x41b5487d,0x70b300e7,0x443d00e9,0x2bdc0066}},	//   осит, ीर्ल, ryw_, _बिसा,
   {{0x63a1b798,0x7d06b799,0xb60800ee,0x63bc0116}},	//   _viln, yeks, _pišť, _črne,
   {{0x63a93ffa,0x628100b8,0x13a700d1,0x2fdf033b}},	//   _tuen, _vylo, _هنری_, trug_,
   {{0xe81c103f,0xbcfb024e,0x98a9016f,0x63a900ab}},	//   निया_, mnéh, kiaľ_, _uuen,
   {{0x2eee0345,0xbcfb024e,0x289c02b5,0x6281b79a}},	//   _ccff_, lnéh, ניזא, _tylo,
   {{0x2bdc2f78,0x7d06b79b,0xdced01ba,0x27e02001}},	//   _बिहा, teks, _diaľ, zrin_,
   {{0x78a2168a,0xbcfb024e,0x6d5d0248,0x2fdf044d}},	//   žovi, nnéh, érap, prug_,
   {{0x613c65c6,0x637f021d,0x00000000,0x00000000}},	//   _célu, bênt, --, --,
   {{0x7d06b79c,0x613c00b5,0x68ef00ee,0x27e0b79d}},	//   seks, _délu, _accd, vrin_,
   {{0xfaa34e35,0x7d06b79e,0x26ca01cb,0x999e00b8}},	//   даро, peks, _rebo_, átů_,
   {{0x27e0b79f,0xbcfb053d,0x26ca0183,0x201d0035}},	//   trin_, jnéh, _sebo_, _krwi_,
   {{0xbcfb290b,0x60cb006c,0x27e0b7a0,0x2d800118}},	// [da40] dnéh, _megm, urin_, _ikie_,
   {{0x27e0b7a1,0x2b5ab7a2,0x23e000be,0xbcfb000d}},	//   rrin_, _umpc_, _निबद, riée,
   {{0x98a66c93,0x3f85081b,0xb87b0079,0x248d0031}},	//   _мине, illu_, _scít, _azem_,
   {{0x27e006c4,0x92a60067,0xa3ce021a,0x00000000}},	//   prin_, zyłą, _शबद_, --,
   {{0x26ca022e,0x87b99753,0xe5a31053,0x613c00b5}},	//   _tebo_, _густ_, фици, _mélt,
   {{0x8c1b0122,0xb33c0024,0xb87b00d5,0x00000000}},	//   יוני, _biħa, _vcít, --,
   {{0xbcfb0187,0x2d80b7a3,0x273700fe,0x00000000}},	//   bnéh, _okie_, _dýně_, --,
   {{0xbcfb0187,0x200f01da,0x6ab71371,0xb03402c8}},	//   cnéh, _bsgi_, _अभ्र, зниш,
   {{0xf9935c8e,0x60cb0a21,0xff0603fe,0xaabf01c0}},	//   ורה_, _degm, оянн, ्रमक,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69da01c0,0x826600f8,0x171b0070,0x321800ac}},	//   átel, _بهان, בויע, _éry_,
   {{0x6eba2218,0x2d9200d7,0x8fa6075c,0x613ca5db}},	//   _श्रु, _chye_, _даде, _célt,
   {{0xa6d500c8,0x4f65006c,0x98a9016f,0x69da2b2c}},	//   স্টট, _کانف, tiaľ_, štel,
   {{0xada501ba,0x2bdc051d,0xbcfb0079,0x60cb0051}},	//   _skúš, _बिरा, inéi, _zegm,
   {{0x2d520009,0x0dca0183,0x68fd009e,0xbcfb0098}},	//   ršer_, _тули_, _pbsd, hnéi,
   {{0xed5800ed,0x00000000,0x00000000,0x00000000}},	//   _мој_, --, --, --,
   {{0xbcfb290b,0x2ca91b68,0x27140033,0xfc3f0310}},	// [da50] vnéh, _igad_, ঠানো_, rcís_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcfb024e,0xab980037,0x248d00fd,0x00000000}},	//   tnéh, _بخير_, _szem_, --,
   {{0xaae704e8,0x6d4f00e2,0x69d500fd,0xb33c0024}},	//   _اسکو, nhca, msze, _riħa,
   {{0x69d53a5f,0xbcfbb7a4,0x60cb03bc,0x58840409}},	//   lsze, rnéh, _regm, _жыра,
   {{0x27e9b7a5,0xbcfb024e,0x24841051,0x883a00a5}},	//   muan_, snéh, _dymm_, _התשו,
   {{0x27e9b7a6,0x69d5b7a7,0x44290043,0xe57321a0}},	//   luan_, nsze, ţa_, _قطر_,
   {{0x68edb7a8,0x2bdc0e04,0x26000461,0x60d90069}},	//   ngad, _बिला, _रहती_, _qdwm,
   {{0x6d4f0608,0x27e9b7a9,0x68ed002a,0xb4e70325}},	//   dhca, nuan_, igad, पली_,
   {{0x2ca9b7aa,0x21260009,0x69d5006c,0xe81c09b4}},	//   _agad_, _enoh_, ksze, निता_,
   {{0x27e906b3,0x656bb7ab,0x69d50035,0x290900c3}},	//   huan_, ongh, jsze, keaa_,
   {{0x27e9b7ac,0x69d53a5f,0x656bb7ad,0x3114093e}},	//   kuan_, dsze, nngh, _офіс,
   {{0x27e9253e,0x81ad0083,0x68ed1058,0x31b1006c}},	//   juan_, _কবি_, dgad, _ház_,
   {{0x27e98e4e,0xa026008a,0x2d994529,0x63bb002f}},	//   duan_, stöð, amse_, _mtun,
   {{0x6b50022a,0x69d5006c,0x29d7003c,0x2d92b7ae}},	//   _lägg, gsze, għa_, _thye_,
   {{0x68edb7af,0x63bbb7b0,0xc2120070,0x6e3c0e0e}},	//   ggad, _otun, עהן_, ärbe,
   {{0x200d57cb,0xb90407b5,0x63bb1815,0x00000000}},	// [da60] nwei_, _नय_, _ntun, --,
   {{0x7d16b7b1,0x6d460086,0x68ed094e,0x69d5b7b2}},	//   _hays, lkka, agad, bsze,
   {{0x7d16b7b3,0x63bbb7b4,0x00000000,0x00000000}},	//   _kays, _atun, --, --,
   {{0x27e90f20,0x92e80083,0x6d46b7b5,0x07a6b7b6}},	//   buan_, _বসে_, nkka, _намн,
   {{0x7d16010d,0x293702b5,0x27e90034,0x9f440248}},	//   _mays, _זאכן_, cuan_, sumé_,
   {{0x656b0082,0x7d160159,0xd6e30083,0xbcfb0098}},	//   angh, _lays, ন্বয, rnéi,
   {{0xbcfb0082,0xf1070b4a,0xf5390168,0x63bbb7b7}},	//   snéi, वजूद_, _foť_, _etun,
   {{0xb6a30f28,0x7d160107,0x9c8700b8,0x00000000}},	//   _числ, _nays, _jičí, --,
   {{0x6f0802ff,0x69d52130,0x00000000,0x00000000}},	//   tedc, zsze, --, --,
   {{0x69d5b7b8,0x68edb7b9,0xa8570122,0x6562a17b}},	//   ysze, zgad, פייה_, lioh,
   {{0x27e927e2,0x7d16b7ba,0x69dab7bb,0x31b100fd}},	//   zuan_, _bays, štej, _gáz_,
   {{0xd843024e,0x27e9b7bc,0x14cc37e8,0x6f0800d7}},	//   ničí_, yuan_, ारिण, sedc,
   {{0x69d5004e,0xa3cf0167,0x27e9b7bd,0x613c00b5}},	//   wsze, वीप_, xuan_, _félr,
   {{0x69d576a8,0x6d460086,0x8fa351be,0x6562081b}},	//   tsze, akka, _заче, hioh,
   {{0x14cc00b4,0x68ed0228,0x7d166a0a,0x2bd90a44}},	//   ाराण, tgad, _fays, _भटका,
   {{0x27e9b7be,0x69d5b7bf,0x19580c28,0x6d460110}},	//   tuan_, rsze, пасы_, ckka,
   {{0x6d4d5efb,0x69d515ee,0x36d5111d,0x6d5f035f}},	// [da70] _ilaa, ssze, дозр, _imqa,
   {{0x68edb7c0,0x76ab1c1b,0x69d5392f,0xfbd20122}},	//   sgad, став_, psze, _שתי_,
   {{0xfbaf00c8,0x63bb09bd,0x6d4d388d,0xa3cf0907}},	//   _কবিত, _stun, _klaa, वीन_,
   {{0xb4e7b7c1,0x656b0395,0x5fdd2821,0x31b11534}},	//   पले_, ungh, _मिलल, _ráz_,
   {{0x27e9b7c2,0xe1f100d1,0xb88600a0,0x39b80107}},	//   quan_, چسب_, _príť, _včse_,
   {{0xd0400095,0x6b50013c,0x6d4d023c,0x07a400d8}},	//   qamə, _vägg, _llaa, _паўн,
   {{0xe2967c71,0x919503e6,0x00000000,0x00000000}},	//   маш_, мјиш, --, --,
   {{0xa0a50c8a,0x63bb001c,0x34951023,0x00000000}},	//   майд, _ttun, _жабр, --,
   {{0x63bbb7c3,0xaabf0e61,0x4abf03de,0x7d1651b0}},	//   _utun, ्राक, ्राव, _rays,
   {{0xf8aa0f9f,0x6d4d4733,0x7d168cf3,0x200db7c4}},	//   _कल्प, _alaa, _says, rwei_,
   {{0x752933dc,0x6d4db7c5,0x7d169b09,0xfce6182f}},	//   _knez, _blaa, _pays, моно,
   {{0x7d161505,0x69da1f20,0x6d460328,0x6b5000be}},	//   _qays, štek, ukka, _mäge,
   {{0x6b50022a,0x6d460086,0x6d4d00d7,0x6b4b00ab}},	//   _läge, rkka, _dlaa, _süga,
   {{0x06e30083,0x753bb7c6,0xa3cf0266,0x2f1800c3}},	//   ন্তি, _louz, वीय_, _ночь_,
   {{0xbcfb00de,0x6b50393f,0x316d00af,0x7529b7c7}},	//   mién, _näge, onez_, _onez,
   {{0x316d02e1,0x6d4d3958,0xbcfbb7c8,0x753b0355}},	//   nnez_, _glaa, lién, _nouz,
   {{0xbf8a01a5,0x66090124,0x316db7c9,0x00000000}},	// [da80] _đoạn_, _ćeka, inez_, --,
   {{0x75290371,0xbcfb00de,0xdb0401f7,0x6442002f}},	//   _anez, nién, _etiò, vyoi,
   {{0x753bb7ca,0x6562b7cb,0xdb0401ef,0xd5b000b5}},	//   _bouz, tioh, _guiá, اہر_,
   {{0x448a3804,0x273f002d,0x75290160,0x753b00f6}},	//   обен_, _sînt_, _cnez, _couz,
   {{0x753bb7cc,0x32050430,0x3d00022e,0xa2a0049c}},	//   _douz, _aply_, ष्ये_, गेन्,
   {{0x629c0187,0x316d01d7,0x2bd000e7,0x75290cb9}},	//   _úrok, enez_, तीया, _enez,
   {{0xbcfb0453,0x24f6b7cd,0xe1ef1301,0x273f0160}},	//   dién, _очар, لسي_, _vînt_,
   {{0xd1300082,0x673c254b,0x316db7ce,0x61f80d35}},	//   امة_, _horj, gnez_, rtvl,
   {{0x673c0c89,0x61ea0395,0xd00703e6,0xc48300af}},	//   _korj, sufl, дење_, _алтк,
   {{0x6d4d0d26,0xbcfb80be,0x753b6a0d,0x13039786}},	//   _slaa, gién, _zouz, _изум,
   {{0x6d4d1c45,0x673c02c6,0x00000000,0x00000000}},	//   _plaa, _morj, --, --,
   {{0xdfcf03fc,0x50661172,0x2bd008b0,0x00000000}},	//   _چين_, _отла, तीभा, --,
   {{0x63a8b7cf,0x6d4d0120,0xbcfb05c9,0xe5710070}},	//   _kidn, _vlaa, bién, אַם_,
   {{0xbcfb0831,0x29020069,0x673c00c3,0xa2c10e61}},	//   cién, _abka_, _norj, रुप्,
   {{0x2bd00d34,0x6560009f,0x00000000,0x00000000}},	//   तीबा, _ommh, --, --,
   {{0x6d4d0858,0x63a801bf,0xac9500d8,0xd90f0416}},	//   _ulaa, _lidn, _пайш, جیح_,
   {{0x6b5006d7,0x753b4b2d,0x62881217,0x6f185a51}},	// [da90] _säge, _rouz, _lydo, _kavc,
   {{0x753b03e6,0x3d000099,0x673c021d,0xadf2060a}},	//   _souz, ष्ठे_, _corj, _अमान_,
   {{0x753b000c,0x58d57b75,0x673c117c,0x2d6802c4}},	//   _pouz, _понт, _dorj, rđev_,
   {{0xa8350202,0xdced0528,0x6b50258a,0x395200d7}},	//   _земљ, _ojač, _väge, chys_,
   {{0x291900af,0xd40b0172,0x63a80124,0xfd5800a5}},	//   _iasa_, تتام_, _bidn, ושאי_,
   {{0xb3e0009a,0x29190657,0x673cb7d0,0x3949b7d1}},	//   _निरख, _hasa_, _gorj, lkas_,
   {{0x2919b7d2,0x20060043,0x23690a78,0x4b380122}},	//   _kasa_, _apoi_, đaj_, ורגל_,
   {{0x3949b7d3,0x29190464,0x69da0279,0x63ad01dd}},	//   nkas_, _jasa_, átei, íans,
   {{0x2919b7d4,0x2d8b5e33,0xbcfb00de,0x316d00a2}},	//   _masa_, dlce_, tién, rnez_,
   {{0x2919b7d5,0x8c150033,0x26d10116,0xa3cf00b4}},	//   _lasa_, ামান_, _jezo_, वीण_,
   {{0x394900ab,0x8d6600aa,0xbcfb0453,0x62885a3f}},	//   kkas_, евне, rién, _gydo,
   {{0x2d8400f7,0x63a805e2,0x6e3c038e,0xa3e42923}},	//   ôme_, _zidn, ärba, पंच_,
   {{0x66f00567,0x39491b1c,0x6f180024,0xbc1903d0}},	//   _चालक_, dkas_, _favc, мірі_,
   {{0x29199b4c,0x2600007c,0x2d8b1bd8,0x3949a0d9}},	//   _aasa_, _रहली_, alce_, ekas_,
   {{0x291901ca,0xa3cf0099,0xdb0f0037,0x3952b7d6}},	//   _basa_, वीत_, ádái, thys_,
   {{0x6135006c,0xa3c10066,0x3949a7f7,0x6e230027}},	//   _pály, ूठा_, gkas_, _irnb,
   {{0xc7260036,0x25bf0c0a,0x7d040232,0x63bc2518}},	// [daa0] ндай, _čula_, _ibis, _črno,
   {{0x7c240371,0x2d82314a,0x394900c3,0x06e30033}},	//   _irir, loke_, akas_, ন্সি,
   {{0x291902c2,0x394956a0,0x63a824ec,0xd63900d8}},	//   _fasa_, bkas_, _ridn, мяці_,
   {{0x3949b7d7,0x3a25054e,0xbcfb000d,0x96954bfe}},	//   ckas_, ælpe_, lnér, труш,
   {{0x6615006c,0x7d04b7d8,0x9cd700a5,0x673cb7d9}},	//   _eszk, _mbis, תונה_, _torj,
   {{0x161d00b4,0x29193b89,0x7c2b008d,0x2d824583}},	//   फिशर_, _zasa_, _ágre, hoke_,
   {{0x7d04b7da,0x63a8242c,0x3fac0083,0x2d826e77}},	//   _obis, _vidn, _গবেষ, koke_,
   {{0x7afb01cc,0x2900b7db,0x63a8b7dc,0x6f18b7dd}},	//   đuti, nfia_, _widn, _savc,
   {{0x63a8022a,0x2d820691,0x6e23b7de,0x62880067}},	//   _tidn, doke_, _arnb, _wydo,
   {{0x7d04a4c6,0x4613006c,0x44244135,0x3949010b}},	//   _abis, _جوہر, _irm_, zkas_,
   {{0x7c2401d5,0x67020b35,0x7bcd023c,0x79860103}},	//   _arir, र्यक_, _swau, _okkw,
   {{0x44243dca,0x2d8201b7,0x7c240055,0x00000000}},	//   _krm_, goke_, _brir, --,
   {{0x2919072e,0x394956a0,0x201f00e2,0x5c04010b}},	//   _rasa_, vkas_, cvui_, ляра,
   {{0x291919c6,0x670207df,0x7d040273,0x7986035f}},	//   _sasa_, र्मक_, _ebis, _akkw,
   {{0x29194d15,0xb9e402ce,0x2d82954b,0x26d102d0}},	//   _pasa_, літи, boke_, _rezo_,
   {{0x4424009c,0x69da0248,0x2d825868,0x394900d8}},	//   _orm_, âtea, coke_, ukas_,
   {{0xb8d927bd,0x23cf4532,0x4424018e,0xf6e702fb}},	// [dab0] _चल_, _सौंद, _nrm_, ецен,
   {{0x3949b7df,0x7d1d63a2,0xb87b0042,0x2aee0035}},	//   skas_, ldss, _adíc, _जाएँ_,
   {{0xb8f70033,0x442402d8,0xdb040132,0x2d420183}},	//   _সা_, _arm_, _suiç, _góes_,
   {{0x7d1db7e0,0x59b616d3,0xbc6800b5,0x29190345}},	//   ndss, _आंतर, _آمین_, _uasa_,
   {{0x53e00f0d,0x798d0858,0xe3b803d0,0xdb04021d}},	//   _निःश, mlaw, ебі_, _quiç,
   {{0x04420370,0xb87b00a0,0x27e9b7e1,0x2d6800f4}},	//   решн, _edíc, mran_, nđer_,
   {{0x69da02c6,0x56942360,0x66150035,0x6b500454}},	//   štev, _барт, _uszk, _jäga,
   {{0x798d010d,0x3f8c05af,0x7d1d08c8,0x6595004b}},	//   nlaw, eldu_, jdss, _рабу,
   {{0x2d82b7e2,0x44241635,0x27e9b7e3,0x798d0159}},	//   voke_, _grm_, nran_, ilaw,
   {{0x798d0464,0x4f221667,0x257c0355,0xf48400af}},	//   hlaw, адьб, díly_, _сусн,
   {{0x27e9b7e4,0x2d82b7e5,0x7c240024,0x64590a8d}},	//   hran_, toke_, _srir, lzwi,
   {{0x7c240bc6,0x27e9b7e6,0x25e90324,0x7d040024}},	//   _prir, kran_, _चटनी_, _qbis,
   {{0x2d82b7e7,0xef0e5454,0x798d86a7,0x2d4201ef}},	//   roke_, _км_, dlaw, _bóer_,
   {{0x27e9b7e8,0x00560122,0x2d82b7e9,0xdee54168}},	//   dran_, _בשנת_, soke_, _роки,
   {{0x27e9b7ea,0x798d001e,0x2d820027,0xbcfb0faa}},	//   eran_, flaw, poke_, rnér,
   {{0x7d04b7eb,0xa2c11e18,0x0c260c8d,0x27e9509d}},	//   _ubis, रुत्, _амин, fran_,
   {{0x18673e87,0x27e995cd,0x629c0076,0x68432b34}},	// [dac0] вати_, gran_, _úrov, анта,
   {{0x998d0a78,0x00000000,0x00000000,0x00000000}},	//   ćeš_, --, --, --,
   {{0xd5b900d4,0x27e90014,0x2a36010b,0x81bc0228}},	//   есі_, aran_, _рэпр, _arēn,
   {{0x27e90129,0x44240897,0x69dc039b,0xb7bb0132}},	//   bran_, _prm_, msre, _grão,
   {{0x3f8c0093,0x69dc626d,0x27e9242d,0x3f8708b7}},	//   yldu_, lsre, cran_, _oknu_,
   {{0xf8bf0118,0x4424004b,0x00000000,0x00000000}},	//   _anéh_, _vrm_, --, --,
   {{0xd24f17bd,0x69dc721c,0xbebc0029,0xa2c1035d}},	//   ينه_, nsre, ldīg, रुध्,
   {{0xdce600d8,0x69de0207,0x3f8700ec,0x00000000}},	//   mokė, _mvpe, _aknu_, --,
   {{0x64a30842,0x670200c4,0xdef8003c,0x4fd3010b}},	//   _вата, र्थक_, liċi_, ажыт,
   {{0xa2c10d53,0x69dc1e74,0xbebc00ea,0x00000000}},	//   रुद्, ksre, idīg, --,
   {{0x13d700c8,0x69dc0506,0x2bd00099,0x00000000}},	//   _সময়, jsre, तीसा, --,
   {{0x69dc038d,0x27e9b7ec,0x67020f9c,0x6abe03d0}},	//   dsre, yran_, र्तक_, _afpf,
   {{0xa3b80084,0x20180029,0x6b50017b,0x7d1d1b2f}},	//   _घूम_, āris_, _säga, rdss,
   {{0x2bb50035,0x69dc41fb,0x6abf0630,0x00000000}},	//   ंदबा, fsre, ्रेर, --,
   {{0x27e9b7ed,0x25bf011c,0x00000000,0x00000000}},	//   wran_, _čulo_, --, --,
   {{0x2e5901c8,0x2bdcb7ee,0x6b505f3c,0xdef80484}},	//   _яшчэ_, _बिचा, _väga, diċi_,
   {{0x9b45064e,0x798d005d,0x27e9b7ef,0x5887325e}},	// [dad0] _منظو, rlaw, uran_, тыва,
   {{0x27e9b7f0,0x5b1503ad,0x69dcb49d,0xd6db03e6}},	//   rran_, _смот, bsre, ќта_,
   {{0x2367003d,0x6b820079,0xc6a700c3,0x31b800b5}},	//   vinj_, _íoga, траи, _néz_,
   {{0x2bd0009a,0x27e9b7f1,0x69c7b7f2,0xfd1f0036}},	//   तीवा, pran_, mpje, ndì_,
   {{0xdfc60ad9,0x69da068b,0x7bdd244c,0xe8e00023}},	//   _دي_, štet, nssu, _ngột_,
   {{0xe299b7f3,0x7bdd5d91,0x64593a63,0x2b41023a}},	//   нал_, issu, rzwi, _johc_,
   {{0x45d400c3,0x23670031,0x00000000,0x00000000}},	//   _восс, rinj_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e00311,0xe4750274,0x60c9b7f4,0x00000000}},	//   _थिए_, _слањ, rbem, --,
   {{0x25ad0051,0x69dcb7f5,0xa2ca111a,0x2d890cdf}},	//   _hiel_, ysre, _स्प्, _akae_,
   {{0x25ad119b,0xf8d31b8f,0x7bdf0d32,0xa3cf3f52}},	//   _kiel_, तराय, _avqu, वीर_,
   {{0x69dc0c61,0xc692011d,0xab5b033b,0x6d8802d7}},	//   vsre, מאי_, spül, eñar,
   {{0x25adb7f6,0xafe5061c,0x7bdd864e,0xd0090012}},	//   _miel_, _солл, gssu, _челе_,
   {{0x9b960088,0xaaa5142a,0x00000000,0x00000000}},	//   الست, _गृहक, --, --,
   {{0x3f85ad8f,0xdb0d0132,0xc5fb0033,0xdea10105}},	//   molu_, _guaí, ীয়তা_, _دیدی,
   {{0xfe7000f8,0x69dcb7f7,0x25adb130,0x06cd0033}},	//   _بده_, rsre, _niel_, _লাগি,
   {{0x248d0189,0x271d0033,0x69dcb7f8,0x23b9021e}},	// [dae0] _nyem_, নানো_, ssre, _nèj_,
   {{0xdef8003c,0xb8ebb7c1,0x680700ea,0x69dc057f}},	//   tiċi_, _र्_, dījā, psre,
   {{0x8afb1804,0x248d01cb,0xceb2011d,0x00000000}},	//   _אהיי, _ayem_, ציא_, --,
   {{0x25adb7f9,0xa2c10ca1,0xd5af00f8,0x23b90107}},	//   _ciel_, रुस्, سفه_, _bèj_,
   {{0x3f85b7fa,0x938a4717,0x25ad6844,0x4346b7fb}},	//   kolu_, нска_, _diel_, ледв,
   {{0x2bb70299,0x68f62628,0x00000000,0x00000000}},	//   _इंसा, lgyd, --, --,
   {{0x3f852c7c,0x39423cf1,0x26da0468,0x248d0118}},	//   dolu_, _koks_, mapo_, _eyem_,
   {{0x64a6b7fc,0x25ad0d35,0x7bc4008c,0x2912b7fd}},	//   _баба, _giel_, _otiu, neya_,
   {{0x2d68006c,0x9f54015a,0x44221652,0x00000000}},	//   tően_, ивич, _ék_, --,
   {{0x25ad7121,0xade50722,0x381700a5,0x3f85007a}},	//   _ziel_, _किशन_, נקים_, golu_,
   {{0x1d3500ef,0x291204fb,0x69da000d,0x81bc0228}},	//   ання, keya_, âtel, _krēm,
   {{0xc27b02b5,0xa3e800a1,0x26dab7fe,0x00000000}},	//   _ארבי, _मटा_, hapo_, --,
   {{0x7bdd0248,0xfd1f01d3,0x248d01e8,0x26da0054}},	//   ussu, rdì_, _xyem_, kapo_,
   {{0x909700d4,0x96d800b4,0x39420b3e,0xdb1600e2}},	//   _світ_, यरफॉ, _aoks_, _huyê,
   {{0xf9930164,0x26da0054,0xa1430029,0x00000000}},	//   مبر_, dapo_, _šķir, --,
   {{0x69c700da,0x29123a34,0x7bc40211,0x2d89023c}},	//   rpje, geya_, _ftiu, _ukae_,
   {{0x69c7b7ff,0x69da1e15,0xbebc00ea,0x7d7400f8}},	// [daf0] spje, áter, mdīb, _داوط,
   {{0xbebc0080,0x25ad0173,0x7d1f013b,0x00000000}},	//   ldīb, _siel_, _haqs, --,
   {{0xcf9302b5,0x25ad0033,0x3942908d,0x7ae105f5}},	//   צטע_, _piel_, _foks_, óltu,
   {{0x6d4f271e,0x69c50a1d,0x7d1f035f,0x68070228}},	//   nkca, _ithe, _jaqs, tījā,
   {{0x7d1f035f,0x25ad02bf,0xa3cf0299,0x26da0657}},	//   _maqs, _viel_, वीं_, bapo_,
   {{0xe3b01301,0x69c500da,0x26dab800,0x25ad0b0d}},	//   سره_, _kthe, capo_, _wiel_,
   {{0x25adb801,0xa2c100e7,0x00000000,0x00000000}},	//   _tiel_, रुष्, --, --,
   {{0x7d1fb802,0x3fe53668,0x60091f7e,0x69c50345}},	//   _naqs, ажив, вним_, _mthe,
   {{0x3f85b803,0x94770ef2,0xdb160019,0x67020808}},	//   tolu_, _صدرا, _duyê, र्वक_,
   {{0x69c501f3,0x6f650a80,0x20d30019,0x613c00b5}},	//   _othe, рвоз, ải_, _mély,
   {{0x644bb804,0xed5a00c7,0x7bc4239d,0x63a3010d}},	//   lygi, вон_, _stiu, mmnn,
   {{0x3f85b805,0xe1f02087,0x656bb806,0xb87b0079}},	//   solu_, _رسم_, nigh, _ndío,
   {{0x69c5b807,0x60db0054,0x3f85b808,0x7d1f003c}},	//   _athe, maum, polu_, _daqs,
   {{0x60dbb809,0x656bb80a,0xbea5379d,0xb3d70083}},	//   laum, high, _калк, _সমাজ,
   {{0xfaa6b80b,0x6d9d0037,0x656b043d,0x644b153f}},	//   раво, féad, kigh, hygi,
   {{0x1c462aac,0x60db000e,0xdb1601a5,0x26da46c2}},	//   _вним, naum, _xuyê, wapo_,
   {{0x656bb80c,0x2912b80d,0x26da2113,0x7f4300a8}},	// [db00] digh, reya_, tapo_, _konq,
   {{0x6d44007c,0x7f43b80e,0x66e6b80f,0x60dbb810}},	//   _hoia, _jonq, рожа, haum,
   {{0xb8fc0083,0x394200d8,0x670208b6,0x26da011e}},	//   _ঠা_, _toks_, र्षक_, rapo_,
   {{0x14260a80,0x6d44b811,0x26daa9f8,0x6d9d0098}},	//   идем, _joia, sapo_, réag,
   {{0x4ada5a77,0x6b4b00ab,0x6d4401f7,0x61e10c6f}},	//   _बजाव, _sügi, _moia, _avll,
   {{0x27e0b812,0xaab600b4,0x6d44b813,0x7f430024}},	//   msin_, ंशिक, _loia, _nonq,
   {{0x6d560332,0x27e0b814,0x656b08dd,0x00000000}},	//   _olya, lsin_, bigh, --,
   {{0xdb160019,0x26d8b815,0xf1260eb1,0xdb057b79}},	//   _quyê, _hero_, рько, _mihá,
   {{0x27e0b816,0x26d8002f,0xa2ca0066,0x00000000}},	//   nsin_, _kero_, _स्थ्, --,
   {{0x7f43af72,0x27e09140,0x26d800f8,0x6d56b817}},	//   _conq, isin_, _jero_, _alya,
   {{0xdb1601a5,0x6d561f8b,0xb87b0183,0x27e0aeac}},	//   _tuyê, _blya, _adíl, hsin_,
   {{0xa2ca0ec5,0x7522b818,0x27e0b819,0x4426027a}},	//   _स्त्, ndoz, ksin_, ovo_,
   {{0x69c5b81a,0xae4300bf,0x6b5001ae,0x2d6f0355}},	//   _sthe, مپیو, _tägl, třeb_,
   {{0x26d8b81b,0x656bb81c,0x6d56b81d,0x4426b81e}},	//   _nero_, zigh, _elya, ivo_,
   {{0x99676b47,0x7d1f003c,0x613c0042,0x6d56008c}},	//   атал, _taqs, _bélx, _flya,
   {{0x44260a78,0x6d44b81f,0x5d84b820,0x7520034d}},	//   kvo_, _goia, _ولول, _namz,
   {{0x26d8b821,0xd6db0370,0x656bb822,0x4426063b}},	// [db10] _bero_, вте_, vigh, jvo_,
   {{0x26d80b4c,0x629a01d7,0x69c50159,0x00000000}},	//   _cero_, _ozto, _tthe, --,
   {{0x656b542d,0x4426985d,0x60db0248,0x644b001e}},	//   tigh, evo_, yaum, wygi,
   {{0x6d440042,0x26d802e2,0x644b055c,0x00000000}},	//   _xoia, _eero_, tygi, --,
   {{0x4429b823,0x656b024b,0x2fc60221,0x26d80168}},	//   ía_, righ, _ntog_, _fero_,
   {{0x26d8820f,0x8505006c,0xa3e8007c,0x644bb824}},	//   _gero_, _گورن, _मटर_, rygi,
   {{0x21690145,0x25b831dc,0x4426b825,0x7f430138}},	//   лики_, _gurl_, avo_, _ronq,
   {{0xc6920779,0xf8bf0d2e,0x644b00d7,0xb33c0024}},	//   _זאל_, _inés_, pygi, _biħs,
   {{0x60db09bd,0x26d8b826,0x2fc6009e,0x656966e5}},	//   raum, _yero_, _ctog_, _imeh,
   {{0x26c12dea,0xf20701c8,0x752010b9,0x6dba0024}},	//   ncho_, _вядо, _zamz, _iċaj,
   {{0x2295b827,0xb87b01c0,0x60db002f,0x6d44924f}},	//   _الاس, _sdíl, paum, _poia,
   {{0x27e00086,0x8d561294,0xf99f00e2,0x82340079}},	//   ysin_, сточ, _nhè_, _بركا,
   {{0x1c1b11b5,0x7f43b828,0x6e2a0051,0x6d44b829}},	//   _पैदल_, _tonq, _erfb, _voia,
   {{0x316d0db4,0xaa469b31,0x00000000,0x00000000}},	//   liez_, бегл, --, --,
   {{0x26d8070b,0x44261b76,0x6569942e,0xf99f027a}},	//   _rero_, zvo_, _omeh, _bhè_,
   {{0xf99fb82a,0x27e0b82b,0x26d8b82c,0x316db82d}},	//   _chè_, tsin_, _sero_, niez_,
   {{0x26d8b82e,0x98a331fb,0xf8bf01f7,0xd943b82f}},	// [db20] _pero_, зите, _anés_, чети,
   {{0x27e0b830,0x316db831,0x6569002f,0x44268a9a}},	//   rsin_, hiez_, _ameh, vvo_,
   {{0x27e0b832,0x26d8b833,0xdd8f0088,0x14c800d1}},	//   ssin_, _vero_, _زوی_, لهای_,
   {{0x27e0b834,0x95eb006c,0x213f012f,0xa2ca007e}},	//   psin_, ابلہ_, jjuh_, सुन्,
   {{0x752200b5,0x26d80a13,0x27e0009f,0x316d0160}},	//   rdoz, _tero_, qsin_, diez_,
   {{0x8c1b00a5,0x25b8009e,0x00000000,0x00000000}},	//   טוני, _turl_, --, --,
   {{0x316d0248,0x92581285,0x9f5f00f7,0x6d9d0037}},	//   fiez_, райт_, ctué_, néac,
   {{0x657b01d2,0xe1ef0098,0x3952004b,0x316db835}},	//   _gjuh, رسى_, nkys_, giez_,
   {{0x25bf0254,0x60dd0093,0x3860028b,0x60d9007a}},	//   _čuli_, ðsma, nzir_, _dewm,
   {{0x25a6b836,0xb35604e8,0xdbd41111,0xf1d9022e}},	//   lmol_, _دیتا_, _núñe, _यौवन,
   {{0xab5b61cb,0xbcfb1534,0x00000000,0x00000000}},	//   nqüe, mnéz, --, --,
   {{0x069702b8,0x316db837,0x25a60633,0x321e148a}},	//   מדים_, ciez_, nmol_, _isty_,
   {{0x26c1b838,0x2fc60159,0x06e30033,0xed5800d8}},	//   ycho_, _utog_, ন্টি, соў_,
   {{0x3860028b,0x139b0070,0x0eba0104,0xf99f0107}},	//   dzir_, ָבלע, _суды_, _shè_,
   {{0x6d9d0248,0x60cd0139,0x00000000,0x00000000}},	//   réab, _înmâ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c10260,0x7d0db839,0x657b02a7,0x2d8bb83a}},	// [db30] tcho_, _ibas, _rjuh, moce_,
   {{0x2d8b02fb,0x7c2d9ca8,0x65695f52,0xa09b016b}},	//   loce_, _irar, _smeh, רימט,
   {{0x26c1b83b,0xf99fb83c,0x0c78042c,0xdce60228}},	//   rcho_, _thè_, _نصیب_, likā,
   {{0xbcfb1010,0x2d8b3fb2,0x26c11d22,0x7d0d0024}},	//   ciét, noce_, scho_, _jbas,
   {{0x7d0db83d,0x321e012f,0xdce600ea,0x316da9fd}},	//   _mbas, _asty_, nikā, viez_,
   {{0xbcfb006c,0x23291d29,0x00000000,0x00000000}},	//   gnéz, роки_, --, --,
   {{0x7d0db83e,0x25a6053e,0xdce6013a,0xe2995cbe}},	//   _obas, bmol_, hikā, шак_,
   {{0x7c2db83f,0x4fe9019e,0x656908c7,0xbfc510bb}},	//   _orar, амин_, _umeh, обик,
   {{0x6d5d01da,0x316db840,0x7c2d0159,0xdb0d0132}},	//   dhsa, riez_, _nrar, _guaç,
   {{0x7d0da364,0x8e09014d,0x442d00f1,0x316d98ec}},	//   _abas, анов_, _ire_, siez_,
   {{0x6e4509c0,0x7c2db841,0xae190035,0x442d00a0}},	//   ценз, _arar, _फैशन_, _hre_,
   {{0xdb0d00fb,0x63bb5ce7,0x4ca80083,0x6d5d0037}},	//   _stað, _kuun, _ক্ষু, ghsa,
   {{0xbcfb0391,0x63bb007c,0x1b230083,0xdee52c51}},	//   viét, _juun, মানে_, _доли,
   {{0x7d0d0006,0x63bbae9f,0x78130324,0x7c2d030d}},	//   _ebas, _muun, डबैक_, _drar,
   {{0x6d5d02a8,0xed5ab842,0x7c2db843,0x25a6099e}},	//   bhsa, _вой_, _erar, ymol_,
   {{0x442db844,0xae780131,0x2d8bb845,0x7c2db846}},	//   _ore_, _усіх_, coce_, _frar,
   {{0x442d59dc,0xbcfb0248,0xfe41006c,0x63bb030d}},	// [db40] _nre_, riét, _رکھی, _nuun,
   {{0x96960370,0xbcfb02d7,0x00000000,0x00000000}},	//   ореш, biés, --, --,
   {{0x442d35d9,0xe61a551f,0xbcfb28f6,0xaad007df}},	//   _are_, рде_, miér, _त्यक,
   {{0x63bb179a,0x442db847,0xbcfb0af7,0xa50a69a3}},	//   _buun, _bre_, liér, реда_,
   {{0x442db848,0x2480b849,0x9f4d0453,0x63bc023a}},	//   _cre_, çim_, nteó_, _črns,
   {{0x442db84a,0x63bb399d,0x7996b84b,0xe5ca0098}},	//   _dre_, _duun, llyw, _نظره_,
   {{0x442da7a1,0x66031a1c,0xab5b00a8,0x98a2010b}},	//   _ere_, _опра, mpüt, _kokį_,
   {{0x442db84c,0x7996560b,0xf8b800be,0x63bb030d}},	//   _fre_, nlyw, _अलोप, _fuun,
   {{0xb4e6017f,0x442d108a,0x2d8bb84d,0xb0a40035}},	//   पणी_, _gre_, voce_, खेंग,
   {{0x63a1009e,0x7c2d01ed,0x00000000,0x00000000}},	//   _ghln, _rrar, --, --,
   {{0xb4ab00fb,0x6d5d009e,0x7d0d0088,0x20043247}},	//   _íþró, thsa, _pbas, stmi_,
   {{0x6ed600a1,0xdce60228,0x00000000,0x00000000}},	//   _मजकु, tikā, --, --,
   {{0x2d8bb84e,0xa2c1162b,0x98b300ea,0x9f5f0176}},	//   roce_, रुक्, ādīt_, ctuï_,
   {{0x7c2d01f4,0xdce600ea,0x2d8b0355,0x705300d1}},	//   _vrar, rikā, soce_, _تنها,
   {{0x2bb70084,0xf96b0ffd,0x80dd0033,0x3f8cb84f}},	//   _इंका, арай_, _যাত্, modu_,
   {{0x7c2d2aff,0x4cd50033,0x3f8c5e48,0x7d0da35c}},	//   _trar, _থাকু, lodu_, _ubas,
   {{0x7c2db850,0x1b100033,0xbcfb0453,0x00000000}},	// [db50] _urar, ায়ে_, biér, --,
   {{0x4e1e09f9,0x442d008c,0x63bb136b,0xbcfb02d7}},	//   _बनाई_, _rre_, _ruun, ciér,
   {{0x63bb066e,0x6725b851,0x442d008b,0x5ebc0033}},	//   _suun, rdhj, _sre_, _আজাই,
   {{0x442db852,0x3f8c1834,0x63bbb853,0x3959027a}},	//   _pre_, hodu_, _puun, _ulss_,
   {{0xbcfb0248,0xdb040b4c,0x3d00012f,0x3f8cb854}},	//   chée, _guió, ष्टे_, kodu_,
   {{0x442d0c1f,0xe7f00066,0x77ba00a5,0x63bb0103}},	//   _vre_, _चिता_, _למשח, _vuun,
   {{0x5694b138,0x63bb073a,0x94d50274,0xa4d51645}},	//   _жарт, _wuun, _новц, _нові,
   {{0x442d0533,0x9505006c,0x6b5000ab,0x63bb9b85}},	//   _tre_, _رہتے_, _vägi, _tuun,
   {{0x442db855,0x245800c3,0x00000000,0x00000000}},	//   _ure_, _дать_, --, --,
   {{0xf8b80967,0x3f8c012e,0x249f6fc9,0xa2ca0099}},	//   _अल्प, godu_, _izum_, सुद्,
   {{0x22770a86,0xc7b400a5,0x00000000,0x00000000}},	//   _بلاگ_, ובץ_, --, --,
   {{0x670b04cc,0x070b00fa,0x27f202ee,0x27e60009}},	//   स्तक_, स्तव_, yryn_, šoni_,
   {{0xbcfbb856,0x3f8cb857,0x2d6f0355,0x9f3501e0}},	//   tiér, bodu_, mřel_, _неді,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcfb0076,0xb87b0033,0xc33200a5,0x3a21021d}},	//   riér, _leíd, עול_, _cshp_,
   {{0xa967b858,0x186a0210,0x6d9db859,0x27f28a3b}},	//   писа_, баби_, léan, tryn_,
   {{0x69ce0602,0x46ea3821,0x27e6000d,0x1dd702b4}},	// [db60] spbe, йдан_, éon_, भीरत,
   {{0xf7725f8a,0xfaa62462,0xd7ef004f,0x3b01012f}},	//   راء_, _напо, اكل_, _gchq_,
   {{0x7abb00a5,0x14ca00c3,0x98a2010b,0x3abb00a5}},	//   _לציו, были_, _tokį_, _למינ,
   {{0xb4e600a1,0x6d9d24db,0xbcfb000d,0x480a00af}},	//   पणे_, héan, phée, _лемн_,
   {{0x29e8013b,0x999e00c7,0x32070067,0x00000000}},	//   lğa_, štų_, etny_, --,
   {{0x670308a9,0x59d30e61,0x6ab00033,0x00000000}},	//   _लायक_, धीकर, _জ্যো, --,
   {{0x3f8c0097,0xc7a3002d,0xb6cb00b5,0x07a300d8}},	//   vodu_, _чирк, _چاہے_, _чарн,
   {{0x3f8c0035,0xdb042c36,0xb0340200,0x2d92073a}},	//   wodu_, _muiñ, дниш, _nkye_,
   {{0xb4ca009a,0x3f8c25c3,0x1b230033,0x00000000}},	//   ोरी_, todu_, মাতে_, --,
   {{0x3eb8177c,0xe2920037,0x2d83020e,0x74130697}},	//   ørt_, _كذا_, čkem_, _سوما,
   {{0x29022381,0x00000000,0x00000000,0x00000000}},	//   _ocka_, --, --, --,
   {{0x6ecc143a,0xa3e00084,0x5bb537e8,0x4fc60368}},	//   _द्रु, _दबा_, ंद्व, _еска,
   {{0x2d800107,0x00000000,0x00000000,0x00000000}},	//   _djie_, --, --, --,
   {{0xade500b4,0x2d92001c,0x29020282,0x31a100d5}},	//   _किचन_, _ekye_, _acka_, róze_,
   {{0x6e932d64,0xdb0401ef,0x00000000,0x00000000}},	//   _пишу, _cuiñ, --, --,
   {{0x2d800298,0x69c80312,0x00000000,0x00000000}},	//   _gjie_, ídea, --, --,
   {{0x61e80176,0x81bc00ea,0x2126009e,0x57b5b85a}},	// [db70] _lvdl, _krēs, _maoh_, дбат,
   {{0x64d51bb5,0xb8f42cb0,0x2d9901a6,0x7bcdb85b}},	//   दर्श, _स्_, llse_, _itau,
   {{0xdb040453,0x2d9942bf,0x00000000,0x00000000}},	//   _guiñ, olse_, --, --,
   {{0x260e0066,0x7f940310,0x00000000,0x00000000}},	//   _ठहरी_, màqu, --, --,
   {{0xe45400d8,0xd7f8081b,0x5fb80354,0x2d99b85c}},	//   нкцы, _нур_, _उंगल, ilse_,
   {{0x97350919,0x883a00a5,0xe7870610,0xb87b0176}},	//   _تکرا, _ותשו, _хумо, _veíd,
   {{0x6fd50299,0x225401ba,0xd5675086,0x00000000}},	//   _मौजू, _čaká_, _етап, --,
   {{0x6727b85d,0x394b12c3,0x659424ee,0xd12e0079}},	//   _hajj, _jocs_, _засу, لمى_,
   {{0x7bcd01a9,0x3207a68f,0x6727b85e,0x8504026b}},	//   _ntau, stny_, _kajj, _سولن,
   {{0x2d9200f1,0xbebc0029,0x67274380,0x00000000}},	//   _skye_, ldīj, _jajj, --,
   {{0x7bcd0f1a,0x6727b85f,0x6d9d11cf,0xfbb7021a}},	//   _atau, _majj, réan, _इंजम,
   {{0x6d9d572e,0xed571645,0x394b0024,0x00000000}},	//   séan, дою_, _nocs_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaa61018,0x67273607,0x5eb70083,0x2d99b860}},	//   даго, _najj, _আজকে, alse_,
   {{0xeb973d22,0xb0d105f8,0xdb040300,0x2cbf0506}},	//   фир_, _सभाग, _quiñ, žuda_,
   {{0x29e8013b,0x6d9d178d,0x394b0176,0x61ee082b}},	//   rğa_, néal, _cocs_, _æble,
   {{0x67270273,0x60dd008a,0x66e6052a,0x0c2300af}},	// [db80] _bajj, ósmy, доза, _амын,
   {{0x7c24b861,0x6d460a23,0xbcfb0037,0x46ea03d0}},	//   _isir, ljka, mhéa, іден_,
   {{0x6727b862,0x5b570122,0x394bb863,0x2d6f0355}},	//   _dajj, _חייב_, _focs_, dřej_,
   {{0x6e23aad9,0x6d4633c7,0xb4ca0b57,0x387f0506}},	//   _msnb, njka, ोरे_, _žure_,
   {{0x68e4b864,0x5ede0033,0x672779ef,0x78dd00e2}},	//   maid, _মাসে, _fajj, _énbạ,
   {{0x68e4b865,0x290003d0,0xf8bf3812,0x6727001c}},	//   laid, lgia_, _jaén_, _gajj,
   {{0x7d040124,0xf1a6021d,0x65c3010b,0x6d9d0098}},	//   _ocis, мрин, _абса, féal,
   {{0x29008d38,0x68e48076,0x394b01f7,0x64a61499}},	//   ngia_, naid, _xocs_, _жаба,
   {{0x02cf39f2,0xf99300a5,0x7306b866,0x7c24b867}},	//   _स्वभ, כרה_, _опаз, _nsir,
   {{0x68e441e3,0xb35600bf,0xbcfb0037,0x7d04273b}},	//   haid, _زیبا_, dhéa, _acis,
   {{0x7c2402e9,0x36f70122,0x7bcd6438,0x6b50013c}},	//   _asir, וצים_, _stau, _lägs,
   {{0xc0a94e4a,0x6d9d0098,0x20230421,0x00000000}},	//   _کامل_, céal, äriä_, --,
   {{0x68e4b868,0xe0430dc8,0x7c2400fd,0x44240282}},	//   daid, _инци, _csir, _jsm_,
   {{0xfe6f1c0c,0x44240183,0xe1f1006c,0x394b0176}},	//   ادی_, _msm_, _جسے_, _socs_,
   {{0x68e4b869,0x44241af8,0x394b0443,0xd6e40033}},	//   faid, _lsm_, _pocs_, মলায,
   {{0x68e4b86a,0xbcfb0082,0x290001d3,0x672756e0}},	//   gaid, bhéa, ggia_, _sajj,
   {{0x7d1db50f,0x67270484,0x6d9d1b73,0x7bcd08c7}},	// [db90] mess, _pajj, néam, _utau,
   {{0x7d1db86b,0x70bb164f,0x67270024,0x00000000}},	//   less, _उल्ल, _qajj, --,
   {{0xb90512eb,0xfad60122,0x8aa7172a,0x68e4b86c}},	//   _না_, _אותך_, _юрид, baid,
   {{0x68e400f1,0x67d506cd,0x65620159,0x6727018e}},	//   caid, _пому, ghoh, _wajj,
   {{0x67270484,0x4424b86d,0xf992016b,0x947500f8}},	//   _tajj, _csm_, _תרכ_, رگرا,
   {{0x27e99e3e,0x7d1db86e,0xf8bf002a,0x31a100d5}},	//   msan_, hess, _xaén_, dóza_,
   {{0x07a401c8,0x7d1db86f,0xb87b002a,0x4424b870}},	//   _раён, kess, _edít, _esm_,
   {{0x34952399,0x27e9b871,0x656208c7,0x602500af}},	//   _забр, osan_, choh, едиа,
   {{0x27e9b872,0x7d1d066e,0xa2ca00b4,0x6d9d178d}},	//   nsan_, dess, _स्क्, réal,
   {{0x6b50013c,0x6d5f0c6f,0x7d1d0328,0x68e48d3e}},	//   _lägr, _alqa, eess, zaid,
   {{0x7d1d1691,0x27e90284,0x44240051,0x6d4d0345}},	//   fess, hsan_, _zsm_, _boaa,
   {{0x7d1db873,0x26070ccf,0x27e9b874,0x90e70609}},	//   gess, _हमनी_, ksan_, _آسان,
   {{0x27e901ff,0x68e4b875,0x98a20260,0x00000000}},	//   jsan_, vaid, _pakč_, --,
   {{0x5f451c64,0xdb1c01c2,0x68e40657,0x27e90874}},	//   _سنبل, _özün, waid, dsan_,
   {{0x68e4b876,0x290001a5,0x7d1db877,0x27e90069}},	//   taid, tgia_, bess, esan_,
   {{0x60c9b878,0x7d1db879,0x7c24116e,0x68ef0176}},	//   ncem, cess, _tsir, _cdcd,
   {{0x27e90159,0x68e4b87a,0x7c241b68,0x00000000}},	// [dba0] gsan_, raid, _usir, --,
   {{0x68e4b87b,0xb4ca0517,0x6d5d0031,0x3a260823}},	//   said, ोर्_, ërav, _змог,
   {{0x68e4b87c,0xaadb0122,0x27e9b87d,0x4424028b}},	//   paid, _מחיר, asan_, _ssm_,
   {{0x27e90a2d,0x44242629,0x2ee5024b,0x00000000}},	//   bsan_, _psm_, half_, --,
   {{0x3d12b87e,0xb87b0370,0x27e9009e,0x88bb00a5}},	//   ध्ये_, _veíc, csan_, _מזכי,
   {{0xf4870e3a,0x6562b87f,0x087702b5,0x7d1db880}},	//   رانی, shoh, _װעלט_, zess,
   {{0x7d1dab35,0x46a3b881,0xbcfb01cb,0x00000000}},	//   yess, _барв, dhén, --,
   {{0x44246fe6,0x00000000,0x00000000,0x00000000}},	//   _tsm_, --, --, --,
   {{0x7d1db882,0x251b0070,0x65600079,0xd00703e6}},	//   vess, _צומא, _ilmh, еење_,
   {{0x7d1db883,0x6d9d0098,0x31a100ac,0x00000000}},	//   wess, réam, róza_, --,
   {{0x7d1db884,0x26c70a78,0x6dba0024,0x00000000}},	//   tess, žnog_, _aċar, --,
   {{0x27e9b885,0x63bab886,0xb87b02d7,0x6abe02a7}},	//   ysan_, _hitn, _leía, _agpf,
   {{0x27e90be2,0x63bab887,0x7c848b54,0x0ca85867}},	//   xsan_, _kitn, гуре, етри_,
   {{0xcf260088,0xa2a70266,0xbcfb01ef,0x63ba035f}},	//   _سرتي, टेक्, chén, _jitn,
   {{0x7d1db888,0x27e9011e,0x61eab889,0x63baa70c}},	//   pess, wsan_, nsfl, _mitn,
   {{0x27e9b88a,0x63ba053e,0x629a2c9a,0x0e9b011d}},	//   tsan_, _litn, _myto, _משול,
   {{0x27e9b88b,0x6b50013c,0x00000000,0x00000000}},	// [dbb0] usan_, _vägr, --, --,
   {{0x27e9b88c,0xfbd00098,0xb8830355,0x63bab88d}},	//   rsan_, _اتي_, vlíč, _nitn,
   {{0x7ae784e4,0xf7480037,0x629a029e,0x00000000}},	//   majt, علمي_, _nyto, --,
   {{0x7ae7b88e,0x27e9b88f,0x442f01ef,0xa3d52ad9}},	//   lajt, psan_, tvg_, водч,
   {{0x63ba0a78,0x27e9013b,0x245833d1,0x6dbb0024}},	//   _bitn, qsan_, наць_, _jċaq,
   {{0x629a1b66,0xe299b890,0x2bd90035,0x3949b891}},	//   _byto, мал_, _बौछा, ljas_,
   {{0x386908bf,0x629ab892,0x63ba0a8a,0x63520bfe}},	//   lzar_, _cyto, _ditn, рвју,
   {{0x3949b893,0x5694b894,0x7ae7b895,0x7777003c}},	//   njas_, _саст, hajt, lixx,
   {{0x38690f56,0x7ae7b896,0x7ed500d4,0x6288b897}},	//   nzar_, kajt, кінч, _exdo,
   {{0x7ae77200,0xdb170972,0x60c9b898,0x63ba0dc3}},	//   jajt, _fixé, scem, _gitn,
   {{0x7ae70936,0xa2ca0d00,0xc3240033,0xdced0207}},	//   dajt, _स्ट्, পাশি_, _emač,
   {{0xed5a3aab,0x00000000,0x00000000,0x00000000}},	//   фом_, --, --, --,
   {{0x40920118,0x644f01f7,0x63ba00e0,0x0d830ffd}},	//   _پلور, _àcid, _yitn, рлян,
   {{0x93fa0122,0x7ae708b7,0xf8bf00a2,0x00000000}},	//   ולשי, gajt, _agé_, --,
   {{0x200db899,0xbcfb00f7,0x39490345,0x00000000}},	//   ltei_, chéo, fjas_, --,
   {{0x6d5d0055,0x00000000,0x00000000,0x00000000}},	//   ërat, --, --, --,
   {{0x7ae7b89a,0x200db89b,0x8c463626,0xcc8a00d1}},	// [dbc0] bajt, ntei_, _репе, _زنده_,
   {{0x4438031b,0x7ae7b89c,0x7bfb0122,0xd9100df3}},	//   _čr_, cajt, _קפיצ, _گیر_,
   {{0x386901ef,0xb87b00de,0x63bab89d,0xd24500f8}},	//   azar_, _veía, _ritn, _اچ_,
   {{0x63ba0a78,0xd9100a86,0xceb2011d,0x629a010b}},	//   _sitn, _دیر_, ביב_, _ryto,
   {{0xa3dd02cb,0x61ea2ea2,0x63ba14a6,0x938a0786}},	//   थील_, wsfl, _pitn, мска_,
   {{0x61ea1037,0xe3af0286,0x61f802c4,0x7bc40103}},	//   tsfl, يرو_, trvl, _muiu,
   {{0xf50662c5,0xd5b221a0,0x63ba988b,0xcb1300a5}},	//   _изво, _نفس_, _vitn, ילג_,
   {{0x2d540279,0x629a0097,0xdb170042,0x7ae70168}},	//   _mães_, _vyto, _vixé, zajt,
   {{0xdefa00af,0x61ea0408,0x00000000,0x00000000}},	//   мын_, ssfl, --, --,
   {{0x7d1600b8,0x63ba152b,0x2d8200ee,0x9f5300c3}},	//   _abys, _uitn, enke_, ивыч,
   {{0x7ae7000a,0x3869007a,0x00000000,0x00000000}},	//   vajt, zzar_, --, --,
   {{0x7bc40211,0xdb160093,0x7c36008c,0x9f4d002a}},	//   _buiu, _styð, _bryr, rreá_,
   {{0x7bc40160,0x7ae7b89e,0xeb0e0066,0x06e80033}},	//   _cuiu, tajt, िभूत_, _পানি,
   {{0x69c300b5,0x7bc43562,0x10a318fd,0x7d16099e}},	//   _ének, _duiu, _тичн, _ebys,
   {{0x7ae72676,0x2d540279,0xda780945,0x661b0009}},	//   rajt, _cães_, вят_, _ćuko,
   {{0x99640012,0x3869b89f,0x7ae75b4c,0x3f9eb8a0}},	//   атул, tzar_, sajt, lltu_,
   {{0x7ae7b8a1,0x39491f13,0x6ca400af,0x00000000}},	// [dbd0] pajt, rjas_, _врэж, --,
   {{0xf7700c26,0x386904c7,0x6d5db8a2,0x2ca41008}},	//   يال_, rzar_, lksa, ümde_,
   {{0x3a8415eb,0x35f56c89,0xb87b0176,0x5a4700d8}},	//   _выяв, упер, _edíp, _рэпа,
   {{0x6d5db8a3,0xe0df00cc,0x00000000,0x00000000}},	//   nksa, ưòi_, --, --,
   {{0x7ae5007c,0x248903e6,0x6d5d01e4,0x69c5b8a4}},	//   _keht, çam_, iksa, _huhe,
   {{0x4209a0be,0x69c50054,0x59da00b4,0x7ae5009f}},	//   енко_, _kuhe, यीकर, _jeht,
   {{0xe2962214,0x69c500ab,0xbcfb00a2,0x00000000}},	//   лаш_, _juhe, thél, --,
   {{0x7ae5b8a5,0xa0a507e5,0x69c53772,0x2249011c}},	//   _leht, лайд, _muhe, ćak_,
   {{0x69c5b8a6,0x7ae501ed,0x00000000,0x00000000}},	//   _luhe, _oeht, --, --,
   {{0x200db8a7,0x7ae50355,0xdb0500ee,0x00000000}},	//   rtei_, _neht, _mihó, --,
   {{0x200d6a67,0x1d0a02fb,0x64593c30,0x69c50027}},	//   stei_, нени_, lywi, _nuhe,
   {{0x65790345,0x7bc40395,0x00000000,0x00000000}},	//   niwh, _puiu, --, --,
   {{0xff5300d1,0xbcfb0af7,0x60db4edf,0x00000000}},	//   _پخش_, chém, mbum, --,
   {{0xdee52079,0x60dbb8a8,0x69c5b8a9,0x2d540132}},	//   _соки, lbum, _buhe, _pães_,
   {{0x7ae5007e,0x00000000,0x00000000,0x00000000}},	//   _deht, --, --, --,
   {{0x69c5071f,0x6d5db8aa,0x98a00254,0x4ea40bfe}},	//   _duhe, cksa, ndić_, _трча,
   {{0x59c00d91,0x999e00b5,0x18674cf3,0x2d830009}},	// [dbe0] _शंकर, ítő_, гати_, čket_,
   {{0x64590035,0x7ae5033b,0x00000000,0x00000000}},	//   dywi, _geht, --, --,
   {{0x9bb70122,0x69c50010,0x75d30037,0x00000000}},	//   _תהיה_, _guhe, ميلا, --,
   {{0xd94623c0,0x645900e9,0x4a7b100a,0x98a00207}},	//   _семи, fywi, _טריב, jdić_,
   {{0x4d7b02b5,0xbebc0029,0x06e80033,0x00000000}},	//   ערנע, ldīt, _পাঠি, --,
   {{0x5334010c,0xd2cf0066,0x61e100e5,0x332c0069}},	//   рект, सुलझ, _bwll, _qadx_,
   {{0x3d05006a,0x77910d4f,0xed6115d8,0xa79b00a5}},	//   _वाले_, _بیلا, ážky_, _נשלח,
   {{0x41544f06,0x41c3004f,0xbcfb00f7,0x60db0159}},	//   рвис, حقيق, thém, gbum,
   {{0xa3cb1db6,0x68e60c99,0x79845850,0x00000000}},	//   _रूप_, _mekd, iniw, --,
   {{0x66e40266,0x141b0070,0x75220044,0x68e60051}},	//   गरिक_, _אומב, leoz, _lekd,
   {{0xa2450987,0x3eb8b8ab,0x4426018e,0x7ae50421}},	//   _نیول_, ärt_, lwo_, _reht,
   {{0x69c5b8ac,0xdd95061c,0xafe60369,0x68e653eb}},	//   _ruhe, рамы, _бодл, _nekd,
   {{0x6d5db8ad,0x69c500ab,0x60c201d5,0x6b950116}},	//   rksa, _suhe, _igom, tozg,
   {{0x69c503ad,0x07030035,0xdcef002d,0x00000000}},	//   _puhe, _लाइव_, fică, --,
   {{0x6459004e,0x69c500da,0xab5b0279,0x68e60107}},	//   zywi, _quhe, nqüi, _bekd,
   {{0x260802cb,0x58d53741,0x4426b8ae,0xc4bf0033}},	//   ांनी_, роат, kwo_, _উজ্জ,
   {{0x7ae5066e,0x60c2000e,0x752200ac,0xb6060254}},	// [dbf0] _teht, _mgom, deoz, _lišć,
   {{0x2ca9028b,0x44269927,0x2fc60159,0x69c5b8af}},	//   _izad_, dwo_, _muog_, _tuhe,
   {{0xfbd005f5,0x57a410be,0xe4d5820c,0x60c2030d}},	//   _وتی_, сшта, لقاد, _ogom,
   {{0x60c2b8b0,0xdb1701ef,0x64590067,0x89da1804}},	//   _ngom, _mixí, tywi, _שחרי,
   {{0x442601a8,0x672e02a7,0xbcfb00a2,0x00000000}},	//   gwo_, _fabj, ckée, --,
   {{0x6459b8b1,0x1b230083,0x60c24023,0xc886033b}},	//   rywi, মাকে_, _agom, üßen_,
   {{0x442601a8,0x645500a8,0x00000000,0x00000000}},	//   awo_, _əziy, --, --,
   {{0x4426070b,0x2d890523,0x00000000,0x00000000}},	//   bwo_, _njae_, --, --,
   {{0x84670133,0x2919b8b2,0xdb170176,0xdb0d01ef}},	//   _съве, _mbsa_, _així, _luañ,
   {{0x2f555fa1,0x889c0070,0x60db4182,0x00000000}},	//   ртис, עבזי, sbum, --,
   {{0x3ea521be,0x2ca90095,0xc2c40125,0xbea5b8b3}},	//   ринг, _azad_, _ايمي, ранк,
   {{0xa3a91a75,0x6ed50302,0x60c2018e,0x25bf0395}},	//   _गीत_, _म्रु, _ggom, _jiul_,
   {{0xe50d0084,0x26d10120,0xa3cb18da,0x00000000}},	//   _हानि_, _ofzo_, _रूम_, --,
   {{0x291903bc,0x98a20035,0x60c200af,0x290b055c}},	//   _absa_, _jaką_, _zgom, _acca_,
   {{0x09e602ce,0x2d8b0248,0x2ca900d7,0x0f7a0317}},	//   робн, ébec_, _ezad_, _ברסל,
   {{0x3ceb0036,0x248d03d0,0x98a2005f,0x00000000}},	//   cacv_, _oxem_, _laką_, --,

   {{0xdd8f0934,0x212f64ae,0xa3e40387,0x249f034d}},	// [dc00] _توي_, _magh_, _भौं_, _nyum_,
   {{0x34de012f,0x7c290225,0x212f00f1,0x68e600d1}},	//   मर्द, çere, _lagh_, _wekd,
   {{0x59a70785,0x762654d3,0xa9a6b8b4,0x8b650079}},	//   _कीवर, рмез, _винд, _دايم,
   {{0x4426006a,0xe45a03ad,0xb6060009,0x61fc0e45}},	//   two_, кже_, _rišć, _årli,
   {{0x2407b8b5,0xd90d042c,0x752200f4,0x98a2005f}},	//   инци_, _سیل_, reoz, _baką_,
   {{0x4426b8b6,0x60c24b9f,0x8c37016b,0x00000000}},	//   rwo_, _sgom, יטנס_, --,
   {{0x661c0bec,0x212f0211,0x46aa007c,0x44260dda}},	//   _uprk, _bagh_, _करिह, swo_,
   {{0x1fda0033,0x25ad009e,0xbcfb0097,0xe43a00d5}},	//   _দিবস, _ghel_, chéh, láčň,
   {{0xe3ba04d9,0x7f9d0248,0x212f03d0,0x00000000}},	//   _аба_, hèqu, _dagh_, --,
   {{0xc30600b5,0x381702b8,0x200b12c3,0x46aa0066}},	//   _خبرو, סקים_, àcia_, _कराह,
   {{0x201d0359,0xdb170183,0x00000000,0x00000000}},	//   _epwi_, _lixã, --, --,
   {{0x61430dba,0x60c2035a,0xdb17002a,0x00000000}},	//   _меха, _ugom, _vixí, --,
   {{0x80dd00c8,0xd0070133,0x249f006d,0x2f18b8b7}},	//   _যাচ্, _вече_, _xyum_, _боль_,
   {{0x20040029,0x27170355,0x2ca900ac,0x2ee71ca7}},	//   mumi_, _mění_, _vzad_, _genf_,
   {{0x2004b8b8,0x2d89b8b9,0x00000000,0x00000000}},	//   lumi_, _tjae_, --, --,
   {{0x644d00c3,0x00000000,0x00000000,0x00000000}},	//   äaik, --, --, --,
   {{0x20040080,0x2d997d8b,0x38340217,0x00000000}},	// [dc10] numi_, mose_, онтр, --,
   {{0x2d99a02c,0x7c2db8ba,0x25bfb8bb,0x290b03d0}},	//   lose_, _isar, _siul_, _wcca_,
   {{0x2004000e,0xcf930070,0x7c2d007a,0x81bc0228}},	//   humi_, קטע_, _hsar, _drēz,
   {{0x2004b8bc,0x2d9918cc,0xe5700c74,0x6d4f0a66}},	//   kumi_, nose_, وطن_, njca,
   {{0x20040ae0,0x68edb8bd,0x6d9d0079,0x7c2d0024}},	//   jumi_, maad, léas, _jsar,
   {{0x68edb8be,0xb5c9126b,0x7c2d010d,0x2d99b8bf}},	//   laad, _موسم_, _msar, hose_,
   {{0x7d0d2993,0xd5bb0036,0xdb1e4dbf,0x212f008c}},	//   _ocas, _аса_, _sipë, _pagh_,
   {{0x68edb8c0,0x200407e5,0x2909b8c1,0xbcfb0037}},	//   naad, fumi_, ngaa_, bhéi,
   {{0x2d99b8c2,0x2004b8c3,0x656b0037,0xd8400187}},	//   dose_, gumi_, mhgh, _účty_,
   {{0x442db8c4,0x7d0db8c5,0x68ed5aa0,0x1f65b8c6}},	//   _ise_, _acas, haad, ском,
   {{0xed5a32a6,0x68edb8c7,0x69d7006f,0x51876299}},	//   гон_, kaad, _ntxe, _куда,
   {{0x442db8c8,0xdb170176,0x7c2d881b,0x2d99b8c9}},	//   _kse_, _aixà, _bsar, gose_,
   {{0x68ed00be,0x442db8ca,0xdb1e002a,0x69d701b7}},	//   daad, _jse_, _hipé, _atxe,
   {{0xb47a02b5,0x6d4b0c1f,0x66050ec0,0x1dcfb8cb}},	//   אָלי, _ògan, kuhk, _संपत,
   {{0x2d99b8cc,0x442db8cd,0x7c2d0a21,0x00000000}},	//   bose_, _lse_, _esar, --,
   {{0x442d01d2,0x68edb8ce,0x660520fb,0x290902ee}},	//   _ose_, gaad, duhk, ggaa_,
   {{0x69d70291,0x6d44b8cf,0x442d005f,0xdb1e0037}},	// [dc20] _etxe, _inia, _nse_, _lipé,
   {{0x6d440221,0x5fdf0099,0xa92700ec,0x00000000}},	//   _hnia, पीएल, _apžē, --,
   {{0x68edb8d0,0x442d02e9,0x66051581,0x6d56027d}},	//   baad, _ase_, guhk, _koya,
   {{0x6d56753c,0xbcfb0037,0xdb1e02d0,0x7aee0110}},	//   _joya, théi, _sipè, labt,
   {{0x6d560ec0,0xb80900b5,0x00000000,0x00000000}},	//   _moya, _نکلے_, --, --,
   {{0x66051d11,0x442d9859,0x200400ea,0x6d9d0079}},	//   buhk, _dse_, vumi_, néar,
   {{0x442db8d1,0x69dcb8d2,0x6605012f,0x27f277e6}},	//   _ese_, npre, cuhk, lsyn_,
   {{0xf1260a55,0x6d56b8d3,0x2d990391,0x4fd488f0}},	//   сько, _noya, xose_, ожит,
   {{0xa4940148,0x2d99b8d4,0x69dcb8d5,0x3e4e0095}},	//   _بیشت, vose_, hpre, məti_,
   {{0x543b00c2,0x160c0ccf,0x6d44b8d6,0x7d0db8d7}},	//   _געמא, _हमार_, _ania, _scas,
   {{0x68ed018e,0xa3e44d99,0xeb9f177c,0x69dc1912}},	//   yaad, भीर_, ktør_, jpre,
   {{0x69dcb8d8,0x656228e5,0x2d9900d8,0x7c2d03d0}},	//   dpre, nkoh, uose_, _psar,
   {{0x7d0db8d9,0x6d56b8da,0x69dc12ba,0x68ed00ab}},	//   _vcas, _doya, epre, vaad,
   {{0x68ed0f25,0x69dc033b,0x2d99b8db,0x65620055}},	//   waad, fpre, sose_, hkoh,
   {{0x69dc2a03,0x799d012f,0x1dcf021a,0x68edb8dc}},	//   gpre, _pksw, _संयत, taad,
   {{0x7c2db8dd,0x2b1a045c,0x6d9d0037,0x6d5609e7}},	//   _tsar, म्बु_, réas, _goya,
   {{0xb8d127bd,0x68edb8de,0x7c2d0f1f,0x6d9d01dd}},	// [dc30] _ओर_, raad, _usar, séas,
   {{0x68ed4872,0x66053101,0x69dca358,0x7bdd00be}},	//   saad, tuhk, bpre, mpsu,
   {{0x656b09c3,0xd91952e6,0x442d525a,0x69dc3811}},	//   thgh, _конц_, _sse_, cpre,
   {{0x442d01d2,0xd1260a86,0x660506b3,0xe7ed0026}},	//   _pse_, _غم_, ruhk, _चौथा_,
   {{0xe3b103c7,0xd00615f8,0x06e80083,0x442d021d}},	//   ورت_, _تل_, _পারি, _qse_,
   {{0x31b3065f,0x442d39ea,0x67d421be,0x660500be}},	//   ुद्ध, _vse_, _хору, puhk,
   {{0x3e4e00a8,0x78c800fd,0x00000000,0x00000000}},	//   bəti_, _ásvá, --, --,
   {{0x442db8df,0x349500d8,0x88e70033,0xd1b900b5}},	//   _tse_, _дабр, _ফাঁক, جاتا_,
   {{0x442d0052,0x1aef0083,0x6d564869,0x5f750172}},	//   _use_, _জানে_, _roya, قادر,
   {{0x2d8b006c,0x6d56b8e0,0x00000000,0x00000000}},	//   ében_, _soya, --, --,
   {{0x69dcb8e1,0x6d5601ed,0xd12e03fc,0x00000000}},	//   xpre, _poya, رمی_, --,
   {{0x69dc02c6,0x6d5600a8,0x00000000,0x00000000}},	//   vpre, _qoya, --, --,
   {{0x6d561010,0x32070176,0x69dcb8e2,0x9f3501e0}},	//   _voya, luny_, wpre, _меді,
   {{0x69dcb8e3,0xf99f0107,0x6d560103,0x3b0a0274}},	//   tpre, _akè_, _woya, јево_,
   {{0x3e4e0095,0x6d56b8e4,0xa3cb0f9c,0x656906d4}},	//   yəti_, _toya, _रूस_, _oleh,
   {{0x7aee043d,0x6d44b8e5,0xdce40c8c,0xb4e80084}},	//   sabt, _unia, _klič, _मजे_,
   {{0x69dcb8e6,0x46ea0c06,0x98a30573,0x3ff90070}},	// [dc40] spre, идан_, дите, יפּע,
   {{0xbf8700e8,0x81df0083,0xbcfb006c,0x69dc6335}},	//   _điện_, _তিন_, nkén, ppre,
   {{0x6b9cb8e7,0x20180043,0xdd8f00d1,0x316d006c}},	//   morg, ării_, _سوی_, khez_,
   {{0x96da16d3,0x6b9c17ad,0x16aa0084,0xdce4011c}},	//   _प्रॉ, lorg, _करीब, _olič,
   {{0xc2f30083,0x656200da,0x3e4e00a8,0x29e8013b}},	//   চ্ছি_, rkoh, rəti_, lşa_,
   {{0x47c30021,0x69c30248,0x9c83053d,0x6b9c1167}},	//   _обяв, _éner, _účel, norg,
   {{0xe1ef0037,0x416a0274,0x6d0a00b4,0x00000000}},	//   نسي_, ијим_, _वांग_, --,
   {{0xdced042a,0xdce40009,0xf99f07e5,0x6b9c76f5}},	//   _imać, _blič, _xkè_, horg,
   {{0xe5a30652,0x6b9cb8e8,0xb4e60066,0x3860b8e9}},	//   _цити, korg, फरी_, nyir_,
   {{0x25a6b8ea,0x6b9c01e9,0x00000000,0x00000000}},	//   llol_, jorg, --, --,
   {{0xe8a70587,0x6b9c2cf6,0x81e40033,0x636f0d51}},	//   _खर्च, dorg, ভূজ_, _bønf,
   {{0x316d00f7,0xd13003c5,0x5bb50355,0x00000000}},	//   chez_, _سمت_, ूद्व, --,
   {{0xbcfb006c,0x0cab27eb,0x00000000,0x00000000}},	//   bkén, ртни_, --, --,
   {{0xa3b0006a,0x96da04bc,0x99d70037,0x00000000}},	//   _टीम_, _प्लॉ, قترا, --,
   {{0x0eba010b,0x00000000,0x00000000,0x00000000}},	//   _туды_, --, --, --,
   {{0x4c95027a,0x65a300be,0x1dcf035d,0x00000000}},	//   _нийс, põhi, _संतत, --,
   {{0x6b9c28a6,0x26c73ce5,0x00000000,0x00000000}},	// [dc50] borg, žnom_, --, --,
   {{0xd6db0df8,0x5a4701c8,0x6b9c0382,0xb902205c}},	//   рта_, _дэма, corg, _न्_,
   {{0xcb1202b8,0x65699dc8,0x7bcd014c,0x00000000}},	//   _אלי_, _pleh, _huau, --,
   {{0x1dbd00e7,0x057401cb,0xa6e30033,0x7bcd0103}},	//   ोदित, واند, _পাওয়, _kuau,
   {{0x7bc5b8eb,0x3d130035,0x2d8b0079,0xb4270037}},	//   _kihu, _थाने_, ince_, تعاو,
   {{0x232916fb,0xd8ba00a5,0x26080099,0x00000000}},	//   соки_, _לצרכ, ांशी_, --,
   {{0xdce401cc,0x7afa008a,0x96f85867,0x62650b25}},	//   _slič, ótti, _фест_, явка,
   {{0x657b25bf,0x6b9c0a75,0x32074a9c,0x645c00a8}},	//   _umuh, zorg, runy_, _əriz,
   {{0x4439b8ec,0x229502fd,0x7bc501a3,0x81bc00ea}},	//   _és_, _کلاس, _oihu, _spēc,
   {{0x2d8b6466,0x443fb8ed,0x39592f0d,0x316d00b5}},	//   ence_, _iru_, _loss_, shez_,
   {{0x443f024e,0x6da67ef0,0x80a500b5,0xada60382}},	//   _hru_, зина, _کمشن, занл,
   {{0xbcfb2f98,0x673502a7,0x00000000,0x00000000}},	//   skén, _lazj, --, --,
   {{0x6b9cb8ee,0x7bc53d63,0x160d02e4,0x7bcd00de}},	//   torg, _bihu, ांडर_, _cuau,
   {{0x26c70f44,0x2d8bb8ef,0xd00e004f,0x31a100d5}},	//   žnoj_, ance_, _صلى_, rózu_,
   {{0x7bc5005d,0xbcfb00f7,0x6b9cb8f0,0xae1f007c}},	//   _dihu, thét, rorg, _बहिन_,
   {{0x39461166,0x88ca05f2,0x65aa0187,0x443fb8f1}},	//   ños_, слав_, výho, _oru_,
   {{0x2d82b8f2,0x443f0484,0x7bcd0138,0x3b0a0274}},	// [dc60] mike_, _nru_, _guau, _лепо_,
   {{0x2d82a549,0x7bc5b8f3,0x7c24b8f4,0x00000000}},	//   like_, _gihu, _ipir, --,
   {{0x443f007c,0x3860046a,0x395992f3,0x6735007a}},	//   _aru_, syir_, _foss_, _dazj,
   {{0x443fb8f5,0x7bc501d5,0xa50a3d1a,0x994a0037}},	//   _bru_, _zihu, седа_, _الحل_,
   {{0xe803006a,0xdce60029,0x68e4b8f6,0x27ee01c0}},	//   _लिया_, dokļ, mbid, álně_,
   {{0x27e00464,0x68e40291,0x7c240054,0x443f47e0}},	//   mpin_, lbid, _mpir, _dru_,
   {{0x443f064b,0x7f58006d,0x69c68caa,0xa2d8022e}},	//   _eru_, _rovq, _kike, नुष्,
   {{0x68e4b8f7,0x443f555b,0x59be9c52,0x7c24040b}},	//   nbid, _fru_, ्दिर, _opir,
   {{0x69c6b8f8,0x68e4b8f9,0x2d82b8fa,0x27e01859}},	//   _mike, ibid, dike_, npin_,
   {{0x69c6b8fb,0x64407469,0x9df80370,0x7bcd009e}},	//   _like, _irmi, онот_, _ruau,
   {{0x69c603ad,0xdd95010b,0x2d82b8fc,0x7c2406a2}},	//   _oike, даны, fike_, _apir,
   {{0x64403788,0x69c60424,0x442400d7,0x2d82080a}},	//   _krmi, _nike, _kpm_, gike_,
   {{0x2d8b01f2,0x2b5a01f7,0x5bc71b8f,0x7bc500ab}},	//   rnce_, _bopc_, लदेव, _pihu,
   {{0x39590553,0x7fb800d1,0xddda006c,0x2b5a01f7}},	//   _soss_, _بهتر_, sztő, _copc_,
   {{0x67350528,0x395901a2,0x7c24b8fd,0x69c6b8fe}},	//   _razj, _poss_, _epir, _bike,
   {{0x3f9eb8ff,0x69c6b900,0xf2df0019,0x6da40166}},	//   lotu_, _cike, _đâm_, _пија,
   {{0xa2bc04aa,0x69c6120d,0x2cfb0066,0x39590f0a}},	// [dc70] षेत्, _dike, ्लील_, _voss_,
   {{0x3f9e4df2,0x69c6b901,0x2eee1691,0x7d1db902}},	//   notu_, _eike, _jeff_, lfss,
   {{0x69c6b903,0x4424730a,0xda6700bc,0x6d4000f7}},	//   _fike, _apm_, _رادي, ômag,
   {{0x3f9e00ac,0x659400af,0x68e48051,0x69c604fb}},	//   hotu_, наху, cbid, _gike,
   {{0x98ab0012,0x3f9eb904,0x240900d4,0x444500b5}},	//   _dacă_, kotu_, інки_, براہ,
   {{0x2d823a73,0x8c1c0070,0x64460124,0x69c6513a}},	//   zike_, צווי, _škic, _zike,
   {{0x6440b905,0x44240176,0x98ab002d,0x2004027a}},	//   _ermi, _epm_, _facă_, ermi_,
   {{0x636f3a92,0x443f0044,0xd17900d8,0x798db906}},	//   _sønd, _tru_, ўскі_, nnaw,
   {{0x443f01d5,0x3cde02e4,0x1dcf018d,0x7d00008e}},	//   _uru_, _क्षे_, _संहत, ómsm,
   {{0x6e23012f,0x798d01a2,0x9e6524c1,0x8af700a8}},	//   _ppnb, hnaw, двод, _şənb,
   {{0x7c24ab76,0x2d82b907,0x442f0297,0x2004979c}},	//   _spir, tike_, lwg_, armi_,
   {{0xd00e0df3,0xb33c0024,0x68ef00a3,0x27e00421}},	//   دلی_, _ikħa, _necd, ypin_,
   {{0xef0e0f8c,0x2d82b908,0x3f9e08c2,0xe6aa0517}},	//   _им_, rike_, botu_, _कर्ज,
   {{0x69c60332,0x8e850896,0x2d82b909,0xb87b02d7}},	//   _sike, _огле, sike_, _leís,
   {{0x69c6ae57,0xfaa34e35,0x2d82b90a,0xc33200a5}},	//   _pike, варо, pike_, כום_,
   {{0x140d3054,0xb4c9009a,0x2d9501c8,0x68e401d7}},	//   _समूह_, ोडो_, _прыс, ubid,
   {{0x69c6b90b,0xbcfb00f7,0x7c241bd8,0x2fc700a5}},	// [dc80] _vike, phér, _upir, _king_,
   {{0x69c6b90c,0x68e4b90d,0x28de1119,0x2d800284}},	//   _wike, sbid, _फ्रि, _hmie_,
   {{0x2fc708eb,0x4424b90e,0x7afa0093,0x2fcf0523}},	//   _ming_, _spm_, óttu, _lugg_,
   {{0xc4862d4b,0x27e009bd,0xdb1e01f7,0x3ea7b90f}},	//   млек, ppin_, _hipà, _mynt_,
   {{0xd24f00bf,0x2fdd006d,0x3f8c008d,0x98ab0139}},	//   ینه_, _ntwg_, yndu_, _vacă_,
   {{0x2fc7b910,0x06e800c8,0x28da1579,0x00000000}},	//   _ning_, _পাকি, युरि, --,
   {{0x3f9e3fcc,0x2d809631,0x2eee0088,0x00000000}},	//   votu_, _omie_, _reff_, --,
   {{0xc0340798,0x2d920010,0xb0340dec,0x60f802fb}},	//   ениј, _njye_, ениш, чния_,
   {{0x442405eb,0xdce6010b,0x3f9eb911,0x2fc70147}},	//   _upm_, likė, totu_, _bing_,
   {{0x2fcf54e4,0x2fc70088,0x2d8056be,0x798d0035}},	//   _dugg_, _cing_, _amie_, znaw,
   {{0xe0da0525,0x2fc7b912,0xf1a90088,0x3f9eb913}},	//   _две_, _ding_, _کاله_, rotu_,
   {{0x7d1d02b1,0x5bc70517,0x3ea7099e,0x00000000}},	//   ufss, लद्व, _dynt_, --,
   {{0x3f9e7ae9,0xb87b006c,0x2fc7b914,0x7d1d0093}},	//   potu_, _leír, _fing_, rfss,
   {{0x2fc777aa,0x00000000,0x00000000,0x00000000}},	//   _ging_, --, --, --,
   {{0xa2a45b7f,0x798d03bc,0x3ea700e9,0x69de023a}},	//   _चुम्, tnaw, _gynt_, _ctpe,
   {{0x69da0082,0x2fc701a5,0x798db915,0x6eda012f}},	//   ítea, _zing_, unaw, पुरु,
   {{0x442f01e8,0xe50d007c,0x57b538bb,0x68e201ef}},	// [dc90] xwg_, हलसि_, ебат, ñoda,
   {{0x2fc7b916,0xb87bb917,0x00000000,0x00000000}},	//   _xing_, _seís, --, --,
   {{0xfc3fb918,0x06e80033,0x00000000,0x00000000}},	//   lví_, _পাখি, --, --,
   {{0x46df0311,0xceb30100,0xa4d500d4,0x442fb919}},	//   _प्रह, דיע_, ході, twg_,
   {{0xd0060041,0x245801c8,0xd6db10b4,0x636f008c}},	//   _حل_, маць_, _мтв_, _rønb,
   {{0x442f6b35,0x00000000,0x00000000,0x00000000}},	//   rwg_, --, --, --,
   {{0xc6a409eb,0x2b12018d,0x442f01e8,0x7c3a00ea}},	//   _арти, _तासु_, swg_, ātri,
   {{0x2fc70796,0x3cfb004e,0x7af506a2,0x00000000}},	//   _sing_, ्लों_, hazt, --,
   {{0x160d00a1,0xdb1e00d5,0x4395005f,0x2fc7b91a}},	//   ांवर_, _lipá, _заас, _ping_,
   {{0x2fc72bf4,0xa3d40fd1,0xbcfb0355,0x237915f8}},	//   _qing_, _संत_, lkéh, _عماد_,
   {{0x2fc7b91b,0x7af50065,0x8cc20067,0x00000000}},	//   _ving_, dazt, रेनो, --,
   {{0x2002010b,0xc6921804,0x2fc73080,0xbcfb00ac}},	//   škia_, ראט_, _wing_, nkéh,
   {{0x2fc7b91c,0xf539016f,0xa2c71ede,0x1dcf00b4}},	//   _ting_, _mať_, ाशक्, _सूरत,
   {{0x34cb00b4,0x2fc7009e,0x7af501a3,0xbcfb00ac}},	//   िशुद, _uing_, gazt, hkéh,
   {{0x3f850099,0xeb971126,0xda660413,0xbcfb00d5}},	//   milu_, хир_, راسي, kkéh,
   {{0x2d80b91d,0x3f8560b2,0xb87b0453,0x2d9201d5}},	//   _umie_, lilu_, _reír, _ujye_,
   {{0xa3cb1db9,0x7af501d7,0xcc360037,0xbcfb00ac}},	// [dca0] _रंग_, bazt, _أربع, dkéh,
   {{0x212db91e,0x3f8500cd,0xdce600d8,0x00000000}},	//   heeh_, nilu_, tikė, --,
   {{0x85060312,0x69de9207,0x00000000,0x00000000}},	//   فوان, _utpe, --, --,
   {{0xd6e800c8,0xd9100a86,0x200d0065,0x00000000}},	//   _পাওয, _خیر_, kuei_, --,
   {{0xd4672171,0xf53901ba,0xd90d0416,0x3f85b91f}},	//   нице_, _dať_, _ذیل_, kilu_,
   {{0xf8af006c,0x68f6b920,0x87b900af,0xdced0228}},	//   _چکے_, layd, _жуст_, _skaļ,
   {{0x3f8513a6,0x31c6b921,0x69cab51c,0x00000000}},	//   dilu_, нсив, _éfes, --,
   {{0x64a63be0,0xbcfb05d3,0x291251c0,0x68f601fb}},	//   _заба, ckéh, ngya_, nayd,
   {{0x59d227bd,0x3f858ea0,0x200d556d,0xa3ba00b5}},	//   _दूसर, filu_, guei_, _فائر_,
   {{0x68f6021d,0x67100026,0xd2aa00af,0x3f850065}},	//   hayd, ालिक_, _екзе_, gilu_,
   {{0x7c362bd6,0x00cab922,0xa3d40380,0x212d0118}},	//   _asyr, _елек_, _सूत_, beeh_,
   {{0xfc3f0311,0x68f6023c,0x00000000,0x00000000}},	//   tví_, jayd, --, --,
   {{0x3f850252,0x68f66de5,0x69da00b5,0x00000000}},	//   bilu_, dayd, íten, --,
   {{0xdced009f,0x00000000,0x00000000,0x00000000}},	//   _klaċ, --, --, --,
   {{0x3da70072,0x7af50291,0x3dc90159,0x00000000}},	//   _приб, razt, _tiaw_, --,
   {{0x1958005f,0x68f6b923,0x29120273,0x6c850037}},	//   насы_, gayd, ggya_, _للعم,
   {{0x6d4db924,0x636f008c,0xa8981dd6,0x7af501ed}},	// [dcb0] _inaa, _løna, екту_, pazt,
   {{0x81bc0080,0x69b304bc,0x76410093,0x00000000}},	//   _spēl, _आठवी, _ályk, --,
   {{0x6d4d0fdb,0x68f6b925,0x394b00e2,0x5f130387}},	//   _knaa, bayd, _tncs_, _दास्_,
   {{0x3f8502f6,0x00000000,0x00000000,0x00000000}},	//   zilu_, --, --, --,
   {{0x588700d8,0x6d4d08c7,0xa3cb0d4e,0x9cd800a5}},	//   _чына, _mnaa, _रूख_, גודה_,
   {{0xbcfb024e,0x00000000,0x00000000,0x00000000}},	//   skéh, --, --, --,
   {{0x3f8502f6,0xe296075c,0x6d4db926,0x61ed0124}},	//   vilu_, каш_, _onaa, ćalo,
   {{0x200d01a3,0x6d4d01a8,0x00000000,0x00000000}},	//   tuei_, _nnaa, --, --,
   {{0x3f85056c,0x63740392,0x200200f4,0xa3d501e0}},	//   tilu_, _bànd, škin_, _розч,
   {{0x6d4d33af,0x2003765d,0x26c70187,0x637401f7}},	//   _anaa, čji_, žnou_, _cànd,
   {{0x13e60b52,0xfce696b5,0x3f851977,0x753bb927}},	//   _নিয়, коно, rilu_, _kauz,
   {{0xd2560122,0x3f8502a7,0x753b01a3,0x68f600e2}},	//   _בשעה_, silu_, _jauz, xayd,
   {{0x200d7cae,0x753b1eb0,0x317a0070,0x3f858b30}},	//   quei_, _mauz, _קאנד, pilu_,
   {{0x63a3b928,0x68f60a8a,0x753bb929,0x6d4d073a}},	//   nonn, wayd, _lauz, _enaa,
   {{0xfaa613f8,0x68f60471,0x00000000,0x00000000}},	//   таво, tayd, --, --,
   {{0x1c463d35,0x63a300e5,0x60db0a04,0x753b01a3}},	//   _аним, honn, ncum, _nauz,
   {{0x63a3b92a,0xe73a0f08,0x68f6b92b,0x1c160354}},	// [dcc0] konn, меа_, rayd, _तमिल_,
   {{0x68f604d4,0x63a3b92c,0x1bba5b16,0x3cde08b0}},	//   sayd, jonn, _تابع_, कुरे_,
   {{0x5a96225d,0x68f608dd,0x753b5838,0x00000000}},	//   _шриф, payd, _bauz, --,
   {{0x753b0043,0x59830945,0x73e600d8,0x63740392}},	//   _cauz, _влюб, водз, _màne,
   {{0x63a31949,0x753b01d7,0x29020523,0xf4870919}},	//   fonn, _dauz, _idka_, پانی,
   {{0x63a3b92d,0x66e3010b,0xdced0024,0x00000000}},	//   gonn, _вора, _plaċ, --,
   {{0x753b0ac8,0x61e1009e,0xa2d8022e,0x00000000}},	//   _fauz, _ctll, नुग्, --,
   {{0x753b0291,0x673c0d4c,0x00000000,0x00000000}},	//   _gauz, _harj, --, --,
   {{0xb4250789,0x34a74ed5,0x63a302ce,0x1b0a0083}},	//   _معلو, _авто_, bonn, শ্যই_,
   {{0x63a3b92e,0x753b01cc,0xe3b741f8,0x6d4d053e}},	//   conn, _zauz, _абу_, _snaa,
   {{0x673c9237,0x6442b92f,0x3eaa01b4,0x69dab930}},	//   _marj, lvoi, æbt_, ítel,
   {{0x629a01ed,0x3cde7e44,0x673c0055,0x752201ed}},	//   _ixto, कुले_, _larj, nfoz,
   {{0x6442599e,0x63740392,0x6560009e,0x636f008c}},	//   nvoi, _tànd, _momh, _mønn,
   {{0x673c2d58,0x29020168,0x65602845,0x636f082b}},	//   _narj, _adka_, _lomh, _lønn,
   {{0x5fb70052,0xdced5b2d,0x5ec00083,0x6b870120}},	//   _שהוא_, _hlač, _শ্রে, rijg,
   {{0x63a3b931,0x261c1111,0x81bc0029,0x6d4d002f}},	//   zonn, dío_, _spēj, _unaa,
   {{0x63a3b932,0x69d89b7c,0xeab000b5,0xa2a4111b}},	// [dcd0] yonn, _éven, معہ_, _चुस्,
   {{0x261c1111,0x660301ba,0xdcedb933,0x6560009e}},	//   fío_, ánko, _imađ, _aomh,
   {{0x673cb934,0xc6a42d4d,0x28f9b935,0x63a3b936}},	//   _darj, арци, _пень_, vonn,
   {{0x656041f0,0x63a3b937,0xdb1e0328,0x00000000}},	//   _comh, wonn, _eipä, --,
   {{0x6560006e,0x63a3b938,0x44292ddc,0xdb050118}},	//   _domh, tonn, ïa_, _akhé,
   {{0x261c0300,0x753b002f,0x673c02a7,0x00000000}},	//   bío_, _wauz, _garj, --,
   {{0x63a3b939,0x3869b93a,0xb59517df,0x261cb93b}},	//   ronn, lyar_, _бивш, cío_,
   {{0xf2df0028,0x63a3b93c,0x56948b32,0xdce40129}},	//   _đâu_, sonn, _таст, _ilić,
   {{0x60dbb93d,0x0584010b,0x3869b93e,0x63a32c60}},	//   rcum, _турм, nyar_, ponn,
   {{0x260802cb,0x60dbb93f,0xdced0a16,0x00000000}},	//   ांची_, scum, _dlač, --,
   {{0x2f540409,0xa3d90067,0x00000000,0x00000000}},	//   ртыс, _ठंड_, --, --,
   {{0xed5a56e6,0x51844054,0x6b851c8b,0x69da0138}},	//   хом_, _куча, _amhg, ítem,
   {{0x644f2a87,0xdced00cd,0x9f4f017b,0xe536016b}},	//   _ácid, _glač, _avgå_, נטשט_,
   {{0x09be012f,0xdcef00ea,0x50b800d1,0x29190345}},	//   ्द्य, ficē, _شدند_, _acsa_,
   {{0x201f55bf,0xaaa40066,0x636f008c,0x00000000}},	//   ltui_, _खुशक, _løno, --,
   {{0x261c3318,0x673c2311,0xb88601c0,0x213fb940}},	//   vío_, _sarj, hlíž, nduh_,
   {{0x38690332,0x81bc0080,0x656002a8,0x201f1397}},	// [dce0] gyar_, _spēk, _romh, ntui_,
   {{0x65600874,0x261c20d9,0x636f0b41,0x00000000}},	//   _somh, tío_, _sønn, --,
   {{0x673cb941,0xa96a00af,0x201f00c3,0xa3c90f0d}},	//   _varj, _зина_, htui_, ोदन_,
   {{0x261c2b83,0x64420526,0x7bd6af1a,0x14c800d1}},	//   río_, tvoi, _kuyu, نهای_,
   {{0x673cb942,0x6442b943,0x7522b944,0x38690027}},	//   _tarj, uvoi, rfoz, cyar_,
   {{0x6442b945,0x3940b946,0x7bd6b947,0x59be04aa}},	//   rvoi, ldis_, _muyu, ्दकर,
   {{0xa3d42fa9,0xe7d800b4,0x6560b948,0x644200c3}},	//   _सूर_, _भूतप, _tomh, svoi,
   {{0x3940b38f,0xdced66ac,0x20020888,0x7d04b949}},	//   ndis_, _plač, škim_, _ndis,
   {{0xa2e60036,0x0443b94a,0x63740310,0x1f741172}},	//   _бозд, _летн, _cànc, илия,
   {{0x7d04b94b,0x25a60553,0xdced219c,0x851407b5}},	//   _adis, lool_, _vlač, _डाँट_,
   {{0x2b1b4407,0x201f0023,0x4aa40864,0x00000000}},	//   _बाबु_, atui_, _खुलव, --,
   {{0x7bd66303,0xdced053d,0x386910b1,0x7d0400f7}},	//   _buyu, _tlač, yyar_, _cdis,
   {{0x3940b94c,0x7d04248b,0x3a3a0036,0x6018b7fb}},	//   ddis_, _ddis, _aspp_, _роля_,
   {{0x25a6483a,0x200b0038,0x7bd6008f,0xa3c90826}},	//   hool_, ácie_, _duyu, ोदय_,
   {{0x25a6b94d,0x35d90084,0xb87b0279,0x333e01f7}},	//   kool_, _बूढ़, _ofíc, _matx_,
   {{0x7d00003e,0x79a705a1,0x00000000,0x00000000}},	//   ómst, урге, --, --,
   {{0x2d8bb94e,0x7bd68ec9,0x636f008c,0xdce40124}},	// [dcf0] mice_, _guyu, _bønl, _slić,
   {{0x213fb94f,0x70d125de,0x7c2db950,0x386903d0}},	//   zduh_, _हल्ल, _ipar, ryar_,
   {{0x6dbc006a,0x3869046a,0xa2a40387,0x5a470144}},	//   _właś, syar_, _चुल्, _сэпа,
   {{0x8af801c2,0x7bd6b951,0x4a5a0122,0x00000000}},	//   _şəxs, _yuyu, _סדרו, --,
   {{0x78fa0052,0x68edb952,0x333e1442,0xbcfb00b5}},	//   _בפרו, mbad, _batx_, lkés,
   {{0x27e92b5d,0x68edb953,0x2d8b4776,0x7c2db954}},	//   mpan_, lbad, hice_, _mpar,
   {{0x2d8bb955,0xe0d1004f,0xe4e71958,0x27e9b956}},	//   kice_, يزة_, _бізн, lpan_,
   {{0x2d8b1851,0x7c2db957,0x25a6b958,0x68edb959}},	//   jice_, _opar, cool_, nbad,
   {{0x2d8bb95a,0x316d4f0f,0x26110084,0x27e936de}},	//   dice_, rkez_, दूरी_, npan_,
   {{0x201f057a,0x5f0500ed,0x316d0009,0x644905b9}},	//   rtui_, јзна, skez_, _irei,
   {{0x201fb95b,0x6449008a,0x2d8bb95c,0x7bd6494f}},	//   stui_, _hrei, fice_, _suyu,
   {{0x2d8bb95d,0x6da6b95e,0x7bd60feb,0x3a3a027a}},	//   gice_, рима, _puyu, _rspp_,
   {{0x68ed1789,0x69d700a2,0x7bd6013b,0x7529b95f}},	//   dbad, _auxe, _quyu, _mbez,
   {{0x442db960,0x27e90008,0xdee51c89,0x2d8bb961}},	//   _mpe_, dpan_, _токи, éber_,
   {{0x75292f3b,0x7c2db962,0x2d8b0690,0xfce60714}},	//   _obez, _epar, bice_, _койо,
   {{0xac760088,0x442d23c2,0x6449b963,0x7bd60159}},	//   _ناخش, _ope_, _orei, _tuyu,
   {{0x69cf6870,0x68435ae7,0x3940b964,0x442d01a9}},	// [dd00] _dice, онта, rdis_, _npe_,
   {{0x68edb965,0x3940043d,0x25a63f07,0x69d701ef}},	//   abad, sdis_, wool_, _fuxe,
   {{0x7afcb966,0x442db967,0x68edb968,0x27e9128f}},	//   mart, _ape_, bbad, apan_,
   {{0x6449b969,0x7afcb96a,0xd9461159,0x39408f53}},	//   _brei, lart, _теми, qdis_,
   {{0x6449b96b,0x69c4b96c,0x25a6007c,0x00000000}},	//   _crei, mmie, rool_, --,
   {{0x6449b96d,0x200db96e,0x2d8bb96f,0x69c47fc8}},	//   _drei, drei_, zice_, lmie,
   {{0x63740014,0x6449b970,0x442db971,0x69dc00a8}},	//   _càna, _erei, _epe_, nqre,
   {{0x6449b972,0x7afcb973,0x29dcb974,0x59c604bc}},	//   _frei, hart, _mía_, लगिर,
   {{0x6449b975,0x7afcb976,0x2d8bb977,0xdb1720d9}},	//   _grei, kart, vice_, _xixó,
   {{0x3f6602c4,0x2d8baa91,0x7afcb978,0x69c4b979}},	//   ртиб, wice_, jart, hmie,
   {{0x2d8bb97a,0x7afcb97b,0x7c2d4f7e,0x3eb80533}},	//   tice_, dart, _spar, årt_,
   {{0x7af7478a,0x7c2d0024,0x200db97c,0x61ea6340}},	//   _sext, _ppar, brei_, mpfl,
   {{0x2d8bb97d,0x69cf0021,0x69c40038,0x69d70391}},	//   rice_, _rice, dmie, _suxe,
   {{0x7afcb97e,0x69cf108a,0x69d70391,0xc90f0035}},	//   gart, _sice, _puxe, िल्म_,
   {{0x69cfb97f,0xd90f064e,0x3f8c01b7,0x61ea033b}},	//   _pice, وید_, midu_, npfl,
   {{0x29dc1166,0x3f8cb980,0x69d7013c,0x6da40088}},	//   _día_, lidu_, _vuxe, _وموم,
   {{0x7afc92a1,0x98b91334,0x61ed0207,0x00000000}},	// [dd10] bart, улат_, ćali, --,
   {{0x68edb981,0x69c4b982,0x3f8c0065,0x29dc01ef}},	//   sbad, amie, nidu_, _fía_,
   {{0x27e9b983,0x200202dd,0xd6d81018,0x69cf4f7d}},	//   span_, ških_, рту_, _tice,
   {{0x6449b984,0x27e9b985,0x1959010b,0xd1260037}},	//   _prei, ppan_, _самы_, _عم_,
   {{0x798d76c6,0x1dd0007c,0x3f8c00cd,0xf95600a5}},	//   miaw, _संघत, kidu_, _הסרת_,
   {{0xe2996c07,0x200d0382,0x083a02b5,0x798d0118}},	//   лал_, vrei_, _געשל, liaw,
   {{0x644900e9,0x2d8900e0,0x3f8c023c,0x00000000}},	//   _wrei, _omae_, didu_, --,
   {{0x7afcb986,0x7529004e,0x200d145c,0x442d000d}},	//   zart, _ubez, trei_, _tpe_,
   {{0x449901c8,0x25ad003c,0x944500b5,0x00000000}},	//   _сваю_, _ikel_, _دھان, --,
   {{0x200db987,0x02a738ea,0x6374009e,0x69c4b988}},	//   rrei_, _крем, _tàna, zmie,
   {{0x798d0ec0,0x69c4b989,0xbea59e5f,0x636f0a8a}},	//   kiaw, ymie, санк, _lønk,
   {{0x7afcb98a,0xbc1a0409,0x29dc27c2,0x200db98b}},	//   wart, лігі_, _ría_, prei_,
   {{0x7afcb98c,0x3f8c361c,0xdd12035f,0xbcfb00b5}},	//   tart, bidu_, _iżżi, tkér,
   {{0x69d800b5,0x29dc213c,0x79960035,0x3d1a52cf}},	//   _évek, _pía_, wnyw, _भावे_,
   {{0x7afc00a1,0xf2d202b5,0x5f7401b2,0x3eaa0187}},	//   rart, לעם_, _ظاهر, čité_,
   {{0x29dc0f56,0xe80307ba,0x249f021d,0x00000000}},	//   _vía_, _लिखा_, _oxum_, --,
   {{0xa92800fe,0xab9a00f8,0x00000000,0x00000000}},	// [dd20] _adžá, _مخدر_, --, --,
   {{0x7afc0031,0x69c4b98d,0x29dcb98e,0x25bf01b7}},	//   qart, smie, _tía_, _ahul_,
   {{0x671e19b7,0xf1ca112b,0x7d770647,0x00000000}},	//   _पाठक_, ागमन, _ضمیر_, --,
   {{0x89361d05,0x25bfb98f,0x3f8cb990,0x61fc0249}},	//   _اعدا, _chul_, zidu_, _ærli,
   {{0x2458365f,0x2365108a,0x25bfb991,0xd5af0bdf}},	//   раль_, _bolj_, _dhul_, رفه_,
   {{0x98a200d8,0xeb9f01b4,0x5f1c04bc,0xdb072e62}},	//   _sakė_, rsøg_, _माध्_, vojë,
   {{0x3f8c5de5,0x39420006,0x236500af,0xbcfb00b5}},	//   vidu_, _kaks_, _dolj_, kkép,
   {{0xf5960082,0x7a430332,0x61ea01ae,0x2ca0b992}},	//   _الرج, lítá, rpfl, _oxid_,
   {{0xdefa0409,0xd1190380,0xeb9f008c,0x61ea033b}},	//   лын_, _धारण_, lsøe_, spfl,
   {{0x200bb993,0x741314ac,0x3942b994,0x7a4300b5}},	//   ácia_, _روما, _laks_, nítá,
   {{0x3f8c035f,0x59a8021a,0x00000000,0x00000000}},	//   ridu_, ककार, --, --,
   {{0x3f8cb995,0xa1c60665,0x39421fac,0x5fba0456}},	//   sidu_, _убед, _naks_, _उठवल,
   {{0x39a100d8,0xb87b0042,0x7a4300b5,0x3f8cb996}},	//   nėse_, _afín, kítá, pidu_,
   {{0xab840969,0xa0070037,0x7a4300b5,0x2ff700af}},	//   пуск, _اقول_, jítá, _уншь_,
   {{0x42db0070,0x7de602de,0x798d10cd,0x39420051}},	//   רקלע, _استم, tiaw, _baks_,
   {{0x996400af,0x00000000,0x00000000,0x00000000}},	//   птул, --, --, --,
   {{0xa3d40f39,0x798db997,0x6d9602c4,0xc6f9b998}},	// [dd30] _संग_, riaw, fšaf, инах_,
   {{0x25bf009e,0x798d05f8,0x2d99011e,0xfb1500f8}},	//   _shul_, siaw, lnse_, _بودج,
   {{0x58d528a1,0x798d20fb,0xf7700037,0xb635017e}},	//   _монт, piaw, راك_, تفاع,
   {{0x2d99006b,0x00000000,0x00000000,0x00000000}},	//   nnse_, --, --, --,
   {{0x68ff0095,0x2d99b999,0x63740392,0x637d0118}},	//   maqd, inse_, _càno, _jèng,
   {{0x63aa001e,0xc5fb0b82,0x637d00e0,0x00000000}},	//   gofn, _معرض_, _mèng, --,
   {{0xdb1e00da,0xe3b00037,0x00000000,0x00000000}},	//   _shpë, رره_, --, --,
   {{0x212b3255,0x3fe515dd,0x249f006d,0x6009b99a}},	//   ých_, ожив, _txum_, аним_,
   {{0x7767006d,0x636f0a8a,0x44396049,0x23650207}},	//   _kojx, _løni, _ès_, _tolj_,
   {{0x443f402d,0x939700bf,0x2d992127,0xa2a47d61}},	//   _isu_, _اجرا, ense_, _चुक्,
   {{0x3eb9004e,0x3f9c0088,0x636f008c,0x00000000}},	//   ęsto_, _djvu_, _rønh, --,
   {{0x443f0024,0x3cca1761,0x69d80640,0xa2c607df}},	//   _ksu_, илно_, _évei, ाधर्,
   {{0xbcfb006c,0x443f01ef,0x7a4300b5,0x7600007e}},	//   rkép, _jsu_, yítá, _kázá,
   {{0x2d99b99b,0x3942553b,0x7ae5009f,0xdb0e0176}},	//   anse_, _saks_, _cfht, embò,
   {{0xaa432901,0x7a4300b5,0x7f436a8c,0x09e30a80}},	//   мерл, vítá, _ianq, досн,
   {{0x28ea0009,0x00000000,0x00000000,0x00000000}},	//   рдап_, --, --, --,
   {{0x6d560232,0x6d4400d7,0xa7662d7a,0x39420044}},	// [dd40] _inya, _iaia, окад, _vaks_,
   {{0x6d56006f,0x47c300d4,0xaade0e3b,0xeab20037}},	//   _hnya, дбув, _मलिक, _يعد_,
   {{0x7f4302e1,0x7c262ba1,0x443fb99c,0x394202d0}},	//   _manq, ltkr, _asu_, _taks_,
   {{0x7a430332,0x6d4406a2,0x68ff0095,0x7f43003c}},	//   sítá, _jaia, caqd, _lanq,
   {{0x6d440291,0x2900b99d,0x6d560054,0xa3d40066}},	//   _maia, maia_, _mnya, _सूख_,
   {{0x29003305,0x6d4400ab,0x31660176,0x443f008c}},	//   laia_, _laia, _sooz_, _dsu_,
   {{0x443f00d8,0x6d56b99e,0x26d8008b,0x7607002d}},	//   _esu_, _onya, _igro_, _мерг_,
   {{0x2900b99f,0x6d44b9a0,0x443f44c8,0x6d5601a8}},	//   naia_, _naia, _fsu_, _nnya,
   {{0x7f43b9a1,0x31660132,0x98b90395,0x27e0013b}},	//   _banq, _vooz_, _iasă_, nqin_,
   {{0x4426b9a2,0x6440b9a3,0x6d560357,0x543b00c2}},	//   mto_, _ismi, _anya, _דעמא,
   {{0x442618e0,0x6d44453e,0x290003d0,0x00e65b55}},	//   lto_, _baia, kaia_, _джен,
   {{0x6562b9a4,0x4426b9a5,0x6d44b9a6,0x2d99027a}},	//   njoh, oto_, _caia, unse_,
   {{0x4426b9a7,0x290001d7,0x98b900af,0x26d8014c}},	//   nto_, daia_, _masă_, _ogro_,
   {{0x4426478a,0x6d46b9a8,0xf41300a5,0x6d561138}},	//   ito_, adka, ופש_, _enya,
   {{0x442637cf,0x6d44b9a9,0x2900b9aa,0x99672344}},	//   hto_, _faia, faia_, отал,
   {{0x4426b9ab,0x26d8b9ac,0x64400e46,0x6d4406a2}},	//   kto_, _agro_, _osmi, _gaia,
   {{0xd6db7cd2,0x44260038,0x47d5004f,0xe87c0463}},	// [dd50] ате_, jto_, سيار, rüşü,
   {{0x4426b9ad,0x27e60037,0xcb6803fa,0x7d1d06d6}},	//   dto_, íona_, _мање_, lgss,
   {{0x69da006c,0xbb3a00a5,0x95cb005f,0x29003815}},	//   ítet, _העתי, ауда_, baia_,
   {{0x7d1db9ae,0x68e4b9af,0x4426b9b0,0xdcef0029}},	//   ngss, ccid, fto_, dicī,
   {{0x4426b9b1,0x764e0297,0x38c903fc,0x78bd00ea}},	//   gto_, _erby, _دادی_, _uzsv,
   {{0x9342a04e,0x00000000,0x00000000,0x00000000}},	//   енше, --, --, --,
   {{0x44260133,0x68fd1719,0x443f79dc,0x6440b9b2}},	//   ato_, _kesd, _wsu_, _esmi,
   {{0x4426b9b3,0x443f006d,0xf6520122,0x68fd011e}},	//   bto_, _tsu_, _אצל_, _jesd,
   {{0x44261175,0xf8b90967,0x443fb9b4,0x68fdb9b5}},	//   cto_, _आरोप, _usu_, _mesd,
   {{0x6d4406a2,0x68fdb9b6,0x657b0296,0x7f439beb}},	//   _saia, _lesd, _hluh, _qanq,
   {{0x2f5402ce,0x68fd0298,0x660501f4,0x9d46002d}},	//   єтьс, _oesd, nshk, пенд,
   {{0xb2ba0122,0xdca60171,0xd00e0e3a,0x6605005f}},	//   _המער, зами, خلی_, ishk,
   {{0xe6b80f17,0x6d441945,0x65695aa0,0x16b800a9}},	//   _अर्ज, _vaia, _moeh, _अर्ब,
   {{0x6d44023c,0x7c261d89,0x62830121,0x29000103}},	//   _waia, rtkr, ozno, waia_,
   {{0xa3d41bb5,0x6d440fa7,0x637d671c,0x29008b47}},	//   _संघ_, _taia, _gène, taia_,
   {{0xb87b181f,0x6d56951f,0x4426b9b7,0xd7f20037}},	//   _efím, _unya, yto_, فكر_,
   {{0x68fd12d1,0x44261423,0x68e4b9b8,0x2900b9b9}},	// [dd60] _desd, xto_, rcid, raia_,
   {{0x68e4b9ba,0x6f0103c9,0x290001d7,0x442602a7}},	//   scid, nalc, saia_, vto_,
   {{0x4426b9bb,0x7c6500f8,0x657b0069,0x98b90395}},	//   wto_, _فایل, _bluh, _pasă_,
   {{0x44260a1f,0xe45a00d4,0x6f010160,0x44240118}},	//   tto_, йже_, halc, _pqm_,
   {{0x6f01219c,0x69deb9bc,0x7afe00c7,0xe8d7011d}},	//   kalc, _hupe, _kept, _מוכר_,
   {{0x69deb9bd,0x6f0102c6,0x7afe0031,0x657b641e}},	//   _kupe, jalc, _jept, _eluh,
   {{0x877b00c2,0xdb1e28e4,0x6f010693,0x69deb9be}},	//   _פאלי, _hipó, dalc, _jupe,
   {{0x7afeb9bf,0x154303fa,0x657b2163,0x69de41a6}},	//   _lept, _песм, _gluh, _mupe,
   {{0x6440a74c,0x60f700d8,0xe5a30043,0x6f01b9c0}},	//   _usmi, чныя_, _чити, falc,
   {{0x438603c7,0x324632c9,0x38600176,0x69be0387}},	//   _علاق, _незг, ixir_, _वीसी,
   {{0x6283004e,0x69deb9c1,0xe8b90569,0x00000000}},	//   czno, _nupe, _आर्च, --,
   {{0x06970052,0x16140026,0xc8be00b4,0xdced00f4}},	//   לדים_, _डिनर_, ्धाट, _mlać,
   {{0x69de0211,0x0cab01d3,0x68fdb9c2,0xdb1e0138}},	//   _aupe, стни_, _resd, _nipó,
   {{0x9a87140e,0x6f01b9c3,0x7f584cf3,0x200200d8}},	//   публ, calc, _факс_, škis_,
   {{0x27e60514,0x69de16f4,0x7afe00a5,0x3f8e007b}},	//   íonn_, _cupe, _dept, _imfu_,
   {{0x69deb9c4,0x31970043,0x3da400d8,0x00000000}},	//   _dupe, tăzi_, _прыб, --,
   {{0x52d00083,0x69da1d2b,0xa3cc0a44,0x69de0051}},	// [dd70] _স্মৃ, íter, रगा_, _eupe,
   {{0xd6db04b2,0x65690099,0xb8830187,0xdced0124}},	//   ста_, _soeh, vníč, _blać,
   {{0x7bdf0be2,0xcb1202b8,0x68fd05dd,0x65690107}},	//   _huqu, _בלי_, _tesd, _poeh,
   {{0x660500da,0x7afe01c0,0x636f0b3e,0x27eb00cc}},	//   rshk, _zept, _lønt, _ttcn_,
   {{0x7d0d91da,0xd00615f4,0x39590279,0x69de0035}},	//   _mdas, _جل_, _inss_, _zupe,
   {{0x8c1c02b8,0xdb1e0310,0x7bdfb9c5,0xdc3d00d5}},	//   מודי, _hipò, _muqu, _náčr,
   {{0xc5950202,0x6f01108a,0x7d0d01d6,0x3949b9c6}},	//   _живј, valc, _odas, odas_,
   {{0x7d0db9c7,0x657b327c,0x6f010067,0x00000000}},	//   _ndas, _uluh, walc, --,
   {{0x6f01b9c8,0x6283006c,0x3949b9c9,0x7bdf00a2}},	//   talc, szno, idas_, _nuqu,
   {{0x8e0951be,0x7d0db9ca,0xdb1e0176,0xdb1c0075}},	//   онов_, _adas, _lipò, områ,
   {{0x6da60948,0x7afe798b,0x63a40aaa,0x6f01b9cb}},	//   дина, _rept, éine, ralc,
   {{0xcb0935d9,0x7bdfb9cc,0x69deb9cd,0x823409b9}},	//   _כל_, _buqu, _rupe, _سرما,
   {{0x7bdf0176,0x3949b9ce,0x7afe5d8c,0x636f0a8a}},	//   _cuqu, ddas_, _pept, _fønt,
   {{0x7d0d0006,0x3949b9cf,0x7bdf897e,0x69de104a}},	//   _edas, edas_, _duqu, _pupe,
   {{0x636f1f8b,0x00000000,0x00000000,0x00000000}},	//   _høns, --, --, --,
   {{0x7bd70392,0x636f08c8,0x00000000,0x00000000}},	//   _eixu, _køns, --, --,
   {{0xdb1e0443,0x636f0a8a,0xb95b00e2,0x00000000}},	// [dd80] _dipò, _jøns, _thìn, --,
   {{0xdced0a78,0x3946123c,0x636f10db,0x386001ef}},	//   _plać, žos_, _møns, rxir_,
   {{0x2b5a021d,0x636f01cf,0x00000000,0x00000000}},	//   _inpc_, _løns, --, --,
   {{0xdb1e01ef,0xa3e200b4,0xe3af3c96,0x00000000}},	//   _tipó, _नंद_, یرو_, --,
   {{0xd4670274,0xeaaf00b5,0x88350043,0x00000000}},	//   мице_, _مٹی_, _пэрц, --,
   {{0x533304bf,0x28a722a7,0x68f6054e,0x7bd701ed}},	//   вешт, _कुटि, lbyd, _xixu,
   {{0x28be021a,0xd25021a0,0x636f0b3e,0x69d800fd}},	//   ्धवि, انب_, _rønt, _éves,
   {{0x3d1a0722,0x071e0722,0x63740392,0x636f008c}},	//   _भागे_, _पाँव_, _màni, _bøns,
   {{0x63740392,0x00000000,0x00000000,0x00000000}},	//   _làni, --, --, --,
   {{0x3a2a00d7,0x3e4c00b8,0x7bdfb9d0,0x3949010b}},	//   ktbp_, _pět_, _ruqu, zdas_,
   {{0x4e8a00c3,0x7bdf0176,0x7c3600c7,0x394900c7}},	//   ющим_, _suqu, _apyr, ydas_,
   {{0x2b5a0395,0xdb070355,0x636f008c,0x00000000}},	//   _anpc_, rojí, _føns, --,
   {{0x071e0084,0x3da400d8,0x321c0334,0x7bc50159}},	//   _पांव_, трэб, luvy_, _phhu,
   {{0xdb1e02d0,0x2b5a0183,0x60c27489,0xdb070097}},	//   _sipò, _cnpc_, _izom, pojí,
   {{0x7bdf012f,0xdb1e0107,0x00000000,0x00000000}},	//   _wuqu, _pipò, --, --,
   {{0xf77000bf,0x7bdf1684,0x7d0d01d5,0xbda70037}},	//   یال_, _tuqu, _udas, _تحتو,
   {{0xb9070299,0xe89403ad,0x39491bda,0xb4cd00e7}},	// [dd90] _पल_, вать, rdas_, _रणे_,
   {{0x3949b9d1,0xbc3811c0,0x636f0a8a,0x2a6e0055}},	//   sdas_, _آسيا_, _lønr, ëmbë_,
   {{0xb8d60b35,0xaa950043,0x394905b6,0x3f9e5f47}},	//   _चु_, _чинч, pdas_, intu_,
   {{0xcdd90070,0x2a7600a5,0xb6070069,0x7dde013a}},	//   פֿער, _נערך_, _ruġġ, _cīsi,
   {{0xc9160122,0xb6070484,0x69cdb9d2,0xf8c3021a}},	//   _אחרת_, _suġġ, mmae, _शरिय,
   {{0x637d0260,0xcc7800a5,0x24521c64,0x59bf02b4}},	//   _bèna, ועדה_, انوس, ्षवर,
   {{0x6d1f0437,0xd66902e7,0xf527757c,0x60c2023c}},	//   _भांग_, _عمرو_, _офан, _azom,
   {{0x3f9e1715,0x7dde00ea,0x69cd016e,0x636f008c}},	//   entu_, _mūsd, nmae, _pøns,
   {{0x4f9500aa,0xd00e0698,0xf1df00be,0x659441bf}},	//   ерну, ملي_, _पूरन, _рату,
   {{0x9e6534d4,0x6b950207,0xd3d800f8,0x00000000}},	//   евод, jizg, _قبلا_, --,
   {{0x7c36b9d3,0xa3cc0084,0xc7b200a5,0x60c2030d}},	//   _spyr, रगर_, רבי_, _ezom,
   {{0xf2df00e8,0x81450088,0xf67a0070,0x636f0185}},	//   _đây_, _سپتم, פארמ, _tøns,
   {{0x61e11e4f,0x636f1923,0x00000000,0x00000000}},	//   _hull, _uøns, --, --,
   {{0x61e108a1,0x69c601d2,0xa51c06fe,0x2d8201f4}},	//   _kull, _shke, _पञ्च_, shke_,
   {{0x61e136bf,0xfaa3010b,0x24860207,0xfbc30279}},	//   _jull, гаро, zzom_, убро,
   {{0x61e1b9d4,0xe9d70192,0xa967538c,0x98a00207}},	//   _mull, екс_, ниса_, nfić_,
   {{0x7d06b9d5,0x68f6b9d6,0x2d80002d,0x02cb175f}},	// [dda0] maks, rbyd, _ilie_, ाधुन,
   {{0x7d063ca2,0x4a4601e0,0xee4900e2,0x61e100f6}},	//   laks, _знов, _kẽ_, _oull,
   {{0x61e1b9d7,0x2d800069,0x00000000,0x00000000}},	//   _null, _klie_, --, --,
   {{0xee490019,0x84e60823,0xdb0e0097,0x09e70033}},	//   _mẽ_, ходж, dobé, _ফিচা,
   {{0xee4901a5,0xf9f20033,0x61e18fba,0xe660013b}},	//   _lẽ_, _জটিল_, _aull, ırığ,
   {{0x7d06b9d8,0x61e13860,0x2486389c,0x8c1b00a5}},	//   haks, _bull, rzom_, פוצי,
   {{0x60c2006c,0x2d80b9d9,0x07a303d0,0xdbc700ab}},	//   _szom, _olie_, _сарн, _tööj,
   {{0x61e1b9da,0x7d062311,0x65795868,0xd65700a5}},	//   _dull, jaks, ckwh, _אילת_,
   {{0x64a360f8,0x7d06b37e,0x661e84db,0x321c00d5}},	//   _бата, daks, lupk, suvy_,
   {{0x61e1b9db,0x75220332,0x2902b9dc,0x2fd80093}},	//   _full, lgoz, _leka_, örg_,
   {{0x61e12cf7,0x3eb876e6,0x9d192349,0xe0da03e6}},	//   _gull, ært_, монт_, _еве_,
   {{0x752219c6,0x29022802,0xc27b32e3,0x673e0223}},	//   ngoz, _neka_, _מרבי, hepj,
   {{0x61e10a75,0x7984000e,0x802600ff,0x00000000}},	//   _zull, dhiw, _سرشم, --,
   {{0x2d80b9dd,0x5f940009,0x26ea0067,0x00000000}},	//   _elie_, _шилт, टडोर_, --,
   {{0x61e1043f,0x6d960029,0xba7708cf,0x6b9518b0}},	//   _xull, mšan, راست, rizg,
   {{0xdd910357,0x661e0ec0,0x2902589f,0xf77300d1}},	//   _خوب_, dupk, _ceka_, گار_,
   {{0x69cd3a92,0x3dc908dd,0x6934002d,0x00000000}},	// [ddb0] rmae, _ihaw_, ынту, --,
   {{0xf7732087,0x200b01ba,0x6da4011c,0x673800ac}},	//   دار_, ácii_, nđan, _čají,
   {{0xcf9302b5,0x3dc901e8,0x57a40166,0x00000000}},	//   נטע_, _khaw_, ушта, --,
   {{0x79849070,0x61e10557,0x00000000,0x00000000}},	//   chiw, _rull, --, --,
   {{0x61e1b9de,0x6d960080,0x04450d30,0xb95410be}},	//   _sull, kšan, телн, _свящ,
   {{0x7d06b9df,0x61e1b9e0,0x6d96008b,0x2902b667}},	//   zaks, _pull, jšan, _zeka_,
   {{0x61e100a8,0x85bb05bc,0x7d0602d0,0x71fa00b5}},	//   _qull, _فارس_, yaks, ورٹس_,
   {{0x20559dfe,0x61e1b9e1,0xee490023,0x6d9635e9}},	//   втор, _vull, _rẽ_, ešan,
   {{0xee4900e8,0x7d060086,0x61e10051,0x7f193c77}},	//   _sẽ_, vaks, _wull, міну_,
   {{0x61e1b9e2,0x7655004e,0x6d9600ea,0x394b439c}},	//   _tull, _krzy, gšan, _lacs_,
   {{0x7d060ccf,0xbea5b9e3,0x9f0400b5,0x2d8000a2}},	//   taks, танк, دوپو, _plie_,
   {{0x3dc901a9,0xee490019,0xed5700d4,0xebe63f6c}},	//   _chaw_, _vẽ_, вою_, комп,
   {{0x7d060ae0,0x2902b9e4,0x59db0387,0x2fc70211}},	//   raks, _reka_, _मंजर, _thng_,
   {{0x290200d1,0x7bce023c,0x00000000,0x00000000}},	//   _seka_, umbu, --, --,
   {{0x7d063f8b,0x7984b9e5,0x7bce01f4,0x394bb9e6}},	//   paks, thiw, rmbu, _bacs_,
   {{0xdb070501,0x6f03024b,0x2d801325,0x00000000}},	//   rojá, _henc, _ulie_, --,
   {{0x2902b9e7,0x1b1700c8,0x6f031034,0xc17200a5}},	// [ddc0] _veka_, দ্ধে_, _kenc, בחן_,
   {{0x7d04b9e8,0x661e545c,0x79840054,0x290224ed}},	//   _heis, tupk, shiw, _weka_,
   {{0x6f03120d,0x7d04256a,0x2902b9e9,0xf7431470}},	//   _menc, _keis, _teka_, рехо,
   {{0x7d0401b7,0x7de100ea,0xd37800f4,0x00000000}},	//   _jeis, _cēsi, _miće_, --,
   {{0x661e012f,0x3940487b,0x765503da,0xa82300b5}},	//   supk, meis_, _erzy, _نکلن,
   {{0x66e611b9,0xf651006c,0x394023c2,0x93b300d8}},	//   _јова, جئے_, leis_, абіц,
   {{0xcb1300a5,0x76550035,0xd24600af,0x00000000}},	//   בלו_, _grzy, тэли, --,
   {{0x7d04708c,0x39400181,0x7de800fe,0xd259010b}},	//   _neis, neis_, _běsn, эці_,
   {{0xf9935c8e,0x637d01f7,0x00000000,0x00000000}},	//   ירה_, _gèno, --, --,
   {{0xd3780a78,0x394001a6,0x7f4a0095,0x637401f7}},	//   _biće_, heis_, _qafq, _cànt,
   {{0x7d0402c9,0x826600bf,0x6d961772,0x539b0d85}},	//   _beis, _جهان, ršan, _קיבו,
   {{0x7d040e0f,0xac1910a9,0x61460202,0x765800c3}},	//   _ceis, ному_, _једа, ävyy,
   {{0x7d04b9ea,0x6d960029,0x39400831,0x6f03b9eb}},	//   _deis, pšan, deis_, _fenc,
   {{0x6f03b9ec,0x394b00f7,0x7dde00ea,0xd3780207}},	//   _genc, _sacs_, _bīst, _fiće_,
   {{0x9e3403ad,0x2d990e8c,0x2e4a02fb,0x7d0410a7}},	//   _сейч, éres_, _цяло_, _feis,
   {{0x7d042a2c,0x3dc908dd,0x6d960207,0x6f03b9ed}},	//   _geis, _uhaw_, nšal, _zenc,
   {{0x2d990ccf,0x6d5f003c,0x0855325e,0x00000000}},	// [ddd0] mise_, _inqa, ываю, --,
   {{0x76550755,0x25cb0964,0x9f4d0132,0x2d99b9ee}},	//   _przy, िष्ण, mpeã_, lise_,
   {{0x39400caa,0x213f022e,0x2d99b9ef,0x6d96011c}},	//   beis_, yeuh_, oise_, kšal,
   {{0x2d99b9f0,0xa97902b5,0x3940b9f1,0x6f0800fe}},	//   nise_, _נאָכ, ceis_, hadc,
   {{0x7c2f0118,0x68ed0207,0x7c2d0024,0xd91a32e3}},	//   ntcr, mcad, _jqar, _אורל,
   {{0x2d99b9f2,0x69dd0310,0x7655004e,0xd37b0043}},	//   hise_, _hise, _trzy, ьче_,
   {{0x69dd99b8,0x6f03b9f3,0xdb07008a,0x2d99b9f4}},	//   _kise, _renc, lljó, kise_,
   {{0x6f03b9f5,0xb1450043,0x5274b9f6,0x2d990055}},	//   _senc, унил, рушу, jise_,
   {{0x6f03b9f7,0x7d04b9f8,0x2d99b9f9,0x213f012f}},	//   _penc, _reis, dise_, reuh_,
   {{0x7d04b9fa,0x69ddb9fb,0x6d5f003c,0xd378044d}},	//   _seis, _lise, _anqa, _piće_,
   {{0x6f03061b,0x69ddb9fc,0x7d04b9fd,0x2d99b9fe}},	//   _venc, _oise, _peis, fise_,
   {{0x69ddb9ff,0x63ad004f,0x7de800b8,0x2d99018d}},	//   _nise, éanf, _těsn, gise_,
   {{0x39400b62,0x7d04ba00,0x6f03ba01,0x637d02d0}},	//   veis_, _veis, _tenc, _lènm,
   {{0x7d0402c9,0x69dd0094,0x200b01ba,0x2d99ba02}},	//   _weis, _aise, áciu_, érer_,
   {{0x7d04ba03,0x69ddba04,0x81e50083,0x2d99ba05}},	//   _teis, _bise, বীর_, bise_,
   {{0x2d99ba06,0x69dd102c,0x200d022e,0xd24f00d8}},	//   cise_, _cise, osei_, сцi_,
   {{0x69dd0ce8,0x3940ba07,0x200dba08,0x442d0189}},	// [dde0] _dise, reis_, nsei_, _nqe_,
   {{0x69ddba09,0x68ed006b,0x3940ba0a,0x9bfb00a5}},	//   _eise, acad, seis_, _רהיט,
   {{0x39400b9f,0x7bde0159,0x69ddba0b,0x4b7b0070}},	//   peis_, _iipu, _fise, _נאטו,
   {{0x69dd10a2,0xc4860086,0x240aafeb,0x1a9b02b5}},	//   _gise, ллек, енди_, _טייע,
   {{0x7bde5cc8,0x7f410031,0x6e21ba0c,0xf8b80066}},	//   _kipu, kelq, hulb, _आडिय,
   {{0x66e338a6,0x987b0070,0x2d99ba0d,0x69ddba0e}},	//   _гора, _טאכט, zise_, _zise,
   {{0x442f011e,0x2d990651,0x63740284,0xe7ea0066}},	//   atg_, yise_, _bànr, _झंडा_,
   {{0x7bdeba0f,0x637d0107,0xdb0e0097,0x301409cc}},	//   _lipu, _jènj, dobí, адир,
   {{0x6d969c6b,0x65600037,0x2d99521d,0x442d0103}},	//   ršal, _inmh, vise_, _gqe_,
   {{0x2d99ba10,0x0f1e0066,0x7bde4f63,0x1e3400d8}},	//   wise_, पलेस_, _nipu, аноў,
   {{0x2d99ba11,0x7c2d01f4,0x6d960293,0x6f080f86}},	//   tise_, _sqar, pšal, radc,
   {{0x6d960009,0x7bde01b7,0x00000000,0x00000000}},	//   lšaj, _aipu, --, --,
   {{0x2d99ba12,0x69ddba13,0x7bde0074,0x7dde005f}},	//   rise_, _rise, _bipu, _dūsa,
   {{0x09bf0d53,0x69dd0006,0x2d99ba14,0xdfd000ad}},	//   ्ष्य, _sise, sise_, _بيت_,
   {{0xf0b000f5,0x69ddba15,0x7bde1d86,0x68ed0223}},	//   _دیکھ, _pise, _dipu, tcad,
   {{0xd5a4006c,0x2d990031,0x27e91505,0x68ed01ef}},	//   _رہ_, qise_, tqan_, ucad,
   {{0x69ddba16,0xb87b002a,0x6d962acc,0x5d840698}},	// [ddf0] _vise, _afír, kšaj, _دليل,
   {{0x68edba17,0xe8ff02e1,0x7bdeba18,0x78bd024e}},	//   scad, _août_, _gipu, _vysv,
   {{0xdced011c,0xa9350036,0x78bd0298,0x00000000}},	//   _hlađ, _кенш, _wysv, --,
   {{0x13dd00b4,0xe8ff0248,0xdced012e,0x5455ba19}},	//   मद्भ, _coût_, _klađ, ивет,
   {{0x23294717,0xb4e50066,0x8899016b,0x00000000}},	//   воли_, _नली_, _סבֿי, --,
   {{0xdced0a78,0xe2992ab4,0x22151457,0x00000000}},	//   _mlađ, кал_, афир, --,
   {{0x442fba1a,0x45d500c3,0x00000000,0x00000000}},	//   stg_, _вовс, --, --,
   {{0x200d007c,0x6449ba1b,0xe8ff00f7,0xc692011d}},	//   tsei_, _tsei, _goût_, _ואל_,
   {{0x644903ad,0x6006010b,0x914803fa,0x39a1010b}},	//   _usei, аным_, учја_, gėsi_,
   {{0x386961b1,0x200dba1c,0xdfce01cb,0x00000000}},	//   ixar_, rsei_, ويي_, --,
   {{0x7bdeba1d,0x200d0279,0x8d661583,0x02a70610}},	//   _ripu, ssei_, авне, _срам,
   {{0x7bdeba1e,0x00000000,0x00000000,0x00000000}},	//   _sipu, --, --, --,
   {{0x0c2307b4,0x6e211b82,0xa928007e,0x00000000}},	//   омян, sulb, _ležá, --,
   {{0x6a860384,0x316d042a,0xc3320070,0xd37800f4}},	//   алга, ljez_, ֿון_, _kića_,
   {{0xcb6700af,0x7bde14dc,0xf8bf00f6,0x6996179c}},	//   шаре_, _vipu, _ayé_, арах,
   {{0xd37800cd,0x317f01ed,0xe9df0312,0x00000000}},	//   _mića_, nkuz_, _ciú_, --,
   {{0x7bdeba1f,0x8c46093c,0xdced00cd,0xe9d71783}},	// [de00] _tipu, _тепе, _glađ, ркт_,
   {{0x6abe0051,0xf77f69d3,0xdced0024,0x00000000}},	//   _typf, _puça_, _imaġ, --,
   {{0xe9df2e36,0xdd8f00bf,0x81ab0033,0x7d160355}},	//   _fiú_, _روی_, _গঠন_, _kdys,
   {{0x2bb40f19,0x26170084,0x63740392,0x2bb60067}},	//   ंकवा, _पटरी_, _rànq, ृतवा,
   {{0x93467598,0xd4031583,0x64a605c7,0x25e6021a}},	//   инде, оящи, шада, _जूरी_,
   {{0xd3780254,0xae0602b4,0xd3b701e0,0x00000000}},	//   _bića_, वीडन_, алії_, --,
   {{0xe81e0035,0x6da402c4,0x6d96011c,0xcb1300a5}},	//   यंका_, rđaj, ršaj, קלה_,
   {{0x3952ba20,0x26ca0207,0x00000000,0x00000000}},	//   ndys_, _izbo_, --, --,
   {{0x6d961bd8,0x00000000,0x00000000,0x00000000}},	//   pšaj, --, --, --,
   {{0x1be1074f,0xd3780009,0x7d160090,0x303901cb}},	//   _गूगल_, _fića_, _adys, اتيک_,
   {{0x63b86367,0xdceb74a6,0xdced011c,0x6b9cba21}},	//   movn, šiča, _slađ, dirg,
   {{0x63b8067b,0x25a60297,0xed65013b,0xc27b00a5}},	//   lovn, nnol_, _şöbə_, _שראי,
   {{0x7d16001e,0x8fa60c95,0x637d0118,0x61e8ba22}},	//   _ddys, _каде, _bènh, _hudl,
   {{0x63b8ba23,0x2cad048c,0x25a60009,0x7d1641dc}},	//   novn, ħed_, hnol_, _edys,
   {{0xb3450370,0x224cba24,0xda7802fb,0x0907a1ab}},	//   leçã, _jsdk_, аят_, ичам,
   {{0x63b80a0b,0x7de10080,0x0b270033,0x996402ee}},	//   hovn, _vēst, য়েল_, отул,
   {{0x63b804c3,0x6b9cba25,0x26c553eb,0xf6e730cc}},	// [de10] kovn, birg, _šlo_, ацен,
   {{0x63b80187,0x25a600e9,0x61e801bf,0x00000000}},	//   jovn, enol_, _oudl, --,
   {{0xd6db0133,0x61e84a7a,0x00000000,0x00000000}},	//   тта_, _nudl, --, --,
   {{0xe94500bf,0x25a6ba26,0x3ed90070,0x6e37016b}},	//   _اردی, gnol_, אַנא, שטאף_,
   {{0xe81e0992,0xb3450279,0xd3780124,0x00000000}},	//   _पिया_, jeçã, _sića_, --,
   {{0x63b8008b,0xe8000066,0xd3780254,0xf1df035d}},	//   govn, _लौटा_, _pića_, _पूजन,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x016500c9,0x61e8ba27,0x6b9c0a21,0x25a60176}},	//   скио, _dudl, zirg, cnol_,
   {{0x63b82e6f,0x637d0176,0x753b04fb,0x7df30160}},	//   bovn, _lèni, _ibuz, _măse,
   {{0x63b8114d,0x23740082,0x443f2971,0x645b01b7}},	//   covn, _والح, _ipu_, _irui,
   {{0x1d0a6c1f,0x61e8ba28,0x69cf02a7,0x00000000}},	//   лени_, _gudl, _ohce, --,
   {{0x645bb5b2,0x443f022e,0xf77f0183,0x22640355}},	//   _krui, _kpu_, _ouço_, ňská_,
   {{0x6b9ca377,0xb3450279,0x753ba6ab,0xf1b93c2c}},	//   tirg, ceçã, _mbuz, moš_,
   {{0xf1b93cd6,0x443fba29,0x69cf02d7,0xdefb00af}},	//   loš_, _mpu_, _ahce, _рыд_,
   {{0x753b01a8,0x25a60297,0xed5a91c8,0x7df30043}},	//   _obuz, ynol_, _бой_, _băse,
   {{0x69cf704a,0xf1b906e2,0x2d8b37fe,0x6b9cba2a}},	//   _chce, noš_, chce_, sirg,
   {{0x8d7604e8,0x1867364f,0xf1df0084,0x443f1a0d}},	// [de20] _ناکا, бати_, _पूछन, _npu_,
   {{0x6d46ba2b,0x4b2676f4,0x753bba2c,0x9b4618dd}},	//   leka, _умов, _abuz, _اندو,
   {{0xe61a48c0,0xd9463f20,0x7c26a7a6,0x443f7305}},	//   уде_, _лени, lukr, _apu_,
   {{0x645bba2d,0x61e800d5,0x7df3002d,0xf1b90009}},	//   _brui, _rudl, _găse, još_,
   {{0x2900ba2e,0x63b86903,0x443f9cd1,0x61e8043d}},	//   mbia_, tovn, _cpu_, _sudl,
   {{0x645bba2f,0x260500a1,0x6d46ba30,0x443f6390}},	//   _drui, हीही_, heka, _dpu_,
   {{0x63b81efc,0x645b01e4,0x6d5a00ea,0x637d0176}},	//   rovn, _erui, ētaj, _xèni,
   {{0x63b802dd,0xb34503e6,0xf1b902c4,0x6d460a78}},	//   sovn, teçã, goš_, jeka,
   {{0x645bba31,0x6d46ba32,0xc9530122,0x63ad00f7}},	//   _grui, deka, למה_, éanc,
   {{0x69c402c9,0xb34503e6,0xb3550987,0x61e80008}},	//   hlie, reçã, _وینا_, _tudl,
   {{0xdceb068b,0xc106017e,0xf1b907fc,0x6d46030d}},	//   žičn, _هواي, boš_, feka,
   {{0x6d46ba33,0xd3780207,0xf1b900f4,0x00000000}},	//   geka, _kićo_, coš_, --,
   {{0x4426b101,0x69c4ba34,0x637d0310,0x00000000}},	//   nuo_, dlie, _sèni, --,
   {{0x69c4ba35,0xd37800cd,0x3e570139,0x60c20371}},	//   elie, _mićo_, _făt_, _iyom,
   {{0x3f9eba36,0x98b00484,0x69c458e7,0x4426002f}},	//   mitu_, _ħaġa_, flie, huo_,
   {{0x69c40133,0x6d46ba37,0x69d6011e,0xdb0eba38}},	//   glie, ceka, gmye, robá,
   {{0x7d0f026b,0x61e25856,0x77990384,0xdb0e00ac}},	// [de30] macs, _miol, акар_, sobá,
   {{0x3f9e6d2e,0x60c20051,0x7d0f00fd,0x61e2ba39}},	//   nitu_, _myom, lacs, _liol,
   {{0x69c4ba3a,0x290002fb,0x443f7733,0x644000ea}},	//   blie, bbia_, _spu_, _apmi,
   {{0x7d0f0987,0xd6d8ba3b,0x3f9e06a2,0x645bba3c}},	//   nacs, сту_, hitu_, _prui,
   {{0x60c20332,0x4426ba3d,0xd4690012,0x3f9eba3e}},	//   _nyom, guo_, риле_, kitu_,
   {{0xe81e13ab,0x6d465877,0xfa3401cb,0xcec300b8}},	//   _पिता_, zeka, _برید, _jiří_,
   {{0x3f9eba3f,0x2d822b6f,0x6d46ba40,0x60c21e41}},	//   ditu_, ykke_, yeka, _ayom,
   {{0x442600a7,0xa2d500a1,0x753b0232,0x798d300c}},	//   buo_, येष्, _ubuz, nhaw,
   {{0xf1b9715f,0x61e2ba41,0x4426ba42,0x3f9e058e}},	//   roš_, _diol, cuo_, fitu_,
   {{0xee394406,0x3f9e9039,0x69c40029,0xf1b9042a}},	//   ано_, gitu_, zlie, soš_,
   {{0x27e325cb,0x6d468d40,0x798d01d1,0x6f0a0bf0}},	//   _mijn_, teka, khaw, _defc,
   {{0x798d01a9,0x68e200d8,0x27e30120,0x61e2026e}},	//   jhaw, žodi, _lijn_, _giol,
   {{0x6d46ba43,0xef0e57d2,0x3f9eba44,0xd0096055}},	//   reka, _ом_, bitu_, _теле_,
   {{0x6d46ba45,0x3f9ea069,0x29190024,0x61e2ba46}},	//   seka, citu_, _adsa_, _ziol,
   {{0x290bba47,0x69c48e69,0x25bf01d6,0x6d460c1e}},	//   _beca_, tlie, _okul_, peka,
   {{0xddc3071d,0x290bba48,0xe8fa31eb,0x69c4ba49}},	//   _общи, _ceca_, рла_, ulie,
   {{0xb4c80302,0x290bba4a,0x92c50033,0x00000000}},	// [de40] _उरे_, _deca_, _এলো_, --,
   {{0x69c4ba4b,0x29197623,0x442602ee,0x69d60159}},	//   slie, _edsa_, vuo_, smye,
   {{0x69c40122,0x798dba4c,0x7c43011c,0xfa6a43ca}},	//   plie, bhaw, čvrš, _танк_,
   {{0x2e3a00c2,0x4426ba4d,0x290b0009,0xe45a47de}},	//   יגענ, tuo_, _geca_, иже_,
   {{0x27e30120,0x61e25cb6,0x20190187,0xe2f80208}},	//   _fijn_, _riol, ásil_, белі_,
   {{0x290b0c9f,0xd7c500a1,0x925a0037,0x61e2ba4e}},	//   _zeca_, वतःच, لشعر_, _siol,
   {{0x63ad0514,0x61e2ba4f,0x4426ba50,0x765c0055}},	//   éana, _piol, suo_, _urry,
   {{0x27e34cca,0x4426023c,0x25adba51,0x00000000}},	//   _zijn_, puo_, _gjel_, --,
   {{0x3f9e604e,0x232a03f5,0x00000000,0x00000000}},	//   titu_, _вози_, --, --,
   {{0xe29a0043,0x60c2000e,0x32460009,0xaac000c0}},	//   _каз_, _vyom, _мезг, _शुभक,
   {{0x3f9eba52,0x798dba53,0x61e24d7d,0xddc9010b}},	//   ritu_, yhaw, _tiol, rydž,
   {{0x3f9eba54,0x61fa05f5,0x3dd20090,0x20060067}},	//   situ_, _ittl, _chyw_, _twoi_,
   {{0x9ccb010b,0x290b3526,0xe7ea030f,0x2b86021d}},	//   рына_, _reca_, _झूला_, _côco_,
   {{0x798d009e,0x33f00392,0x00000000,0x00000000}},	//   whaw, _màx_, --, --,
   {{0xd3780a78,0x27e3ba55,0xfe6f0079,0xae1701c0}},	//   _moć_, _rijn_, _لدي_, _थिएन_,
   {{0x66d80168,0x00000000,0x00000000,0x00000000}},	//   _mäkč, --, --, --,
   {{0x290b383e,0x27e30120,0x23ca06fe,0x3ce900be}},	// [de50] _veca_, _pijn_, िताद, _igav_,
   {{0xd3780470,0x798d0054,0x25bf010d,0x3864022f}},	//   _noć_, shaw, _skul_, _šmrc_,
   {{0x6da40f44,0x7d0d0ac8,0x6e2802c6,0x6d96a5ec}},	//   rđav, _keas, nudb, ršav,
   {{0xb8d10083,0x7bc7ba56,0x27e301e4,0xa927017e}},	//   _ওর_, llju, _wijn_, _بعده,
   {{0x7d0d59d2,0x39490608,0xdb1500b8,0x61fa03d0}},	//   _meas, meas_, hozí, _attl,
   {{0x3949ba57,0x7d0d4c34,0xceb800d8,0x8cce00ab}},	//   leas_, _leas, ngęs_, _सरसो,
   {{0xd378025c,0xa91b008a,0xe7f10066,0xb5a75084}},	//   _doć_, _alþi, _अंडा_, _драй,
   {{0x7d0dba58,0x2bd2ba59,0x60091368,0x25ad1405}},	//   _neas, _दीना, бним_, _ujel_,
   {{0x7bc70888,0x3dd2001e,0x61fa0137,0x637d00e0}},	//   klju, _rhyw_, _ettl, _bènt,
   {{0x39490a24,0x7bc708b7,0x637d0310,0x62970042}},	//   heas_, jlju, _cènt, úxos,
   {{0xed5a0c95,0x6d96012e,0x637d0118,0x799d0b88}},	//   бон_, kšat, _dènt, _omsw,
   {{0x7d0dba5a,0x5bb60517,0x523a0070,0x00000000}},	//   _ceas, ृत्व, _לײענ, --,
   {{0x3949ba5b,0x7d0d0014,0xd1b80148,0xa2bf0084}},	//   deas_, _deas, _بالا_, _लुत्,
   {{0xff510357,0x70520037,0x7bc70523,0xdb1c0031}},	//   _سخت_, _أنوا, glju, morë,
   {{0x3ced28c2,0x2a350677,0x672100c3,0xa96a0dee}},	//   ževa_, мэтр, _öljy, бива_,
   {{0x7d0dba5c,0x394900f1,0xfe700037,0x00000000}},	//   _geas, geas_, _جده_, --,
   {{0xa2a2051d,0xdb1c01f4,0xdceb0009,0x7bc705e2}},	// [de60] _केन्, norë, _šiće, blju,
   {{0x6d56ba5d,0x7af7027a,0x637d0176,0x79840067}},	//   _haya, _gfxt, _mèns, skiw,
   {{0x7d0dba5e,0x25bd1c7f,0x39490a07,0xf1cb0a90}},	//   _yeas, fowl_, beas_, ातान,
   {{0x6d5650e0,0x39498e1d,0x63ad0037,0x00000000}},	//   _jaya, ceas_, éann, --,
   {{0x6d5608dd,0x2912ba5f,0xd378022f,0xe4e31645}},	//   _maya, maya_, _poć_, нішн,
   {{0x6d561034,0x2912002f,0xcc3b02b5,0x2d9900f7}},	//   _laya, laya_, מענט, érez_,
   {{0xa2b1111b,0xe1d8010b,0x6da40207,0xe64310da}},	//   _अखण्, одкі_, nđas, _перп,
   {{0x2912ba60,0x7de8000c,0x637d0118,0x7bc700cd}},	//   naya_, _měst, _bèns, zlju,
   {{0x7d0d0122,0x7df30139,0x00000000,0x00000000}},	//   _reas, _răsa, --, --,
   {{0x29120f1a,0x6d56ba61,0x7d0d796c,0xe7be1bb5}},	//   haya_, _aaya, _seas, ्तिप,
   {{0x6d56ba62,0x7bc701cc,0x2912ba63,0x7df30160}},	//   _baya, vlju, kaya_, _păsa,
   {{0x29121034,0x6e280b3e,0x00000000,0x00000000}},	//   jaya_, rudb, --, --,
   {{0x6d560457,0x2912272d,0x9f3403d0,0x6e28ba64}},	//   _daya, daya_, _желі, sudb,
   {{0x7d0d2400,0x629c0093,0x00000000,0x00000000}},	//   _weas, _þros, --, --,
   {{0x7d0dace8,0x3949ba65,0x5a440c8a,0x2912ba66}},	//   _teas, teas_, нэта, faya_,
   {{0x2912ba67,0x7bc740f5,0x87090831,0x00000000}},	//   gaya_, slju, _লাইফ_, --,
   {{0x7bc70a23,0xa40b0084,0x6d9600f4,0x5779010b}},	// [de70] plju, _सौंप_, ršat, обаў_,
   {{0x3949ba68,0x04fe0083,0x6d560103,0x6f1c0098}},	//   seas_, ুলোর_, _zaya, órch,
   {{0x39492675,0x2912ba69,0x6d56ba6a,0x95cb0009}},	//   peas_, baya_, _yaya, буда_,
   {{0x29125040,0x7ddf025f,0x2100008b,0x6d562764}},	//   caya_, _būsi, nčič_, _xaya,
   {{0x63ad81c7,0xf99f021e,0x00000000,0x00000000}},	//   éano, _imè_, --, --,
   {{0xdb1c0118,0x00000000,0x00000000,0x00000000}},	//   gorè, --, --, --,
   {{0x6d8601ef,0x91fc00ea,0x637d0118,0x00000000}},	//   _sóam, _arāb, _sèns, --,
   {{0xdb1c00da,0x80650e0a,0x26d10036,0x63740260}},	//   torë, движ, _izzo_, _màny,
   {{0x34940810,0x6d561d4c,0x26d10124,0x7df30139}},	//   _затр, _raya, _hzzo_, _căsn,
   {{0x657b0345,0xdb1c0031,0x2912045e,0x7dcf0036}},	//   _houh, rorë, zaya_, vùsa,
   {{0x63a37bfa,0x2912ba6b,0xdb1c0031,0x6d560cec}},	//   minn, yaya_, sorë, _paya,
   {{0x63a3ba6c,0x29120510,0xdca60036,0x865a0070}},	//   linn, xaya_, дами, קדרי,
   {{0x62832da5,0x6d56ba6d,0x2912045e,0xdb1c000d}},	//   lyno, _vaya, vaya_, loré,
   {{0xa3cd00c0,0xa3bf210a,0x6d562f18,0x63a3ba6e}},	//   रति_, ीति_, _waya, ninn,
   {{0x6d561d50,0x2912ba6f,0x28e00963,0x656900fe}},	//   _taya, taya_, पेनि, _oneh,
   {{0x63a30d4c,0xbbe900ff,0xb33c009f,0x657b0345}},	//   hinn, _کريم_, _imħe, _nouh,
   {{0xb9060429,0x2912ba70,0xa3bf1b8f,0x63a3ba71}},	// [de80] _पण_, raya_, ीता_, kinn,
   {{0x2912ba72,0x63a35ed7,0x656910cd,0x7de80355}},	//   saya_, jinn, _aneh, _těst,
   {{0x63a35098,0x6f1c0279,0x657b00f6,0x7df30139}},	//   dinn, órci, _bouh, _măso,
   {{0x29120510,0x186a3af1,0xdb1500fd,0x00000000}},	//   qaya_, _дами_, mozá, --,
   {{0x63a39a5e,0xe2f8004b,0x00000000,0x00000000}},	//   finn, пелі_, --, --,
   {{0xf62609ea,0x63a3ba73,0xb33c0024,0x00000000}},	//   _одго, ginn, _omħe, --,
   {{0x1339006c,0xe5a63649,0x6283ba74,0xd2570104}},	//   ستوں_, _живи, gyno, дцы_,
   {{0xdb1c013c,0xdce400d5,0x78af00cd,0xd3780207}},	//   llrä, _anič, šivš, _mići_,
   {{0xd6b00083,0x3942028b,0x63a3073a,0xdb152d87}},	//   _করিয, _mbks_, binn, hozá,
   {{0xdb15006c,0x442600e9,0x63a3ba75,0xdb1cba76}},	//   kozá, mro_, cinn, boré,
   {{0xd12f35a5,0x657b01cb,0xdb1c000d,0x7c260b17}},	//   _их_, _youh, coré, erkr,
   {{0x4426ba77,0x008600af,0xd6b00033,0xa6b00831}},	//   oro_, _олео, _করায, _করাট,
   {{0x5c742374,0x3ced02f6,0x00000000,0x00000000}},	//   влят, ževo_, --, --,
   {{0x4426130f,0xcf2600d1,0x2bd20035,0xdfa60833}},	//   iro_, _آرشي, _दीदा, _تحصي,
   {{0x442600e9,0x7c2603bc,0xf1c900d5,0x00000000}},	//   hro_, arkr, siáš_, --,
   {{0xdce40187,0xea000019,0x63a3ba78,0xd378012e}},	//   _znič, _giật_, zinn, _dići_,
   {{0x777c01f4,0x442601e9,0x62830067,0x260c0bdd}},	// [de90] _borx, jro_, zyno, डीसी_,
   {{0x657b9633,0x6569ba79,0xa80201ef,0x27e7008d}},	//   _souh, _sneh, áñan, önn_,
   {{0x63a3abd2,0x44265075,0x98af0225,0x657b0355}},	//   vinn, ero_, ıgı_, _pouh,
   {{0x63a31659,0x4426ba7a,0xf8bf00ee,0x00000000}},	//   winn, fro_, _dcér_, --,
   {{0x4426ba7b,0x777c0042,0x6283016e,0x00000000}},	//   gro_, _forx, wyno, --,
   {{0x42550011,0x39595cd8,0x777c77b8,0xb4c1007c}},	//   етит, _hass_, _gorx, _ुरी_,
   {{0x63a3ba7c,0x2489ba7d,0x442602fb,0xdb0e3eef}},	//   rinn, šam_, aro_, tobú,
   {{0x63a3ba7e,0xdce40009,0x3cf90035,0x6283ba7f}},	//   sinn, _snič, ंडों_, ryno,
   {{0x2019006c,0x63a3023f,0x3959ba80,0x44390031}},	//   ési_, pinn, _mass_, _ës_,
   {{0x3959a42c,0x82f800f8,0xeafb00b4,0x35a50387}},	//   _lass_, _قرمز_, ्रोत_, _खगड़,
   {{0xd131004f,0xed5a36ed,0x398e0093,0x00000000}},	//   _مما_, пон_, _lýsa_, --,
   {{0xdb0a0076,0x3f8e0054,0xed5a0d3d,0x9f470031}},	//   čník, _elfu_, чом_, _kinë_,
   {{0xa283006c,0xdce40009,0xd3780506,0x63740176}},	//   _سیکو, _tnič, _sići_, _pànx,
   {{0x207a0070,0xdce4008b,0xe51f0d4e,0x7dd601ef}},	//   _מאנא, _unič, मृति_, dáse,
   {{0xfb8501c8,0x6da62fc1,0x39592aa0,0xada63fe2}},	//   тыўн, _пика, _bass_, _пакл,
   {{0x3959ba81,0x4426ba82,0xdb152d87,0xdce4007a}},	//   _cass_, yro_, rozá, _eliġ,
   {{0x39590446,0xdd8f183b,0xfc320037,0x777c01f7}},	// [dea0] _dass_, _دوي_, _صحة_, _porx,
   {{0x44260370,0xdc3b0122,0x777c0095,0x26de0097}},	//   vro_, _צעיר, _qorx, _útok_,
   {{0x3959191b,0x44260090,0x98c0013b,0x00000000}},	//   _fass_, wro_, ırıq_, --,
   {{0x4426a745,0xf651006c,0x3959ba83,0x7dd600b5}},	//   tro_, گئے_, _gass_, lásb,
   {{0x4426ba84,0xdceb00cd,0x7dd601ef,0x777c2d73}},	//   uro_, šića, cáse, _torx,
   {{0x77910df3,0x9f4701f4,0x46a6081b,0x3940ba85}},	//   _پیما, _dinë_, _загв, lfis_,
   {{0x60e50095,0x4426ba86,0x38601c5b,0x6d440067}},	//   ərmə, sro_, lvir_, _obia,
   {{0x4426ba87,0xd25901c8,0x394000b9,0x00000000}},	//   pro_, ьці_, nfis_, --,
   {{0xf9930122,0xcfa61517,0x3860ba88,0x00000000}},	//   טרה_, ешни, nvir_, --,
   {{0x25a60955,0x6d4406a2,0x389b0d85,0x0fce0033}},	//   liol_, _abia, פיינ, রদ্ধ,
   {{0xdd9500d8,0xbcfb006c,0xfe4200fd,0x9f470359}},	//   ваны, ndég, اکتی, _minè_,
   {{0x25a6ba89,0xac190f92,0x00000000,0x00000000}},	//   niol_, мому_, --, --,
   {{0x6d960009,0xdb1c00e9,0x39599cb0,0x00000000}},	//   ršap, gorï, _rass_, --,
   {{0x25a6001e,0x69c6ba8a,0x39592a4d,0x6d44030d}},	//   hiol_, _akke, _sass_, _ebia,
   {{0x2d991010,0x3959ba8b,0x7ddf010b,0xeef700a5}},	//   ères_, _pass_, _būst, _אמור_,
   {{0x62980fd5,0x2b5a0176,0x00000000,0x00000000}},	//   izvo, _eapc_, --, --,
   {{0x25a60297,0x6d4f005d,0x2bd207ba,0xe8940d13}},	// [deb0] diol_, meca, _दीवा, гать,
   {{0x7dd6ba8c,0x6d4f006a,0x69c600fb,0x7bc5046a}},	//   ráse, leca, _ekke, _ukhu,
   {{0x7c2f4552,0x765a01ba,0xf7700957,0x661c0506}},	//   lucr, _štyr, حاق_, _cvrk,
   {{0x6d5d0d51,0x6d4fba8d,0x2d8b01c0,0xd37800f4}},	//   ndsa, neca, nkce_, _miću_,
   {{0x76550755,0xf8d50084,0x2909002f,0x6fd000b4}},	//   _wszy, _दरिय, mbaa_, हतां,
   {{0xe6130987,0x7c3d02b1,0x57be021a,0x1bf8025a}},	//   _مشر_, itsr, ्तृह, עצור_,
   {{0x69cd001e,0x41b51d6b,0x25a6409c,0x00000000}},	//   olae, ксит, biol_, --,
   {{0x6d4f029d,0x7dd600fd,0x00000000,0x00000000}},	//   jeca, zásb, --, --,
   {{0x65940043,0x6d4fba8e,0x661c0124,0xe7b8046c}},	//   _сату, deca, _zvrk, _आदमप,
   {{0xdee52f19,0x6d5d0b88,0x6d44027a,0xd378011c}},	//   копи, edsa, _sbia, _biću_,
   {{0x9f4701c0,0xd37a0070,0x2b5000a8,0x9f4f000d}},	//   _jiné_, _קרעט, _öncə_, _jugé_,
   {{0x6da6107b,0xb33c003c,0x7c3d7d65,0xeb0a021a}},	//   тима, _imħa, ftsr, वर्त_,
   {{0x69cd0297,0x557602b5,0x1fb50eee,0x442fba8f}},	//   dlae, דערן_, _искр, nug_,
   {{0x6d5d0159,0xd3780207,0x00000000,0x00000000}},	//   adsa, _fiću_, --, --,
   {{0xc3320bed,0x442f03be,0x7c3db35d,0x00000000}},	//   יום_, hug_, atsr, --,
   {{0x3a250093,0xdb1cba90,0x6449ba91,0x00000000}},	//   álpa_, morí, _opei, --,
   {{0x61eb0133,0x442f01cb,0xdb1c2eae,0x57ea30cc}},	// [dec0] _migl, jug_, lorí, ддам_,
   {{0x3860ba92,0x442f0f5d,0x2d800159,0x25a600e9}},	//   rvir_, dug_, _hoie_, wiol_,
   {{0xe9da0202,0xdb1cba93,0x9f4700f7,0x9f4d0453}},	//   _око_, norí, _ciné_, lpeó_,
   {{0x8ab700a5,0x2d80ba94,0x758901e0,0x443d0312}},	//   _יהיו_, _joie_, нсів_, ftw_,
   {{0x25a6001e,0xb33c0069,0x442f00e0,0x25b700d5}},	//   riol_, _amħa, gug_, _želé_,
   {{0xdceb0c0a,0x61eb23bb,0x64a3027f,0x25a60090}},	//   žićn, _aigl, шача, siol_,
   {{0x61ebba95,0x2d9202d0,0xdb1c0453,0x9f470176}},	//   _bigl, _olye_, jorí, _giné_,
   {{0x442f02b3,0x2fc70cca,0xdb1cba96,0x61eb198b}},	//   bug_, _akng_, dorí, _cigl,
   {{0x61eba93e,0xbcfb00f7,0xd3780207,0xa2a2021a}},	//   _digl, ndée, _siću_, _केर्,
   {{0xa3cd0096,0x2d92166c,0xd34601cb,0x7bce02c4}},	//   रतः_, _alye_, _شیعه_, jlbu,
   {{0xdb1c1166,0x61eb01d3,0x6d4fba97,0xf8bf0248}},	//   gorí, _figl, teca, _idée_,
   {{0x61eb027a,0x602600d8,0xbbbd1e18,0xa18300c3}},	//   _gigl, _адда, ोत्क, _вышл,
   {{0x201901c0,0x6d5dba98,0x6d4f2d74,0xada4010b}},	//   ásit_, rdsa, reca, раўл,
   {{0x8fa315de,0xdb0700da,0x61eb0009,0x7c3d029e}},	//   _каче, mijë, _zigl, rtsr,
   {{0x442f04c9,0x7c2fba99,0x2d80000d,0x63ad399b}},	//   zug_, sucr, _foie_, éani,
   {{0x7bce52d7,0xa806027d,0x69c401a3,0x442f0430}},	//   albu, ktığ, goie, yug_,
   {{0x98a201c2,0x3dc98650,0x290900ec,0x69cd00be}},	// [ded0] _bakı_, _ikaw_, rbaa_, rlae,
   {{0x3b550cf9,0x7f8401f7,0x69cdba9a,0x00000000}},	//   _скор, _tòqu, slae, --,
   {{0x6449ba9b,0xcf9300c2,0xa2a202cb,0xd0060357}},	//   _spei, סטע_, _केल्, _گل_,
   {{0x442fba9c,0x3995008c,0xd6d8081b,0xc8840457}},	//   tug_, _båse_, тту_, _bağı_,
   {{0xd0062087,0xfc3f0082,0xef180029,0x61eb03bc}},	//   _دل_, ntí_, kaļ_, _rigl,
   {{0x442f4401,0x61ebba9d,0xdb1c0033,0x95420095}},	//   rug_, _sigl, yorí, əşmə,
   {{0x05bb10ad,0x61eb4831,0x442fba9e,0x443d0035}},	//   _قدرت_, _pigl, sug_, stw_,
   {{0x61fe0187,0x798dba9f,0xdb1c00a0,0xdb0e0097}},	//   ípla, nkaw, vorí, dobý,
   {{0x61ebbaa0,0xf94a0070,0x69da1e7e,0xdfe91783}},	//   _vigl, געפֿ, ïtei, ндид_,
   {{0xdb1cbaa1,0x2d990120,0x2d80000d,0x69c4baa2}},	//   torí, ëren_, _soie_, zoie,
   {{0x61ebbaa3,0x22290088,0x2d920107,0x00000000}},	//   _tigl, _سزای_, _plye_, --,
   {{0xed5700d4,0xc1050037,0xd00e00b5,0x7dd60079}},	//   гою_, _صوتي, _کلو_, fása,
   {{0x711a0052,0x2d8047b8,0xdb1cbaa4,0x69c45a66}},	//   _נוספ, _voie_, sorí, voie,
   {{0xe0d001df,0x798dbaa5,0x00000000,0x00000000}},	//   _بزم_, ekaw, --, --,
   {{0x69c4baa6,0x6eca0f17,0x00000000,0x00000000}},	//   toie, _सुपु, --, --,
   {{0x798d18ad,0x00000000,0x00000000,0x00000000}},	//   gkaw, --, --, --,
   {{0x38660079,0xfc3f01f7,0x69c489ac,0x7996016e}},	// [dee0] íor_, ctí_, roie, rhyw,
   {{0xe73702c4,0x66e6baa7,0xb8cc007c,0xbcfb000d}},	//   леу_, гоза, _कइ_, rdée,
   {{0x7d7705f5,0x80aa0433,0x452a0dde,0xdb1c01f7}},	//   _شمیر_, _जेने, ежен_, morà,
   {{0xc51600bc,0xa806027d,0x49ba00b5,0xd5d5010b}},	//   ابات, ttığ, _ساجد_, аючы,
   {{0xd8760642,0x7d1600e9,0x245845e5,0xd91b00a5}},	//   _صاحب, _meys, таль_, _אוכל,
   {{0x932600d1,0x7d16a464,0x3952baa8,0xea000019}},	//   ارشن, _leys, leys_, _ngẫu_,
   {{0xe2461301,0x7dd600fd,0xa80601fb,0x00000000}},	//   اختي, zása, stığ, --,
   {{0xa80601d6,0x7d160b11,0x7df3002d,0x3ced0ce9}},	//   ptığ, _neys, _găsi, ževi_,
   {{0x2fc501ae,0xf8b40035,0x351b00a5,0xbfaa0368}},	//   folg_, ंपिय, _רומנ, етне_,
   {{0xf1a90118,0xa8570122,0xa2bf22a3,0x3dc90392}},	//   _یانه_, נייה_, _लुक्, _skaw_,
   {{0x59c401d1,0x00000000,0x00000000,0x00000000}},	//   वकार, --, --, --,
   {{0x7dd6006c,0xa2bb024b,0x00000000,0x00000000}},	//   tása, _אמבט, --, --,
   {{0x5b2707f5,0xdced009f,0x00000000,0x00000000}},	//   льва, _inaċ, --, --,
   {{0xfc3fbaa9,0xbe860a86,0x7dd6baaa,0x798d0159}},	//   rtí_, _مجبو, rása, wkaw,
   {{0xfc3fbaab,0x6f1a744c,0x7d16016e,0xe91900d4}},	//   stí_, matc, _feys, кові_,
   {{0x7d165064,0x1958010b,0x6f1abaac,0x00000000}},	//   _geys, ласы_, latc, --,
   {{0x798d06d4,0x2d99004f,0x97152dbb,0x5efb0099}},	// [def0] rkaw, mhse_, имац, लुक्_,
   {{0x6f1a0381,0x798dbaad,0x00000000,0x00000000}},	//   natc, skaw, --, --,
   {{0xb8cc3ded,0x941f0095,0x6d5f01e9,0xb87b0a4f}},	//   _के_, ərək_, _kaqa, _egíp,
   {{0x7bc7baae,0xa2bf00be,0x29f8012e,0xdb1cbaaf}},	//   loju, _लुग्, _očaj_, morá,
   {{0x6d5fbab0,0x588700c7,0x1b180083,0x291b0510}},	//   _maqa, _сына, _তাতে_, maqa_,
   {{0x6d5f007a,0x7bc700ea,0xe2850421,0x14a40099}},	//   _laqa, noju, илли, _खेळण,
   {{0x52750012,0x2fc50136,0xdb1cbab1,0xa80601d6}},	//   рулу, volg_, norá, rtış,
   {{0x91fc0029,0x6d5f007a,0xd185027a,0x291b0c6f}},	//   _grām, _naqa, рлий, naqa_,
   {{0x7bc70029,0xd34700d1,0x9f47027a,0x6eca29ad}},	//   koju, _میشه_, _finì_, _सुबु,
   {{0x6f1abab2,0x628abab3,0xff2503e6,0x205401d3}},	//   gatc, byfo, јмно, стър,
   {{0x6d5f2c4b,0x7bc70029,0x7d16008d,0x1d0a0036}},	//   _baqa, doju, _peys, кени_,
   {{0xfce6bab4,0x00000000,0x00000000,0x00000000}},	//   ионо, --, --, --,
   {{0x645b00a2,0x7d0901ef,0x7d1600a3,0x7bc70d8f}},	//   _jsui, ñesa, _veys, foju,
   {{0xdee534b5,0xdb1c063d,0x69dd833e,0x7bc72a28}},	//   _коли, forá, _ahse, goju,
   {{0x6d5f007a,0x2d990874,0x291b7b11,0xbea203e6}},	//   _faqa, bhse_, faqa_, _машк,
   {{0x2d99033b,0x66760df3,0xb906027a,0xdc350bca}},	//   chse_, یدار, рзак, _zúčt,
   {{0x7dd60332,0x443f006d,0x39520210,0x7bc70228}},	// [df00] láso, _nqu_, reys_, boju,
   {{0x753b002d,0x661b0035,0x27ee0093,0x6d5f00a8}},	//   _acuz, _łuka, öfn_, _zaqa,
   {{0x443f0d9a,0xd94632a6,0x91fc00ea,0x85064e87}},	//   _aqu_, _кени, _prām, لوان,
   {{0x6d5f013b,0x7ddd01f7,0x3abb00a5,0x00000000}},	//   _xaqa, césd, _ימינ, --,
   {{0x290200fe,0x6f1a0a21,0x00000000,0x00000000}},	//   _ifka_, yatc, --, --,
   {{0xb4d60953,0xbcfb004f,0x7dd600b5,0x29000096}},	//   _हरी_, idéa, káso, lcia_,
   {{0x2b470723,0x7ddd006c,0xd250004f,0x443f0024}},	//   _önce_, lése, سنة_, _equ_,
   {{0x6f1aa2dd,0x63aa046a,0x7dd600b5,0xd1300037}},	//   watc, sifn, dáso, أمة_,
   {{0x6d5f0024,0x7df30043,0x290000de,0x7bc7002f}},	//   _raqa, _măsu, icia_, yoju,
   {{0x63ad004f,0x6d5f035f,0x65600037,0x244002d0}},	//   éant, _saqa, _hamh, mòm_,
   {{0xa3e30967,0x2900016f,0x244002e9,0x6d5f0031}},	//   नगर_, kcia_, lòm_, _paqa,
   {{0x656200da,0x6560000e,0xdb1c0f84,0x6d5f0be2}},	//   ndoh, _jamh, vorá, _qaqa,
   {{0x6442bab5,0x7bc7bab6,0x0ca81a0b,0x6d5f0c6f}},	//   ntoi, toju, атри_, _vaqa,
   {{0x6d5f5fbe,0x2900bab7,0x6560006b,0xdb1c314b}},	//   _waqa, ecia_, _lamh, torá,
   {{0xdced0470,0x6d5f0024,0x69c00c99,0x7bc75ca4}},	//   _inač, _taqa, čmen, roju,
   {{0x637d0c1f,0x80dd22c7,0x65607236,0x6f180024}},	//   _dèny, _परमे, _namh, _hevc,
   {{0x7d1d5473,0x6f1801e8,0x7bc7bab8,0xa3d6bab9}},	// [df10] mass, _kevc, poju, सता_,
   {{0x2900baba,0xe719004f,0xe733028c,0x753b002d}},	//   acia_, ايات_, تصر_, _scuz,
   {{0x1dbb05f8,0x2126022f,0x6f1801d6,0x443f008c}},	//   _उदात, _odoh_, _mevc, _squ_,
   {{0x290001d3,0x7d1dbabb,0x244002d0,0x65600284}},	//   ccia_, nass, fòm_, _camh,
   {{0x7dd6006c,0x6560b9ea,0xe8160387,0x00000000}},	//   záso, _damh, दीदा_, --,
   {{0x7d1dbabc,0xb3c82659,0x212600f8,0x67e902a7}},	//   hass, аліз_, _adoh_, _ožji,
   {{0xd6e500c8,0x06e500c8,0xe695004f,0x29190dc3}},	//   _প্রয, _প্রি, _الأد, _kesa_,
   {{0x6b85012f,0x7d1d136b,0x78b8011c,0x753b045e}},	//   _lohg, jass, šavš, _ucuz,
   {{0x6442babd,0x7d1dbabe,0x9f4e02d0,0x7df30160}},	//   ctoi, dass, _kifè_, _lăst,
   {{0x2919babf,0x7dd60332,0x3f830093,0xf2c72447}},	//   _lesa_, táso, ðju_, _ксен,
   {{0x7d1d02c9,0x201f03e6,0x7ddd006c,0xdce40009}},	//   fass, ssui_, zése, _knić,
   {{0x7d1dbac0,0x2919bac1,0x7dd600b5,0x7bde0031}},	//   gass, _nesa_, ráso, _shpu,
   {{0x515a00a5,0x7e6a1472,0x7ddd01ef,0x7df30395}},	//   _תכנו, _erfp, xése, _răsu,
   {{0x3b9500ed,0x6f180160,0x442f4dbb,0xe81b0067}},	//   ојст, _gevc, irg_, _पौधा_,
   {{0x2919bac2,0xf8bf1dfd,0x244002d0,0x386b0168}},	//   _besa_, _axé_, zòm_, _arcr_,
   {{0xe9df0028,0x7ddd006c,0x2919bac3,0x2d9200ea}},	//   _chú_, tése, _cesa_, īzes_,
   {{0x2900560f,0x2919bac4,0x4ca60083,0xa9670945}},	// [df20] rcia_, _desa_, _গুরু, щита_,
   {{0x6560bac5,0x2900bac6,0xbcfb01dd,0x869a1b5d}},	//   _samh, scia_, ndén, лтет_,
   {{0x442f013a,0x2e2301d6,0x29008e8c,0x244002d0}},	//   erg_, nıf_, pcia_, wòm_,
   {{0xdb1c2e00,0x2919046a,0x4a5b0122,0x63140083}},	//   forç, _gesa_, _עדכו, _সাইট_,
   {{0xfe6700bf,0x260c0006,0xf3f10023,0x656220c6}},	//   _کد_, डीजी_, _bị_, rdoh,
   {{0x6442bac7,0x61b2022e,0x7d1dbac8,0x7c241766}},	//   rtoi, ुक्ष, zass, _mvir,
   {{0x6442bac9,0x7d04474f,0x442fbaca,0x79860858}},	//   stoi, _ofis, arg_, _kokw,
   {{0x7d1d0183,0x656009c3,0x91d500dc,0x15433ff3}},	//   xass, _uamh, _डीआई, _несм,
   {{0x7d1d7ce9,0x6e230a8a,0xdb1c0392,0x6f180116}},	//   vass, _avnb, corç, _pevc,
   {{0x7d04bacb,0x437510da,0x7d1dbacc,0x7986030d}},	//   _afis, _мухт, wass, _lokw,
   {{0xf8d50084,0x7ddd00b5,0x34b8074f,0x00000000}},	//   _दर्प, vésb, _अशुद, --,
   {{0x4424a29f,0xc69302b5,0x79863ab1,0x7c240024}},	//   _kvm_, פאר_, _nokw, _bvir,
   {{0x7d1dbacd,0x2919bace,0x44240523,0x3ced00ab}},	//   rass, _resa_, _jvm_, äev_,
   {{0x7d0407ee,0x291901f4,0x7c2400d8,0x61fabacf}},	//   _efis, _sesa_, _dvir, _kutl,
   {{0xe9df0028,0x2919bad0,0x394b008c,0x442400ec}},	//   _phú_, _pesa_, _pbcs_, _lvm_,
   {{0x7d1d009f,0x61fabad1,0x00000000,0x00000000}},	//   qass, _mutl, --, --,
   {{0xb4c70302,0x6d4dbad2,0x2919357b,0x44240051}},	// [df30] _उडे_, _ibaa, _vesa_, _nvm_,
   {{0xba550431,0x6fdd00f7,0x61fabad3,0x9f4700a0}},	//   _двој, pèce, _outl, _kiná_,
   {{0xe9df93bc,0xd6db49ad,0x7c24bad4,0x9f4700b8}},	//   _thú_, ута_, _zvir, _jiná_,
   {{0x9b4500b5,0x2e3b0070,0x7bd5871b,0x29190176}},	//   _انھو, רגאנ, llzu, _uesa_,
   {{0x442fbad5,0x61fa0009,0x29d72cd6,0x44240183}},	//   urg_, _autl, nçam_, _cvm_,
   {{0x61fa12c3,0x42093810,0x79860027,0x39490409}},	//   _butl, анко_, _zokw, lfas_,
   {{0xe2992a32,0x79864296,0xdb1c0132,0x65950c4c}},	//   рай_, _yokw, sorç, _даву,
   {{0x80dd31fa,0xc0050fa7,0xdb1c0279,0x394935a6}},	//   _परदे, опик, porç, nfas_,
   {{0x38690095,0x764564d3,0x00000000,0x00000000}},	//   nvar_, lthy, --, --,
   {{0x6d4d09d6,0xd00e00f8,0xf8aa0070,0x6eca018d}},	//   _abaa, کلی_, יספֿ, _सुहु,
   {{0x7c240a78,0xbcfb002a,0x7645001e,0x61fa0124}},	//   _svir, rdén, nthy, _gutl,
   {{0xe2940070,0x7dd61534,0x00000000,0x00000000}},	//   _צװײ_, pásm, --, --,
   {{0xf1d50026,0x06b00033,0x7645bad6,0x7dd600b5}},	//   _डीएन, _করছি, hthy, lásk,
   {{0x69cfbad7,0x76450031,0x6d4dbad8,0x9f4300c3}},	//   _akce, kthy, _ebaa, öjä_,
   {{0x9d461402,0x7986bad9,0x752904aa,0x39490523}},	//   _дейд, _pokw, _odez, ffas_,
   {{0x7d04000e,0x7c2400d8,0x394600d8,0x7ddd0279}},	//   _ufis, _tvir, ўнаг, résc,
   {{0x3f87bada,0x6609badb,0x3869badc,0xe7aa0112}},	// [df40] _konu_, _čeka, gvar_, авал_,
   {{0x2d8210ec,0x75297e24,0x79860027,0x69cf00f4}},	//   ljke_, _adez, _wokw, _ekce,
   {{0x7986badd,0x442400f6,0x4c050919,0x00000000}},	//   _tokw, _svm_, _وظیف, --,
   {{0x61faa9f8,0x44241db7,0x2d820a18,0x78bb3b1a}},	//   _rutl, _pvm_, njke_, _žuve,
   {{0x61fa7bea,0x29120b69,0x195700a5,0xf8de00b4}},	//   _sutl, mbya_, _ובכל_, _मरिय,
   {{0x61fabade,0x69d6badf,0x366a010b,0x00000000}},	//   _putl, llye, _каго_, --,
   {{0xd6271578,0xe29703fa,0x61fa0510,0x7ddd0118}},	//   _море_, жај_, _qutl, hésa,
   {{0x6eca018d,0x399c0079,0xfbc20033,0x2b580207}},	//   _सुषु, _físe_, োগিত, herc_,
   {{0xdced009f,0x4424bae0,0x6fd40176,0x00000000}},	//   _ilaħ, _uvm_, làci, --,
   {{0xff980500,0x61fa908d,0x3f98bae1,0x7dd6006c}},	//   ској_, _tutl, óru_, lásh,
   {{0xb7db02b5,0x61461958,0x69d60159,0x59ba0066}},	//   שקיי, _межа, klye, ईचार,
   {{0xdced0024,0x386d00d5,0xbcfb00a2,0xd9c400b8}},	//   _jlaħ, _šerm_, rdéo, वकोट,
   {{0x7b672aac,0x6ecaa487,0xf0b000b5,0xed58010b}},	//   отве, _सुरु, _سیدھ, цоў_,
   {{0x7645001e,0xa007250f,0x1eaa0118,0x29d7092a}},	//   ythy, _بقول_, _پاتي_, rçam_,
   {{0x69d6bae2,0x61e2bae3,0x8f9b011d,0x5a440043}},	//   flye, _khol, _דיגי, мэта,
   {{0x3f876a22,0x6d4d073a,0x3a2d0207,0x6fd40176}},	//   _zonu_, _ubaa, čep_, dàci,
   {{0x61e2066a,0xbcfbbae4,0xe70b7e94,0x00000000}},	// [df50] _mhol, ndém, لتان_, --,
   {{0xe9450ef5,0x2b58002d,0x80dd07b5,0xfcaa016b}},	//   _کردی, cerc_, _परसे, _ליפּ,
   {{0xd57510a9,0x38691e54,0xa3c011b5,0x61e2bae5}},	//   зуль, svar_, ीवन_, _ohol,
   {{0x76452db2,0xbc680df3,0x61e20024,0x00000000}},	//   rthy, _امین_, _nhol, --,
   {{0xd469bae6,0x25af099e,0x9879016b,0xa879016b}},	//   силе_, rigl_, _האָט, _האָר,
   {{0x61e206a2,0x57f400c3,0x7dd600b5,0x6fd40176}},	//   _ahol, _опят, tásk, bàci,
   {{0x80dd0066,0x61e24dbb,0x7f8d01f7,0x6fd40310}},	//   _परहे, _bhol, _xúqu, càci,
   {{0xd24e3d15,0x3f8704d4,0x98ab0644,0x61e2687a}},	//   اني_, _sonu_, _hacı_, _chol,
   {{0x25adbae7,0x61e2009e,0x7fd5005f,0x3f870069}},	//   _imel_, _dhol, зіні, _ponu_,
   {{0xee39022c,0x3f9ebae8,0x25bf0990,0x7ddd01ef}},	//   бно_, ghtu_, _hjul_, vésa,
   {{0x59bd065f,0x80dd0026,0x7dd61534,0x61e20719}},	//   ्कार, _परवे, lási, _fhol,
   {{0x200d046a,0x61e2bae9,0xdb1500b5,0x91fc02d4}},	//   ppei_, _ghol, kozó, _prāv,
   {{0xea0000e8,0x61e93854,0x7dd60183,0xdb0e000d}},	//   _biết_, mmel, nási, libé,
   {{0x61e9baea,0x3f9e189a,0x398e0093,0x3b070274}},	//   lmel, chtu_, _lýst_, зеро_,
   {{0x09e6baeb,0x61e901ef,0x25ad757d,0x64b800ab}},	//   зовн, omel, _omel_, _अश्श,
   {{0x61e9baec,0xf2d20070,0x3dd60033,0x9b4600e0}},	//   nmel, געל_, _সংকল, _کندو,
   {{0x23cb1649,0x2912010d,0x61e9baed,0x00000000}},	// [df60] िवाद, rbya_, imel, --,
   {{0xea000019,0x7c26baee,0x61e93f67,0x25adbaef}},	//   _giết_, mskr, hmel, _amel_,
   {{0xd90d0332,0x7c2617ad,0xeab20180,0x7bce00ac}},	//   _چیف_, lskr, _سعد_, mobu,
   {{0x7dd60473,0x6f1c0035,0x00000000,0x00000000}},	//   fási, órcz, --, --,
   {{0x7c26baf0,0x61e901b4,0x9f5f0132,0x938abaf1}},	//   nskr, dmel, rquê_, йска_,
   {{0x61e2baf2,0x25ad4595,0x5334baf3,0x61e9baf4}},	//   _shol, _emel_, фект, emel,
   {{0x61e2baf5,0x66e643db,0x78a41bd8,0x9f470086}},	//   _phol, _хова, lziv, _minä_,
   {{0xb6bb0122,0x7c26baf6,0x61e9baf7,0x2b940523}},	//   _הצלי, kskr, gmel, _bäck_,
   {{0x78a4baf8,0x7df40012,0x7bcebaf9,0x64a30466}},	//   nziv, _răsp, kobu, _зата,
   {{0x08e900c8,0x7c266cfb,0x61e20122,0x2b9401ff}},	//   টুকু_, dskr, _whol, _däck_,
   {{0x61e2bafa,0x7bce00a0,0xfe2306d8,0xdb1c00b5}},	//   _thol, dobu, ньян, ború,
   {{0x3f9e01d2,0xa44b0187,0x61e2bafb,0x7c26bafc}},	//   shtu_, lášť_, _uhol, fskr,
   {{0x9ccb005f,0x7c264240,0x6ab507df,0x69cd002a}},	//   сына_, gskr, ःप्र, voae,
   {{0xdeb4081b,0x200bbafd,0x442608e8,0x78a4bafe}},	//   _облы, ície_, iso_, dziv,
   {{0xea0000e8,0x15ec00c4,0x7ac4b845,0xf1b00026}},	//   _viết_, जगार_, есте, _जगान,
   {{0x4426baff,0x99640043,0x7c26bb00,0xf1cc0ea3}},	//   kso_, нтул, bskr, ाविन,
   {{0xea000028,0x91fc0029,0x7bce0027,0x00000000}},	// [df70] _tiết_, _krās, bobu, --,
   {{0x4c9c0122,0x7bce0345,0xade100ab,0x61e9bb01}},	//   _לבחו, cobu, _गीतन_, zmel,
   {{0x4426001e,0xcf930070,0xf1cc01d1,0x28f900af}},	//   eso_, עטע_, ावान, _мень_,
   {{0x3ea100ab,0xfa5600b5,0x00000000,0x00000000}},	//   _ühte_, _کریگ, --, --,
   {{0xf8c106bb,0x44263da0,0x6e3a68bb,0xe4cb103b}},	//   _एशिय, gso_, hutb, حبان_,
   {{0x7dd67cce,0x00000000,0x00000000,0x00000000}},	//   rási, --, --, --,
   {{0x44260273,0x61e9bb02,0x7d0601ff,0x7c26bb03}},	//   aso_, tmel, ycks, zskr,
   {{0xd9e308a9,0x4426005f,0x61e9bb04,0x92de0160}},	//   _कीमत_, bso_, umel, _datπ_,
   {{0x4426bb05,0xafe538bb,0x7bce01a8,0x316601ed}},	//   cso_, моил, yobu, _daoz_,
   {{0xe7bf021a,0x91fc0029,0x61e9bb06,0x6e3abb07}},	//   ्विप, _prāt, smel, futb,
   {{0xdb1c016f,0xee360043,0x9f5f00a2,0xed5a3945}},	//   porú, мнэ_, nqué_, оон_,
   {{0x61360463,0x9f4700c3,0x316601ed,0x00000000}},	//   rülü, _sinä_, _gaoz_, --,
   {{0xd7bf0099,0x91aa006c,0xe7bf022e,0x4c8302fb}},	//   ्वाच, _بننے_, ्वाप, вляв,
   {{0x9fb501c2,0x799d0051,0xbd030051,0x6d4100b5}},	//   dəçi_, _alsw, _éénp, őlap,
   {{0x7c262395,0x00000000,0x00000000,0x00000000}},	//   sskr, --, --, --,
   {{0x442600e9,0xe9da1728,0x213f046a,0x7c2614c2}},	//   yso_, іка_, nguh_, pskr,
   {{0x79840034,0x6d4401ed,0xb90609b4,0x00000000}},	// [df80] rjiw, _icia, _फर_, --,
   {{0x1b1800c8,0xe8de073f,0x78a4185c,0x00000000}},	//   _তাকে_, _मरीच, rziv, --,
   {{0xe8fa730d,0x9f5f0955,0x29f80097,0x00000000}},	//   _млн_, rquè_, _včas_, --,
   {{0x4426bb08,0x6fd401f7,0x00000000,0x00000000}},	//   tso_, làct, --, --,
   {{0x44263da5,0x045a0037,0x03a60328,0xea0000e2}},	//   uso_, تجات_, мидо, _khắt_,
   {{0x442610bb,0xa3a807ba,0x9a2500b5,0xf8b3011d}},	//   rso_, खों_, _تعین, _ישר_,
   {{0x44265051,0x3860016e,0x29f807e7,0x00000000}},	//   sso_, lwir_, _učas_, --,
   {{0x6d4401e8,0x325301d3,0x614303fa,0x7c290409}},	//   _ncia, твър, већа, šeri,
   {{0x394000ab,0xcfaa0037,0x27f802a7,0x00000000}},	//   igis_, قادم_, _kirn_, --,
   {{0x83fd006c,0x187b00a5,0x6d44014c,0xada40067}},	//   _erős, קטיב, _acia, óźni,
   {{0x073700a5,0x6fd40443,0x75203b48,0x00000000}},	//   ואים_, dàct, _kemz, --,
   {{0x6d44027a,0x6e3a0e6c,0xe4f500ab,0x26d803d0}},	//   _ccia, rutb, ुँचि_, _myro_,
   {{0xdb050514,0x50e2035d,0xb0e207df,0x20e209a0}},	//   _amhá, _परिष, _परिग, _परिध,
   {{0x2124148b,0x6d440024,0xbcfb0037,0xa3ce018d}},	//   lamh_, _ecia, idéi, रवि_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2124bb09,0x75200332,0x6f0d0c99,0x6d440098}},	//   namh_, _nemz, _đaci, _gcia,
   {{0xa3ce5a77,0xb4dd0722,0x00000000,0x00000000}},	// [df90] रवा_, _डरे_, --, --,
   {{0xd6db190a,0x399c008d,0xda7b00af,0x394000be}},	//   оте_, _vísa_, _дям_, agis_,
   {{0x199501db,0xfbdf0132,0x9f5d0118,0xa53503e6}},	//   _заня, ntêm_, _duwè_, енеч,
   {{0x6d5d5dd5,0x9f5f84cd,0x2d9932c5,0x752002d7}},	//   nesa, rqué_, nkse_, _cemz,
   {{0x92bb0083,0x6f0a03d0,0x9f5f1db3,0x21240719}},	//   _ঘরে_, _offc, squé_, damh_,
   {{0x6d5dbb0a,0x7dd6bb0b,0x27f8009e,0xd7c900f8}},	//   hesa, lást, _girn_, _روزه_,
   {{0x6d5dbb0c,0xf99f02e9,0xd24e2f7a,0x00000000}},	//   kesa, _klè_, منو_, --,
   {{0x6d5d4760,0x7dd6bb0d,0x2d990120,0xdb0700c3}},	//   jesa, nást, jkse_, lijä,
   {{0x6d5dbb0e,0x00000000,0x00000000,0x00000000}},	//   desa, --, --, --,
   {{0x6d44bb0f,0x65690024,0x660901f2,0x2d9911cc}},	//   _scia, _haeh, _čekj, ekse_,
   {{0x6d5d0952,0xf99f0036,0x290b0207,0x443d0051}},	//   fesa, _olè_, _ofca_, luw_,
   {{0x6d5dbb10,0x386000e9,0x21240211,0x00000000}},	//   gesa, ywir_, camh_, --,
   {{0xbdf90332,0x7c3d007c,0x644b0a8a,0xdb070086}},	//   _کرتا_, gusr, ntgi, kijä,
   {{0x2d99bb11,0xf99fbb12,0x290b0051,0x12d10033}},	//   akse_, _alè_, _afca_, াধীদ,
   {{0x6d5d3101,0x34dc0f39,0x6fd412c3,0x8f9a0319}},	//   besa, _बर्द, ràct, _מיסי,
   {{0x6d5dbb13,0x443dbb14,0x7dd600b5,0x2d990345}},	//   cesa, kuw_, tásu, ckse_,
   {{0x26debb15,0x3940bb16,0xea000023,0x7520bb17}},	// [dfa0] _što_, rgis_, _thắt_, _remz,
   {{0x290b0024,0xf99f021e,0x443d02a2,0xea0000e2}},	//   _efca_, _elè_, duw_, _ngầu_,
   {{0xfc3f0187,0x443d01e4,0x3860bb18,0xbb3b0070}},	//   nzín_, euw_, swir_, _צעטי,
   {{0x9426027a,0xdce40169,0x7bdc0523,0x7ae100b5}},	//   емде, _laič, llru, ülte,
   {{0x656900d7,0xdb0e2f07,0x7dd600b5,0xc953011d}},	//   _daeh, hibí, láss, _גמר_,
   {{0xdb1c0093,0x6d5dbb19,0xbcfb021d,0xdb050a8a}},	//   fnré, zesa, rdéi, _emhæ,
   {{0x66e362c5,0x3afb02b5,0x9f4e3cba,0x6d5d0f25}},	//   _бора, פּגע, _rifà_, yesa,
   {{0xea0000e8,0xdcf60107,0x24490093,0x987000ee}},	//   _nhật_, _anyč, búm_, _lúča_,
   {{0x6d5dbb1a,0xdced022f,0xd5ad00b5,0x82fa103b}},	//   vesa, _inać, _بہن_, _فراز_,
   {{0x200bbb1b,0x2124066a,0x6e982325,0xa3c70b35}},	//   ícia_, samh_, двор_, _उदय_,
   {{0xdd9105bc,0x705400d1,0x00000000,0x00000000}},	//   لود_, رنگا, --, --,
   {{0x29d70443,0x7c3d1e1f,0xea000023,0x7bdc0051}},	//   nçat_, tusr, _chật_, elru,
   {{0x2d999de7,0x6d4f0088,0x48c40033,0x7dd62fba}},	//   rkse_, rfca, ্ধুর, vást,
   {{0x6d5d50aa,0xcf26004f,0x0ce100b4,0x7c3dbb1c}},	//   sesa, _أرشي, _नरीम, rusr,
   {{0xdb0e27c2,0x7dd678cf,0xdb150031,0xdb0700c3}},	//   cibí, tást, lizë, vijä,
   {{0x3f8e0054,0x5c750346,0xd9bd00b4,0x00000000}},	//   _hofu_, _алит, ्केट, --,
   {{0x3f8e0009,0x7dd6bb1d,0x7d0dbb1e,0xdb150031}},	// [dfb0] _kofu_, rást, _ifas, nizë,
   {{0x6569046a,0xab8400af,0xd12600b5,0x00000000}},	//   _saeh, _буюк, _ھم_, --,
   {{0x7c2dbb1f,0xc7c401f6,0x672501f4,0xdb072119}},	//   _hvar, усти, rahj, rijä,
   {{0x7c2d03d0,0x7dd600b5,0x7d0d009f,0x00000000}},	//   _kvar, lásr, _jfas, --,
   {{0x7d0dbb20,0x84eb0066,0x7c2d007a,0xfc3f0176}},	//   _mfas, जेंट_, _jvar, nuí_,
   {{0x644bbb21,0x443d4171,0x2449bb22,0x7c2dbb23}},	//   rtgi, ruw_, rúm_, _mvar,
   {{0x644b09e1,0xfc3f0037,0xdce402c4,0x60dc00a8}},	//   stgi, huí_, _raič, ərmi,
   {{0x96f8150d,0x7c2dbb24,0x657b008e,0x7d0dbb25}},	//   _чест_, _ovar, _unuh, _nfas,
   {{0x29d70132,0xa1560274,0x7dd600b5,0x7c2d0c6f}},	//   lças_, тању_, záss, _nvar,
   {{0x02a7562d,0x7d0dbb26,0xdced012e,0xfc3fbb27}},	//   _прем, _afas, _znać, duí_,
   {{0x29d70370,0x7c2dbb28,0xa3c002cb,0x6da60525}},	//   nças_, _avar, ीवर_, вина,
   {{0xaad50243,0x80d30083,0xdb0e20d9,0x2d96272c}},	//   _धड़क, দেষ্, ribí, трос,
   {{0xb87b0332,0xfc3fbb29,0xc5f2025a,0x7c2d0312}},	//   _szín, guí_, ידט_, _cvar,
   {{0x316d27d6,0x7dd600b5,0x4fe800d4,0x7c2d12ea}},	//   ldez_, táss, _змін_, _dvar,
   {{0xea000028,0x7c2dbb2a,0x7d0d00e9,0x3daa0210}},	//   _thật_, _evar, _ffas, _окко_,
   {{0x442d0537,0x316dbb2b,0x7d1b008a,0x798f099e}},	//   _ove_, ndez_, ðust, _cocw,
   {{0x6d56bb2c,0xa3e44092,0x316d0473,0x394600ea}},	// [dfc0] _ibya, नतम_, idez_, ļos_,
   {{0xdced012e,0xdce40207,0x00000000,0x00000000}},	//   _snać, _uniđ, --, --,
   {{0x4b370070,0x7dd60453,0x7c2dbb2d,0x442d594d}},	//   _בריל_, lásq, _zvar, _ave_,
   {{0xf8bf0310,0x63a1008e,0x25a00079,0x00000000}},	//   _adéu_, _alln, óil_, --,
   {{0x29d70132,0x69c60051,0x6d560b13,0x00000000}},	//   aças_, _ijke, _mbya, --,
   {{0x442dbb2e,0x57250037,0x00000000,0x00000000}},	//   _dve_, _مرفق, --, --,
   {{0x442d3ea6,0xdb1cbb2f,0x6d56bb30,0x00000000}},	//   _eve_, loró, _obya, --,
   {{0xd130004f,0x69c60051,0x7dd600b5,0x442d007e}},	//   حمة_, _jjke, zásr, _fve_,
   {{0x66091abc,0x032601c8,0x4fd4075c,0x67470093}},	//   _čeki, _адзн, лжит, _þrjá,
   {{0x29d7bb31,0x7d0dbb32,0x6d56bb33,0xc29a265e}},	//   nçar_, _sfas, _abya, _отец_,
   {{0x7c2dbb34,0xdd95323d,0xc7b30122,0xe5a300af}},	//   _svar, ганы, שבת_, _сиӂи,
   {{0x25a646bb,0x63b8bb35,0xfc3f1e60,0x236cbb36}},	//   nhol_, livn, tuí_, _hadj_,
   {{0x4fc60002,0x7ddd1485,0xdb150097,0x629800a0}},	//   _иска, nési, lizé, lyvo,
   {{0xc0e30f94,0x6d5609d6,0x63b80009,0x09bd03de}},	//   _точк, _ebya, nivn, ्क्य,
   {{0x6fdd2870,0x75fa01c0,0x7ddd00f7,0xdb1500ac}},	//   dèch, _různ, hési, nizé,
   {{0x7c2dbb37,0x39a49bdf,0x7d0d0848,0x995c00ee}},	//   _tvar, ашув, _ufas, _píš_,
   {{0xfc3fa050,0x7c2d07c0,0xdb1c01f7,0x25a6bb38}},	// [dfd0] quí_, _uvar, goró, dhol_,
   {{0x7ddd00a2,0x7c2904d9,0x2d8b030a,0x00000000}},	//   dési, šers, ljce_, --,
   {{0x442d1254,0xd6db2101,0x63b820f1,0xaa95002d}},	//   _sve_, фта_, divn, _синч,
   {{0x29d70132,0xceb3011d,0x442d0d3c,0x2d8b040b}},	//   rças_, סיף_, _pve_, njce_,
   {{0x7ddd014c,0x236c0107,0xa3ce022e,0x00000000}},	//   gési, _badj_, रवं_, --,
   {{0x63b86626,0xe6130206,0xbcfb006c,0x68d40274}},	//   givn, _نشر_, ldés, _ђорђ,
   {{0xada607c0,0x42520037,0x7bd501ed,0x75fa00fe}},	//   _hnúš, منور, iozu, _kůzl,
   {{0x200b00c9,0x45d542c2,0x25a6bb39,0x442d148e}},	//   ício_, _собс, chol_, _tve_,
   {{0x7bd5bb3a,0x316dbb3b,0x65942bfc,0x442dbb3c}},	//   kozu, rdez_, _тату, _uve_,
   {{0xea000019,0x645b01d7,0x62980051,0x00000000}},	//   _giặt_, _ipui, byvo, --,
   {{0x7bd53176,0x6fdd01f7,0x00000000,0x00000000}},	//   dozu, nèci, --, --,
   {{0x399c0187,0xea000023,0x00000000,0x00000000}},	//   _písm_, _nhạt_, --, --,
   {{0xf1b901a0,0x645b0176,0x6e3a12ba,0xa3c70099}},	//   miš_, _jpui, artb, _उदा_,
   {{0xd00e02aa,0xfc032e87,0xf1b917ee,0x23c30096}},	//   _على_, спро, liš_, वचिद,
   {{0x32050052,0xfaa33242,0x15f50fd1,0x7e9606c9}},	//   _july_, баро, ेदार_, _منور_,
   {{0xf1b90528,0xa2c40ac4,0xdb1c004e,0xa9671fde}},	//   niš_, िपत्, toró, лиса_,
   {{0xa2da02cb,0x57ea0de3,0x7ddd01dd,0xfc320037}},	// [dfe0] _पुन्, едам_, xési, _احب_,
   {{0xf8bf0176,0xc1b001c0,0x00000000,0x00000000}},	//   _adés_, _जग्ग, --, --,
   {{0x29d74db0,0x25a6001e,0x2d801090,0x320500ac}},	//   rçar_, thol_, _knie_, _nuly_,
   {{0x6d460464,0xf1b91635,0xdc3400ee,0xb5da42c5}},	//   ngka, jiš_, _lúče, رباء_,
   {{0x63b80690,0x2d80006a,0x69c492b7,0xf1b92eaf}},	//   tivn, _mnie_, mnie, diš_,
   {{0x69c4bb3d,0x6298bb3e,0x7ddd0320,0x3205030d}},	//   lnie, tyvo, rési, _buly_,
   {{0x63b83e69,0x25a6bb3f,0xbcfbbb40,0x645b50f2}},	//   rivn, phol_, ndér, _epui,
   {{0xb0340202,0xc03409ea,0xe5a315df,0x645b009e}},	//   аниш, аниј, _лиси, _fpui,
   {{0x80dc0083,0x3205010d,0xf99300a5,0x69c4bb41}},	//   মেন্, _euly_, מרה_, inie,
   {{0xbcfb00b5,0x69c463b6,0x65621e7b,0x6d460298}},	//   zdés, hnie, leoh, egka,
   {{0xf1b90693,0x2d923d25,0x69c4bb42,0x7bd500b8}},	//   biš_, _boye_, knie, vozu,
   {{0x69c4bb43,0xe7eb1282,0xf1b900cd,0x69d6024b}},	//   jnie, _जीना_, ciš_, joye,
   {{0x69c4147e,0x2d927616,0x7dd601ef,0x7bd5bb44}},	//   dnie, _doye_, rásp, tozu,
   {{0x69c4057e,0x6d460221,0x765cbb45,0x7f96000d}},	//   enie, agka, _opry, _pâqu,
   {{0xea000019,0x9f4700b8,0x8cd50967,0x7bd50f86}},	//   _phạt_, _jiný_, _युरो, rozu,
   {{0x69c4bb46,0x391544a0,0x89a7006c,0x69d61998}},	//   gnie, рмар, اھدہ_, goye,
   {{0xbcfb0332,0xa3e413f0,0x65622f62,0x7bd5bb47}},	// [dff0] rdés, नता_, deoh, pozu,
   {{0xf1b92a9f,0x3f9ebb48,0x7c2fbb49,0x46a73466}},	//   ziš_, nktu_, mscr, лшеб,
   {{0x69c46369,0x645bbb4a,0x7c2fbb4b,0xd7c80c74}},	//   bnie, _spui, lscr, دوله_,
   {{0x99670091,0xd6d83b21,0xfe090023,0x24191667}},	//   _стол, уту_, _hắc_, воды_,
   {{0xf1b92eaf,0x7c2f8c1a,0xd4690d6e,0x00000000}},	//   viš_, nscr, тиле_, --,
   {{0xd7f8027a,0x6fdd0443,0x386b0036,0x7c2f0036}},	//   _бус_, pèci, _iscr_, iscr,
   {{0xfe0901a5,0xf1b92209,0xaadb0066,0x7c2f0098}},	//   _mắc_, tiš_, _मुमक, hscr,
   {{0x798d19bd,0xfe090019,0x349530dd,0x3f9e0067}},	//   njaw, _lắc_, _кабр, ektu_,
   {{0x20060019,0x78ad0f38,0xb33c009f,0x644200e2}},	//   _cuoi_, nzav, _ilħn, cuoi,
   {{0x442fbb4c,0x69c4bb4d,0x81bc0080,0x7c2f9c68}},	//   msg_, znie, _svēt, dscr,
   {{0xf1b94707,0x6727003c,0x69c4bb4e,0x7c3d213d}},	//   piš_, _mejj, ynie, ersr,
   {{0x66070124,0x81bc00ea,0x9f5c0260,0x491500b4}},	//   _mujk, _dvēs, _livè_, _फ्लो_,
   {{0xef0e12b3,0x69d61010,0x2d920c1f,0xfe090028}},	//   _мм_, voye, _voye_, _bắc_,
   {{0x69c4006a,0xb92b0019,0xc4f600a5,0x2d920027}},	//   wnie, _thuỷ_, יזרי_, _woye_,
   {{0x69c4275e,0x69d6bb4f,0xc9b60431,0x7f3a0070}},	//   tnie, toye, асањ, _סעקו,
   {{0x7c2fbb50,0x2d80bb51,0xbcfb4029,0x69c40197}},	//   bscr, _unie_, rdér, unie,

   {{0x69c4bb52,0x7d040010,0xe8fabb53,0xdb1c0093}},	// [e000] rnie, _igis, тла_, borð,
   {{0x69c40080,0x998d765d,0x443dbb54,0x38790168}},	//   snie, češ_, drw_, _drsr_,
   {{0x67270484,0x443d004e,0x69c4bb55,0xbb3b00a5}},	//   _dejj, erw_, pnie, _בעיי,
   {{0x1e5600c2,0x7c240010,0x660702c4,0x3ce00118}},	//   ישער_, _kwir, _dujk, _kyiv_,
   {{0x7ddd0aca,0x9f4f00de,0x9998010b,0x24582f44}},	//   mést, _jugó_, strų_, уаль_,
   {{0xd25a1362,0x7c24bb56,0x6727007a,0x660700ee}},	//   вци_, _mwir, _gejj, _fujk,
   {{0x200601d3,0xfe670071,0xf1a61126,0xdd210355}},	//   _suoi_, _بد_, ирин, _růžo,
   {{0xa2da10aa,0x20060133,0x7c2f0602,0x7d0400bf}},	//   _पुण्, _puoi_, yscr, _ngis,
   {{0x200602e1,0x64a338d2,0x6727001c,0x00000000}},	//   _quoi_, _дата, _yejj, --,
   {{0x200601d3,0x7d04bb57,0x7e7802c4,0x3ce90009}},	//   _vuoi_, _agis, _prvp, _rzav_,
   {{0x44240189,0x78adbb58,0xfe090023,0x3f9e2b26}},	//   _hwm_, zzav, _rắc_, rktu_,
   {{0x2006bb59,0xfe090028,0x4424006f,0xac196e5f}},	//   _tuoi_, _sắc_, _kwm_, лому_,
   {{0xa2da4e29,0x9ccb0409,0x6ce70044,0x98a20107}},	//   _पुत्, тына_, ріне, _bekč_,
   {{0x09b102cb,0x69c802e1,0x53d60243,0x7c2f0037}},	//   ीच्य, éden, धविश, rscr,
   {{0x442401a9,0xff170122,0x2b5a0260,0x9f37011d}},	//   _lwm_, _דקות_, _dbpc_, _כנגד_,
   {{0x4efb0122,0x442f00e9,0x81bc00ea,0x7c2f0312}},	//   _בלוג, ysg_, _zvēr, pscr,
   {{0x7c24001e,0xfe0901a5,0xbda70919,0x798d3016}},	// [e010] _gwir, _tắc_, _محکو, rjaw,
   {{0x78ad5f44,0x7c22b667,0x7dc80225,0x00000000}},	//   rzav, _çora, hısl, --,
   {{0x41d60035,0x17f80037,0x995c00b8,0xb522060a}},	//   डकास, شركة_, _síť_, मरूप_,
   {{0xeef70d85,0x660702c4,0x9f5c00ee,0x6fdd01f7}},	//   במבר_, _vujk, _divé_, lèct,
   {{0x3ce0006d,0x5552042c,0x442400e9,0x69ddbb5a}},	//   _xyiv_, سپور, _cwm_, _ikse,
   {{0xfc3f0082,0x9cd80052,0x3949bb5b,0xa3494b41}},	//   irí_, בודה_, lgas_, узка_,
   {{0x5275002d,0x356b031a,0x3869099e,0x92640037}},	//   сулу, _иран_, lwar_, قديم,
   {{0x3949057a,0x442401e8,0xe7eb0461,0x6d4d0103}},	//   ngas_, _fwm_, _जीता_, _ncaa,
   {{0x3949bb5c,0xeae4073f,0x00000000,0x00000000}},	//   igas_, _गर्त_, --, --,
   {{0x225e012f,0xf8b20122,0x75290051,0x399c0093}},	//   _fptk_, פשי_, _heez, _vísi_,
   {{0x9f4712c3,0x59c70517,0x69ddb0e7,0x44240221}},	//   _sinó_, रचार, _okse, _zwm_,
   {{0xcb090122,0x44240221,0xa2c40ea3,0x6d4d030d}},	//   _טל_, _ywm_, िपर्, _ccaa,
   {{0x442401a9,0x9f470359,0x7529bb5d,0xfc3f0310}},	//   _xwm_, _dinò_, _meez, grí_,
   {{0x386996a7,0x3cdc1b8f,0xdb1c0031,0x394921aa}},	//   dwar_, _गुणे_, mirë, egas_,
   {{0x68e301c2,0xfaa31a12,0x4ad21b8f,0x00000000}},	//   əndi, паро, _दुखव, --,
   {{0x3949bb5e,0x09065cbe,0xf2d202b5,0x7c2404fb}},	//   ggas_, спан, פען_, _twir,
   {{0xea0000e8,0x249d006d,0xa3d7aa67,0x7c24007b}},	// [e020] _nhất_, jywm_, सवा_, _uwir,
   {{0x69ddbb5f,0x66090009,0xe8f70f68,0x7ddd01f7}},	//   _ekse, _čekr, слу_, béss,
   {{0x44240611,0x44d400af,0x7ddd00a2,0xdb1c0055}},	//   _swm_, _sπ_, céss, hirë,
   {{0x44240221,0x9986004f,0x7ddd00b5,0x00000000}},	//   _pwm_, _الحو, lésr, --,
   {{0xea000028,0x752900f6,0x44240118,0x00000000}},	//   _chất_, _deez, _qwm_, --,
   {{0x4424006f,0xd5b2042c,0x29de00e9,0x69c1000d}},	//   _vwm_, _کفر_, rïau_, élev,
   {{0x29de00e9,0xa7a70d13,0x7529073a,0xd062013b}},	//   sïau_, _укра_, _feez, ərəf,
   {{0x4424bb60,0xdb1c01f4,0x64a65951,0x752905f5}},	//   _twm_, firë, _лаба, _geez,
   {{0x2eb2035d,0x7ddd00b5,0x00000000,0x00000000}},	//   ुप्त, zéss, --, --,
   {{0xc32200c8,0x9f470176,0x75290223,0x00000000}},	//   _নাকি_, _sinò_, _zeez, --,
   {{0x8c000083,0x11d62374,0x7529073a,0x394900c7}},	//   ্ঠান_, _людя, _yeez, ygas_,
   {{0x69c8006c,0xc6930122,0xfc3f01ba,0xdb050132}},	//   édel, לאת_, trí_, _ilhé,
   {{0x9f340044,0x00000000,0x00000000,0x00000000}},	//   _делі, --, --, --,
   {{0x7ddd00b5,0xfc3f265c,0x00000000,0x00000000}},	//   téss, rrí_, --, --,
   {{0x0f570052,0x3949126f,0xfe0901a5,0x3d95257f}},	//   _היום_, tgas_, _hắn_, _микр,
   {{0x394900d8,0x7ddd2507,0x00000000,0x00000000}},	//   ugas_, réss, --, --,
   {{0xa2da25d8,0x3949bb61,0x23ab01b4,0x63a8008c}},	// [e030] _पुस्, rgas_, _høje_, _oldn,
   {{0x38690b88,0x3949bb62,0xfe090019,0xd7f89e5f}},	//   rwar_, sgas_, _mắn_, бух_,
   {{0x3869034d,0x00000000,0x00000000,0x00000000}},	//   swar_, --, --, --,
   {{0x69ddbb63,0xea0000e2,0x23ab008c,0x00000000}},	//   _ukse, _phất_, _møje_, --,
   {{0x5fc80803,0xf1c900e2,0xb60200d5,0xfe0900e2}},	//   िचाल, hạc_, _šách, _nắn_,
   {{0x80dc0299,0xe2992e02,0x63ba055c,0x00000000}},	//   _पड़े, иал_, _cmtn, --,
   {{0x25600260,0xa18900c3,0x23ab08c8,0x00000000}},	//   _bčlč_, ибка_, _nøje_, --,
   {{0xea000028,0xfe090019,0xdb1c01f4,0x7ddd00b5}},	//   _thất_, _bắn_, tirë, zésr,
   {{0xfe090023,0xae032135,0xaadb1ca8,0x60090200}},	//   _cắn_, _रंजन_, _मुसक, јном_,
   {{0x53342356,0x23ab0a8a,0x00000000,0x00000000}},	//   _неут, _bøje_, --, --,
   {{0x02a70fc5,0x2367bb64,0xdb1c0031,0x93884be9}},	//   _урам, menj_, sirë, _уста_,
   {{0x82d602b5,0x7d09010b,0x236000cb,0x23ab008c}},	//   _וועג_, žesn, đije_, _døje_,
   {{0x2247006c,0x90e75238,0xfe0901a5,0x399c00b8}},	//   lunk_, _اسان, _gắn_, _míst_,
   {{0xbea517e3,0x98a20029,0x09e200e7,0xe9df00a0}},	//   _малк, _nekā_, पत्य, _akú_,
   {{0x23ab008c,0x224700fd,0x00000000,0x00000000}},	//   _gøje_, nunk_, --, --,
   {{0xdce400cb,0x00000000,0x00000000,0x00000000}},	//   _naić, --, --, --,
   {{0xe9d70eb9,0xfe090023,0x48e356b1,0x00000000}},	// [e040] іку_, _xắn_, дотв, --,
   {{0x9b4600b5,0x7ddd0320,0x00000000,0x00000000}},	//   _بندو, lésp, --, --,
   {{0xa6ca004f,0x7bdcbb65,0x2247bb66,0x332e33c5}},	//   جوال_, moru, junk_, vafx_,
   {{0xa2da0567,0x1dca0bad,0xae5a02b5,0x224700b5}},	//   _पुष्, ाचित, יכער, dunk_,
   {{0x938a1e56,0xdb15bb67,0xb87b006c,0xeafa03c5}},	//   иска_, lizá, _szív, _حرکت_,
   {{0x7bdcbb68,0xfe090019,0x7a150035,0x224716f9}},	//   noru, _rắn_, _wąte, funk_,
   {{0xdb154078,0xe5a63649,0xa2da0243,0x224700b5}},	//   nizá, _диви, _पुश्, gunk_,
   {{0xf1261958,0x00000000,0x00000000,0x00000000}},	//   цько, --, --, --,
   {{0xa2da1bb5,0xd5b901c8,0x7522bb69,0x54ee0035}},	//   _पुर्, _усё_, mboz, _जरिए_,
   {{0x7bdc5632,0x6d400093,0xfe090023,0x8cd50026}},	//   joru, óman, _vắn_, _युगो,
   {{0xd12f0b25,0xc2c601cb,0x7ddd0051,0x79860103}},	//   _ох_, _بياي, fésp, _onkw,
   {{0xd83f0187,0xdced00cd,0xfe0900e2,0x00000000}},	//   íčku_, _snađ, _tắn_, --,
   {{0xa2be08b0,0x00000000,0x00000000,0x00000000}},	//   _वेत्, --, --, --,
   {{0x23bc00b4,0xbebc0ae0,0x7bdc0024,0x79862efd}},	//   ्चिद, rbīb, goru, _ankw,
   {{0x64420608,0xda7807b0,0x7e2a01e0,0x320c0147}},	//   hroi, оят_, _тіла_, _judy_,
   {{0x6442bb6a,0x00000000,0x00000000,0x00000000}},	//   kroi, --, --, --,
   {{0x23bc021a,0x7bdc0987,0x224700b5,0x00000000}},	// [e050] ्चाद, boru, zunk_, --,
   {{0xf6e70665,0x7bdc0395,0x81c20083,0x399c0093}},	//   оцен, coru, ৃতি_, _síst_,
   {{0x236708b7,0x69c100b5,0x320cbb6b,0x00000000}},	//   venj_, éles, _nudy_, --,
   {{0x644200f7,0x48c90033,0x071b00b4,0x9f470079}},	//   froi, _শরীর, _प्रव_, _mhná_,
   {{0xfbd00580,0x399c008a,0x63851c6b,0x320c00e0}},	//   _ستی_, _víst_, згла, _audy_,
   {{0x2247006c,0x78fa00a5,0xdb1c000d,0xfa5600fd}},	//   tunk_, _לפרו, tiré, _بریگ,
   {{0xe299750a,0x3f8901a5,0x00000000,0x00000000}},	//   сай_, _đau_, --, --,
   {{0x7bdc1a2f,0x224700b5,0x9f5cbb6c,0x320c00fe}},	//   zoru, runk_, _diví_, _dudy_,
   {{0x7bdc08a1,0x201901d2,0xdb0ebb6d,0x6442bb6e}},	//   yoru, ësi_, ribú, croi,
   {{0x224700fd,0xdb1c00a2,0x00000000,0x00000000}},	//   punk_, piré, --, --,
   {{0x7bdc2b1c,0x00000000,0x00000000,0x00000000}},	//   voru, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc0012,0x06e20831,0x00000000,0x00000000}},	//   toru, _বলছি, --, --,
   {{0xdb15795c,0xe1f900c7,0x0d1c00b4,0x00000000}},	//   tizá, lmų_, _भ्रष_, --,
   {{0x6da61000,0x7bdcbb6f,0x753b0a78,0xdee2bb70}},	//   _ника, roru, _oduz, _поши,
   {{0x7d762087,0x7bdc002d,0x8d760118,0xdb15bb71}},	//   _رابط, soru, _رابا, rizá,
   {{0x7bdc15d8,0x661b0200,0xf8c602e4,0xfe090023}},	// [e060] poru, _čuka, लपेप, _mắm_,
   {{0xfe090028,0x7e630051,0x46f60dee,0x753b021d}},	//   _lắm_, _kpnp, пчет, _aduz,
   {{0xfe050669,0xdd8f01cb,0x8b9b00a5,0x6b9b024b}},	//   _üçün_, _شوی_, _הבית, _השיד,
   {{0xfe090019,0xb33c0024,0x80dc0099,0x00000000}},	//   _nắm_, _ilħi, _पडले, --,
   {{0x397b00a5,0x320c00ac,0x00000000,0x00000000}},	//   _הטכנ, _sudy_, --, --,
   {{0x64426b73,0x320c00d5,0x995c06fe,0x00000000}},	//   rroi, _pudy_, _jíž_, --,
   {{0x27f700b8,0x673cbb72,0x3f980093,0x00000000}},	//   řené_, _idrj, örum_, --,
   {{0xfe090019,0x6442bb73,0x9f5c0453,0x7ae1033b}},	//   _cắm_, proi, _viví_, ülti,
   {{0x660e00ee,0xb87b006c,0xb4aa99c3,0x04431e9f}},	//   _hubk, _nyíl, _указ_, _петн,
   {{0x995c00b8,0x00000000,0x00000000,0x00000000}},	//   _níž_, --, --, --,
   {{0x68e60298,0x1df90421,0x00000000,0x00000000}},	//   _lykd, жены_, --, --,
   {{0xfe090023,0x7ae50421,0x00000000,0x00000000}},	//   _gắm_, _ryht, --, --,
   {{0x61e20484,0xa2c40edf,0xf1b300a5,0x673c0124}},	//   _ikol, िपक्, _אסף_, _odrj,
   {{0x25a6012f,0x661c0228,0x9f5c0183,0x00000000}},	//   hkol_, _otrk, _divã_, --,
   {{0xaf5b00a5,0x1f5b00a5,0x61e2073a,0x37c40033}},	//   _הכוכ, _הדוא, _kkol, ্তার,
   {{0xf7730ef5,0x61e20484,0x199402fb,0x00000000}},	//   کار_, _jkol, нася, --,
   {{0xa2be25d8,0xa3dc00a1,0x61e208c7,0x672e0c6f}},	// [e070] _वेस्, ठवा_, _mkol, _bebj,
   {{0x2c6f0069,0x61e2007a,0x00000000,0x00000000}},	//   _iżd_, _lkol, --, --,
   {{0xf770099f,0x36340037,0xfbd00bdf,0xb9041cc3}},	//   داق_, فرنس, _حتي_, _पु_,
   {{0x6d4fbb74,0x25a6046a,0x29350070,0x61e201a8}},	//   ngca, gkol_, _קאָן_, _nkol,
   {{0x69cd0254,0x764300b5,0x6560009e,0xf8d1046c}},	//   mnae, ányb, _dbmh, _सखिय,
   {{0xa2e500af,0xfe0901a5,0x61e20273,0x69df01e9}},	//   молд, _sắm_, _akol, loqe,
   {{0x61e20069,0x660e00ee,0xa1f50279,0x00000000}},	//   _bkol, _gubk, мџиј, --,
   {{0x2360042a,0x69cdbb75,0x6d5d02a2,0x753b013b}},	//   đija_, nnae, jfsa, _uduz,
   {{0xbf05035d,0x2054bb76,0x660ebb77,0x656bbb78}},	//   रश्न_, нтэр, _zubk, megh,
   {{0xd9ba0808,0xee391d32,0xdb1e0248,0x2d89bb79}},	//   _इष्ट, оно_, _empê, _anae_,
   {{0x9d466239,0x644bbb7a,0xdb080248,0xfe090019}},	//   менд, lugi, _élém, _tắm_,
   {{0x9f451f10,0x656b12a2,0x2d8902d7,0x61e20107}},	//   illé_, negh, _cnae_, _gkol,
   {{0x61fb01a8,0x645908f3,0x644b7ad4,0x61e90225}},	//   mmul, ntwi, nugi, mlel,
   {{0x61e969fe,0x61fb499a,0x68e603bc,0x64590e54}},	//   llel, lmul, _rykd, itwi,
   {{0xea000028,0x4adb0084,0x09e6292e,0x25bf002d}},	//   _chết_, _मुआव, довн, _omul_,
   {{0xfe090023,0x644bbb7b,0xf2d20070,0xdb1c0138}},	//   _lắk_, kugi, דעל_, mirí,
   {{0x2007bb7c,0x661cbb7d,0xa3dd01c0,0x23dd157d}},	// [e080] _kini_, _strk, णका_, यवाद,
   {{0x260f0302,0x200f348f,0x25adbb7e,0x68e600d8}},	//   _तूही_, _mugi_, _alel_, _vykd,
   {{0x2007bb7f,0x61e90bc5,0x200f3df5,0x25a6bb80}},	//   _mini_, klel, _lugi_, tkol_,
   {{0x644b9c49,0xea000028,0x2007bb81,0x29d70484}},	//   fugi, _đặc_, _lini_, għad_,
   {{0x61e943fa,0x6281bb82,0x644b0036,0x76450051}},	//   dlel, _arlo, gugi, arhy,
   {{0x20072176,0x61e21d48,0x62811bd8,0x61fb073a}},	//   _nini_, _skol, _brlo, emul,
   {{0x661c0c21,0x7996006f,0x644b010b,0x6281009e}},	//   _utrk, ojyw, augi, _crlo,
   {{0xdb1cbb83,0x2007bb84,0x61fb0dc3,0x30a64a35}},	//   dirí, _aini_, gmul, дров,
   {{0x2007003c,0xc05a02ce,0x6281bb85,0xa0670274}},	//   _bini_, цій_, _erlo, дања_,
   {{0x200fbb86,0x61e20484,0xb4aa0992,0x20076b01}},	//   _dugi_, _wkol, खनी_, _cini_,
   {{0x2007bb87,0x61e960f9,0x628100c5,0xdb1e00e0}},	//   _dini_, blel, _grlo, _impè,
   {{0x61e2a024,0x2007bb88,0x7bcebb89,0x61e9bb8a}},	//   _ukol, _eini_, enbu, clel,
   {{0x2007bb8b,0x61e0011e,0xd3780009,0xd90f00d1}},	//   _fini_, moml, _kać_, یید_,
   {{0x09c700a1,0x2007bb8c,0xdb1c0b06,0x61e0080a}},	//   रच्य, _gini_, birí, loml,
   {{0xdb1c0b06,0x69cd0254,0xfe6f183b,0x69df0055}},	//   cirí, tnae, _ندي_, toqe,
   {{0x2007bb8d,0x200f052e,0x7bce0051,0xdb0700c3}},	//   _zini_, _yugi_, anbu, kijö,
   {{0x20071190,0x7d0d2790,0x3f9cbb8e,0x656b002d}},	// [e090] _yini_, _igas, _kovu_, vegh,
   {{0x644b0232,0x3f9c0009,0xd378022f,0x69cd1e1a}},	//   vugi, _jovu_, _nać_, snae,
   {{0x41de00b4,0x61e0ace9,0x7c2dbb8f,0xa2be0d2a}},	//   मवास, koml, _hwar, _वेल्,
   {{0x3f9c003d,0x91fc0029,0x644bbb90,0x4efb0070}},	//   _lovu_, _spān, tugi, קלאג,
   {{0x656bbb91,0x7d0d011e,0x5fde112b,0x61e03e69}},	//   regh, _mgas, नकाल, doml,
   {{0x3f9c6207,0x7c2dbb92,0x628114d8,0x6459bb93}},	//   _novu_, _mwar, _prlo, rtwi,
   {{0xc2e700c8,0x7c2d012f,0x61fbbb94,0x6459bb95}},	//   গেনি_, _lwar, tmul, stwi,
   {{0x7d0dbb96,0x20074367,0x7c2d012f,0x7dc80095}},	//   _ngas, _sini_, _owar, nıst,
   {{0x2007bb97,0x61e9bb98,0x3ce901e8,0x321e0118}},	//   _pini_, rlel, _nyav_, _etty_,
   {{0x7d0d189e,0x61fb9097,0xdb1c27c2,0x442db3ac}},	//   _agas, smul, tirí, _iwe_,
   {{0x2007bb99,0x6609bb9a,0x7c2d0122,0xddc60192}},	//   _vini_, _kiek, _awar, ебни,
   {{0x20070260,0x442db8ae,0xdb1e67f7,0x7c2d0010}},	//   _wini_, _kwe_, _impé, _bwar,
   {{0x2007bb9b,0x442d0c1f,0x6609bb9c,0x7d0d0139}},	//   _tini_, _jwe_, _miek, _dgas,
   {{0x7c2dbb9d,0x6609bb9e,0x442d33f4,0x7d0d073a}},	//   _dwar, _liek, _mwe_, _egas,
   {{0x442d0273,0xdfce183b,0x660901ed,0xdb1c021d}},	//   _lwe_, _ديو_, _oiek, eirã,
   {{0x6609bb9f,0x442dbba0,0x3f9c0254,0xed640187}},	//   _niek, _owe_, _zovu_, _drží_,
   {{0x7c2dbba1,0x6d560232,0x18675b66,0x442d0c22}},	// [e0a0] _gwar, _icya, нати_, _nwe_,
   {{0x5c5b0317,0xf99f0118,0x660901ed,0x7d0d0288}},	//   _צדיק, _hièl_, _aiek, _zgas,
   {{0x34a8046c,0x7c2d3dd2,0x6609bba2,0xcb5700a5}},	//   कन्द, _zwar, _biek, _אסיה_,
   {{0x442d39a7,0x6609004e,0x799d0159,0xa2da000c}},	//   _bwe_, _ciek, _gosw, _पुग्,
   {{0xb4aa006a,0x66090ce8,0x3ce901e8,0x442d0088}},	//   खने_, _diek, _xyav_, _cwe_,
   {{0x442d142f,0xb7da2149,0x00000000,0x00000000}},	//   _dwe_, _روزا_, --, --,
   {{0x442dbba3,0x38720297,0xa2da0066,0x61e0bba4}},	//   _ewe_, lwyr_, _पुख्, toml,
   {{0xd130004f,0x395200e9,0x3f9c435f,0x7c3b0207}},	//   جمة_, ngys_, _sovu_, šuri,
   {{0x442dbba5,0x3872001e,0x6b9e053e,0x61e0bba6}},	//   _gwe_, nwyr_, _oopg, roml,
   {{0x66090a75,0x7c2d0010,0x7d0d0036,0x6d560371}},	//   _ziek, _rwar, _sgas, _acya,
   {{0x7c2d491f,0x3872001e,0x63a502b1,0xdb1c0176}},	//   _swar, hwyr_, öhne, dirà,
   {{0x717300d1,0xdd12037a,0x7dc800a8,0x7c2d0107}},	//   _مهما, rüşm, xıst, _pwar,
   {{0x69c1000d,0xc19b00a5,0x8fa65544,0x7d0d023a}},	//   èlem, _משאי, _паде, _vgas,
   {{0x38720297,0xf4120083,0x3f9c1476,0xd0070043}},	//   dwyr_, _হবার_, _uovu_, _зече_,
   {{0x6b9e1b25,0xf99f0107,0xfbd201c0,0x00000000}},	//   _dopg, _fièl_, _सदरम, --,
   {{0x7d0dbba7,0x7c2dbba8,0xdb1c0279,0x387200e9}},	//   _ugas, _twar, tirã, fwyr_,
   {{0x38720297,0x6609677d,0x7ddd006c,0x7c2d0d95}},	// [e0b0] gwyr_, _riek, kész, _uwar,
   {{0x6609bba9,0x442dbbaa,0x2cb30448,0xb33c0069}},	//   _siek, _rwe_, ındı_, _joħd,
   {{0x660992b7,0x6e3abbab,0x442dbbac,0x799d0103}},	//   _piek, nstb, _swe_, _tosw,
   {{0x7bc7bbad,0x27e1bbae,0x442d2505,0xdb1cbbaf}},	//   liju, sohn_, _pwe_, mirá,
   {{0x75240138,0xa8f5021a,0x00000000,0x00000000}},	//   ñiza, _आरिफ_, --, --,
   {{0x7bc7bbb0,0x6609004e,0x64a28f0d,0x7ddd006c}},	//   niju, _wiek, раша, gész,
   {{0x225601ca,0x52750012,0x6609a2b5,0xdb1c0453}},	//   نلود_, тулу, _tiek, nirá,
   {{0xceb8004e,0x442d0010,0x20190132,0x00000000}},	//   dzę_, _twe_, ísio_, --,
   {{0x442dbbb1,0x7bc7bbb2,0xf99f0107,0x33750200}},	//   _uwe_, kiju, _nièm_, _игар,
   {{0x645b8169,0x657bbbb3,0xa28300d1,0x7bc7bbb4}},	//   _iqui, _hauh, _میتو, jiju,
   {{0x7bc7bbb5,0x273c01c0,0x657ba70d,0x415511ab}},	//   diju, lání_, _kauh, _авес,
   {{0xdb1c0138,0xf99f027a,0x657bbbb6,0x6b9e0051}},	//   dirá, _noè_, _jauh, _sopg,
   {{0x273c01c0,0x853a00a5,0xf8bf0176,0x6e2402a7}},	//   nání_, וגרי, _meés_, _čibe,
   {{0x8fa20573,0x2d9901f4,0x657b01d7,0x7bc7bbb7}},	//   _ваше, ajse_, _lauh, giju,
   {{0xceb80035,0x273c00b8,0xdb1c0176,0x00000000}},	//   czę_, hání_, rirà, --,
   {{0x273c01c0,0x9f450079,0x657bbbb8,0x3872016e}},	//   kání_, illí_, _nauh, twyr_,
   {{0x26170279,0x2d5a02c6,0x7e640009,0x00000000}},	// [e0c0] _aço_, _všeč_, _ćipi, --,
   {{0x273c000c,0x38720297,0xdb1cbbb9,0x7bc7164b}},	//   dání_, rwyr_, birá, ciju,
   {{0x645bbbba,0x1dc600b1,0x7ddd006c,0x69c8bbbb}},	//   _aqui, _लगात, vész, édes,
   {{0x2d5a02a7,0xe9a605a1,0x00000000,0x00000000}},	//   _ušeč_, _рамп, --, --,
   {{0x77910a86,0xa2da021a,0x00000000,0x00000000}},	//   _گیلا, _पुज्, --, --,
   {{0x7c220225,0x00000000,0x00000000,0x00000000}},	//   _çoru, --, --, --,
   {{0x645b0fe4,0x877b0070,0x133900b5,0x7ddd00b5}},	//   _equi, _קאלי, رتوں_, rész,
   {{0x28c70e6f,0x80e00083,0x16770122,0x7bc7bbbc}},	//   _रेडि, _পৃষ্, _בגלל_, ziju,
   {{0xdfda07e5,0xb46500f8,0x7e6d0207,0x00000000}},	//   дън_, _مدله, _ćapa, --,
   {{0xaadb0084,0xdce4011c,0x6fb45238,0x94060934}},	//   _मुझक, _naiđ, امدا, _شواه,
   {{0x777cbbbd,0xdd915002,0x42561897,0x03a30202}},	//   _marx, مود_, _штат, _њихо,
   {{0x5066081b,0x6e3a1167,0xe046081b,0x23690254}},	//   _атка, rstb, _анди, đaje_,
   {{0xceb8004e,0x4426bbbe,0x5c74657c,0xab640067}},	//   szę_, npo_, алят, ężni,
   {{0x442609ab,0x8f34876f,0xdb1cbbbf,0x777c1505}},	//   ipo_, _секц, tirá, _narx,
   {{0xa3ca0084,0x273c00b8,0x7bc7bbc0,0x00000000}},	//   _लगन_, zání_, riju, --,
   {{0x1e970052,0x7bc70a93,0xdb1c365a,0x5d5505c7}},	//   _יכול_, siju, rirá, _скит,
   {{0x777c002a,0x657b0086,0x7bc7010b,0x44260009}},	// [e0d0] _barx, _rauh, piju, jpo_,
   {{0x273c0311,0x7643006c,0x777c0392,0x2ca401ff}},	//   vání_, ányo, _carx, ämde_,
   {{0xdce40024,0x645b0a1f,0x7bc50027,0xa3d6022e}},	//   _iniġ, _squi, _imhu, ाचन_,
   {{0x7995294d,0x273c00b8,0x31b100ac,0x7d0900ea}},	//   _симф, tání_, _oáza_, _tīrī,
   {{0x798f001e,0x44260dc3,0x657b00c3,0xc7cb010b}},	//   _incw, gpo_, _vauh, _жыве_,
   {{0x273c00b8,0x60cd0124,0xfe0a00e2,0xdce40069}},	//   rání_, _žamo, _hắt_, _jniġ,
   {{0x657bbbc1,0x4426bbc2,0x02c300b4,0xdce40069}},	//   _tauh, apo_, _वेशभ, _mniġ,
   {{0x96f800af,0x273c0355,0x31b100ee,0x00000000}},	//   _рест_, pání_, _báza_, --,
   {{0xfe0a0028,0x67170035,0x60090d13,0x7bc54e42}},	//   _mắt_, _तलाक_, нним_, _omhu,
   {{0x777c0955,0x443fbbc3,0x53b700a1,0x23b705f8}},	//   _xarx, _ivu_, _अतिश, _अतिद,
   {{0xed5a86a3,0xada602c4,0x6da62351,0xdb1c008a}},	//   нон_, ганл, гина, gnrý,
   {{0x644b0036,0x7bc5bbc4,0x63a100b5,0x3f8e030d}},	//   orgi, _amhu, _holn, _enfu_,
   {{0x63a1bbc5,0x00000000,0x00000000,0x00000000}},	//   _koln, --, --, --,
   {{0x317fbbc6,0x443f149d,0x903a0070,0xc2f60033}},	//   lduz_, _mvu_, _טענה, _চলতি_,
   {{0xd9460de3,0xfe0a0028,0xc3320d85,0x63a1bbc7}},	//   леви, _bắt_, מום_, _moln,
   {{0x443f0537,0xfe0a01a5,0x317fbbc8,0xdb1ebbc9}},	//   _ovu_, _cắt_, nduz_, _impí,
   {{0xe9d70423,0x6735bbca,0xfe0a0023,0x6d4401a3}},	// [e0e0] укт_, _bezj, _dắt_, _idia,
   {{0x7c240463,0x6b560f6d,0xb87b01ef,0x26180785}},	//   _itir, _стих, _oxíf, _बंदी_,
   {{0xfaa60f9d,0x443f008c,0x86c60079,0x7d0900f4}},	//   _сано, _avu_, ديان, žest,
   {{0x35e52659,0x63a1009e,0xfe0a0023,0x38790118}},	//   аців, _aoln, _gắt_, _fssr_,
   {{0x63a10169,0x777cbbcb,0x69c6bbcc,0x661501a3}},	//   _boln, _tarx, _imke, _euzk,
   {{0x63a1bbcd,0x7c24002f,0x00000000,0x00000000}},	//   _coln, _mtir, --, --,
   {{0x44260a20,0x63a175bc,0x644b01ed,0x27ea028b}},	//   spo_, _doln, argi, _ikbn_,
   {{0x4426089e,0x6d44004f,0x7c240124,0x443f008c}},	//   ppo_, _ndia, _otir, _fvu_,
   {{0x7c2401d5,0x63a1bbce,0x66157ca1,0x443f008c}},	//   _ntir, _foln, _zuzk, _gvu_,
   {{0x6d4430c0,0x4424bbcf,0x3860bbd0,0x31b10faa}},	//   _adia, _itm_, itir_, _váza_,
   {{0x7c24bbd1,0x4ea63471,0x69c62069,0xbebc00ea}},	//   _atir, урпа, _omke, icīg,
   {{0xac19022b,0x3860bbd2,0x7a15004e,0x27ea012f}},	//   кому_, ktir_, _wątk, _lkbn_,
   {{0x2a7a229d,0x628800ac,0x6d4400e9,0x4424700b}},	//   _aspb_, _hrdo, _ddia, _jtm_,
   {{0x6d44143f,0xfe0a0019,0x69c8000d,0x46b40099}},	//   _edia, _sắt_, èden, ंनाह,
   {{0x7c240095,0x00000000,0x00000000,0x00000000}},	//   _etir, --, --, --,
   {{0x3860bbd3,0xbebc0228,0x6d5a00b5,0x8e470037}},	//   ftir_, ecīg, őtar, _إليك_,
   {{0x981716e6,0x2a7a0009,0xb6c900b5,0xfe0a0023}},	// [e0f0] ابرا, _espb_, ھائے_, _vắt_,
   {{0xd6db4dcc,0x6288bbd4,0xfc3f0037,0x7bc5008d}},	//   нте_, _ordo, msí_, _umhu,
   {{0xd6dbbbd5,0xfe0a01a5,0x443f0254,0x63a10035}},	//   хта_, _tắt_, _svu_, _roln,
   {{0x63a12ce1,0x00000000,0x00000000,0x00000000}},	//   _soln, --, --, --,
   {{0x63a1bbd6,0x6288bbd7,0x228301d6,0x3860081d}},	//   _poln, _ardo, _sık_, ctir_,
   {{0x8c1c0070,0x443f5d11,0xfc3f0079,0x6288011c}},	//   עווי, _vvu_, isí_, _brdo,
   {{0xe2990bba,0x5b580052,0x63a160f3,0xea000019}},	//   тай_, אשון_, _voln, _chặt_,
   {{0x63a1004e,0x628334f8,0x48fc000c,0x628800d5}},	//   _woln, rvno, लेको_, _drdo,
   {{0x628801d6,0x339504cd,0x63a100fd,0x65690027}},	//   _erdo, _پلاز, _toln, _ibeh,
   {{0xb068004f,0x9e6500d8,0x6d4407c0,0x7c24009f}},	//   اصيل_, авод, _sdia, _rtir,
   {{0x75f8043f,0xf7720122,0x28c702e4,0x60ce0095}},	//   líza, חקי_, _रेसि, _əhmə,
   {{0x3860008d,0x2a7a5fa9,0x442405eb,0x7bd502d7}},	//   ytir_, _rspb_, _ytm_, enzu,
   {{0xd1b800d1,0x55760070,0x75f80042,0x6569007b}},	//   _حالا_, בערן_, níza, _mbeh,
   {{0xbcfb008a,0x00000000,0x00000000,0x00000000}},	//   mfél, --, --, --,
   {{0xdb25006c,0x6d4400d7,0x6569bbd8,0xeb970368}},	//   ásár, _tdia, _obeh, шир_,
   {{0x3860bbd9,0x13d2018d,0xe9d76e70,0xe206008a}},	//   ttir_, _तद्भ, акс_, _þótt_,
   {{0xfbdf0370,0xa3e5007c,0x47c600d8,0x9f470187}},	// [e100] guês_, नवा_, абав, _akné_,
   {{0x18670b78,0x320f0187,0xdb1c0079,0x2d80bbda}},	//   рафи_, _ligy_, rnró, _haie_,
   {{0xdb1e0176,0x00000000,0x00000000,0x00000000}},	//   _impà, --, --, --,
   {{0x3860bbdb,0xb8cc0083,0xbcfb0b22,0x81bc02d4}},	//   ptir_, _কই_, kfél, _atēn,
   {{0xdce40496,0x69d6bbdc,0x628807e7,0x2d80018d}},	//   _obič, mnye, _srdo, _maie_,
   {{0x051600c8,0x6602bbdd,0x2fc70159,0x026a0eb1}},	//   ারের_, smok, _nmng_, вший_,
   {{0x95960202,0x69d6000e,0xa59600d4,0x6684132d}},	//   _краљ, onye, _кращ, _دیال,
   {{0x69d6bbde,0x23690a78,0x2fc70430,0x518641bf}},	//   nnye, đaja_, _amng_, рука,
   {{0x6ad300b4,0xbcfb0146,0xe5d90dec,0x00000000}},	//   _सश्र, gfél, _сфрј_, --,
   {{0x2d926251,0x81460609,0x1fa600af,0x6569b046}},	//   _anye_, _چنان, рриг, _zbeh,
   {{0x2d80250a,0xc224006c,0x2486054e,0x212d0036}},	//   _baie_, _اکتو, lvom_, bbeh_,
   {{0x200ebbdf,0x248600f4,0x67290207,0x00000000}},	//   _wifi_, ovom_, _đejm, --,
   {{0xa3ca1db6,0x2d920107,0x200ebbe0,0x00000000}},	//   _लगा_, _dnye_, _tifi_, --,
   {{0x2d9210a2,0xfd1f07e5,0x2d850035,0xfc3fbbe1}},	//   _enye_, scì_, śle_, rsí_,
   {{0xfb8401c8,0xf9c701d3,0x199502fb,0xb87b00b5}},	//   цыян, ащан, бавя, _nyír,
   {{0x24860a78,0x391506cd,0xdb1e0176,0xfc3fbbe2}},	//   kvom_, смар, _empà, psí_,
   {{0xa3d60429,0x3dc9010d,0x24860009,0x6a7c0523}},	// [e110] ाचा_, _imaw_, jvom_, _påfå,
   {{0x2d8001d7,0xe70b0934,0x75f801ef,0x00000000}},	//   _zaie_, نتان_, víza, --,
   {{0x75150514,0xa6470088,0xa50f012f,0xa80201ef}},	//   مواض, شخان, िश्च_, íñan,
   {{0xb995004f,0xdb1e002a,0xbcfb00b5,0x2419021f}},	//   _الحب, _impá, yfél, годы_,
   {{0xb8cc00c8,0x24890132,0x7844002d,0xfbdf021d}},	//   _কে_, íam_, _мэрж, quês_,
   {{0xfe0a01a5,0x75f80391,0x69cd001e,0xe7872632}},	//   _lắp_, ríza, liae, _тумо,
   {{0x0bb800a5,0x3875027d,0xdd2c00c7,0x00000000}},	//   שלום_, şarı_, _lėšo, --,
   {{0x224901cc,0x69cd0297,0xfe0a0023,0x6569bbe3}},	//   čak_, niae, _nắp_, _ubeh,
   {{0x95c85017,0x78adbbe4,0x2d80bbe5,0x00000000}},	//   _тура_, nyav, _raie_, --,
   {{0x3fb70083,0xd9c4021a,0xbcfb008a,0x67f00086}},	//   ীক্ষ, _षष्ट, rfél, täji,
   {{0xbebc0080,0xdee518cd,0xfe0a0023,0x2d80bbe6}},	//   ecīb, сони, _bắp_, _paie_,
   {{0xed57311c,0xea000019,0xfe0a0023,0x260a0099}},	//   бою_, _đắc_, _cắp_, िषयी_,
   {{0x3f6902f3,0x69cd0297,0x61e94669,0x98a00207}},	//   _било_, diae, moel, mbić_,
   {{0x61e9bbe7,0x09d00099,0x00000000,0x00000000}},	//   loel, सच्य, --, --,
   {{0x248601ba,0x2d8000af,0x00000000,0x00000000}},	//   zvom_, _taie_, --, --,
   {{0xfd12083a,0x69cdbbe8,0x2ef802b1,0xfe0a00cc}},	//   _عجب_, giae, ürfe_, _gắp_,
   {{0x69d6100b,0x78ad00d7,0xb7160037,0x00000000}},	// [e120] rnye, gyav, مباش, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b7b0100,0x7bce0371,0x61e9bbe9,0x7c3600e9}},	//   _גרינ, mibu, koel, _hwyr,
   {{0x24860936,0x844602e7,0x61e9b92f,0x7bce3cc2}},	//   tvom_, مختل, joel, libu,
   {{0x61e93440,0xc4480118,0x78ad0371,0x00000000}},	//   doel, شیان_, cyav, --,
   {{0xf99f0c1f,0x9f58027d,0x248600cd,0x00000000}},	//   _chèf_, örü_, rvom_, --,
   {{0x7d16001e,0x9c8701ba,0x61e9099e,0xb2861ac5}},	//   _ogys, _kočí, foel, сылк,
   {{0x75d600bf,0x79841d17,0x61e906a2,0xdb0500f6}},	//   _ايرا, ndiw, goel, _bohê,
   {{0xf4844e4a,0x3ce0006d,0x7bcebbea,0x75f801ef}},	//   _بازی, _nxiv_, kibu, lízo,
   {{0x3104018d,0xfe0a01a5,0x487b0070,0x673e00b5}},	//   शेषः_, _sắp_, נטיס, napj,
   {{0xbcfb024e,0x51863d4d,0x7c3600e9,0xa3e50d2a}},	//   rfém, _гула, _awyr, नवर_,
   {{0x8cb597cb,0xd24f0037,0x644200c3,0x9f4500c3}},	//   उनलो, _سنه_, osoi, ellä_,
   {{0x64423cd9,0x6ce7004b,0xac192dc3,0xb33c035f}},	//   nsoi, сіне, рогу_, _joħo,
   {{0x7d160332,0x7bce0cb9,0x69da0248,0x69cd001e}},	//   _egys, gibu, éten, wiae,
   {{0x7f3b012b,0x5e26096a,0x75f801ba,0x69cd00e9}},	//   _געוו, _اعتق, vízn, tiae,
   {{0x383500ef,0x23ab01b4,0x78ad94cd,0x798408dd}},	//   жнар, _højt_, tyav, gdiw,
   {{0x69cd02c7,0xdb0500da,0x7bce018c,0x9f470037}},	// [e130] riae, _kohë, bibu, _ghnó_,
   {{0x78ad030d,0x61e93ebc,0x69cdbbeb,0x161d0127}},	//   ryav, zoel, siae, _बंदर_,
   {{0x163b0514,0xb8f03979,0x61e9002f,0x59f9002d}},	//   اسطة_, _वे_, yoel, _веня_,
   {{0x7afabbec,0x23ab008c,0xf99f0107,0x00000000}},	//   ütte, _løjt_, _shèf_, --,
   {{0x046734a2,0x61e902e6,0x9f4500f7,0x69dd0223}},	//   стем, voel, solé_, _ijse,
   {{0x75220036,0xc7b8010b,0xd2a90200,0x00000000}},	//   acoz, _лёс_, икле_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9fb0d00,0x7bce1815,0xd9f90067,0x41a918cd}},	//   ्षित_, zibu, ंतित_, рвин_,
   {{0x7bce0186,0x9f4500c3,0x98a00207,0x00000000}},	//   yibu, yllä_, rbić_, --,
   {{0x3e7abbed,0x61e40c99,0x2011006c,0xb33c035f}},	//   _būt_, čila, özi_, _joħl,
   {{0xd9fb02cb,0x753b0a75,0x61e9bbee,0xa3d6018d}},	//   ्षात_, _keuz, poel, ाचर_,
   {{0x248dbbef,0x1d0a03e6,0x7bce01d5,0xed5a2860}},	//   _krem_, иени_, wibu, шом_,
   {{0x7bcebbf0,0xccfa0208,0x00000000,0x00000000}},	//   tibu, рхні_, --, --,
   {{0xb33c0024,0x00000000,0x00000000,0x00000000}},	//   _noħl, --, --, --,
   {{0x9c872ab5,0x201f02d7,0x3b0a0142,0xada60c7e}},	//   _počí, lqui_, рево_, _макл,
   {{0x3ce00d4b,0x753bbbf1,0x7bcebbf2,0x75f801ba}},	//   _txiv_, _neuz, sibu, vízo,
   {{0xe7e6009a,0x201f08bf,0x7bce034d,0xa3ca007c}},	// [e140] कवला_, nqui_, pibu, _लगल_,
   {{0x46f601d3,0x3f85bbf3,0xdb07008d,0x213f021d}},	//   очет, ndlu_, skjá, hauh_,
   {{0xa96a0370,0xdb230d4f,0x869a2dc1,0x00000000}},	//   _кина_, _توپی, штат_, --,
   {{0x213f005d,0x64420421,0x248dbbf4,0x00000000}},	//   jauh_, tsoi, _brem_, --,
   {{0x3940bbf5,0x240a2c61,0xb226003e,0x752201ef}},	//   mais_, анди_, klæð, rcoz,
   {{0x7522bbf6,0xdb050815,0x248d099e,0x64423e6b}},	//   scoz, _bohè, _drem_, rsoi,
   {{0x6442bbf7,0x248d01f7,0x9663bbf8,0x3f85248b}},	//   ssoi, _erem_, _окре, ddlu_,
   {{0x3940bbf9,0x248d0909,0x673cbbfa,0x9f5c00ee}},	//   nais_, _frem_, _herj, _divý_,
   {{0x673c0464,0x248d008b,0x28d00af9,0x394001ef}},	//   _kerj, _grem_, _सेमि, iais_,
   {{0x3940bbfb,0x661cbbfc,0xbfaa002d,0xd00703e6}},	//   hais_, _kurk, ртие_, оење_,
   {{0x394033a9,0x673c254b,0x213f00d7,0xe81c00ab}},	//   kais_, _merj, bauh_, _भूसा_,
   {{0x63a8086d,0x69da0332,0x39402686,0x661c3086}},	//   _hodn, étel, jais_, _murk,
   {{0x63a8bbfd,0x3940bbfe,0x661cbbff,0x0ca895ec}},	//   _kodn, dais_, _lurk, отри_,
   {{0x673cbc00,0x63a80009,0xd007002d,0x00000000}},	//   _nerj, _jodn, _дече_, --,
   {{0x63a80116,0xaff90070,0x661cbc01,0x394000e9}},	//   _modn, _פּני, _nurk, fais_,
   {{0x3940bc02,0x2d850080,0x63a815d8,0x799415d5}},	//   gais_, ēles_, _lodn, мисф,
   {{0x673c49c2,0x661c03cb,0x753b02a2,0x00000000}},	// [e150] _berj, _aurk, _reuz, --,
   {{0xf7731b15,0x6560004f,0x249d0221,0x6d5d4793}},	//   بار_, _acmh, vxwm_, lgsa,
   {{0x248d02c4,0x661cbc03,0x05190594,0x673c871b}},	//   _srem_, _curk, مياب_, _derj,
   {{0x3940bc04,0x248d0392,0xe61801e0,0x7e9b00a5}},	//   cais_, _prem_, іді_, יסבו,
   {{0xc864046e,0xa3d600a1,0x673cbc05,0xdb17002a}},	//   _отри, ाचं_, _ferj, _alxé,
   {{0x248d002d,0x661c1870,0x673c2f21,0x00000000}},	//   _vrem_, _furk, _gerj, --,
   {{0x63a80187,0x057710ad,0x61e402c6,0x67070067}},	//   _dodn, _وارد, čiln, वेशक_,
   {{0x248d872b,0xdb0500f7,0x205522a9,0x764300fd}},	//   _trem_, _cohé, птор, ányu,
   {{0xdb1e03ad,0xc21b0066,0xb36701d3,0x657900a5}},	//   _ympä, _पूरब_, _мъжк, mewh,
   {{0x3940bc06,0xd9c30083,0x201f0d9a,0x6d5d7eb3}},	//   zais_, ্কিম, rqui_, egsa,
   {{0x201fbc07,0x39403645,0x764504fb,0x00000000}},	//   squi_, yais_, nshy, --,
   {{0x6281bc08,0x3f830528,0xdb1c004f,0x6d5dbc09}},	//   _islo, žju_, mhré, ggsa,
   {{0x3940bc0a,0x6459bc0b,0x1c430823,0x7f951538}},	//   vais_, nuwi, нням, _надх,
   {{0xe81f08a9,0x201d010d,0x2d8498b3,0xab271d91}},	//   _बढ़ा_, _iuwi_, žme_, зора_,
   {{0x3940bc0c,0x3af500c3,0x64593568,0x7f3a024b}},	//   tais_, дятс, huwi, _העצו,
   {{0x673c003c,0x201d01ca,0x442f0159,0x6459053e}},	//   _serj, _kuwi_, kpg_, kuwi,
   {{0x3940bbf9,0x673cad58,0x661c0421,0x2919099e}},	// [e160] rais_, _perj, _surk, _dgsa_,
   {{0x6281011c,0x3940bc0d,0x661cbc0e,0x7f4101ae}},	//   _oslo, sais_, _purk, nalq,
   {{0x3940bc0f,0x673cbc10,0x64591192,0xcb0a00f8}},	//   pais_, _verj, euwi, _ديدن_,
   {{0x63a802c6,0x271900b8,0x986a00af,0x661c0298}},	//   _sodn, třní_, _лимб_, _vurk,
   {{0x673caa66,0xc95302b8,0x6459010d,0x4519010b}},	//   _terj, _אמר_, guwi, іцця_,
   {{0x661c08ee,0x798604fb,0x00000000,0x00000000}},	//   _turk, _hakw, --, --,
   {{0x63a81834,0x66e3bc11,0x7f410138,0xdb1cbc12}},	//   _vodn, _зора, dalq, ghré,
   {{0xcb130052,0x201d24a8,0x63a80035,0x6459010d}},	//   עלה_, _buwi_, _wodn, buwi,
   {{0x5ea90083,0x69c10035,0x79865c3d,0x64590118}},	//   _ছেলে, रोटी, _makw, cuwi,
   {{0x79861a99,0xbcfb000d,0xdfd0132d,0x9f45972c}},	//   _lakw, ngée, ئيد_, bolí_,
   {{0x798616df,0x2019003e,0xdd910413,0x00000000}},	//   _oakw, ísir_, نود_, --,
   {{0x79865c23,0x6b850118,0xa0a61da6,0x00000000}},	//   _nakw, _sahg, _наед, --,
   {{0xdcef002d,0xe81c0324,0x5c077090,0xdb0500a0}},	//   decă, _भूला_, зява, _dlhý,
   {{0x28c700dc,0xea000023,0x7f412ade,0x6fb400fd}},	//   _रेगि, _đạc_, calq, _زمبا,
   {{0x79860c1b,0x2cb30355,0x6459bc13,0x394b00ee}},	//   _bakw, _řadě_, zuwi, _pdcs_,
   {{0x6edb00a5,0x26df0207,0xd6c40831,0x00000000}},	//   _לחופ, _ćuo_, ্থায, --,
   {{0x6d4d010d,0x79860b0e,0x321e0035,0x4815061c}},	// [e170] _idaa, _dakw, _luty_, дмас,
   {{0x7c2d0010,0x9cd8025a,0x00000000,0x00000000}},	//   _itar, _מוחה_, --, --,
   {{0x1a6500b5,0xf7700c74,0x752d02d7,0x247d021e}},	//   _تیزی_, طال_, ñazo, _sňm_,
   {{0xf6501168,0x25a9008a,0x6459bc14,0x7986251e}},	//   ائل_, ðal_, tuwi, _gakw,
   {{0x65790069,0xfc4600b8,0x321e007e,0x00000000}},	//   rewh, říve_, _auty_, --,
   {{0x3869bc15,0x9f4701ba,0x321e0035,0xe299bc16}},	//   mtar_, _okná_, _buty_, жак_,
   {{0xf7720122,0x79861548,0x201d01cb,0x00000000}},	//   _שקל_, _yakw, _suwi_, --,
   {{0x321ebc17,0x64590159,0x6d4d030d,0x9f4501f7}},	//   _duty_, puwi, _ndaa, rolí_,
   {{0x7c2d0232,0xc5e901c0,0x7529007b,0x7af70282}},	//   _ntar, टकीय_, _ifez, _lyxt,
   {{0x442dbc18,0x38695d38,0xdb1c00a2,0x64490409}},	//   _ite_, itar_, phré, _ivei,
   {{0x62812c3f,0x7c2dbc19,0x90e70e3a,0x3869bc1a}},	//   _uslo, _atar, _کسان, htar_,
   {{0x3869bc1b,0x442d0031,0x6449704d,0x7c2d01ed}},	//   ktar_, _kte_, _kvei, _btar,
   {{0xdb1e039f,0x201d067f,0xdc1300a8,0x6d4d018e}},	//   _impú, _uuwi_, _ağıl, _ddaa,
   {{0x442d0183,0x798600f8,0x7c2d0079,0x6d4d3a35}},	//   _mte_, _sakw, _dtar, _edaa,
   {{0x7c2dbc1c,0xca751ac5,0x386900af,0x79860051}},	//   _etar, нуты, etar_, _pakw,
   {{0x3869072e,0x442d6d6e,0xcee70e3a,0x3f877ff7}},	//   ftar_, _ote_, _ورژن_, _hanu_,
   {{0x1867bc1d,0x3869004f,0xe7aa0086,0x442dbc1e}},	// [e180] мати_, gtar_, овал_, _nte_,
   {{0x798608e1,0x090303fa,0x7a150035,0xdb2400c3}},	//   _wakw, тпун, _wątp, ärät,
   {{0x442dbc1f,0x3f879118,0x798678a5,0x64490279}},	//   _ate_, _manu_, _takw, _avei,
   {{0x89361c0c,0x442d028b,0x3869732d,0xd91002fd}},	//   _تعدا, _bte_, btar_, _میز_,
   {{0x38698ebc,0x442d521c,0x00000000,0x00000000}},	//   ctar_, _cte_, --, --,
   {{0x28c7073f,0x75290fbc,0x00000000,0x00000000}},	//   _रेटि, _efez, --, --,
   {{0xe29709ea,0xfd650019,0x644943b6,0x261800b4}},	//   дај_, _chuố, _evei, _बंटी_,
   {{0xbbbb0c67,0xd130004f,0x2bbb049c,0xe1f9010b}},	//   _उत्क, دمة_, _उत्थ, glų_,
   {{0x30142495,0x672315d7,0x00000000,0x00000000}},	//   ндир, žnje, --, --,
   {{0xdb1e0443,0x321ebc20,0x3f8700e9,0x75f80183}},	//   _empú, _tuty_, _canu_, dízi,
   {{0x3f87bc21,0x3eb83daf,0x1eaa0118,0x05c2258f}},	//   _danu_, árt_, زادي_, _शताब,
   {{0x25a6bc22,0xa3d604bc,0x3869bc23,0x31b100ee}},	//   njol_, ाचक_, ytar_, _bázu_,
   {{0x4fc66118,0x3869ad25,0x61e201cb,0x3f878afc}},	//   _оска, xtar_, _ijol, _fanu_,
   {{0xb3450370,0x3869023a,0x3f87bc24,0x9f450176}},	//   maçã, vtar_, _ganu_, colà_,
   {{0xb34500c9,0xf1b20e1d,0xa0070037,0x28c70380}},	//   laçã, _जवान, _تقول_, _रेजि,
   {{0x23692c3f,0x3869bc25,0x391557d2,0x3f87bc26}},	//   đaji_, ttar_, ембр, _zanu_,
   {{0xb3450370,0x28f80086,0x3869bbd0,0xda1f046c}},	// [e190] naçã, деть_, utar_, _मूरत_,
   {{0x38696eed,0x442dbc27,0xe1f900c7,0x25a60298}},	//   rtar_, _rte_, zlų_, ejol_,
   {{0x6449bc28,0x442dbc29,0x06b20033,0x2d890a8a}},	//   _svei, _ste_, _টেবি, _kaae_,
   {{0x386932ac,0x28d00026,0x29d70484,0x61e2bc2a}},	//   ptar_, _सेवि, għat_, _njol,
   {{0x442d0c6f,0x2d89008c,0x232905c2,0x3a26023a}},	//   _qte_, _maae_, поли_, _čopi_,
   {{0x7bd5bc2b,0xb3450370,0x3a21022e,0x3206416e}},	//   nizu, daçã, _kuhp_, _ahoy_,
   {{0x3f8700cd,0x221500af,0x00000000,0x00000000}},	//   _ranu_, нфир, --, --,
   {{0x3f870200,0x64492129,0x320603da,0x7bd50065}},	//   _sanu_, _tvei, _choy_, hizu,
   {{0x442dbc2c,0xb3450370,0xe0d939db,0x7bd5bc2d}},	//   _ute_, gaçã, яви_, kizu,
   {{0x09dc051d,0xfd650028,0x6006325e,0x75f84681}},	//   _यद्य, _thuố, нным_, vízi,
   {{0xf77202b5,0x25ad0b0d,0x61ed0009,0x05d30246}},	//   נקט_, _koel_, čalb, _दगाब,
   {{0xb3450183,0x6da6034b,0x00000000,0x00000000}},	//   baçã, хима, --, --,
   {{0xb345051b,0x61fb01d6,0x7bd501f4,0x3f8708a0}},	//   caçã, mlul, fizu, _tanu_,
   {{0xdee54717,0x61fb8814,0x320d008e,0x7bd5054b}},	//   _поли, llul, lmey_, gizu,
   {{0x63730463,0x6e95004f,0xdce400cb,0x2d89008c}},	//   mını, _ألعا, _obić, _faae_,
   {{0x25ad7452,0x63730463,0xdced5ed9,0x3eb803db}},	//   _noel_, lını, _zbač, ørte_,
   {{0x6d4635b5,0x7bd5054b,0x00000000,0x00000000}},	// [e1a0] maka, bizu, --, --,
   {{0x6d46776a,0x63730463,0x7d048ec7,0x61fbbc2e}},	//   laka, nını, _izis, hlul,
   {{0xb345051b,0x25ad02a2,0xbb3b00a5,0x28d0021a}},	//   zaçã, _boel_, _מעיי, _सेरि,
   {{0x1c04198f,0xb9060033,0x25ad099e,0x63732f80}},	//   _शीतल_, _ফর_, _coel_, hını,
   {{0x25ad152b,0x61fb0069,0x63730463,0x69d6bc2f}},	//   _doel_, dlul, kını, miye,
   {{0x6d463dc2,0x69d606d0,0xb3450370,0xf1b90029}},	//   haka, liye, vaçã, ekš_,
   {{0x6d46bc30,0xbcfb0248,0x6373037a,0x39421394}},	//   kaka, nfér, dını, _keks_,
   {{0xb34500c9,0x6d46bc31,0x61fb3a9e,0x69d6bc32}},	//   taçã, jaka, glul, niye,
   {{0x6d460464,0x61e2960b,0xe453006c,0x765e4733}},	//   daka, _vjol, _مہنگ, lupy,
   {{0xb345051b,0x3dc008dd,0x50b70037,0x69d61008}},	//   raçã, _aliw_, عديد_, hiye,
   {{0xd3370122,0x7bd5bc33,0x6d462929,0x69d641a6}},	//   _נראה_, vizu, faka, kiye,
   {{0xb3450370,0xa3cc073f,0x92c2045e,0x51830d39}},	//   paçã, शोर_, ışın, _буша,
   {{0x69d6008f,0x6ad90577,0x637304d4,0x6e2402c4}},	//   diye, णप्र, bını, _čibu,
   {{0xbcfb1010,0xf99fb82a,0x7d04004e,0x6373008f}},	//   ffér, _chèn_, _dzis, cını,
   {{0x7d04018e,0x7bd56561,0xda78bc34,0x39420051}},	//   _ezis, rizu, нят_, _beks_,
   {{0x69c4bc35,0x4efb00a5,0x69d6bc36,0x98ad00cd}},	//   ghie, _מהוו, giye, _žeđ_,
   {{0x25ad0223,0x7dc601ef,0x391554b8,0x7bd501ed}},	// [e1b0] _roel_, _bósf, тмар, pizu,
   {{0xf6e7290e,0x25ad12a9,0x7bd50055,0x00000000}},	//   нцен, _soel_, qizu, --,
   {{0x69d67bce,0x25ad1472,0x39420b3e,0x00000000}},	//   biye, _poel_, _feks_, --,
   {{0x69d6bc37,0x6373037a,0xd6d83f96,0x00000000}},	//   ciye, zını, хту_, --,
   {{0x25adbc38,0x637306d3,0x7dc60473,0xc86701e0}},	//   _voel_, yını, _fósf, _ятни,
   {{0x6d46bc39,0x798d21a3,0x25ad0298,0x00000000}},	//   zaka, ldaw, _woel_, --,
   {{0x61fbbc3a,0x25ad018d,0x00000000,0x00000000}},	//   tlul, _toel_, --, --,
   {{0x798dbc3b,0x25bf1cc0,0x6d460065,0xdce400f4}},	//   ndaw, _ulul_, xaka, _ubić,
   {{0x63730463,0x61fb4595,0x600909a5,0x00000000}},	//   tını, rlul, мним_, --,
   {{0x6d46bc3c,0x69d6bc3d,0x661b00c3,0x443f0118}},	//   waka, ziye, _hiuk, _iwu_,
   {{0x63733410,0x6d461120,0xed5a0eee,0xeadc00c8}},	//   rını, taka, мон_, _ধর্ম,
   {{0x63733410,0x23690a78,0x69d60510,0x307500af}},	//   sını, đaju_, xiye, _аукс,
   {{0x6d461221,0xc8d01e79,0xdb1c008a,0x798dbc3e}},	//   raka, _सेंट, firð, ddaw,
   {{0x799d0122,0x661b1ac5,0x69d6bc3f,0x637300a8}},	//   _answ, _liuk, wiye, qını,
   {{0x6d467758,0x60c901d6,0xbb432e50,0x3942010d}},	//   paka, lzem, реск, _peks_,
   {{0x798d043d,0x644b7f62,0x60d6010b,0xdc1400d0}},	//   gdaw, ksgi, _žymi, rşıy,
   {{0x69d6bc40,0xbcfb4e39,0x60c9bc41,0xe81c0324}},	// [e1c0] riye, sfér, nzem, _भूखा_,
   {{0x69d6bc42,0x61e418b0,0x6d44452a,0x66090027}},	//   siye, čili, _heia, _ahek,
   {{0x69c427bf,0xbcfb6670,0x661b028b,0x6b9e0036}},	//   phie, ngén, _biuk, _inpg,
   {{0x660957b4,0x7c242206,0x443f0371,0x2bce1cce}},	//   _chek, _kuir, _bwu_, होरा,
   {{0x661b149f,0x656201f4,0x67230bc6,0x6d44bc43}},	//   _diuk, rgoh, žnja, _meia,
   {{0x60c9ae42,0xa3cc004e,0x3860bc44,0x6d44bc45}},	//   dzem, शों_, muir_, _leia,
   {{0x3860bc46,0x7c2401a6,0x443f2b62,0x64591ebb}},	//   luir_, _luir, _ewu_, arwi,
   {{0xe1ef0bdf,0x661b011e,0x68ed01f4,0x21670274}},	//   يسي_, _giuk, _ëndë, вићи_,
   {{0x3860bc47,0x443f007a,0x7c2400a2,0x00000000}},	//   nuir_, _gwu_, _nuir, --,
   {{0x6e233c1e,0x4424bc48,0x61ed0124,0x00000000}},	//   _bunb, _ium_, čala, --,
   {{0x442416b5,0x51860036,0x6e2300f1,0xa75b0070}},	//   _hum_, _аула, _cunb, ודיר,
   {{0x4424bc49,0x6e233c9d,0x7c241a07,0xdb1c008d}},	//   _kum_, _dunb, _buir, virð,
   {{0x7c24006e,0x4424824b,0x6d4406a2,0x6ce70210}},	//   _cuir, _jum_, _deia, тіне,
   {{0x44240273,0x3860bc4a,0x45280083,0x6e230282}},	//   _mum_, duir_, মরিক_, _funb,
   {{0x4424bc4b,0x99673c0c,0xac185f13,0x6e23bc4c}},	//   _lum_, ктал, тору_, _gunb,
   {{0x201c0657,0x7c240014,0x3ce9006f,0x6d449de2}},	//   _hivi_, _fuir, _txav_, _geia,
   {{0x4424a86d,0x9f4c0187,0x798dbc4d,0x201c9ebb}},	// [e1d0] _num_, hodí_, rdaw, _kivi_,
   {{0x66095f34,0x26e70083,0xf77021a0,0x798d2646}},	//   _shek, _করবো_, قام_, sdaw,
   {{0xd7f85c37,0x60c9bc4e,0x661b4ab4,0x443f021d}},	//   тут_, zzem, _piuk, _swu_,
   {{0x3860bc4f,0x644b013c,0x799d0090,0x00000000}},	//   buir_, tsgi, _unsw, --,
   {{0x442409eb,0x33d50823,0xad9b0391,0x3949bc50}},	//   _cum_, лікт, clúe, maas_,
   {{0x39490244,0x60c9278c,0x6ec5012f,0x00000000}},	//   laas_, vzem, ानमु, --,
   {{0x44242a1c,0x67d44025,0x6609bc51,0xb36401d3}},	//   _eum_, _тору, _thek, ръчк,
   {{0x4424bc52,0x60c9bc53,0xdb0501ef,0x3949bc54}},	//   _fum_, tzem, _xohá, naas_,
   {{0x44240014,0x6e23bc55,0xf36709d0,0x6d44bc56}},	//   _gum_, _sunb, _атен, _reia,
   {{0xee3909c2,0x60c9bc57,0x6d44bc58,0x7dc605ee}},	//   нно_, rzem, _seia, _móse,
   {{0x44240446,0x201c00ea,0x60c9b7bf,0x7c24bc59}},	//   _zum_, _divi_, szem, _suir,
   {{0xb2ba00c2,0x865a016b,0x9b9602fd,0x7c2400f1}},	//   _אמער, עדרי, گلست, _puir,
   {{0x394914d4,0x4424bc5a,0x6d442278,0xd00e04cd}},	//   daas_, _xum_, _veia, تلی_,
   {{0x705206ca,0xa0663dd9,0x201c00ee,0x6e230103}},	//   _انوا, _саша_, _givi_, _tunb,
   {{0xfc3f043f,0xdb052eef,0x2d8400f7,0x6d44bc5b}},	//   rxía_, _pohá, ômes_, _teia,
   {{0xf2d202b5,0x3949bc5c,0x3860bc5d,0x201cbc5e}},	//   צען_, gaas_, tuir_, _zivi_,
   {{0xbcfbbc5f,0x2d82bc60,0x98a33f20,0x161d0066}},	// [e1e0] ngél, meke_, бите, _बंजर_,
   {{0xb8dc04cc,0xe8f71b79,0x3860115d,0x9d1b00a5}},	//   _अथ_, улу_, ruir_, _אופט,
   {{0x4424bc61,0x3949bc62,0x3860028b,0xdb1c0079}},	//   _sum_, baas_, suir_, bhrá,
   {{0x2d82a888,0x394900ec,0xdb1c94cf,0x44240611}},	//   neke_, caas_, chrá, _pum_,
   {{0x7e618dbc,0x386001f7,0x7afe0107,0x4424bc63}},	//   hulp, quir_, _hypt, _qum_,
   {{0x2d82bc64,0x439406d8,0x00000000,0x00000000}},	//   heke_, ракс, --, --,
   {{0x2d82bc65,0x668404e8,0x201cbc66,0xdb1e6143}},	//   keke_, _خیال, _rivi_, _impó,
   {{0x2d826209,0x4424bc67,0x90540368,0x201c080a}},	//   jeke_, _tum_, авиц, _sivi_,
   {{0x4424028b,0x201c0506,0x2d828f7e,0x00000000}},	//   _uum_, _pivi_, deke_, --,
   {{0x53b84eee,0x30770037,0x23b8012f,0x212f2642}},	//   _अविश, احية_, _अविद, _efgh_,
   {{0x7413036b,0x201c55c9,0x20020029,0x7e61010d}},	//   _اولا, _vivi_, ēki_, gulp,
   {{0x2d821642,0xdcf600a8,0x614300af,0x00000000}},	//   geke_, _qayğ, _геца, --,
   {{0x201cbc68,0xdfda01d3,0x5c740d13,0x999a005f}},	//   _tivi_, _пък_, блят, _bvpž_,
   {{0x39490298,0x5a35141d,0x00000000,0x00000000}},	//   waas_, ингт, --, --,
   {{0x39498409,0x2d82bc69,0x539b0122,0x7e61153c}},	//   taas_, beke_, עילו, culp,
   {{0xf99f0023,0xc4c40067,0x7afe0044,0xb33c0024}},	//   _thèm_, वनाओ, _dypt, _moħq,
   {{0x06b20083,0x3949bc6a,0xa3d40066,0x3f8e00cd}},	// [e1f0] _টেলি, raas_, हफा_, _kafu_,
   {{0xb8cd02b4,0x3949bc6b,0x3f8e003c,0x69dabc6c}},	//   _कप_, saas_, _jafu_, éter,
   {{0x67230254,0x370742f1,0x7bc501ed,0x00000000}},	//   žnjo, учав, _ilhu, --,
   {{0x29e81505,0x645d013c,0x1da801c0,0xdb1e0132}},	//   lğan_, _åsik, गायत, _empó,
   {{0x64a5a4da,0xdcfd00d8,0x7e6101d7,0x98b9005f}},	//   рала, kesč, zulp, _besą_,
   {{0x425511ca,0x2d8239b3,0xdb1e0107,0x3f8e035f}},	//   атит, zeke_, _impò, _nafu_,
   {{0xfbb800a5,0x02d83421,0x00000000,0x00000000}},	//   רפות_, _भेदभ, --, --,
   {{0x02050370,0x00000000,0x00000000,0x00000000}},	//   јзин, --, --, --,
   {{0x3f8e018e,0x00000000,0x00000000,0x00000000}},	//   _bafu_, --, --, --,
   {{0x2d82bc6d,0xd00e21a0,0xd0090274,0x1fb50a80}},	//   weke_, ولي_, ђене_, рсир,
   {{0x2d82bc6e,0xd5b90591,0xf99f0359,0x9fbd0035}},	//   teke_, _आवाज, _chèk_, _słów_,
   {{0xf99f01cb,0x41e4010b,0x00000000,0x00000000}},	//   _dhèk_, _ліча, --, --,
   {{0x2d82bc6f,0x7e61010d,0x814c0070,0xe7fa00b8}},	//   reke_, sulp, _טעאַ, ्तमा_,
   {{0x2d823ff4,0x09de00a1,0x7a1c0260,0x00000000}},	//   seke_, नच्य, _pōto, --,
   {{0x2d82bc70,0x7ff418dd,0x7bc50168,0xaa46bc71}},	//   peke_, _اسنا, _dlhu, ребл,
   {{0xdb1c122d,0x7bc51e5c,0x88e600af,0x798f0090}},	//   nkré, _elhu, ажбе, _cacw,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [e200] --, --, --, --,
   {{0x23b900e0,0xeb9a18cd,0x00000000,0x00000000}},	//   _kèju_, _рио_, --, --,
   {{0x7bdcbc72,0x06860a46,0x39ea00d8,0xfaa61346}},	//   miru, рген, _адно_, _тано,
   {{0x7bdc50c6,0x25a00453,0x798f0027,0x00000000}},	//   liru, ñil_, _gacw, --,
   {{0x69c66810,0xf1a923f0,0x63860336,0x00000000}},	//   _ilke, कानन, игда, --,
   {{0x7bdc010b,0x06660647,0x7d010098,0x31b8007e}},	//   niru, _پاسپ, lárú, _lézt_,
   {{0x66e32a2d,0x3f8e08c7,0x461605f5,0x31c60274}},	//   _дора, _rafu_, _نوسر, исив,
   {{0x3f8e0054,0x6d562973,0x00000000,0x00000000}},	//   _safu_, _ndya, --, --,
   {{0x387202df,0xcfa60c90,0xdfa60214,0x6602bc73}},	//   ntyr_, ашни, ајно, mlok,
   {{0x6602bc74,0x6d5602d7,0x6fc40211,0x7bdcbc75}},	//   llok, _adya, _bòca, jiru,
   {{0x7c3600da,0x7bdc11f9,0x6fc40284,0x6e63399d}},	//   _atyr, diru, _còca, отяж,
   {{0x6602bc76,0x3f8ebc77,0x629a0421,0x00000000}},	//   nlok, _wafu_, _irto, --,
   {{0x7643006c,0x7bc50221,0x3f8e8c2a,0x7bdc1435}},	//   ányz, _plhu, _tafu_, firu,
   {{0x69c636cc,0x66020345,0x629a02c4,0x7bdc899b}},	//   _alke, hlok, _krto, giru,
   {{0xe0e80083,0x29e80510,0x1f3732e3,0x0e4600af}},	//   _পরিভ, rğan_, _דרור_, _тэлм,
   {{0x39a49bdf,0x89370037,0x31b800ee,0x00000000}},	//   ошув, شعرا, _tézu_, --,
   {{0xdb5b00c3,0x6602bc78,0xad9b002a,0x00000000}},	// [e210] _июн_, dlok, clúa, --,
   {{0xc60f035d,0x69c6bc79,0x960f20ab,0x7bdc014c}},	//   िष्य_, _elke, िष्ट_, ciru,
   {{0xb8fe006a,0x6602008a,0x9a870763,0x66dc03d0}},	//   _थे_, flok, _тупл, _råkø,
   {{0x76240210,0x66026b9d,0xdb07003e,0x00000000}},	//   іміз, glok, skjó, --,
   {{0xa87902b5,0x24f8021f,0x98790070,0xd8cb002d}},	//   _גאָר, анцы_, _גאָט, _рынд_,
   {{0x28d0258f,0x00000000,0x00000000,0x00000000}},	//   _सेटि, --, --, --,
   {{0xb5a717c8,0xdb1c033b,0x956701d3,0x629a00f4}},	//   _край, chrä, _възд, _crto,
   {{0x7bdc1944,0x6fc40211,0x00000000,0x00000000}},	//   ziru, _ròca, --, --,
   {{0x7dc60037,0x657b2379,0x629a3b08,0x00000000}},	//   _nósa, _ibuh, _erto, --,
   {{0x248d0484,0xdb1c42f6,0x724200b5,0x6fc401da}},	//   _isem_, skré, _کھول, _pòca,
   {{0x7c36362b,0xb4e719b7,0x22950987,0x00000000}},	//   _styr, _पशु_, _دلاس, --,
   {{0xb33c035f,0x51840aeb,0x7bdc2724,0x00000000}},	//   _inħa, _муча, wiru, --,
   {{0x248d0311,0x213f0464,0xc0a800b5,0xa3cb073f}},	//   _jsem_, mbuh_, _ناول_, _लता_,
   {{0x6fc40211,0x00000000,0x00000000,0x00000000}},	//   _tòca, --, --, --,
   {{0x657bbc7a,0xdd110076,0x4e350172,0x7bdcbc7b}},	//   _obuh, _výšk, _اعتز, riru,
   {{0x7bdc55a3,0x7ae10037,0x248d0bc9,0x3e7100b5}},	//   siru, últa, _osem_, mát_,
   {{0x3e711055,0x7bdcbc7c,0x2fc7bc7d,0x98a32695}},	// [e220] lát_, piru, _klng_, пите,
   {{0xbb860082,0x3f85bc7e,0x657b87c7,0x2d924d0b}},	//   _الدي, nelu_, _abuh, _haye_,
   {{0x2d92bc7f,0x3872bc80,0x66020d35,0x248dbc81}},	//   _kaye_, styr_, tlok, _asem_,
   {{0x5efa0070,0x3f850328,0x00000000,0x00000000}},	//   אפעד, helu_, --, --,
   {{0x6ba5008a,0x6602bc82,0x3e71006c,0x394031fc}},	//   _útgá, rlok, hát_, mbis_,
   {{0x3f85bc83,0x3e7105fa,0x2d92b9d0,0x2fc7067f}},	//   jelu_, kát_, _laye_, _nlng_,
   {{0x3e710332,0x248dbc84,0x93cb00fd,0x00000000}},	//   ját_, _esem_, دانہ_, --,
   {{0x2d92bc85,0x629a0528,0xb034075a,0x2fc70cca}},	//   _naye_, _vrto, ониш, _alng_,
   {{0x39400037,0xdce4011c,0x00000000,0x00000000}},	//   ibis_, _obiđ, --, --,
   {{0xb7fa4e96,0x3f8500e9,0x2d92073a,0x38600098}},	//   ्तिम_, gelu_, _aaye_, irir_,
   {{0xd3370052,0x3e71006c,0x3860108b,0x2d92bc86}},	//   _הרבה_, gát_, hrir_, _baye_,
   {{0x386003d0,0x7dc60079,0x00000000,0x00000000}},	//   krir_, _pósa, --, --,
   {{0x3f85bc87,0x2d920359,0x5ed00831,0x5c740bfc}},	//   belu_, _daye_, _সুখে, плят,
   {{0x3e712d87,0x2f18010b,0xd9b30246,0xa3be00ab}},	//   bát_, _коль_, ीस्ट, ँघट_,
   {{0x6d5a0031,0x38603576,0x00000000,0x00000000}},	//   ėtar, erir_, --, --,
   {{0x3860a979,0x2d9202d0,0x26e70033,0xdb0505ed}},	//   frir_, _gaye_, _করলো_, _kohú,
   {{0x6d4fbc88,0xbbeb00bf,0x3dc90dc3,0x3860bc89}},	// [e230] maca, _مردم_, _ilaw_, grir_,
   {{0x6d4fb08a,0x7d0db0e5,0x2a980260,0x290283ad}},	//   laca, _izas, _fčb_, _dyka_,
   {{0x3940bc8a,0x3ebe3ee4,0xa3ac205c,0x00000000}},	//   bbis_, nytt_, गान_, --,
   {{0x6d4fbc8b,0x25a401f7,0xa5bd009e,0x00000000}},	//   naca, _cnml_, _siųb, --,
   {{0x99800dac,0x69cd012f,0x69df0055,0x00000000}},	//   lmiş_, mhae, miqe, --,
   {{0x6d4f01da,0x69cdbc8c,0x248d02c6,0x3dc9001e}},	//   haca, lhae, _vsem_, _llaw_,
   {{0x6d4fbc8d,0xd5ae006c,0x9980008f,0x00000000}},	//   kaca, رہے_, nmiş_, --,
   {{0x657b0232,0x3e71006c,0x248d01e8,0x6d4fbc8e}},	//   _ubuh, vát_, _tsem_, jaca,
   {{0x6e2a01ae,0x6d4fbc8f,0x394b00f7,0x2fc7010d}},	//   _aufb, daca, _mecs_, _plng_,
   {{0x3e71bc90,0xdd0900ee,0x99800448,0x69df0055}},	//   tát_, _bôži, kmiş_, hiqe,
   {{0x59c90c67,0x69cd046a,0x6d4f13b3,0x2d92bc91}},	//   रसार, khae, faca, _paye_,
   {{0x3e712eef,0x38600093,0x656b2b0c,0x2fc7010d}},	//   rát_, yrir_, nggh, _wlng_,
   {{0x7d0d006a,0x00e50332,0x3e710332,0x61e9bc92}},	//   _czas, _بتای, sát_, mnel,
   {{0x386002e1,0xa3ac018d,0xdb1e1534,0x248000d0}},	//   vrir_, गाय_, _alpá, çimi_,
   {{0xdde900bf,0x2d920359,0xdcfd00ea,0x7d0d030d}},	//   _گروه_, _taye_, resā, _ezas,
   {{0x6d4fbc93,0x61fbbc94,0x3e5500ea,0x394b0176}},	//   caca, noul, māt_, _cecs_,
   {{0x3940bc95,0x20c948cd,0x386000f7,0x3e5500ea}},	// [e240] rbis_, िनिध, urir_, lāt_,
   {{0x61e9bc96,0x62812193,0x3860bc97,0x869a05c2}},	//   hnel, _oplo, rrir_, итет_,
   {{0x3e550080,0x628101a9,0x61e9010b,0x61fb13d8}},	//   nāt_, _nplo, knel, koul,
   {{0x98a606a6,0x69cd821c,0x7e7e017b,0x80c90066}},	//   _диме, chae, _äppe, िनाइ,
   {{0x69c4003c,0x61e9042a,0x6281bc98,0x64c42450}},	//   mkie, dnel, _aplo, वनेश,
   {{0x69c4bc99,0x3e550029,0xd25a02f3,0x6e2400be}},	//   lkie, kāt_, аци_, _liib,
   {{0x04fc00c8,0x6d4f036a,0x61fb0fce,0x6fc43376}},	//   েশের_, yaca, foul, _dòcl,
   {{0x69c4bc9a,0x61e90c61,0x79962637,0x3e550029}},	//   nkie, gnel, ndyw, dāt_,
   {{0x7d04bc9b,0xdb1e0132,0x224900cd,0xbfaa258d}},	//   _nyis, _impõ, ćaka_, атне_,
   {{0x61e90043,0x6d4f5db0,0xdd0901ba,0x3dc9bc9c}},	//   anel, waca, _pôži, _slaw_,
   {{0x7d04142f,0x6d4fbc9d,0x69c4bc9e,0xc9070084}},	//   _ayis, taca, kkie, _शर्म_,
   {{0x6f03012f,0x61fb512a,0x6e24009e,0x7d0404fb}},	//   _dync, coul, _ciib, _byis,
   {{0x6e2420fb,0x48cc0033,0x69c40035,0x7d0404fb}},	//   _diib, লপুর, dkie, _cyis,
   {{0x6d4fbc9f,0x67234693,0x60cc0463,0x61e0037a}},	//   saca, žnji, ılmı, liml,
   {{0x69cd17b3,0x656b3ee4,0x7dc601f7,0x2b5a0160}},	//   thae, yggh, _góso, _ddpc_,
   {{0x61e0bca0,0x99800463,0x3c2f033b,0x31b100ee}},	//   niml, rmiş_, _tüv_, _bázy_,
   {{0x7d0db05e,0x69cd00e9,0xa2b12874,0xef180228}},	// [e250] _uzas, rhae, _अपभ्, deļi_,
   {{0x61ed3727,0x61e0bca1,0x7bce8c84,0x7de400b5}},	//   čali, himl, chbu, rőse,
   {{0x61e004d4,0x61e9576d,0xb87b01ef,0x61fb08c7}},	//   kiml, ynel, _exíp, youl,
   {{0x69c4bca2,0x8afa00a5,0x60c02f06,0x31b107c0}},	//   ckie, _להתי, kymm, _fázy_,
   {{0x7c2d06b3,0x183500c2,0x69dd003c,0x6281108a}},	//   _juar, _מאָל_, _imse, _splo,
   {{0x7c2dbca3,0x61fb02d0,0x7647006d,0x386901f4}},	//   _muar, woul, _twjy, muar_,
   {{0x38695b93,0xe7fa0e04,0x7c2dbca4,0x61fb01ef}},	//   luar_, ्तरा_, _luar, toul,
   {{0xdb1e0248,0x7a1c0260,0x68290009,0x3e550228}},	//   _impô, _pōti, _ežde, vāt_,
   {{0x61fbbca5,0xa3b8006c,0x752901d5,0x7c2da9da}},	//   roul, _ڈالر_, _igez, _nuar,
   {{0x6e24bca6,0x69c4bca7,0x6f03001e,0x61e9bca8}},	//   _siib, zkie, _pync, snel,
   {{0x6281bca9,0x61fbbcaa,0x442dbcab,0x386901f4}},	//   _uplo, poul, _hue_, huar_,
   {{0x386901d2,0x4425bcac,0x442dbcad,0x3eb8013c}},	//   kuar_, _hil_, _kue_, ärta_,
   {{0x7c2dbcae,0x386900da,0x442d0033,0x41b2026e}},	//   _cuar, juar_, _jue_, _سمور,
   {{0x69dd0297,0x7c2dbcaf,0x44251d24,0x386901f4}},	//   _amse, _duar, _jil_, duar_,
   {{0xfaa3bcb0,0x442d03ad,0xa3ac00a1,0x69c4bcb1}},	//   наро, _lue_, गात_, tkie,
   {{0x4425048c,0x752988c1,0x7c2dbcb2,0xba232264}},	//   _lil_, _ngez, _fuar, едск,
   {{0x7c2d0a1f,0x4425bcb3,0x442d00f7,0x69dd0069}},	// [e260] _guar, _oil_, _nue_, _dmse,
   {{0x69c4bcb4,0x61e004d4,0xdc9b1198,0x7529018c}},	//   skie, ziml, _פסיכ, _agez,
   {{0x34c400b8,0x3bbb0122,0x249f027c,0x7bde16a3}},	//   वन्द, _המיד, _arum_, _impu,
   {{0x4425001e,0x442dbcb5,0x3869b851,0x249fbcb6}},	//   _ail_, _bue_, buar_, _brum_,
   {{0x4425bcb7,0x249f00d7,0x61e0045e,0x299b0d85}},	//   _bil_, _crum_, viml, _הסכמ,
   {{0x442d4948,0x4425bcb8,0x64490223,0x39527dd3}},	//   _due_, _cil_, _dwei, lays_,
   {{0x4425bcb9,0x249f00fb,0x442d3113,0x61e0033e}},	//   _dil_, _erum_, _eue_, timl,
   {{0x442d00c8,0x4425004a,0x11d8004f,0x673b042a}},	//   _fue_, _eil_, توبة_, _đuji,
   {{0x644902c7,0x442504f0,0x7dc62cad,0x442d0703}},	//   _gwei, _fil_, _cósm, _gue_,
   {{0x61e00723,0x30130409,0x44256be1,0x7c2d2039}},	//   siml, ндыр, _gil_, _ruar,
   {{0x386901d2,0x644902c9,0x7c2d253e,0x2bb00099}},	//   zuar_, _zwei, _suar, ञाना,
   {{0x7bde9c63,0x442d1d24,0x63ba00af,0xa2b100e7}},	//   _ampu, _yue_, _hotn, _अपत्,
   {{0x44250225,0x8fa68ba1,0x386900da,0x7c2d3359}},	//   _yil_, _наде, xuar_, _quar,
   {{0xe10b00c2,0x442501ef,0x386901f4,0xbcfb000d}},	//   _פּאָ, _xil_, vuar_, dgét,
   {{0x7c2500c3,0x63ba008b,0x00000000,0x00000000}},	//   _vihr, _motn, --, --,
   {{0x386901d2,0x7c2dbcba,0x7bdebcbb,0x63ba004e}},	//   tuar_, _tuar, _empu, _lotn,
   {{0x290f022a,0x2d8bbcbc,0xf8f4002d,0x00000000}},	// [e270] åga_, mece_, ептэ, --,
   {{0x3869071f,0x442d02e1,0x2d8b2768,0x290700ea}},	//   ruar_, _rue_, lece_, āna_,
   {{0x3869bcbd,0xf55903c5,0x24840a4e,0x26c701c0}},	//   suar_, قلاب_, _apmm_, áno_,
   {{0x4425bcbe,0x2d990a45,0x2d8b18a1,0x69dd033b}},	//   _sil_, ndse_, nece_, _umse,
   {{0x26c702dd,0x63ba4601,0x3869bcbf,0x00000000}},	//   šno_, _botn, quar_, --,
   {{0x442d02e1,0x7bc70553,0xfe78010b,0x64a24bba}},	//   _vue_, nkju, ktį_, таша,
   {{0x44258eda,0x994d016f,0xf1a90067,0x22152c93}},	//   _vil_, _môžu_, कालन, мфир,
   {{0x4425019c,0x63a8054e,0x442dbcc0,0x2d8b025c}},	//   _wil_, _endn, _tue_, jece_,
   {{0x442576e6,0x2d8b0723,0x932709b9,0x442d007c}},	//   _til_, dece_, _فران, _uue_,
   {{0x4425bcc1,0x6006037c,0x2d992069,0x2ca0009f}},	//   _uil_, мным_, edse_, _rrid_,
   {{0xd17500c7,0x2ca00207,0xaf090698,0x00000000}},	//   _жылы, _srid_, تقدم_, --,
   {{0x2ca018b0,0xfce60ebb,0xfbc932e3,0x6fc40284}},	//   _prid_, домо, _דת_, _lòch,
   {{0x68e900cb,0x61fc003e,0xa928007e,0x00000000}},	//   _žedn, _írla, _lyžá, --,
   {{0x39520122,0xe9df0079,0x2d990b88,0x00000000}},	//   ways_, _amú_, adse_, --,
   {{0xab2722a9,0x00000000,0x00000000,0x00000000}},	//   дора_, --, --, --,
   {{0x2ca00484,0x9f45298d,0x2d8b007b,0xbcfb00fd}},	//   _trid_, colò_, cece_, ggés,
   {{0xeb9a09cc,0x395206c6,0x00000000,0x00000000}},	// [e280] _дип_, rays_, --, --,
   {{0xbcfbbcc2,0x7bde2379,0x39520cd5,0xc1da052f}},	//   rgét, _umpu, says_, _बग्ग,
   {{0x6fc401a6,0xb90500ab,0xef1800ea,0x63babcc3}},	//   _dòch, _भे_, beļu_, _rotn,
   {{0xdb1c0097,0x80d40033,0x00000000,0x00000000}},	//   ckrá, দপত্, --, --,
   {{0x63ba008b,0x6d46028b,0x3c34017b,0x00000000}},	//   _potn, ibka, _jäv_, --,
   {{0x2d8b0395,0x9cd7011d,0x00000000,0x00000000}},	//   zece_, וונה_, --, --,
   {{0xf1a902cb,0xbcfb00f8,0x2d99bcc4,0x02a800b4}},	//   कांन, ngér, ydse_, कमेन,
   {{0xa3ac0299,0xcb130122,0x3d0f0099,0x00000000}},	//   गाह_, כלו_, _ठरले_, --,
   {{0x2d8b01d3,0x00000000,0x00000000,0x00000000}},	//   vece_, --, --, --,
   {{0xdfd00bdf,0x6442bcc5,0x9ed803e6,0xada7002a}},	//   ايد_, mpoi, змот_, _opúñ,
   {{0x644200c3,0xdd910c74,0x00000000,0x00000000}},	//   lpoi, هود_, --, --,
   {{0xa3ac00a1,0xfe7800d8,0x00000000,0x00000000}},	//   गाव_, rtį_, --, --,
   {{0x2d8b1ea3,0x6442bcc6,0x2d995930,0x621b0070}},	//   rece_, npoi, rdse_, _וואק,
   {{0x2d8b008b,0xab844e6b,0x6fb40118,0x7df200ec}},	//   sece_, куск, _سمبا, rāsa,
   {{0x7bc7008a,0xbcfb00f7,0x2d8b8b96,0x3f8c011c}},	//   rkju, ggér, pece_, medu_,
   {{0x3f8c8102,0x3e78006c,0x7bc7bcc7,0x99640043}},	//   ledu_, mét_, skju, ктул,
   {{0x2aff056a,0x4815005f,0xb81500ed,0x3e7800b5}},	// [e290] _शुरु_, емас, едај, lét_,
   {{0xdb1c008a,0x6aa301ef,0x3f8c099e,0xdc3c00a5}},	//   skrá, _ánfo, nedu_, _ועזר,
   {{0x3e7882f5,0xf7705cfa,0x6fcd02d7,0xfc3f01ef}},	//   nét_, شال_, _júca, rxíu_,
   {{0x25a90b4c,0x6fc40176,0x00000000,0x00000000}},	//   ñal_, _dòci, --, --,
   {{0x69cf6c50,0x8ca20354,0x6385bcc8,0x6fc40260}},	//   _ilce, खियो, егла, _tòch,
   {{0xe2998629,0x3f8cbcc9,0x3e78006c,0x00000000}},	//   зак_, jedu_, két_, --,
   {{0xf2200084,0x3e78006c,0x66820088,0xdd3200a8}},	//   मगढ़_, jét_, _میلل, _nəşr,
   {{0x69da000d,0x00000000,0x00000000,0x00000000}},	//   étex, --, --, --,
   {{0x6025176f,0x7f75002d,0x00000000,0x00000000}},	//   ндиа, нунц, --, --,
   {{0x443f203f,0xf2c7036c,0x64590479,0x6fcd0312}},	//   _itu_, _осен, mswi, _búca,
   {{0x3e78006c,0x64590479,0xc7b200a5,0x5de63cd7}},	//   gét_, lswi, אבי_, ежна,
   {{0x443fbcca,0x64590223,0x00000000,0x00000000}},	//   _ktu_, oswi, --, --,
   {{0x3f8c0b16,0x2d9e01c0,0xe0ce292e,0x707502b5}},	//   bedu_, ěte_, _св_, _נײַע_,
   {{0x443f19c6,0x645902a2,0x3f8c0090,0x22913f5d}},	//   _mtu_, iswi, cedu_, _kšk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69260274,0x17fa0e9b,0x443fbccb,0x229107c0}},	//   емба, ्त्व_, _otu_, _mšk_,
   {{0x443f006f,0x6442027a,0x645901e4,0x6fc401f7}},	// [e2a0] _ntu_, xpoi, jswi, _sòci,
   {{0x317f028b,0x6459bccc,0xe8e70183,0x69cfbccd}},	//   hfuz_, dswi, хмуд_, _elce,
   {{0x443fbcce,0xd910064e,0xa3b3049c,0x0566bccf}},	//   _atu_, _چیز_, टान_, евен,
   {{0x644201a2,0xd91000bf,0x443f4605,0x2e3a0070}},	//   tpoi, _نیز_, _btu_, לגענ,
   {{0x64592a03,0xa3ac020c,0x3e7800fd,0x00000000}},	//   gswi, गाल_, zét_, --,
   {{0x443f08c8,0xb7f400b4,0x3e7800fd,0x22910207}},	//   _dtu_, _आदिम_, yét_, _bšk_,
   {{0x64421a71,0xfe67234a,0x3f8ca5ea,0x682900d8}},	//   spoi, _حد_, vedu_, _užda,
   {{0x6442bcd0,0x7dc627c2,0x3e7800b5,0x443f00e2}},	//   ppoi, _fósi, vét_, _ftu_,
   {{0x63ab01c0,0xdb1c1193,0x3f8c00f4,0x00000000}},	//   ální, lkrä, tedu_, --,
   {{0x3e78006c,0x629c0355,0xd9dd00e7,0x289b016b}},	//   tét_, _šrou, _यष्ट, ליפא,
   {{0x3f8cbcd1,0xdb1c40d1,0x1df90421,0xe0cf00f8}},	//   redu_, nkrä, дены_, لزی_,
   {{0x3f8c793a,0x3e78bcd2,0x00000000,0x00000000}},	//   sedu_, rét_, --, --,
   {{0x3e78006c,0x61e2027a,0x0ca81195,0x7afb027d}},	//   sét_, _imol, нтри_, ğutm,
   {{0x6fe600f7,0x3e7800fd,0x00000000,0x00000000}},	//   _décè, pét_, --, --,
   {{0x5fa60299,0x66026816,0xdb1c02b1,0xb60600cd}},	//   _कोयल, kook, chrü, _košć,
   {{0x6440011c,0x660200ab,0x00000000,0x00000000}},	//   _otmi, jook, --, --,
   {{0x8dfc00a5,0x6602030d,0xb6060207,0xd7c90079}},	// [e2b0] _מההת, dook, _mošć, ووره_,
   {{0x65600037,0x443f0228,0x62880fdb,0x779890f5}},	//   _admh, _rtu_, _opdo, нкур_,
   {{0x64440012,0x61e20ff0,0x64402791,0x6595bcd3}},	//   ţiil, _omol, _atmi, кажу,
   {{0xcb1202b8,0xa2a409b4,0x37040370,0xb6060009}},	//   _כלי_, किन्, учув, _nošć,
   {{0x628800d8,0xa3ac018d,0xe22f0023,0xdb1c0079}},	//   _apdo, गां_, ợđiệ, bhró,
   {{0x64591167,0x3949bcd4,0x32060dc3,0xdb170042}},	//   rswi, lbas_, _akoy_, _loxí,
   {{0x64400dac,0x6459bcd5,0x9f5e00f7,0xbe120033}},	//   _etmi, sswi, coté_, _সংসদ_,
   {{0x6602bcd6,0x56946823,0x1b1e0033,0x61e20207}},	//   cook, _щаст, বুকে_, _cmol,
   {{0x443f1766,0x7bd5012f,0x45d4021d,0x629c03e0}},	//   _utu_, khzu, _сотс, _šrot,
   {{0xee393425,0x7645012f,0x61e2bcd7,0xa3ac0096}},	//   мно_, ophy, _emol, गाः_,
   {{0x9d460dde,0x25ad0051,0x25bfbcd8,0x00000000}},	//   кенд, _knel_, _koul_, --,
   {{0x38697ccb,0x200c01d7,0x6b85009e,0xdb1701ef}},	//   krar_, aldi_, _abhg, _coxí,
   {{0x320d0602,0x7de400b5,0x7e680223,0x200c0051}},	//   mley_, sőso, ardp, bldi_,
   {{0x3869bcd9,0x39490033,0x5f0501ee,0x320d1655}},	//   drar_, ebas_, _изла, lley_,
   {{0x2d9b00da,0x25ad01f7,0xa6ec0033,0x00000000}},	//   _faqe_, _onel_, _কর্ম_, --,
   {{0x78a90c99,0x25bf0043,0xb2220093,0x38697cce}},	//   _ševa, _noul_, _þætt, frar_,
   {{0xdb1c0037,0x66020207,0x00000000,0x00000000}},	// [e2c0] thró, vook, --, --,
   {{0x25adbcda,0x46a6bcdb,0x7bd501ae,0xdb1c10c0}},	//   _anel_, казв, chzu, tkrä,
   {{0xe57a0a93,0x6440012f,0x25bf02d0,0x320d0ba4}},	//   дзе_, _stmi, _boul_, kley_,
   {{0xceb21899,0x0446587d,0x600f0c71,0x25ad0036}},	//   ייב_, ведн, dømm, _cnel_,
   {{0x66024c4f,0xdb1c0ed4,0x25bf0107,0x200c0093}},	//   rook, skrä, _doul_, yldi_,
   {{0xf74334d4,0x61e2bcdc,0x25adbcdd,0x66020273}},	//   _веро, _smol, _enel_, sook,
   {{0x37e32eb3,0x25bf02d0,0xa3de0026,0x66e6bcde}},	//   _торг, _foul_, दोष_, _рова,
   {{0x2b58066a,0x320dbcdf,0x30a62d64,0x69d60023}},	//   harc_, gley_, вров, nhye,
   {{0x2eca2e99,0x14260f27,0xa0671a31,0xf99f0107}},	//   ान्त, _адам, вања_, _okèn_,
   {{0xb4ce0e6f,0x78a6bce0,0x1fa61b96,0xd9bf0726}},	//   शनी_, _mrkv, триг, _एक्ट,
   {{0x442c4a4c,0x320d39c6,0x2d9b01f4,0x394900c7}},	//   _iid_, bley_, _paqe_, ybas_,
   {{0x61460cf9,0x32060430,0x3869624a,0xdfd00088}},	//   _реда, _ukoy_, yrar_, _گيت_,
   {{0x7d160035,0x442cbce1,0x00000000,0x00000000}},	//   _czys, _kid_, --, --,
   {{0x442c0260,0x4ea60ea7,0x3869bce2,0x1ae40033}},	//   _jid_, _ариа, vrar_, _গড়ে_,
   {{0x442cbce3,0x1ae60083,0x257d006c,0xa3b300a1}},	//   _mid_, _খুবই_, náló_, टात_,
   {{0x442cbce4,0x3204bce5,0xb33c0069,0x3f9c081b}},	//   _lid_, nomy_, _inħu, _havu_,
   {{0x78a60537,0x442c598f,0x394901c8,0x3f9c8ec0}},	// [e2d0] _crkv, _oid_, rbas_, _kavu_,
   {{0x3869bce6,0x6fcd2a87,0x442c0297,0x25ad04ce}},	//   rrar_, _núcl, _nid_, _snel_,
   {{0x25bfbce7,0x320d233c,0xa3ac1119,0x321f08dd}},	//   _poul_, yley_, गाई_, ymuy_,
   {{0x3869bce8,0x320d019a,0x442c00a5,0xb87b0042}},	//   prar_, xley_, _aid_, _oxíx,
   {{0x442c022d,0x6e2d1292,0x320d0345,0x225e01ed}},	//   _bid_, _miab, vley_, _avtk_,
   {{0x69cd0a1e,0x799d6ef9,0x7d0d0371,0x6e2dbce9}},	//   lkae, _hasw, _myas, _liab,
   {{0x442c0122,0x36d5248c,0x799dbcea,0x7d0d9a1a}},	//   _did_, _совр, _kasw, _lyas,
   {{0x2c1a007c,0x6e2dbceb,0x9f45bcec,0x799d0345}},	//   _मीनू_, _niab, milé_, _jasw,
   {{0x44f5bced,0x320d022d,0x442c0484,0x799d000e}},	//   _спас, rley_, _fid_, _masw,
   {{0x442cbcee,0x6ed30095,0x799d8848,0x7dc6002a}},	//   _gid_, ləbə, _lasw, _lóst,
   {{0xc7d60122,0x7d0dbcef,0x02d9097f,0x3f9c219e}},	//   רותי_, _ayas, _ثواب_, _davu_,
   {{0x8c4654d6,0x6e2d58d3,0x7d0dbcf0,0x799d1766}},	//   леме, _ciab, _byas, _nasw,
   {{0x407900c2,0x61e9bcf1,0x1ae10033,0x7d0d01d5}},	//   _נאַװ, miel, _খুলে_, _cyas,
   {{0x61e9bcf2,0x7d0d02d0,0x799d3599,0x442c013b}},	//   liel, _dyas, _aasw, _xid_,
   {{0xada6027a,0x2005bcf3,0x3f87bcf4,0x09cc0083}},	//   _байл, moli_, _ibnu_, রোফা,
   {{0xa2a41bc6,0x2005bcf5,0x6e2d043d,0x09cc0033}},	//   कित्, loli_, _giab, রোনা,
   {{0x60c90e83,0x1867bcf6,0x60db08c2,0x7d16004e}},	// [e2e0] nyem, лати_, nzum, _uzys,
   {{0x61e9bcf7,0x2005bcf8,0x661b002f,0x9f4545c0}},	//   hiel, noli_, _ahuk, filé_,
   {{0x61e9bcf9,0x5b7b011d,0x2005027a,0x661b073a}},	//   kiel, _אריא, ioli_, _bhuk,
   {{0x442cbcfa,0x661bbcfb,0x2005bcfc,0x60c95d11}},	//   _sid_, _chuk, holi_, kyem,
   {{0x2005bcfd,0x61e9bcfe,0x6d56bcff,0x9f4502e9}},	//   koli_, diel, _meya, pilè_,
   {{0xa3de004e,0x2005bd00,0x66090088,0x661b01d7}},	//   दों_, joli_, _ekek, _ehuk,
   {{0x61e99dfc,0x442c4b47,0x200500e9,0xf36503d0}},	//   fiel, _vid_, doli_, ртін,
   {{0x3f9c0080,0x61e9004e,0xb3a400c0,0xdb1e0042}},	//   _savu_, giel, _गोरख, _copé,
   {{0x442c04ca,0x6e2dbd01,0x3ea70042,0x32040187}},	//   _tid_, _riab, _arnt_, romy_,
   {{0x987b00c2,0x20050484,0x661b022e,0x6e2dbd02}},	//   עריק, goli_, _zhuk, _siab,
   {{0x51861c4d,0x61e9bd03,0x6d5632c7,0x52750409}},	//   _була, biel, _beya, _вучу,
   {{0x629a1852,0x61e9bd04,0x60c97dbe,0x7c3601fb}},	//   _isto, ciel, byem, _buyr,
   {{0x00da08cf,0x3f9c00ea,0x1c16007c,0x60c904fb}},	//   _ثبات_, _tavu_, _दीहल_, cyem,
   {{0x20050133,0xac1902c4,0x6b9e0310,0x7d0d034d}},	//   coli_, тогу_, _capg, _vyas,
   {{0x7dc6bd05,0x6e2d011e,0x799dbd06,0x6d560107}},	//   _póst, _tiab, _pasw, _feya,
   {{0x6d5643dc,0x7d0d0951,0x6e2d009e,0x00000000}},	//   _geya, _tyas, _uiab, --,
   {{0xac950009,0xb4ce018d,0x799d0345,0xd76b002d}},	// [e2f0] _тапш, शनो_, _vasw, ешед_,
   {{0x661b2edd,0x61e9bd07,0x629a26be,0xb33c003c}},	//   _shuk, ziel, _osto, _jaħd,
   {{0xa3d800dc,0x2ca9024e,0x799dbd08,0xbb3a00a5}},	//   ासन_, _hrad_, _tasw, _בעתי,
   {{0x788700ea,0x20050155,0x26f529ad,0xa3e726d4}},	//   tīvā, zoli_, _आशीर_, मोन_,
   {{0x61e9b474,0x2d890118,0x629abd09,0x00000000}},	//   viel, _mbae_, _asto, --,
   {{0x61e9bd0a,0x03a512f8,0x2d890009,0x6ed300a8}},	//   wiel, рико, _lbae_, səbə,
   {{0x2005bd0b,0x61e9bd0c,0x661b01cb,0x00000000}},	//   voli_, tiel, _thuk, --,
   {{0x60db2543,0x60c92b2a,0x66090848,0x2005bd0d}},	//   tzum, tyem, _ukek, woli_,
   {{0x61e928d1,0x6d560c1f,0x2005bd0e,0x629a07d6}},	//   riel, _reya, toli_, _esto,
   {{0x09d21365,0x61e9bd0f,0x6d56bd10,0x60db1f3d}},	//   _सत्य, siel, _seya, rzum,
   {{0x612b1a68,0x2005bd11,0x61e9bd12,0x2ca9002d}},	//   _bölü, roli_, piel, _arad_,
   {{0x2005bd13,0xb2ba0122,0xf2c401e0,0xa3b3046c}},	//   soli_, _במער, _усун, टाव_,
   {{0x4b2300c8,0x200518fd,0x7c3810ec,0x7df200ea}},	//   _ব্লগ_, poli_, _čvrs, nāsi,
   {{0x629a0297,0x78a40382,0x6d56001c,0x00000000}},	//   _ysto, vviv, _weya, --,
   {{0x39461111,0x6d56bd14,0xe7fb0066,0x68fd0118}},	//   ñoso_, _teya, ्वना_, _axsd,
   {{0xf2d202b5,0x213f028b,0x394600d8,0x61f90069}},	//   קען_, ncuh_, рнаг, _jjwl,
   {{0x2ca9bd15,0x6b9e0159,0xe73a0214,0x9b460987}},	// [e300] _grad_, _tapg, вез_, _پنجو,
   {{0x3cf10187,0x78a4449a,0x9f8900ee,0x076a0037}},	//   šová_, rviv, _aúú_, ئماً_,
   {{0x248d0f5d,0xa2b10026,0xdb050a8a,0x4aba00af}},	//   _apem_, _अपग्, _anhæ, _рупя_,
   {{0xa2a41ede,0x32ee0095,0xfc3fb403,0xe9a63537}},	//   किस्, _rəy_, lvía_, _тамп,
   {{0x39420282,0x27f80183,0x00000000,0x00000000}},	//   _ifks_, _tjrn_, --, --,
   {{0x326637f8,0x386002a8,0x3940bd16,0xfc3f0300}},	//   атив, msir_, lcis_, nvía_,
   {{0x4e064532,0xd25700d8,0xfe06065f,0xae06046c}},	//   रवाई_, ацы_, रवास_, रवान_,
   {{0x394071e9,0x629a53eb,0x00000000,0x00000000}},	//   ncis_, _vsto, --, --,
   {{0x80b00026,0x3860bd17,0x39400079,0xdfda01d3}},	//   जमें, nsir_, icis_, вън_,
   {{0x4ea6bd18,0x386002e1,0x09b300a1,0x4fc6188d}},	//   арма, isir_, _ंच्य, рсиа,
   {{0xa3b3046c,0x35ab0992,0x629a336f,0x0737011d}},	//   टार_, _घोड़, _usto, יאים_,
   {{0xb33c0484,0x7de700d4,0x2ca91b84,0x6fcd0098}},	//   _waħd, ріод, _prad_, _lúch,
   {{0xed5800d8,0xb33c003c,0x5c7401f5,0x00000000}},	//   шоў_, _taħd, олят, --,
   {{0xdb1e016e,0xf53900ee,0x00000000,0x00000000}},	//   _copï, _maťa_, --, --,
   {{0x9b58176c,0x00000000,0x00000000,0x00000000}},	//   рист_, --, --, --,
   {{0xb33c009f,0x6829005f,0x00000000,0x00000000}},	//   _jaħb, _iždi, --, --,
   {{0x2ca9778c,0x6fcd0168,0x89385128,0xb33c009f}},	// [e310] _urad_, _búch, рпус_, _maħb,
   {{0xd7590fab,0xf7730071,0xcb9900d4,0x7dc62314}},	//   الات_, تار_, _свої_, _hósp,
   {{0x248d0024,0x6fcd0037,0x29070035,0x00000000}},	//   _spem_, _dúch, łna_, --,
   {{0x6d5dbd19,0xf53900ac,0xdb050168,0x316600e0}},	//   nasa, _baťa_, _dohô, _ndoz_,
   {{0x64a5061c,0x7bc5007c,0xdff82135,0xa3b300dc}},	//   сала, _kohu, ुवाद_, टाल_,
   {{0x6fa602e4,0x425501d3,0x3959345d,0x316601ed}},	//   _कोलं, бтит, _hess_, _adoz_,
   {{0x6d5dbd1a,0x39590107,0x41d201d1,0x00000000}},	//   kasa, _kess_, तसंस, --,
   {{0x96f8386a,0x7bc59052,0xdb05017b,0x00000000}},	//   _тест_, _lohu, _inhä, --,
   {{0x9f450036,0x60090274,0x04c80118,0x39590cdb}},	//   bilì_, лним_, _پولي_, _mess_,
   {{0xe81d9f50,0x39590122,0x6b9500f4,0x7bc5bd1b}},	//   _बीमा_, _less_, jezg, _nohu,
   {{0xed5a059b,0xee360043,0x6d5dbd1c,0x6da659d4}},	//   лон_, йнэ_, fasa, бина,
   {{0xfbc96a92,0x63a10099,0x7bd701ef,0x65790159}},	//   _את_, _haln, _alxu, ngwh,
   {{0x63a12686,0x2281006c,0x90450c26,0x7bc5bd1d}},	//   _kaln, lók_, _انته, _bohu,
   {{0x63a171e6,0x8fa40037,0x00000000,0x00000000}},	//   _jaln, _ومنه, --, --,
   {{0xc33202da,0xfc3f0b06,0x91db4407,0xa96a0970}},	//   לום_, rvía_, _बताई, лива_,
   {{0x1a2abd1e,0x3860bd1f,0x7bd70176,0xfc3f0138}},	//   ужби_, tsir_, _elxu, svía_,
   {{0x3959022a,0xdb0516ad,0x6c86004f,0x3940bd20}},	// [e320] _dess_, _anhä, _الخم, rcis_,
   {{0x39400138,0x628319be,0x63a1bd21,0x6eca013b}},	//   scis_, ktno, _naln, bəbd,
   {{0xa686bd22,0x3860bd23,0xdb1e024e,0x3e63027d}},	//   след, ssir_, _kopí, nıt_,
   {{0x228100b5,0x250b014a,0x499a195c,0x00000000}},	//   dók_, گرمی_, _стоя_, --,
   {{0x779400bf,0x62810069,0xb60800a0,0x00000000}},	//   _ویرا, _aqlo, _našť, --,
   {{0x25a0308b,0x63a1009e,0x6d5dbd24,0x3e630225}},	//   žil_, _caln, zasa, kıt_,
   {{0x69c6bd25,0x6d5dbd26,0x6d440035,0xe5a659d4}},	//   _koke, yasa, _ofia, _ливи,
   {{0xe7fb00b4,0x66f700a5,0x69c69155,0xb33c0069}},	//   ्वथा_, _המלא_, _joke, _qaħb,
   {{0x6d5dbd27,0x7413132d,0x69c601c8,0xa3d82095}},	//   vasa, _کولا, _moke, ासद_,
   {{0x6d5d108b,0x2281008a,0x6d44bd28,0x69c6bd29}},	//   wasa, bók_, _afia, _loke,
   {{0x66fa09b1,0x9f5e9b36,0x79960211,0xd36f0037}},	//   ्थिक_, gotá_, keyw, _أهم_,
   {{0x2bd1473a,0x7bc800ab,0x00000000,0x00000000}},	//   हस्थ, ödun, --, --,
   {{0x6d5d1221,0x63a10dac,0x7bc5bd2a,0xdb1e148a}},	//   rasa, _yaln, _pohu, _dopí,
   {{0x6d5d70fd,0x3959035f,0xa3d8012f,0x8fa37086}},	//   sasa, _sess_, ासि_, _наче,
   {{0x6d5d0cca,0x99670210,0x69c61281,0xcf260c74}},	//   pasa, йтал, _boke, _ارشي,
   {{0x69c61c26,0x06df0033,0x5c7500c3,0x3a3a03d0}},	//   _coke, _বুঝি, _длит, _dupp_,
   {{0xa3d82e4f,0x7bc5bd2b,0x2281006c,0x395905f5}},	// [e330] ासा_, _tohu, zók_, _vess_,
   {{0xd6db0043,0x67eb003c,0x7bdc5c35,0x62830355}},	//   лте_, rżjo, chru, ytno,
   {{0xa9351958,0x69c602c4,0x62830211,0x63a101f2}},	//   _менш, _foke, xtno, _raln,
   {{0x69c60345,0x00000000,0x00000000,0x00000000}},	//   _goke, --, --, --,
   {{0xe7fb060a,0xa87902b5,0xa5bd00d8,0xd7fb02ce}},	//   ्वदा_, _דאָר, _siųs, _був_,
   {{0x3e63036a,0x22810332,0x644b027a,0x224903e6}},	//   yıt_, tók_, rpgi, апки_,
   {{0x657a0082,0x6eca00a8,0x69c66a0a,0x00000000}},	//   úchá, həbb, _yoke, --,
   {{0x644b022a,0x628300cd,0x2281470c,0x63a1bd2c}},	//   ppgi, rtno, rók_, _waln,
   {{0x62830252,0x63a1bd2d,0x261c0079,0x636b0d6e}},	//   stno, _taln, síoc_, _брег_,
   {{0x9e650b00,0x63a102c4,0x6d4413fb,0xaaba111b}},	//   овод, _ualn, _sfia, _उपलक,
   {{0x4427010d,0xd12e006c,0xdb1e0187,0xf77232e3}},	//   mmn_, ٹمی_, _popí, וקי_,
   {{0x2b5a0392,0xf53907c0,0xe01900ab,0xc1e600e0}},	//   _sepc_, _maťo_, _नीरद_, _وکيل_,
   {{0x7bdc8fc1,0x61ebbd2e,0x3a3a0147,0x00000000}},	//   thru, _imgl, _supp_, --,
   {{0x95e626c6,0x69c600c3,0x031d00b4,0xe1f900c7}},	//   _कष्ट_, _soke, _फराह_, lnų_,
   {{0xab2a7a12,0x2fc7bd2f,0x69c6bd30,0xfaa32b34}},	//   рова_, _iong_, _poke, маро,
   {{0x7bdc026e,0xe9d724df,0x69d800d8,0x644901b7}},	//   shru, окс_, _įves, _otei,
   {{0x2fc7134c,0x57eabbd5,0x69c61813,0xb33c035f}},	// [e340] _kong_, адам_, _voke, _laħa,
   {{0x2fc7bd31,0x95f41fe0,0x69c60027,0xf5390168}},	//   _jong_, ेक्ट_, _woke, _baťo_,
   {{0x2fc7bd32,0x6449bd33,0xa3b30726,0x249f0139}},	//   _mong_, _atei, टाई_, _asum_,
   {{0x2fc7bd34,0x68fb0009,0x291c013b,0x00000000}},	//   _long_, _žude, əvan_, --,
   {{0x649a0227,0x7de400b5,0x27ea02d7,0x6569016e}},	//   ртер_, lőss, _tmbn_, _ddeh,
   {{0x66e6bd35,0x64490037,0xb33c003c,0x00000000}},	//   _дога, _dtei, _baħa, --,
   {{0x9f45027a,0x64494cff,0x00000000,0x00000000}},	//   dilà_, _etei, --, --,
   {{0xb33c035f,0x78a900cd,0xa3d80099,0x6449009e}},	//   _daħa, _ševi, ासह_, _ftei,
   {{0xdfd00082,0x2fc7bd36,0x9f4c00f7,0x2b11007c}},	//   فية_, _bong_, lidé_, _दुनु_,
   {{0x2fc7bd37,0x388e00ea,0xb33c009f,0xdb1c00b5}},	//   _cong_, mērā_, _faħa, nkró,
   {{0xdefa005f,0x2fc7bd38,0x2ca0bd39,0x25a6001e}},	//   рып_, _dong_, _asid_, odol_,
   {{0x25a6bd3a,0xdce40097,0x2d800337,0x00000000}},	//   ndol_, _edič, _ccie_, --,
   {{0x2fc7046a,0xd7da0099,0x2ca00395,0x2486bd3b}},	//   _fong_, णसाच, _csid_, ntom_,
   {{0x2fc70044,0xfc3f0b06,0x61ed01ba,0x2a7800f6}},	//   _gong_, svío_, ďale, furb_,
   {{0x69d801c8,0x200cbd3c,0x6fcd0453,0x25a60159}},	//   _įver, modi_, _cúcu, kdol_,
   {{0x248615ce,0x25a4046a,0x2fc7bd3d,0x00000000}},	//   ktom_, _naml_, _zong_, --,
   {{0x25a602c7,0x2d99bd3e,0x2fc722d1,0xdcfd0029}},	// [e350] ddol_, mese_, _yong_, resē,
   {{0x2a78aad9,0x2fc701a5,0x200c00e9,0x25a601ba}},	//   burb_, _xong_, nodi_, edol_,
   {{0x6449bd3f,0xfdff0e04,0x3952bd40,0x601401f7}},	//   _stei, _उदास_, bbys_, gàmi,
   {{0x1a9a02b5,0x2d99bd41,0x200c03c9,0x7bd50051}},	//   _פירע, nese_, hodi_, lkzu,
   {{0x200c0054,0x2d99027a,0xd7770079,0xb33c035f}},	//   kodi_, iese_, _واسع, _saħa,
   {{0xe0190299,0x25a600e9,0xf1a30035,0x883a00a5}},	//   _नींद_, adol_, _खोजन, _לתשו,
   {{0x2fc7bd42,0x2d99bd43,0x9f4c0248,0x65690051}},	//   _rong_, kese_, cidé_, _tdeh,
   {{0x249f01a9,0x2fc70122,0x2d99bd44,0x01650370}},	//   _tsum_, _song_, jese_, чкио,
   {{0x2d99043f,0x2fc70dc3,0x249f00e0,0x64490132}},	//   dese_, _pong_, _usum_, _utei,
   {{0xb4d711b5,0x200cbd45,0xa3e70084,0x2d80bd46}},	//   ानी_, godi_, मोश_, _scie_,
   {{0xf77202b5,0x2d99bd47,0x2fc7bd48,0x6829010b}},	//   עקט_, fese_, _vong_, _uždu,
   {{0x2fc71c04,0x2d99bd49,0xa3e71e82,0xdb160355}},	//   _wong_, gese_, मोर_, ícíc,
   {{0x2fc7bd4a,0x621a0100,0x61fb0043,0x200c01a0}},	//   _tong_, _פונק, mnul, bodi_,
   {{0x8fa51fda,0x69cb3308,0x9f4500d5,0x2fc700e2}},	//   _хаке, ögen, bilá_, _uong_,
   {{0x2d990391,0x25a65593,0x61fb2909,0x6fcd2b01}},	//   bese_, ydol_, onul, _dúct,
   {{0x2d99bd4b,0x61fbbd4c,0x9f4c00de,0x7bd50051}},	//   cese_, nnul, vidé_, akzu,
   {{0xdb1e00d5,0x50db021a,0x248600a0,0x09e3693d}},	// [e360] _dopá, यनिष, xtom_, хотн,
   {{0x61fbbd4d,0x7bd5033b,0x7b0700b5,0x25a4093a}},	//   hnul, ckzu, érté, _saml_,
   {{0x6e24006d,0x61fbbd4e,0x91db4eee,0x00000000}},	//   _khib, knul, बसाई, --,
   {{0x200c0b5e,0x248600a5,0xa2bf7d61,0x00000000}},	//   zodi_, ttom_, वमन्, --,
   {{0x293700c2,0x888413cf,0x61fb00f4,0xc44801cb}},	//   _מאכן_, _زیان, dnul, زیان_,
   {{0x9294ad23,0x69c4bd4f,0x9d1b0070,0x261c0453}},	//   дакц, ljie, זונט, cíon_,
   {{0x200c10ec,0x53330043,0x9c8700d5,0x25a600f4}},	//   vodi_, нешт, _kačí, pdol_,
   {{0x2486029d,0x61fbbd50,0x2d9901dd,0x69c4bd51}},	//   ptom_, gnul, xese_, njie,
   {{0x200cbd52,0x2d99bd53,0x09ca045c,0x68e4bd54}},	//   todi_, vese_, _रवैय, nzid,
   {{0x6e2429f7,0x2d99bd55,0x61fbbd56,0x7d1f0069}},	//   _ahib, wese_, anul, _rzqs,
   {{0x2d99bd57,0x200cbd58,0x00000000,0x00000000}},	//   tese_, rodi_, --, --,
   {{0xf1a90079,0x200cbd59,0x69c4003c,0x67e0013c}},	//   _وانه_, sodi_, jjie, _höjd,
   {{0x6e24bd5a,0x2d99bd5b,0x160d0084,0x69c4bd5c}},	//   _dhib, rese_, िकतर_, djie,
   {{0x2d99bd5d,0x68e40096,0xfc3fbd5e,0x3a290110}},	//   sese_, dzid, lvík_, wmap_,
   {{0x2d99bd5f,0xba080066,0x6562bd60,0xdb1e0097}},	//   pese_, वकूफ_, kaoh, _popá,
   {{0x5a344697,0x7e7a012f,0x6e2400f1,0xa3b35bba}},	//   енст, mutp, _ghib, _जोन_,
   {{0x6d5f0024,0x3a29bd61,0x00000000,0x00000000}},	// [e370] _ieqa, rmap_, --, --,
   {{0x61fb00cb,0x67e001ff,0x27210033,0x6143008d}},	//   znul, _nöjd, _বলবো_, _kíló,
   {{0x61fbbd62,0xdb1e726f,0x6d5f0031,0x3a294288}},	//   ynul, _topá, _keqa, pmap_,
   {{0xe81d0ccf,0x7e9b02b5,0xe3b80448,0xdb1e08c8}},	//   _बीरा_, מסבו, _anı_, _bopæ,
   {{0xb4d7bd63,0xa3d8022e,0xd469002d,0x61fb0124}},	//   ाने_, ासं_, циле_, vnul,
   {{0xa3e7004e,0x9c87033a,0x7c37007a,0x00000000}},	//   मों_, _začí, _jixr, --,
   {{0x78ad007c,0x69dd00d7,0x61fb011c,0x6d4601ff}},	//   lvav, _klse, tnul, ycka,
   {{0x20030169,0x6d5f0be2,0x00000000,0x00000000}},	//   čjim_, _neqa, --, --,
   {{0x61fb0043,0x8f751112,0x753b0065,0x6d410355}},	//   rnul, муні, _iguz, ělal,
   {{0x61fb0506,0x2628002d,0x798d00e9,0x443f0024}},	//   snul, _uşor_, hfaw, _iuu_,
   {{0x69dd1f8b,0x443f0657,0x7d160086,0xdee518cd}},	//   _olse, _huu_, _syys, фони,
   {{0x443fbd64,0x9f470037,0x645b0107,0xb33c0069}},	//   _kuu_, _imní_, _kwui, _laħl,
   {{0x443f19c6,0x4425bd65,0x7c370024,0x67e001ff}},	//   _juu_, _khl_, _bixr, _höje,
   {{0x443f0d4c,0x7c250211,0xf99f0260,0xb33c009f}},	//   _muu_, _chhr, _okès_, _naħl,
   {{0x160d252b,0x69c4bd66,0xfebb00bf,0x6e24bd67}},	//   िकार_, tjie, _داشت_, _thib,
   {{0x7d0401d7,0x753b58bf,0x6e240027,0x00000000}},	//   _txis, _nguz, _uhib, --,
   {{0x6b93022a,0xb4d720af,0x443f02ec,0x69c4007a}},	// [e380] ädgå, ानो_, _nuu_, rjie,
   {{0x68e4bd68,0x69c4053e,0x69ddbd69,0x46f60be8}},	//   rzid, sjie, _else, мчет,
   {{0x6b9cbd6a,0x67e0013c,0x3a2603fa,0xb33c035f}},	//   merg, _nöje, _омог, _daħl,
   {{0x93bc0019,0x601d027a,0x00000000,0x00000000}},	//   _chăn, kèmo, --, --,
   {{0x249a0357,0x44254564,0x443fbd6b,0x2d920103}},	//   تخاب_, _bhl_, _cuu_, _mbye_,
   {{0x4425bd6c,0xe73a00f0,0x443fbd6d,0x753b01d7}},	//   _chl_, _фев_, _duu_, _eguz,
   {{0x65624a70,0xfe670180,0xdced00c1,0x00000000}},	//   paoh, _جد_, _ocağ, --,
   {{0x6b9c505b,0x6829010b,0x69dd02d7,0x00000000}},	//   herg, _uždr, _xlse, --,
   {{0xfc3f0093,0x443fbd6e,0x6b9cbd6f,0x60f80340}},	//   rvík_, _guu_, kerg, яния_,
   {{0x60f700d8,0x2d920107,0x6b9cbd70,0xfc3f003e}},	//   ьныя_, _abye_, jerg, svík_,
   {{0x6d5f1505,0x63ba0069,0x7d1a00a8,0x179b00a5}},	//   _peqa, _intn, ətsi, חייב,
   {{0x6440bd71,0x2cb2001e,0x443f2d0f,0x63a8ad42}},	//   _kumi, _bryd_, _yuu_, _hadn,
   {{0x628a229d,0xdb1701ef,0xa3b32501,0x6440bd72}},	//   ltfo, _inxé, _जोड_, _jumi,
   {{0x63a80c0a,0x6b9cbd73,0x6560012f,0x2d92073a}},	//   _jadn, gerg, _lemh, _ebye_,
   {{0x628abd74,0xdeef323d,0x9e0710bb,0x64401970}},	//   ntfo, _ры_, _очил, _lumi,
   {{0xb0d200b4,0x7bdebd75,0x69352c72,0x63a8bd76}},	//   _तथाग, _elpu, енбу, _ladn,
   {{0x6440bd77,0x7c37035f,0x9be700d4,0x63ba1e7e}},	// [e390] _numi, _tixr, _жінк, _ontn,
   {{0xf7701c51,0x628a36a2,0x78adbd78,0x443f01d1}},	//   لام_, ktfo, rvav, _ruu_,
   {{0xb4d709b4,0x443fbd79,0x78ad005b,0xa5bd009e}},	//   ान्_, _suu_, svav, _dhųn,
   {{0x6440bd7a,0x69ddbd7b,0x443f2933,0xdb0500e0}},	//   _bumi, _ulse, _puu_, _rahè,
   {{0x6440bd7c,0xf99202b8,0x63a86caa,0x44252454}},	//   _cumi, _ערך_, _badn, _phl_,
   {{0x6440bd7d,0x3869bd7e,0x628a2c9a,0x63a80090}},	//   _dumi, msar_, ftfo, _cadn,
   {{0x443f021e,0x05770312,0x93bc01a5,0x59d3051d}},	//   _wuu_, _يارد, _thăn, _सवार,
   {{0x00c90210,0x443fbd7f,0x63ba033b,0x6b9c7771}},	//   злик_, _tuu_, _entn, zerg,
   {{0x386903d0,0x9f89008d,0xdff5010b,0x442502ee}},	//   nsar_, _búð_, еянь, _thl_,
   {{0x38690370,0x63a80506,0x6b9c0a4a,0x3a39bd80}},	//   isar_, _gadn, xerg, _lisp_,
   {{0x6b9c08f3,0x644001ae,0x628a01e4,0x9f4c0b68}},	//   verg, _zumi, ctfo, cidí_,
   {{0x63a84beb,0xed5702ce,0x2cb2001e,0x3a39022e}},	//   _zadn, ною_, _pryd_, _nisp_,
   {{0x522c00c2,0x63a8022e,0x68fb011c,0x6eca00a8}},	//   _וואַ, _yadn, _žudn, ləbl,
   {{0xc05802fd,0x39490228,0xfaa61a09,0x6b9c02b1}},	//   _آشنا_, ecas_, наго, uerg,
   {{0x6b9c1472,0xf1d3021a,0x501a0070,0x00000000}},	//   rerg, _तवान, _צוצו, --,
   {{0xe9df0037,0x6b9cbd81,0x29190090,0x00000000}},	//   _clú_, serg, _bysa_, --,
   {{0x3a390036,0x38694601,0x78a902c4,0x48e32503}},	// [e3a0] _disp_, gsar_, _ševr, готв,
   {{0x644009df,0x66e61b96,0x39490138,0x00000000}},	//   _rumi, ноза, acas_, --,
   {{0x63a83015,0x6440bd82,0x2003008b,0x3949006d}},	//   _radn, _sumi, čjih_, bcas_,
   {{0x7ddf01d2,0x63a8bd83,0x644000a7,0x2d82bd84}},	//   _kësa, _sadn, _pumi, ngke_,
   {{0x63a800cb,0xfba40026,0x211e0026,0x6fd6000d}},	//   _padn, _ओसाम, _परेश_, _fâch,
   {{0x02a62c0f,0x628abd85,0xd25a10ac,0x6fd6000d}},	//   ерим, ttfo, пци_, _gâch,
   {{0x764e15ed,0xfbd300a5,0x63a8bd86,0xdb050118}},	//   _utby, רתו_, _vadn, _pahé,
   {{0x6440bd87,0x64a6010b,0x00000000,0x00000000}},	//   _tumi, _паба, --, --,
   {{0x628a038d,0x2bd1018d,0xb33c0069,0x6440034d}},	//   stfo, _सकला, _jaħk, _uumi,
   {{0x628a721c,0xddc90035,0x39490453,0x6eca00a8}},	//   ptfo, łożo, zcas_, bəbl,
   {{0x11d600d4,0x59e01ef5,0x00000000,0x00000000}},	//   _підр, नसार, --, --,
   {{0x7c2ebd88,0x6d400e46,0x38690523,0x7a0500c7}},	//   embr, žman, ysar_, kėta,
   {{0x3a390676,0x20d310ad,0x68fb01ba,0xdce600ea}},	//   _risp_, _متوج, _ľudo, cekļ,
   {{0x7a0500c7,0x00000000,0x00000000,0x00000000}},	//   dėta, --, --, --,
   {{0x3f9e9402,0x29dc0042,0xbea30dec,0x00000000}},	//   metu_, _vían_, _бајк, --,
   {{0x3869bd89,0x7c2e027a,0x9f4c0176,0x7afa470c}},	//   tsar_, ambr, lidà_, útta,
   {{0xc4c400f5,0x39492140,0xa898093e,0x3a392063}},	// [e3b0] _اے_, rcas_, нкту_, _visp_,
   {{0x3949532a,0x3869bd8a,0x37070eee,0x391400af}},	//   scas_, rsar_, нчев, умур,
   {{0xf77007f6,0x3869bd8b,0x981417bd,0x34d9000c}},	//   صال_, ssar_, ابقا, भन्द,
   {{0x3869bd8c,0x3a39027a,0x07080698,0x3f9e00b9}},	//   psar_, _uisp_, ريني_, hetu_,
   {{0x64a5323d,0x6fd600f7,0x58d453f6,0x00000000}},	//   тала, _tâch, _боят, --,
   {{0x3f9e0470,0x0454006c,0xe2996550,0x69cfbd8d}},	//   jetu_, ائند, дак_, _hoce,
   {{0x69cf7f6b,0x3f9ebd8e,0xdb050138,0xfbb8011d}},	//   _koce, detu_, _inhó, תפות_,
   {{0x69cf2c60,0x6595005f,0xf48500b5,0x80ca0033}},	//   _joce, _шабу, _لائی, িনন্,
   {{0x3c24013c,0x3f9e3c2c,0x67e0017b,0x80db0067}},	//   höva_, fetu_, _höja, यनें,
   {{0xd00e017e,0x6d4d018e,0x69cfbd8f,0x44f485ad}},	//   يلي_, _afaa, _loce, _спус,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x11f900d1,0x91a700fd,0x673a05f5,0x00000000}},	//   _کوچک_, _سنتے_, _útje, --,
   {{0xe0ce4ae8,0x3f9ebd90,0xddc900cd,0x00000000}},	//   _тв_, betu_, budž, --,
   {{0x2eb50dbf,0x6d4d001c,0xab2a010b,0x00000000}},	//   _асис, _efaa, дога_, --,
   {{0xaf760070,0xb33c0069,0xdee5167d,0x6d4d073a}},	//   _סעקס_, _daħh, _шоки, _ffaa,
   {{0x236702d0,0xdb1e0168,0x3ea70147,0x00000000}},	//   hanj_, _kopú, _isnt_, --,
   {{0x1867bd91,0xa3e10084,0x0c26021d,0xa52000a1}},	// [e3c0] кати_, दसा_, _имин, _बरेच_,
   {{0x291c0228,0xd7f900d4,0x4a461888,0x69cf03d0}},	//   āva_, нує_, _инов, _eoce,
   {{0x26dc033a,0xa2a10035,0x69cf0355,0x2367030a}},	//   ávo_, _कैल्, _foce, danj_,
   {{0x69cf757d,0x3f9e0207,0x7bdc0345,0x00000000}},	//   _goce, zetu_, lkru, --,
   {{0xf1c529ad,0x3f9e08c7,0x00000000,0x00000000}},	//   वानन, yetu_, --, --,
   {{0xdb0e00fb,0x9cd70122,0x23670693,0xdb050176}},	//   _þjón, כונה_, ganj_, _inhò,
   {{0x3f9e0254,0x81ab0033,0xe2972123,0x32631667}},	//   vetu_, খান_, вај_, атыв,
   {{0x79840895,0x7bdc79f3,0x00000000,0x00000000}},	//   ngiw, hkru, --, --,
   {{0x30142ef5,0x64a39f4f,0x2367029d,0x3f9e5305}},	//   лдир, _ката, banj_, tetu_,
   {{0xa3e60299,0xdefa0104,0xbbd101c0,0x236700cd}},	//   _पति_, дым_, _सकेक, canj_,
   {{0x3f9e3ecb,0xdef415eb,0xddc90254,0x00000000}},	//   retu_, упны, rudž, --,
   {{0xe0da0202,0x92e4027d,0x660230c8,0x7bdc0345}},	//   _ове_, ışıl, nnok, ekru,
   {{0xa3e627bd,0xc0e30bfe,0x5f940d6e,0x66023706}},	//   _पता_, _коцк, _билт, inok,
   {{0xa2b80ea3,0x69cfbd92,0x3d120099,0x5c04004b}},	//   ्मप्, _soce, _धुळे_, аяса,
   {{0x69cf0627,0x61e20118,0x00000000,0x00000000}},	//   _poce, _klol, --, --,
   {{0x1f370122,0x660200b5,0x27210033,0x201ebd93}},	//   _ברור_, jnok, _বললো_, llti_,
   {{0x69cf284b,0x201e027a,0x9f5e000d,0x61e208c7}},	// [e3d0] _voce, olti_, enté_, _mlol,
   {{0xb8cb27bd,0x7bdc10c0,0x629a0cd5,0x00000000}},	//   _कई_, ckru, _opto, --,
   {{0x2367bd94,0xfc3f002a,0x69cf2005,0xd5754747}},	//   vanj_, rvíu_, _toce, гуль,
   {{0x98650332,0x2ca90034,0x7ddf01f4,0xa2b8012f}},	//   _میرے_, _ksad_, _mëso, ्मन्,
   {{0x7a05010b,0x151401e0,0x41b60354,0x236700f4}},	//   lėto, адця, _अफ़स, tanj_,
   {{0xa3b30299,0x61e20486,0xfc3f01ef,0x67e0017b}},	//   _जोश_, _alol, lvís_, _höjn,
   {{0x2367bd95,0xe29912ea,0x7a0500c7,0x00000000}},	//   ranj_, хай_, nėto, --,
   {{0xa3b3020c,0x629a01f7,0x2ca9bd96,0x42d401e0}},	//   _जोर_, _dpto, _osad_, рішу,
   {{0x23670280,0x7fd515d6,0xe4a400ed,0x61e20107}},	//   panj_, гіні, _врхо, _dlol,
   {{0xbfc500c3,0x61e200b5,0x7a05010b,0x00000000}},	//   убок, _elol, kėto, --,
   {{0xa2d5004f,0xdb054469,0x32550352,0xe3b000d1}},	//   _حيات, _bahí, _свер, _برق_,
   {{0x2d8901f7,0x8d760079,0x00000000,0x00000000}},	//   _ccae_, دادا, --, --,
   {{0x2245bd97,0x25ad289b,0xe1f9010b,0x23652d00}},	//   _hulk_, _mael_, mių_, _kelj_,
   {{0xe1f90a93,0x8c430d13,0x0ffb0754,0x66020035}},	//   lių_, сере, _تعصب_, znok,
   {{0x2ca9bd98,0x7bdcbd99,0x67e00523,0x00000000}},	//   _esad_, rkru, _böjn, --,
   {{0xe1f90a93,0x98a609ce,0x7bdc0a8c,0x601d0443}},	//   nių_, либе, skru, dèmi,
   {{0xa6ca05f5,0xa9260f08,0x6602552b,0x00000000}},	// [e3e0] کوال_, удал, vnok, --,
   {{0x25bfbd9a,0x3f85bd9b,0x38cb13cf,0xfc3f0176}},	//   _anul_, nglu_, راقی_, avís_,
   {{0xe1f901c8,0xe57a9d83,0xb8cb175f,0xf99f0118}},	//   kių_, езе_, _कै_, _ijèn_,
   {{0x25ad02c7,0x6b9b0207,0x00000000,0x00000000}},	//   _cael_, đuge, --, --,
   {{0x7c3ebd9c,0x6602bd9d,0x2365a50e,0x3ae800b5}},	//   _kipr, rnok, _belj_, _سبھی_,
   {{0xf7431607,0x7c3e0024,0x2245bd9e,0x61e2018d}},	//   _геро, _jipr, _bulk_, _slol,
   {{0xe81d074f,0x23652b6b,0x00000000,0x00000000}},	//   _बीटा_, _delj_, --, --,
   {{0x25ad02c7,0xe1f9010b,0xa07405a1,0x85b50274}},	//   _gael_, gių_, агич, _кључ,
   {{0x2edc000c,0xdfd0004f,0x69dc021a,0x26da00c7}},	//   मन्त, قية_, _नवनी, lypo_,
   {{0x749b0319,0xb4e00084,0x22450345,0x7ddf0031}},	//   _אימפ, दनी_, _fulk_, _pëso,
   {{0x3a207215,0xe1f900d8,0x381700a5,0xb17d00d5}},	//   klip_, bių_, רקים_, chťo,
   {{0x614605f2,0x443e00a5,0x442c0a8a,0x00000000}},	//   _седа, _hit_, _hhd_, --,
   {{0x443e0dd5,0x50a81fc3,0x3a20010d,0x3a2b0124}},	//   _kit_, _कनिष, dlip_, _rhcp_,
   {{0x9f3431ee,0x7c3ebd9f,0xe7bf0083,0x443ebda0}},	//   _келі, _cipr, _ইত্য, _jit_,
   {{0x443ebda1,0x7c3e38bf,0x442c0187,0x3a200a8a}},	//   _mit_, _dipr, _mhd_, flip_,
   {{0x443ebda2,0x5a440144,0xf99f0107,0x442c0090}},	//   _lit_, сэра, _ejèn_, _lhd_,
   {{0x6e2dbda3,0x57f5bda4,0x6eca013b,0x00000000}},	// [e3f0] _ihab, апат, dəbi, --,
   {{0x443e12c3,0x7c3e043d,0x601d02d0,0x442c0051}},	//   _nit_, _gipr, tèmi, _nhd_,
   {{0x6e2dbda5,0xdb0500e9,0x6d4f027a,0x00000000}},	//   _khab, _wahâ, occa, --,
   {{0x443ebda6,0x3a202b1f,0xa5670416,0x7c3e0b51}},	//   _ait_, clip_, ادان, _zipr,
   {{0xe1f901c8,0x442c02c2,0xdb1e0260,0x6d5d0159}},	//   vių_, _bhd_, _anpè, ibsa,
   {{0x987a02b5,0xa87a0070,0x25adbda7,0xd7e401e0}},	//   _באשט, _באשר, _wael_, _лісо,
   {{0x443ebda8,0xd24e0372,0x67e006d7,0x3cfc07ba}},	//   _dit_, ونو_, _möjl, _लेने_,
   {{0x25bf0012,0x443e0044,0x4095bda9,0x673abdaa}},	//   _unul_, _eit_, арот, _útja,
   {{0xe1f90a93,0x68ed09ab,0xb38700bc,0xe450036b}},	//   rių_, nzad, _مجاه, _فضل_,
   {{0xe1f901c8,0x443e01d6,0x656bbdab,0x76470010}},	//   sių_, _git_, lagh, _kujy,
   {{0xed5a1c76,0x63a3bdac,0x7c3ebdad,0xa2b8060a}},	//   кон_, menn, _ripr, ्मण्,
   {{0x6283bdae,0x63a3bdaf,0x656bbdb0,0x443e0a75}},	//   muno, lenn, nagh, _zit_,
   {{0x660900da,0x6283bdb1,0x61e9bdb2,0x61fb0395}},	//   _mjek, luno, mhel, miul,
   {{0x61fbbdb3,0x6609124d,0x656b010d,0x63a3bdb4}},	//   liul, _ljek, hagh, nenn,
   {{0x661b39a7,0x7647bdb5,0x6283bdb6,0x7c3e0987}},	//   _okuk, _nujy, nuno, _vipr,
   {{0x6e2d1093,0x61e9bdb7,0x63a3bdb8,0x61fbbdb9}},	//   _ghab, nhel, henn, niul,

   {{0x63a35d91,0x60dbbdba,0x6283bdbb,0x656b0b04}},	// [e400] kenn, nyum, huno, dagh,
   {{0x63a3bdbc,0x661bbdbd,0x6283bdbe,0x60c90443}},	//   jenn, _akuk, kuno, ixem,
   {{0x63a32257,0x5b7b0122,0x66090009,0x61e9bdbf}},	//   denn, _בריא, _bjek, khel,
   {{0x62833882,0xdcf601d6,0x61fb0054,0x443ebdc0}},	//   duno, _hayı, jiul, _sit_,
   {{0x443ebdc1,0xb4e00907,0xdcf60723,0x63a30297}},	//   _pit_, दने_, _kayı, fenn,
   {{0x6609bdc2,0x6283bdc3,0x661b0ad2,0x443e0055}},	//   _ejek, funo, _ekuk, _qit_,
   {{0x443ebdc4,0x6283bdc5,0xdcf606d0,0xdce6024e}},	//   _vit_, guno, _mayı, dakč,
   {{0x98b201d6,0x68fb77ec,0x61fbbdc6,0x66090044}},	//   layı_, _žudi, giul, _gjek,
   {{0x443ebdc7,0x63a30297,0x4fc638a6,0xb37600d1}},	//   _tit_, benn, асна, _نداش,
   {{0x443e1cd5,0x6d44a761,0x6e2dbdc8,0x442c008c}},	//   _uit_, _agia, _shab, _uhd_,
   {{0x7640bdc9,0x74134dc0,0x62830043,0x91e638a2}},	//   _kimy, _بولا, cuno, _коже,
   {{0x518305f2,0x6d44012f,0x6e2d006d,0x61fb01f1}},	//   _душа, _cgia, _qhab, ciul,
   {{0x2bc3317c,0x6d5d67a1,0xe7c90f9f,0x3eb900ea}},	//   शाला, rbsa, रामप, āsta_,
   {{0x764002e9,0x6d4406a2,0x8fa311d0,0x6fb31301}},	//   _limy, _egia, _маче, _ومنا,
   {{0x6e2d0082,0x9f5e0037,0x9967410e,0x6d44009e}},	//   _thab, nntí_, итал, _fgia,
   {{0x68edbdca,0x827702b5,0x63a3bdcb,0x6e2d5ba0}},	//   tzad, יעלע_, zenn, _uhab,
   {{0x63a3bdcc,0x776701e8,0x7c95004f,0x656b8673}},	// [e410] yenn, _pejx, _الخص, vagh,
   {{0xd6dbbdcd,0x6283bdce,0x68edb286,0x660900d4}},	//   кте_, yuno, rzad, _sjek,
   {{0x95cb0086,0xdb0500a6,0x656b0fc2,0x66090031}},	//   куда_, _anhö, tagh, _pjek,
   {{0x361802ce,0x63a3bdcf,0x261c42ae,0xdcf6027d}},	//   ацію_, wenn, díos_, _zayı,
   {{0xdcf60d6f,0x656bbdd0,0x6609003a,0x7640012f}},	//   _yayı, ragh, _vjek, _dimy,
   {{0xe784bdd1,0x6283a970,0x261c42ae,0xdb0500b8}},	//   _мусо, tuno, fíos_, _zahá,
   {{0x61e9bdd2,0x6609bdd3,0x656b2326,0x61fb8676}},	//   thel, _tjek, pagh, tiul,
   {{0xc69200c2,0x63a3bdd4,0x62834733,0x661b0371}},	//   _מאל_, senn, runo, _ukuk,
   {{0x61e92d3f,0x6283bdd5,0x20d50131,0x61fb002d}},	//   rhel, suno, сійс, riul,
   {{0x628325f5,0x61fbbdd6,0x261c01ef,0x9f4500ac}},	//   puno, siul, bíos_, bilý_,
   {{0xee3a1159,0x7ddf01d2,0x61e9bdd7,0x66f90433}},	//   лно_, _kësh, phel, ्पिक_,
   {{0xdcf60d6f,0x644170e6,0x682900b8,0xd12e103b}},	//   _sayı, _hili, _vždy, ظمی_,
   {{0x6441bdd8,0xdea1006c,0x60c40484,0x656994c5}},	//   _kili, _کیجی, _ġimg, _meeh,
   {{0xdcf601c2,0x644100d6,0x7ddf01f4,0x66190035}},	//   _qayı, _jili, _lësh, howk,
   {{0x98b205f9,0x00000000,0x00000000,0x00000000}},	//   vayı_, --, --, --,
   {{0x6441bdd9,0x7f3a0070,0x3946010b,0x64490345}},	//   _lili, _געצו, снаг, _ouei,
   {{0x6441004f,0x249f006d,0xdce4010b,0x644900c7}},	// [e420] _oili, _npum_, _keič, _nuei,
   {{0x64416a7c,0x3b86192f,0x5baa16b8,0x7640bdda}},	//   _nili, _улог, _ском_, _simy,
   {{0x3cfc0461,0x98b2033e,0xa9a60fc5,0x00000000}},	//   _लेते_, rayı_, _линд, --,
   {{0xa2b8bddb,0x261c0b4c,0x6441bddc,0x6449021d}},	//   ्मस्, víos_, _aili, _buei,
   {{0x64413a0c,0x7ddf01d2,0x6449000d,0xb33c0069}},	//   _bili, _dësh, _cuei, _naħr,
   {{0x6441bddd,0x76400371,0x00000000,0x00000000}},	//   _cili, _wimy, --, --,
   {{0x6569046a,0x76400159,0xf99f0359,0xddc90009}},	//   _feeh, _timy, _akèy_, vrdž,
   {{0x261cbb83,0x905405f2,0x26c50009,0xb33c0024}},	//   ríos_, овиц, _šlog_, _baħr,
   {{0x6441bdde,0xdd170324,0xa3b30026,0x6449bddf}},	//   _fili, _धुंध_, _जोक_, _guei,
   {{0x64411478,0x65690223,0x6fb400fd,0x00000000}},	//   _gili, _zeeh, آمدا, --,
   {{0xa3ad06bb,0x200bbde0,0xfe6d5b0c,0x6449bde1}},	//   _औसत_, écia_, نگي_, _zuei,
   {{0x64410657,0xddeb0413,0x25a602d7,0x7ddf0055}},	//   _zili, ارده_, neol_, _kësi,
   {{0x6441a5e3,0x00000000,0x00000000,0x00000000}},	//   _yili, --, --, --,
   {{0x6441aff1,0x7ddf01f4,0x2ca0023a,0x25a60098}},	//   _xili, _mësi, _dpid_, heol_,
   {{0x81ab00c8,0x9b58002d,0xa3e600ab,0x00000000}},	//   খার_, сист_, _पतई_, --,
   {{0xd2570122,0x00000000,0x00000000,0x00000000}},	//   משלה_, --, --, --,
   {{0xb33c0069,0x6fdf00f6,0x00000000,0x00000000}},	// [e430] _maħq, _bêch, --, --,
   {{0xe9df004f,0xdd31004e,0x64493113,0x25fb0354}},	//   _siúd_, _mężc, _ruei, लोनी_,
   {{0x7bc5bde2,0x6441b6f1,0xa3b304bc,0x7ddf0031}},	//   _inhu, _rili, _जोग_, _pësh,
   {{0x249f00d7,0x7a05010b,0x956702fb,0x00000000}},	//   _ppum_, kėti, съжд, --,
   {{0x6441bde3,0x64497caa,0x7ddf00da,0xdb0501d6}},	//   _pili, _quei, _vësh, _bahç,
   {{0x644120e2,0x7a0500d8,0x4255097b,0xf99f0118}},	//   _qili, dėti, отит, _ojèk_,
   {{0x6441bde4,0x316d01a3,0x7bdc016b,0xc7b232e3}},	//   _vili, taez_, רקוו, _קבל_,
   {{0x939700b5,0xe1f10754,0x659421d7,0xee49055c}},	//   _گجرا, بست_, _насу, _bẽn_,
   {{0x6441bde5,0x9f5e0279,0xdce600ec,0x63c400b8}},	//   _tili, mitê_, kakā, átní,
   {{0xa2b804bc,0xdb1e01d6,0xcf3900d4,0x64410719}},	//   ्मश्, _popü, ичні_, _uili,
   {{0x8e0a1d30,0x9f450036,0x63c400b8,0x2ca0bde6}},	//   инов_, filò_, štní, _spid_,
   {{0xfbc9035e,0xcdf600d8,0x60c400fe,0x24805710}},	//   _בת_, ічны, _šime, šime_,
   {{0x68300301,0x7bd7545b,0xf99f0118,0xdb050282}},	//   läde, _boxu, _ijèh_, _lahä,
   {{0xdee50cb5,0x7bd701ef,0x8af700a8,0x653a0070}},	//   _моли, _coxu, ğənn, יערד,
   {{0xed5a01d3,0xe7ff00b1,0x78bd0036,0x34a600dc}},	//   _кой_, ोचना_, _arsv, _गन्द,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fdf0248,0x6830033b,0x6fcd0266,0x00000000}},	// [e440] _pêch, häde, तापू, --,
   {{0xfc320037,0x7bd701ed,0xe9df026e,0x00000000}},	//   _تحب_, _goxu, _ciúb_, --,
   {{0xd9462701,0xf1bf021a,0xba7639e6,0xb95b0211}},	//   _мени, _शोभन, _باخت, _gnìo,
   {{0xad9b0079,0x24860009,0x64a6010b,0xa5262f7c}},	//   miúc, tuom_, жада, омед,
   {{0x69c6bde7,0xad9b004f,0xdb1e0391,0x7bd70be2}},	//   _inke, liúc, _topó, _yoxu,
   {{0xb33c0024,0x00000000,0x00000000,0x00000000}},	//   _saħq, --, --, --,
   {{0x26cc01d2,0x533308f1,0x41c505f8,0xad9b0079}},	//   _çdo_, мешт, वांस, niúc,
   {{0x672e0c0a,0xd5ad006c,0xe61702fb,0x00000000}},	//   _izbj, _مہم_, _ддс_, --,
   {{0x65620034,0xc05a01e0,0xdfa60bfe,0x9f5e021d}},	//   mboh, шій_, ојно, entá_,
   {{0x33d50eb9,0x9f5e0031,0x6d56023c,0x65621a47}},	//   _ніхт, mitë_, _afya, lboh,
   {{0x69c616d1,0x24500019,0x9f5e0055,0x00000000}},	//   _onke, _hàm_, litë_, --,
   {{0x29dc0453,0x26c501ef,0x7bda5c9a,0x00000000}},	//   _mías_, _áloe_, ötun, --,
   {{0x8cf400d8,0x9f5e0031,0x00000000,0x00000000}},	//   дзяц, nitë_, --, --,
   {{0x6b9b025c,0x212b033b,0x24500211,0xf99f0107}},	//   đugo, üche_, _màm_, _tjèk_,
   {{0x2450098b,0xdce600ec,0xf96b01d3,0x799d0069}},	//   _làm_, rakā, ирай_, _pbsw,
   {{0xa2b20167,0xdce600ea,0x5c751888,0x527b011d}},	//   _आनन्, sakā, _елит, ינלא,
   {{0xdce6013a,0x68fb01ba,0x7bd700a8,0xe89400c3}},	// [e450] pakā, _ľuds, _toxu, мать,
   {{0x69c67c0e,0xcd340c74,0x3f8cbde8,0x9f5e0031}},	//   _enke, _غريب, ngdu_, ditë_,
   {{0xf1b9336f,0xac380037,0x799d034d,0x00000000}},	//   loše_, _بسيط_, _tbsw, --,
   {{0x29dc09ab,0x9f5e01f4,0xdb1e0392,0x683001ff}},	//   _días_, fitë_, _topò, väde,
   {{0xf1b9bde9,0x24504564,0x24f81482,0x8cbe0067}},	//   noše_, _càm_, онцы_, शियो,
   {{0x493a00a5,0xf8bf00de,0xf8da00a5,0xa3fb0033}},	//   _לגרו, _iré_, _החשמ, েত্য_,
   {{0x81b40083,0x5b7c1899,0x212905e2,0x4b7c0070}},	//   ঞান_, ברוא, _šah_, באוו,
   {{0x798dbdea,0x68300ed4,0x9f5e02d0,0xf1b9011c}},	//   ngaw, räde, litè_, koše_,
   {{0x200b0183,0x245800c3,0x657b04fb,0x00000000}},	//   écio_, _мать_, _iduh, --,
   {{0x1e85107a,0x7ddf01f4,0x798d012f,0xf1b9011c}},	//   плом, _mësu, hgaw, doše_,
   {{0x7a05010b,0xa3b808cf,0x37bd0033,0x00000000}},	//   lėtu, _باقر_, _আকার, --,
   {{0xd1b807f8,0xcfe900d1,0x78ad251e,0x442702b1}},	//   _وانا_, _گفته_, kwav, lln_,
   {{0x53c0022e,0xf1b901a0,0x6e920fa2,0x200e00fe}},	//   _षोडश, goše_, ولیا, _fjfi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab2a7538,0x9f5e01f4,0x657b0009,0xf8bf0118}},	//   сова_, zitë_, _oduh, _aré_,
   {{0xad9b0082,0x798dbdeb,0x29dc20d9,0x657b007b}},	//   riúc, ggaw, _rías_, _nduh,
   {{0x98a34697,0xad9b0079,0xf8bf0079,0x2d920371}},	// [e460] ните, siúc, _cré_, _icye_,
   {{0x02bd012f,0x798d1187,0x29dc002a,0xf8bf0051}},	//   ्माभ, agaw, _pías_, _dré_,
   {{0x236c0345,0xba7629fe,0x245000cc,0x00000000}},	//   _redj_, _عادت, _sàm_, --,
   {{0x29dc0b4c,0x645b009e,0x9f5e0031,0x69c605aa}},	//   _vías_, _btui, titë_, _unke,
   {{0x649a1e56,0x657b011e,0x6283bdec,0x69da000d}},	//   стер_, _dduh, erno, êteu,
   {{0x38600ce8,0x9f5e00da,0xa5331958,0x660b39f6}},	//   mpir_, ritë_, хніч, angk,
   {{0x46a31954,0x9f5e01f4,0x645bbded,0x00000000}},	//   _парв, sitë_, _etui, --,
   {{0x9f5ebdee,0x3a2200d7,0x2fc755ad,0x764e00ee}},	//   mité_, _jkkp_, _anng_, _iuby,
   {{0x9f5ebdef,0x764e011e,0x3cfc007c,0x628303a5}},	//   lité_, _huby, _लेले_, arno,
   {{0xb4d821b2,0x66029037,0x764e041b,0x657b0009}},	//   ाही_, liok, _kuby, _zduh,
   {{0xdefa0409,0x9f5e41f9,0x81462ac4,0x00000000}},	//   сып_, nité_, _فنان, --,
   {{0x63aa008a,0x764e041b,0x6602bdf0,0x2fc70103}},	//   lefn, _muby, niok, _enng_,
   {{0xdb1e0260,0x628a00c3,0x62980408,0x764e001c}},	//   _anpà, lufo, ltvo, _luby,
   {{0x764e0c1f,0x63aa008a,0xa2c000e7,0x765c0523}},	//   _ouby, nefn, विप्, _otry,
   {{0xf1b90c99,0x798d6f1a,0x62980e54,0x9f5ebdf1}},	//   soše_, tgaw, ntvo, vitè_,
   {{0xf8bfbdf2,0x201ebdf3,0x9f5e0248,0x78ad2d1a}},	//   _pré_, loti_, dité_, twav,
   {{0x6d403f23,0x57b50390,0x798d0173,0x2c2700d4}},	// [e470] žmar, мбат, rgaw, _ньог,
   {{0x201e3cf1,0x9f470187,0x78ad08c3,0x9f5e000d}},	//   noti_, _plné_, rwav, fité_,
   {{0x645bbdf4,0x3dc904f4,0x63aa00e9,0xd6db02fb}},	//   _stui, _knaw_, defn, щта_,
   {{0xa2c00b54,0xf8bf5bdd,0x201e0371,0x764ebdf5}},	//   विन्, _tré_, hoti_, _duby,
   {{0x201e0bbc,0x62830297,0x3e4c01c0,0x3a2900b5}},	//   koti_, wrno, _děti_, mlap_,
   {{0x0fe70083,0x201ebdf6,0x7a05010b,0x3a29bdf7}},	//   _পদ্ধ, joti_, rėtu, llap_,
   {{0x9f5e1010,0x201e3cf1,0x4e1d0035,0x764e010d}},	//   cité_, doti_, नवाई_, _guby,
   {{0x24800254,0x3a29bdf8,0x200c00ab,0x60c4093f}},	//   šima_, nlap_, endi_, _šima,
   {{0x6b9c0297,0x224601ed,0x200c008d,0x442700d5}},	//   yfrg, _diok_, fndi_, pln_,
   {{0x201ebdf9,0xb4e90e04,0x00000000,0x00000000}},	//   goti_, मनी_, --, --,
   {{0xe7f507ba,0x3a2920fe,0x683000be,0x78b80228}},	//   _इतना_, klap_, näda, āvvi,
   {{0x224600e7,0x200c027a,0xed5701e0,0x386005ee}},	//   _giok_, andi_, мою_, ypir_,
   {{0x51844f87,0x3a293120,0x417403fc,0x5576016b}},	//   _чуха, dlap_, _سانس, וערן_,
   {{0x660201d7,0x6abc0009,0xfaa6b5c9,0xddc40103}},	//   ziok, tvrf, маго, _kiiŋ,
   {{0x8c432b8e,0xef1f0095,0x9f5e000d,0x3a290345}},	//   тере, şüb_, xité_, flap_,
   {{0x9f5e02e1,0xad9b0037,0x764e01d5,0x9f450355}},	//   vité_, liún, _ruby, chlá_,
   {{0x765cbdfa,0x6e240232,0xd3780a78,0xd7c902cb}},	// [e480] _stry, _ikib, _hoće_, रांच,
   {{0x9f5ebdfb,0xad9b0079,0x66e630cc,0x00000000}},	//   tité_, niún, моза, --,
   {{0x86c60082,0x4e0209f9,0x3e4c0355,0x644f1c5b}},	//   بيان, _लगाई_, _pěti_, _écij,
   {{0x9f5e1010,0x452a3bd5,0xad9b0037,0x7d7b0070}},	//   rité_, ожен_, hiún, ַנצו,
   {{0x9f5e7620,0x776e006d,0x6602bdfc,0x63aa0093}},	//   sité_, _tebx, riok, tefn,
   {{0xd25a0896,0x6602bdfd,0x6846093e,0x764e2696}},	//   оци_, siok, _інва, _tuby,
   {{0x201ebdfe,0xf74376d2,0xdb07006c,0x63aabdff}},	//   voti_, _аеро, tejé, refn,
   {{0x628abb84,0x320d01ed,0x6298be00,0xdced022f}},	//   rufo, gney_, rtvo, _udać,
   {{0x62980759,0x201ebe01,0x30be0033,0x00000000}},	//   stvo, toti_, েন্স, --,
   {{0x6e2435c5,0xad9b0037,0xff980274,0x0ec90026}},	//   _akib, giún, чкој_, िमंड,
   {{0x3a290008,0xdd95010b,0x3c24013c,0x68e4028b}},	//   ylap_, наны, hövs_, hyid,
   {{0x6e362d88,0x00e61e9c,0x644811be,0xd37800f4}},	//   _chyb, _ожен, _hidi, _doće_,
   {{0x201e000e,0xa2b8021a,0x644877b6,0xe0d21c73}},	//   poti_, ्मक्, _kidi, _جزا_,
   {{0x6e2409d6,0x644802d0,0xdf0a061c,0x2d850225}},	//   _ekib, _jidi, _мэйл_, şle_,
   {{0x644859fe,0x60c20366,0x24860284,0xf1b919be}},	//   _midi, _hrom, hrom_, loša_,
   {{0x8cc6009a,0x60c2be02,0x1de300b4,0xf4140033}},	//   ामखो, _krom, _पवित, িতির_,
   {{0x3a29be03,0x383554d4,0xf1b92c14,0x7b670945}},	// [e490] rlap_, енар, noša_, _отне,
   {{0x2486be04,0xc6171119,0x6e3d33c2,0x60c20858}},	//   drom_, तव्य_, lmsb, _mrom,
   {{0xf4140083,0x9f4c02d7,0x3a29be05,0x00000000}},	//   িতার_, lidó_, plap_, --,
   {{0x60c20fde,0x6448be06,0x683001ff,0x35f801cb}},	//   _orom, _aidi, räda, ورند_,
   {{0xb4e90ca1,0xd4695ca3,0x6448be07,0x69dd0160}},	//   मने_, чиле_, _bidi, _iose,
   {{0xc6a774ea,0x69ddbe08,0xdced0168,0x00000000}},	//   _орби, _hose, _obaľ, --,
   {{0x64484e9e,0x6d4d030d,0x387e00ea,0xa2b80808}},	//   _didi, _ogaa, _ātri_, ्मग्,
   {{0x6d4dbe09,0xf7700332,0x2486be0a,0x9e4801ba}},	//   _ngaa, _ماہ_, brom_, _keďž,
   {{0x69ddbe0b,0x60c2be0c,0x6448be0d,0x6e36001e}},	//   _mose, _crom, _fidi, _rhyb,
   {{0x60c2be0e,0x6d4d018e,0x6448be0f,0x6e2401b4}},	//   _drom, _agaa, _gidi, _skib,
   {{0xad9b004f,0xa2c000a1,0x60c2be10,0x32040067}},	//   riún, विण्, _erom, bimy_,
   {{0x7c25046a,0xad9b0082,0x69dd02c6,0x60c2be11}},	//   _akhr, siún, _nose, _from,
   {{0x61e90987,0xad9bbe12,0x6448be13,0x3a20011e}},	//   mkel, miúl, _yidi, voip_,
   {{0x6e3dbe14,0xad9b0037,0x61e9be15,0x6d4dbe16}},	//   amsb, liúl, lkel, _egaa,
   {{0xd00e13cf,0xf1d31cce,0x69dd8eac,0x161f0f39}},	//   _دلو_, थापन, _bose, यकार_,
   {{0xf2d2012b,0x61e9939d,0x69ddbe17,0xa2c01cc3}},	//   נען_, nkel, _cose, वित्,
   {{0xa84a0789,0x69ddbe18,0xb4e9018d,0x61e901e4}},	// [e4a0] سلام_, _dose, मनो_, ikel,
   {{0x69dd71b3,0x61e900be,0xdc9b0070,0xad9b0079}},	//   _eose, hkel, _צייל, hiúl,
   {{0x61e9be19,0x68e4046a,0x69ddbe1a,0x7bde027a}},	//   kkel, syid, _fose, _iopu,
   {{0x7ae128e6,0x7bdebe1b,0x2005666e,0x69ddbe1c}},	//   älte, _hopu, hili_, _gose,
   {{0x20059bce,0x6448be1d,0x7bdebe1e,0x0fd20066}},	//   kili_, _pidi, _kopu, तामढ,
   {{0x20052ce7,0x248000c7,0x24860183,0x61e92193}},	//   jili_, šimo_, rrom_, ekel,
   {{0x64480936,0x2d80010d,0x7bde0139,0xa2c000e7}},	//   _vidi, _odie_, _mopu, विध्,
   {{0x60c210d3,0xe6439fde,0x7bde0086,0x644854fd}},	//   _prom, _бесп, _lopu, _widi,
   {{0x644806d7,0x2005be1f,0x09c50033,0x31570037}},	//   _tidi, fili_, _একমা, رجية_,
   {{0x20050723,0xa2c0638d,0x3013081b,0x9f4c0831}},	//   gili_, विद्, лдыр, vidó_,
   {{0x211a2588,0x61e920fb,0x9f5e0037,0x1b050083}},	//   _کتاب_, bkel, ontú_, _শুনে_,
   {{0x60c2be20,0x61e908f9,0xad9b0037,0xc33300a5}},	//   _trom, ckel, ciúl, _עוף_,
   {{0x2005be21,0x9ccb00d8,0x7bde0345,0x2d80099e}},	//   bili_, чына_, _bopu, _ddie_,
   {{0x69ddbe22,0x9f4c4a22,0x00000000,0x00000000}},	//   _sose, ridó_, --, --,
   {{0x69dd04c3,0x7bde0121,0xdeef2281,0x09c50083}},	//   _pose, _dopu, _сы_, _একবা,
   {{0x3cfc0006,0x99cf0033,0x8e830037,0x63babe23}},	//   _लेके_, রস্ক, _إليه, _latn,
   {{0x41b800b4,0x9f5e002a,0x69dd02a7,0xbddb0176}},	// [e4b0] _आसनस, hití_, _vose, rmèd,
   {{0x2ca9be24,0xf770146d,0x7c2500d7,0x7bde0024}},	//   _ipad_, مام_, _ukhr, _gopu,
   {{0x57a4010b,0x99802276,0x69dd27be,0x56950086}},	//   ышта, sliš_, _tose, тает,
   {{0x44250282,0x00000000,0x00000000,0x00000000}},	//   _skl_, --, --, --,
   {{0xb4bd018d,0x20052c53,0x63ba2e16,0x4425055c}},	//   ेमे_, yili_, _batn, _pkl_,
   {{0x03a509eb,0x63ba01a2,0x232905c2,0x20050095}},	//   тико, _catn, моли_, xili_,
   {{0x61e93a5a,0x02bd22a7,0xb5a703d4,0xad9b0037}},	//   tkel, ्मेन, _прай, tiúl,
   {{0x2005be25,0xa2b80246,0x163500c3,0x6830033b}},	//   wili_, ्मज्, _ребя, hädl,
   {{0x61e9317d,0x63babe26,0xad9b0098,0x44252c67}},	//   rkel, _fatn, riúl, _tkl_,
   {{0x61e90aeb,0x63ba008d,0xe9df004f,0xad9b0079}},	//   skel, _gatn, _siúl_, siúl,
   {{0x2005be27,0x2bd500a1,0xfbd500b8,0x2d800176}},	//   rili_, दाना, दानम, _pdie_,
   {{0x63ba769d,0x7bde064a,0x00000000,0x00000000}},	//   _zatn, _sopu, --, --,
   {{0x7bdebe28,0xad9b0132,0x2ca9021d,0x00000000}},	//   _popu, ciúm, _cpad_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab27619e,0x00000000,0x00000000,0x00000000}},	//   вора_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bde7419,0x25bd0297,0x6735003c,0x3eb90228}},	// [e4c0] _topu, ddwl_, _azzj, āstu_,
   {{0xdb1c01f4,0x98a30226,0x00000000,0x00000000}},	//   ndrë, рифе, --, --,
   {{0x63ba01cc,0xf98612da,0xc81502ce,0xf1b900ea}},	//   _ratn, _игно, уєть, jošo_,
   {{0x7c2e8762,0xa2c00b54,0x63ba0ce9,0xb8660312}},	//   llbr, विस्, _satn, _لاسو,
   {{0x63babe29,0x2b060461,0x00000000,0x00000000}},	//   _patn, _हेतु_, --, --,
   {{0xdb070355,0x80b706fe,0x00000000,0x00000000}},	//   zejí, ्टने, --, --,
   {{0xfba40821,0x2ba46d67,0xf62633ce,0x63ba2129}},	//   ख्यम, ख्या, _адво, _vatn,
   {{0xbbdf2095,0x63ba0159,0xdb05063c,0x00000000}},	//   _नक्क, _watn, _nahý, --,
   {{0x63ba0024,0x5edf0033,0xa446019e,0x00000000}},	//   _tatn, _ফেলে, _анад, --,
   {{0x9ed803e6,0x7c2e02c4,0xef1f027d,0x9f5e00d5}},	//   емот_, jlbr, ğün_, pití_,
   {{0xd36f00f8,0xef1f045e,0x2ca900f2,0x00000000}},	//   _ذهن_, şün_, _spad_, --,
   {{0x248920e8,0x7e7a4a8e,0xdb1c0031,0x067b025a}},	//   šame_, rstp, adrë, ונטל,
   {{0x50b6178c,0x5c0701d3,0x6fb60037,0xdb0702d7}},	//   _अनिष, вява, _لمشا, rejí,
   {{0xdb0701c0,0x2f1830aa,0xce94027a,0x00000000}},	//   sejí, _поль_, _бакъ, --,
   {{0x9b5807f2,0x9f5e6778,0x20191f3c,0x3ced03c9}},	//   тист_, mità_, ésie_, šev_,
   {{0x9f5e3b01,0x9964be2a,0xb0b6022e,0x00000000}},	//   lità_, итул, _अनाग, --,
   {{0x1017006c,0x2ca90881,0x6d5d00b5,0x9954002d}},	// [e4d0] _سکیں_, _upad_, mcsa, ркуц,
   {{0x9f5ea07b,0xdb0500d5,0xd9440200,0x109b024b}},	//   nità_, _zahý, ређи, ובמב,
   {{0xa3b60067,0xf77011c0,0x00000000,0x00000000}},	//   ज़न_, زال_, --, --,
   {{0x80b70eff,0x6d5d00b5,0x00000000,0x00000000}},	//   ्टमे, ncsa, --, --,
   {{0x057425d9,0x1da5049c,0x69cfbe2b,0x458400d4}},	//   شاند, ग्यत, _ince, ргів,
   {{0x59d10437,0xe29900af,0x00000000,0x00000000}},	//   हावर, еак_, --, --,
   {{0xa2c0178c,0x9f5e68d5,0x36d40eb1,0x23260183}},	//   विष्, dità_, _корр, лоши_,
   {{0x442e11cc,0xd378011c,0xf48500b5,0x85040099}},	//   alf_, _voća_, _مائی, _शेवट_,
   {{0xbcfb76b5,0x60cd02c4,0xc61f0099,0x9f5e0176}},	//   ncéd, _šamb, यकीय_, fità_,
   {{0xa2c020ab,0x9f5e0036,0x9f450079,0x00000000}},	//   विश्, gità_, mhlú_, --,
   {{0x69cfbe2c,0x7655005f,0x00000000,0x00000000}},	//   _once, _juzy, --, --,
   {{0x7655006a,0x245901a5,0xa2c0022e,0x00000000}},	//   _muzy, _kèm_, विर्, --,
   {{0x8fa50d39,0xe0ce737f,0x2d9e0035,0x24590359}},	//   _бале, _ув_, ęte_, _jèm_,
   {{0x9f5e0133,0x6d5d1a07,0x2d9e00b8,0x24594d6d}},	//   cità_, acsa, řte_, _mèm_,
   {{0xcf240ef2,0xf8bf006c,0x3eb900ea,0x24595ab9}},	//   _پروي, _szép_, āsts_, _lèm_,
   {{0xdb1cbe2d,0x00000000,0x00000000,0x00000000}},	//   ndré, --, --, --,
   {{0xdb0e0093,0x245901cb,0x6e2600fd,0x00000000}},	// [e4e0] ndbú, _nèm_, mokb, --,
   {{0x67f2008a,0xb8dc6017,0x99890067,0x00000000}},	//   _bæja, _आन_, gnał_, --,
   {{0x9f5e00ac,0xdb07021d,0x00000000,0x00000000}},	//   nitá_, rejã, --, --,
   {{0xd5b90208,0x65790159,0x80a4007c,0x00000000}},	//   ксі_, gawh, _कहले, --,
   {{0x2eb023f0,0xa4d40185,0xbcfb000d,0x00000000}},	//   _जन्त, ролі, ccéd, --,
   {{0xa2c037e8,0x6e260223,0xd7f20079,0x00000000}},	//   विल्, hokb, _اكس_, --,
   {{0xe737be2e,0x9f5ebe2f,0x2bd50963,0xfe670079}},	//   _бер_, vità_, दाता, _دد_,
   {{0x245902d0,0x9f5e00d5,0x00000000,0x00000000}},	//   _fèm_, ditá_, --, --,
   {{0x6046279d,0x463b02b5,0x9f5e36c1,0xe45f027d}},	//   лхоз, _טעלע, tità_, _çöp_,
   {{0x527640b4,0x09e100a1,0xad9b004f,0x0446021d}},	//   _буду, _नव्य, miúi, _сезн,
   {{0x8f340500,0x9f5e64a3,0xad9b004f,0x29dc0aaf}},	//   ренц, rità_, liúi, _díaz_,
   {{0x9f5e02fb,0x245902d0,0x867b00a5,0x99890067}},	//   sità_, _yèm_, ערכו, znał_,
   {{0xae040c67,0xcd0776d2,0xad9b0037,0x6d5dbe30}},	//   शोधन_, учни, niúi, rcsa,
   {{0x61e2007c,0xab9503fa,0x30830037,0x9f5e00d5}},	//   _hool, јављ, _الوف, bitá_,
   {{0xc4c4be31,0xf1b808a9,0xad9b0037,0x9f5e0183}},	//   _کے_, _आसान, hiúi, citá_,
   {{0x61e20345,0x82770070,0x00000000,0x00000000}},	//   _jool, טעלע_, --, --,
   {{0xcfb70083,0x26e20033,0xe895010b,0xb60600f4}},	// [e4f0] জারন, _গেলো_, разь, _mašć,
   {{0x61e288d6,0xad9b0037,0x24590023,0x7bda967e}},	//   _lool, diúi, _rèm_, ötut,
   {{0x657902b3,0x26c709ca,0xf770097f,0x24593b4b}},	//   tawh, íno_, ثاق_, _sèm_,
   {{0x61e2b3d4,0x69cf024b,0x9f450098,0x24590107}},	//   _nool, _unce, thlú_, _pèm_,
   {{0xa3d0012f,0x6579009f,0xad9b004f,0xa8790070}},	//   षां_, rawh, giúi, _באָר,
   {{0x62650b25,0x32060dc3,0x00000000,0x00000000}},	//   авка, _amoy_, --, --,
   {{0x38697a9c,0xb60600f4,0x00000000,0x00000000}},	//   lpar_, _bašć, --, --,
   {{0x245902e9,0x61e2be32,0x11e58b9c,0x00000000}},	//   _tèm_, _cool, ржим, --,
   {{0x61e2be33,0xad9b0037,0xe53401e0,0x7e6402a7}},	//   _dool, ciúi, _геть, _čipa,
   {{0x660bbe34,0x249f0024,0xef1f01fb,0x00000000}},	//   ligk, _iqum_, şüm_, --,
   {{0x02d90ef5,0x3ea50c90,0x4427062c,0x25bf012f}},	//   _جواب_, шинг, mon_, _kaul_,
   {{0x61e27ae4,0x6cc60409,0xc1050118,0x720700b5}},	//   _gool, айма, _پوتي, _حفصہ_,
   {{0x44271eca,0x7ae101ae,0x200b00f7,0x1da5021a}},	//   oon_, ältn, écis_, ग्धत,
   {{0x4427be35,0xe4f8012f,0x1ef9004f,0x64430037}},	//   non_, ्छति_, _لعبة_, nmni,
   {{0xab2a9470,0x6443be36,0x4427be37,0x660b043d}},	//   това_, imni, ion_, kigk,
   {{0x4427be38,0xdb1e01f4,0x60c40bde,0x2480571a}},	//   hon_, _hapë, _šimi, šimi_,
   {{0xa8060862,0x975603fa,0x660b01ae,0xdb1e0031}},	// [e500] азал, атељ, digk, _kapë,
   {{0x4427be39,0x6443004e,0xbc7b00a5,0xdb0737d0}},	//   jon_, jmni, _שנית, sejá,
   {{0x25bf2a81,0x09c50033,0xf99f021e,0xbcfb000d}},	//   _baul_, _একরা, _imèn_, rcée,
   {{0xad9b004f,0xe5a60043,0x442700e5,0x660b4cf0}},	//   tiúi, риди, eon_, gigk,
   {{0x62810e6c,0x649a036c,0x7642336d,0x2480004f}},	//   _avlo, ттер_, rmoy, éim_,
   {{0x4427062c,0xad9b0037,0x61e21b43,0x672e008c}},	//   gon_, riúi, _sool, _tybj,
   {{0x66e60b00,0xad9b004f,0x660bbe3a,0xb6060009}},	//   _това, siúi, bigk, _pašć,
   {{0x248911c6,0x30a6818c,0x60cd71d6,0x25bf3e99}},	//   šama_, аров, _šama, _gaul_,
   {{0x4427be3b,0xdfd0004f,0x628115c8,0x61e200ab}},	//   bon_, كية_, _evlo, _vool,
   {{0x4427be3c,0xb60500ac,0x00000000,0x00000000}},	//   con_, _višň, --, --,
   {{0xdefa004b,0x61e2be3d,0x201912c3,0x3fc803c5}},	//   тып_, _tool, ésia_, ندگی_,
   {{0x10a61d29,0xf99f021e,0x28c90a90,0x443e00e2}},	//   _видн, _amèn_, रिमि, _hht_,
   {{0x00d70647,0x13aa0033,0x00000000,0x00000000}},	//   _نبوت_, _গোয়, --, --,
   {{0x26fc0083,0x9989004e,0x2007022e,0xdb1ea2c4}},	//   _এখনো_, znań_, _gmni_, _kapè,
   {{0x200cbe3e,0x7ac40b00,0x443e01cf,0x70b60026}},	//   midi_, осте, _mht_, _अनुल,
   {{0x4427be3f,0x443e4aec,0x7bda2103,0xd3781bfa}},	//   zon_, _lht_, ötur, _leć_,
   {{0x44273b1d,0xa3b6004e,0xe7d202cb,0x6e2d0010}},	// [e510] yon_, ज़ा_, सांप, _ikab,
   {{0x25bfbe40,0x41a6143a,0x3869be41,0xb8ff000c}},	//   _saul_, क्तस, rpar_, _थप_,
   {{0x4427be42,0x660b02c9,0x25bf7a0e,0xe94500d1}},	//   von_, tigk, _paul_, _گردی,
   {{0x2d99be43,0x200c0657,0x4427be44,0x2bd505dc}},	//   ngse_, hidi_, won_, दावा,
   {{0xd49b1eba,0x2ba40066,0x660b02b1,0x6e2dbe45}},	//   тре_, ख्वा, rigk, _mkab,
   {{0x660b01ae,0x200c0103,0x25fb0067,0x4427016e}},	//   sigk, jidi_, लोजी_, uon_,
   {{0x4427028b,0x68edbe46,0x200cbe47,0x6443be48}},	//   ron_, lyad, didi_, rmni,
   {{0x4427be49,0x6e2d0010,0x40951a1c,0xef1f027d}},	//   son_, _nkab, брот, şük_,
   {{0x68edbe4a,0x6609000e,0x442790b9,0x200c774a}},	//   nyad, _imek, pon_, fidi_,
   {{0x6e2d76a4,0x4427be4b,0x753b0a78,0x200c027a}},	//   _akab, qon_, _izuz, gidi_,
   {{0x68ed0282,0xfbcb1371,0xbddb0176,0x00000000}},	//   hyad, ायनम, rmèn, --,
   {{0x7c3e01d2,0xc69200c2,0xbdfa05f5,0xf1b9213a}},	//   _shpr, האט_, اردا_, koši_,
   {{0x661bbe4c,0x200c0054,0x66095961,0x7c3e0791}},	//   _mjuk, bidi_, _mmek, _phpr,
   {{0x200cbe4d,0x3c1900d8,0x68ed1008,0x683001ae}},	//   cidi_, аўся_, dyad, pädi,
   {{0x6e9502aa,0x660900cb,0x0f7a0070,0x5e950037}},	//   _العا, _omek, _ערקל, _العط,
   {{0x68ed0381,0x61b50f17,0x661bbe4e,0x00000000}},	//   fyad, _अघोष, _njuk, --,
   {{0x81cc0083,0x68ed0987,0xf99f0359,0x753b0371}},	// [e520] _রকম_, gyad, _imèl_, _nzuz,
   {{0x9947002d,0x6609000e,0xdb1c181f,0xa3a90035}},	//   спуб_, _amek, ldrí, ग्म_,
   {{0x61fb05d0,0xd3780c21,0x5b5702b5,0x2bd500a1}},	//   khul, _reć_, _לייב_, दारा,
   {{0x200c000e,0x68edbe4f,0xdb1c6cd2,0xd71905a2}},	//   zidi_, byad, ndrí, _दशरथ_,
   {{0x68ed0312,0x61fbbe50,0xd378011c,0xceb80035}},	//   cyad, dhul, _peć_, zwę_,
   {{0x2900000e,0x6609be51,0x443e00a8,0x69c4be52}},	//   mzia_, _emek, _qht_, ldie,
   {{0xd3780537,0x200cbe53,0x26ca0160,0x6d56030d}},	//   _već_, vidi_, _urbo_, _ogya,
   {{0x61fbbe54,0x69c47605,0x6d56be55,0xda7b0070}},	//   ghul, ndie, _ngya, אנקר,
   {{0x2900be56,0x442c0a8a,0x69c4be57,0xdb1e0176}},	//   nzia_, _tkd_, idie, _wapè,
   {{0x6e2d054e,0x65621e0a,0x69c40069,0x6ee60037}},	//   _skab, lcoh, hdie, مسجل,
   {{0x200c93e8,0xdd9101b2,0x78a403a6,0x6d560159}},	//   ridi_, وود_, htiv, _bgya,
   {{0x61fbbe58,0x60c419cd,0xd73700a5,0x65620031}},	//   chul, _šimu, מטית_, ncoh,
   {{0x69c40484,0xa2c00d41,0x200c1df1,0x2d99be59}},	//   ddie, विक्, pidi_, rgse_,
   {{0x69c4be5a,0x6d56be5b,0x2900297a,0xf99f0107}},	//   edie, _egya, dzia_, _emèl_,
   {{0xec340a55,0xf8d109b4,0xcfa900d1,0xb4b50066}},	//   їнсь, सम्प, _خانم_, _जन्_,
   {{0x6e2d08bd,0x68ed8251,0xf1bd01c0,0xf1b90029}},	//   _ukab, tyad, ्ययन, toši_,
   {{0x7c971d05,0x2d890176,0x661b03d0,0x00000000}},	// [e530] _اشعا, _idae_, _rjuk, --,
   {{0x1da5073f,0xf1b95b4a,0x661b0533,0x69c45a67}},	//   ग्रत, roši_, _sjuk, adie,
   {{0x68ed00a7,0x78a4ab7b,0x2900be5c,0xd6d10037}},	//   syad, ativ, azia_, بقا_,
   {{0xd24600bf,0x999900d8,0x7e640009,0x28c92a06}},	//   _زن_, _visų_, _čipl, रिदि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2489be5d,0x60cd0168,0xdb1e01cb,0x00000000}},	//   šamo_, _šamo, _sapé, --,
   {{0x61fbbe5e,0xdb1e0279,0x41c40ed1,0x569432e2}},	//   thul, _papé, वयंस, _нарт,
   {{0x66090054,0x69c0003e,0xa5f8037c,0x00000000}},	//   _umek, _ómet, _лесу_, --,
   {{0x20190183,0x753b0371,0x00000000,0x00000000}},	//   ésio_, _uzuz, --, --,
   {{0x61fbb2b6,0x69c401ba,0x60090267,0x657b0bf7}},	//   shul, zdie, рном_, _heuh,
   {{0x62350814,0xe448004f,0x60c4010b,0x2480010b}},	//   _дежу, _اللى_, _šimt, šimt_,
   {{0x9f4500b8,0xf8bf00a2,0x645b023c,0x05cf01c0}},	//   chlý_, _osé_, _kuui, _सोमब,
   {{0x62830d35,0xc0e51761,0x25ad034d,0x00000000}},	//   lsno, _фолк, _mbel_, --,
   {{0x317fbe5f,0x645b0183,0x00000000,0x00000000}},	//   lauz_, _muui, --, --,
   {{0x60c9be60,0x69c4be61,0x1ea800f8,0xf8bf0312}},	//   lvem, tdie, _هايي_, _asé_,
   {{0x78a4be62,0x6d560332,0x29000291,0xbcfb004f}},	//   ttiv, _ugya, tzia_, scéa,
   {{0x98a309d0,0x69c4be63,0xf1b2100a,0x290057e4}},	// [e540] мите, rdie, וסן_, uzia_,
   {{0x290001ba,0xda0b0099,0x00000000,0x00000000}},	//   rzia_, सोबत_, --, --,
   {{0xbcfbbe64,0x569300d4,0xf1b9a0ca,0x25ad021d}},	//   ncén, даєт, lošu_, _bbel_,
   {{0x6441be65,0x645b15ff,0xad9b0037,0x1ddd1140}},	//   _ahli, _buui, liúr, यायत,
   {{0x6441003b,0xa3b60992,0x21f800b5,0x65620031}},	//   _bhli, ज़ल_, _néha_, rcoh,
   {{0x6441be66,0x201900f7,0x25ad02a7,0x00000000}},	//   _chli, ésil_, _ebel_, --,
   {{0xfc3f2e7d,0x644109bb,0xa2bd3010,0xa3a9364c}},	//   ntía_, _dhli, _वैद्, ग्ध_,
   {{0xd3780a78,0x644101fb,0x00000000,0x00000000}},	//   _moći_, _ehli, --, --,
   {{0x41a61662,0xef180029,0x64a60374,0xf1a6170c}},	//   क्षस, daļa_, _фаза, क्षन,
   {{0x765cbe67,0x4ea69215,0xdb0e0093,0x64410874}},	//   _kury, орма, ndbó, _ghli,
   {{0xd3780a78,0x2bde04eb,0xfbde0355,0x1dd60026}},	//   _noći_, माना, मानम, धांत,
   {{0x765c0010,0x63b800fe,0x645b00d7,0x00000000}},	//   _mury, levn, _yuui, --,
   {{0x6298be68,0xdb0507c0,0x2029008d,0x5c741d41}},	//   luvo, _lahô, ótið_, млят,
   {{0x63b8be69,0xc04f093e,0xdb1500b5,0x6255009f}},	//   nevn, _іі_, lezé, _iġor,
   {{0xc1ee0953,0xa2c0162b,0x3950013b,0x6298334e}},	//   _जवाब_, विट्, ənsə_, nuvo,
   {{0xd3780470,0x91fc00ea,0x7e9900b5,0xee0810b4}},	//   _doći_, _stāj, _انٹر_, _мејл_,
   {{0x2e320093,0x80cd018d,0x6255009f,0xbd8800b5}},	// [e550] gáfu_, तिये, _jġor, _بچپن_,
   {{0x765c0232,0x63b80627,0xdb170095,0xf7702087}},	//   _bury, jevn, _naxç, نام_,
   {{0xd6dbbe6a,0xdb150332,0xf4020083,0x35b51e5b}},	//   шта_, kezé, ৎকার_, збер,
   {{0x6441be6b,0x765cbe6c,0x629892fe,0xdb1500b5}},	//   _shli, _dury, duvo, jezé,
   {{0x7bc50e08,0x9f4c0037,0x765cbe6d,0x70a9007c}},	//   _kahu, ghdú_, _eury, _कहेल,
   {{0x6283be6e,0x2bde06fe,0x7bc7be6f,0xdb1c6fe8}},	//   tsno, माया, ndju, ldrá,
   {{0x7bc53a3d,0x05871126,0x28c90b35,0xa8020042}},	//   _mahu, _муам, रिवि, éñen,
   {{0xdb1cbe70,0x4095195a,0xa2c01bc6,0x7bc520a4}},	//   ndrá, прот, विज्, _lahu,
   {{0xfbcb112b,0x6283be71,0x3959028b,0x00000000}},	//   ायाम, ssno, _mgss_, --,
   {{0x7bc57abb,0x777c01ef,0xaf0501d3,0x64410097}},	//   _nahu, _xerx, зпол, _uhli,
   {{0xed5abe72,0x60c90506,0x2cb20a8c,0x00000000}},	//   йон_, svem, _spyd_, --,
   {{0xd1310082,0xd5af03d0,0xf1b90228,0x00000000}},	//   _كما_, есi_, tošu_, --,
   {{0x7bc50010,0xf1b90693,0xad9b0312,0x00000000}},	//   _bahu, meš_, tiúr, --,
   {{0xcb67002d,0x9f4701f4,0xd37800cb,0x7bc50160}},	//   заре_, _jonë_, _poći_, _cahu,
   {{0x34b897c4,0x7bc55443,0x0f7a00a5,0x00000000}},	//   _इन्द, _dahu, _הרצל, --,
   {{0x09e30525,0xf1b90612,0xfc3f0b06,0x63b819cd}},	//   носн, neš_, rtía_, zevn,
   {{0x2d82be73,0xfc3f0caa,0x765cbe74,0xa3bd060a}},	// [e560] make_, stía_, _sury, ेया_,
   {{0x2d822dbf,0xfc3f004f,0x9ce70332,0x7bc5be75}},	//   lake_, ltín_, _روپے_, _gahu,
   {{0xf1bd2064,0x41bd02cb,0xdb1e0c1f,0x7e641f20}},	//   ्यान, ्यास, _enpò, _čipk,
   {{0x2d82be76,0xf1b91164,0x7bc50371,0x28c9052f}},	//   nake_, ješ_, _zahu, रिशि,
   {{0xb4d600ab,0xf1b907cb,0x63b8053d,0x3e61be77}},	//   िमे_, deš_, tevn, _lót_,
   {{0x62980a93,0x69c6be78,0x2d82be79,0x765c004e}},	//   tuvo, _hake, hake_, _tury,
   {{0x69c62536,0x2d8201ca,0x63b8be7a,0xa2b300b5}},	//   _kake, kake_, revn, ٹینڈ,
   {{0xdb1e0038,0x69c6be7b,0x63b86aff,0x64a60847}},	//   _napí, _jake, sevn, _наба,
   {{0x69c60b93,0x2d82be7c,0x7c2e3bec,0x63b80097}},	//   _make, dake_, kobr, pevn,
   {{0xe9df01a5,0xdb1c00b8,0x3e61be7d,0x2ef40212}},	//   _khúc_, zdrá, _bót_, дзор,
   {{0x7bc5007c,0xdd950104,0x69c60602,0x24863e04}},	//   _rahu, маны, _oake, lsom_,
   {{0x442ebe7e,0xf1b90334,0x38a601ba,0x69c6be7f}},	//   lof_, ceš_, kôr_, _nake,
   {{0x7bc5be80,0xdb1c0093,0x9f47021e,0x1154010b}},	//   _pahu, ndræ, _lonè_, _ўклю,
   {{0x60c2be81,0x41da018d,0xf1da00b1,0xc5fa0083}},	//   _isom, भावस, भावन, েকটা_,
   {{0x69c66d14,0x2d82be82,0x7bc7be83,0x2b5a0176}},	//   _bake, bake_, rdju, _dgpc_,
   {{0x2486026a,0x69c6be84,0x2d82be85,0x442eadb1}},	//   ksom_, _cake, cake_, hof_,
   {{0x7bc54150,0x7c2e0200,0xd3780254,0xbd4521a0}},	// [e570] _tahu, bobr, _hoću_, _تنظي,
   {{0xd6db0a71,0x2bde0af9,0xfbde0803,0x3f9e94e0}},	//   йте_, माणा, माणम, ngtu_,
   {{0xe9df01a5,0xa7fb0ddb,0x69c6be86,0x3e610023}},	//   _chúc_, _nuñe, _fake, _xót_,
   {{0xe9df0028,0x9f4701f4,0xa2bd074f,0x69c60979}},	//   _giúp_, _sonë_, _वैष्, _gake,
   {{0xf1b90293,0x8cd00035,0x64a50799,0x60c2263a}},	//   veš_, दियो, фала, _nsom,
   {{0x69c60a75,0x2d82be87,0x09c50033,0x442e016e}},	//   _zake, zake_, _একটা, gof_,
   {{0xea000028,0xddcd004e,0x60c2be88,0xa2bd05e7}},	//   _hoạt_, _miał, _asom, _वैश्,
   {{0x7c2e0a53,0x3e61be89,0x69c6be8a,0x00000000}},	//   zobr, _rót_, _xake, --,
   {{0x3494be8b,0xf1b902c6,0x9f4700da,0x60c2006c}},	//   _патр, reš_, _tonë_, _csom,
   {{0x2d82000e,0xdb1e03e6,0xf1b90169,0x442e0661}},	//   wake_, _japã, seš_, cof_,
   {{0x2d82be8c,0xf1b90009,0xdb1e5b59,0xea000019}},	//   take_, peš_, _papí, _loạt_,
   {{0xa3a906bc,0x80cd0edf,0xdb1e021d,0x00000000}},	//   ग्र_, तिदे, _lapã, --,
   {{0x69c602e2,0x2d82be8d,0x7c2ebe8e,0x522a00c2}},	//   _rake, rake_, tobr, _ווײַ,
   {{0x69c6be8f,0x2d82be90,0xfc3fbe91,0x41bd0d34}},	//   _sake, sake_, stín_, ्यवस,
   {{0x69c6be92,0x2d82be93,0x2fc74fbb,0xfaa312e3}},	//   _pake, pake_, _iang_, каро,
   {{0x7c2ebe94,0xc8c902e4,0xa2ce00e7,0x2fc7be95}},	//   sobr, रिंट, थित्, _hang_,
   {{0x61eb5c4d,0x2fc70703,0x69c6be96,0x7524003c}},	// [e580] _mogl, _kang_, _vake, żizz,
   {{0x442ebe97,0x26d101cc,0xe9df01a5,0x69c6be98}},	//   xof_, _brzo_, _phúc_, _wake,
   {{0x2fc7be99,0x69c6be9a,0x998000d8,0x4a461747}},	//   _mang_, _take, ulių_, _онов,
   {{0x2fc77ab4,0x61eb0022,0x9f5e0031,0xdb1e0211}},	//   _lang_, _nogl, thtë_, _iapà,
   {{0x2d800006,0x442ebe9b,0x998000c7,0xbcfb00a2}},	//   _meie_, tof_, slių_, ycém,
   {{0x2fc7be9c,0xd36f0312,0xe9df01a5,0x24860533}},	//   _nang_, لهه_, _thúc_, rsom_,
   {{0xc7a303d0,0x9f5e01d2,0x9989016f,0x966365e1}},	//   _ширк, shtë_, slať_, _аксе,
   {{0x442ebe9d,0x61eb0382,0x80b20033,0xf7432d7a}},	//   sof_, _cogl, জিস্, _ресо,
   {{0x2fc70cec,0x7e6d00f4,0x66020051,0x00000000}},	//   _bang_, _čapa, mhok, --,
   {{0x44380079,0x2fc700e2,0x21f800d5,0x63a400f4}},	//   _ór_, _cang_, _tého_, đins,
   {{0x61ebbe9e,0xa3bd043b,0xdb0e022a,0x2fc7be9f}},	//   _fogl, ेयर_, nebä, _dang_,
   {{0x61eb0297,0x2fc7001e,0x99890035,0x72160957}},	//   _gogl, _eang_, ział_, _غذائ,
   {{0x7984000e,0x60c2306e,0x2fc7345d,0x2bcb0d41}},	//   daiw, _usom, _fang_, ायला,
   {{0x2fc7293a,0x61eb023a,0x00000000,0x00000000}},	//   _gang_, _zogl, --, --,
   {{0x62a20187,0x61eb01e8,0xef1f05f9,0xa3b00c03}},	//   _útoč, _yogl, şür_, ट्य_,
   {{0x2fc72652,0x20140067,0x2489bea0,0x99890067}},	//   _zang_, ścić_, šami_, wiał_,
   {{0x2fc74150,0xe9df01a5,0x69a5164f,0x66022e62}},	// [e590] _yang_, _chúa_, ङ्गी, dhok,
   {{0x1ddd0e1d,0xb907020d,0x2246012f,0x201e0093}},	//   यावत, _मऊ_, _lhok_, nnti_,
   {{0xa3e21cce,0x201e0086,0xf4140033,0x99890035}},	//   धान_, inti_, াকার_, riał_,
   {{0x224600e2,0x99890067,0x00000000,0x00000000}},	//   _nhok_, siał_, --, --,
   {{0x61eb03c9,0x100e02b4,0x00000000,0x00000000}},	//   _rogl, ाफाश_, --, --,
   {{0x61ebbea1,0x00000000,0x00000000,0x00000000}},	//   _sogl, --, --, --,
   {{0x61eb0888,0x6b7c0052,0x4255bea2,0xe2990bba}},	//   _pogl, חרונ, нтит, чай_,
   {{0x2fc7bea3,0xdb1c0370,0x201ebea4,0x90c5027a}},	//   _sang_, ferê, enti_, ебие,
   {{0x2fc732e1,0x61ebbea5,0xdb1ebea6,0xfa0d00e2}},	//   _pang_, _vogl, _mapá, _đấu_,
   {{0xe3b001ca,0x2d800044,0x00000000,0x00000000}},	//   _نرم_, _seie_, --, --,
   {{0x61ebbea7,0x2fc7bea8,0x80cd018d,0x2bde0099}},	//   _togl, _vang_, तिहे, मासा,
   {{0x201e4f22,0x91fc0029,0xdb1e0187,0x827600a5}},	//   anti_, _stāv, _napá, _נענע_,
   {{0x2fc7bea9,0x518412ea,0x15f20035,0xdb0e227c}},	//   _tang_, _руха, _अकसर_, ndbö,
   {{0x224dac1a,0x2fc700a1,0x3ced00be,0x21f10097}},	//   lmek_, _uang_, äeva_, _váhu_,
   {{0x2d80007c,0x3f8500b8,0x7984023c,0x9f5e00ac}},	//   _teie_, malu_, taiw, nitý_,
   {{0x3f850f1a,0xe1f901c8,0x224d01d6,0xdb1e00fe}},	//   lalu_, nkų_, nmek_, _capá,
   {{0x63ad326f,0xdb05033b,0xb8652abf,0xcc8a0037}},	// [e5a0] đanj, _abhä, نالو, _عنده_,
   {{0x3f8505e2,0x61bd021a,0xfd471667,0xdb1c0031}},	//   nalu_, ्युष, _язык_, nerë,
   {{0x660200f8,0xc0490023,0xa96a3e86,0x224d0225}},	//   thok, _sườn_, _нина_, kmek_,
   {{0xf5390038,0x2c660009,0x9f5c021e,0x3f85beaa}},	//   _byť_, _kôd_, _elvè_, halu_,
   {{0xc95501c8,0x3f85beab,0xa3bd012f,0x201e00c3}},	//   _атры, kalu_, ेयं_, ynti_,
   {{0xf2c605ac,0xc04901a5,0x66020848,0x224601f4}},	//   есин, _vườn_, shok, _shok_,
   {{0x3f85beac,0x9f47024e,0x533302c8,0x6e2400e0}},	//   dalu_, _plný_, лешт, _ojib,
   {{0xdb1c2de6,0x68e41f2c,0xf99f0107,0x6e240118}},	//   terê, oxid, _elèf_, _njib,
   {{0xdfd00514,0xbddb0248,0x3f85001e,0x68e401dd}},	//   لية_, llèg, falu_, nxid,
   {{0xa2e6257f,0x201ebead,0x0edb00b4,0x6e24a0b5}},	//   _позд, unti_, यमंड, _ajib,
   {{0x6d44beae,0x224600f8,0x3a200b88,0x3817024b}},	//   _azia, _thok_, knip_, תקים_,
   {{0x645abeaf,0x628a17ad,0x443cbeb0,0xa7fb01ed}},	//   _hiti, msfo, llv_, _muña,
   {{0x645abeb1,0x3f854372,0x6f060248,0x628a082b}},	//   _kiti, balu_, _bébé, lsfo,
   {{0x6d44006a,0x645a9559,0xbcfb416d,0x3f851bfa}},	//   _dzia, _jiti, ncéi, calu_,
   {{0x645abeb2,0x03d700a5,0xdb1e445a,0xe9df0079}},	//   _miti, עולם_, _papá, _dhún_,
   {{0x62987ac0,0x645a23e8,0x00000000,0x00000000}},	//   irvo, _liti, --, --,
   {{0xab870810,0xa7fb01ed,0x645abeb3,0xb95502fb}},	// [e5b0] _пунк, _auña, _oiti, тващ,
   {{0x645abeb4,0x6e3d7f9b,0x628abeb5,0x66000051}},	//   _niti, llsb, ksfo, _almk,
   {{0xa7fb1111,0x2bde03de,0x9f5e0453,0x443c0176}},	//   _cuña, मारा, litó_, dlv_,
   {{0x628a31cb,0x7afa03db,0xf65018dd,0x644800c3}},	//   dsfo, øtte, مئن_, _ahdi,
   {{0x69ddbeb6,0x645abeb7,0x62983777,0x64480211}},	//   _inse, _biti, ervo, _bhdi,
   {{0x74151d05,0x3fcb0083,0xdb1c12c3,0x645abeb8}},	//   ضوعا, _লক্ষ, ferè, _citi,
   {{0x645a1034,0x78adbeb9,0x9f4d0463,0x224d01d6}},	//   _diti, ltav, ünün_, tmek_,
   {{0x61bd07df,0xd24e11cf,0xe1f900d8,0x645a0037}},	//   ्येष, ينو_, ukų_, _eiti,
   {{0x224dbeba,0x78ad8042,0x645abebb,0x3f85bebc}},	//   rmek_, ntav, _fiti, talu_,
   {{0x645a02b3,0x245500bf,0x765b0008,0x224d3d01}},	//   _giti, _شناس, _hiuy, smek_,
   {{0x69ddbebd,0x78ad6c26,0x3f856158,0x6d44006c}},	//   _onse, htav, ralu_, _szia,
   {{0x78adbebe,0x645abebf,0x3f8500ab,0x50b50043}},	//   ktav, _ziti, salu_, _аску,
   {{0xf65202b5,0x64480086,0x78ad01f4,0x61e9bec0}},	//   יצט_, _yhdi, jtav, mjel,
   {{0x69ddba9b,0x61e9bec1,0x3e5e009f,0x78ad0009}},	//   _anse, ljel, _aċtu_, dtav,
   {{0x3a2001a2,0xa3e200a1,0x9f470187,0xdcfd013a}},	//   tnip_, धात_, _koní_, rasā,
   {{0x61e90f1a,0x61fbbec2,0xba233fe5,0x3eaa01c0}},	//   njel, nkul, адск, žití_,
   {{0x9f5e00de,0x44250009,0x1c460043,0x753b04f7}},	// [e5c0] citó_, _ojl_, _иним, _nyuz,
   {{0x61e9bec3,0xa7fbb43b,0x69dd05f0,0x48030370}},	//   hjel, _puña, _ense, апув,
   {{0x61fb274e,0x645abec4,0x248d0043,0x69cd028b}},	//   kkul, _riti, _avem_, bdae,
   {{0x645abec5,0xa2d5051e,0xc1bd09b1,0x442500d7}},	//   _siti, भिन्, ्योग, _ajl_,
   {{0x61e90280,0x645a142f,0xe5a3a31d,0x78ad0392}},	//   djel, _piti, ричи, ctav,
   {{0xdb1cbec6,0x7bce6722,0xdb1e0310,0x629802c4}},	//   terè, ndbu, _capç, trvo,
   {{0x645abec7,0x66e3619e,0xdb1c27c2,0x12e00033}},	//   _viti, _кора, feré, বন্দ,
   {{0x61e9bec8,0x765b011e,0x61fb3b2e,0x645ab7fd}},	//   gjel, _giuy, gkul, _witi,
   {{0x91fc0029,0x673c01f4,0x628a0135,0xdb050359}},	//   _stās, _hyrj, ssfo, _echè,
   {{0x645a19c1,0x9f5e0453,0x2d92021e,0x61fb43dc}},	//   _uiti, vitó_, _adye_, akul,
   {{0xdfd00118,0x7e6473c0,0x61e9bec9,0x248d023a}},	//   ليک_, _čips, bjel, _zvem_,
   {{0x61e9beca,0xe9df0079,0x7bde01b7,0x61fb0c6f}},	//   cjel, _chúl_, _anpu, ckul,
   {{0xa3e60299,0x6e3dbecb,0x6004021e,0x00000000}},	//   _बचा_, rlsb, _pòmd, --,
   {{0x200500d5,0x7e630479,0xdfcf0037,0xac240674}},	//   chli_, _funp, _وين_, афск,
   {{0xdeef247f,0x7e63596e,0x9f5e432a,0xdb1e00a0}},	//   _ты_, _gunp, sitó_, _napä,
   {{0x78ad0d36,0x0f570122,0x63ad0a78,0x60040107}},	//   ttav, _ביום_, đani, _dòme,
   {{0xc4c400f5,0x69cd1628,0x57b55027,0xc9840374}},	// [e5d0] _بے_, rdae, лбат, руси,
   {{0xb8cb0299,0x673c2129,0x7649becc,0x60040107}},	//   _गम_, _byrj, _shey, _fòme,
   {{0xcf9300c2,0xa3d60f9f,0x7c354cbf,0xf7700957}},	//   שטע_, ियन_, mozr, تاق_,
   {{0x69dd02bf,0xa3b03933,0x78adbecd,0xfad600a5}},	//   _unse, ट्स_, ptav, _עורך_,
   {{0x61e9bece,0xe9df00a0,0xdb1c00b5,0x9f470176}},	//   vjel, _inú_, veré, _roní_,
   {{0xdb052948,0x753b0097,0x80d60127,0xee3f0097}},	//   _aché, _vyuz, बिने, hlý_,
   {{0xdb1cbecf,0x61e9bed0,0xe3b00413,0xad9b0037}},	//   teré, tjel, ترن_, thúl,
   {{0x61fb7ad4,0x7ae802b1,0x93270088,0x47ca0033}},	//   ukul, ädti, _یران, রাণী,
   {{0x61e95d62,0x28c90d00,0x9f5e0036,0xf99f021e}},	//   rjel, रिटि, vitò_, _klèb_,
   {{0xdb053b46,0x61e9bed1,0xa7fb5668,0x24890029}},	//   _tchè, sjel, _muño, šams_,
   {{0x61e9029d,0x61fbbed2,0x7c3500a0,0x9f5e00d5}},	//   pjel, pkul, dozr, chtí_,
   {{0x200524ce,0x02fa0070,0xfbc9011d,0xcf490225}},	//   shli_, _אלעמ, _מת_, _ışık_,
   {{0x3e6800a2,0x2cbb021d,0xed5701e0,0xe9df055c}},	//   _eût_, _cpqd_, лою_, _chúm_,
   {{0x4092004f,0x75160070,0x3e68000d,0xfaa6a687}},	//   _الور, אַלע_, _fût_, лаго,
   {{0xab2770bc,0x7bce11cb,0x99870b67,0x9f5e0036}},	//   гора_, rdbu, _šiša_, pitò_,
   {{0x316dbed3,0x00000000,0x00000000,0x00000000}},	//   ncez_, --, --, --,
   {{0xa3d60efa,0xa7fb002a,0x673c00c3,0xaa4318cd}},	// [e5e0] ियम_, _cuño, _syrj, сетл,
   {{0x3a393532,0x7bde0147,0x00000000,0x00000000}},	//   _eksp_, _unpu, --, --,
   {{0xdb15002a,0x3a3900fe,0x09b90831,0x00000000}},	//   pezá, _fksp_, ঁয়া, --,
   {{0xc97603c7,0x94aa014d,0x09e6702b,0x1f360070}},	//   _حادث, етка_, _сомн, ארער_,
   {{0x4e3702b5,0x00000000,0x00000000,0x00000000}},	//   אָגן_, --, --, --,
   {{0xdb0564cb,0x798612ba,0x9f4e0107,0x3d1700ab}},	//   _sché, _hekw, _fofè_, _पइसे_,
   {{0xd25a1362,0x7986028b,0x1daa0099,0xd9fb0e61}},	//   нци_, _kekw, _काढत, _एकमत_,
   {{0x7ddb081b,0xa785006c,0x75d62d82,0x66190035}},	//   _mäsä, _مشہو, _حيرا, ciwk,
   {{0x60cd0009,0x62810090,0x00000000,0x00000000}},	//   _šamr, _ewlo, --, --,
   {{0x30140009,0xa3cf012f,0x25a6010d,0xb4c2111b}},	//   рдор, षयः_, lgol_, ौटी_,
   {{0xd36f0934,0x6d40027d,0xdb0500a2,0xe29710da}},	//   _رهن_, üman, _tché, _бах_,
   {{0xa3b00567,0x25a6bed4,0xa2c10026,0x9f4758bd}},	//   ट्र_, ngol_, लबर्, _donà_,
   {{0xbddb01f7,0x00000000,0x00000000,0x00000000}},	//   elèc, --, --, --,
   {{0xee3f0097,0x00000000,0x00000000,0x00000000}},	//   slý_, --, --, --,
   {{0x3ffb00c2,0xfc3f2669,0x7986439e,0xee3f64ec}},	//   _אפגע, ktív_, _bekw, plý_,
   {{0x13cd0083,0x4975005f,0xa7fb0300,0xa2d501c0}},	//   লায়, рлас, _puño, भित्,
   {{0x481500c7,0x2d8bbed5,0xd7e000a1,0xb8150274}},	// [e5f0] амас, mace_, नांच, адај,
   {{0xb8dd23e3,0x2d8bbed6,0x6446010b,0x37070dc8}},	//   _आह_, lace_, _ūkin, лчев,
   {{0xf7701b15,0x9f470187,0x00000000,0x00000000}},	//   سال_, _koná_, --, --,
   {{0xe51600ab,0x8f370070,0xbbc50066,0x069800b5}},	//   _देहि_, נטאג_, _लघुक, اخلت_,
   {{0x26d80bc8,0xa2bd00df,0x63851499,0x26ca1ba3}},	//   _erro_, _वैज्, агла, _esbo_,
   {{0x69cf00c8,0xa3b00084,0xe299bed7,0xddd9009f}},	//   _hace, ट्ल_, вак_, _avvż,
   {{0x2d8b000c,0x69cf00f8,0x38af037a,0x7986030d}},	//   kace_, _kace, lür_, _yekw,
   {{0xe51629ad,0x69cf0035,0xa3a900a1,0xc2450274}},	//   _देवि_, _jace, ग्ज_, јник,
   {{0x2d8b00b8,0x38af0644,0x3ebc0107,0x69cf032b}},	//   dace_, nür_, _apvt_, _mace,
   {{0x69cfbed8,0x41a70026,0xf07600b5,0xa3dc0066}},	//   _lace, _गावस, جیوں_, _तोप_,
   {{0xa3e20fcf,0xdced009f,0x3fc700b5,0x00000000}},	//   धार_, _ffaċ, ندھی_, --,
   {{0x69cf043f,0x2d8b3723,0x62550009,0x7ddb0328}},	//   _nace, gace_, _ašov, _räsä,
   {{0x7986035f,0xef1800ea,0xa3e9142a,0x00000000}},	//   _rekw, daļu_, याप_, --,
   {{0x38af0463,0x7986bed9,0x69cf011e,0xab2a5118}},	//   dür_, _sekw, _aace, вога_,
   {{0xa3d61a75,0x80cd0a44,0x69cfbeda,0x78bd123c}},	//   ियत_, तिके, _bace, _apsv,
   {{0x38af3959,0x6926a387,0x2d8bbedb,0xf1bd0931}},	//   für_, амба, cace_, ्यटन,
   {{0xe8f701f1,0xdb1cbaa1,0x69cf00ec,0x38c80e3a}},	// [e600] алт_, merí, _dace, دازی_,
   {{0xdb1c09ab,0x60040c1f,0xb8ee00b4,0x7986034d}},	//   lerí, _kòma, _शन_, _wekw,
   {{0xa3e9a391,0x0566bedc,0xa3a90632,0x3b0a0227}},	//   यान_, авен, ग्छ_, _рено_,
   {{0x98a609ce,0xdb1c0b4c,0x69cfbedd,0x3f871e5a}},	//   _киме, nerí, _gace, _lenu_,
   {{0x25a601f7,0x8cd90461,0xa3e200a1,0x69c4bede}},	//   rgol_, मियो, धाल_, meie,
   {{0x69c4bedf,0x2d8b000c,0x25a6001e,0x69cf0693}},	//   leie, zace_, sgol_, _zace,
   {{0x44200a78,0x3f983c0e,0x600402d0,0xdb1c0132}},	//   đi_, órum_, _nòma, lerâ,
   {{0x69c40176,0xdb1c0831,0xe5a3117a,0x69cf01dd}},	//   neie, jerí, _миси, _xace,
   {{0xdb1cbee0,0x2d8bbee1,0xf1bd021a,0x3eae0f00}},	//   derí, vace_, ्यजन, _sqft_,
   {{0x3f871352,0xdefa342d,0x69c403d0,0x6abe02ce}},	//   _cenu_, вым_, heie, _oppf,
   {{0xdb1c8a0b,0x2d8b01c0,0x3f8700e9,0x69c401ed}},	//   ferí, tace_, _denu_, keie,
   {{0xfe7800c7,0x78a46f5e,0xdb1c7cce,0x00000000}},	//   rpį_, kuiv, gerí, --,
   {{0x2d8b000c,0x61e267ee,0x614307c1,0x8ca20035}},	//   race_, _inol, _деца, कूलो,
   {{0x69cfbee2,0x2d8bbee3,0x600402e9,0x3f87bee4}},	//   _sace, sace_, _fòma, _genu_,
   {{0x2d8bbee5,0x6e940082,0xa3ae017a,0x61e25056}},	//   pace_, _البا, _कान_, _knol,
   {{0x3f8c0a0b,0xdb1c0b4c,0x3f87bee6,0x38afbee7}},	//   ladu_, cerí, _zenu_, tür_,
   {{0xa3d6227d,0xa3e91022,0x3f87000e,0x478b03fe}},	// [e610] िया_, याम_, _yenu_, всем_,
   {{0xb5fd19be,0x38af0644,0xf1b900f4,0x00000000}},	//   _miše, rür_, miše_, --,
   {{0xf1b91269,0x69c44a4c,0x69cfbd9f,0xe719004f}},	//   liše_, beie, _tace, ديات_,
   {{0xd6d89183,0xb7c600ea,0x78a40036,0x249d016e}},	//   шту_, _apģē, buiv, trwm_,
   {{0xf1b90bec,0x81d50083,0xdb17002a,0xfc3f002a}},	//   niše_, _সকল_, _taxó, stíu_,
   {{0x5f09018d,0x798d018e,0x32060176,0x3f8c00cd}},	//   ानम्_, laaw, _aloy_, jadu_,
   {{0x5694bee8,0xdb1c00de,0xa3e90066,0xe2a800d1}},	//   _март, yerí, याब_, لاين_,
   {{0x798d018e,0x00853312,0x16341470,0xdb1e07a6}},	//   naaw, блио, _деся, _papú,
   {{0xfc3fbee9,0x03c70086,0xdb1c9407,0x3f8c0090}},	//   ntís_, _всем, verí, fadu_,
   {{0xa3ae0429,0x3f8c1a8a,0x63ad0a78,0x69c41c2c}},	//   _काय_, gadu_, đans, zeie,
   {{0xdb1c0f56,0x798da347,0x3f8700f7,0x44270159}},	//   terí, kaaw, _venu_, mnn_,
   {{0x6443beea,0xb5fdbeeb,0x83fc0254,0x3f8736e0}},	//   llni, _fiše, _viđe, _wenu_,
   {{0xe7c70d1f,0x44270094,0x3f8700f7,0x798d0103}},	//   रजाप, onn_, _tenu_, daaw,
   {{0x2d9ebeec,0x3f8c00fe,0x69c4beed,0x60c922e5}},	//   şte_, cadu_, weie, mwem,
   {{0x44278abd,0xdb1cbeee,0x69c49abb,0x09e60b32}},	//   inn_, derã, teie, бовн,
   {{0xc3320052,0x3ea5beef,0x798d24a8,0x8966bef0}},	//   פון_, mult_, gaaw, скаж,
   {{0x69c4bef1,0xc0440019,0xf1b900f4,0x00000000}},	// [e620] reie, _đoạt_, ciše_, --,
   {{0x25ad002d,0x69c4bef2,0x78a40036,0x317f7932}},	//   _acel_, seie, ruiv, hbuz_,
   {{0xb8ef012f,0x6abe4cfe,0x3ea50006,0x7afc01f4}},	//   _वै_, _uppf, nult_, qyrt,
   {{0xad9b004f,0x60c90979,0x3f8c39c0,0x64430035}},	//   thúi, kwem, zadu_, elni,
   {{0x78a40b62,0x04460431,0x3ea5038e,0x764200e5}},	//   quiv, бедн, hult_, rloy,
   {{0x3ea5bef3,0xdb1c0132,0xb87b00d5,0xfc3f0079}},	//   kult_, cerã, _bríf, ltír_,
   {{0x7642bef4,0x3f8cbef5,0xd25000d1,0x3ea569cf}},	//   ploy, vadu_, ونت_, jult_,
   {{0x44270f46,0xb5fd17ee,0x6443843d,0x30a64774}},	//   ann_, _piše, alni, бров,
   {{0xb5fd0009,0x3f8c1297,0x00000000,0x00000000}},	//   _fišb, tadu_, --, --,
   {{0xf1b901cc,0xb5fd0a78,0xdb1cbef6,0x6602145d}},	//   više_, _više, ndró, lkok,
   {{0x50d60148,0x3f8c25e2,0x28cf0d00,0xdb0e01ae}},	//   _گزار, radu_, _सैनि, gebü,
   {{0x7c3e012f,0x3f8cbef7,0x6602bef8,0xf1b9011c}},	//   _akpr, sadu_, nkok, tiše_,
   {{0x443ebef9,0x3ea500a2,0xdddb2143,0x316601ed}},	//   _kkt_, ault_, lptū, _igoz_,
   {{0x7bd80473,0xf1b90254,0x798d0273,0x443e194f}},	//   _óvul, riše_, waaw, _jkt_,
   {{0xa3e9134b,0x443ebefa,0xdb1c03e6,0xfc3f0b4c}},	//   यात_, _mkt_, verã, guía_,
   {{0x201ebefb,0xf1b90528,0x26df0254,0x2bad06fe}},	//   liti_, piše_, _čuo_, ञ्जा,
   {{0x4427498f,0x798d001c,0x442cbefc,0x57f5110d}},	// [e630] ynn_, raaw, _ojd_, опат,
   {{0x201ebefd,0xb7672b79,0x443e3f07,0x798d01a8}},	//   niti_, стай, _nkt_, saaw,
   {{0xb87b3a89,0x44270023,0xd6db1ac5,0x798d010d}},	//   _oríg, vnn_, ыта_, paaw,
   {{0x7afa06ed,0x442c2802,0x201ebefe,0x443ebeff}},	//   ätte, _ajd_, hiti_, _akt_,
   {{0x201ebf00,0xd49b3d21,0x443e4a70,0x442c0051}},	//   kiti_, уре_, _bkt_, _bjd_,
   {{0x201e0e46,0x2bad00b8,0xdb1c10ba,0x88ba0070}},	//   jiti_, ञ्चा, lerá, _דזשי,
   {{0x201e2a9f,0x442701a6,0x443e002f,0xdb0700be}},	//   diti_, rnn_, _dkt_, pejõ,
   {{0xdb1c122d,0xe1f903d0,0x1dd90325,0x40952626}},	//   nerá, рги_, _बोलत, орот,
   {{0x201e000e,0x6443024e,0xa3e9052b,0x443ebf01}},	//   fiti_, plni, याद_, _fkt_,
   {{0x3ea50006,0x6e2d0054,0x201ebf02,0x3a290159}},	//   tult_, _ajab, giti_, hnap_,
   {{0xb87b0176,0xa3d600b1,0x2be30722,0x661b0159}},	//   _fríg, ियर_, खाईं_, _kmuk,
   {{0xed5a0948,0xb87b00a0,0x3ea5713c,0xdb1c02b1}},	//   ион_, _kríd, rult_, rdrü,
   {{0x201ebf03,0x66095429,0x3a2951c0,0x3ea5bf04}},	//   biti_, _mlek, dnap_, sult_,
   {{0x3ea5029d,0x201ebf05,0xfc3f0a20,0x3ad802d0}},	//   pult_, citi_, tuía_, _pčp_,
   {{0x8c43bf06,0xdd9200f5,0x66090006,0xdb1c024e}},	//   фере, _ہوں_, _olek, ferá,
   {{0xf2d20bed,0x3a2900b5,0xfc3f01ef,0x00000000}},	//   ועל_, gnap_, ruía_, --,
   {{0x2bb209f9,0xfc3f002a,0xa7fb02d7,0xd9430336}},	// [e640] _जापा, suía_, _zuñi, дети,
   {{0x661b1939,0x7f8c0070,0x3942010b,0xdb1c0392}},	//   _amuk, ָנאַ, _vyks_, perà,
   {{0x06ca6426,0xdb1c0168,0x66094cfa,0xfc3f1111}},	//   ргей_, berá, _blek, quía_,
   {{0x201e2676,0x7c3c0485,0xdb1c365a,0xd0120083}},	//   ziti_, lorr, cerá, িচয়_,
   {{0x320d0159,0xb1240083,0x201e02e9,0x6602bf07}},	//   dhey_, _পর্ব_, yiti_, rkok,
   {{0x6004009e,0x661b073a,0x38b409af,0x00000000}},	//   _còml, _emuk, mär_, --,
   {{0x201e06cc,0x38b406d2,0x2bb21d78,0x66096af2}},	//   viti_, lär_, _जाना, _flek,
   {{0x201e00d1,0x7c3c01a3,0x7e6400be,0x7bc7882a}},	//   witi_, horr, _niip, zeju,
   {{0x201e2288,0x6d440d4b,0x7c3cbf08,0x38b4bf09}},	//   titi_, _nyia, korr, när_,
   {{0xdb1c114d,0x6e2d03c4,0x3a2d0e31,0xd9c7007c}},	//   zerá, _sjab, čepi_, _लस्ट,
   {{0x443cbf0a,0x7c3cbf0b,0x38b401ff,0x27f80107}},	//   mov_, dorr, här_, _morn_,
   {{0x443cbf0c,0x201ebf0d,0x200c0c54,0x320d01a2}},	//   lov_, siti_, shdi_, chey_,
   {{0x201ebf0e,0x7c3cbf0f,0x7bc71e7b,0x7e644f63}},	//   piti_, forr, teju, _diip,
   {{0x443cbf10,0x38b401ff,0x7c3c06a2,0xdb05002a}},	//   nov_, där_, gorr, _achá,
   {{0xf1b90bde,0x298b0274,0x7bc7061c,0x7bd5bf11}},	//   liša_, исао_, reju, rdzu,
   {{0x38b4022a,0xf1bc3100,0x69d6043d,0x68ed7e89}},	//   fär_, ्जिन, gdye, txad,
   {{0x443c18f2,0x7c3cbf12,0xb5fd62b8,0xa3bc0084}},	// [e650] kov_, borr, _niša, ेजा_,
   {{0xd6dbbf13,0x443c016f,0x68ed610a,0x661bbf14}},	//   ите_, jov_, rxad, _smuk,
   {{0xa3e94f13,0x443cbf15,0x66094b27,0x98bc00ea}},	//   यास_, dov_, _plek, āvā_,
   {{0x38b4022a,0xd2462087,0x60c20693,0xe9df01a5}},	//   bär_, _سن_, _opom, _chút_,
   {{0xd126004f,0x3cde0084,0x443cbf16,0x27f8bf17}},	//   _أم_, खिये_, fov_, _forn_,
   {{0x443cbf18,0xb87b01ef,0xb5fd2c8d,0x83fc0124}},	//   gov_, _críe, _diša, _piđa,
   {{0xa3bc0084,0x66b49df2,0x00000000,0x00000000}},	//   ेज़_, _обру, --, --,
   {{0xa3e90992,0x661b0232,0x83fc044d,0x7c3cbf19}},	//   याह_, _umuk, _viđa, zorr,
   {{0x443cbf1a,0xf1b90c99,0xd24e0c26,0x92ab0083}},	//   bov_, giša_, دني_, গবে_,
   {{0x320d010d,0x443cbf1b,0x60090267,0xad9b0093}},	//   shey_, cov_, сном_, khús,
   {{0x600d1fca,0x2615016f,0x6d441221,0xee3a38a2}},	//   _núme, sťou_, _syia, йно_,
   {{0xbddb1010,0xa3e955f5,0xf1b90c99,0xb2ba0122}},	//   blèm, याव_, biša_, _למער,
   {{0x7c3cbf1c,0x99800009,0x25bf0118,0x6441009f}},	//   torr, jniš_, _mbul_, _kkli,
   {{0x60db4583,0x61f9bf1d,0xc10400e0,0x7e64052a}},	//   mvum, _howl, _توهي, _wiip,
   {{0x63bc01d6,0x61f901a2,0x09e600d4,0xdb1c0644}},	//   _örne, _kowl, повн, _üzün,
   {{0x443c016f,0xfc3fbf1e,0x78b60086,0x656900e0}},	//   zov_, quín_, ttyv, _ngeh,
   {{0x27f8b431,0x7c3cbf1f,0x644179c9,0x61f90090}},	// [e660] _porn_, porr, _okli, _mowl,
   {{0x443c006f,0xe73a03d0,0x61f9bf20,0x21f10187}},	//   xov_, без_, _lowl, _váhy_,
   {{0xe9df01a5,0x443c1916,0x20050159,0xb5fda5ec}},	//   _phút_, vov_, ikli_, _siša,
   {{0x3ce00a18,0xb5fd022f,0xdb050334,0x61f90051}},	//   _kriv_, _piša, _uchá, _nowl,
   {{0x443cbf21,0x7984bf22,0xe51656f9,0xd4e300c3}},	//   tov_, mbiw, _देखि_, еющи,
   {{0xb5fd0121,0xa7fb1e6e,0x6569008c,0xf1b901a0}},	//   _viša, _buñu, _egeh, viša_,
   {{0x60c207c0,0x443cbf23,0x6458bf24,0x00000000}},	//   _spom, rov_, rmvi, --,
   {{0x443cbf25,0x30a61129,0xc181006c,0x61f991b8}},	//   sov_, пров, پیوٹ, _cowl,
   {{0x61f9bf26,0x443c01fe,0xe1ef0079,0xb5fd0254}},	//   _dowl, pov_, اسى_, _kišn,
   {{0xdb1e0831,0x6e981c1b,0xc8b70070,0xdcef0029}},	//   _japó, овор_, פּחה_, sacī,
   {{0xa3e91033,0x61f9bf27,0x6f010297,0xdcf60095}},	//   यार_, _fowl, gylc, _peyğ,
   {{0x78a4bf28,0x61f9003c,0x3f830093,0x60040359}},	//   kriv, _gowl, ðjur_, _kòmk,
   {{0x60c23b5e,0x6e3d00b5,0xc05a010b,0x463b016b}},	//   _upom, rosb, _лік_, מעטע,
   {{0x78a40307,0x2bb202cb,0x2005027d,0x515b00a5}},	//   driv, _जाणा, ckli_, _הכדו,
   {{0x7ac41412,0x81cf0033,0x78a400be,0x7659016e}},	//   нсте, শার_, eriv, ymwy,
   {{0xad9b0093,0x7afa013c,0x78a4027a,0x99800207}},	//   rhús, ätta, friv, tniš_,
   {{0x69347ee0,0xad9b008d,0x3f8e00ee,0xe9df026e}},	// [e670] енту, shús, _kefu_, _bhúr_,
   {{0xf7700125,0xb87b016f,0x39470029,0xa3dc0a44}},	//   هام_, _príb, āns_, _तोल_,
   {{0x6d4106d0,0xdb1c01ae,0x2bb204cc,0xb5fd012e}},	//   şlad, gerä, _जाता, _dišn,
   {{0x6441bf29,0xb87b0037,0x78a4b77c,0x60db010b}},	//   _skli, _críc, briv, yvum,
   {{0xa3e9046c,0x78a4bf2a,0x99f60122,0xa3ae0084}},	//   याल_, criv, _חזרה_, _काश_,
   {{0xe9df0079,0xb4ad0ceb,0x466b5288,0xdb1c01ff}},	//   _thús_, _कमी_, _грам_, berä,
   {{0xa3ae020c,0x6263006c,0xe5f30160,0x425502c4}},	//   _कार_, _főol, _căţă, мтит,
   {{0xdb1c0279,0x00e516ac,0x60db00be,0xdb1e021e}},	//   serç, джин, tvum, _kapò,
   {{0x9f5e0082,0x81cf0083,0xdb1c1531,0x24f800af}},	//   chtú_, শাল_, perç, _енты_,
   {{0xdb1e0391,0xb5fd044d,0x9f4e1c98,0x64410355}},	//   _xapó, _kišo, _sofá_, _ukli,
   {{0x6da6bf2b,0x60c40080,0x78a40928,0xada60d6e}},	//   мина, _ģime, zriv, манл,
   {{0x28e00099,0xb5fd00f4,0x38720055,0x26de0207}},	//   निमि, _mišo, yqyr_, _štok_,
   {{0xa2d5021a,0x7bd701d7,0x6ff50037,0xdea101df}},	//   भिक्, _baxu, _يستط, ریکی,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81b40083,0x3f85bf2c,0x798f099e,0xa3ae00ab}},	//   _ছোট_, mblu_, _becw, कलत_,
   {{0xa3e99f50,0x78a40012,0xc33202b8,0x6aa1848f}},	//   याँ_, triv, דול_, álfa,
   {{0xa3ae0325,0x6004009e,0x7bd70160,0x6b990098}},	// [e680] _काल_, _bòmh, _faxu, éagó,
   {{0xa3dc0084,0x60040014,0xb5fd33a5,0xdb1cbf2d}},	//   _तों_, _còmh, _bišo, terä,
   {{0xb5fd01a0,0xf9860279,0x600401a6,0xa96a0ef3}},	//   _višn, _огно, _dòmh, _мина_,
   {{0x78a40a78,0xeef60070,0x6004009e,0x64a6449f}},	//   priv, ומער_, _eòmh, дада,
   {{0xa3e91db6,0xdb1e0b06,0x7bd70095,0xf4cc0033}},	//   यां_, _tapó, _yaxu, লম্ব,
   {{0xfc3f043f,0xa2a214ab,0xdb1c0086,0xa3ae00a1}},	//   oría_, _गिद्, perä, _काळ_,
   {{0x2bc00ebd,0xb87bbf2e,0xfbc071ff,0x07a30798}},	//   श्या, _tríc, श्यम, _јасн,
   {{0xfc3f20d9,0x3f8e0af3,0x00000000,0x00000000}},	//   iría_, _sefu_, --, --,
   {{0xb5fd10ec,0xfa1c00e2,0x00000000,0x00000000}},	//   _mišl, _đất_, --, --,
   {{0xa3e90026,0xf95700a5,0x7c2e5c92,0x60040107}},	//   याः_, וספת_, jnbr, _kòmi,
   {{0xf8ab0324,0x00000000,0x00000000,0x00000000}},	//   _चम्प, --, --, --,
   {{0xfc3f0033,0xceb83e9a,0xb5fd02c4,0x7c2e0345}},	//   dría_, rtę_, _nišl, enbr,
   {{0x7afa022a,0xfc3f0300,0xceb8297a,0xdfd20037}},	//   ättn, ería_, stę_, _ليش_,
   {{0xfc3f0b06,0xdb1e02d0,0xce940382,0x00000000}},	//   fría_, _rapò, _закъ, --,
   {{0x27ed01a5,0xfc3f4f85,0x2019bf2f,0x6298bf30}},	//   _đen_, gría_, ësie_, nsvo,
   {{0x2a7400d5,0x7c2e0345,0xdb1e021e,0xa3e529ad}},	//   _žabí_, anbr, _papò, _बोन_,
   {{0xa3ae035d,0xdb0502c9,0xfc3f1111,0x6d4000b9}},	// [e690] कला_, _schä, aría_, ümat,
   {{0xfc3f4f85,0xb87b27c2,0xb8f7021a,0xb5fd0207}},	//   bría_, _cría, _ान_, _pišo,
   {{0x23d906bc,0xdb1c0ab8,0x78690009,0x629e356e}},	//   _योगद, terå, _džva, ápol,
   {{0x78a2024e,0x60040176,0x6298bf31,0xb5fd01a0}},	//   šova, _dòmi, dsvo, _višo,
   {{0x629abf32,0x1dc1012f,0xe00e02cb,0x64a59264}},	//   _avto, ष्यत, िसाद_, хала,
   {{0x6298bf33,0x60040359,0xdb1c01ff,0x6b9502d7}},	//   fsvo, _fòmi, rdrö, nazg,
   {{0x44290a78,0x78ad00c3,0x09040033,0x00000000}},	//   đa_, luav, _রেপু_, --,
   {{0x200e023a,0x1dc107df,0x644abf34,0x69cd4de8}},	//   _alfi_, ष्मत, alfi, neae,
   {{0x9f470037,0x78adbf35,0xa0c5026e,0x657b0027}},	//   _inné_, nuav, ريدو, _ifuh,
   {{0xb5fd023a,0x69cd018d,0x00000000,0x00000000}},	//   _mišm, heae, --, --,
   {{0x47ca0033,0xf99f0359,0x00000000,0x00000000}},	//   রাচী, _odè_, --, --,
   {{0xdca62447,0x200e3720,0x66190225,0x78ad0009}},	//   нами, _elfi_, _çakı, kuav,
   {{0x8fa57d29,0x78adbf36,0x657b0027,0x00000000}},	//   _зале, juav, _mfuh, --,
   {{0xfc3f0b4c,0x09a800a1,0xdb1c7c6e,0x6b9500b5}},	//   tría_, गल्य, merú, gazg,
   {{0x7c2e2049,0xca5603fa,0xb5fd0207,0x48bf0033}},	//   rnbr, етањ, _pišl, উটোর,
   {{0xfc3f0b4c,0xdb1c00a2,0x7c3600f4,0x69cd018d}},	//   rría_, nfré, _šarč, geae,
   {{0x656d01ba,0xb87b01ef,0xb5fd0207,0x3f8100be}},	// [e6a0] ľahl, _pría, _višl, _õhus_,
   {{0x1dc10f17,0x6e260008,0x7d060086,0xf99f0260}},	//   ष्ठत, likb, myks, _edè_,
   {{0xb4e80b35,0xa3e90bc1,0x39ea17e3,0x7bcebf37}},	//   यम्_, याई_, _едно_, mebu,
   {{0x186a00aa,0x7bdcbf38,0x600401f7,0x6e2616b1}},	//   _нами_, ldru, _vòmi, nikb,
   {{0xb87b002a,0xdb150138,0x2d920260,0x6aae0051}},	//   _tría, bezó, _meye_, lubf,
   {{0x7bdcbf39,0x6e2604ce,0x7bcebf3a,0x229a0029}},	//   ndru, hikb, nebu, tīk_,
   {{0x53340086,0xe80500a1,0xae100026,0xb5fd03c9}},	//   ъект, _शकता_, ासान_, _mišj,
   {{0x20bd0755,0xa2d50380,0xb6bb02b8,0x62982b78}},	//   ्बंध, भिज्, _מצלי, rsvo,
   {{0x7bcebf3b,0x600dbf3c,0x63b701f4,0xe3b20e3a}},	//   kebu, _súma, çanë, _مرا_,
   {{0x7642030d,0x61ebbf3d,0x7bce0118,0x6298aca7}},	//   looy, _engl, jebu, psvo,
   {{0x8f344032,0x7bce17ad,0x91e62626,0xd36f0c74}},	//   тенц, debu, _поже, _اهم_,
   {{0x7bdc2aa8,0xd6e20831,0x00000000,0x00000000}},	//   edru, _যথায, --, --,
   {{0x7bdc476c,0x2d92bf3e,0xb87b0392,0xf8cf046c}},	//   fdru, _deye_, _arín, _सैंय,
   {{0x7bce02c9,0xb87b0176,0xa3d600b4,0x7bdc0d35}},	//   gebu, _brín, ियट_, gdru,
   {{0x6b95860c,0x61ebbf3f,0x8ff703c5,0xfc3f01ef}},	//   razg, _yngl, _سرور_, brín_,
   {{0x78ad0176,0x79960159,0xfc3f01ef,0x00000000}},	//   tuav, gayw, crín_, --,
   {{0x97a71a76,0x41c20e61,0xf1c2021a,0x7bce1a15}},	// [e6b0] ерел, व्यस, व्यन, bebu,
   {{0x7bcebf40,0xc02e01a5,0x00000000,0x00000000}},	//   cebu, _điệu_, --, --,
   {{0x69cd0553,0x2d920657,0xcf9302b5,0x248d053e}},	//   peae, _yeye_, רטע_, _swem_,
   {{0x7642073a,0xa64702fd,0xc8a914ab,0xb5fd02c4}},	//   gooy, رخان, _छटपट, _tišm,
   {{0x78ad027a,0x386a0107,0xb5fd0116,0x00000000}},	//   quav, _fibr_, _hišk, --,
   {{0x998000a0,0xb5fd0f27,0x61eb0024,0x00000000}},	//   rniť_, _kišk, _sngl, --,
   {{0x7bc50118,0x00000000,0x00000000,0x00000000}},	//   _mbhu, --, --, --,
   {{0xb5fdbf41,0xf99f0c1f,0x7bce004e,0x7c27104e}},	//   _mišk, _elèv_, zebu, hijr,
   {{0x2055bc43,0xf99f0260,0x27210f9f,0xdb1c008d}},	//   ктор, _flèv_, _मधुर_, rfré,
   {{0xa2a9017f,0x7d06010b,0xfc3f0138,0x15ef0066}},	//   _टिप्, vyks, drío_, छावर_,
   {{0x4427bf42,0xb5fd0200,0x2d920c1f,0xc2c400f8}},	//   min_, _nišk, _peye_, _ميلي,
   {{0x6443bf43,0x61ebace6,0x7d0603ad,0x44270b73}},	//   loni, _ungl, tyks, lin_,
   {{0x518430e0,0x44271093,0x64430006,0x7bdc02c0}},	//   _суха, oin_, ooni, tdru,
   {{0x4427bf44,0x6443bf45,0xb87b8e8c,0x8fa51c1b}},	//   nin_, noni, _prín, _раке,
   {{0x7bdc0b3c,0xae1f1343,0x7642001c,0xb5fd02c6}},	//   rdru, मोहन_, yooy, _višj,
   {{0x7bce1cad,0xb87b004f,0x224d0282,0x7ae5044d}},	//   sebu, _crío, nlek_, _drht,
   {{0x442738e5,0x6443bf46,0x6e240232,0xa3e1021a}},	// [e6c0] kin_, koni, _imib, धया_,
   {{0x4427bf47,0x6443048c,0x7642073a,0xb87b0037}},	//   jin_, joni, wooy, _trín,
   {{0xa3d51649,0xa3e51649,0xb87bbb83,0x224d00e0}},	//   िजन_, _बोध_, _frío, klek_,
   {{0x4427bf48,0x225f0a4e,0xb60800ac,0x80b70033}},	//   ein_, jmuk_, _odšť, _অনন্,
   {{0x4427bf49,0xcd770070,0xa3ae007c,0x6281bf4a}},	//   fin_, דענק_, कलल_, _atlo,
   {{0x4427bf4b,0xa3e91649,0xc44800f8,0xe1f9010b}},	//   gin_, याग_, ریان_, ejų_,
   {{0xd25a2356,0x74160580,0x92b30037,0x00000000}},	//   мци_, _یورا, لحيا, --,
   {{0x44270a24,0xa2b300b4,0x6d56021e,0x224d24ff}},	//   ain_, _इमर्, _ozya, glek_,
   {{0xdfd00514,0x6443bf4c,0xe3ba0267,0x3d0c0067}},	//   مية_, boni, _оба_, हनों_,
   {{0x212bbf4d,0x6e24bf4e,0xbddb488c,0xe28609cc}},	//   úcha_, _amib, hlèt, _алжи,
   {{0xdd950409,0xdef701c8,0x645a01d6,0x201901f4}},	//   ланы, выя_, _ihti, ësia_,
   {{0xd3780c99,0xa3bc0a44,0x9f5c01f7,0x60040392}},	//   _daće_, ेजक_, _jové_, _ròmu,
   {{0xf1b30122,0x6600044d,0x00000000,0x00000000}},	//   _כסף_, _momk, --, --,
   {{0xb5fd219c,0x5f941783,0x6e24018e,0x60040176}},	//   _pišk, _сикт, _emib, _pòmu,
   {{0xb87b0082,0xdb230723,0xd37800cb,0xbddb000d}},	//   _prío, _ürün, _gaće_, flèt,
   {{0x9f5c114d,0x5a347920,0x6443bf4f,0xb5fd0121}},	//   _nové_, анст, zoni, _višk,
   {{0x4427bf50,0x2d99bf51,0x9955bf52,0x49742aff}},	// [e6d0] yin_, mase_, укац, рлус,
   {{0x4427bf53,0x2d99bf54,0x6d4d179a,0xf99f0260}},	//   xin_, lase_, _iyaa, _alèt_,
   {{0x4427bf55,0x6443bf56,0x2d99002d,0x2a60006d}},	//   vin_, voni, oase_, bmib_,
   {{0x4427bf57,0xb5fd093f,0x645a2615,0xe3b800d0}},	//   win_, _kiši, _ahti, _acı_,
   {{0x4427bf58,0xfbc000b8,0xd49b44d9,0x224d0298}},	//   tin_, श्वम, фре_, vlek_,
   {{0x3a290159,0x4427ac75,0x2d99bf59,0x6d4d0103}},	//   liap_, uin_, hase_, _myaa,
   {{0x4427bc23,0x69ddbf5a,0x224d0b2a,0xb5fd0d5c}},	//   rin_, _kase, tlek_, _liši,
   {{0x645abf5b,0x442704d5,0x69dd01a0,0xe0d90674}},	//   _ehti, sin_, _jase, еви_,
   {{0x4427bf5c,0x2d99bf5d,0x6443bf5e,0x224d13a8}},	//   pin_, dase_, poni, rlek_,
   {{0x4427bf5f,0x224d01d6,0xf076006c,0x6e2403d0}},	//   qin_, slek_, دیوں_, _smib,
   {{0x6d4d0103,0x765b0028,0xa34700d8,0x224db53b}},	//   _ayaa, _khuy, _рэал, plek_,
   {{0x69dd0500,0x7c250082,0x2d99bf60,0x6d411a68}},	//   _nase, _amhr, gase_, ğlan,
   {{0x6d410092,0xa0a5bf61,0x10a5075c,0x645a0086}},	//   şlan, _салд, _силн, _yhti,
   {{0x4425bf62,0xb87b00de,0x6d4d010d,0x2909011e}},	//   _jml_, _crím, _dyaa, dyaa_,
   {{0x69dd8df0,0x611b0009,0x2fc70159,0x61fb08c7}},	//   _base, _bъlg, _ibng_, ojul,
   {{0xceb201f3,0x2d99bf63,0x61fbbf64,0x7e6dbf65}},	//   _היה_, case_, njul, _giap,
   {{0x69ddbf66,0x6600bf67,0xb87b008d,0x6d4d073a}},	// [e6e0] _dase, _romk, _frím, _gyaa,
   {{0x69ddbf68,0x764902d0,0x2ca00036,0xb87b0093}},	//   _ease, _akey, _ivid_, _grím,
   {{0x2c6f0484,0x7bde0034,0x55e6117a,0x2ca00c71}},	//   _iżda_, _iapu, ложб, _hvid_,
   {{0x765b098b,0x69dda81f,0x7bdebf69,0x4425001e}},	//   _chuy, _gase, _hapu, _aml_,
   {{0x69c40223,0xa426149e,0x80d30066,0xdb050a8c}},	//   mfie, лькл, _बैले, _schø,
   {{0x69ddbf6a,0x2d99043f,0xf7460e88,0x69c43df0}},	//   _zase, zase_, _бего, lfie,
   {{0x7bde7897,0x68e40bb0,0x2d990371,0x0cb106bc}},	//   _mapu, lvid, yase_, _जम्म,
   {{0x2d993612,0x7bdebf6b,0x2fc7011e,0x68e400be}},	//   xase_, _lapu, _abng_, ovid,
   {{0x2d99bf6c,0x7e6d0382,0x30142c93,0x05dd00b4}},	//   vase_, _riap, идир, _नोटब,
   {{0xa3ae0299,0x7e6dbf6d,0x765b046a,0x2d99bf6e}},	//   _काट_, _siap, _zhuy, wase_,
   {{0x630643ff,0x2d99bf6f,0xe7c60d53,0xd7c60380}},	//   _حوال, tase_, र्यप, र्यच,
   {{0xb5fd02c6,0x90e60ca8,0x6d4d0118,0x320dbf70}},	//   _piši, _مستن, _pyaa, ckey_,
   {{0x2d99bf71,0x69ddbf72,0xa3e902cb,0x4425053e}},	//   rase_, _rase, याच_, _yml_,
   {{0x7bde2028,0x68e46e3f,0xb5fd068b,0x2d99a523}},	//   _capu, dvid, _viši, sase_,
   {{0x2d99bf73,0x69c45e98,0x3a293635,0x7bde5117}},	//   pase_, ffie, tiap_, _dapu,
   {{0xb5fd2209,0x59df21a8,0x8e830037,0xa2d75860}},	//   _tiši, _पोखर, _اليه, _मनस्,
   {{0xa3b5065a,0x69dd4e84,0xc984021d,0x290f006c}},	// [e6f0] _झाल_, _vase, суси, ága_,
   {{0xf1b9bf74,0x3a29028b,0xfc3f01dd,0x69dd3d5c}},	//   riši_, siap_, tuíu_, _wase,
   {{0x76b91334,0x69ddbf75,0xd6d10220,0xa3ae135e}},	//   тлер_, _tase, تقا_, _काज_,
   {{0x7bde0169,0x3ce904ca,0xd6d80104,0xf1b92163}},	//   _zapu, _krav_, ыту_, piši_,
   {{0x798d3b4a,0x2ed1046c,0x44250526,0x68e42f97}},	//   mbaw, _तन्त, _pml_, cvid,
   {{0x232900d4,0xb5fd0009,0x78adbf76,0x3ce900cd}},	//   коли_, _nišv, mrav, _mrav_,
   {{0x765b01a5,0x320d055c,0xf10d060a,0x78ad3221}},	//   _thuy, tkey_, िन्द_, lrav,
   {{0x212b0279,0x44250024,0x78ad0714,0xe9df0132}},	//   úcho_, _wml_, orav, _jaú_,
   {{0x3ce9006d,0x44250228,0x944200b5,0x320dbf77}},	//   _nrav_, _tml_, _ڈھون, rkey_,
   {{0xb87b016f,0x442515d6,0x60092f2c,0x224002b2}},	//   _príj, _uml_, тном_, čika_,
   {{0x26c1bf78,0x998903ab,0x7bde6552,0x78ad6fb9}},	//   ntho_, znaš_, _rapu, hrav,
   {{0x3ce968cf,0x60160279,0x78ad2c9a,0x00000000}},	//   _brav_, _câmb, krav, --,
   {{0x7bdebf79,0x68e400f7,0x3eac4996,0x601600af}},	//   _papu, xvid, ardt_, _dâmb,
   {{0x6a860210,0x78ad2190,0x92d70083,0xa13602b5}},	//   илга, drav, ামী_, _דאנק_,
   {{0xeb9705c0,0x7bdebf7a,0xe9df0132,0x199600ed}},	//   рис_, _vapu, _baú_, ијар,
   {{0x78ad7215,0x68e40f0a,0xdb1c01ba,0x798d2326}},	//   frav, tvid, cerý, gbaw,
   {{0x69c4bf7b,0x7bdebf7c,0xa3d50006,0x3ce9bf7d}},	// [e700] rfie, _tapu, िजा_, _grav_,
   {{0x68e4bf7e,0xa3e500fa,0x07a60e02,0xf1b90009}},	//   rvid, _बोल_, ражн, mišu_,
   {{0xf1b9a355,0x68e4bf7f,0x78ad027a,0x69c4bf80}},	//   lišu_, svid, arav, pfie,
   {{0x1a9b0070,0x38710478,0x6b9cbf81,0x68e41bf8}},	//   _ביטע, _žorž_, larg, pvid,
   {{0xf1b962b8,0x78ad0f84,0x5d7b0070,0x00000000}},	//   nišu_, crav, דאנק, --,
   {{0x66e60133,0xdb1c006c,0x02a6420c,0x6b9cbf82}},	//   _кога, kerü, арим, narg,
   {{0xe7c60099,0xc7a30923,0x28ac0e6f,0xdb150183}},	//   र्णप, _фиск, _चिडि, bezõ,
   {{0x6b9c38bf,0xe6435b4b,0xf1b90009,0xdb1c00b5}},	//   harg, _десп, kišu_, derü,
   {{0xbf0e0e6f,0x6b9cbf83,0xe7c6035d,0x0f0e0931}},	//   ान्न_, karg, र्थप, ान्स_,
   {{0x6016002d,0x60041e44,0x23890355,0x6b9c003e}},	//   _sâmb, _còmp, čují_, jarg,
   {{0x08570052,0x6d4106d0,0xb87b01ba,0xb33c003c}},	//   שבים_, ğlam, _prík, _idħo,
   {{0x6d4106d0,0x3ce9108a,0x628a0282,0xa3ae0066}},	//   şlam, _prav_, mpfo, कलक_,
   {{0x6b9cbf84,0x628a4996,0x00000000,0x00000000}},	//   farg, lpfo, --, --,
   {{0x6b9c9182,0x7f840037,0x26c100e9,0x798d011e}},	//   garg, _الغن, ytho_, wbaw,
   {{0xda78001d,0xbebc0080,0xb5fd8a3c,0x00000000}},	//   ият_, dzīg, _kišt, --,
   {{0x78adbf85,0x3ce93fd5,0xf1b90009,0x9dab02fb}},	//   trav, _trav_, bišu_, _ръка_,
   {{0x6b9c2303,0x798d1581,0x32d80023,0x9f470093}},	// [e710] barg, rbaw, _lũy_, _inná_,
   {{0x6b9c0f56,0xb5fd0187,0x78adbf86,0x798dbf87}},	//   carg, _lišt, rrav, sbaw,
   {{0x8ae402ce,0xdc3c0122,0xfc3f01dd,0x78adb2ee}},	//   _діял, _בעזר, buír_, srav,
   {{0xb5fd505f,0x9f5c0097,0x00000000,0x00000000}},	//   _ništ, _noví_, --, --,
   {{0x26c10118,0x8b6703fc,0xbb4800b5,0xdb1c02d7}},	//   stho_, _حاکم, _ملین_, beró,
   {{0x7bd5bf88,0xb87b002a,0x00000000,0x00000000}},	//   nezu, _asíg, --, --,
   {{0x9f5c0176,0xd298010b,0x20190055,0x00000000}},	//   _boví_, атыі_, ësim_, --,
   {{0x2ba700e7,0xfba7022e,0xcb3800a5,0xb5fd0ce9}},	//   कृता, कृतम, ינוק_, _pišu,
   {{0x600d01dd,0x7a33003c,0x7bd546c7,0xb5fd5d85}},	//   _húmi, għti, kezu, _dišt,
   {{0x43940183,0xaffe0019,0xdb1c00fd,0xf1b90b5e}},	//   _маус, _phướ, terü, višu_,
   {{0x2eb60f3d,0x6b9cbf89,0x5f450037,0x59a70099}},	//   _अमृत, varg, إنجل, गणार,
   {{0x78a29035,0x6b9c06d4,0xe9df0019,0xf8c7046c}},	//   šovi, warg, _thúy_, रझाय,
   {{0x3085004f,0x6b9cbf8a,0xafe51eb9,0xb4f9016b}},	//   _التف, targ, _голл, נפֿי,
   {{0xf1b9bf8b,0xaffe01a5,0xe4fa022e,0x3f790070}},	//   rišu_, _thướ, ्हति_, _גאַס,
   {{0xfc3f01dd,0x6b9cbf8c,0x600d01ef,0xe4560070}},	//   tuír_, rarg, _númi, מישט_,
   {{0x6b9c2791,0xf1b900cd,0xdb0500ac,0x00000000}},	//   sarg, pišu_, _uchý, --,
   {{0x1b200083,0xdb1cbf8d,0xfc3f01dd,0x7bd51394}},	// [e720] _মুখে_, teró, ruír_, bezu,
   {{0x3cfb0d85,0xb9000066,0xfc3f0042,0x00000000}},	//   _עלינ, _दन_, suír_, --,
   {{0x205602b5,0xdb0500e0,0x00000000,0x00000000}},	//   ציעל_, _ndhè, --, --,
   {{0xe5a30923,0x7c2ebf8e,0xceb200c2,0x05663f6e}},	//   зици, libr, ליב_, бвен,
   {{0x69d601d6,0xad9b01ef,0xdb0500a2,0x00000000}},	//   meye, ljúc, _adhè, --,
   {{0x69d601d6,0xa50703fa,0x9f5c01f7,0xa2a9021a}},	//   leye, сеља_, _soví_, _टिश्,
   {{0xb5fd0944,0x81e10083,0x00000000,0x00000000}},	//   _pišt, দান_, --, --,
   {{0x69d6bf8f,0x00000000,0x00000000,0x00000000}},	//   neye, --, --, --,
   {{0xdb0502c9,0xb5fd00c7,0x998000c7,0x7bd50f25}},	//   _schü, _višt, lnių_, yezu,
   {{0x3f98bf90,0xa20804d4,0x7c2e023a,0xf507002d}},	//   úru_, ılış_, jibr, _унул_,
   {{0x7bd502dd,0x60160370,0xb5fdbf91,0xdb1c0093}},	//   vezu, _câma, _tišt, lfræ,
   {{0x442ebf92,0x6016021d,0xdb05009e,0x6d5a0067}},	//   lif_, _dâma, _ochò, ętan,
   {{0x7bd5bf93,0xdb050118,0x00000000,0x00000000}},	//   tezu, _idhé, --, --,
   {{0xdb0500da,0x442ebf94,0x9f5e00da,0x4e9300d1}},	//   _udhë, nif_, njtë_, _کشور,
   {{0x3f9ebf95,0x9f47008c,0x49cb00af,0x00000000}},	//   matu_, _annæ_, луам_, --,
   {{0x3f9e0291,0x644a2494,0x7bd53c4d,0x600d008d}},	//   latu_, hofi, sezu, _rúmi,
   {{0x7799244d,0x61e2a5f1,0xdb1c008e,0x00000000}},	// [e730] икар_, _maol, rfrá, --,
   {{0x3f9e9a4f,0x20c2008d,0x61e25a38,0x998901ba}},	//   natu_, iði_, _laol, dnať_,
   {{0x7ac7022c,0x442ebf96,0x2d9b01f4,0xaa5919fa}},	//   _успе, dif_, _keqe_, _вину_,
   {{0x3f9ebf97,0x6aa1008a,0x6e2fb556,0xdebb0317}},	//   hatu_, álfu, nicb, רמאל,
   {{0x3f9e0291,0xcc340332,0x2d9b01f4,0x78930e3a}},	//   katu_, _ذریع, _meqe_, _ریاض,
   {{0xd7fbbf98,0x442ebf99,0xdb050248,0x644a00e9}},	//   _сум_, gif_, _adhé, gofi,
   {{0xdc3800c2,0x3f9e06a2,0x62657bff,0x61e29e97}},	//   זאגט_, datu_, овка, _baol,
   {{0x20c200fb,0x61e20874,0x80a96925,0x00000000}},	//   fði_, _caol, авив_, --,
   {{0x20c200fb,0xe7c6142a,0x61e2154d,0xd7c61371}},	//   gði_, र्वप, _daol, र्वच,
   {{0xbebc0080,0x3f9e5b67,0x442e00a2,0x644a468b}},	//   dzīb, gatu_, cif_, cofi,
   {{0x61e2026e,0x02d909b9,0xee3a2695,0x27e30478}},	//   _faol, _خواب_, ино_, _majn_,
   {{0x92b400d2,0x61e20037,0x27e30009,0x69c905e7}},	//   _رحما, _gaol, _lajn_, _हॉली,
   {{0x8fa538a6,0x3f9ebf9a,0x7c2e00f6,0x00000000}},	//   _дале, batu_, tibr, --,
   {{0xdb1c008a,0x3f9e747a,0x27e302c4,0x3f693537}},	//   ferð, catu_, _najn_, _кило_,
   {{0xdb1c00fb,0xcb6a3eba,0x69d601d6,0x2007bf9b}},	//   gerð, раве_, teye, _ioni_,
   {{0x20070291,0xe9da04bf,0x442e5235,0x3a2b009e}},	//   _honi_, јка_, zif_, _cmcp_,
   {{0xd9100a86,0xe8fa1174,0x69d62fe8,0x644a002f}},	// [e740] ریس_, шла_, reye, yofi,
   {{0x69d66251,0x998900a0,0x3b830352,0x25bf0139}},	//   seye, vnať_, _ольг, _acul_,
   {{0x2007bf9c,0x644a007e,0x69d602d0,0xe57abf9d}},	//   _moni_, vofi, peye, азе_,
   {{0x3f9e1624,0x2007bf9e,0x20c2003e,0xdce605f9}},	//   zatu_, _loni_, yði_, lakı,
   {{0x92e60083,0x27e374f0,0x9980010b,0xb0d80354}},	//   _পথে_, _fajn_, snių_, _बैंग,
   {{0x2007bf9f,0xdb1c008a,0x61e2bfa0,0xb87bbfa1}},	//   _noni_, rfræ, _saol, _prív,
   {{0x61e299e9,0xff47004f,0xe73715df,0xdb1c0093}},	//   _paol, _آخ_, _дер_, sfræ,
   {{0x9f5c1840,0x30a6bfa2,0xdd1400a0,0x3f9e2a92}},	//   _nová_, оров, pĺňa, watu_,
   {{0x3f9ebfa3,0x2007bfa4,0x644a0054,0x92bc0033}},	//   tatu_, _boni_, pofi, েটে_,
   {{0x20c2064b,0x2018008a,0x93cb006c,0x2007bfa5}},	//   rði_, óri_, _نامہ_, _coni_,
   {{0x3f9e03cb,0x61e200be,0x2007bfa6,0xb77b016b}},	//   ratu_, _taol, _doni_, יאיש,
   {{0x3f9e4388,0xdb1c008a,0x78a4bfa7,0x660202ee}},	//   satu_, verð, ksiv, njok,
   {{0x3f9e0635,0x9ccb00c7,0x3e7a00ec,0x442c0b3e}},	//   patu_, шына_, _mīti_, _kmd_,
   {{0x68fb0443,0xdfcf0037,0x2249030a,0xa3cd0096}},	//   _àudi, _ليه_, čake_, ष्प_,
   {{0x5fb70122,0x27e30200,0x799f046a,0x764b4f4a}},	//   _והוא_, _rajn_, taqw, yogy,
   {{0x7bda00f7,0x20072570,0x62860009,0x7bc800be}},	//   ôtur, _zoni_, _čkol, õdur,
   {{0x7c670eea,0x7afa013c,0x27e30009,0x6e2d0027}},	// [e750] _واخل, ättr, _pajn_, _imab,
   {{0x6aa100fb,0x79860107,0xc7f801e0,0xb8d30e61}},	//   álfs, _efkw, онує_, _टि_,
   {{0x3a2b00e2,0x81e10831,0x00000000,0x00000000}},	//   _tmcp_, দাত_, --, --,
   {{0x3f9c0478,0x442cbfa8,0xae1f22a7,0x68200282}},	//   _levu_, _amd_, मोचन_, _nödf,
   {{0x443ebfa9,0xb5fd0e31,0x25a00093,0xc4db0200}},	//   _bjt_, _dišp, ðila_, рђе_,
   {{0x442c59e5,0x764bbfaa,0x2a6900be,0x00000000}},	//   _cmd_, sogy, lmab_, --,
   {{0x659501c8,0x799d28c3,0x61c6021a,0x201e0055}},	//   _наву, _kesw, लभूष, dhti_,
   {{0xb87b0093,0x2007bfab,0x25bf01cb,0x00000000}},	//   _frít, _soni_, _ucul_, --,
   {{0x661b00be,0x68200523,0x00000000,0x00000000}},	//   _iluk, _dödf, --, --,
   {{0x6e2dbfac,0x6609bc38,0x799d021e,0x661b0097}},	//   _amab, _hoek, _lesw, _hluk,
   {{0x661bbfad,0x660954f5,0xc7b20070,0x3f9c2b69}},	//   _kluk, _koek, עבט_, _devu_,
   {{0x82370332,0x2a69006d,0x44dd0359,0x799d030d}},	//   _برطا, jmab_, _kň_, _nesw,
   {{0x317a0319,0x600d0279,0xa3df0099,0xdb1c0ef0}},	//   _האנד, _súmu, _तसा_, nerö,
   {{0x201ebfae,0x6609bfaf,0x6e2d018e,0x224dbfb0}},	//   chti_, _loek, _emab, loek_,
   {{0x661bbfb1,0xa3cd0e68,0x6b630573,0xdce6037a}},	//   _oluk, ष्य_, екра, rakı,
   {{0x78a41130,0x3ce00221,0x224d707c,0x661b030d}},	//   tsiv, _tsiv_, noek_, _nluk,
   {{0x799d01ae,0xe7aa0409,0xfbd10033,0xfc3f213c}},	// [e760] _desw, йвал_, ায়ত, grís_,
   {{0x6d566075,0x224dbfb2,0x661bbfb3,0xb90406d9}},	//   _iyya, hoek_, _aluk, _भई_,
   {{0x66091c47,0x224dbfb4,0x661b7650,0x66760105}},	//   _boek, koek_, _bluk, سدار,
   {{0xb87b01ba,0x442cbfb5,0x44dd0359,0x799d03bc}},	//   _prít, _smd_, _bň_, _gesw,
   {{0xd90d0d4f,0x01c30083,0x1dc10808,0x224dbfb6}},	//   _پیل_, ্যাদ, ष्टत, doek_,
   {{0x2bc01856,0x3fe60083,0x661b007c,0x78a20334}},	//   श्चा, _পক্ষ, _eluk, šovs,
   {{0x661b56bd,0xb87b008d,0xe2970bfe,0x3f9c000d}},	//   _fluk, _frís, пај_, _revu_,
   {{0x8cad0035,0x44dd0359,0x6b9e023a,0xb87b451f}},	//   _जिलो, _fň_, _lepg, _grís,
   {{0xdfd00514,0x0ef41e79,0x76430332,0x3a200159}},	//   نية_, इम्स_, énye, ihip_,
   {{0x660925cb,0xe0cf0bdf,0x251b0317,0x6b9e0b88}},	//   _zoek, ازي_, _הומא, _nepg,
   {{0x224d47fc,0x7e76011e,0x6d560210,0x1b0c0831}},	//   boek_, _biyp, _ayya, _হেসে_,
   {{0xf27b0052,0xa3cd0518,0x201ebfb7,0x073700a5}},	//   _הראש, ष्ठ_, shti_, לאים_,
   {{0xfc3f0b06,0x7e6400e0,0x799d016e,0x52dc0af6}},	//   esía_, _dhip, _resw, _मनुस,
   {{0x9a870a26,0x7e640c47,0x6b9e0371,0x27f802a7}},	//   зуал, _ehip, _cepg, _nnrn_,
   {{0xdb1cbfb8,0xb4a9018d,0xe457016b,0x00000000}},	//   ngrè, _खट्_, פילט_, --,
   {{0x6e2d0dc3,0x0f5700a5,0x7f3b025a,0x7e640139}},	//   _umab, _מיום_, _לעוו, _ghip,
   {{0x6609a884,0xa3e50167,0x00000000,0x00000000}},	// [e770] _roek, _बोझ_, --, --,
   {{0x224d0a75,0x6609bfb9,0x661b8b76,0xfc3f01dd}},	//   zoek_, _soek, _sluk, rrís_,
   {{0x2ca94d3e,0xb87b124b,0x6e3d4df9,0x661b38b9}},	//   _hvad_, _prís, onsb, _pluk,
   {{0x3a20bfba,0x6e3d3bd1,0x601f021d,0x80d30831}},	//   chip_, nnsb, _iême, তিত্,
   {{0x629a6f7c,0xdb1c013c,0xe8eb0037,0xc4840210}},	//   _awto, rfrå, _ارجو_, елік,
   {{0xd24e132d,0x69cd001e,0xe3b80095,0x764300b5}},	//   ینو_, lfae, _alıb_, ényb,
   {{0x68ed50a1,0x66090903,0xb87b01ef,0x321f00e2}},	//   lvad, _toek, _trís, thuy_,
   {{0x601f0248,0xf99f0359,0x661bbfbb,0x629a00ee}},	//   _même, _alèz_, _uluk, _dwto,
   {{0x25ad0523,0x224dbfbc,0x7e6400d7,0x68edbfbd}},	//   _idel_, roek_, _rhip, nvad,
   {{0x443101c2,0x6e3d5e54,0x224dbfbe,0xc87f01ae}},	//   _öz_, ensb, soek_, _muß_,
   {{0xa3cd05f7,0x28dd00dc,0x1f6500d4,0xa29400d4}},	//   ष्ण_, नौति, ьком, _захі,
   {{0xd12e07e4,0xf99f0107,0x1b0c0033,0xed5ab80f}},	//   امی_, _elèz_, _হইলে_, жом_,
   {{0x61e91781,0x00000000,0x00000000,0x00000000}},	//   mdel, --, --, --,
   {{0x61e95c1b,0x63a3bfbf,0xddcd002d,0x68ed0088}},	//   ldel, nann, _piaţ, dvad,
   {{0x60c9bfc0,0x63a30034,0x69cdaf6c,0x248d011e}},	//   ltem, iann, ffae, _ltem_,
   {{0x6d4401a9,0xdb1c671c,0xddcd0043,0x290001d7}},	//   _txia, ngré, _viaţ, txia_,
   {{0x63a383f3,0x61e9bfc1,0x6b6700f7,0x6ea11e82}},	// [e780] kann, idel, tégé, _कौतु,
   {{0x60c902e1,0xb87b016f,0x290001dd,0x63a3bfc2}},	//   item, _prír, rxia_, jann,
   {{0x63a3bfc3,0xdb0502bf,0x76590297,0x6d4101d6}},	//   dann, _schö, flwy, şlat,
   {{0x61e9bfc4,0x60c9bfc5,0x6b67006c,0x64410009}},	//   jdel, ktem, ségé, _ajli,
   {{0x61e9bfc6,0x63a3bfc7,0xfc3f0037,0xe5a33d52}},	//   ddel, fann, isín_, тичи,
   {{0x7bdcbfc8,0x63a3261b,0xb4de0006,0x61e99b50}},	//   neru, gann, _तनी_, edel,
   {{0x61e9588c,0x59e2020d,0x7bdc00af,0x321d099e}},	//   fdel, _पसार, ieru, _blwy_,
   {{0x7bdcbfc9,0x63a300e0,0xdb2500b5,0x682001ff}},	//   heru, aann, ésér, _döde,
   {{0x63a3bfca,0x301403fe,0x60c9bfcb,0x6abc0051}},	//   bann, едпр, gtem, hurf,
   {{0x22490a78,0x68205f3c,0x63a3bfcc,0x7bdc52d6}},	//   čaka_, _föde, cann, jeru,
   {{0x7bdcbfcd,0x741300d2,0x80bd0083,0xb4de07b5}},	//   deru, _جولا, ্টগ্, _तनु_,
   {{0xd3780a78,0x2005006d,0x61e9bfce,0x6e3d0009}},	//   _naći_, ajli_, cdel, unsb,
   {{0x60c902e1,0x7bdcbfcf,0xb87b002a,0x38780608}},	//   ctem, feru, _asín, _oirr_,
   {{0x201900da,0x6abc001e,0x09a70099,0x00000000}},	//   ësit_, furf, गण्य, --,
   {{0x81e10083,0xb4bb0387,0xd5a4006c,0xa2c10bad}},	//   দার_, _अम्_, _پہ_, रूप्,
   {{0x63a3bfd0,0x38780183,0x25a0008d,0x79960b88}},	//   zann, _airr_, ðill_, gbyw,
   {{0x30bc00c8,0xee3f024e,0x7bdcbfd1,0x63a3bfd2}},	// [e790] _অনুস, mný_, beru, yann,
   {{0x68ed1430,0xee3f0076,0x61e9bfd3,0x9c3800c3}},	//   rvad, lný_, zdel, _опыт_,
   {{0x68edbfd4,0x61e9bfd5,0x7bc5bfd6,0x63a3bfd7}},	//   svad, ydel, _ichu, vann,
   {{0x7ae5071f,0xee3f0076,0x60c914d0,0x94790274}},	//   _isht, nný_, ytem, пску_,
   {{0x6820017b,0x61e9bfd8,0x24f906d8,0xb87b008d}},	//   _söde, vdel, янды_, _gríp,
   {{0x63a3012f,0x61e90088,0x7ae50031,0x02c5262e}},	//   uann, wdel, _ksht, ейко,
   {{0x7bc5000e,0xee3f0187,0x61e9bfd9,0x39590282}},	//   _mchu, kný_, tdel, _hyss_,
   {{0x63a34b36,0x60c9bfda,0xee3f053d,0x7ae50054}},	//   sann, ttem, jný_, _msht,
   {{0x61e9245b,0xee3f05d3,0x7bc50187,0x7bdcbfdb}},	//   rdel, dný_, _ochu, yeru,
   {{0x60c9bfdc,0x7bdcbfdd,0x7bc5bfde,0x61e9bfdf}},	//   rtem, xeru, _nchu, sdel,
   {{0x69d00302,0x61e93f34,0xdb1c02d7,0xdbdd008d}},	//   ड्डी, pdel, sfrú, váðu,
   {{0xe7cf009a,0x7bc59ace,0x63a13e48,0x7bdcbfe0}},	//   स्तप, _achu, _heln, weru,
   {{0x9f47071f,0x6281bfe1,0x63a1bfe2,0xb23a0070}},	//   _kanë_, _hulo, _keln, _צענז,
   {{0x9f47071f,0x6281bfe3,0x6abc36a2,0x7bdc01ae}},	//   _janë_, _kulo, turf, ueru,
   {{0xee3f1840,0x63a10029,0xdbdd008a,0x7bdcbfe4}},	//   bný_, _meln, ráðu, reru,
   {{0xb87b0038,0x628116c2,0xee3f0187,0x09e3bfe5}},	//   _príp, _mulo, cný_, лосн,
   {{0x7ae5071f,0x3946bfe6,0x6d41036a,0x6e3b0122}},	// [e7a0] _esht, ços_, şlar, _מתקד,
   {{0x57e7bfe7,0x7bdc0031,0x78b603d0,0xb6080168}},	//   ндум_, qeru, rryv, _mešť,
   {{0x28ac1bc6,0x6281bfe8,0x00000000,0x00000000}},	//   _चिकि, _nulo, --, --,
   {{0x25a00514,0xb87b0d9a,0x5ab70070,0x5fcf0355}},	//   úil_, _tríp, _אלטע_, त्तल,
   {{0xb97b0122,0x69c60523,0xb6080187,0xf53900d5}},	//   _מרכז, _icke, _nešť, _peťa_,
   {{0x6281bfe9,0xee3f0187,0x93bc0139,0x63a1045c}},	//   _bulo, zný_, _amăr, _celn,
   {{0x2bd20d91,0x6281bfea,0xfbd20931,0x63a1bfeb}},	//   द्या, _culo, द्यम, _deln,
   {{0x63a1007c,0x62810dc3,0xc7af006c,0x60f802fb}},	//   _eeln, _dulo, _پڑے_, дния_,
   {{0xc05a01c8,0x62816b13,0xee3f290b,0x63a1006c}},	//   зін_, _eulo, vný_, _feln,
   {{0x63a1bfec,0x25a60159,0x9f47021e,0x49080066}},	//   _geln, laol_, _kanè_, _सपनो_,
   {{0xee3f0076,0xdd95004b,0x6281bfed,0x69c66ba8}},	//   tný_, каны, _gulo, _ocke,
   {{0x7bc5288f,0x63a1bfee,0xe7c70066,0x00000000}},	//   _schu, _zeln, _लाभप, --,
   {{0xee3f05d3,0x628101a3,0x60160132,0x7bc50223}},	//   rný_, _zulo, _lâmi, _pchu,
   {{0xee3f024e,0x7a2300ab,0x69c6bfef,0x25a600e9}},	//   sný_, _mõte, _acke, haol_,
   {{0x62810176,0xee3f024e,0x22ac00b8,0x27ff0023}},	//   _xulo, pný_, něk_, _đun_,
   {{0x9b5801e0,0x2bd2021a,0x00000000,0x00000000}},	//   хист_, द्बा, --, --,
   {{0x26d8bff0,0x9f5c01ba,0x7bc5678b,0x200ebff1}},	// [e7b0] _apro_, _novú_, _tchu, _kofi_,
   {{0xb9090722,0x7bc50657,0xc6a7446e,0x29070254}},	//   _मन_, _uchu, ерди, ćna_,
   {{0xf3ff098b,0x7ae501d2,0xd3780009,0x3ebe01e0}},	//   _đã_, _usht, _kaću_, nutt_,
   {{0x6281125e,0x63a1bff2,0x248901ef,0x00000000}},	//   _rulo, _seln, íamo_, --,
   {{0x1dd300b8,0x62814589,0x63a1bff3,0x9f470055}},	//   ध्यत, _sulo, _peln, _panë_,
   {{0x628121ea,0x293600c2,0xe3b30148,0x27ea009e}},	//   _pulo, _יארן_, ارش_, _gabn_,
   {{0x81ea0b52,0x92e80037,0x63a1025f,0x3ebe00be}},	//   মান_, فريق_, _veln, jutt_,
   {{0xdb1c008c,0x63a15aa5,0x628115a8,0x75e7010b}},	//   rfrø, _weln, _vulo, _яўге,
   {{0x9f4701f4,0xe3b33345,0x200e0107,0xd37b002d}},	//   _tanë_, _مرض_, _bofi_, _ече_,
   {{0x6281bff4,0x69df0031,0x3e7b00e1,0x200ebff5}},	//   _tulo, heqe, _rūta_, _cofi_,
   {{0x628108dd,0x00000000,0x00000000,0x00000000}},	//   _uulo, --, --, --,
   {{0xd05f00a8,0x9f47bff6,0x23742604,0x93bc0139}},	//   _əvəz, _jané_, _صالح, _umăr,
   {{0xd3780c99,0x9f470183,0x00000000,0x00000000}},	//   _daću_, _mané_, --, --,
   {{0x320f07a8,0x61ebbff7,0x3ebebff8,0x9f470118}},	//   _hogy_, _hagl, butt_, _lané_,
   {{0xfe460c8d,0xe80500c0,0xa1f902c4,0x61eb00e0}},	//   _инко, राना_, šćuš, _kagl,
   {{0x61eb23c2,0x320f0168,0x9f4500d5,0x00000000}},	//   _jagl, _jogy_, ndlí_, --,
   {{0x61ebbff9,0x0e57024b,0x00000000,0x00000000}},	// [e7c0] _magl, _בשקט_, --, --,
   {{0x61ebbffa,0xe3b800d0,0x320f00ac,0x395c00ea}},	//   _lagl, _alın_, _logy_, āvs_,
   {{0x6fd30066,0xf71900d8,0x9f470118,0x6b660043}},	//   ब्यू, ніцы_, _bané_, _шкоа,
   {{0x61eb1fd9,0xdb1cbffb,0x22ac01c0,0x6820013c}},	//   _nagl, ngrí, věk_, _döda,
   {{0x9f47031d,0x7a3b0421,0x00000000,0x00000000}},	//   _dané_, sätä, --, --,
   {{0xa7da01ca,0xa5070274,0x93bc00af,0x69c4bffc}},	//   _توسط_, теља_, _slăb, lgie,
   {{0x02a3323d,0x61ebbffd,0x2d80bffe,0x9586097c}},	//   арым, _bagl, _ogie_, _албе,
   {{0x61eb02fb,0xe3b200bf,0x78b1008a,0x9f4702d7}},	//   _cagl, _چرا_, _ákvæ, _gané_,
   {{0x61eb4f95,0xe7cf021a,0xad9b0093,0x320f00d5}},	//   _dagl, स्वप, sjúk, _dogy_,
   {{0xe8050461,0xa3ba0037,0x69df0031,0x2d800345}},	//   राया_, _زائر_, zeqe, _agie_,
   {{0x81d70b52,0x61eb03d8,0xd7bb0070,0x539b011d}},	//   ায়_, _fagl, וציר, _חיבו,
   {{0x61eb12a2,0x68e4bfff,0x93bc0395,0x3ebe903b}},	//   _gagl, kwid, _flăc, rutt_,
   {{0xdfd40409,0x22460a4e,0x69c40d35,0xe805052b}},	//   _болы, _ijok_, dgie, रामा_,
   {{0x09cb012f,0x61e001d6,0xdfd00037,0x68e4c000}},	//   ाभ्य, leml, _طيب_, dwid,
   {{0x2bd20567,0xfbd209b4,0x60c0c001,0x307b0317}},	//   द्धा, द्धम, lumm, _קאונ,
   {{0x69c4c002,0x61e0c003,0x00000000,0x00000000}},	//   ggie, neml, --, --,
   {{0x60c02172,0xaa580043,0x68e40024,0x69df0055}},	// [e7d0] numm, титу_, gwid, reqe,
   {{0x2bd21d25,0x7d5800a5,0x00000000,0x00000000}},	//   द्दा, _ביחד_, --, --,
   {{0x12bd0083,0x25ff00a1,0x9f470176,0xdcef01fb}},	//   _আন্দ, ळाली_, _pané_, macı,
   {{0x60c02889,0xe6100b82,0x61e0c004,0x28ac00ab}},	//   kumm, يشن_, jeml, _चिचि,
   {{0xe8df00e8,0xa8a40370,0x61eb00e9,0x61e07ad5}},	//   _thực_, _врск, _ragl, deml,
   {{0x61ebc005,0xe78716ed,0x78ad0533,0x60c002ee}},	//   _sagl, _шумо, msav, dumm,
   {{0x61eb12d7,0x78adc006,0x9f470176,0x00000000}},	//   _pagl, lsav, _tané_, --,
   {{0x93bc002d,0x26c108dd,0x80be0033,0x61e000fd}},	//   _plăc, muho_, ্বন্, geml,
   {{0x61eb1de4,0x03c70043,0x26c108dd,0x30750368}},	//   _vagl, _асем, luho_, луос,
   {{0x61eb41c5,0x1dc600a1,0xd02200af,0x78ad0103}},	//   _wagl, _वाहत, ймый, isav,
   {{0x61ebc007,0x6da61517,0x2ba70067,0x00000000}},	//   _tagl, лина, _औज़ा, --,
   {{0xa2d8065f,0x78adc008,0x7bd701ef,0x60c0c009}},	//   _महत्, ksav, _abxu, bumm,
   {{0x6443c00a,0x78ad1f3d,0xb87b00fd,0x00000000}},	//   onni, jsav, _csík, --,
   {{0x78ad17ad,0x225fc00b,0x81ea0033,0x00000000}},	//   dsav, lluk_, মাণ_, --,
   {{0x6443913c,0xe6d20084,0xab2a03e5,0x69c403bc}},	//   inni, _सहेज, хова_, tgie,
   {{0x69c40080,0x6e92004f,0x5fcf32ea,0x225f027d}},	//   ugie, _اليا, त्रल, nluk_,
   {{0x6e247f59,0x9f5c021e,0x6d5a0067,0x225f01ed}},	// [e7e0] _ilib, _anvè_, ętas, iluk_,
   {{0x68e4c00c,0x225f01d1,0x69c42668,0xebe60370}},	//   rwid, hluk_, sgie, _сооп,
   {{0x225fc00d,0x09b00083,0x7d0901f4,0x26c1010d}},	//   kluk_, ঙ্গা, _tërë, guho_,
   {{0x6443004e,0xa5260f9d,0x6e240069,0x68200523}},	//   enni, лмед, _jlib, _gödn,
   {{0x6e249dda,0xae5700a5,0x00000000,0x00000000}},	//   _mlib, נסנס_, --, --,
   {{0x6e240955,0x26c1c00e,0x2a6000be,0x7642c00f}},	//   _llib, buho_, llib_, snoy,
   {{0x61e0c010,0x6e24c011,0x225f0009,0xd62a0274}},	//   teml, _olib, fluk_, _зове_,
   {{0x6443c012,0x60c0c013,0x52140192,0x7afa00c3}},	//   anni, tumm, рдит, ätty,
   {{0x61e002dd,0x463b00c2,0xdcef00d0,0x60c00159}},	//   reml, _נעמע, yacı, uumm,
   {{0x6e24073a,0x60c01a45,0xb87b002a,0x44270110}},	//   _alib, rumm, _epíf, chn_,
   {{0x60c0c014,0xb33c0484,0x645ac015,0x93cb006c}},	//   summ, _ieħo, _ikti, _سالہ_,
   {{0x10a60183,0x6e24004f,0x78ad1b5b,0x9c87148a}},	//   _бидн, _clib, ysav, _nečí,
   {{0x81ea0083,0x6add021a,0x40960166,0xa3e80127}},	//   মাদ_, मब्र, _срет, _बसा_,
   {{0x6e24002d,0xa2ab0099,0xb33c0024,0x5f940036}},	//   _elib, ींच्, _jeħo, _тикт,
   {{0x501b0d85,0x6e2423ca,0xdcef027b,0x00000000}},	//   _אוגו, _flib, racı, --,
   {{0x3ce90189,0x78ad06c7,0x63aa0093,0x00000000}},	//   _tsav_, tsav, hafn, --,
   {{0x6443c016,0x7e6d011e,0x383565a7,0xe3b81d1b}},	// [e7f0] ynni, _ihap, анар, _alım_,
   {{0x201ec017,0x200c012f,0x225f0225,0x2a60034d}},	//   nkti_, njdi_, zluk_, alib_,
   {{0x78adc018,0xb87b2c0e,0x2a601fd9,0x2baa0035}},	//   ssav, _kríz, blib_, _क़ता,
   {{0x7afa054e,0xeef70d85,0x78adc019,0x45d51cba}},	//   ætte, טמבר_, psav, родс,
   {{0x2bd20517,0x7e6dc01a,0x225f0207,0x62980298}},	//   द्वा, _mhap, vluk_, epvo,
   {{0x644300c3,0x7bc70093,0xf49600fd,0xdb1c0405}},	//   unni, ngju, جپوت_, lgrá,
   {{0xa34901d3,0x56941c4d,0x645a008c,0x225fc01b}},	//   ъзка_, _гаст, _dkti, tluk_,
   {{0xe1ff05c9,0xdb1c00e4,0x5b7c016b,0x00000000}},	//   ñó_, ngrá, ערהא, --,
   {{0x225f878b,0x1b0c0083,0x765b0027,0x61450142}},	//   rluk_, _হইছে_, _ikuy, репа,
   {{0x225fc01c,0x6e24c01d,0x7e6d8c8b,0x705211cf}},	//   sluk_, _slib, _ahap, ينيا,
   {{0x4425c01e,0x43840082,0xb87b081d,0x6e2402a7}},	//   _ill_, _المق, _epíg, _plib,
   {{0x7e6d1ce3,0x3eb8063d,0x41550421,0xb33c009f}},	//   _chap, árta_, _квес, _meħl,
   {{0xa0a5081b,0x7e6d00d1,0x3a2900d1,0x765b034d}},	//   _талд, _dhap, dhap_, _mkuy,
   {{0x7bc70093,0x55760070,0x6d5f0031,0x4425008c}},	//   ggju, יערן_, _dyqa, _jll_,
   {{0xfaa61c6b,0x765b85f6,0xddc40160,0x682001ff}},	//   рабо, _okuy, _chiţ, _dödl,
   {{0xceb8004e,0x7e6d0345,0x6e24c01f,0x765b024c}},	//   rzęt_, _ghap, _ulib, _nkuy,

   {{0xfce61c1b,0x4425c020,0x2a600510,0x9f470138}},	// [e800] _топо, _oll_, rlib_, _maní_,
   {{0x7a23007c,0x4425006d,0x765b1642,0x961e23f0}},	//   _võta, _nll_, _akuy, पस्ट_,
   {{0x3bbb0122,0x93bc0160,0xddc40139,0xf99f0107}},	//   _במיד, _blăn, _ghiţ, _poèt_,
   {{0x4425c021,0x2bd20c67,0x9f5c031b,0x3a290a75}},	//   _all_, द्रा, _nový_, chap_,
   {{0x201e75e0,0x44250a8a,0x26170183,0x9f4e055c}},	//   ykti_, _bll_, _aços_, _cafê_,
   {{0x18a369d5,0x98a3c022,0x947301cb,0x765b030d}},	//   _фарм, _фире, يدوا, _ekuy,
   {{0x4425046a,0xb7db011d,0x63aa00e9,0x9f470168}},	//   _dll_, _שקלי, rafn, _baní_,
   {{0x442512c3,0x63aa008a,0x7c3c0110,0x00000000}},	//   _ell_, safn, hirr, --,
   {{0x9f470187,0x7c3c01ed,0x999907c0,0x00000000}},	//   _daní_, kirr, _ujsť_, --,
   {{0x7e6d00a5,0x201e1406,0x92d50033,0xa2be021a}},	//   _shap, ukti_, িয়ে_, _षिप्,
   {{0x201e00d8,0xb87b01ba,0x3a29011e,0x7c3c0093}},	//   rkti_, _príz, yhap_, dirr,
   {{0x443cc023,0x63a83fd5,0x00000000,0x00000000}},	//   liv_, _hedn, --, --,
   {{0x40940514,0x6288016f,0x0ca801d3,0x4425c024}},	//   _التر, _hudo, итри_, _yll_,
   {{0x64580121,0xbebc0080,0x28b70035,0x7c3c01a3}},	//   novi, dzīv, ेंसि, girr,
   {{0x63a8c025,0x7e6d0315,0x9a870f68,0x7bc7c026}},	//   _medn, _thap, ругл, rgju,
   {{0x7e6d0bec,0x64580496,0x443cc027,0x63a8c028}},	//   _uhap, hovi, hiv_, _ledn,
   {{0x443c0044,0xc4c4006c,0x7c3c5efd,0x682002b1}},	// [e810] kiv_, _تے_, birr, _tödl,
   {{0x443c0888,0x64580690,0x6e3dc029,0x3ec300b8}},	//   jiv_, jovi, lisb, _ústí_,
   {{0x76b90a80,0xcfe10083,0x62880453,0x7d1dc02a}},	//   улер_, বাচন, _nudo, lyss,
   {{0x3f7902b5,0xe805056a,0xd246036b,0xdb05006c}},	//   אָנע, राहा_, _رن_, _nehé,
   {{0x4425c02b,0x6560001e,0x6458c02c,0x24e700ed}},	//   _pll_, _cymh, fovi, рцег,
   {{0x645802dd,0x6288c02d,0xb4e70b4a,0x4425027a}},	//   govi, _budo, _बनी_, _qll_,
   {{0x9f4700b8,0x62888d0b,0x63a88d36,0x6e3dc02e}},	//   _paní_, _cudo, _dedn, kisb,
   {{0xa2d8057c,0x765b007b,0x44250069,0xddc408b7}},	//   _महर्, _ukuy, _wll_, _ohiš,
   {{0x64583e20,0x443c00ab,0x34942447,0x6560001e}},	//   bovi, biv_, _матр, _gymh,
   {{0x6458c02f,0x4425c030,0x62880009,0x76590035}},	//   covi, _ull_, _fudo, lowy,
   {{0x62882670,0xdb05006c,0x26d301a3,0x9f4e0260}},	//   _gudo, _fehé, ntxo_, _jafè_,
   {{0x81b10033,0x63a8c031,0xb87b002a,0x76590035}},	//   ঞ্জ_, _zedn, _eríx, nowy,
   {{0xee370572,0x30751761,0x7c3c7cce,0xd7c70066}},	//   сня_, _лукс, tirr, _लांच,
   {{0x6288012f,0x00000000,0x00000000,0x00000000}},	//   _yudo, --, --, --,
   {{0x81ea00c8,0xff530bb4,0xab27c032,0x4e951dbf}},	//   মার_, _بخش_, бора_, _اشتر,
   {{0xbb438490,0x443c4702,0x645802dd,0x6fd3021a}},	//   ческ, ziv_, zovi, ब्रू,
   {{0xe8fa021f,0x7659004e,0x443c02d0,0x7c3c6390}},	// [e820] ыла_, dowy, yiv_, pirr,
   {{0x443cc033,0x3a2042dc,0xf2090066,0xa2d800be}},	//   xiv_, skip_, वाड़_, _महल्,
   {{0x63a8c034,0x9f4e3433,0x443cc035,0x645801a0}},	//   _redn, _cafè_, viv_, vovi,
   {{0x63a8c036,0x452a4166,0x9f470176,0x60160279}},	//   _sedn, лжен_, _manà_, _lâmp,
   {{0x443c16f4,0x645818b0,0x98a0004e,0x7a23007c}},	//   tiv_, tovi, dzić_, _mõtl,
   {{0x9cd70122,0x6288c037,0x2bdb166b,0x9f4e0055}},	//   מונה_, _pudo, म्पा, _qafë_,
   {{0x443c04ca,0x63a8108a,0x8bf20083,0xd7060200}},	//   riv_, _vedn, ঞাপন_, _узви,
   {{0x443cc038,0x63a86161,0x7d1d4a70,0x76590067}},	//   siv_, _wedn, yyss, cowy,
   {{0x6458011c,0x9f4e02e9,0x63a802c6,0x81ea0083}},	//   povi, _zafè_, _tedn, মাল_,
   {{0x6288c039,0x6016002d,0x9f450132,0x6e3d0298}},	//   _tudo, _câmp, melê_, wisb,
   {{0x6d403651,0xe0cf0df3,0xdb1c1193,0x6e3d3bd1}},	//   úman, وزی_, ngrä, tisb,
   {{0x2bdb0d1f,0x80a301cb,0xde592327,0x7d1d00c3}},	//   म्ना, _کمون, рамі_, tyss,
   {{0x6e3d4fbb,0x463b0070,0x25d70070,0x7e930160}},	//   risb, רעכע, זוכן_, _răpe,
   {{0x6e3d0223,0x6ec00fcf,0x7d1d236a,0x76590067}},	//   sisb, _विपु, ryss, zowy,
   {{0xa3cd0d53,0x9f5c0183,0x7ff30ef2,0x27f1068f}},	//   ष्ट_, _vovó_, _رسوا, _razn_,
   {{0x99990fdd,0x6e4400c9,0x7afa008d,0x7d0900c3}},	//   ркат_, _нејз, ætta, äess,
   {{0xb4e70b4a,0xe80525de,0xb8150274,0x4815082e}},	// [e830] _बने_, राला_, одај, омас,
   {{0xfbaa0355,0x2cb401c0,0x2baa0099,0x76590035}},	//   करणम, řadí_, करणा, wowy,
   {{0x765920ef,0x7a2a00ee,0x00000000,0x00000000}},	//   towy, _sýte, --, --,
   {{0xe3b80092,0xf7700fab,0x3e7b01c8,0xdb07031d}},	//   _adı_, رال_, _būti_, nají,
   {{0x638511b9,0x7659004e,0x69dd01e0,0x9f470d9b}},	//   огла, rowy, _ibse, _maná_,
   {{0x76590035,0xe894c03a,0x3d0a012f,0x93bc0139}},	//   sowy, _харь, ामते_, _flăm,
   {{0x8c1c168d,0x2bdb04eb,0xe29901c8,0x6d4106d3}},	//   רווי, म्या, шай_, ğlay,
   {{0x6d410dac,0x00000000,0x00000000,0x00000000}},	//   şlay, --, --, --,
   {{0xdb0700b8,0x98a000cd,0x410501e0,0xa50701e0}},	//   dají, rzić_, ізов, _уявл,
   {{0x225d0118,0x2bdb09b4,0x00000000,0x00000000}},	//   _wkwk_, म्मा, --, --,
   {{0x3f6918cd,0x69cf0107,0x69c0021d,0x00000000}},	//   рино_, _occe, _ômeg, --,
   {{0x9f4701ef,0x68ef0069,0xdce4013a,0x00000000}},	//   _caná_, _oscd, _aziā, --,
   {{0x2bdb06fe,0x9f470097,0xb4e70066,0x60160395}},	//   म्भा, _daná_, _बनो_, _tâmp,
   {{0x69cf4562,0x69dd4e5b,0x224900f4,0x80dc0033}},	//   _acce, _abse, čaku_, বিশ্,
   {{0xc05800e0,0x00000000,0x00000000,0x00000000}},	//   _اشنا_, --, --, --,
   {{0x2bdb0d91,0xbebc0228,0x00000000,0x00000000}},	//   म्बा, rzīt, --, --,
   {{0xe7aa0665,0xe8f70009,0x249d0221,0x3ea700e9}},	// [e840] ивал_, олт_, jpwm_, _hwnt_,
   {{0x69cf01d3,0x6ec0035d,0x7d1b01ae,0x20130176}},	//   _ecce, _विमु, äuse, _òxid_,
   {{0x46ea1355,0x06ea002d,0x3e7b00ea,0xf9860421}},	//   рден_, рмек_, _sūti_, _мгно,
   {{0x05661c60,0xe5a31578,0x09060370,0xd49a36ed}},	//   овен, дици, _дпмн, арк_,
   {{0xe8f74b41,0x6ec0018d,0x62820fdb,0x7afe00f4}},	//   _для_, _विभु, _rioo, _hrpt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68200282,0x00000000,0x00000000,0x00000000}},	//   _nödi, --, --, --,
   {{0xb1140274,0xb33c0024,0x00000000,0x00000000}},	//   змиш, _jeħi, --, --,
   {{0xdb0700b8,0x039600af,0x628201bf,0xe9df05ee}},	//   vají, _дрея, _vioo, _sjúk_,
   {{0xf3ca0a42,0xd01a6350,0x7bde0298,0xb33c0024}},	//   _خبره_, рфи_, _nbpu, _leħi,
   {{0xe29704e7,0x00000000,0x00000000,0x00000000}},	//   _дах_, --, --, --,
   {{0xc1060312,0x629a01ed,0x7bde6cc0,0xddab0279}},	//   _وواي, _itto, _abpu, штол_,
   {{0xddcd00ee,0x00000000,0x00000000,0x00000000}},	//   _tiaž, --, --, --,
   {{0x7a23007c,0x644ac03b,0xdb07c03c,0x29050395}},	//   _võtm, nnfi, sají, _ăla_,
   {{0xb0240019,0xe80e00dc,0x644a0037,0xa3d209b4}},	//   _giườ, साना_, infi, _वान_,
   {{0xe7dd022e,0x7bde03d0,0xddeb12f4,0xe70b00f8}},	//   न्नप, _ebpu, _ضربه_, یتان_,
   {{0xfbd31e79,0x69ddc03d,0xab870043,0xa2ca720e}},	// [e850] _तापम, _vbse, _мунк, सूत्,
   {{0x629a01d3,0x644a02c4,0xe616008b,0xb8050835}},	//   _otto, jnfi, _čišč, राइम_,
   {{0x98ac0029,0x32060159,0x25af0159,0x9f4e00b5}},	//   ālās_, _onoy_, tagl_, _infó_,
   {{0x69cf0382,0x68fd0118,0x3afa016b,0xcff30033}},	//   _ucce, _trsd, _פּיע, জায়_,
   {{0x629ac03e,0x64a518d9,0xa3e70035,0x09b10033}},	//   _atto, чала, यजल_, _ছাপা,
   {{0x3e72024e,0x3206010d,0x68ed0858,0xe8df0023}},	//   máte_, _anoy_, mwad, _nhức_,
   {{0x68ed34a7,0x20090019,0x2d890009,0x3e720097}},	//   lwad, _đai_, _ogae_, láte_,
   {{0x69cdc03f,0xd4e7262e,0x7e930160,0x00000000}},	//   ngae, _мюзи, _năpa, --,
   {{0x629a773b,0x68ed00e9,0xd5fb00e2,0x3e720097}},	//   _etto, nwad, _giú, náte_,
   {{0x25ad06ba,0xe8df0028,0xb87b00b5,0xea0000e2}},	//   _heel_, _chức_, _zsír, _trầu_,
   {{0x961d0ae0,0x2ca901a2,0x25ad3d97,0x764b001e}},	//   _ziņa, _awad_, _keel_, ongy,
   {{0xfce602ce,0xfe720642,0x68edc040,0xe9df00ac}},	//   помо, عدد_, kwad, _nbú_,
   {{0x25adc041,0xc1040082,0x82340088,0x61e9c042}},	//   _meel_, _يومي, _ترلا, meel,
   {{0xeb970165,0x3e72024e,0x5eda0083,0x68ed67cb}},	//   зир_, dáte_, _বছরে, dwad,
   {{0x2007c043,0xa2c100b4,0xab2797bf,0x60c90c6f}},	//   _inni_, रंट्, пора_, luem,
   {{0x3e7b0080,0x1dc602cb,0x61e9c044,0x69cdc045}},	//   _būtu_, _वाटत, neel, ggae,
   {{0x2edb3138,0xe8ff00f6,0x60c90c6f,0x00000000}},	// [e860] _बहुत, _crû_, nuem, --,
   {{0x61e91a6a,0x69cd01ed,0x7e930395,0x00000000}},	//   heel, agae, _zăpa, --,
   {{0x61e9c046,0xdb0e0118,0x7bdc0249,0x9f4500b5}},	//   keel, kabé, mfru, felé_,
   {{0xa2ca1e82,0xd6cf16e6,0x6820013c,0x3a2b01ef}},	//   संस्, طقه_, _nödv, _glcp_,
   {{0x25ad0d26,0x61e90244,0xd5af0125,0xd46a021d}},	//   _deel_, deel, افه_, биде_,
   {{0x7bcec047,0x02a64ac3,0x961d0080,0x7bdc002d}},	//   ngbu, прим, _viņa, nfru,
   {{0x66e324c8,0x25ad0122,0xdb0e1ea3,0x320608dd}},	//   _пора, _feel_, fabé, _pnoy_,
   {{0x20070133,0x25adc048,0xddcb13a6,0xc1ea00d4}},	//   _anni_, _geel_, _žiže, ське_,
   {{0x24851ed8,0x7c3e0282,0x60c942ed,0xe8df0019}},	//   _film_, _ompr, guem, _phức_,
   {{0x6ec00808,0x2018008a,0xe366875c,0x2d895d48}},	//   _विदु, ðri_, _екзи, _sgae_,
   {{0x61e90261,0x7522006c,0x443ec049,0x442c1f8b}},	//   beel, lyoz, _imt_, _ild_,
   {{0x7c3e04bd,0x2007c04a,0x61e9555c,0x9982021e}},	//   _ampr, _enni_, ceel, _ankō_,
   {{0xe8df0028,0xdb050f56,0x443ec04b,0x22910097}},	//   _thức_, _vehí, _kmt_, _zák_,
   {{0x68fb03e6,0x717b0122,0x442c028b,0x3e7200b8}},	//   _áudi, _הנדס, _jld_, váte_,
   {{0x7e860311,0x443e027a,0x3fdb00a5,0x5fdb00a5}},	//   íspě, _mmt_, _הקוב, _החוק,
   {{0x3e720097,0x443e00ea,0x7a2a01ba,0x9f4701f7}},	//   táte_, _lmt_, _pýta, _sanç_,
   {{0x442c0122,0x6e2d067f,0x9f458337,0xa9540044}},	// [e870] _old_, _ilab, velé_, екті,
   {{0x68ed4ac8,0x25adc04c,0x442c00cc,0x7a2a0355}},	//   rwad, _seel_, _nld_, _výta,
   {{0x6e2dc04d,0x9f4501c0,0x68edc04e,0x61e9023c}},	//   _klab, telé_, swad, yeel,
   {{0x443e504a,0x1dad0456,0x442c0065,0x229100fd}},	//   _amt_, चरित, _ald_, _rák_,
   {{0x25adc04f,0x248d00c9,0x443e0095,0x61e95979}},	//   _veel_, _quem_, _bmt_, veel,
   {{0x443ec050,0x25ad55e5,0x61e901bf,0x2a697253}},	//   _cmt_, _weel_, weel, llab_,
   {{0xe3b00a9b,0x6e2dc051,0x61e9c052,0x04ff0083}},	//   اره_, _olab, teel, ্নের_,
   {{0x02dd00b1,0x442cc053,0x443ec054,0x754800b5}},	//   _महीन, _eld_, _emt_, ászá,
   {{0x49000f39,0x61e9c055,0xdb0e1432,0x248d00be}},	//   रियो_, reel, rabé, _uuem_,
   {{0x443ec056,0x61e9c057,0x442c4e5f,0x24850036}},	//   _gmt_, seel, _gld_, _uilm_,
   {{0x6e2dc058,0x661bc059,0x2a69c05a,0x61e95976}},	//   _blab, _kouk, klab_, peel,
   {{0x6443c05b,0x661b0086,0x6e2dc05c,0xe7dd057c}},	//   lini, _jouk, _clab, न्तप,
   {{0x60c967f7,0x6443009d,0x225f30bc,0xb4bb0066}},	//   quem, oini, mouk_, _आटो_,
   {{0x6443c05d,0x7afc01cc,0x3b0a0086,0x7ae5012f}},	//   nini, tvrt, оего_, _bpht,
   {{0xa3df112b,0x7bdc84fc,0x6609c05e,0x8f9a024b}},	//   ध्य_, rfru, _onek, _ויצי,
   {{0x7bdc283e,0x2a69006d,0x6443c05f,0x224d2092}},	//   sfru, glab_, hini, nnek_,
   {{0x6443c060,0x2bdb2c29,0xd94303ad,0x7e6408bd}},	// [e880] kini, म्हा, вети, _ikip,
   {{0x6443c061,0x6609c062,0x7522002f,0xdb0700b5}},	//   jini, _anek, vyoz, sajá,
   {{0x64432115,0x224d0332,0x2a69c063,0x661b02d0}},	//   dini, knek_, blab_, _bouk,
   {{0x81e20083,0xb33c003c,0x442cc064,0x6ec0112b}},	//   _ফোন_, _meħt, _sld_, _विसु,
   {{0xa3d20785,0x661b1080,0x224d00b5,0x7e7600ee}},	//   _वाद_, _douk, dnek_, _mhyp,
   {{0x6443c065,0xe3b804d4,0x6609a12e,0x224d652e}},	//   gini, _alır_, _enek, enek_,
   {{0x250800e0,0x7e6402e9,0xbddb0443,0x442c0223}},	//   _کرزی_, _okip, dièn, _vld_,
   {{0x6443b75a,0x2902245d,0x224d00b5,0x7a2a0168}},	//   aini, _krka_, gnek_, _mýto,
   {{0x6443c066,0x961d0080,0x60f700d8,0xdfd00037}},	//   bini, _ziņo, дныя_, هية_,
   {{0x3f1403fe,0x7e640054,0xbddb6346,0xdb051df9}},	//   едос, _akip, gièn, _lehá,
   {{0x3eb800f5,0x629ec067,0x6e2d00ee,0x27f8016e}},	//   ért_, ípod, _plab, _marn_,
   {{0x26c70254,0x2902c068,0xdb050fb5,0x7e76578e}},	//   šnog_, _orka_, _nehá, _chyp,
   {{0x2bd30066,0x03f10033,0x7ff35b0c,0xa2ca0f17}},	//   _तादा, চারী_, رسیا, सूर्,
   {{0xbddb0443,0xf99f0107,0x7a3100d4,0x00000000}},	//   cièn, _enèl_, _måte, --,
   {{0x7a31022a,0x2a69c069,0x2902c06a,0xb87b0079}},	//   _låte, tlab_, _arka_, _spío,
   {{0x3e560029,0xb87b2b01,0x44270200,0xbddbc06b}},	//   tāte_, _epíl, zkn_, gnèt,
   {{0x61e2c06c,0x6443a7b7,0xa9550274,0xa3c30246}},	// [e890] _mbol, yini, хваљ, ्लम_,
   {{0x661bc06d,0xc98403fa,0x27f8c06e,0x47c70083}},	//   _souk, ђути, _carn_, র্নী,
   {{0x6443c06f,0x661bc070,0x27f800e9,0x61e20496}},	//   vini, _pouk, _darn_, _obol,
   {{0x6443c071,0x2bdb0ebd,0x201cc072,0x290200cb}},	//   wini, म्रा, _lovi_, _frka_,
   {{0x6443c073,0x27f800e9,0xc9840012,0x2902011c}},	//   tini, _farn_, _аури, _grka_,
   {{0x201c5fde,0x36d51bfd,0x7640a3c2,0x6820013c}},	//   _novi_, _погр, _emmy, _döds,
   {{0x6443c074,0x224d006c,0x661b0086,0x3e720079}},	//   rini, tnek_, _touk, háta_,
   {{0x6443c075,0x6609c076,0x2d9f148e,0x68200523}},	//   sini, _unek, ñuel_, _föds,
   {{0x70850714,0x225f0a12,0x224dc077,0x25bfc078}},	//   нгиз, rouk_, rnek_, _idul_,
   {{0x7e64200b,0x6443c079,0x6ec03e6d,0x224d006c}},	//   _skip, qini, _विशु, snek_,
   {{0xfe46359e,0xbddb12c3,0xd24e04e8,0x6441b897}},	//   енно, rièn, شنی_, _imli,
   {{0xed5a219f,0x6ec00567,0x644100ee,0x00000000}},	//   зом_, _विरु, _hmli, --,
   {{0x61fbc07a,0x2d84018d,0xdb0700be,0x68320b3e}},	//   mdul, äme_, hajä, _hæde,
   {{0x61f90297,0x09ba02cb,0x60dbc07b,0x2606258f}},	//   _hawl, ेल्य, mtum, _सोनी_,
   {{0x09e601f5,0x60dbc07c,0x25a6045e,0xa3d20b35}},	//   новн, ltum, ybol_, _वास_,
   {{0x201c025c,0x321d012f,0xed5a002d,0x7e64c07d}},	//   _zovi_, _jowy_, _ной_, _ukip,
   {{0x61f9c07e,0xb87b01ef,0x6f030097,0x683208c8}},	// [e8a0] _mawl, _epím, _hrnc, _læde,
   {{0x25bf027c,0x6c34006c,0x60dbc07f,0x7d04c080}},	//   _adul_, _شہزا, itum, _iris,
   {{0x7d04c081,0x60db066e,0xdb05006c,0x23c9164f}},	//   _hris, htum, _tehá, _राजद,
   {{0x7d042cb7,0x29020759,0xa3d20299,0x321d004e}},	//   _kris, _trka_, _वाह_, _nowy_,
   {{0x25a6010d,0x27f800f7,0x61fb123f,0x00000000}},	//   rbol_, _tarn_, ddul, --,
   {{0x7d040054,0x6ec00066,0x61e20036,0x78a41402}},	//   _mris, _विलु, _sbol, mpiv,
   {{0x2bd302cb,0x61f90818,0x201c0036,0x78a40036}},	//   _तासा, _bawl, _rovi_, lpiv,
   {{0x28c73054,0x93bc002d,0x61fb2487,0x29000036}},	//   _लिमि, _alăt, gdul, ovia_,
   {{0x61f903d0,0x64c60088,0x2900c082,0x60db2268}},	//   _dawl, _سيال, nvia_, gtum,
   {{0x93bc0395,0xa3df25d8,0xa0670274,0xdfd01301}},	//   _clăt, ध्द_, нања_, جيد_,
   {{0x61fb007a,0x2ca0028b,0x6f0300cb,0x7d04c083}},	//   bdul, _atid_, _crnc, _aris,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7dc084,0x7a23007c,0xb87b00d5,0x26c50044}},	//   rmsp, _mõtt, _spím, _ålov_,
   {{0x7d044759,0x3e727d76,0x00f700a5,0x00000000}},	//   _dris, ráta_, _נמוך_, --,
   {{0x7d04a631,0x2cea083f,0x2ca002d0,0xdb5800c3}},	//   _eris, टबॉल_, _etid_, еют_,
   {{0x7d043993,0xbeec073f,0xdb0e021d,0x00000000}},	//   _fris, जबीन_, cabí, --,
   {{0x6f030e46,0x3a29c085,0x5c750de2,0x1958081b}},	// [e8b0] _zrnc, rkap_, _илит, еаты_,
   {{0x3a292434,0x6820013c,0x38780107,0x61fb00b5}},	//   skap_, _södr, _chrr_, zdul,
   {{0xdcfd036a,0x249f0523,0xc5d52659,0x8d740987}},	//   ması, _stum_, віль, _لایا,
   {{0xdcfd0644,0xd6d8010b,0x6832008c,0x00000000}},	//   lası, эту_, _ræde, --,
   {{0x3e560029,0x7d0400a8,0x98a90067,0x786b00be}},	//   nāta_, _xris, dzać_, hüvi,
   {{0xdcfd0463,0xd7f8002d,0x61f9030d,0x00000000}},	//   nası, _пус_, _sawl, --,
   {{0xdce4006a,0x61f9c086,0xb3d200a1,0xa3d20d2a}},	//   _dzię, _pawl, _सारख, _वार_,
   {{0x60dbc087,0x7afa0093,0x93bc0160,0xdcfd10b1}},	//   ttum, ætti, _slăt, hası,
   {{0x212bc088,0xdcfd0ec4,0x34951150,0x61fbc089}},	//   ách_, kası, _разр, rdul,
   {{0x60dbc08a,0x601e00b8,0x4ae20084,0x7d0495f8}},	//   rtum, _námě, _पहलव, _rris,
   {{0x34d1114e,0x6da60ebc,0x2ca000cd,0xdcfd00c1}},	//   _समुद, кина, _stid_, dası,
   {{0x270100d8,0x98a90035,0x80dc0033,0x60dbc08b}},	//   _mėn_, czać_, বিজ্, ptum,
   {{0xdcfd0448,0xee372780,0x3e560228,0x00000000}},	//   fası, тня_, gāta_, --,
   {{0x7d04c08c,0x628bc08d,0x6f03022f,0xa1360070}},	//   _vris, _higo, _trnc, _באנק_,
   {{0x5b354ca7,0x628b43e9,0x2bd3366c,0x0b590aeb}},	//   гэту, _kigo, _तारा, ерты_,
   {{0x2900c08e,0xc33202b8,0x628bc08f,0x00000000}},	//   tvia_, בול_, _jigo, --,
   {{0xf1b200c2,0x60c972ce,0x628bc090,0x59860036}},	// [e8c0] יסן_, nrem, _migo, тлаб,
   {{0x628b00d8,0x60c90248,0x290027e9,0x656f0187}},	//   _ligo, irem, rvia_, _úchy,
   {{0x99990332,0xbddb0fce,0xfaa612ea,0x93bc0139}},	//   _első_, zièm, _шано, _olăr,
   {{0x64a6c091,0x601e0355,0xfc3f0138,0x44e90183}},	//   вада, _zámě, mpía_, fº_,
   {{0x7a23007c,0xbddb0248,0x34d11cc3,0x7a2a00ac}},	//   _võtt, xièm, _समृद, _lýtk,
   {{0x07a3001d,0xfc3f0300,0xf99f00e0,0x07ba0037}},	//   _варн, opía_, _anèh_, _زهرة_,
   {{0x628bc092,0x77910a86,0x7a23007c,0xdb0501ae}},	//   _bigo, _ایما, _tõtt, _gehä,
   {{0x60f84fb2,0xf506117a,0xdcfd0463,0x5186c093}},	//   ения_, _избо, zası, купа,
   {{0xdcfd01c2,0x628b85bb,0xfbb80083,0x60c9c094}},	//   yası, _digo, _জানত, grem,
   {{0xf99f0118,0xdcfd00a8,0x98a90067,0x7a310044}},	//   _enèh_, xası, szać_, _måta,
   {{0x7a310364,0x60c9014c,0xdcfd00c1,0xf1b90228}},	//   _låta, arem, vası, ekšu_,
   {{0x63b80496,0xd36f0bdf,0xc0aa0d82,0x6e642705}},	//   lavn, _بهم_, _قاتل_, итяж,
   {{0xdcfd037a,0xdb150752,0x9d18027a,0xa2ca07df}},	//   tası, mazé, воят_, संक्,
   {{0x09cb2095,0x628b5878,0x63b803db,0x229800b5}},	//   िल्य, _zigo, navn, _kék_,
   {{0xdcfd0092,0x35d800ab,0x628b0371,0x200e00b9}},	//   rası, _डाढ़, _yigo, _infi_,
   {{0x63b801b4,0x79a40086,0x39a403e6,0x7a310533}},	//   havn, ируе, ишув, _båta,
   {{0x25fd11b5,0xa3d28833,0x49750572,0x63b803c9}},	// [e8d0] _रोगी_, वला_, улас, kavn,
   {{0x63b802c6,0x38341b70,0xdcfd00a8,0xc6a70fb4}},	//   javn, анур, qası, врди,
   {{0x63b80496,0xdb05013c,0x998001f2,0xad2703fc}},	//   davn, _behå, rkiš_, _سرکو,
   {{0xdb0701ba,0x7a2300ab,0x80b80033,0x60c9c095}},	//   kajú, _võts, _আমন্, yrem,
   {{0xc9870fb4,0x7a310523,0x00000000,0x00000000}},	//   _јуни, _gåta, --, --,
   {{0x60c901cc,0x628b01d6,0xf77302fd,0xdb0700a0}},	//   vrem, _sigo, _ناز_, dajú,
   {{0xe1f10037,0x8c1c00a5,0xa2ca065f,0x00000000}},	//   مسة_, ווגי, संग्, --,
   {{0xc1b9004f,0x628b0d92,0x60c9a501,0x28c8021a}},	//   رابط_, _qigo, trem, िंचि,
   {{0x63b82676,0x60c93253,0x628bc096,0x3114010b}},	//   bavn, urem, _vigo, афэс,
   {{0x60c90505,0xa2ca131c,0xef1907c7,0xa3ba020c}},	//   rrem, संख्, емо_, _अजय_,
   {{0xd371183b,0xe7f6004e,0x628bc097,0x5f450037}},	//   _اها_, ीयता_, _tigo, انجل,
   {{0xe80a004e,0x23df0d00,0x60c956fa,0xdca60a80}},	//   _होना_, प्रद, prem, лами,
   {{0xf1b917ee,0xb4f90070,0xafe502ee,0xdb1c02b1}},	//   maš_, עפֿי, _болл, sgrü,
   {{0xd0400095,0x557602b5,0xf1b90693,0x9f0500d1}},	//   kumə, טערן_, laš_, _موتو,
   {{0xf8bf00f6,0x00000000,0x00000000,0x00000000}},	//   _avé_, --, --, --,
   {{0xf1b90169,0x63b81942,0x7a317808,0x9f4500d5}},	//   naš_, zavn, _påta, celá_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [e8e0] --, --, --, --,
   {{0xe73a464d,0xe8f706d8,0xb8ec00be,0x7a2a00ac}},	//   нез_, ылу_, _रट_, _mýti,
   {{0xf1b90881,0xa3ba0534,0xdb0701ba,0x3e560228}},	//   kaš_, _अजब_, zajú, nāto_,
   {{0xf1b902dd,0x7afa008d,0x93bc0139,0x7e930395}},	//   jaš_, ættu, _alăp, _căpi,
   {{0x63b8552b,0xf1b91635,0xa3b400d8,0x7a2a0093}},	//   tavn, daš_, аблі, _nýti,
   {{0x7c2e32c5,0xdb0701ba,0x320f0160,0x00000000}},	//   nkbr, vajú, _angy_, --,
   {{0x63b802dd,0x68f6001e,0x53342374,0x2d920103}},	//   ravn, lwyd, рейт, _ogye_,
   {{0xf1b918b0,0x69d6c098,0xf75301b2,0x248c0051}},	//   gaš_, ngye, _انفج, _widm_,
   {{0x25fd1163,0x261100a1,0xb0346c06,0x68f600e9}},	//   _रोटी_, णारी_, иниш, nwyd,
   {{0x41a400c4,0xf1a41bc6,0xdb0e00b5,0xdb0701ba}},	//   _ग्रस, _ग्रन, zabá, rajú,
   {{0x33930082,0xf1b92676,0x81e90083,0x74130037}},	//   _المز, baš_, ময়_, _دولا,
   {{0xbd6b2519,0x2cb2001e,0xf1b9003d,0xdd910037}},	//   ерге_, _bwyd_, caš_, توح_,
   {{0x7a310282,0x2cb20090,0x00000000,0x00000000}},	//   _båtn, _cwyd_, --, --,
   {{0x961d0029,0x9f5c01f4,0x2d929208,0x68f6016e}},	//   _viņi, _javë_, _egye_, dwyd,
   {{0xf8bf000c,0xdb0e2905,0x28c700a1,0xc90d000c}},	//   _své_, tabá, _लिहि, सम्म_,
   {{0x2cb200e9,0x69d68c98,0x2d92001c,0xf9930037}},	//   _fwyd_, ggye, _ggye_, صبر_,
   {{0x68f60297,0x644ac099,0x57b50328,0x7e930395}},	// [e8f0] gwyd, kifi, ибат, _răpi,
   {{0x25fd00a1,0x683201b4,0x644ac09a,0x57b400d4}},	//   _रोजी_, _pæda, jifi, йбут,
   {{0x81cc0083,0xf1b902c6,0xc6a72746,0x7bc50031}},	//   শ্য_, ljše_, урзи, _idhu,
   {{0xdb1c0392,0x00000000,0x00000000,0x00000000}},	//   pgrò, --, --, --,
   {{0xf1b90627,0xb87b01dd,0x9982021e,0x644a4354}},	//   vaš_, _osíx, _ankņ_, fifi,
   {{0xd90e0332,0x2246c09b,0x644ac09c,0xf794010b}},	//   _کیے_, _amok_, gifi, _гарэ,
   {{0xf1b9264f,0x7bc5034d,0x00000000,0x00000000}},	//   taš_, _mdhu, --, --,
   {{0x22461bfa,0xe813193c,0x00000000,0x00000000}},	//   _cmok_, ठावा_, --, --,
   {{0xf1b93384,0x2055c09d,0x9f470097,0x644a01d5}},	//   raš_, итор, _daný_, bifi,
   {{0x644a716f,0x764b03be,0x09b20461,0x998900a0}},	//   cifi, ligy, _ज़्य, chať_,
   {{0xf1b90169,0xef16002d,0x2bdc25fe,0xdee5027a}},	//   paš_, амэ_, _बाबा, шони,
   {{0x7bc5c09e,0x81cc0083,0xb87b01ef,0x68f600e9}},	//   _adhu, শ্ব_, _esíx, ywyd,
   {{0x9f4c02fb,0xc10505f5,0x6aa5c09f,0x00000000}},	//   ledì_, _خوشي, _athf, --,
   {{0x69cbc0a0,0x913a0070,0xb87b0355,0x4fa536eb}},	//   ógen, _בענק, _zpív, _тикв,
   {{0xae1e0299,0x9f4c02fb,0x290f022a,0x7ae3013c}},	//   _बचपन_, nedì_, ågan_, _äntl,
   {{0xc33202b8,0x644ac0a1,0x7bc50118,0x26d3002a}},	//   קון_, zifi, _edhu, duxo_,
   {{0x87ba0086,0xada90037,0xe8fa0382,0x00000000}},	// [e900] вует_, _صديق_, ъла_, --,
   {{0x68f65d0f,0x644a3c2e,0x6e240037,0x00000000}},	//   rwyd, xifi, _hoib, --,
   {{0x103602b5,0x68f600e9,0x6fd805e7,0x5fdd29ce}},	//   סטעם_, swyd, _मासू, _मानल,
   {{0x81ab0033,0x25a001a6,0x7a38c0a2,0xe4a60f68}},	//   কৃত_, ùil_, _bíte, арко,
   {{0x644a5c25,0x25a90831,0xb90300d8,0xb4c20066}},	//   tifi, ñala_, _дзяк, ्ढे_,
   {{0x0ec51e79,0xf2c601ee,0x26d301dd,0x9f5c02d0}},	//   _विंड, асин, buxo_, _favè_,
   {{0x15e70026,0x764b00a7,0xdb1e05ed,0x00000000}},	//   _टॉवर_, bigy, _odpí, --,
   {{0xe80ac0a3,0x75d61301,0xa3d2021a,0x6e240098}},	//   _होता_, _خيرا, _वाक_, _noib,
   {{0x1da70632,0xd010004f,0x100a004f,0x64a367a0}},	//   _क्षत, كلة_, نتدى_, _мата,
   {{0x66005ff2,0x91a6004e,0x44e0027a,0x6602c0a4}},	//   _hamk, _ट्रै, mò_, ldok,
   {{0x645a0d9f,0x44e20019,0x44e007e5,0x6448009f}},	//   _ijti, _hư_, lò_, _imdi,
   {{0x6602c0a5,0x6e24c0a6,0x5186061c,0x3e720037}},	//   ndok, _coib, _кула, náth_,
   {{0x44e01fc7,0x660039c0,0x6e24239a,0xa3ba021a}},	//   nò_, _mamk, _doib, _अजा_,
   {{0x78a906d3,0x80a301cb,0x9f4701f7,0x6600c0a7}},	//   _çevi, _بمون, _canó_, _lamk,
   {{0x78a60093,0x8ff7006c,0x6e36787d,0xdddd004e}},	//   _atkv, _ضرور_, _flyb, rosł,
   {{0xbdb50836,0x0dcb2374,0x5a34182f,0x6e24c0a8}},	//   _убиј, _руки_, онст, _goib,
   {{0x5fdd1db6,0x7e6dc0a9,0x9f47021e,0x64481e54}},	// [e910] _मामल, _ikap, _abnè_, _omdi,
   {{0x9f470831,0xe8df0023,0xf99f0260,0xa814039e}},	//   _ganó_, _nhục_, _anèt_, одуш,
   {{0xfbdc0429,0xf7700a72,0xda670c74,0x7e6d0793}},	//   _बातम, وام_, _ناحي, _kkap,
   {{0x9f4c02fb,0x60c20254,0x66020008,0x645a023a}},	//   vedì_, _ovom, gdok, _ajti,
   {{0x44e20028,0xa3d20099,0x7e6d0054,0x6600c0aa}},	//   _cư_, वलं_, _mkap, _damk,
   {{0x26d30391,0x44e20019,0xe8df0019,0xdb050c71}},	//   puxo_, _dư_, _chục_, _behø,
   {{0x7a2a024e,0xd24e0118,0x97250e3a,0x66000c6f}},	//   _výtv, کني_, _افزو, _famk,
   {{0xe1f92399,0x7e6d010d,0x7c2517f0,0x7a380300}},	//   уги_, _nkap, _lohr, _títe,
   {{0x7649bd60,0x44e0027a,0x7e930139,0xe5340421}},	//   _imey, cò_, _lăpt, _деть,
   {{0x7e6d6020,0x6600c0ab,0x60c2125d,0x12e701e0}},	//   _akap, _zamk, _dvom, _відг,
   {{0x6e240082,0x4425c0ac,0xfeb900d1,0x60c20160}},	//   _poib, _iol_, داخت_, _evom,
   {{0x4425c0ad,0xdb150076,0xa3ab0026,0x201e0031}},	//   _hol_, gazí, _क्त_, ajti_,
   {{0x4425c0ae,0x224dc0af,0x7c25033b,0x2bdc0380}},	//   _kol_, miek_, _bohr, _बादा,
   {{0x224dc0b0,0x9f4502ee,0xdd9900a0,0x09e50033}},	//   liek_, telä_, ľňa_, _পোলা,
   {{0x09a900c8,0x8c432a34,0x9f95007c,0x7c25ac67}},	//   _ওয়া, чере, _müük_, _dohr,
   {{0x4425984d,0x224dc0b1,0x9f450282,0x7a2a008d}},	//   _lol_, niek_, relä_, _nýtt,
   {{0x19b901c8,0x6600c0b2,0x7c250282,0x57ea005f}},	// [e920] русь_, _ramk, _fohr, лдам_,
   {{0x660000fb,0x44e07bb8,0x4425c0b3,0x80cf6882}},	//   _samk, vò_, _nol_, _दिने,
   {{0x44e201a5,0x66022aab,0xdce400cd,0x224dc0b4}},	//   _sư_, tdok, _iziđ, kiek_,
   {{0x05ba0642,0x44e007e5,0x3f7a0070,0x7c2500a0}},	//   ادات_, tò_, אָדע, _zohr,
   {{0x4425c0b5,0x6fd81163,0xe8df0028,0x224dc0b6}},	//   _bol_, _मालू, _phục_, diek_,
   {{0x4425c0b7,0x68e404ca,0x44e002fb,0xa5c6004e}},	//   _col_, mtid, rò_, dróż,
   {{0xc5ed0b52,0x68e46d0a,0x4425c0b8,0x60c20254}},	//   ওয়া_, ltid, _dol_, _svom,
   {{0x44e200e8,0x4425574b,0x644d00f7,0x224d1c4a}},	//   _tư_, _eol_, éair, giek_,
   {{0x55540332,0x4425c0b9,0xdced044d,0xa507bc16}},	//   _بھار, _fol_, _izać, _лета_,
   {{0x7e6d0343,0xa3d204eb,0x68e41fbd,0xd49100e2}},	//   _skap, _वाट_, itid, _gì_,
   {{0xb4e805dc,0xc7b30122,0x68e400ab,0x2d9e00b8}},	//   _बहु_, הבת_, htid, ěten_,
   {{0x90e600bf,0x224d458c,0x68e4007c,0x60c200cb}},	//   _هستن, ciek_, ktid, _tvom,
   {{0x7c251075,0x44250092,0x412a02ce,0x626500ad}},	//   _pohr, _yol_, _щодо_, _بالق,
   {{0x629a225e,0x1ddb009a,0x80a400bf,0xe81c00c0}},	//   _kuto, _भावत, _همچن, नाफा_,
   {{0x4ea6034b,0x290702d4,0x63bac0ba,0x290b41d3}},	//   _урла, ānam_, _metn, _srca_,
   {{0x63ba184e,0xb4e80084,0x629a8c31,0x0f5700a5}},	//   _letn, _बहू_, _muto, _ליום_,
   {{0x68e401bc,0x7c25c0bb,0x629e0097,0xf1b9008b}},	// [e930] gtid, _tohr, ípoj, njša_,
   {{0x629ac0bc,0x224dc0bd,0x63bac0be,0x26c72ba3}},	//   _outo, ziek_, _netn, šnom_,
   {{0x2baf035d,0x7d0d15d7,0x68e453e6,0x629a1bb9}},	//   _ज्या, _hras, atid, _nuto,
   {{0x26c1013a,0x00000000,0x00000000,0x00000000}},	//   rsho_, --, --, --,
   {{0x4425c0bf,0x68e4301c,0x224d01ba,0x290b0171}},	//   _pol_, ctid, viek_, _urca_,
   {{0xdb1c01ae,0x442500a8,0x78ad270c,0x224d0035}},	//   rgrö, _qol_, mpav, wiek_,
   {{0x224d89c0,0xdb1cc0c0,0x44257a0e,0xf77315f8}},	//   tiek_, varë, _vol_, _راس_,
   {{0x4425c0c1,0x7d0dc0c2,0x00c9021d,0xd7d92b22}},	//   _wol_, _oras, алик_, _ढाँच,
   {{0xdb1c01d2,0x224d0291,0xa3d20026,0x5455029f}},	//   tarë, riek_, _वाच_, _дват,
   {{0x44250370,0x224dc0c3,0x629a80c1,0x63ba73e0}},	//   _uol_, siek_, _futo, _getn,
   {{0x7d0dc0c4,0xfbd30026,0x629a3295,0xdb1e00ac}},	//   _aras, _ताजम, _guto, _odpá,
   {{0x7d0d051b,0x765902c7,0x68e40185,0xbddb01f7}},	//   _bras, nnwy, ytid, diès,
   {{0x1ddb32b1,0x61e9c0c5,0xe81c09b1,0x3e560029}},	//   _भारत, mfel, नामा_, nāti_,
   {{0x7d0d8530,0x61e90044,0xdb0d0187,0xdd06013b}},	//   _dras, lfel, _škál, çqın,
   {{0x7d0dc0c6,0x26c70254,0x0eb9081b,0x61e90036}},	//   _eras, šnoj_, _тулы_, ofel,
   {{0x68e4c0c7,0x394058bd,0xa3ab0026,0xdb170183}},	//   ttid, tzis_, _क्स_, _xexé,
   {{0x602500b8,0xa3b9c0c8,0xb4e80722,0x7a382f07}},	// [e940] _témě, चरा_, _बहे_, _cíta,
   {{0x394000af,0x3e560228,0x00000000,0x00000000}},	//   rzis_, dāti_, --, --,
   {{0xbddb1010,0x7659001e,0x63ba0909,0x29090421}},	//   mièr, fnwy, _retn, avaa_,
   {{0xac970ef5,0xbddb02e1,0x7bdc721c,0x94aa191f}},	//   _دنیا_, lièr, lgru, атка_,
   {{0x63ba15d7,0x629ac0c9,0x61e9c0ca,0xdb17002a}},	//   _petn, _suto, dfel, _rexé,
   {{0x48f900c2,0x629a2c26,0xbddb02e1,0x02a62682}},	//   _פּרא, _puto, nièr, орим,
   {{0x64580523,0xb33c0069,0x7a310523,0x3e72c0cb}},	//   rnvi, _jeħx, _båth, látu_,
   {{0x61e90332,0x4444006c,0x2005027e,0xdb0500d5}},	//   gfel, _کررہ, edli_, _nehý,
   {{0x320201ba,0x7bdcc0cc,0x3e72031d,0x00000000}},	//   ľky_, kgru, nátu_, --,
   {{0x32020076,0x8f0a002d,0x7d0d0055,0x12c80033}},	//   žky_, ахма_, _rras, _শহীদ,
   {{0x91e61f62,0x2ca91ead,0x7bdc47ff,0x629a08dd}},	//   _може, _stad_, dgru, _uuto,
   {{0x7d0dc0cd,0x98b2004e,0x78ad081b,0xe81100b4}},	//   _pras, czyć_, ypav, _डोना_,
   {{0x7bdc01ae,0x5c074406,0x7d0d7b11,0x00000000}},	//   fgru, оява, _qras, --,
   {{0xe80ac0ce,0x7d0d00da,0x26c70038,0x7bdcc0cf}},	//   _होला_, _vras, ánok_, ggru,
   {{0x628201a9,0x2bdc035d,0x0dcb3fae,0x765900e9}},	//   _khoo, _बारा, _купи_, ynwy,
   {{0x7d0d3945,0x9f5c0168,0x999902fb,0x00000000}},	//   _tras, _javí_, скат_, --,
   {{0x7d0dc0d0,0x7bdc002a,0xc4c4006c,0x3e7200d5}},	// [e950] _uras, bgru, _جے_, gátu_,
   {{0x1ddb0066,0xbddb000d,0x6282c0d1,0x7b0805ee}},	//   _भाँत, cièr, _lhoo, ðstí,
   {{0x78adc0d2,0xdb15016f,0xf77000b5,0x56950086}},	//   spav, bazá, پال_, чает,
   {{0xfad60122,0x3e560029,0x3b010069,0xdb1501ef}},	//   _צורך_, tāti_, _ishq_, cazá,
   {{0x03a555e2,0x060800d8,0xa5099415,0x7659016e}},	//   пило, ўнік_, села_, rnwy,
   {{0xe29905d8,0x03a50eb1,0x3e5600ea,0x96d300b4}},	//   бак_, чико, rāti_, _डिपॉ,
   {{0x61e9c0d3,0x68f906d3,0x9f5c0187,0xf48500b5}},	//   tfel, şadı, _baví_, _ہائی,
   {{0x62820122,0xa3ab074f,0xbddb000d,0x00000000}},	//   _choo, _क्र_, zièr, --,
   {{0xc3cb0041,0x2bdc1119,0x61e9c0d4,0x98b20035}},	//   _نظام_, _बाला, rfel, rzyć_,
   {{0x61e9c0d5,0x98b20035,0xdb0e58ae,0x2d9e0355}},	//   sfel, szyć_, rabú, ětem_,
   {{0xfd4d0028,0x61e9c0d6,0xbddb00f7,0x25a00bc6}},	//   _triệ, pfel, vièr, žile_,
   {{0x2003765d,0x6282009e,0xe1f00079,0x24490067}},	//   žji_, _ghoo, _لسه_, dźmi_,
   {{0xbddb02e1,0xc19a0122,0xdb15006c,0x7bdc36a2}},	//   tièr, _השני, vazá, tgru,
   {{0xb068036b,0x2bdc00a1,0xc00401e0,0x00000000}},	//   _وصول_, _बाळा, _опік, --,
   {{0x7bdc1949,0xbddb0248,0xdb8300af,0x68330225}},	//   rgru, rièr, егри, _mıdı,
   {{0xee3f024e,0x7bdc2172,0x28c713ab,0xbddb488c}},	//   chý_, sgru, _लिखि, sièr,
   {{0xdb1507a6,0x394600d8,0xbddb000d,0x00000000}},	// [e960] razá, чнаг, pièr, --,
   {{0x3e720076,0xb8650841,0xb7da00bc,0xa8030bfe}},	//   rátu_, والو, صوصا_, нзул,
   {{0xa9a66f47,0x04040083,0x998933ee,0xbf7900cc}},	//   _нинд, লামী_, rkaš_, _đuốc_,
   {{0x6aa31111,0x63820079,0xd5fb055c,0x00000000}},	//   _énfa, _líní, _chù, --,
   {{0x62820d24,0x00000000,0x00000000,0x00000000}},	//   _rhoo, --, --, --,
   {{0x29020159,0x0443c0d7,0xd49901e0,0x62829f76}},	//   _iska_, нечн, ірі_, _shoo,
   {{0x62820189,0x78a906d0,0xb0240023,0x45d600af}},	//   _phoo, _çevr, _nhườ, _нцат,
   {{0x75840416,0x628901ef,0x00000000,0x00000000}},	//   _قیام, gmeo, --, --,
   {{0x3e560029,0x26dac0d8,0x7a38007e,0x00000000}},	//   nātu_, lupo_, _líto, --,
   {{0xdefa037c,0x73e30200,0x00000000,0x00000000}},	//   бым_, _поуз, --, --,
   {{0x62820189,0x5fdd0914,0x2d800223,0x26110099}},	//   _thoo, _मारल, _azie_, णाची_,
   {{0xc1e30e1d,0xd37b0070,0x290200ab,0x31790035}},	//   _गायब_, _פראט, _oska_, ższa_,
   {{0xa3c202cb,0x94050095,0x290202c4,0xe2450698}},	//   _्या_, _ailə_, _nska_, _تخلي,
   {{0x25a6028b,0x26da010d,0x3e560228,0x7a38007e}},	//   hcol_, kupo_, dātu_, _bíto,
   {{0x7b642f44,0x7a38c0d9,0x59e1021a,0x00000000}},	//   етте, _vítn, _फादर, --,
   {{0xdb1e0345,0x00000000,0x00000000,0x00000000}},	//   _kepê, --, --, --,
   {{0x3206067f,0x61e20069,0x3e72003e,0x290f008d}},	// [e970] _maoy_, _mcol, rátt_, íga_,
   {{0xb60600f4,0x80cf0099,0xed58024b,0x00000000}},	//   _lešć, _दिसे, _מבחר_, --,
   {{0xf1dc0429,0xfbd202b8,0x26c701c0,0x48f9051d}},	//   _यांन, _בתי_, éno_, _उनको_,
   {{0xb8d30b52,0xcf9302b5,0x55550d4f,0x00000000}},	//   _টি_, גטע_, وپار, --,
   {{0xe53400d4,0xd5fb0023,0x28c70066,0x3a2b0107}},	//   нець, _chú, _लिटि, _iocp_,
   {{0x61e2c0da,0x7a38008e,0xdb1701dd,0x3e48006c}},	//   _acol, _lítl, _lexí, lőtt_,
   {{0x753c0095,0x26da027a,0xb6060124,0xdb050312}},	//   _ərzi, cupo_, _bešć, _bfhé,
   {{0x394d064b,0xfbe30083,0x80a901e0,0x63820098}},	//   _þess_, য়িত, овив_, _síní,
   {{0x7fd500ef,0x6289c0db,0xa4d400d4,0x00000000}},	//   міні, rmeo, _поті, --,
   {{0xb02401a5,0x25bf0bf7,0x6832008c,0x602501e0}},	//   _phườ, _heul_, _pædi, єдна,
   {{0xfbe30083,0x90e4026b,0x73c401b2,0x249f0027}},	//   য়াত, وسین, _سينم, _huum_,
   {{0x200b1ea2,0x7bc1008d,0x61e20079,0x249f00be}},	//   ści_, ðlun, _gcol, _kuum_,
   {{0x61fb14cc,0x4129002d,0x37d50831,0x9405013b}},	//   meul, _фоло_, স্যর, _silə_,
   {{0xb0240028,0x61fb14fa,0x8c95b516,0x26da08c7}},	//   _thườ, leul, ерсі, yupo_,
   {{0xeb9711d0,0x09e601e0,0x60db4466,0x9f5c0310}},	//   дир_, мовн, luum, _gavà_,
   {{0xed5a0733,0x20074144,0x7a38978f,0x3e5600ea}},	//   _мой_, _hani_, _víto, tātu_,
   {{0xdb1cc0dc,0x2007bdb1,0x2baf111a,0xddd600d5}},	// [e980] marí, _kani_, _ज्वा, _chyť,
   {{0x7d04c0dd,0x7a3812c3,0xdb1cc0de,0x61fbc0df}},	//   _isis, _títo, larí, heul,
   {{0x8c1b012b,0x2007c0e0,0x49ba0206,0x2ca00120}},	//   _וויי, _mani_, _واحد_, _huid_,
   {{0x60dbc0e1,0x2ca00006,0xdb1c956a,0x2007c0e2}},	//   kuum, _kuid_, narí, _lani_,
   {{0x6e3d00da,0x61fb3b7c,0x290200f4,0x4aa40067}},	//   ërbi, deul, _uska_, _खंडव,
   {{0x2ca0c0e3,0x2007000e,0x25a6c0e4,0x69c4822d}},	//   _muid_, _nani_, scol_, laie,
   {{0x4e0e3893,0xae0e5da7,0x38a4013c,0x3e560029}},	//   ियाई_, ियान_, _hör_, nāts_,
   {{0x38a43be8,0x20076001,0xdb1c00de,0x69c4c0e5}},	//   _kör_, _aani_, jarí, naie,
   {{0x2007a85b,0xdb1cc0e6,0xd1300312,0xb6060009}},	//   _bani_, darí, امخ_, _vešć,
   {{0xdfd00ad9,0x2007c0e7,0x69c4c0e8,0x99820107}},	//   ديد_, _cani_, haie, _nakō_,
   {{0x20071269,0x2c2200e7,0x443e621c,0x61fb0211}},	//   _dani_, मानं_, _ilt_, beul,
   {{0x442c0076,0xdb1cc0e6,0x2ca00e0b,0x9980010b}},	//   _hod_, garí, _buid_, nkių_,
   {{0x442c95a0,0x2ca01093,0x7a312895,0xad9b0037}},	//   _kod_, _cuid_, _mått, ndúi,
   {{0x20070657,0x205600d4,0x2ca0616d,0xdb1e0118}},	//   _gani_, _ютер, _duid_, _kepè,
   {{0x442cc0e9,0xc1080028,0x7d0401d3,0xdb1cb405}},	//   _mod_, _hỗ_, _esis, barí,
   {{0x442cc0ea,0x38a4022a,0x7c3e0523,0xdb1c7b06}},	//   _lod_, _bör_, _elpr, carí,
   {{0x2007c0eb,0x2ca00159,0x76423187,0x443e2122}},	// [e990] _yani_, _guid_, dhoy, _olt_,
   {{0xe6100ef5,0x25bf02e1,0x38a401ff,0x61fb00af}},	//   یشن_, _seul_, _dör_, zeul,
   {{0x249f0107,0x2ca00120,0xc1080019,0x69c40065}},	//   _suum_, _zuid_, _lỗ_, baie,
   {{0x38a41304,0x80cf00a1,0x764200d7,0x442c0312}},	//   _för_, _दिले, ghoy, _aod_,
   {{0x442c02c7,0x38a4c0ec,0x6e2d043d,0x443e8492}},	//   _bod_, _gör_, _moab, _blt_,
   {{0xd378006a,0x442c890b,0xdb1c2b83,0x6385658d}},	//   _być_, _cod_, zarí, нгла,
   {{0x442cc0ed,0x61fbc0ee,0xe81c020d,0xdb1c03e6}},	//   _dod_, teul, नारा_, marã,
   {{0x20071315,0x60db391f,0x249fc0ef,0xdb1e0310}},	//   _sani_, tuum, _tuum_, _depè,
   {{0x442c02c7,0x2c0f012f,0xdb1cc0f0,0x2007c0f1}},	//   _fod_, ायां_, varí, _pani_,
   {{0x442cc0f2,0x60db7b7c,0x200720e2,0xc1080023}},	//   _god_, ruum, _qani_, _dỗ_,
   {{0x44e939ec,0x2ca00626,0x2007c0f3,0xdb1cc0f4}},	//   lú_, _suid_, _vani_, tarí,
   {{0x200700d1,0xa3ab0f8a,0x2bb81f4c,0x799d0479}},	//   _wani_, कुर_, अर्थ, _ngsw,
   {{0x200701d2,0x2ca0123d,0xdb1cbffb,0x442c5611}},	//   _tani_, _quid_, rarí, _yod_,
   {{0xdb1c0b4c,0x69cfc0f5,0x38a4013c,0x660900ab}},	//   sarí, _adce, _rör_, _laek,
   {{0xe80a006a,0x6d46006a,0x60c9c0f6,0x22910009}},	//   _होगा_, szka, lsem, _aški_,
   {{0x7d04c0f7,0xdb26006c,0xdd92006c,0x2bdc0026}},	//   _tsis, _épít, _یوں_, _बाका,
   {{0x7c9643af,0xd9431129,0x69c4c0f8,0x44e90038}},	// [e9a0] _проц, гети, raie, jú_,
   {{0x44e939ec,0x60c9c0f9,0x1aff0083,0x69c4c0fa}},	//   dú_, isem, _উপরে_, saie,
   {{0x6443c0fb,0x660900d7,0x442c024b,0x69c4c0fc}},	//   dhni, _baek, _rod_, paie,
   {{0x442c003c,0xdb1ec0fd,0x66760e3a,0x60c9c0fe}},	//   _sod_, _repè, ردار, ksem,
   {{0x442cc0ff,0xdb1c0a4f,0xd25000f8,0x00000000}},	//   _pod_, barã, ینت_, --,
   {{0xa3ab0bc1,0x442c006d,0xa2a40378,0x6443c100}},	//   कुल_, _qod_, _चंद्, ghni,
   {{0x81e900c8,0x442caf09,0x7e640176,0x6299289e}},	//   য়ন_, _vod_, _ojip, _biwo,
   {{0x442701e9,0x998901ba,0x442c165a,0x877b0070}},	//   ajn_, skať_, _wod_, _זאלי,
   {{0xe213004f,0x442cc101,0xdb1e0176,0x60f700d8}},	//   طبيع, _tod_, _depé, еныя_,
   {{0x64a30812,0x63b3024e,0x442c010d,0x6e2d002a}},	//   _сафа, čení, _uod_, _soab,
   {{0x60c918af,0x085700a5,0x00000000,0x00000000}},	//   asem, תבים_, --, --,
   {{0x11e90ad9,0x62990103,0x7a38007e,0x00000000}},	//   _يعني_, _giwo, _dítk, --,
   {{0xe0d402b5,0x7e640107,0x0cab0382,0x6e2d01ef}},	//   _סײַ_, _djip, ятни_, _voab,
   {{0x7e640359,0xb3e00067,0x00000000,0x00000000}},	//   _ejip, नलिख, --, --,
   {{0xdb1c61cb,0x3e64027d,0x44e90138,0x9b681a55}},	//   varã, sıta_, zú_, ешта_,
   {{0xa8a70086,0xdb050282,0x00000000,0x00000000}},	//   ержк, _oehö, --, --,
   {{0xdb1c0279,0xa3c2074f,0x660900be,0x23e00099}},	// [e9b0] tarã, ्णा_, _raek, _नांद,
   {{0x7e7dc102,0x44e9016f,0x2a6000ab,0x2c22012f}},	//   llsp, vú_, anib_, माणं_,
   {{0x7bc70ac8,0xd6dbc103,0xdced0254,0x7e7d0345}},	//   maju, ята_, _izađ, olsp,
   {{0xdb05c104,0x7bc7c105,0x60c9c106,0x44e9355a}},	//   _behö, laju, ysem, tú_,
   {{0xdb1c47b3,0xc9842c48,0x644309c3,0xdb1e00f7}},	//   mará, _бури, thni, _repé,
   {{0x44e9c107,0xdb1c008a,0x7bc7c108,0x68edc109}},	//   rú_, lará, naju, mtad,
   {{0x68ed0aca,0x44e907f8,0xf1b902c6,0x2fc510db}},	//   ltad, sú_, ljši_, valg_,
   {{0x56945f4e,0x60c9c10a,0x64430031,0xb8030083}},	//   _баст, tsem, shni, _উচিত_,
   {{0xe66417f9,0x394957cd,0xdb0502c9,0x60c90248}},	//   _стро, nzas_, _gehö, usem,
   {{0x60c99379,0x7bc78eb7,0x68ed61b8,0x68320b3e}},	//   rsem, jaju, itad, _hædr,
   {{0x60c950db,0x7bc70a78,0x68edc10b,0x9f4500de}},	//   ssem, daju, htad, veló_,
   {{0x68edc10c,0xed5ab633,0xdb1cbce6,0x201cc10d}},	//   ktad, дом_, jará, _envi_,
   {{0xdb1c1529,0xb33c0069,0x321d0345,0x00000000}},	//   dará, _egħd, _inwy_, --,
   {{0x09ca00a1,0xd011006c,0x307902b5,0x39490029}},	//   िण्य, _ضلع_, _קאַנ, dzas_,
   {{0xbad501c8,0x205602b5,0x629c00f7,0x39490138}},	//   літы, _ביסל_, _érot, ezas_,
   {{0x3b0700c9,0xf2d202b5,0x68edc10e,0xdb1cc10f}},	//   њето_, יעל_, ftad, gará,
   {{0x68ed535e,0xdb0e0a20,0xa3d10096,0x656901f4}},	// [e9c0] gtad, tabó, _वयं_, _nxeh,
   {{0x7a380aaf,0x7bc700cd,0x25ad187a,0xe73a0336}},	//   _míti, caju, _afel_, мез_,
   {{0x7a3800fb,0xdb1c68f3,0x290f013c,0x657b0118}},	//   _líti, bará, ågar_, _ayuh,
   {{0x75d30082,0xe9a60525,0x9473064e,0x7d16c110}},	//   ليما, _шамп, یدوا, _krys,
   {{0x68ed2993,0x200c0297,0xd4e30086,0x7a380079}},	//   ctad, yddi_, ающи, _ríth,
   {{0x07a609ea,0xb33c0069,0x00000000,0x00000000}},	//   _јавн, _lgħe, --, --,
   {{0x32663e89,0x68320249,0xfbd30277,0x25ad099e}},	//   ктив, _fædr, בתו_, _ffel_,
   {{0x2281008a,0x6441c111,0xd7e2051d,0x00000000}},	//   sókn_, _elli, _पाँच, --,
   {{0x64a6c112,0x7a380334,0x7bc7002f,0x64410055}},	//   _раза, _cíti, yaju, _flli,
   {{0xdb1cc113,0x9f450036,0xd57500d8,0xa3ab00be}},	//   zará, velò_, _сусь, कुआ_,
   {{0x2bdc0fd1,0x7bc701cc,0x481502b5,0xa3e770a4}},	//   _बाजा, vaju, אַרן_, _भात_,
   {{0x200a02dd,0x7d16c114,0xf7730122,0x7bc70054}},	//   žbi_, _brys, יקת_, waju,
   {{0xe0460af5,0x7d16c115,0xdb1cc116,0xd7e22516}},	//   _инди, _crys, vará, _पांच,
   {{0x7d1600e9,0xd00f0037,0x00000000,0x00000000}},	//   _drys, _ولن_, --, --,
   {{0x7bc7438c,0xdb1cc117,0x7a31026a,0xa3e0258f}},	//   raju, tará, _båtp, _थाई_,
   {{0x7d169f78,0xcbe30b52,0x68edc118,0x7bc70043}},	//   _frys, য়েছ, ttad, saju,
   {{0xdb1cc119,0x693424f9,0x6458c008,0x7d16053e}},	// [e9d0] rará, анту, kivi, _grys,
   {{0x3949116c,0x64580496,0x6e3dc11a,0x9f5e01f4}},	//   rzas_, jivi, lksb, jetë_,
   {{0xdb1c0076,0x657b0034,0x3dd200e9,0x81e90831}},	//   pará, _syuh, _ydyw_, য়ত_,
   {{0xb9090083,0xe7ff004e,0x6e3d0223,0x88b20831}},	//   _মন_, _उसका_, nksb, _চিরক,
   {{0xd1261e23,0x89da02da,0x58d40133,0x9479667b}},	//   _ام_, _אחרי, _коят, нску_,
   {{0x6458879c,0x7bc501e9,0x00000000,0x00000000}},	//   givi, _jehu, --, --,
   {{0x7a3803e6,0x7bc5c11b,0x00000000,0x00000000}},	//   _síti, _mehu, --, --,
   {{0x96f81362,0x65952691,0xe9df0042,0x9980040b}},	//   _шест_, _бабу, _flúe_, ljiš_,
   {{0xe4d9006c,0x6458b2db,0x657b0118,0xd05901e0}},	//   _سوات_, bivi, _uyuh, ерні_,
   {{0x7a380bc8,0x765904fc,0x64412b06,0x6e3d0223}},	//   _víti, liwy, _ulli, eksb,
   {{0x34940036,0x8eb200f8,0x00000000,0x00000000}},	//   _тафр, یمیش, --, --,
   {{0x7d16c11c,0x765900e9,0x00000000,0x00000000}},	//   _prys, niwy, --, --,
   {{0x7bc50c7c,0x463a0070,0xee370043,0x81e90033}},	//   _behu, גערע, уня_, য়দ_,
   {{0xd00693ec,0x7d160173,0xdca30ddc,0x3b0a00c3}},	//   _беше_, _vrys, сари, него_,
   {{0xcb67235d,0xdea109b9,0x7bc5c11d,0xbb431403}},	//   гаре_, _دیجی, _dehu, берк,
   {{0x7d161016,0x60db02e2,0x9f5e0031,0x00000000}},	//   _trys, orum, zetë_, --,
   {{0x765900e9,0xe8fa057a,0x3e79008d,0x00000000}},	// [e9e0] diwy, эла_, rétt_, --,
   {{0x7bc511cc,0x6458013b,0x9cbb025a,0x00000000}},	//   _gehu, xivi, _רציח, --,
   {{0x64580b4c,0x44220023,0x60dbc11e,0x1fc80033}},	//   vivi, _đk_, hrum, _শামস,
   {{0x64a607f5,0x2a79028b,0x442200b5,0x44fb0132}},	//   гада, _gksb_, _ők_, fª_,
   {{0x81e912eb,0x7bc50feb,0xe5e700b5,0x9f5e0031}},	//   য়া_, _yehu, ازمی, tetë_,
   {{0x07a318fd,0x69c6c11f,0x83f80be8,0x3358002d}},	//   _гарн, _heke, текс_, калэ_,
   {{0x69c60464,0x27ea046a,0x81b50033,0x60db1e7b}},	//   _keke, _icbn_, _জয়_, erum,
   {{0xdb1e0097,0x80cf0067,0xdb0723f4,0x60dbc120}},	//   _nepí, _दिखे, rbjø, frum,
   {{0xa2a40096,0x64581130,0x6602023c,0xc56640e2}},	//   _चूर्, pivi, meok, _скак,
   {{0x9f5e0684,0xddd60168,0x00000000,0x00000000}},	//   leté_, _chyž, --, --,
   {{0x04930037,0xb7db0070,0x7bc5c121,0x25a90121}},	//   _اللح, עקטי, _rehu, žale_,
   {{0x69c6c122,0x7bc50ac8,0xde5900d8,0x60db1901}},	//   _neke, _sehu, тамі_, brum,
   {{0x60db0602,0xd24f004f,0x2be922d4,0xade6007c}},	//   crum, _عنه_, _जादू_, _कारन_,
   {{0x9f5e95e0,0x69c601ed,0xd9dd0af9,0x76590067}},	//   heté_, _aeke, यल्ट, ziwy,
   {{0x69c6c123,0xab9503fa,0x7a380093,0x62800176}},	//   _beke, рављ, _lítu, olmo,
   {{0x200ec124,0x69c6c125,0x78a60a23,0x9f5e9b09}},	//   _hafi_, _ceke, _bukv, jeté_,
   {{0x69c60223,0x2bcb0274,0xecdc00ab,0x14c6018d}},	// [e9f0] _deke, _пуно_, _बियफ, रीमण,
   {{0xee3f00b8,0x2bc60099,0x27f80a8a,0x60c208c7}},	//   lký_, वरणा, _cbrn_, _mwom,
   {{0x200ec126,0x69c6006c,0xa2a40722,0x60c2001c}},	//   _mafi_, _feke, _चूल्, _lwom,
   {{0x69c60d21,0x79820067,0xee3f0097,0x60c2073a}},	//   _geke, żowa, nký_, _owom,
   {{0xa5096058,0x7659016e,0x00000000,0x00000000}},	//   тела_, riwy, --, --,
   {{0x69c604ce,0x200e0fef,0x7659c127,0xee3f0187}},	//   _zeke, _nafi_, siwy, hký_,
   {{0x1610030f,0x249e0107,0x60c2030d,0xee3f00ac}},	//   _ठोकर_, _ditm_, _awom, kký_,
   {{0xa3e73914,0xd5f902b5,0x60c23ab1,0x00000000}},	//   _भाव_, _שפּר, _bwom, --,
   {{0x681b0029,0xdb1e4e1c,0xd24e0037,0xe8df00e2}},	//   _tādē, _repí, بني_, _diệc_,
   {{0x60dbc128,0x28da0026,0x62800051,0x60c20067}},	//   rrum, यूटि, almo, _dwom,
   {{0xf36774db,0x0e66622d,0x9e662374,0x3f693d58}},	//   _стан, икон, ивод, тино_,
   {{0x60dbabd6,0x6f1800cd,0x290b01f7,0x29190523}},	//   prum, _drvc, _osca_, _orsa_,
   {{0x69c6c129,0xb33c0069,0x200e021d,0x60c238d3}},	//   _reke, _igħa, _fafi_, _gwom,
   {{0x69c6c12a,0xafe2210e,0x200e0176,0x1d070200}},	//   _seke, _дошл, _gafi_, јери_,
   {{0x69c65fe5,0x2919c12b,0x290b027a,0x6602023c}},	//   _peke, _arsa_, _asca_, yeok,
   {{0xee3f114d,0xb33c003c,0x2fc723c2,0xc33200a5}},	//   cký_, _jgħa, _heng_, חול_,
   {{0x2fc7c12c,0x47c62dbb,0x2919462c,0x69c601e0}},	// [ea00] _keng_, ибав, _crsa_, _veke,
   {{0x3ea725cb,0x69c6c12d,0x2fc701cb,0x9f47c12e}},	//   _kunt_, _weke, _jeng_, _acné_,
   {{0x69c6c12f,0x290b32b0,0xdb0501b4,0xf71900d8}},	//   _teke, _esca_, _afhæ, ліцы_,
   {{0x320f0332,0x3ea7c130,0xeef60070,0xb33c035f}},	//   _nagy_, _munt_, ימער_, _ngħa,
   {{0x9f5e00f7,0x3ea7ac5a,0xa3d101d1,0x00000000}},	//   reté_, _lunt_, वणं_, --,
   {{0x2fc700bf,0x3ea0c131,0x68e42c18,0xb33c035f}},	//   _neng_, _liit_, muid, _agħa,
   {{0xa3e71b8f,0x68e44e92,0xb33c007a,0x1bee00ab}},	//   _भार_, luid, _bgħa, _जानल_,
   {{0x7a381423,0x60c202e9,0x200e0054,0x2fc700e0}},	//   _títu, _pwom, _safi_, _aeng_,
   {{0xe8df00e8,0x68e4c132,0x2fc74227,0x2d800054}},	//   _việc_, nuid, _beng_, _nyie_,
   {{0x03a30aec,0x249e0a4e,0x2fc70f5d,0x3ea7c133}},	//   _дифо, _uitm_, _ceng_, _bunt_,
   {{0x2fc73b82,0xe8df0019,0x3e720187,0xee3f00d5}},	//   _deng_, _tiệc_, láty_, tký_,
   {{0x60c2c126,0xd6d80033,0x68e4c134,0xdb1c01f7}},	//   _twom, _সহায, kuid, mbrè,
   {{0x224642b7,0x200e03d0,0x776ebab3,0x2d80099e}},	//   _ilok_, _tafi_, _lxbx, _cyie_,
   {{0xee3f031b,0x2fc71585,0x32045ea3,0xe0fb0122}},	//   ský_, _geng_, lemy_, _סלול,
   {{0x3a22012f,0x2246c135,0xa3ab1119,0x3ea70051}},	//   _bnkp_, _klok_, कुट_, _gunt_,
   {{0x29190944,0x3e720187,0x3ea0010d,0x9f9b00a5}},	//   _prsa_, káty_, _giit_, _בסופ,
   {{0x97a70043,0x2fc70118,0x00000000,0x00000000}},	// [ea10] арел, _yeng_, --, --,
   {{0x7d0dc136,0x32040159,0x99e800d5,0x00000000}},	//   _isas, hemy_, _peňá, --,
   {{0x22460034,0x81de0033,0x78ba0355,0x7cfd0523}},	//   _olok_, দ্য_, _čtve, _fårö,
   {{0x3204006a,0x68e41430,0x2919023a,0x9f45021d}},	//   jemy_, buid, _trsa_, melô_,
   {{0x38c90609,0x68e40138,0x32049251,0x888200b5}},	//   _حاجی_, cuid, demy_, _کیلن,
   {{0xdb1e2cad,0x2246352d,0x1cb800a5,0x7d0d08c7}},	//   _hepá, _alok_, סלול_, _msas,
   {{0xdb15954a,0x68330355,0x7d0d0069,0xf7704cbc}},	//   mazó, _výdě, _lsas, _قاف_,
   {{0x2fc7c137,0x3ea7022a,0x7d0dc138,0xb2250036}},	//   _seng_, _runt_, _osas, смил,
   {{0x3ea709eb,0x320f00f5,0xca2a0070,0xe81c0099}},	//   _sunt_, _vagy_, רופֿ, नाचा_,
   {{0x3ea7c139,0x3ea00006,0x2246c13a,0x644a0110}},	//   _punt_, _siit_, _elok_, chfi,
   {{0xa3ac0bc1,0x7d0dc13b,0x320f0187,0x69cd018d}},	//   _गलत_, _asas, _tagy_, kaae,
   {{0x2909000e,0x7bd701dd,0x2246c13c,0xdb1ec13d}},	//   kwaa_, _adxu, _glok_, _nepá,
   {{0x2fc7c13e,0x30a742ee,0xdb1cb215,0x427406c9}},	//   _teng_, _трев, mbré, _بالآ,
   {{0x61e908db,0xac0a002d,0x3dd80484,0x55760070}},	//   lgel, ынга_, _żewġ_, מערן_,
   {{0x7d0d815a,0x2005c13f,0x61e900e9,0xdb1c58ae}},	//   _esas, meli_, ogel, larú,
   {{0x61e9c140,0x2005c141,0x68e42de1,0xa9a60714}},	//   ngel, leli_, tuid, сиад,
   {{0x6e24c142,0xdb17002a,0x00000000,0x00000000}},	// [ea20] _inib, _xexú, --, --,
   {{0xdb153612,0x68e4c143,0x7a380138,0x25a400d4}},	//   gazó, ruid, _cítr, _sgml_,
   {{0x7afe1c3e,0x177901c8,0xa3ab0084,0x2005002d}},	//   _uppt, асць_, कुछ_, ieli_,
   {{0x7bcec144,0x80d819b7,0x2ca90221,0x2005c145}},	//   labu, _मिले, _yuad_, heli_,
   {{0x61e90afc,0x644a004f,0xdb050023,0x4e7b0070}},	//   dgel, thfi, _nghê, נאנצ,
   {{0x2005c146,0x7bcec147,0x3e7205d3,0x61e90b19}},	//   jeli_, nabu, ráty_, egel,
   {{0x25a9030a,0x61e99abb,0x3204189a,0x66e3ac0e}},	//   žala_, fgel, temy_, _нора,
   {{0x61e9c148,0x7bcec149,0x9663465e,0x7a3800b8}},	//   ggel, habu, _ексе, _zítr,
   {{0x7bcec14a,0x80d800a1,0x2005c14b,0x22460b88}},	//   kabu, _मिळे, feli_, _vlok_,
   {{0x2005c14c,0x6e245ddf,0x61e97479,0x7bcec14d}},	//   geli_, _anib, agel, jabu,
   {{0x43865f8a,0x8f340202,0x645ac14e,0x6448c14f}},	//   _الاق, ценц, _imti, _ildi,
   {{0xf99f0118,0x3f820228,0x479b016b,0x00000000}},	//   _kaèt_, āku_, טייס, --,
   {{0xa3ac0084,0x2ca9c150,0x91e31470,0xdb1e002a}},	//   _गला_, _quad_, _хоче, _repá,
   {{0x2005c151,0x9f5ec152,0xdb1e20d9,0x509603fa}},	//   celi_, letí_, _sepá, _уређ,
   {{0xa3d00cf1,0x387a0009,0x7ff700a5,0xb33c007a}},	//   _वजन_, dopr_, _הזוג_, _mgħo,
   {{0x2aa80d9c,0x7f830037,0x29090054,0x6e240118}},	//   стро_, _علين, twaa_, _gnib,
   {{0x38354dcc,0x7bce2506,0x645a0103,0x7e6d08c7}},	// [ea30] онар, babu, _omti, _ijap,
   {{0x99980043,0x61e9c153,0x2909214a,0x81ae0033}},	//   скут_, zgel, rwaa_, করি_,
   {{0xdb15c154,0xdc380070,0x61e9c155,0x2bee0099}},	//   razó, _לאזט_, ygel, _जातं_,
   {{0x64480291,0xceb302b5,0x28c405f8,0x9f5e00b8}},	//   _aldi, ליע_, _लौकि, jetí_,
   {{0x7ae78c65,0x2bbf0e6f,0x81ae0033,0x200572ab}},	//   lujt, ्रपा, করা_, yeli_,
   {{0x42d9c156,0x987902b5,0x8ccb0355,0x61b3022e}},	//   афия_, _כאָט, तीयो, ीर्ष,
   {{0x61e97de4,0x74db44d2,0x7ae70097,0xa3b80324}},	//   tgel, _निवृ, nujt, चड़_,
   {{0xe0d9001f,0x2005000e,0x6448c157,0x7bcec158}},	//   ави_, weli_, _eldi, zabu,
   {{0x61e9c159,0x569402ee,0x7ae789fc,0x7bcec15a}},	//   rgel, _хатт, hujt, yabu,
   {{0xd7660332,0x6e363a20,0x61e9c15b,0x7ae71a7f}},	//   _انہی, _soyb, sgel, kujt,
   {{0x61e90fdb,0x81de00c8,0x6443004e,0x2005c15c}},	//   pgel, দ্ধ_, mkni, reli_,
   {{0x7ae70187,0x4425025c,0x64430b87,0x7bcec15d}},	//   dujt, _hnl_, lkni, wabu,
   {{0x2005c15e,0x7bcec15f,0x7e6d0118,0x44250118}},	//   peli_, tabu, _djap, _knl_,
   {{0x64430557,0x225f50ad,0xb33c003c,0x459a016b}},	//   nkni, liuk_, _ogħl, יסרע,
   {{0xa3e76a76,0x7bceb9c7,0x7ae7168a,0xf21e0299}},	//   _भाई_, rabu, gujt, _मोड़_,
   {{0x6e24c160,0x7bcec161,0x225fc162,0xa2cc02b4}},	//   _unib, sabu, niuk_, _सबस्,
   {{0x7bce1c5c,0xb33c035f,0x442514c1,0x00000000}},	// [ea40] pabu, _agħl, _onl_, --,
   {{0xb90200be,0x7649045e,0x6721011c,0x7e6d0124}},	//   _धि_, _aley, _šlja, _zjap,
   {{0xdb050019,0x2a69006d,0x7ae701c6,0x224d010d}},	//   _nghè, bnab_, cujt, khek_,
   {{0x5efa00c2,0x4425c163,0xd5b00071,0x13b407df}},	//   יפעד, _anl_, رفت_, ुर्भ,
   {{0x442546ed,0x2c0f00a1,0xb33c0024,0x224d01cb}},	//   _bnl_, ायचं_, _egħl, dhek_,
   {{0x2bbf48cd,0x44250176,0x765b030d,0xd37200f8}},	//   ्रया, _cnl_, _emuy, وهش_,
   {{0x7649c164,0x68f69af6,0xdc9b016b,0x224d0298}},	//   _fley, ltyd, ביסל, fhek_,
   {{0x7649008a,0x44251890,0xcad700a5,0xb8820355}},	//   _gley, _enl_, קופת_, řída,
   {{0x2bbf2064,0xfbbf000c,0x661d008a,0x321800b8}},	//   ्रमा, ्रमम, _óska, ěry_,
   {{0x6443022a,0xdced04d4,0xa3e700ab,0x64480228}},	//   ckni, _ayağ, _भाए_, _uldi,
   {{0xc7b3035e,0x3eb801f4,0x2a690312,0x224d0118}},	//   ובת_, ërt_, ynab_, bhek_,
   {{0x2bbf00b4,0x4126006c,0xdb1f05ee,0x13cf0033}},	//   ्रभा, _وفاق, ðvík, _রায়,
   {{0xa06a0202,0x225709b9,0x201a021d,0x00000000}},	//   _када_, _بلند_, _ópio_, --,
   {{0x7ae7571a,0x2d850228,0x68f60345,0x7c37007a}},	//   tujt, āle_, dtyd, _qoxr,
   {{0x2902013a,0x00000000,0x00000000,0x00000000}},	//   _apka_, --, --, --,
   {{0x7ae71824,0x42db02b5,0xbda74d1e,0x290200d7}},	//   rujt, יקלע, _بحثو, _bpka_,
   {{0x7ae7156f,0x37ab0265,0x6443c165,0x394000b5}},	// [ea50] sujt, атен_, ykni, gyis_,
   {{0x7ae7156f,0xb33c035f,0xb91100e2,0x00000000}},	//   pujt, _agħm, _khoả_, --,
   {{0x7649c166,0x442500ee,0x00000000,0x00000000}},	//   _pley, _rnl_, --, --,
   {{0x44250526,0x4efb016b,0xdb0500e2,0xbddb00a2}},	//   _snl_, שלאג, _nghé, chèt,
   {{0x4425c167,0xc9840043,0xe53401e0,0x64430067}},	//   _pnl_, _жури, мець, tkni,
   {{0x7e7dc168,0xb33c0024,0x00000000,0x00000000}},	//   hosp, _egħm, --, --,
   {{0x64434409,0x224dc169,0x27f13bd6,0x03a21682}},	//   rkni, thek_, _iczn_, нишо,
   {{0x56940183,0x765b0232,0x6443c16a,0x27e900af}},	//   _жаст, _umuy, skni, şină_,
   {{0x7e7dc16b,0x225f104e,0xddc4022f,0xf4870274}},	//   dosp, riuk_, _njiš, _дужн,
   {{0x9327186e,0x8f7500d4,0x9f5c0176,0xe7cb018d}},	//   _وران, зумі, _navó_, िरिप,
   {{0x7e7d0453,0x6f620043,0x00000000,0x00000000}},	//   fosp, евэз, --, --,
   {{0x3ea4022a,0x7e7dc16c,0x12fa00a5,0x39520067}},	//   ömt_, gosp, _להעב, yzys_,
   {{0xe167004f,0x00000000,0x00000000,0x00000000}},	//   _بداي, --, --, --,
   {{0xd47902b5,0x61fb1f9d,0x9f5e01f7,0x00ba00a5}},	//   מאָל, lful, betà_, _המסמ,
   {{0xd00e02aa,0x8b231334,0x00000000,0x00000000}},	//   _إلى_, ндре, --, --,
   {{0x89aa0210,0x81e90033,0x2bd8000c,0x9f961804}},	//   скав_, য়ক_, _भएका, _צדקה_,
   {{0xdb1c0d2e,0x3a3973cb,0x9f5eae50,0x00000000}},	// [ea60] mbrí, _dosp_, metá_, --,
   {{0xa3e7009a,0x68f6c16d,0x2bbf157d,0x9f5e9ae6}},	//   _भाग_, rtyd, ्रणा, letá_,
   {{0x39461772,0xd7ef004f,0x68f6c16e,0xbddb00f7}},	//   šos_, اكم_, styd, phèt,
   {{0x3a39c16f,0x98a60043,0xbddb0176,0x986600fd}},	//   _gosp_, _ниме, lhèr, _کیئے_,
   {{0x69c4c170,0xdb1c004f,0x1a9b02b5,0x61fbc171}},	//   mbie, ibrí, _ליטע, dful,
   {{0x69c49d1e,0x7d04018e,0x3d1d018d,0xf8bf0093}},	//   lbie, _mpis, मिते_, _bréf_,
   {{0x6ada0084,0x68e43e48,0x2bbf035d,0x00000000}},	//   _बटोर, lrid, ्रता, --,
   {{0x69c4939d,0x68e42dd3,0x9989030a,0x07a3c172}},	//   nbie, orid, ljaš_, _часн,
   {{0x624701ed,0x00000000,0x00000000,0x00000000}},	//   _iñol, --, --, --,
   {{0x68e419fd,0x9ed8453e,0x645d00d8,0x998904c3}},	//   irid, омот_, _įsig, njaš_,
   {{0x68e40079,0x7d04034d,0x69c40051,0xbddb01cb}},	//   hrid, _apis, kbie, dhèr,
   {{0x648d004f,0x68e40075,0x7d04262d,0x9f5e01f7}},	//   núin, krid, _bpis, retà_,
   {{0x69c4c173,0x6282c174,0x51831e46,0xed5800d8}},	//   dbie, _ikoo, _пуша, зоў_,
   {{0x2ca5c175,0x2bbf04eb,0xbddb00f7,0x3ced0084}},	//   öld_, ्रधा, thès, _जमीं_,
   {{0x68e4007c,0x3ffb0122,0xd5cc05f7,0x7e7d088a}},	//   erid, _הפוע, ाराज, posp,
   {{0xaa58c176,0x81de0083,0x68e48169,0x67210124}},	//   пису_, দ্র_, frid, _šljo,
   {{0x68e4c177,0x1dc348cd,0x2bbf205c,0x26d8c178}},	// [ea70] grid, _व्यत, ्रदा, _avro_,
   {{0x37ab0923,0xbddb00f7,0x69c402d7,0x00000000}},	//   стан_, chèr, abie, --,
   {{0x69c4c179,0x442b01a5,0x68e4007c,0x212b0023}},	//   bbie, _đc_, arid, ̣ch_,
   {{0xd2460372,0xd6d82286,0x6282c17a,0x00000000}},	//   _شن_, яту_, _nkoo, --,
   {{0xc9871052,0x69cf00ea,0x1c221fe0,0x26d8c17b}},	//   _хуни, _iece, माचल_, _evro_,
   {{0x057402fd,0xd7f800af,0x6282c17c,0xfbbf0355}},	//   راند, _нус_, _akoo, ्रिम,
   {{0x69cf0464,0x61fb0699,0x7dd800fd,0x22b500ec}},	//   _kece, tful, núsí, _bāka_,
   {{0x2fce0107,0x244b0044,0x65950036,0x26c100f6}},	//   _aefg_, _døma_, _жабу, mpho_,
   {{0x61fb14c2,0xfbbf0cea,0x26c10183,0x93a70043}},	//   rful, ्राम, lpho_, _ешед,
   {{0x09aa193c,0x69cfc17d,0x61fb038d,0xe8df00e2}},	//   _कल्य, _lece, sful, _nhọc_,
   {{0x69ddc17e,0x7d04c17f,0x2d8c0035,0x49140067}},	//   _odse, _spis, ędem_, _नैनो_,
   {{0x68e4c180,0x78a70223,0x3eaec181,0xbbc6021a}},	//   yrid, _lijv, _duft_, वर्क,
   {{0x205522f1,0xcc26006c,0x68e40069,0x629b46ed}},	//   _откр, ورسٹ, xrid, mmuo,
   {{0x69ddc182,0x68e40f0a,0x7d0402c6,0x62898ace}},	//   _adse, vrid, _vpis, lleo,
   {{0xdca3206f,0x7d04006a,0x69c4c183,0x69cf5922}},	//   тари, _wpis, tbie, _bece,
   {{0x7ae10332,0xe7f00066,0xf99f021e,0xeb97081b}},	//   álta, _चाहा_, _obèd_, фис_,
   {{0x78a704ce,0x7d040a78,0xda65017e,0x68e400be}},	// [ea80] _bijv, _upis, رافي, urid,
   {{0xb8f6c184,0x69c4c185,0x68e41adb,0x69dd0069}},	//   _सब_, sbie, rrid, _edse,
   {{0x69cf539a,0xe61a0d07,0x6289c186,0x68e436ad}},	//   _fece, жде_, kleo, srid,
   {{0xa3d00953,0x69cf01d6,0x5ee007b5,0xceb2016b}},	//   _वजह_, _gece, _किस्_, דיא_,
   {{0xb33c009f,0xdb1e0168,0xe5a31355,0xf8bf0312}},	//   _igħi, _nepú, вици, _créd_,
   {{0x62820626,0xf1bf0b06,0x69cf0af3,0x22b500ea}},	//   _skoo, ñán_, _zece, _sāka_,
   {{0x62890297,0xdb1c2fbe,0xdb050019,0xf99f0260}},	//   fleo, maró, _nghì, _ebèd_,
   {{0x37e30083,0xb33c0484,0xc114192f,0x6289c187}},	//   ন্দর, _jgħi, емиј, gleo,
   {{0x95834311,0x00000000,0x00000000,0x00000000}},	//   _алте, --, --, --,
   {{0xdb1c0037,0x00000000,0x00000000,0x00000000}},	//   naró, --, --, --,
   {{0x2bbf00a9,0x61480093,0x62890312,0x00000000}},	//   ्रसा, félö, bleo, --,
   {{0x6289c188,0xbddb0248,0xb33c003c,0x00000000}},	//   cleo, thèq, _ngħi, --,
   {{0x69cfc189,0xdc3a036a,0x6280698b,0x00000000}},	//   _rece, _açıl, momo, --,
   {{0x628002d0,0x7d1d01b4,0xddcd2f70,0xe16700f8}},	//   lomo, rvss, _ukaž, _تضمی,
   {{0x200cc18a,0x78a702a2,0x9f88003e,0x648d0098}},	//   medi_, _rijv, _góði_, dúil,
   {{0x6280c18b,0x200cc18c,0xdb12004f,0x2bbf1e18}},	//   nomo, ledi_, ógái, ्रहा,
   {{0x69cfc18d,0xb33c0024,0xf8bf00f6,0x00000000}},	// [ea90] _vece, _dgħi, _orée_, --,
   {{0x6280c18e,0x3ea9012f,0x200cc18f,0x9cd8011d}},	//   homo, _hiat_, nedi_, _חוזה_,
   {{0x62805c64,0xe7f00907,0xb8d60e04,0x69cf9810}},	//   komo, _चारा_, _चू_, _tece,
   {{0xb935051b,0x2bbf131c,0xd0170083,0x69dd01b4}},	//   _земј, ्रवा, ়ায়_, _udse,
   {{0x6280c190,0xdb1c1534,0x200c1678,0xe9df00a0}},	//   domo, mbrá, kedi_, _idú_,
   {{0xdb1e1423,0x200c029d,0x3ea90ac8,0xf8bf00f7}},	//   _repú, jedi_, _liat_, _crée_,
   {{0xe784c191,0x27f81840,0x68edc192,0xdb1e02d7}},	//   _ауто, žený_, luad, _sepú,
   {{0x3ea9149f,0x628000d8,0xdb0500e2,0x00000000}},	//   _niat_, gomo, _nghí, --,
   {{0x629b00d8,0x9f5e03ad,0x6289c193,0x25ad5b47}},	//   rmuo, hetä_, rleo, _igel_,
   {{0xaec503c6,0x628901a3,0x200c222e,0xe8020761}},	//   нбол, sleo, gedi_, र्पा_,
   {{0x62890033,0x6280c194,0x7bd501b7,0x00000000}},	//   pleo, bomo, dazu, --,
   {{0xf7720319,0xfce61d67,0x531a00a5,0x7659045e}},	//   רקט_, номо, _מועצ, _çayı,
   {{0x61d60122,0x200c395c,0x3ea901a3,0x41291f39}},	//   _נוסף_, bedi_, _diat_, _холо_,
   {{0x200cc195,0x00000000,0x00000000,0x00000000}},	//   cedi_, --, --, --,
   {{0xf8bf130f,0xa3c20953,0x28e2018d,0xab273379}},	//   _até_, ूरत_, _पिहि, нора_,
   {{0xc33202da,0x3ea9c196,0xf2d202b5,0xdb1c0067}},	//   נון_, _giat_, טעל_, waró,
   {{0x68ed0a17,0x7bd5c197,0x97c6002d,0x4c860bfe}},	// [eaa0] guad, bazu, ейзе, _плив,
   {{0x7d5700a5,0x7e6610cd,0x7bd500af,0x6d460c3d}},	//   _נייד_, likp, cazu, myka,
   {{0xf7434ed5,0x6d46c198,0xb33c003c,0x7c650312}},	//   лефо, lyka, _tgħi, _جايل,
   {{0xe802007c,0xdb1c01ef,0x00000000,0x00000000}},	//   _रउवा_, saró, --, --,
   {{0x68ed0f56,0x62805e42,0x7c3e0627,0x69d6c199}},	//   cuad, vomo, _kopr, maye,
   {{0x28b50821,0x14c61604,0x69d61fd2,0x7c3e00ea}},	//   _अंति, रीगण, laye, _jopr,
   {{0x6fd60953,0x200c0169,0x62807605,0x2bee0006}},	//   _मजबू, vedi_, tomo, _जाईं_,
   {{0x69d62ca9,0xd25746e2,0x7c3e0107,0x6d4602ee}},	//   naye, ець_, _lopr, kyka,
   {{0x50663b41,0x9980003c,0x7bd560e8,0x200c0225}},	//   етна, jjiż_, yazu, tedi_,
   {{0x38b6008e,0x69d6c19a,0x6280c19b,0x7c3ec19c}},	//   _mær_, haye, somo, _nopr,
   {{0x442c0022,0x200cc19d,0x69d6c19e,0x62802d5b}},	//   _ind_, redi_, kaye, pomo,
   {{0x442cc19f,0x443e0122,0x200cc1a0,0x7aee0392}},	//   _hnd_, _hot_, sedi_, dubt,
   {{0x443e39ea,0x200cc1a1,0x69d6c1a2,0x38b6c1a3}},	//   _kot_, pedi_, daye, _nær_,
   {{0x315700c2,0x7c3ec1a4,0xe80209b1,0x7ae100b5}},	//   _אידן_, _copr, र्मा_, álto,
   {{0xc4c400f5,0x7c3e031d,0x443ec1a5,0x7bd5c1a6}},	//   _گے_, _dopr, _mot_, razu,
   {{0x68ed2587,0x443e472b,0x69d604fb,0x38b63d9d}},	//   tuad, _lot_, gaye, _bær_,
   {{0x442c02c7,0xc4c40332,0x6ca7c1a7,0x6e2dc1a8}},	// [eab0] _ond_, _دے_, _прож, _inab,
   {{0x443e01f3,0x68ed0608,0x2bee0035,0xb90906fe}},	//   _not_, ruad, _जाएं_, _यि_,
   {{0xbbbf1ae9,0x68edc1a9,0xe8020006,0x69d6c1aa}},	//   ्रीक, suad, _रउरा_, baye,
   {{0x442c6a92,0x38b6008a,0x69d6c1ab,0xb33c0024}},	//   _and_, _fær_, caye, _jgħu,
   {{0x443ec1ac,0x68edc1ad,0x38b6008a,0x92ad0033}},	//   _bot_, quad, _gær_, _কবে_,
   {{0x657801ba,0xdddd0035,0x442c0371,0x62470065}},	//   _ťahá, nisł, _cnd_, _iñoi,
   {{0x443ec1ae,0x6d460067,0x6e2d021d,0x00000000}},	//   _dot_, zyka, _onab, --,
   {{0x442c161f,0x93240088,0x5bbf022e,0x6e2d01a8}},	//   _end_, ارون, ्रुव, _nnab,
   {{0x443ec1af,0x442c009e,0x4095141d,0x03f90274}},	//   _fot_, _fnd_, крот, _онај_,
   {{0x6e2dc1b0,0x661bc1b1,0x443e905c,0x442c179a}},	//   _anab, _hauk, _got_, _gnd_,
   {{0x661bc1b2,0xc7b202b8,0x7e662e35,0xdb1c008a}},	//   _kauk, יבי_, tikp, jarð,
   {{0x7c3ec1b3,0x443ec1b4,0x661b23c6,0x2f541470}},	//   _sopr, _zot_, _jauk, утьс,
   {{0x7c3e6d53,0x443e0107,0xb33c0024,0x661bc1b5}},	//   _popr, _yot_, _dgħu, _mauk,
   {{0x661bc1b6,0xc0e20dfc,0x2d8c0029,0x6e2d0122}},	//   _lauk, _тошк, āde_, _enab,
   {{0x38b64777,0xdb1c0093,0x6b63c1b7,0x6d46012f}},	//   _sær_, garð, акра, syka,
   {{0x661bc1b8,0x7aee008c,0x44fb0183,0x6d46004b}},	//   _nauk, rubt, kê_, pyka,
   {{0xfaa30994,0x69d6c1b9,0x7c3e01d6,0xa9674b34}},	// [eac0] рато, raye, _topr, вита_,
   {{0x0b462263,0x69d6c1ba,0x60db145d,0x38b603db}},	//   _анон, saye, isum, _vær_,
   {{0x443e712f,0x661b29c2,0x5c3700a5,0xf8bf00a2}},	//   _rot_, _bauk, _סרטן_, _préc_,
   {{0x443e7f98,0x38b6c1bb,0x69d60107,0x60dbc1bc}},	//   _sot_, _tær_, qaye, ksum,
   {{0x661b0291,0x443e9d08,0x00000000,0x00000000}},	//   _dauk, _pot_, --, --,
   {{0x8d5b0122,0x442c05c7,0x60db0067,0xdb1c08c8}},	//   וכני, _qnd_, dsum, rbræ,
   {{0xe80202e4,0x443ec1bd,0x442c01a5,0x60db0409}},	//   र्णा_, _vot_, _vnd_, esum,
   {{0x21290d77,0x2450009e,0x661bc1be,0x52142a63}},	//   _šaha_, _dàma_, _gauk, удит,
   {{0xd0100082,0x66020ac8,0x60db190b,0xb50527f6}},	//   ملة_, mfok, gsum, _مظلو,
   {{0x442cc1bf,0x7054103b,0x6e2dc1c0,0x67210254}},	//   _und_, اندا, _snab, _šlji,
   {{0x60db14e7,0x7640c1c1,0x1df9021f,0xd34500f8}},	//   asum, _komy, нены_, _میوه_,
   {{0xe802c1c2,0xdb1c0093,0xdd0e22d4,0xc8e200b4}},	//   र्ता_, varð, िबंध_, _पिंट,
   {{0xb88401c0,0x3f820067,0x00000000,0x00000000}},	//   _zvíř, łku_, --, --,
   {{0xbbbf1856,0x1dc3035d,0x60cd0225,0x7e64001c}},	//   ्रेक, _व्रत, _çama, _emip,
   {{0x7e64022e,0x00000000,0x00000000,0x00000000}},	//   _fmip, --, --, --,
   {{0x201c00b5,0x212600d7,0x6e2dc1c3,0xba740037}},	//   _havi_, _kroh_, _unab, لاقت,
   {{0x661bc1c4,0x201c02a7,0x661d008d,0x1da71662}},	// [ead0] _rauk, _kavi_, _óski, _गणित,
   {{0x661bc1c5,0xdbcd008a,0x7522156f,0x201cc1c6}},	//   _sauk, _góðu, dvoz, _javi_,
   {{0x661ba11d,0x61e2c1c7,0x201c00d0,0xe80206d9}},	//   _pauk, _odol, _mavi_, र्धा_,
   {{0x60c2122c,0x201c0c1f,0x764001ef,0x44fb0132}},	//   _otom, _lavi_, _comy, tê_,
   {{0x7522022f,0x7640c1c8,0x60c2008c,0x00000000}},	//   gvoz, _domy, _ntom, --,
   {{0x61e2c1c9,0x29190484,0x3949010d,0x44fb0132}},	//   _adol, _issa_, myas_, rê_,
   {{0x60c2b2be,0x661bc1ca,0x3949c1cb,0x320600cc}},	//   _atom, _tauk, lyas_, _bboy_,
   {{0x60dbc1cc,0x764031ad,0xdb1e0168,0x44fb0183}},	//   tsum, _gomy, _nepý, pê_,
   {{0x00850f78,0x201c0a78,0x7fd50746,0x61e200e9}},	//   ллио, _bavi_, ліні, _ddol,
   {{0x2a6901a9,0x0495028c,0xf4840423,0x201c0382}},	//   hiab_, _صلاح, _кухн, _cavi_,
   {{0x201c0183,0x212600e0,0x48160070,0x60c2030d}},	//   _davi_, _eroh_, אַכן_, _etom,
   {{0x2919c1cd,0x6441c1ce,0x39494990,0x2126033b}},	//   _ossa_, _holi, kyas_, _froh_,
   {{0x644118b0,0x60db007a,0x21260088,0x00000000}},	//   _koli, qsum, _groh_, --,
   {{0x6441c1cf,0xfba50d53,0x61e205d1,0x201c0036}},	//   _joli, _गृहम, _zdol, _gavi_,
   {{0x6441c1d0,0x09e643f7,0x2007c1d1,0x752200d5}},	//   _moli, ловн, _ibni_, zvoz,
   {{0x224d00b5,0x321d189a,0x1c0000ab,0x00000000}},	//   nkek_, _jawy_, _लउकल_, --,
   {{0x9e6500b5,0x0e9b00a5,0xa806081b,0x00000000}},	// [eae0] _خاون, _אשקל, лзал, --,
   {{0x64410029,0x69cb0093,0x201cc1d2,0x25cc06fe}},	//   _noli, ðger, _xavi_, ार्ण,
   {{0x2919c1d3,0x7640004e,0x85eac1d4,0x224d006c}},	//   _essa_, _pomy, едев_, kkek_,
   {{0xd01c0083,0xdb1c0301,0x31790035,0x66020009}},	//   তায়_, rbrä, ższy_, ufok,
   {{0x6441c1d5,0x6602c1d6,0x04460948,0xe534399d}},	//   _boli, rfok, ледн, рель,
   {{0x7522c1d7,0x2900c1d8,0x7d7b016b,0x00000000}},	//   rvoz, mtia_, ענסו, --,
   {{0x3d160378,0x29000443,0x201cc1d9,0xc30600f3}},	//   _पैसे_, ltia_, _ravi_, ابتو,
   {{0x77910357,0x3a200069,0x64418697,0x99890644}},	//   _بیما, ndip_, _eoli, ndaş_,
   {{0x301400d8,0xdb1c0132,0x3e6b0107,0x201c081b}},	//   адпр, marõ, _lòtè_, _pavi_,
   {{0x29001049,0x224d01ed,0x00000000,0x00000000}},	//   itia_, akek_, --, --,
   {{0xa3c11fe0,0x2a6901e8,0xde5900d4,0x290000c3}},	//   ंडर_, yiab_, вані_, htia_,
   {{0x6441c1da,0x2a6901e8,0x705400e0,0x78ae00fe}},	//   _zoli, xiab_, انگا, _libv,
   {{0x60c2013c,0x644102d7,0x201cc1db,0x00000000}},	//   _utom, _yoli, _tavi_, --,
   {{0x64410345,0x6458c1dc,0x13d80033,0x29190065}},	//   _xoli, nhvi, _সাড়, _rssa_,
   {{0x290093ff,0xdb1c000d,0x2d84033b,0xce9501d3}},	//   etia_, ncrè, ümer_, _какъ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xae050026,0x52d10067,0x00000000,0x00000000}},	// [eaf0] ष्णन_, _सब्स, --, --,
   {{0x7d0d39a8,0x2a690189,0x00000000,0x00000000}},	//   _ipas, siab_, --, --,
   {{0x6441c1dd,0xdb1e4a74,0x8d740647,0xaa950212}},	//   _roli, _depó, _نایا, _винч,
   {{0x2bbf0567,0x394908dd,0xbb3a016b,0x00000000}},	//   ्रका, pyas_, _סערי, --,
   {{0x29000043,0xa3c10f09,0xe80200be,0x7bd70065}},	//   ctia_, ंडल_, र्हा_, _kexu,
   {{0x68ed01a6,0x80c30083,0x64a513ba,0x672100cd}},	//   mrad, _শিল্, шала, _šlju,
   {{0x64413f23,0x42552701,0xb87b008d,0xdb1c0d8f}},	//   _voli, итит, _tvíb, barõ,
   {{0x7d0dc1de,0x7bd74c46,0x68ed09c3,0x00e516b8}},	//   _opas, _lexu, orad, ажин,
   {{0x6441c1df,0x68edc1e0,0xe0d645d7,0x6ec10029}},	//   _toli, nrad, авы_, _mēbe,
   {{0x68ed0952,0xa3c200b4,0x7529c1e1,0x3e6f00c3}},	//   irad, ूरः_, _irez, yötä_,
   {{0x68ed086d,0xd3710082,0x7d0dc1e2,0x290006a2}},	//   hrad, _بها_, _apas, ztia_,
   {{0xd131004f,0x7529c1e3,0x7659001e,0xba3b01f7}},	//   _وما_, _krez, nhwy, _xiït,
   {{0x68ed28f9,0x6609c1e4,0x463a0070,0x52840037}},	//   jrad, _mbek, דערע, _النك,
   {{0x8fa53b41,0xbc190210,0x752905e2,0xb5fd0168}},	//   _кале, лісі_, _mrez, _omšo,
   {{0x68ed4e53,0xdb1e03e6,0x05d54e29,0x6609c1e5}},	//   erad, _repó, दराब, _obek,
   {{0x290003fe,0x68edc1e6,0x7529c1e7,0xdb1cc1e8}},	//   ttia_, frad, _orez, ncré,
   {{0x68edc1e9,0x98e60037,0x99893833,0x2900081b}},	// [eb00] grad, شكاو, rdaş_, utia_,
   {{0x290040bc,0x60c90248,0xdb1e02d0,0x200502d0}},	//   rtia_, ipem, _depò, nfli_,
   {{0x7bdc0043,0x7529c1ea,0x68ed0315,0x487900c3}},	//   maru, _arez, arad, устя_,
   {{0x7529c1eb,0x2900002d,0x8f9a00a5,0xa5261888}},	//   _brez, ptia_, דיעי, имед,
   {{0x689100f5,0x68ed3207,0x7529002d,0x7bd701e8}},	//   _کیلئ, crad, _crez, _yexu,
   {{0x240700af,0x3ce9004e,0x660901ed,0xd90d00d1}},	//   инчи_, _जिसे_, _ebek, _سیم_,
   {{0x66e30cb5,0x7529c1ec,0xd36f00ce,0xe3cf0033}},	//   _мора, _erez, وهه_, _রাখব,
   {{0x7bdc4f98,0x7659c1ed,0x7529c1ee,0xe81400ab}},	//   haru, chwy, _frez, ड़वा_,
   {{0x7bdcc1ef,0x7529c1f0,0xdb1c488c,0x624702d7}},	//   karu, _grez, scrè, _años,
   {{0xcfa60adb,0xa2e65128,0x2f2500ec,0x00000000}},	//   ишни, _вожд, _bēg_, --,
   {{0x7d0da0d6,0x68ed00ac,0xb7db0070,0x7bd701dd}},	//   _spas, zrad, כקיי, _rexu,
   {{0x6d2202e4,0xe4db01c0,0xdceb48cf,0x68ed03c1}},	//   मिंग_, zšíř, šičn, yrad,
   {{0x7bdcc1f1,0xddd600ee,0x224b02b1,0x00000000}},	//   faru, _mlyň, öcke_, --,
   {{0x7c87536e,0x7bdc0232,0x68ed0183,0xe8e00023}},	//   руме, garu, vrad, _nuốt_,
   {{0x6fcc021a,0xc5d70033,0x624701b7,0xaa673fe2}},	//   _द्यू, _হাসপ, _iñor, атак,
   {{0x0f570122,0x645d010b,0x2459000d,0x648d0098}},	//   _כיום_, _įsim, _ième_, lúit,
   {{0x7d0dc1f2,0x7bdc1cf5,0xe8e000e2,0xfe9a00fd}},	// [eb10] _upas, baru, _buốt_, _حصوں_,
   {{0x752900da,0x7bdc002d,0x6ab70044,0x00000000}},	//   _rrez, caru, _tuxf, --,
   {{0xd12607e4,0x75290129,0xc6a7039e,0x68edc1f3}},	//   _کم_, _srez, арди, srad,
   {{0x68edc1f4,0x569500c3,0xb559002d,0x245900a2}},	//   prad, щает, лиеф_, _mème_,
   {{0xe7f00243,0xf8bf1d8a,0x68ed0510,0x7af5c1f5}},	//   _चाचा_, _krém_, qrad, luzt,
   {{0x75298356,0x58d40217,0x00000000,0x00000000}},	//   _vrez, _форт, --, --,
   {{0x03a50421,0x7af501b7,0x00000000,0x00000000}},	//   щико, nuzt, --, --,
   {{0x7529c1f6,0x7bdc0eae,0x07d8006c,0x62473658}},	//   _trez, zaru, _مذہب_, _añor,
   {{0x0fd91db7,0x7bdc0848,0x7529c1f7,0x60c9c1f8}},	//   льны_, yaru, _urez, upem,
   {{0x60c90f20,0xdb1cbc12,0x7af501ed,0x00000000}},	//   rpem, scré, kuzt, --,
   {{0x7bdcc1f9,0x339502e7,0x60c90207,0x00000000}},	//   varu, _الاز, spem, --,
   {{0x60c9c1fa,0x7bdc43dd,0x628402c4,0x6234c1fb}},	//   ppem, waru, čioc, _меху,
   {{0xd00981e6,0x00000000,0x00000000,0x00000000}},	//   _беле_, --, --, --,
   {{0x24590260,0x9f5e1dab,0x0c790421,0x00000000}},	//   _fème_, letý_, ассы_, --,
   {{0x7bdc0010,0x2bbf1b8f,0x20020095,0x00000000}},	//   raru, ्रजा, əki_, --,
   {{0x7bdcc1fc,0xc3320122,0xe8e001a5,0xe1f900d8}},	//   saru, הול_, _suốt_, ngų_,
   {{0x7bdc1051,0x6aa437fd,0xe81407b5,0xaa430f6d}},	// [eb20] paru, rmif, ड़ला_, четл,
   {{0xe73a2101,0x00000000,0x00000000,0x00000000}},	//   лез_, --, --, --,
   {{0xbc680332,0xfa6a1018,0x648d0037,0x46eac1fd}},	//   _مجھے_, _банк_, húis, уден_,
   {{0x54e60037,0x00000000,0x00000000,0x00000000}},	//   مستق, --, --, --,
   {{0xd6250082,0x22b500ec,0xe8e000e2,0x00000000}},	//   تعلي, _māku_, _tuốt_, --,
   {{0x68460dee,0xe8560754,0x00000000,0x00000000}},	//   _унга, _انسد, --, --,
   {{0x8c1b076b,0xb7db00a5,0x80da021a,0xe3b200fd}},	//   רוצי, _תקלי, पीने, _ہرا_,
   {{0x3ce9004e,0xd257021f,0x22b500ec,0x2d800282}},	//   _जिले_, йцы_, _nāku_, _oxie_,
   {{0xdfd00514,0x6fe2000c,0xb6a32d4d,0xdbda0132}},	//   وية_, jící, _хитл, nçói,
   {{0x3ea059b6,0xe1f9010b,0xdce400ea,0x50b70037}},	//   _ahit_, agų_, _dziļ, حديد_,
   {{0xe2ca0021,0x2002004e,0x3ea0009e,0x9e15093e}},	//   _след_, ęki_, _bhit_, одні,
   {{0x539b011d,0x877b1804,0x3ea03161,0x00000000}},	//   _גיבו, ראטי, _chit_, --,
   {{0x3ea0009e,0x00000000,0x00000000,0x00000000}},	//   _dhit_, --, --, --,
   {{0x7af503cb,0x645d010b,0xe0fb00a5,0x998908b7}},	//   tuzt, _įsik, _עלול, tjaž_,
   {{0x2246c1fe,0x00000000,0x00000000,0x00000000}},	//   _kook_, --, --, --,
   {{0x78ba01c0,0x386a099e,0x2246018d,0x7af501ed}},	//   _čtvr, _ambr_, _jook_, ruzt,
   {{0x22462f4b,0x3e720009,0x00000000,0x00000000}},	// [eb30] _mook_, ušte_, --, --,
   {{0x22464305,0x26130019,0x5c7513f9,0x44d60035}},	//   _look_, _ảo_, _флот, dł_,
   {{0x625cc1ff,0xb09b00a5,0xe1f9010b,0x28b5364c}},	//   _géog, ניבר, ygų_, _अंकि,
   {{0x3e720bec,0x37a80036,0x9f5e014c,0x00000000}},	//   pšte_, стун_, letó_, --,
   {{0x6d4f055c,0x26c700c7,0x69df01e9,0x2d8000a2}},	//   nyca, ūno_, maqe, _xxie_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44d6004e,0x22460122,0x04c905f5,0x00000000}},	//   ał_, _book_, _چوري_, --,
   {{0xe1f900d8,0x04c90413,0x69df01f4,0xda6f0009}},	//   ugų_, _نوري_, naqe, niя_,
   {{0x212bc200,0xdb1c008c,0x22460223,0xe1f900c7}},	//   ích_, sbrø, _dook_, rgų_,
   {{0x9477083a,0x648d0079,0x3ea03080,0x69df0c6f}},	//   _ادرا, rúis, _shit_, haqe,
   {{0xe80b06bc,0x533418ea,0x244b01cf,0x69df0031}},	//   स्या_, _нефт, _dømt_, kaqe,
   {{0xa6e20093,0x7bc555e5,0x00000000,0x00000000}},	//   æðil, _afhu, --, --,
   {{0xafe500c3,0x80c300c8,0xda6f0009,0x66d00260}},	//   _долл, _শিক্, diя_, _kòkò,
   {{0xb87b008d,0xf1b20319,0x7ae500e2,0xdb0a1dab}},	//   _svín, _חסד_, _bvht, žník,
   {{0x69df01f4,0x3ea0c201,0x6fe20355,0x3ce602b4}},	//   faqe, _thit_, sící, _झटके_,
   {{0x61fbc202,0x49ca0183,0x3ced01a0,0x31af045e}},	//   ngul, рлан_, ševa_, _gözü_,
   {{0x2d800051,0x00000000,0x00000000,0x00000000}},	// [eb40] _uxie_, --, --, --,
   {{0x6e24c203,0x7d040024,0x00000000,0x00000000}},	//   _haib, _iqis, --, --,
   {{0x2bd09526,0x6e240269,0x69df01e9,0x00000000}},	//   _त्या, _kaib, baqe, --,
   {{0xb87b0093,0x452a315d,0x645f0055,0x00000000}},	//   _hvíl, ижен_, ëqin, --,
   {{0x6e2418ad,0x224611ad,0xb87b00d5,0x7d04009f}},	//   _maib, _rook_, _kvíl, _jqis,
   {{0x68e47868,0xd4d901c8,0xc1d20099,0x69c400ea}},	//   msid, сьці_, सर्ग, lcie,
   {{0xd25a1714,0x68e41e8b,0x2246067f,0x648d0079}},	//   ици_, lsid, _pook_, túir,
   {{0xd37801cc,0x6e24c204,0x61fb0273,0x69c40720}},	//   _neće_, _naib, ggul, ncie,
   {{0x733600b5,0x22b500ea,0xdddd00a0,0x69c40228}},	//   _ڈرائ, _sākt_, nosť, icie,
   {{0x31af04d4,0x2246055c,0x6e36024b,0x258606fe}},	//   _sözü_, _wook_, _anyb, _cílů_,
   {{0x38170052,0x6e24c205,0x68e41bc5,0x224600a5}},	//   חקים_, _baib, hsid, _took_,
   {{0x6448c206,0x6e24184f,0x69c40035,0x999901ba}},	//   _hodi, _caib, jcie, _hosť_,
   {{0x61e0008f,0x6e2400f1,0x7e6f0176,0x999907c0}},	//   maml, _daib, ricp, _kosť_,
   {{0x6448c207,0xd00f004f,0xd1490a86,0x68e402ce}},	//   _jodi, _لله_, _دشمن_, dsid,
   {{0x64480a1f,0x6e240248,0x9f5e0a17,0x26d80051}},	//   _modi, _faib, retó_, _nwro_,
   {{0xddc401d6,0xfbd0006c,0x64486d2e,0x61e0023c}},	//   _iliş, فتہ_, _lodi, naml,
   {{0x7e6d01a2,0x645a0421,0x69df01f4,0x68e41bd3}},	// [eb50] _imap, _olti, raqe, gsid,
   {{0x6448c208,0xf72b0f22,0x61e0c209,0x6e249d3d}},	//   _nodi, ицей_, haml, _zaib,
   {{0x87e40086,0xe3d80083,0x501b0122,0x61e0c20a}},	//   ьюте, _সাংব, שובו, kaml,
   {{0x68e4c20b,0x69c4c20c,0x64480211,0x645ac20d}},	//   bsid, ccie, _aodi, _alti,
   {{0x672e022a,0x7c25027d,0x26d827b0,0x69dd00af}},	//   _erbj, _kahr, _ewro_, _iese,
   {{0x7c2502bf,0x64485e19,0xe787c20e,0x69ddc20f}},	//   _jahr, _codi, _дубо, _hese,
   {{0x69dd2bab,0x6448c210,0x62843262,0xd6c303c5}},	//   _kese, _dodi, čion, _آمری,
   {{0x645ac211,0x27e100d7,0xe0d900c3,0x61e00cfc}},	//   _elti, lahn_, бви_, gaml,
   {{0x69dd0bf0,0x6e240514,0xe80b0266,0x41b500f5}},	//   _mese, _raib, स्था_, _ہمار,
   {{0x6448c212,0x7c2514f0,0x69ddc213,0x6e24c214}},	//   _godi, _nahr, _lese, _saib,
   {{0x69c4004e,0x6e24c215,0xa2070644,0xddc40160}},	//   ycie, _paib, şmış_, _cliş,
   {{0xe80b0bc1,0x4425c216,0x69ddc217,0x64430a23}},	//   स्ता_, _hal_, _nese, ljni,
   {{0x4425c218,0x7c251051,0xd3780a78,0x6448b7c8}},	//   _kal_, _bahr, _veće_, _yodi,
   {{0xdb1cc219,0xb04201a5,0x8b0800b8,0x7c250260}},	//   scrí, _thưở, jdří, _cahr,
   {{0x69dd4978,0x09b420ab,0x765bc21a,0xdc670dfc}},	//   _bese, ंख्य, _oluy, чард_,
   {{0x68e4c21b,0x78b50029,0x69ddc21c,0x69c400ea}},	//   tsid, _aizv, _cese, ucie,
   {{0x7c2502bf,0x69c4c21d,0x2ebd0033,0x38c80088}},	// [eb60] _fahr, rcie, _আবিষ, تازی_,
   {{0x4425c21e,0x68e40d51,0x69c40502,0x397902ce}},	//   _nal_, rsid, scie, істю_,
   {{0xe8020825,0x3bbb00a5,0x7bde00af,0x61eb011c}},	//   र्गा_, _למיד, _iepu, _odgl,
   {{0x69ddc21f,0x6448c220,0x7c25086d,0x4425452a}},	//   _gese, _sodi, _zahr, _aal_,
   {{0x7bde0464,0x27e15270,0x76420088,0x61e0045e}},	//   _kepu, bahn_, rjoy, vaml,
   {{0x4425c221,0x7bde1d11,0x6448012f,0x6abe033b}},	//   _cal_, _jepu, _qodi, _kupf,
   {{0x4425c222,0x7bde046a,0x765b0453,0x69dd9d7e}},	//   _dal_, _mepu, _fluy, _yese,
   {{0x7bde5344,0xcb13011d,0x44276dd6,0x765b0118}},	//   _lepu, גלה_, adn_, _gluy,
   {{0x4425c223,0x644800c3,0x61e0c224,0xe8030803}},	//   _fal_, _todi, raml, _लामा_,
   {{0x442501c8,0x645ac225,0x4427596e,0x61e06ea0}},	//   _gal_, _ulti, cdn_, saml,
   {{0xd9a91d78,0x3de10033,0x6abe0371,0x00000000}},	//   _कण्ट, _ভাবল, _nupf, --,
   {{0x7c25c226,0x4425c227,0x61e0013b,0x225f8e7f}},	//   _sahr, _zal_, qaml, chuk_,
   {{0x69ddc228,0x4425c229,0x7bde0345,0x2a600103}},	//   _rese, _yal_, _bepu, dhib_,
   {{0x69dd03c3,0x4425013b,0x3ced01a0,0x7bde00ea}},	//   _sese, _xal_, ševo_, _cepu,
   {{0x69dd09df,0x9f620086,0x78bd6fef,0xb33c0069}},	//   _pese, ävän_, _susv, _agħz,
   {{0x7c2502c9,0x7e6d1292,0x2f9700a5,0x6abe04fb}},	//   _wahr, _umap, _מכון_, _dupf,
   {{0x69ddc22a,0x7c251d52,0x44272fa1,0xf4d70033}},	// [eb70] _vese, _tahr, ydn_, _সম্ব,
   {{0x69ddc22b,0x7bde152b,0x765b0051,0x6abe008c}},	//   _wese, _gepu, _sluy, _fupf,
   {{0x7e7dc22c,0xe719004f,0x69dd6de5,0x6abe0010}},	//   onsp, تيات_, _tese, _gupf,
   {{0x44251e4f,0x2a607f91,0x7e7dc22d,0xa3cf0099}},	//   _sal_, chib_, nnsp, वुन_,
   {{0x4425012c,0x00000000,0x00000000,0x00000000}},	//   _pal_, --, --, --,
   {{0x4425003c,0x3a2908dd,0xa49300fd,0x00000000}},	//   _qal_, ldap_, ریات, --,
   {{0x290900c3,0xd5fb00cc,0x00000000,0x00000000}},	//   ltaa_, _chụ, --, --,
   {{0x5694c22e,0x44257418,0x3a2965fc,0xddc40124}},	//   _заст, _wal_, ndap_, _omiš,
   {{0x442504f0,0x290903ad,0x442700e7,0x0019010b}},	//   _tal_, ntaa_, pdn_, оўны_,
   {{0xaec51847,0x78600448,0x225f081b,0x00000000}},	//   мбол, _gövd, shuk_, --,
   {{0x29090086,0x3ce90107,0xddc4093f,0x2f5400af}},	//   htaa_, _avav_, _amiš, етяс,
   {{0x7bde272d,0x1ee70332,0x2a605a08,0xdb1c033b}},	//   _sepu, _ہوتی_, xhib_, rbrü,
   {{0x7bdec22f,0x2d84c230,0x2fc70118,0x00000000}},	//   _pepu, çme_, _tfng_, --,
   {{0x78600332,0x394001e8,0x7e7d0298,0x39520421}},	//   _köve, vxis_, ansp, vyys_,
   {{0xa3e5046c,0x41d11f29,0x3ce9012f,0xddc40009}},	//   _भजन_, _सभास, _evav_, _emiš,
   {{0xe80b1af6,0x290902ee,0x00000000,0x00000000}},	//   स्सा_, ftaa_, --, --,
   {{0x7bde149f,0x4c862d7a,0xf8bf02d7,0x5fc401c0}},	// [eb80] _tepu, _олив, _cué_, लुकल,
   {{0x2a60542a,0x3940c231,0xd3780124,0x3a390183}},	//   shib_, rxis_, _leća_, _ensp_,
   {{0x7860006c,0xdb1c004f,0xb6c51958,0x290900ec}},	//   _növe, rbró, есій, ataa_,
   {{0xe8020fd0,0x7afca731,0xf8bf0831,0x00000000}},	//   र्जा_, murt, _fué_, --,
   {{0x69d6c232,0x1fe30033,0x94aa07bc,0x7afcc233}},	//   mbye, _মানস, отка_, lurt,
   {{0xa6e2008a,0x3e72010b,0xf8bf021d,0xd5fb00cc}},	//   æðsl, kšto_, _créu_, _phụ,
   {{0xe8030324,0x645d010b,0x7afc01ed,0x00000000}},	//   _लाता_, _įsit, nurt, --,
   {{0x30ea12da,0xc7a307b0,0x69d602d0,0x07a341f8}},	//   офон_, _риск, nbye, _расн,
   {{0x7afcc234,0x23cf06d9,0xf50301d3,0x53cf0edf}},	//   hurt, _स्वद, _изто, _स्वश,
   {{0x7afcc235,0xe8020fcf,0xc05701e0,0x9982007e}},	//   kurt, र्चा_, дію_, _laků_,
   {{0xe81000a1,0xddc4011c,0xb87b07c0,0x6458198d}},	//   ठ्या_, _smiš, _dvíh, mkvi,
   {{0x7afcc236,0x64580282,0xc7b300a5,0xf1a90088}},	//   durt, lkvi, כבת_, _کامه_,
   {{0x50660bd7,0xed5801c8,0x7e7d20f7,0x69d60a8c}},	//   _отка, доў_, rnsp, dbye,
   {{0xe57102b5,0x6458c237,0xd6df0035,0x78602af1}},	//   אַל_, nkvi, ółka_, _lövb,
   {{0x7afcc238,0xd5de142a,0x00000000,0x00000000}},	//   gurt, मराज, --, --,
   {{0x29090d36,0x786001c2,0x68f600e9,0x62820103}},	//   ttaa_, _növb, fryd, _jjoo,
   {{0xf8bf00c8,0xa3cf07ba,0x3835081b,0x2bd001d1}},	// [eb90] _qué_, वुड_, ннар, _त्वा,
   {{0x29090086,0x7afcc239,0x5c741897,0x7ac73a49}},	//   rtaa_, burt, _альт, _осме,
   {{0x8bd60052,0x0c74317b,0x29090d36,0xb906018d}},	//   _אותו_, _جديد, staa_, _यौ_,
   {{0x97a42bfa,0xfe100019,0x68f6c23a,0xf8bf00f7}},	//   трул, _lắng_, bryd, _tué_,
   {{0x6aad1b4b,0x78600282,0xe5040037,0xceb400a5}},	//   mmaf, _dövb, نبوي, דיף_,
   {{0x03a5c23b,0xfe1001a5,0xd3780c99,0x6282c23c}},	//   нило, _nắng_, _seća_, _ajoo,
   {{0x6282021d,0xc6060033,0x00000000,0x00000000}},	//   _bjoo, োয়া_, --, --,
   {{0x65956e5f,0xfbb80122,0xe810aa67,0x62820345}},	//   _забу, ופות_, ठ्ठा_, _cjoo,
   {{0xd3780a78,0xf1b9022f,0x7afc01a3,0xfe10055c}},	//   _veća_, ješe_, zurt, _bắng_,
   {{0x6458c23d,0x60092217,0xf1b902c4,0x9980082d}},	//   ckvi, чном_, deše_, ndiš_,
   {{0xbcfb0332,0xe3b32087,0x7d1603bc,0x6305026b}},	//   szél, _شرط_, _spys, _سوشل,
   {{0x3f9900ea,0x7afc02c4,0x00000000,0x00000000}},	//   āsu_, vurt, --, --,
   {{0xee3701af,0x00000000,0x00000000,0x00000000}},	//   хня_, --, --, --,
   {{0x7afcc23e,0xe0060b4a,0xfe100019,0x78600095}},	//   turt, _शायद_, _gắng_, _mövc,
   {{0x1e967b96,0x6fd50f06,0xdca30043,0xf99f0176}},	//   _прир, _म्यू, уари, _obès_,
   {{0x3dda00c8,0x2bd0143a,0x68f6c23f,0x7afcc240}},	//   _থাকল, _त्रा, tryd, rurt,
   {{0xe8fa2b34,0x6a831159,0x65b60095,0x69d6c241}},	// [eba0] яла_, улта, _mühü, rbye,
   {{0x7afcc242,0xb8821840,0x68f6037d,0x998002c4}},	//   purt, _čísl, rryd, gdiš_,
   {{0xe61a1c36,0x00000000,0x00000000,0x00000000}},	//   зде_, --, --, --,
   {{0x98a000cd,0x55061f76,0x76590298,0xcf92016b}},	//   kvić_, ечка, gkwy, נטא_,
   {{0xad9b0138,0x64580207,0xd5e700fd,0x26c50118}},	//   lfúr, tkvi, رٹون_, _élon_,
   {{0xdceb011c,0xb4e00066,0x0443c243,0x1c04018d}},	//   šićn, _दबी_, лечн, श्चल_,
   {{0xc79501c8,0x6458c244,0x625c000d,0x289700a5}},	//   _арты, rkvi, _déon, _נדלן_,
   {{0x179b0319,0xa50ac245,0xf8bf00cc,0x2d9e0067}},	//   _זילב, _неба_, _trét_, ętej_,
   {{0xe0cf0a86,0x98a00207,0x00000000,0x00000000}},	//   یزی_, gvić_, --, --,
   {{0x660200b5,0x00000000,0x00000000,0x00000000}},	//   lgok, --, --, --,
   {{0x81df0b52,0xfe100019,0x1df910b0,0xf1b90009}},	//   _তার_, _vắng_, мены_, veše_,
   {{0x6602c246,0x518600af,0x00000000,0x00000000}},	//   ngok, _пула, --, --,
   {{0xfe6e064e,0xf1b90009,0xa3200387,0x00000000}},	//   تگو_, teše_, _मनुज_, --,
   {{0x61e2c247,0x212601cb,0x2cba099e,0x00000000}},	//   _heol, _isoh_, _cipd_, --,
   {{0x60c203ad,0x0b881158,0x61e268d2,0x62800345}},	//   _huom, ести_, _keol, onmo,
   {{0x201ec248,0x60c2c249,0x1d3501af,0x66e700b8}},	//   leti_, _kuom, _ания, _léká,
   {{0x60c200c3,0xf1b900f4,0x00000000,0x00000000}},	// [ebb0] _juom, peše_, --, --,
   {{0xb8e9009a,0x61e2580c,0x3b550043,0x60c208c7}},	//   _लं_, _leol, _акор, _muom,
   {{0x3ea900d7,0x60c200c3,0x629b5153,0x99801bd8}},	//   _khat_, _luom, yluo, rdiš_,
   {{0xfb1a00f5,0xd57517e0,0x201e00b5,0x212600ee}},	//   _کریں_, куль, heti_, _osoh_,
   {{0x201ec24a,0x60c201c8,0x3a2b0036,0x5a3400c3}},	//   keti_, _nuom, _iacp_, _снят,
   {{0x201ec24b,0x2ba804bc,0x3ea908dd,0x660201a3}},	//   jeti_, _गरमा, _lhat_, agok,
   {{0xf8bf0248,0x5c3800a5,0x21260107,0xe7841d13}},	//   _trés_, תרון_, _asoh_, _буто,
   {{0x3ea90019,0x61e20037,0xd24e026e,0x60c2005f}},	//   _nhat_, _ceol, قنى_, _buom,
   {{0xd24e017e,0x60c21bc8,0x201ec24c,0x21260176}},	//   تني_, _cuom, feti_, _csoh_,
   {{0x60c201c8,0x857410cc,0x201ec24d,0x26c30124}},	//   _duom, _слух, geti_, _kujo_,
   {{0xf1d200b4,0x200b0035,0x27e30009,0x3ea90069}},	//   _ध्वन, ęci_, _mejn_, _bhat_,
   {{0x26c3bf74,0x27e30484,0x29190124,0x13e60033}},	//   _mujo_, _lejn_, _opsa_, _নায়,
   {{0x26fe0299,0x26c30033,0x7ebe00e1,0x1e83010b}},	//   _उम्र_, _lujo_, _rūpe, рлям,
   {{0x201ec24e,0x61e2c24f,0x224f0345,0x68ff013b}},	//   ceti_, _zeol, _hogk_, duqd,
   {{0xfe0a0953,0x09e601ee,0x61e20159,0x26c3023a}},	//   _वापस_, ковн, _yeol, _nujo_,
   {{0xc3320122,0x61e201dd,0x3ea9c250,0xc0b900b8}},	//   סון_, _xeol, _ghat_, řádá,
   {{0xad9b043f,0x27e30484,0x26d106a2,0x81b30083}},	// [ebc0] lgún, _bejn_, _atzo_, জুর_,
   {{0xed5700a5,0x7d57025a,0x00000000,0x00000000}},	//   _סביר_, _סייד_, --, --,
   {{0x7c3e06a2,0xb8e90243,0x26c30279,0x27e3035f}},	//   _inpr, _लू_, _cujo_, _dejn_,
   {{0x201ec251,0x3ce00359,0x78600282,0x00000000}},	//   zeti_, _kwiv_, _döva, --,
   {{0x61e2001e,0x27e30484,0x201ec252,0x2d8f01b4}},	//   _reol, _fejn_, yeti_, _øget_,
   {{0x61e24b36,0x29000054,0x26c3002f,0x7c2e521d}},	//   _seol, muia_, _fujo_, ndbr,
   {{0x60c20d36,0x61e27b7d,0x65c602ee,0xf7430f24}},	//   _suom, _peol, _абба, _керо,
   {{0x78bc3075,0x3ced0ce9,0x625c00f7,0x201e0027}},	//   _hirv, ševi_, _géol, weti_,
   {{0x201ec253,0x62801791,0x30a60142,0x78bc26dd}},	//   teti_, rnmo, кров, _kirv,
   {{0xb42509b9,0x27e30484,0x3ea9c254,0x26c30118}},	//   _معمو, _xejn_, _shat_, _yujo_,
   {{0x442c41e3,0x3ea90019,0x52260d8a,0x81b30033}},	//   _iad_, _phat_, _афла, জুল_,
   {{0x442cc255,0x60c2325e,0x201ec256,0xb87b0093}},	//   _had_, _tuom, seti_, _hvít,
   {{0x442cc257,0xe80304bc,0xc69300a5,0x443e008c}},	//   _kad_, _लाला_, שאר_, _knt_,
   {{0x3ea901f3,0x442ca36c,0xd0100789,0x20563e1f}},	//   _what_, _jad_, _طلب_, _штер,
   {{0x3ea935d9,0xa3200006,0x1613045c,0x443e00ab}},	//   _that_, _मनोज_, ण्डर_, _mnt_,
   {{0x442c01b4,0x7c3ec258,0x320400cc,0x443e0029}},	//   _lad_, _enpr, ngmy_, _lnt_,
   {{0x443ec259,0x2d8f0248,0xa8150036,0x2900c25a}},	// [ebd0] _ont_, _âge_, лдаш, guia_,
   {{0xf1b9123c,0x443ec25b,0x6e2d1447,0x26c301f7}},	//   neša_, _nnt_, _haab, _pujo_,
   {{0x6e2dc25c,0x442e0297,0x2bd9051d,0x78bcc25d}},	//   _kaab, ddf_, _ब्या, _dirv,
   {{0x443ec25e,0x41b4045c,0x2900002d,0x79a702c8}},	//   _ant_, ुशास, buia_, _арге,
   {{0x6e2d40ee,0x442c567f,0x443e0088,0x7d0d009f}},	//   _maab, _bad_, _bnt_, _jqas,
   {{0x442c0082,0x81df00c8,0x6e2dc25f,0x260816c1}},	//   _cad_, _তাই_, _laab, _हाथी_,
   {{0xe299c260,0x443e30bc,0xf1b90009,0x442cc261}},	//   нак_, _dnt_, deša_, _dad_,
   {{0x6e2da44f,0x442c872b,0xb87b002a,0x78bc0644}},	//   _naab, _ead_, _evít, _zirv,
   {{0x442c04d6,0x6abdc262,0x3e620037,0x625c00f7}},	//   _fad_, _misf, _nóta_, _géom,
   {{0x442cc263,0x68ed03e6,0xc95200a5,0x443ec264}},	//   _gad_, isad, צמי_, _gnt_,
   {{0x6e2d0273,0x2900000e,0x3ce002e9,0x5f0500d8}},	//   _baab, zuia_, _swiv_, ызна,
   {{0x68edc265,0x442cc266,0x9f450097,0x7d0d0069}},	//   ksad, _zad_, nalé_, _bqas,
   {{0x442c00a8,0x443e01d6,0x3e620098,0xf1b900f4}},	//   _yad_, _ynt_, _cóta_, beša_,
   {{0xd9dc00b4,0x2d9e0228,0x61e9c267,0x7e660055}},	//   बर्ट, āte_, lael, shkp,
   {{0x6eca0d00,0x660916ae,0x68ed1741,0x7c2ec268}},	//   _संयु, _ocek, esad, rdbr,
   {{0x6e2d01a8,0x78bc23aa,0x68ed0523,0x61e90054}},	//   _gaab, _sirv, fsad, nael,
   {{0xed5a052a,0x6abd0b68,0x68edc269,0x7e64c26a}},	// [ebe0] _чоп_, _disf, gsad, _ilip,
   {{0x61e9002d,0x20c901a5,0x2900002d,0x6e2d0273}},	//   hael, _múi_, ruia_, _zaab,
   {{0x6e2d01a8,0x442cc26b,0x7bdcc26c,0xfba814ab}},	//   _yaab, _rad_, mbru, _गरिम,
   {{0x68ed87bf,0xb87b00b8,0x7bdc493e,0x6b7b0070}},	//   bsad, _svít, lbru, _טרינ,
   {{0x442cc26d,0x29001a71,0x68ed00b5,0x20c901a5}},	//   _pad_, quia_, csad, _núi_,
   {{0x7bdc28a9,0x442c1684,0x443e1783,0x7bce02c4}},	//   nbru, _qad_, _qnt_, ncbu,
   {{0x442cc26e,0x2c16018d,0x443e010b,0x7529018e}},	//   _vad_, द्यं_, _vnt_, _esez,
   {{0x61e9c26f,0x6f01c270,0x442cc271,0x82a600c3}},	//   gael, dulc, _wad_, ышле,
   {{0x442cc272,0x443ec273,0x20c90023,0xf1b90207}},	//   _tad_, _tnt_, _cúi_, teša_,
   {{0xdefaa548,0x7e640657,0x6e2dc274,0x443ec275}},	//   ным_, _alip, _saab, _unt_,
   {{0x68edc276,0x6e2dc277,0x7bdc0b41,0xf1b900f4}},	//   zsad, _paab, dbru, reša_,
   {{0x61e9027d,0x6e9500d4,0x68edabfc,0x7bdc0051}},	//   cael, риму, ysad, ebru,
   {{0x22930082,0xf1b900f4,0x7bdc84a9,0x00000000}},	//   _النس, peša_, fbru, --,
   {{0x7e6403fa,0x6e2d01a8,0x3e620037,0x6f01c278}},	//   _elip, _waab, _vóta_, bulc,
   {{0x309b0122,0x6e2d4179,0x00000000,0x00000000}},	//   _רשומ, _taab, --, --,
   {{0x68edc279,0x7e6423c2,0xa3be0066,0x5bb800c3}},	//   tsad, _glip, _ेलन_, улся_,
   {{0x99820009,0x7afc0037,0x987518d0,0x7c66132d}},	// [ebf0] _pakš_, arrt, алац, _چاپل,
   {{0x68edc27a,0x2c667667,0x2be6012f,0x26c50118}},	//   rsad, _pôde_, करणं_, _élok_,
   {{0x97a7c27b,0x68edc27c,0x61e908c7,0x7e6400c3}},	//   урал, ssad, yael, _ylip,
   {{0x3ced00cb,0xa5350279,0x56950421,0x00000000}},	//   ševu_, инеч, шает, --,
   {{0xd12615f4,0x5887325e,0x61e9c27d,0x3e7200f4}},	//   _بم_, _быва, vael, ušti_,
   {{0xa87900c2,0xc4840131,0x61e90054,0x2a69006d}},	//   _יאָר, блік, wael, lhab_,
   {{0x61e9c27e,0x9f5100c1,0x7860013b,0x00000000}},	//   tael, üzü_, _mövl, --,
   {{0x3e7202c4,0x2ce50127,0xb87b003e,0x00000000}},	//   pšti_, _कबूल_, _tvís, --,
   {{0x394901dd,0x7bdc079a,0xe6642839,0x75290371}},	//   nxas_, ybru, _утро, _usez,
   {{0x7ebf013a,0x2055c27f,0x39494f54,0x2a69012f}},	//   _rūpa, ртир, ixas_, hhab_,
   {{0x8fa5087b,0xfe460086,0x200502fb,0xdb1c0037}},	//   ране, анно, rgli_, scrú,
   {{0xed5a1306,0x20c901a5,0x62990371,0x00000000}},	//   вом_, _túi_, _ukwo, --,
   {{0xc0e54db5,0xa6960122,0x7bdc008c,0x92b40079}},	//   _толк, שכרה_, tbru, _احلا,
   {{0x6f01bee2,0x224d02c6,0xdde500ea,0x69c10139}},	//   pulc, ljek_, āpša, _şlep,
   {{0x78600669,0xeb9a271c,0xddcd0723,0xf99f021e}},	//   _dövl, тив_, _ulaş, _ayè_,
   {{0x7bdc2d2e,0x7e64c280,0x6eca00fa,0xeabf009e}},	//   sbru, _ulip, _संतु, _ciù_,

   {{0xeabf0211,0x00000000,0x00000000,0x00000000}},	// [ec00] _diù_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75e600d8,0xbb4600ed,0xeabf00f1,0x87ba002d}},	//   аўле, _тенк, _fiù_, туат_,
   {{0xeabf0382,0x6441c281,0x387a0159,0x25a00183}},	//   _giù_, _anli, sipr_, üilo_,
   {{0xe53407f5,0x963300d8,0xcb9705f5,0x225f0009}},	//   сель, ўніц, _منیش_, dkuk_,
   {{0xb6020355,0xf5390168,0x26080167,0x04580037}},	//   _řádk, _drť_, _हावी_, طلبة_,
   {{0x24800254,0x3266174b,0x00000000,0x00000000}},	//   đim_, итив, --, --,
   {{0xd2570086,0x644149f7,0xd576365f,0xddcd00f4}},	//   ицы_, _enli, _кузь, _omaš,
   {{0x81e80083,0x2912c282,0x26da00c3,0x00000000}},	//   _বাদ_, ntya_, lppo_, --,
   {{0x2a690ec0,0x32ca01a5,0xd7aa02e4,0xd378012e}},	//   zhab_, _tùy_, _कराच, _leći_,
   {{0x50b7004f,0x224d0ce8,0xb80b4e29,0x4ea71a55}},	//   جديد_, bjek_, स्टम_, ирма,
   {{0x2a695b0b,0x00000000,0x00000000,0x00000000}},	//   xhab_, --, --, --,
   {{0x39490069,0xb87b01ef,0xeabf0211,0x00000000}},	//   xxas_, _ovíp, _riù_, --,
   {{0x515b00a5,0x00000000,0x00000000,0x00000000}},	//   _בכדו, --, --, --,
   {{0xeabf0021,0xdb5803ad,0xee870086,0x2c160096}},	//   _più_, ают_, _выпо, द्धं_,
   {{0xe8195dc3,0x8f9b0122,0xf99f02e9,0x7afa3c0e}},	//   न्ना_, _שיהי, _pyè_, átta,
   {{0x7e7dc283,0x9f471214,0xf1b3016b,0x00000000}},	// [ec10] misp, _nenê_, ַסע_, --,
   {{0x2a69012f,0x1c1600a1,0x7e7dc284,0x3949002a}},	//   shab_, द्दल_, lisp, rxas_,
   {{0x6d5dc285,0xc5d51958,0x7bc50008,0x00000000}},	//   lysa, біль, _ighu, --,
   {{0x7e7d0054,0xf99f021e,0x00000000,0x00000000}},	//   nisp, _tyè_, --, --,
   {{0x224d029d,0x26080084,0x6d5dc286,0xbcfb00b5}},	//   vjek_, _हारी_, nysa, mzés,
   {{0x7e7da30c,0xbcfb00b5,0x2c1a0380,0x240901e0}},	//   hisp, lzés, म्पू_, унки_,
   {{0x7e7d35a1,0x7ebf00ea,0x224d5138,0x7cfe008d}},	//   kisp, _rūpn, tjek_, _kærð,
   {{0x56942327,0xc2450cb5,0xcfe30083,0x316d01d7}},	//   _даст, сник, _মাইন, tzez_,
   {{0x661bc287,0xa1120037,0x224d0987,0x6441009e}},	//   _ibuk, كويت, rjek_, _tnli,
   {{0x442300f5,0x753b03cb,0x6d5d00e5,0xae0a1db9}},	//   _új_, _iruz, dysa, _वाहन_,
   {{0xe8190967,0x54340609,0xddcd0009,0x753b00d5}},	//   न्या_, _برقر, _smaš, _hruz,
   {{0x7e7dc288,0x6ed30395,0x00000000,0x00000000}},	//   gisp, _răbd, --, --,
   {{0xd378326f,0x9f4701f4,0x661b00d1,0x9f456886}},	//   _reći_, _kenë_, _mbuk, malí_,
   {{0x9f4700da,0xc0b20019,0xd3780009,0x63a1c289}},	//   _jenë_, _mười_, _seći_, _kyln,
   {{0x661b09d6,0x7e7d1d2b,0xcaa6004f,0xd378011c}},	//   _obuk, bisp, مصري, _peći_,
   {{0x2a7900d7,0x753b012e,0x6d5d1f8b,0xbcfb00b5}},	//   _cmsb_, _oruz, bysa, gzés,
   {{0xa3e70587,0xd3780a78,0x2f11006c,0x39460279}},	// [ec20] परा_, _veći_, lág_, ãos_,
   {{0x7d0603ad,0x661ba3e1,0x291200b5,0x9f47021d}},	//   muks, _abuk, rtya_, _renê_,
   {{0x7d06c28a,0x291200f8,0x81e80033,0x661b6fad}},	//   luks, stya_, _বাস_, _bbuk,
   {{0x69da002d,0x00000000,0x00000000,0x00000000}},	//   _ştef, --, --, --,
   {{0x753b0aca,0xc0b20028,0x7d06c28b,0x8936250f}},	//   _cruz, _cười_, nuks, _اعجا,
   {{0x753b0b67,0x661b030d,0x3358002d,0xf746846a}},	//   _druz, _ebuk, иалэ_, _лего,
   {{0x753bc28c,0xf99f0118,0x7d06194e,0x00000000}},	//   _eruz, _acèh_, huks, --,
   {{0x60f846d8,0x2900c28d,0xd251006c,0x6aa4c28e}},	//   ания_, oria_, ِنٹ_, nlif,
   {{0xc05a0402,0x26ca31ce,0x60db08dd,0x05661747}},	//   гін_, _hubo_, gpum, _уван,
   {{0x7d06c28f,0x26cac290,0x2ef40ea0,0x661b0031}},	//   duks, _kubo_, озор, _zbuk,
   {{0x6aa40463,0x889b0319,0x9f452141,0x63a10044}},	//   klif, רביי, balí_, _gyln,
   {{0x6e6701d3,0x6d5d0421,0x9fbe00ac,0x27ea009e}},	//   стож, tysa, _učím_, _lebn_,
   {{0x7e7dc291,0xa3cf0ccf,0xe8192df6,0x26ca0168}},	//   risp, वुक_, न्डा_, _lubo_,
   {{0x26d81819,0x2900c292,0x6d5dc293,0x7e7dc294}},	//   _otro_, dria_, rysa, sisp,
   {{0x2900c295,0xf3f10023,0x307b00a5,0x00000000}},	//   eria_, _học_, _תאונ, --,
   {{0x2bd90d00,0x38c9006c,0x7d06c296,0x2900c297}},	//   _ब्रा, لائی_, buks, fria_,
   {{0x2900c298,0xbcfb006c,0x38af02b1,0x672e1217}},	// [ec30] gria_, rzés, hüre_, _asbj,
   {{0x9f470260,0x753b0031,0x00000000,0x00000000}},	//   _benè_, _rruz, --, --,
   {{0x8a190043,0x2900c299,0x6aa400ac,0x37ab0200}},	//   _конс_, aria_, blif, утан_,
   {{0x2900c29a,0xadfb045c,0x753b116d,0x1a650987}},	//   bria_, ्लिन_, _pruz, _بیری_,
   {{0x2f11006c,0x672e01b4,0x81c30083,0x2bd001d1}},	//   zág_, _esbj, ্রম_, तुका,
   {{0x9f4701d2,0x58d42f54,0x26c7063c,0xf77300bc}},	//   _qenë_, _хорт, ínos_, _فاز_,
   {{0x850501cb,0x4dfb0963,0xae0a00ab,0x00000000}},	//   _ژورن, ्लाई_, _वालन_, --,
   {{0xd3780470,0x661b0232,0x6b7c0d85,0x753b027a}},	//   _neću_, _ubuk, טרונ, _truz,
   {{0x753b01d5,0x7e8b0067,0xfe7f0176,0x26ca0207}},	//   _uruz, tępn, diï_, _zubo_,
   {{0x2bd90953,0xe3b32087,0xef1903fa,0x63a10035}},	//   _ब्ला, _فرض_, амо_, _tyln,
   {{0x81e800c8,0xbba809a3,0x6e2600b5,0x7c270035}},	//   _বার_, _गरेक, tekb, dejr,
   {{0x7d060d36,0xe8197f73,0x29000168,0x60cd0079}},	//   tuks, न्ता_, yria_, _éamo,
   {{0x2f110332,0x4427c29b,0x9f47000d,0x6e2600fd}},	//   ság_, oen_, _mené_, rekb,
   {{0x7d06c29c,0x6aa4099e,0x25ad0107,0x7c270118}},	//   ruks, wlif, _mzel_, gejr,
   {{0x6aa4c29d,0x4427c29e,0x60cb008a,0xa09a0070}},	//   tlif, ien_, _hugm, _דיסט,
   {{0x4427c29f,0x2900bbcd,0x6289c2a0,0x9f470036}},	//   hen_, tria_, nneo, _renè_,
   {{0x4427c2a1,0x61ebc2a2,0x26ca63a8,0xbcfb006c}},	// [ec40] ken_, _megl, _subo_, szér,
   {{0x290003cb,0x61eb02e9,0x60c30069,0x62890098}},	//   rria_, _legl, _jinm, hneo,
   {{0xbc6a09b9,0xa3180084,0xe5c617a3,0x2fc70159}},	//   _ممکن_, _दहेज_, осло, _mgng_,
   {{0x4427c2a3,0x29004a10,0xd94611d0,0x61eb0a1f}},	//   een_, pria_, _деми, _negl,
   {{0x4427c2a4,0x9f470118,0x28c337e8,0x6fc90ec5}},	//   fen_, _dené_, _वंचि, रशां,
   {{0x4427c2a5,0x66e6c2a6,0xe819000c,0x2fc70159}},	//   gen_, _мога, न्दा_, _ngng_,
   {{0x07a3151c,0x26d811cb,0x61eb1d8e,0x25ad0225}},	//   _жарн, _utro_, _begl, _ezel_,
   {{0x60c31093,0xf99f0260,0x9f470176,0x41e60402}},	//   _ainm, _abèy_, _gené_, ціка,
   {{0x4427c2a7,0x61eb0133,0xf8af006c,0x3fc80609}},	//   ben_, _degl, _سکے_, یدگی_,
   {{0x4427c2a8,0x60cbaa76,0x3ea0c2a9,0x26c4c2aa}},	//   cen_, _dugm, _akit_, _himo_,
   {{0x3ea008dd,0x60cb0211,0x3eb200e2,0x26c4023c}},	//   _bkit_, _eugm, _bhyt_, _kimo_,
   {{0x60c3c2ab,0x62890a32,0x61ebc2ac,0x78600225}},	//   _einm, cneo, _gegl, _dövi,
   {{0xd3780254,0x60cb1296,0x60c36eed,0x22460065}},	//   _veću_, _gugm, _finm, _inok_,
   {{0xed4e00b5,0x35cc07b5,0x27170355,0x3eb2081b}},	//   چھی_, ़खड़, něná_, _ehyt_,
   {{0x9f450176,0x00000000,0x00000000,0x00000000}},	//   calà_, --, --, --,
   {{0x4427c2ad,0x26c42922,0x63a708c8,0x625c00a2}},	//   zen_, _nimo_, _øjne, _géot,
   {{0x4427c2ae,0x9f47c2af,0x3eb97282,0xf4e50033}},	// [ec50] yen_, _rené_, mmst_, _নম্ব,
   {{0x4427c2b0,0x6280c2b1,0x200cc2b2,0x9f450453}},	//   xen_, himo, ngdi_, lalá_,
   {{0x4427c2b3,0xd7c801cb,0x628031ee,0x26c4027c}},	//   ven_, زونه_, kimo, _bimo_,
   {{0x4427c2b4,0xa3dd1b8f,0x6280c2b5,0x26c4c2b6}},	//   wen_, थुन_, jimo, _cimo_,
   {{0x6280c2b7,0x26c4c2b8,0x00000000,0x00000000}},	//   dimo, _dimo_, --, --,
   {{0x4427c2b9,0x61ebc2ba,0x6d4f0176,0x60cb008c}},	//   uen_, _segl, ixca, _rugm,
   {{0x4427c2bb,0x61eb022f,0x60c302d0,0x290900c3}},	//   ren_, _pegl, _rinm, luaa_,
   {{0x7860006c,0xae0a0bdd,0x26c40282,0x00000000}},	//   _rövi, _वाइन_, _gimo_, --,
   {{0x4427c2bc,0x61ebc2bd,0x6289662c,0x5ba80569}},	//   pen_, _vegl, rneo, _गर्व,
   {{0x9f450955,0x442700da,0xe5c476f4,0x3ea03e7e}},	//   talà_, qen_, _істо, _skit_,
   {{0x6280c2be,0x61ebc2bf,0x60c30f0a,0x3ea6260f}},	//   bimo, _tegl, _vinm, зинг,
   {{0x62800b4c,0x60cbc2c0,0x22460036,0x26c40d9a}},	//   cimo, _tugm, _gnok_, _ximo_,
   {{0x80de0083,0x60c300e2,0x3ce9009e,0x42524d1e}},	//   _মিথ্, _tinm, _cwav_, _سنور,
   {{0xc17201f3,0x3e62008a,0xf1b9003a,0xa15600a5}},	//   _אחד_, _móti_, ješi_, _מבנה_,
   {{0xcb67002d,0xe9df0093,0xbb43c2c1,0x625c00f6}},	//   паре_, _snúa_, нерк, _géos,
   {{0x32d1098b,0x9f451111,0x3ea00430,0x80de0033}},	//   _máy_, calá_, _ukit_, _মিত্,
   {{0x7af5006c,0x3ce9021e,0x00000000,0x00000000}},	// [ec60] aszt, _gwav_, --, --,
   {{0x44e9004e,0x6280c2c2,0x6e360a21,0x97b600af}},	//   dź_, zimo, _hayb, псеш,
   {{0x6e3601d6,0x212dc2c3,0x25a400e9,0x3ec5033e}},	//   _kayb, hweh_, _syml_, _üstü_,
   {{0x69b40026,0x6e3683fe,0x4efa016b,0x00000000}},	//   _आरपी, _jayb, מלעג, --,
   {{0x4ad2009a,0xe81933f0,0x64a63b6c,0x6280c2c4}},	//   _दंडव, न्हा_, пада, vimo,
   {{0x81c30083,0x1c1f00b4,0x26080354,0x81e80033}},	//   ্রা_, म्पल_, _हाकी_, _বাই_,
   {{0x26c4c2c5,0x9f58033e,0x3e620c8e,0x00000000}},	//   _timo_, ürü_, _tóth_, --,
   {{0x46a3c2c6,0x00000000,0x00000000,0x00000000}},	//   _засв, --, --, --,
   {{0x628003d0,0x9f450187,0x00000000,0x00000000}},	//   rimo, valá_, --, --,
   {{0x6280c2c7,0x2937016b,0x00000000,0x00000000}},	//   simo, לאפן_, --, --,
   {{0x6e36c2c8,0x9f4501dd,0x6e950043,0x628002d7}},	//   _bayb, talá_, дину, pimo,
   {{0x645ac2c9,0x2002027d,0x2c6f02b1,0x3ce9021e}},	//   _hoti, şki_, _müde_, _pwav_,
   {{0x645ac2ca,0x6e36a277,0xfd4700d8,0x6562c2cb}},	//   _koti, _dayb, чэнн, nyoh,
   {{0x91bb0122,0x625c000d,0x6ac5007e,0x00000000}},	//   _המדי, _géor, वद्र, --,
   {{0xe81000dc,0x64480118,0x00000000,0x00000000}},	//   ालना_, _mndi, --, --,
   {{0x64483081,0x7af52e2f,0x3ce94c9d,0x00000000}},	//   _lndi, rszt, _twav_, --,
   {{0x645a0009,0x6448c2cc,0x383500af,0x7e6d1292}},	// [ec70] _ooti, _ondi, мнар, _ilap,
   {{0x645ac2cd,0x7e6d0b67,0xb905007c,0x6562007b}},	//   _noti, _hlap, _नऽ_, dyoh,
   {{0xf1b90009,0xe6c70698,0xc3240831,0xf3f1055c}},	//   reši_, ستاي, ভিডি_, _bọn_,
   {{0x6448c2ce,0x645a009e,0x2bd901c0,0x4ad2021a}},	//   _andi, _aoti, बुरा, _दंतव,
   {{0x645ac2cf,0x7c3701ef,0x2bb50099,0x7e6d179a}},	//   _boti, _kaxr, ंधका, _mlap,
   {{0xdfc60082,0x7e6dc2d0,0x03a56118,0x85b800f8}},	//   _لي_, _llap, мило, سانس_,
   {{0xf79400d8,0x6562011e,0x625c000d,0x7c37055c}},	//   _зарэ, ayoh, _réor, _maxr,
   {{0xe0d90859,0x32d101a5,0x644844a7,0x161400b4}},	//   ови_, _váy_, _endi, _डायर_,
   {{0x645a9c6d,0x320dc2d1,0x20d200e5,0x65620027}},	//   _foti, rgey_, _câi_, cyoh,
   {{0x7e6d0332,0xb87b0501,0x7649008d,0x00000000}},	//   _alap, _avíz, _hney, --,
   {{0x6e360096,0x7e6d0345,0x7bc80124,0x765b0260}},	//   _payb, _blap, žduk, _kouy,
   {{0x7e6dc2d2,0x645a00da,0x68f6001e,0x765b0107}},	//   _clap, _zoti, ysyd, _jouy,
   {{0x38b410c0,0x64480093,0x20180443,0x57aa018d}},	//   läre_, _yndi, òric_, _कर्ह,
   {{0x4e0a0084,0x3f6918cd,0x00000000,0x00000000}},	//   _वाकई_, _мило_, --, --,
   {{0x6e3601a2,0xfaa600d8,0x38b4033b,0xddc40139}},	//   _tayb, даво, näre_, _bliţ,
   {{0x4cdd0083,0x765b02d0,0x1e95010b,0x7e6d1b4b}},	//   _বিরু, _nouy, _прыр, _glap,
   {{0xfaa32819,0x38b4033b,0x7c370510,0x9f4700a0}},	// [ec80] тато, häre_, _faxr, _mení_,
   {{0x38b40282,0x76490283,0x68f630e5,0x6562002f}},	//   käre_, _aney, rsyd, vyoh,
   {{0x765b4dff,0x645ac2d3,0xf1b9c2d4,0xdb2400c3}},	//   _bouy, _roti, mešu_, äräs,
   {{0x9f47000c,0x645ac2d5,0x26dc0029,0x05aa0043}},	//   _není_, _soti, īvo_, овей_,
   {{0x645ac2d6,0x28af1140,0xb9030033,0x6aa30132}},	//   _poti, _जीवि, _নয়_, _ênfa,
   {{0x656201d5,0x7649030d,0xd467275f,0xf1b90228}},	//   ryoh, _eney, миче_, nešu_,
   {{0x645aa3f2,0x765b02e9,0x65620c47,0xb87b0093}},	//   _voti, _fouy, syoh, _stíg,
   {{0x32b70082,0xd250004f,0x6562011e,0x9f4700d5}},	//   ودية_, انة_, pyoh, _cení_,
   {{0x645ac2d7,0x00000000,0x00000000,0x00000000}},	//   _toti, --, --, --,
   {{0x6448c2d8,0x7e6d988d,0x15f80cf1,0xf99300a5}},	//   _undi, _slap, ुलकर_, כרח_,
   {{0xd9ee0141,0x7e6d1500,0xdbc70282,0xf1b900f4}},	//   जरात_, _plap, _höök, dešu_,
   {{0xa40e0722,0x625c00a2,0x940e00ab,0x787208c8}},	//   _साँप_, _géop, _साँच_, _hævd,
   {{0x161343fd,0x7e6d0298,0x859b016b,0x394203d0}},	//   ण्टर_, _vlap, ַשלו, _nrks_,
   {{0x5fd200ab,0x2126104e,0x80d50083,0x786000a8}},	//   _सलिल, _ipoh_, _দিচ্, _mövs,
   {{0x20190669,0xdeef0c8a,0x7e6dc2d9,0x260f13a0}},	//   əsi_, _шы_, _tlap, _डाली_,
   {{0x7e6d00f1,0x63a80176,0x394200ee,0x6ed30160}},	//   _ulap, _mydn, _brks_, _zăbo,
   {{0xdff20084,0xa40e0084,0x26080026,0x940e00ab}},	// [ec90] _आजाद_, _सांप_, _हाजी_, _सांच_,
   {{0x37ab3cc0,0x765b0260,0x00000000,0x00000000}},	//   отен_, _souy, --, --,
   {{0x765b2c60,0x00000000,0x00000000,0x00000000}},	//   _pouy, --, --, --,
   {{0xd7df0517,0x645e022a,0xe7df111a,0x3a22012f}},	//   _प्रच, öpin, _प्रप, _gbkp_,
   {{0x94251303,0x2a690feb,0x286b0bfe,0x5887010b}},	//   емле, mkab_, _дрво_, _жыва,
   {{0x201e0009,0x344b195c,0x81e80033,0xee3f00d5}},	//   jfti_, ючен_, _বাগ_, dlým_,
   {{0x765b0c1f,0x2489003a,0x63a800e9,0x80de0033}},	//   _touy, đam_, _cydn, _মিষ্,
   {{0x2a6920e5,0x3a390260,0xda0f0167,0x7afa003e}},	//   nkab_, _jasp_, िलित_, átti,
   {{0x101500d8,0x3a390183,0x9f4702d7,0x00000000}},	//   ньня, _masp_, _vení_, --,
   {{0x26d1030d,0x3a390282,0x00000000,0x00000000}},	//   _kuzo_, _lasp_, --, --,
   {{0x20180955,0x2a69007c,0x63a800e9,0x00000000}},	//   òria_, kkab_, _gydn, --,
   {{0x3e620093,0xddc40197,0x26d1030d,0x00000000}},	//   _nótt_, _ališ, _muzo_, --,
   {{0xddc4023a,0x787208c8,0x1e95002d,0x00000000}},	//   _bliš, _hæve, трэр, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00e0514,0x29190034,0xf1b900ea,0xfe720037}},	//   _الى_, _aqsa_, rešu_, _مدة_,
   {{0x2a69011e,0x3a3901f7,0xddc40184,0x00000000}},	//   gkab_, _casp_, _eliš, --,
   {{0x6e24031e,0x26d101a3,0x00000000,0x00000000}},	// [eca0] _ibib, _auzo_, --, --,
   {{0x6d44c2da,0x26d10453,0x9f4c031d,0xddc400cd}},	//   _iria, _buzo_, zadí_, _gliš,
   {{0x2a6900d7,0x6d4407c0,0xdbc700be,0x7872008c}},	//   bkab_, _hria, _söök, _næve,
   {{0xb8f600c8,0x9f4e0260,0x6d4400c7,0x38af033b}},	//   _সব_, _defè_, _kria, büro_,
   {{0xe5340d36,0x786001c2,0x9f4c0097,0x6e241939}},	//   тель, _dövr, vadí_, _mbib,
   {{0xe6600381,0x78720a8a,0x3ea20223,0x7c3c0055}},	//   ırış, _bæve, hokt_, ndrr,
   {{0x68e46744,0xe7e00099,0x2126023a,0x6e24662a}},	//   lpid, खुणा_, _spoh_, _obib,
   {{0x6d44001e,0xdbc7007c,0x786000a8,0x00000000}},	//   _oria, _töök, _tövs, --,
   {{0x6d44006d,0x3940c2db,0x3ce00221,0x9f4c0bca}},	//   _nria, nvis_, _ntiv_, radí_,
   {{0x5f040907,0x6e243c4c,0xd2500416,0xb97b00a5}},	//   _विद्_, _abib, انک_, פניי,
   {{0x6d440297,0xdef70a93,0x7c2ec2dc,0x3940c2dd}},	//   _aria, ныя_, debr, hvis_,
   {{0x442ec2de,0x63a401d6,0x78600095,0xddc4008b}},	//   lef_, ğind, _mövq, _sliš,
   {{0x6d4400c9,0x2f180332,0x7c2e08bf,0x261505e7}},	//   _cria, ség_, febr, फ्टी_,
   {{0x7c2e29a4,0x62820d4b,0x6e2409d6,0x394034ae}},	//   gebr, _hmoo, _ebib, dvis_,
   {{0x6d44c2df,0x2a6900ab,0xa6e70023,0xb50d0d1f}},	//   _eria, tkab_, _chứ, _सम्प_,
   {{0x442e65d8,0xf1b90009,0xb87b01f7,0x673b0228}},	//   hef_, pešt_, _otíc, _ņujo,
   {{0x6d445fef,0xf80743f7,0x3940177c,0x3a39034b}},	// [ecb0] _gria, ечен, gvis_, _vasp_,
   {{0x2a69c2e0,0x7c2e6b77,0x6e3d03c1,0x7eb600d5}},	//   skab_, cebr, ldsb, rápe,
   {{0x442ec2e1,0x6d4400a0,0x3940621c,0x98b90160}},	//   def_, _zria, avis_, _arsă_,
   {{0x68f20093,0x787211cb,0x00000000,0x00000000}},	//   úkdó, _ræve, --, --,
   {{0x442ec2e2,0x64cb01c0,0xc987081b,0xddec02b5}},	//   fef_, ादेश, _чуни, פֿאָ,
   {{0x6aadc2e3,0x26d10054,0x6282014c,0x7d1d033b}},	//   llaf, _tuzo_, _amoo, itss,
   {{0xe29922bb,0x7c25009e,0x00000000,0x00000000}},	//   мак_, _mbhr, --, --,
   {{0xc2451158,0x6aad43c1,0x7c2e08b6,0x7d1d8cc1}},	//   тник, nlaf, zebr, ktss,
   {{0x38b4013c,0x9f4567f7,0x290908c8,0x65943079}},	//   lära_, mblé_, nraa_, _бату,
   {{0x6aad01ae,0x7c2e039f,0x78720b3e,0x00000000}},	//   hlaf, xebr, _tæve, --,
   {{0x68e406a2,0x6d44111f,0x3ce0c2e4,0x7c2e03e4}},	//   zpid, _sria, _stiv_, vebr,
   {{0x6d440038,0x7d1d1949,0x44250523,0x7e92013a}},	//   _pria, ftss, _hbl_, rāpo,
   {{0x61e9c2e5,0x7c2e48e1,0x44250159,0x427a0070}},	//   mbel, tebr, _kbl_, _קאנג,
   {{0xab2a0eb9,0x61e9c2e6,0x69ddc2e7,0x9f4c0176}},	//   мога_, lbel, _afse, badà_,
   {{0x4425008a,0x7d1dc2e8,0x2909b2d7,0x2c7401ff}},	//   _mbl_, atss, eraa_, _rädd_,
   {{0xf2d200c2,0x61e9c2e9,0x442ec2ea,0x3940c2eb}},	//   שען_, nbel, zef_, tvis_,
   {{0x6d4409e0,0x61e9010d,0x0c9400fd,0x69a2074f}},	// [ecc0] _uria, ibel, _مددگ, _कुशी,
   {{0x68e406a2,0x61e9c2ec,0x9f4c00a0,0xa6e700e2}},	//   rpid, hbel, ladá_, _thứ,
   {{0xd6d901e0,0x68e4c2ed,0x8a060610,0x39404409}},	//   еті_, spid, _изне, svis_,
   {{0x9f4c04a5,0x2f5a0070,0x7afa0093,0x68e4c2ee}},	//   nadá_, ודענ, áttu, ppid,
   {{0xceb302b8,0x4425c2ef,0xa2c5018d,0x61e9c2f0}},	//   ביא_, _bbl_, ागन्, dbel,
   {{0x44250098,0x628200a5,0x61e917a8,0xd90d0d4f}},	//   _cbl_, _smoo, ebel, _ریم_,
   {{0x442ec2f1,0x2bba0026,0x9f4e0132,0x17c700af}},	//   ref_, _इरफा, _tefé_, _агри_,
   {{0x442ec2f2,0x326300c3,0x44250211,0xddcd9ae6}},	//   sef_, итыв, _ebl_, _smaž,
   {{0x44255483,0x442e1de4,0x9f4c0042,0x361b00a5}},	//   _fbl_, pef_, dadá_, _קומד,
   {{0x83fc0009,0xdefa0733,0xb35600b5,0x00000000}},	//   _bođe, мым_, _لیتا_, --,
   {{0x61e9a8af,0xa3a9021a,0xe47500af,0x00000000}},	//   bbel, _गुप_, _сутэ, --,
   {{0x83fc0c0a,0x91e607c1,0x7d1d30f6,0x7bde008c}},	//   _dođe, _роде, ttss, _afpu,
   {{0x6e3dc2f3,0x00000000,0x00000000,0x00000000}},	//   rdsb, --, --, --,
   {{0x7d1d7d12,0x7bdc0051,0xddcd023a,0x00000000}},	//   rtss, gcru, _umaž, --,
   {{0x83fc0009,0x69cf0211,0xb5fd007e,0x7b640185}},	//   _gođe, _pgce, _hoše, атте,
   {{0xb5fd02b2,0x48fe0066,0x2909c2f4,0x6a78008d}},	//   _koše, _लिखो_, traa_, _líff,
   {{0x2c1b2cb0,0xd75903c5,0x3ea90600,0xb5fd0009}},	// [ecd0] _बापू_, کلات_, _ikat_, _joše,
   {{0x2909145d,0xb767262e,0x3ea90118,0x61e9822e}},	//   rraa_, ктей, _hkat_, zbel,
   {{0x7529c2f5,0x61e9c2f6,0xb5fd0254,0x37ab0409}},	//   _spez, ybel, _loše, фтан_,
   {{0x4425c2f7,0x24f9171d,0x34cb00e7,0x6aa41db3}},	//   _sbl_, енды_, ाद्द, coif,
   {{0xfd1f027a,0x7eb60097,0xdc560d4f,0x00000000}},	//   ntì_, nápa, _شریک, --,
   {{0x61e9415b,0xa879016b,0x38b4018d,0x00000000}},	//   wbel, _טאָר, pära_, --,
   {{0x82f400d8,0xddcd0069,0x59a78178,0x78a5c2f8}},	//   ачыц, _amaż, _कुतर, mohv,
   {{0x83fc0537,0x6d4100ea,0x61e91192,0xd24e0098}},	//   _rođe, ālaj, ubel, كنى_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e60723,0x61e9c2f9,0xd5b80043,0xb5fdc2fa}},	//   ıkla, sbel, _рсс_, _doše,
   {{0x61e90051,0x6aa408c7,0x82152402,0x63a40225}},	//   pbel, yoif, _مواص, ğinc,
   {{0x83fc0254,0xfce62a0b,0x35a80066,0x63a4045e}},	//   _vođe, ломо, _छुड़, şinc,
   {{0x9105294d,0xb5fd0009,0x78a53bb7,0x00000000}},	//   _спле, _goše, kohv, --,
   {{0x6abe0e96,0x25ad04ee,0x3ea902ee,0x00000000}},	//   ्द्र, _myel_, _ekat_, --,
   {{0x5a961279,0x16140084,0x9f4c00b8,0x2ba404bc}},	//   граф, _डालर_, padá_, _खुशा,
   {{0x6a710e45,0x00000000,0x00000000,0x00000000}},	//   _påfa, --, --, --,
   {{0x3946c2fb,0x59a70066,0x7eb60138,0x25ad13cf}},	// [ece0] íos_, _कुदर, cápa, _nyel_,
   {{0xb86600b5,0x26dc01ef,0x6aa400a2,0x2c6607c0}},	//   دارو, ívoo_, soif, _pôdu_,
   {{0xe7e3046c,0xbc1b016b,0xf3f100cc,0x00000000}},	//   गड़ा_, _אויש, _gọi_, --,
   {{0xbebd0029,0x00000000,0x00000000,0x00000000}},	//   rtīg, --, --, --,
   {{0x7c3ec2fc,0x35f31bda,0x62890a8c,0xbebd00ea}},	//   _kapr, спір, dieo, stīg,
   {{0x9f4701d6,0xb5fd0009,0x64a300d8,0x81f00033}},	//   _genç_, _roše, бача, _টাইপ_,
   {{0x2912c2fd,0x7c3ec2fe,0x7eb60187,0x25ad0118}},	//   luya_, _mapr, zápa, _eyel_,
   {{0x7c3ec2ff,0xb5fd71d0,0x26cd0023,0x25ad0260}},	//   _lapr, _poše, _gieo_, _fyel_,
   {{0x2912027d,0x92370274,0x644d0139,0x00000000}},	//   nuya_, учју_, _şniţ, --,
   {{0x3ea9c300,0x2018018d,0x388b0409,0x6ed80099}},	//   _skat_, üri_, _gėrė_, _नंदु,
   {{0x2c1b0006,0x2ba419db,0x443e4fb4,0xa2e63669}},	//   _बाबू_, _खुला, _iat_, _соед,
   {{0x443e02d8,0x38af01d6,0x7c3e35df,0xfd1f027a}},	//   _hat_, türk_, _aapr, ttì_,
   {{0x443ec301,0x5c07c302,0x61fd0093,0xa06ac303}},	//   _kat_, лява, ðsle, _пада_,
   {{0xdfcf0082,0xfd1f027a,0x00000000,0x00000000}},	//   _فيه_, rtì_, --, --,
   {{0x7c3e0c1f,0x8cd50939,0xfd1f0036,0xe9df00ee}},	//   _dapr, _यूरो, stì_, _pfú_,
   {{0x443e006a,0x5a3503e6,0x6f04009e,0x00000000}},	//   _lat_, јнат, _āich, --,
   {{0x443e5053,0x7c870ebc,0x57f50166,0x2912b7fd}},	// [ecf0] _oat_, _буне, ипат, guya_,
   {{0x29071851,0x13cc00c8,0x443ec304,0x6ed30139}},	//   čna_, রুয়, _nat_, _săbi,
   {{0x4735002d,0x9f470176,0x25ad0359,0x00000000}},	//   рнес, _venç_, _syel_, --,
   {{0x7c3ec305,0x2912c306,0x443e245b,0x6e3f003c}},	//   _zapr, buya_, _aat_, _jaqb,
   {{0x6e3f007a,0x443e0ca5,0x7c3e027d,0xe3b800a8}},	//   _maqb, _bat_, _yapr, _azı_,
   {{0x443e7b73,0x67d41499,0x78720b3e,0x04450f08}},	//   _cat_, _гору, _hævn, рекн,
   {{0x443ec307,0xc3040037,0x00000000,0x00000000}},	//   _dat_, مبيو, --, --,
   {{0xa3a920ab,0x41050274,0x443e00a5,0x787201b4}},	//   _गुण_, азив, _eat_, _jævn,
   {{0x443e00a5,0x545500d8,0x40950142,0x661b007b}},	//   _fat_, _кват, ирот, _icuk,
   {{0x443ec308,0x753bc309,0x63a4c30a,0xe4a71d77}},	//   _gat_, _isuz, şina, _србо,
   {{0x7c3ec30b,0x6a78021d,0x29121505,0x00000000}},	//   _rapr, _hífe, zuya_, --,
   {{0x7c3ec30c,0x443ec30d,0x7872054e,0x2912bc37}},	//   _sapr, _zat_, _nævn, yuya_,
   {{0x7c3ec30e,0x61fb00de,0x443e90f9,0xa07500d8}},	//   _papr, maul, _yat_, _выйш,
   {{0x443e0443,0xa0666060,0xd009178e,0x61fbc30f}},	//   _xat_, _ваша_, _реке_, laul,
   {{0x6b630272,0x6a780093,0x999900fe,0x7c3e018d}},	//   окра, _lífe, _basů_, _vapr,
   {{0x61fb5bfa,0x7c3e5ff2,0x8f9a011d,0x78bc0124}},	//   naul, _wapr, _ביצי, _shrv,
   {{0xe9d704e7,0x7c3e069a,0x9f450037,0x753b0027}},	// [ed00] рку_, _tapr, iblí_, _nsuz,
   {{0x61fbc310,0xb87b0079,0x661b0371,0x291200a3}},	//   haul, _dtío, _acuk, ruya_,
   {{0xb87b07a6,0x7eb6c311,0x443e02d8,0x7e64380c}},	//   _etío, nápo, _rat_, _koip,
   {{0x443ec312,0x0bb702b8,0xe8fa02c4,0x75464fa2}},	//   _sat_, _כלים_, _илм_, инез,
   {{0x443ec313,0xe81e0299,0x61fb0ce8,0x09b00033}},	//   _pat_, _पापा_, daul, _কলকা,
   {{0x443e00a8,0x2902201d,0xa2da0067,0xddc40067}},	//   _qat_, _ivka_, _पंद्, _bliź,
   {{0x443ec314,0xd4670202,0x2900c315,0x6d4100ea}},	//   _vat_, рије_, lsia_, ālai,
   {{0x443ec316,0x3254191f,0x442000b8,0x61fbc317}},	//   _wat_, свир, ři_, gaul,
   {{0x443e048c,0x60f701c8,0x2900c318,0xb27300d4}},	//   _tat_, аныя_, nsia_, ільш,
   {{0x76420176,0x29000086,0x26d89ae2,0x69b900a1}},	//   ldoy, isia_, _kuro_, ्धती,
   {{0x75220332,0x1df915eb,0x290002c2,0x26d8c319}},	//   ltoz, лены_, hsia_, _juro_,
   {{0xb5fd02dd,0x290003ad,0x764232a3,0x7ebd006c}},	//   _koša, ksia_, ndoy, képe,
   {{0x51830847,0xb5fd329c,0xf27b02b8,0x29001a63}},	//   _муша, _joša, _בראש, jsia_,
   {{0x26d80bc8,0x7ebd0248,0x76400159,0x7b1900af}},	//   _ouro_, dépe, _lamy, логр_,
   {{0xbebd0080,0x26d80159,0x7eb61e15,0x9b6854b8}},	//   rtīb, _nuro_, cápo, ашта_,
   {{0xbebd0080,0x9f450097,0xb87b021d,0x00000000}},	//   stīb, nalý_, _etíl, --,
   {{0xdebc0122,0x27f8c31a,0x7ebd00b5,0x2d8f00be}},	// [ed10] _במהל, _bern_, gépe, _äge_,
   {{0x26d80afc,0x085400d4,0x2bde0066,0x61fb2e73}},	//   _buro_, овую, _मलया, zaul,
   {{0xec360052,0x2900c31b,0x26d8c31c,0x7640c31d}},	//   _האתר_, asia_, _curo_, _bamy,
   {{0x83fc0254,0xb5fdb696,0x3ed9016b,0x76400090}},	//   _rođa, _boša, אַסא, _camy,
   {{0x154502c4,0xf8db007c,0x76400260,0x27f8034e}},	//   селм, _बढिय, _damy, _fern_,
   {{0xb5fd0a78,0xe81e3dc1,0x27f801ae,0x26d85a64}},	//   _doša, _पाया_, _gern_, _furo_,
   {{0xe7ed02cb,0x96f8c31e,0x26d8c31f,0x61fbc320}},	//   _च्या_, _вест_, _guro_, taul,
   {{0x83fc0c99,0x764000d8,0xeb980122,0xf8db22a7}},	//   _vođa, _gamy, ידור_, _बढाय,
   {{0x61fb12c3,0x753b1d60,0x3cdc021a,0x00000000}},	//   raul, _usuz, _गंधे_, --,
   {{0xcea900c2,0x205505c2,0xd3a70c46,0x76400e7c}},	//   _װי_, стир, _креп, _zamy,
   {{0x61fbc321,0x64410159,0x26d8002a,0x76400027}},	//   paul, _iali, _xuro_, _yamy,
   {{0x29000b0e,0x64431cdb,0xb87bc322,0x64410cec}},	//   ysia_, ldni, _stíl, _hali,
   {{0xdd922499,0x3f8b0035,0x627b0035,0x7e640768}},	//   سوس_, ńcu_, głoś, _voip,
   {{0xa3bb009a,0x6443c323,0x9f471408,0x6441c324}},	//   _घरा_, ndni, _menú_, _jali,
   {{0x394bc325,0x64430009,0x00000000,0x00000000}},	//   _arcs_, idni, --, --,
   {{0x6441c326,0x225f2bab,0x2900c327,0xeabf5794}},	//   _lali, njuk_, tsia_, _chù_,
   {{0x29008b7b,0x26d8c328,0x764000c7,0xdb0500ac}},	// [ed20] usia_, _suro_, _ramy, _vyhá,
   {{0x6441c329,0x26d82aaf,0x76407f36,0xbddb12c3}},	//   _nali, _puro_, _samy, ndèn,
   {{0x6443013c,0x26d8012f,0x27f80044,0xe81e00ab}},	//   ddni, _quro_, _vern_, _पाठा_,
   {{0x64432aa8,0x6441c32a,0xb5fd0a78,0x2900c32b}},	//   edni, _aali, _poša, psia_,
   {{0x6441c32c,0x786001c2,0xd46a0e9f,0x9f450bca}},	//   _bali, _mövz, лиде_, valý_,
   {{0x64411116,0x7522006c,0x26d8c32d,0x6a6a0187}},	//   _cali, rtoz, _turo_, _výfu,
   {{0x64411885,0x08770070,0x61f90312,0x7640c32e}},	//   _dali, _פעלט_, _bewl, _tamy,
   {{0x7d04029d,0xe6960082,0x64411b39,0x200700b5}},	//   _ovis, _الرد, _eali, _adni_,
   {{0xb5fd030a,0x61fd003e,0x59ae021a,0x315a0079}},	//   _košn, ðsla, _झुमर, اجعة_,
   {{0x64417605,0x0eea01e0,0x00000000,0x00000000}},	//   _gali, льми_, --, --,
   {{0x7d04c32f,0xb5fdc330,0xa30b00b5,0x00000000}},	//   _avis, _mošn, _مرنے_, --,
   {{0xc3b702b5,0x00000000,0x00000000,0x00000000}},	//   _פלאץ_, --, --, --,
   {{0x6441843f,0x9f470382,0xddcd3b1a,0x2d9f000d}},	//   _yali, _menù_, _blaš, çue_,
   {{0x644100a8,0xb5fd011c,0x9f450453,0x7d043b1a}},	//   _xali, _nošn, galó_, _dvis,
   {{0xeabf01a5,0x5f935795,0x7d04c331,0x00000000}},	//   _phù_, _ништ, _evis, --,
   {{0x6443c332,0x00000000,0x00000000,0x00000000}},	//   zdni, --, --, --,
   {{0x6e2dc333,0xb5fd0254,0x7e7d0037,0x14a80067}},	// [ed30] _ibab, _bošn, mhsp, गवाण,
   {{0x81bd0083,0x6d4d00ab,0x442cc334,0x00000000}},	//   _আলম_, _iraa, _nbd_, --,
   {{0x64410bce,0xeabf0019,0x7d0407c0,0x3b5400af}},	//   _rali, _thù_, _zvis, _екэр,
   {{0x442cc335,0x6d4dc336,0xe8150266,0x35b52ac7}},	//   _abd_, _kraa, _ढाका_, обер,
   {{0x6441c337,0xa3cb0653,0x6e2dc338,0xe3e90647}},	//   _pali, रेन_, _mbab, لکان_,
   {{0x68edc339,0x64417d40,0x69a200b4,0x83fc011c}},	//   mpad, _qali, _कुटी, _dođo,
   {{0x6441c33a,0x68ed0015,0x3949c33b,0x6443543e}},	//   _vali, lpad, lvas_, rdni,
   {{0x6441c33c,0x6d4dc33d,0xbcfb00b5,0x68ed2407}},	//   _wali, _oraa, nyés, opad,
   {{0xe0d601c8,0x3ce901e8,0xa3a90084,0x68edc33e}},	//   овы_, _ntav_, _गुर_, npad,
   {{0xaf051bdf,0x6e2d19c7,0x68ed2132,0x3949c33f}},	//   опол, _abab, ipad, ivas_,
   {{0x7d04c340,0x66090187,0x394900ab,0x6d4dc341}},	//   _svis, _kdek, hvas_, _araa,
   {{0x6d4d6213,0xb5fd168a,0x63ad2f80,0x39490168}},	//   _braa, _mošo, ğand, kvas_,
   {{0xddcd2c14,0x763a00c2,0x9f450036,0xb5fd00cd}},	//   _plaš, בערג, galò_, _lošo,
   {{0x6d4d0903,0x68edc342,0x6e2d2387,0xdfdb02fb}},	//   _draa, dpad, _ebab, _съд_,
   {{0x2a7900d7,0xbb43c343,0x6d4dc344,0xddcd3c4a}},	//   _blsb_, мерк, _eraa, _vlaš,
   {{0xa3cb0907,0x6d4d12ef,0x7e7dc345,0x7d04c346}},	//   रेय_, _fraa, chsp, _tvis,
   {{0x6d4dc347,0x68edc348,0x2a79012f,0x8c461676}},	// [ed40] _graa, gpad, _dlsb_, _депе,
   {{0x6e2d00ac,0xdb050282,0xbebd0228,0xddc40207}},	//   _zbab, _byhä, ntīn, _kliž,
   {{0x442cc349,0x68ed0037,0x38b400be,0x628b0298}},	//   _rbd_, apad, näri_, _omgo,
   {{0xd62a02e0,0x442ca5de,0x8f9a00a5,0xcf9200a5}},	//   роде_, _sbd_, ביעי, וטב_,
   {{0x44f301c8,0x69b40026,0x14f300d8,0x66091289}},	//   дпіс, _आरटी, дзіў, _ddek,
   {{0x3d1200a1,0x83fc00cd,0x628b099e,0x38b40421}},	//   _तिने_, _vođo, _amgo, käri_,
   {{0xbcfb00b5,0x00000000,0x00000000,0x00000000}},	//   nyér, --, --, --,
   {{0xfbd30052,0xf48402fd,0x29120159,0x00000000}},	//   ותו_, _کاری, orya_, --,
   {{0xa2da0967,0x2c1b0324,0x93bc00af,0x442c0337}},	//   _पूर्, _बालू_, _scăd, _tbd_,
   {{0xddc40bcc,0xa3560037,0x195700a5,0x395700a5}},	//   _bliž, _وخاص, קביל_, קשים_,
   {{0x3ce91c8e,0x7e7dc34a,0xb7db0319,0x28bd007e}},	//   _stav_, thsp, יקיי, ्गति,
   {{0x6d4d0626,0x394900d8,0xe2920e3a,0x00000000}},	//   _praa, yvas_, _غذا_, --,
   {{0xe0180026,0x2eec02d7,0x00000000,0x00000000}},	//   _दाऊद_, spdf_, --, --,
   {{0x6d4d06ba,0x00000000,0x00000000,0x00000000}},	//   _vraa, --, --, --,
   {{0x6d4d0b0d,0xdefa061c,0x00000000,0x00000000}},	//   _wraa, _тыл_, --, --,
   {{0x6d4db3af,0x68ed068f,0x6e2d306e,0x99d90033}},	//   _traa, tpad, _ubab, তর্ক,
   {{0xb5fdc34b,0xdd9110ad,0x3ce901ff,0x6d4dc34c}},	// [ed50] _došl, _سود_, _utav_, _uraa,
   {{0x68edc34d,0xa3cb25d8,0x9f5e0031,0xdb050421}},	//   rpad, रेड_, jatë_, _pyhä,
   {{0x68ed341d,0xc6a721b7,0x3949ab01,0x370700d8}},	//   spad, орди, svas_, ючав,
   {{0x68ed013c,0xcb120070,0x6725039b,0x00000000}},	//   ppad, _אלט_, rthj, --,
   {{0xd1260082,0x660901d2,0x73e50133,0x4a5a00a5}},	//   _ثم_, _vdek, полз, _הדרו,
   {{0x81c20033,0xb5fd20dc,0x9f5e0183,0x00000000}},	//   ্ডা_, _tošo, ratê_, --,
   {{0x61fd008e,0x15f5021a,0x248c013a,0x00000000}},	//   ðslo, आरआर_, _dmdm_, --,
   {{0x9f5e02d0,0xb5fd1abc,0x6609c34e,0xb87b031d}},	//   matè_, _košm, _udek, _stíh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b303c7,0x94773f25,0x9f85488b,0x032b01e0}},	//   _قرض_, _بدرا, згод, _відп_,
   {{0x9f5e0c1f,0xb5fd0009,0xaadb06fe,0x7eb6021d}},	//   natè_, _lošm, _मूलक, lápi,
   {{0xa3cb012f,0xbebd00ea,0xb87b02d7,0x6da60200}},	//   रेण_, stīn, _huíd, зима,
   {{0x57b80ed1,0x1c202b22,0x31580037,0xee3701e0}},	//   _अर्ह, _बादल_, _وجهة_, чня_,
   {{0x9f5e02d0,0x9f05017e,0x629bc34f,0x38b400c3}},	//   katè_, _فوتو, lnuo, päri_,
   {{0xb5fd1f6f,0x2d820d7f,0xb87b0183,0x00000000}},	//   _pošl, szke_, _muíd, --,
   {{0xe9da4717,0xada6010b,0x29120159,0x629bc350}},	//   ска_, _найл, trya_, nnuo,
   {{0x98a00a69,0x6ab6c351,0x7afb0c99,0xae1b00a5}},	// [ed60] stič_, rlyf, ćuta, _הופכ,
   {{0xb90400c4,0x499901e0,0x2912c352,0xc3010831}},	//   _पं_, іття_, rrya_, _এমনি_,
   {{0x25bf0aca,0x59b00035,0xbb4a0037,0xc2f00033}},	//   _azul_, _फ़रवर, _الجن_, _টিভি_,
   {{0x3e7b00da,0x59a704bc,0x4abf021a,0xb6cb00b5}},	//   _këta_, _कुकर, ्षणव, مانے_,
   {{0x48e353b7,0x9f5e0031,0xb8080033,0x673b0207}},	//   _появ, tatë_, র্গত_, _ćuje,
   {{0xb87b0453,0x798408c7,0xd83800d5,0x52a400b4}},	//   _cuíd, mziw, _úč_, ऑक्स,
   {{0x9f5e00da,0x07a30ecf,0xddc40024,0x43670166}},	//   ratë_, _зарн, _aliż, зајн_,
   {{0x629b3e71,0xddc40067,0xd62748da,0x6f0206fe}},	//   gnuo, _bliż, _носе_, _líbá,
   {{0xe57a0009,0x79842004,0x93bc0139,0x00000000}},	//   _уза_, nziw, _abăt, --,
   {{0x44e2008d,0x4438c353,0x2fd80c71,0x43467e7c}},	//   _ið_, _úr_, ørg_, _незв,
   {{0x09b9111a,0xd9b9052b,0xddc40069,0xdfd011c0}},	//   _आर्य, _आर्ट, _eliż, ضيح_,
   {{0x59be0761,0x66020054,0xdd950409,0x9f5e0097}},	//   ्धार, naok, дамы, naté_,
   {{0x9f5e02e9,0x394202a7,0x00000000,0x00000000}},	//   zatè_, _nsks_, --, --,
   {{0x6ab594e2,0x79840067,0x55770070,0x9f5e0097}},	//   ंत्र, dziw, לעכן_, haté_,
   {{0x3d1200a1,0x6602c354,0xff4f026e,0x160c0099}},	//   _तिथे_, kaok, _مخي_, हणार_,
   {{0xfd47006c,0x69da00af,0x628000e2,0x201e00e1}},	//   _ٹیسٹ_, _şter, nhmo, lgti_,
   {{0xf99300bf,0x6aad6641,0xdd9200b5,0x1958057a}},	// [ed70] ربر_, roaf, _لوٹ_, паты_,
   {{0x201e01c8,0x3eb9c355,0x2246012f,0x9f5c021d}},	//   ngti_, llst_, _laok_, _revê_,
   {{0x44e2c356,0xb9046017,0x6f1a022f,0xb87b2314}},	//   _að_, _पू_, nutc, _ruíd,
   {{0xd7c81c2d,0x660201ef,0x6280c357,0x9f5ec358}},	//   سونه_, gaok, jhmo, ratè_,
   {{0x044507c1,0xd4695ca3,0xb87b002a,0xb5fd007e}},	//   делн, жиле_, _puíd, _hošk,
   {{0x7eb6c359,0x629e00a2,0x3eb902b1,0x00000000}},	//   rápi, épon, hlst_, --,
   {{0xb5fd0c4b,0x9f5ec35a,0x491922a3,0xe6950421}},	//   _jošk, baté_, यूरो_, _живы,
   {{0xb5fd02c6,0xd5ae006c,0xd24e026e,0x62800069}},	//   _mošk, اہے_, لنى_, ghmo,
   {{0x81b50b52,0xf4f700b5,0xb5fd39e9,0x25bf0139}},	//   ছেন_, _رواں_, _lošk, _uzul_,
   {{0x3ea00345,0x6a710282,0xbddb0118,0x3eb20ddf}},	//   _sjit_, _gåfv, bdèk, _skyt_,
   {{0x3ea6141d,0xaabf09b1,0x6280006d,0x4abf03de}},	//   динг, ्षाक, bhmo, ्षाव,
   {{0x38b401ff,0x6280666e,0x00000000,0x00000000}},	//   lärt_, chmo, --, --,
   {{0xd0094e91,0x6145c35b,0xe81e0437,0x00000000}},	//   _деле_, _цела, _पाला_, --,
   {{0x6f1a012f,0xb5fd0bc6,0x321f005f,0x7afb00cd}},	//   butc, _bošk, lguy_, ćutn,
   {{0x09e6c35c,0xebe3107b,0x201800a0,0x9f5c0260}},	//   добн, тосп, órie_, _nevè_,
   {{0xc332035e,0x9f47c35d,0xb5fd1b97,0x3ea00031}},	//   כול_, _menü_, _došk, _ujit_,
   {{0x63a40723,0x6e2404fb,0x00000000,0x00000000}},	// [ed80] ğini, _icib, --, --,
   {{0x63a4c35e,0x6602002f,0xb5fd0207,0x00000000}},	//   şini, waok, _fošk, --,
   {{0x9f5e000d,0x66021183,0x98ab055c,0x00000000}},	//   taté_, taok, _cscđ_, --,
   {{0x7c3c06a2,0x386a00e9,0x6d440067,0x7c2e617d}},	//   lerr, _wobr_, _ksia, lfbr,
   {{0xa3cb00dc,0x6602c35f,0x6280006d,0x9f5ec360}},	//   रेस_, raok, vhmo, raté_,
   {{0x6d44023c,0x00000000,0x00000000,0x00000000}},	//   _msia, --, --, --,
   {{0x628000da,0xf74304de,0x6d4b01ef,0x00000000}},	//   thmo, _иеро, _ágav, --,
   {{0x7c3cc361,0x7c290c99,0x00000000,0x00000000}},	//   herr, đeri, --, --,
   {{0x14260279,0xa2da0f39,0x7c3cc362,0x68e400a8}},	//   _одам, _पंक्, kerr, nqid,
   {{0x628001f4,0x7c3c01f4,0x81c20033,0x63ad033e}},	//   shmo, jerr, ্ডল_, şana,
   {{0x381702b8,0x6d44c363,0xdef700d8,0x443ca9ec}},	//   וקים_, _asia, мыя_, mev_,
   {{0x6448c364,0x443cc365,0x442e496a,0xb5fd0612}},	//   _hadi, lev_, lff_, _rošk,
   {{0x6448c366,0x7c3cc367,0x645a011e,0xdbc700a8}},	//   _kadi, ferr, _knti, _köçk,
   {{0x64481f1d,0xa3cb021a,0x442e0602,0x7c3cc368}},	//   _jadi, रेव_, nff_, gerr,
   {{0x6448c369,0xe2070035,0x6d44c36a,0x442e00e9}},	//   _madi, spół_, _esia, iff_,
   {{0x3204042f,0x83fc003a,0x443cc36b,0x6448109e}},	//   namy_, _dođi, hev_, _ladi,
   {{0x7c3cc36c,0x645ac36d,0x443cc36e,0x5cc73c3b}},	// [ed90] berr, _onti, kev_, _осоз,
   {{0x443c0169,0x3e7b01d2,0x7c3c28e4,0x7d1d6445}},	//   jev_, _këto_, cerr, muss,
   {{0x7d1dc36f,0xd14801a5,0x443cc370,0x38b4013c}},	//   luss, _lễ_, dev_, värt_,
   {{0xb5fd70cf,0x442e03bc,0x6e3dc371,0x9f4c00b5}},	//   _koši, eff_, nesb, ladó_,
   {{0x6448c372,0x7e6d0008,0xb5fd02c4,0xe3b804d4}},	//   _badi, _moap, _joši, _ayı_,
   {{0xdfc601ca,0x6448c373,0x29090211,0x443c00ab}},	//   _مي_, _cadi, msaa_, gev_,
   {{0xb5fd0280,0x6448c374,0x6600c375,0x6e3d5280}},	//   _loši, _dadi, _femk, kesb,
   {{0xb1453dd9,0x645ac376,0x7c3cc377,0x7e6d0043}},	//   енил, _enti, zerr, _noap,
   {{0x81d700c8,0x7c2593e0,0x7d1dc378,0x69dd0159}},	//   ়ুন_, _ochr, juss, _mgse,
   {{0x6448c379,0xd1480028,0x7d1dc37a,0x443c02c6}},	//   _gadi, _dễ_, duss, cev_,
   {{0x3ce04dff,0xa3cb2afe,0x60d8013a,0x4adb0066}},	//   _suiv_, रेश_, _divm, _मंगव,
   {{0x7c3c2b28,0x3204004e,0x644801a0,0x29090086}},	//   werr, camy_, _zadi, ksaa_,
   {{0x7d1dc37b,0x6448242d,0xb87b01dd,0x76490051}},	//   guss, _yadi, _xuíc, _maey,
   {{0x8fa53be4,0x644800a8,0x61e9c37c,0x83fc00cd}},	//   _пале, _xadi, lcel, _pođi,
   {{0x2005c37d,0x7c3c3b74,0xdea225d9,0x4425034d}},	//   mali_, rerr, _میدی, _mcl_,
   {{0x61e9c37e,0x6d440189,0x7c3c2391,0x443c01c0}},	//   ncel, _tsia, serr, zev_,
   {{0x443c0669,0x7d1d598f,0x7c3cc37f,0xf2d202b5}},	// [eda0] yev_, cuss, perr, רען_,
   {{0x2005c380,0x3940004e,0x44250118,0x290b008c}},	//   nali_, rwis_, _ncl_, _dvca_,
   {{0xabfb0122,0xf77207f8,0x7649012f,0x7bde011e}},	//   _מהיר, داء_, _baey, _igpu,
   {{0x6448c381,0x2005c382,0x765b0051,0xf5065544}},	//   _sadi, hali_, _cnuy, ездо,
   {{0x2005a189,0x6448c383,0x443c39ea,0x61e955e5}},	//   kali_, _padi, tev_, dcel,
   {{0x2005c384,0x64483886,0x32040067,0x61eb183a}},	//   jali_, _qadi, wamy_, _afgl,
   {{0x2005c385,0x6448c386,0x443cc387,0x18a3210f}},	//   dali_, _vadi, rev_, _сарм,
   {{0x443cc388,0xcb130052,0x6448c389,0x645a0051}},	//   sev_, אלה_, _wadi, _wnti,
   {{0x6448b2af,0x2005c38a,0xe5a31180,0x32040035}},	//   _tadi, fali_, _бити, ramy_,
   {{0x2005c38b,0x3204028b,0x645a5c6f,0x6448002f}},	//   gali_, samy_, _unti, _uadi,
   {{0x7d1dc38c,0x61e9c38d,0xb4cc0864,0xe9df0453}},	//   wuss, bcel, रगी_, _baúl_,
   {{0x7c253a44,0x7d1dc38e,0xb5fd02c6,0x61e9c38f}},	//   _schr, tuss, _poši, ccel,
   {{0x2005c390,0x6e3dc391,0x7d1d0118,0xa11300bc}},	//   bali_, resb, uuss, _مونت,
   {{0x2005972f,0x6e3d42c3,0xbcfb0042,0x00000000}},	//   cali_, sesb, bxén, --,
   {{0x7d1dc392,0xa2c5022e,0x4abf0099,0x9f4c00fd}},	//   suss, ागच्, ्षलव, radó_,
   {{0x7d1dc393,0xb5fd044d,0x66e5004b,0x63bc0211}},	//   puss, _toši, _dėkl, _ùrnu,
   {{0x38b4022a,0x04060033,0x61fd003e,0x00000000}},	// [edb0] värr_, _রানী_, ðsli, --,
   {{0x7c2505d1,0x2909b99c,0xd6d90067,0x9f5e00ac}},	//   _uchr, rsaa_, _sił_, hatí_,
   {{0x290902e2,0x4425c394,0x7d0dc395,0xb87b00d5}},	//   ssaa_, _rcl_, _hvas, _stís,
   {{0x9f5e01ba,0x290b021d,0xad9b021d,0x00000000}},	//   jatí_, _tvca_, haúm, --,
   {{0x20050273,0x6d420009,0xfd1f0036,0x154502c4}},	//   yali_, _šoaz, nuì_, телм,
   {{0x9f4500a2,0x7eb600d5,0x00000000,0x00000000}},	//   sclé_, nápr, --, --,
   {{0xa3cb006a,0xb87b4e5c,0x7649c396,0x61e9c397}},	//   रें_, _guía, _taey, tcel,
   {{0x2005c398,0xa56200bf,0x7d0dc399,0x9f5e0176}},	//   wali_, _چگون, _ovas, gatí_,
   {{0xe9dfc39a,0x41020086,0x61e93ec3,0x6a780079}},	//   _raúl_, азыв, rcel, _dífh,
   {{0x7ebd1010,0x61e919aa,0xe9df1f51,0x00000000}},	//   léph, scel, _saúl_, --,
   {{0x2005c39b,0x2018c39c,0x7d0dc39d,0x8c270083}},	//   rali_, ória_, _avas, য়ান_,
   {{0x2c74033b,0xc7d600a5,0xbcfb01ef,0x7ebd00a2}},	//   _lädt_, כותי_, rxén, néph,
   {{0x20054d67,0xfd1f027a,0x66e500c7,0x7d0d9a57}},	//   pali_, guì_, _sėkl, _cvas,
   {{0x6ada0380,0x7d0d010b,0x224dc39e,0xe1f900c7}},	//   भद्र, _dvas, ldek_, lbų_,
   {{0x09d90033,0x2b1551fe,0x93bc0160,0x00000000}},	//   ধুমা, льтр, _ncăl, --,
   {{0x224dc39f,0xb5fd26f9,0xfd1f0036,0x2bde193c}},	//   ndek_, _košu, buì_, _मलका,
   {{0x2d95010b,0x290c00ea,0xddd600ee,0xbcfb002a}},	// [edc0] _брэс, _ādas_, _flyš, nxél,
   {{0x92dc0033,0x6d5604fb,0x00000000,0x00000000}},	//   তীয়_, _irya, --, --,
   {{0x31be021a,0x394dc3a0,0x6a78008a,0x7d090254}},	//   _ऊर्ध, _šest_, _lífi, šest,
   {{0x940700a8,0x63ad0448,0x00000000,0x00000000}},	//   minə_, ğanl, --, --,
   {{0xa3d4074f,0x63ad037a,0x940700a8,0x00000000}},	//   सेन_, şanl, linə_, --,
   {{0x02ca0355,0xb4cc0380,0x44b300d8,0xa2da020c}},	//   ाग्न, रगे_, абіс, _पूज्,
   {{0x02a6002d,0x9407013b,0x00000000,0x00000000}},	//   крим, ninə_, --, --,
   {{0x6d560d75,0x6a780176,0xc7a30185,0xb87b021d}},	//   _orya, _bífi, _тиск, _juín,
   {{0x6a780176,0x75d6c3a1,0xb5fd0168,0x9f5e0097}},	//   _cífi, _شيطا, _pošv, ratí_,
   {{0xb5fd0207,0x00000000,0x00000000,0x00000000}},	//   _došu, --, --, --,
   {{0x7d0d6fa3,0x6d56c3a2,0x50d30037,0x7afb02c4}},	//   _svas, _arya, جزير, ćutk,
   {{0xc7b302b8,0xddd600b8,0xfd1f027a,0x1c2000b4}},	//   יבת_, _slyš, tuì_, _बाउल_,
   {{0xbebd0029,0x4034010b,0xddc4008b,0x62829daf}},	//   ktīv, _белс, _poiš, _iloo,
   {{0x628201a9,0x66e500d8,0x8f5400b2,0xfd1f0036}},	//   _hloo, _sėkm, _منتش, ruì_,
   {{0x69c603cb,0xdee30202,0xb5fd0a78,0x6d5601a8}},	//   _azke, _који, _košt, _erya,
   {{0xb87b171c,0xb5fdc3a3,0x9f5c06fe,0x00000000}},	//   _atíp, _jošt, _jeví_, --,
   {{0x628201a9,0xf80700d4,0xead40ebb,0xb5fd5620}},	// [edd0] _mloo, вчен, роть, _mošt,
   {{0x7e7d1b4a,0x224d137e,0x940700a8,0x4ac31140}},	//   lksp, zdek_, binə_, _वीरव,
   {{0x69c606a2,0xe1f9010b,0x62827326,0x00000000}},	//   _ezke, ybų_, _oloo, --,
   {{0x6282006d,0xf770017e,0xe9df0176,0x7e7dc3a4}},	//   _nloo, غال_, _ugú_, nksp,
   {{0xa82503c5,0x7ae50086,0xb87b00d5,0x25a90cce}},	//   _مکان, _huht, _ftíp, çal_,
   {{0x6282018e,0x03a51999,0x04c811c0,0x63ad00d0}},	//   _aloo, лило, نوني_, şanm,
   {{0x7ae50006,0x6282c3a5,0x224d03c4,0xb5fd08b7}},	//   _juht, _bloo, tdek_, _bošt,
   {{0x23690a78,0x7ae5c0eb,0xc24500c3,0x85056202}},	//   ćaj_, _muht, уник, _مورن,
   {{0x20c2008a,0x224dc3a6,0xe1f9010b,0xb5fd15ce}},	//   rðin_, rdek_, rbų_, _došt,
   {{0x940701c2,0xddcd030a,0x95c81837,0x212d0a4e}},	//   yinə_, _blaž, _руса_, rteh_,
   {{0xa2f56d5c,0x628200a5,0xb87b0079,0x4ab50afa}},	//   _спеч, _floo, _luío, ूताव,
   {{0xddcd024e,0xf38c0070,0x2eb500af,0x9407013b}},	//   _dlaž, _קראָ, исяс, vinə_,
   {{0x61fbc3a7,0x61fd0093,0xb87b1be9,0xdb050097}},	//   mbul, ðslu, _ruín, _vyhý,
   {{0x753b0010,0x94070095,0x7e7da8e2,0xb87b0132}},	//   _mpuz, tinə_, ërpr, _suín,
   {{0x09be5860,0x30da0070,0xddcd023a,0x40da016b}},	//   ्ध्य, _אַהע, _glaž, _אַהײ,
   {{0x940701c2,0xb87b004f,0x61fbc3a8,0x7e7dc3a9}},	//   rinə_, _buío, nbul, cksp,
   {{0x940701c2,0xa81a04e8,0x81b50033,0x98a0011c}},	// [ede0] sinə_, فتار_, ছের_, ntić_,
   {{0xa803081b,0x00000000,0x00000000,0x00000000}},	//   йзул, --, --, --,
   {{0xeb9ac3aa,0xe61a05f2,0x98a00009,0x00000000}},	//   _чин_, еде_, htić_, --,
   {{0x95ca2b34,0xa96a3537,0x84e601e0,0xd6d90044}},	//   нула_, _зима_, годж, вті_,
   {{0x6aa4002d,0x98a0042a,0xb5fd0a53,0xe5a30272}},	//   mnif, jtić_, _rošt, бици,
   {{0x6282aea2,0xd4670043,0xbebd00ea,0x9f5e0097}},	//   _sloo, личе_, ltīt, hatá_,
   {{0xb5fd0a0b,0x62828fa2,0xf48700f8,0xe61a1645}},	//   _pošt, _ploo, دانی, _пдв_,
   {{0x75d60bdf,0x61fb1296,0x851c0066,0xbebd02d4}},	//   _ميزا, gbul, _निपट_, ntīt,
   {{0x83fc0a78,0x81dc00c8,0xddcd0a78,0x201803e6}},	//   _anđe, তুন_, _slaž, ório_,
   {{0xddcd02dd,0x83fc0200,0x61fbc3ab,0x68e60159}},	//   _plaž, _vođs, abul, _mukd,
   {{0x9f3403d0,0x61fb01a8,0x6aa4c3ac,0x2fd801ff}},	//   шені, bbul, knif, ärg_,
   {{0x91e60086,0xddcd15d7,0xb5fd0009,0x00000000}},	//   _соде, _vlaž, _uošt, --,
   {{0x7ae52efa,0x7e7dc3ad,0x8d840210,0xd041013b}},	//   _suht, rksp, бурд, hmlə,
   {{0x10a30109,0x7ae5127d,0xa3cb1fc3,0x00000000}},	//   _личн, _puht, रेक_, --,
   {{0xb87b0082,0x8aa704b2,0xc8790043,0xddcd011c}},	//   _suío, град, _îşi_, _ulaž,
   {{0x98a90506,0x68e651f1,0x00000000,0x00000000}},	//   rtač_, _bukd, --, --,
   {{0x98a90506,0x76420448,0x290fc3ae,0x38c9103b}},	// [edf0] stač_, deoy, éga_, نائی_,
   {{0x80ca02e4,0x68e60159,0x37ab1355,0x00000000}},	//   _सीमे, _dukd, нтен_, --,
   {{0x61e2c3af,0x753b0124,0x61fb1505,0x00000000}},	//   _ogol, _spuz, ybul, --,
   {{0x61e2c3b0,0x6aa401f7,0x635c00af,0x00000000}},	//   _ngol, cnif, _mănă, --,
   {{0x15b8005f,0x00000000,0x00000000,0x00000000}},	//   лышы_, --, --, --,
   {{0x4d7c02b5,0x98a00200,0x61e2c3b1,0x6579024b}},	//   ערגע, vtić_, _agol, rywh,
   {{0x9f5c01f7,0x7d1d8dcf,0x62650f88,0x00000000}},	//   _nevà_, hrss, ивка, --,
   {{0x395900d7,0xbb3c016b,0x00000000,0x00000000}},	//   _krss_, געהי, --, --,
   {{0xb42709b9,0xd5381b15,0x6a78008d,0x00000000}},	//   _معاو, _مثلا_, _gífu, --,
   {{0x25bf0669,0x61e221a3,0x61fb241f,0xe81e007c}},	//   _iyul_, _egol, sbul, _पाछा_,
   {{0x2054021f,0x644306d5,0x98a00254,0xa2c90066}},	//   стыр, meni, stić_, _हीथ्,
   {{0x6443c3b2,0x1e960421,0x660b0dc3,0x44eb11cb}},	//   leni, ррор, nagk, _kø_,
   {{0x6cc600d4,0xfce6326d,0x66e500c7,0xd041013b}},	//   ийма, рого, _dėki, zmlə,
   {{0x6443c3b3,0x629b00d8,0xceb90035,0x660bc3b4}},	//   neni, liuo, stęp_, hagk,
   {{0xa09a0317,0xdca35f11,0x660b043d,0x68e611e9}},	//   _ביסט, цари, kagk, _sukd,
   {{0x6443c3b5,0x629b00d8,0x20070987,0x6f1c0138}},	//   heni, niuo, _heni_, árce,
   {{0xe9da8197,0x64431e34,0x200701d2,0x673c025c}},	// [ee00] тка_, keni, _keni_, _sprj,
   {{0x64430936,0x200700da,0xbebd0080,0x97560274}},	//   jeni, _jeni_, stīt, итељ,
   {{0x6443c3b6,0x2007c3b7,0x2cb81f79,0x629b010b}},	//   deni, _meni_, mord_, kiuo,
   {{0x2cb8c3b8,0x7d04c3b9,0x1f360070,0x26cdc3ba}},	//   lord_, _kwis, ירער_, _cheo_,
   {{0x64436460,0xe80107b5,0x9f4e0359,0x7d04c3bb}},	//   feni, _लड़का_, _jefò_, _jwis,
   {{0x7d042176,0x2007c3bc,0xd7f2004f,0x2cb80533}},	//   _mwis, _neni_, _ذكر_, nord_,
   {{0xd4090037,0x07a303d0,0x2485013a,0x00000000}},	//   اتهم_, _дарн, _dllm_, --,
   {{0xd257c3bd,0x66e301c8,0xddcd5485,0x44eb0b41}},	//   аць_, _фота, _plaż, _fø_,
   {{0x6443c3be,0x30a620b6,0x2007c3bf,0x635c0043}},	//   beni, иров, _beni_, _sănă,
   {{0x64431c90,0x2007c3c0,0x213d0159,0x2cb80075}},	//   ceni, _ceni_, _dpwh_, jord_,
   {{0x20073b0a,0x7d04035f,0x987b0070,0x1c20007c}},	//   _deni_, _awis, דריק, _बाजल_,
   {{0x442c0284,0x61e20036,0x7d04c3c1,0x7761002a}},	//   _hcd_, _ugol, _bwis, _álxe,
   {{0xb87b004f,0x6a78008a,0x2cb80624,0x41d2112b}},	//   _suím, _lífs, ford_, देशस,
   {{0x2007c3c2,0x2cb8bb36,0x442ca4ce,0x635c0139}},	//   _geni_, gord_, _jcd_, _tănă,
   {{0x200cc3c3,0x00000000,0x00000000,0x00000000}},	//   madi_, --, --, --,
   {{0x200cc3c4,0x64437f3d,0x2007c3c5,0xa3cb2207}},	//   ladi_, zeni, _zeni_, रेट_,
   {{0x200708d2,0x2cb8039b,0x6443c3c6,0x80c90083}},	// [ee10] _yeni_, bord_, yeni, রদর্,
   {{0x3eb90690,0x6d4dc3c7,0x2cb804b0,0x64432c36}},	//   lost_, _isaa, cord_, xeni,
   {{0x7d0402bf,0x3ce901e8,0x64433587,0xb7678497}},	//   _zwis, _huav_, veni, штай,
   {{0x3eb9605c,0x6443c3c8,0x3ce9006d,0x4fd902b5}},	//   nost_, weni, _kuav_, אַנד,
   {{0xe61803d0,0x200cc3c9,0x3959c3ca,0x0a68002d}},	//   рді_, kadi_, _urss_, _трэи_,
   {{0x6d4d0657,0x200c65fc,0x00000000,0x00000000}},	//   _msaa, jadi_, --, --,
   {{0x6443c3cb,0x26cd00e8,0x62890082,0xd6db1e38}},	//   reni, _theo_, theo, _ата_,
   {{0x200792a0,0x3e7b00da,0x3eb90254,0x6d4dc3cc}},	//   _seni_, _këtu_, jost_, _osaa,
   {{0x3eb90672,0x629bc3cd,0x3ce90221,0xa3cb2478}},	//   dost_, riuo, _nuav_, रेज_,
   {{0x14740082,0x64430031,0x39491292,0x629b010b}},	//   _والج, qeni, iwas_, siuo,
   {{0x160b142a,0x6d4d018e,0x2007c3ce,0xe808252b}},	//   _हजार_, _asaa, _veni_, षरता_,
   {{0x3949c3cf,0x3eb91bd8,0xfd1f0036,0x5c270033}},	//   kwas_, gost_, frì_, য়োগ_,
   {{0x200c1034,0x3ce9006f,0x66093a74,0x20078345}},	//   badi_, _cuav_, _meek, _teni_,
   {{0x3ce90221,0x200c334e,0xab2a0d84,0x644e0a4a}},	//   _duav_, cadi_, лога_, _óbit,
   {{0x8fa28b9c,0xc05200a5,0x9ef50c74,0x6d4dc3d0}},	//   _наше, _מזג_, _استش, _esaa,
   {{0x4f16012b,0x3a290cfb,0x7c3b0c99,0x6609559a}},	//   _פֿון_, ggap_, đura, _neek,
   {{0xa9670432,0x7e64c3d1,0x39490a2d,0xfd1f0036}},	// [ee20] бита_, _inip, gwas_, crì_,
   {{0xe9d712fe,0x7ebd0138,0x81ac0033,0x5b3600af}},	//   ску_, sépt, _গরম_, _лэму,
   {{0x7e640d35,0x6609c3d2,0x62990273,0x442cc3d3}},	//   _knip, _beek, _omwo, _rcd_,
   {{0x3ce91020,0x5fba02b5,0x6b810c61,0x69090093}},	//   _yuav_, אצענ, ølge, úsdó,
   {{0x200c00f8,0x3ce901e8,0x7e64023c,0x00000000}},	//   yadi_, _xuav_, _mnip, --,
   {{0x62990aee,0x7aed00b5,0x00000000,0x00000000}},	//   _amwo, _öltö, --, --,
   {{0x33170082,0x200cbe5d,0xd46703fa,0x29120159}},	//   مزيد_, vadi_, сије_, lsya_,
   {{0x9695192f,0x200c9fbf,0x50f40947,0x7e7608dd}},	//   _друш, wadi_, озит, _noyp,
   {{0x3eb91405,0x200cc3d4,0x2912149b,0xe1ef0125}},	//   vost_, tadi_, nsya_, رسي_,
   {{0xdefa15eb,0x442cc3d5,0x66090223,0x7e645671}},	//   лым_, _ucd_, _zeek, _anip,
   {{0x200cc3d6,0x3eb90a0b,0x3ce901a9,0x7e762a8f}},	//   radi_, tost_, _suav_, _boyp,
   {{0x200cc3d7,0x3ce9006f,0xf77300a5,0xb7db0070}},	//   sadi_, _puav_, לקת_, טקיי,
   {{0x3eb9c3d8,0x200c027c,0xa13300bf,0x3ce9006f}},	//   rost_, padi_, _فروش, _quav_,
   {{0x68fb01f4,0x00000000,0x00000000,0x00000000}},	//   _çudi, --, --, --,
   {{0x3eb9c3d9,0x28be07df,0xdb05017b,0x00000000}},	//   post_, ्तनि, _lyhö, --,
   {{0x139b02b5,0x6d4d309b,0x3ce90189,0x7e760176}},	//   אבלע, _tsaa, _tuav_, _goyp,
   {{0x6d4d01a2,0x3a29046a,0x66099de3,0x66e5010b}},	// [ee30] _usaa, rgap_, _reek, _lėkt,
   {{0x66090d19,0x3b1300cc,0x6725c3da,0x00000000}},	//   _seek, _tvxq_, tuhj, --,
   {{0x394901a2,0xa2ad0096,0x00000000,0x00000000}},	//   swas_, ुकम्, --, --,
   {{0xb4c300dc,0x6725104e,0xfdf90026,0x66ca0097}},	//   ृष्_, ruhj, ंडिस_, týka,
   {{0xd1265002,0x66091b43,0x0608010b,0x00000000}},	//   _تم_, _veek, снік_, --,
   {{0x6609c3db,0x1bfb09b8,0x22ac00b8,0xf795010b}},	//   _week, ्रिल_, věka_, _дагэ,
   {{0x66091ea5,0xa3d41bb5,0x00000000,0x00000000}},	//   _teek, सेल_, --, --,
   {{0xc7b200a5,0x12b90033,0x00000000,0x00000000}},	//   _חבל_, ুদ্দ, --, --,
   {{0x940e01c2,0xc42b2087,0xe57301b2,0x5ba60e62}},	//   hifə_, _مثال_, _عطر_, _ऐश्व,
   {{0x60090cc7,0x00000000,0x00000000,0x00000000}},	//   шном_, --, --, --,
   {{0xcdc91899,0xbebd0080,0xfe464073,0xd24e0ef2}},	//   _סך_, drīb, онно, رنی_,
   {{0x629904fb,0x3f8b0067,0x00000000,0x00000000}},	//   _umwo, ącu_, --, --,
   {{0x2d84024e,0x3f833b64,0x00000000,0x00000000}},	//   áme_, šju_, --, --,
   {{0x2b410260,0x83b5016b,0x00000000,0x00000000}},	//   _bphc_, ַפּע_, --, --,
   {{0x4a9a00d8,0x7ebd0320,0xddc4005f,0x00000000}},	//   атаў_, répr, _kniū, --,
   {{0xada6195c,0x3aee0097,0x00000000,0x00000000}},	//   _майл, _výp_, --, --,
   {{0x316d01ed,0x00000000,0x00000000,0x00000000}},	// [ee40] nxez_, --, --, --,
   {{0x291c336f,0x2912010d,0xbb46002d,0xad9b05f3}},	//   čva_, rsya_, _деок, raút,
   {{0x3ce30084,0xe9df021d,0x00000000,0x00000000}},	//   _टूटे_, _baús_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fd60066,0x00000000,0x00000000,0x00000000}},	//   _ठण्ड, --, --, --,
   {{0x7ae30138,0x00000000,0x00000000,0x00000000}},	//   _éntr, --, --, --,
   {{0x442008a1,0xa2c600a1,0xe80000a1,0xa3d400b4}},	//   ği_, ातल्, _ल्या_, सें_,
   {{0x1fcf0083,0x4420c3dc,0xd13a1126,0x32b70037}},	//   রশাস, şi_, ахо_, يدية_,
   {{0x6602c3dd,0xdcea0355,0x940e013b,0xe5a30f08}},	//   mbok, čněj, zifə_, _жити,
   {{0x660206a2,0x44380014,0x2bc0111a,0x26c628ef}},	//   lbok, _ùr_, _शुभा, lloo_,
   {{0x44f000e8,0x443e00cc,0xf1c60355,0x5fd501c0}},	//   _hà_, _ibt_, _řádu_, डेलल,
   {{0xd2500609,0x443ec3de,0xa3c907b5,0x44f0055c}},	//   _سنت_, _hbt_, ोधर_, _kà_,
   {{0x61a51e79,0xd12f004f,0x0dcb08d9,0x260b37e8}},	//   खपृष, _لمن_, руни_, ारती_,
   {{0x44f000e8,0x2bb606bb,0xee3f0187,0xbf1400d1}},	//   _mà_, _आँखा, mným_, _فوتب,
   {{0x44f0098b,0xee3f0187,0x75220097,0x6602c3df}},	//   _là_, lným_, hroz, kbok,
   {{0x443e0024,0x940e013b,0x00000000,0x00000000}},	//   _lbt_, rifə_, --, --,
   {{0xee3f0187,0x44f00023,0x752215bd,0x81dc0033}},	// [ee50] nným_, _nà_, jroz, তুর_,
   {{0x27e701e0,0x38784dbb,0x6d5f035f,0xd7fb0c06}},	//   ønn_, _corr_, _irqa, руа_,
   {{0x998002c4,0x7d160097,0x648f03d0,0x00000000}},	//   rgiš_, _zvys, _høig, --,
   {{0x44f00028,0xe51c021a,0x443e2cfc,0x66024541}},	//   _bà_, _निशि_, _abt_, gbok,
   {{0x44f001a5,0x752207ae,0xee3f0187,0x2c1f0066}},	//   _cà_, groz, jným_, _बयां_,
   {{0x44f0c3e0,0xee3f290b,0xb97a0122,0x69cf0029}},	//   _dà_, dným_, _הנשי, _izce,
   {{0x8c4401c2,0x44f0009e,0x69cf0168,0x00000000}},	//   əşdi, _eà_, _hzce, --,
   {{0x6d5f0095,0x44f0c3e1,0x6a71039b,0x00000000}},	//   _orqa, _fà_, _påfy, --,
   {{0x44f001a5,0x74f80969,0x273502df,0x75220160}},	//   _gà_, _метр_, lån_, croz,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5f028b,0x7bc5c3e2,0x81dc0033,0x44f0055c}},	//   _arqa, _nyhu, তুল_, _zà_,
   {{0xee3f0187,0xe3b20070,0x00000000,0x00000000}},	//   bným_, _אױב_, --, --,
   {{0x81a7006c,0x44f00023,0x628bc3e3,0xee3f0097}},	//   _بحال, _xà_, _ilgo, cným_,
   {{0xaff90ef2,0x7bc50a8a,0x00000000,0x00000000}},	//   _افغا_, _byhu, --, --,
   {{0x0b59323d,0x3d180380,0x7bc5016e,0x00000000}},	//   орты_, _भटके_, _cyhu, --,
   {{0x6486008a,0x661b0118,0x2a79016e,0xddcb0207}},	//   _aðil, _nduk, _cosb_, šiša,
   {{0xd943c3e4,0x387848e2,0xa96727eb,0xad9b0093}},	// [ee60] нети, _porr_, пита_, lbún,
   {{0x13e300c8,0x3ea2c3e5,0xbcfb0042,0x9d450594}},	//   নুয়, likt_, rxét, _آئين,
   {{0xb8f30fd1,0x44f0c3e6,0x2d82053e,0x628b0009}},	//   _ही_, _sà_, lyke_, _olgo,
   {{0x443e0279,0xe7ee0084,0xe7b300d1,0x44f00023}},	//   _sbt_, _जलवा_, رمند, _pà_,
   {{0x3878c3e7,0x443ec3e8,0x661b073a,0x7c2e0051}},	//   _torr_, _pbt_, _dduk, ogbr,
   {{0x44f0098b,0x2900c3e9,0x3ea20a75,0x7522c3ea}},	//   _và_, mpia_, hikt_, rroz,
   {{0xe727002d,0x44f0055c,0xe7e30534,0xf7431b79}},	//   _норд_, _wà_, _कृपा_, _перо,
   {{0x44f050e4,0x60f80945,0xee3f0237,0x2900c3eb}},	//   _tà_, ония_, tným_, opia_,
   {{0x850609b9,0x7ae6c3ec,0x6d44006d,0x629c010b}},	//   _روان, _mikt, _npia, _įrod,
   {{0x672333dc,0xf8be4f02,0xee3f0187,0x628b1e5c}},	//   šnje, ्तिय, rným_, _elgo,
   {{0x3d0f00a1,0x644ac3ed,0xee3f0187,0x741321b6}},	//   तीने_, mefi, sným_, _سونا,
   {{0x7ae6c3ee,0x6458c3ef,0xd24f00f8,0xee3f0097}},	//   _nikt, ldvi, _منم_, pným_,
   {{0xf8be018d,0x601831e6,0xdb230594,0x69c6008c}},	//   ्ताय, _доля_, کوزی, _nyke,
   {{0x6458038d,0x644ac3f0,0x39a300ab,0x32e700e2}},	//   ndvi, nefi, _कs_, _tđyt_,
   {{0x7ae6c3f1,0x00000000,0x00000000,0x00000000}},	//   _bikt, --, --, --,
   {{0x644a001e,0x273501ff,0x69c6008c,0x7ae6c3f2}},	//   hefi, vån_, _byke, _cikt,
   {{0x69c60f61,0x644ac3f3,0x2eee09b3,0x648f008c}},	// [ee70] _cyke, kefi, _huff_, _høie,
   {{0x69c6376a,0xed60010b,0x6e3d02b1,0x644a247c}},	//   _dyke, įžti_, lfsb, jefi,
   {{0x6560198d,0xf3f100cc,0x00000000,0x00000000}},	//   _armh, _lạc_, --, --,
   {{0x2735022a,0x1a6500b5,0x395200c3,0x2eeec3f4}},	//   rån_, _تیری_, änsä_, _muff_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644abf38,0x20c2008d,0xe1f70d91,0x3d0f022e}},	//   gefi, iðis_, ीर्ण_, तीये_,
   {{0xe2994194,0x360500ce,0xe73800c3,0x93bc0395}},	//   жай_, _يوسف, _неё_, _scăr,
   {{0x6aadc3f5,0x64580223,0x661b01d5,0x6e3d02a2}},	//   nnaf, advi, _uduk, jfsb,
   {{0xd12e00ad,0xc4f8017e,0x644a0110,0x764bc3f6}},	//   لمي_, _فعلا_, befi, megy,
   {{0x644ac3f7,0x7659c3f8,0xef192349,0x00000000}},	//   cefi, ldwy, омо_, --,
   {{0x6d44c3f9,0x200e0359,0x3ea200ea,0x68e702a2}},	//   _spia, _defi_, tikt_, _mijd,
   {{0xada60a93,0x29000526,0x68e701e4,0x6da6c3fa}},	//   дамл, ypia_, _lijd, дима,
   {{0x7ae6c3fb,0xdb1e0187,0x3ea2c3fc,0x61eb0024}},	//   _rikt, _vypí, rikt_, _iggl,
   {{0x61420665,0x7ae6c3fd,0x9f0500b5,0x69c6c3fe}},	//   _реша, _sikt, _قوتو, _ryke,
   {{0xfce326f3,0x7ae64c0c,0x64418fb8,0x69c6c3ff}},	//   торо, _pikt, _mbli, _syke,
   {{0x764b006c,0x64580097,0x644ac400,0x6aad05ee}},	//   jegy, zdvi, zefi, gnaf,
   {{0x7ae603c1,0x76590297,0x68e70a75,0x320f006c}},	// [ee80] _vikt, ddwy, _bijd, _megy_,
   {{0x9f4701f7,0x29190345,0x69c62ff1,0xc9d500b5}},	//   _agné_, _dvsa_, _vyke, رملک,
   {{0xd70a0210,0x7ae6c401,0x69c60051,0x78be2193}},	//   інде_, _tikt, _wyke, ropv,
   {{0x2900c402,0xe1e70372,0x6441c403,0xd9100416}},	//   ppia_, _لس_, _abli, _میر_,
   {{0x6aa40054,0x20c2008d,0x6441009e,0x1fba48cd}},	//   miif, iðir_, _bbli, _उड्ड,
   {{0x74141062,0xe1ff0b4c,0x61eb8489,0x6aa42206}},	//   روبا, ñón_, _aggl, liif,
   {{0x17790d36,0x200e0260,0x2fc70159,0x64580533}},	//   _есть_, _refi_, _nyng_, rdvi,
   {{0x2eee0298,0x28be05f7,0x68e701e4,0x6aa40103}},	//   _ruff_, ्तवि, _zijd, niif,
   {{0x79848658,0x321d001e,0x644a37ed,0xb97b0070}},	//   nyiw, _ddwy_, pefi, ַנטי,
   {{0x3ea02292,0x61eb4b19,0x00000000,0x00000000}},	//   _amit_, _eggl, --, --,
   {{0x98a9004e,0x934601e0,0xe80f09b4,0x2fc700e5}},	//   stać_, _інде, िरता_, _cyng_,
   {{0xbd6b1bdc,0x64418013,0x2ca301e4,0x1fcf0033}},	//   орге_, _zbli, wijd_, রশংস,
   {{0x2ca304ce,0x2005048c,0x6aad07c0,0x386a0260}},	//   tijd_, bbli_, vnaf, _onbr_,
   {{0x2eee01ff,0x6d5d08c8,0x00000000,0x00000000}},	//   _tuff_, rvsa, --, --,
   {{0x68e70a75,0x2ca30120,0x386d0009,0x8ff71a7c}},	//   _rijd, rijd_, _đer_, _غرور_,
   {{0xbcfb006c,0xc98725ef,0x00000000,0x00000000}},	//   tvéd, музи, --, --,
   {{0x6aadc404,0x5ea4004f,0x1dd3111b,0x127b016b}},	// [ee90] rnaf, _جميل, _सरित, קאמע,
   {{0x7d0dc405,0x98a40274,0xd7950382,0x00000000}},	//   _iwas, виђе, низъ, --,
   {{0x68e70069,0x764bc406,0x2ca107c0,0x00000000}},	//   _vijd, tegy, _imhd_, --,
   {{0x7d0dc407,0x3dc90159,0x35b51499,0x68e702a2}},	//   _kwas, _kyaw_, нбер, _wijd,
   {{0x68e704ce,0x7996004e,0x2a6b00d7,0xd4695b4b}},	//   _tijd, czyw, _incb_, зиле_,
   {{0x7d0dc408,0x00000000,0x00000000,0x00000000}},	//   _mwas, --, --, --,
   {{0x28be06d9,0x56952374,0x7d0d073a,0x6d5a02d4}},	//   ्तरि, _завт, _lwas, ātai,
   {{0xd24e004f,0x7d0d08b5,0x6abf0033,0xe3b000f8}},	//   منى_, _owas, ্দকো, جره_,
   {{0x63530095,0x3ea000cc,0x04c91026,0x7d0d1d46}},	//   _mənə, _rmit_, _فوري_, _nwas,
   {{0x3ea0c409,0x64413e9d,0xa3d7007c,0x00000000}},	//   _smit_, _ubli, _सरप_, --,
   {{0x3dc9149b,0x7d0dc40a,0x00000000,0x00000000}},	//   _ayaw_, _awas, --, --,
   {{0xdd1e002d,0x7d0db789,0x61eb9af1,0x2018008d}},	//   _câşt, _bwas, _uggl, órir_,
   {{0x20c200fb,0x611400d8,0x224d01a3,0x5fd129ce}},	//   rðir_, _адчу, meek_, _हरवल,
   {{0x224d06a2,0x7d0d0b88,0x229100ee,0x317a016b}},	//   leek_, _dwas, _dáke_, _מאנד,
   {{0xcb6744d9,0xbb43c40b,0x60c1010d,0x7d0d0118}},	//   наре_, лерк, molm, _ewas,
   {{0xa3d40775,0xe8fa4bfe,0x60c10be2,0x224d01b7}},	//   सेट_, зла_, lolm, neek_,
   {{0x7d0d02c7,0x6aa4018d,0x00000000,0x00000000}},	// [eea0] _gwas, riif, --, --,
   {{0x6d56c40c,0x224d01e4,0x81dc0033,0xbcfb000d}},	//   _isya, heek_, তুক_, uvée,
   {{0xbcfb000d,0x7ceb035f,0x4c83002d,0x224dc40d}},	//   rvée, _iżra, _слэв, keek_,
   {{0x60c1c40e,0x83fc042a,0xe61221b6,0x9f5e00ac}},	//   holm, _inđi, اشا_, jatý_,
   {{0x64a635f7,0xa3e20096,0xe89b0463,0x224d01d7}},	//   нада, नेन_, _çağı, deek_,
   {{0x672328ed,0x3952001e,0x6d560159,0x1dd300ab}},	//   šnja, mwys_, _msya, _सरसत,
   {{0x3952001e,0x851c0a5e,0x60c10036,0xe8be00a1}},	//   lwys_, _निकट_, dolm, ्तीच,
   {{0x66e300ed,0x09e40083,0x224d0065,0x6d2000b4}},	//   _боса, _ফ্যা, geek_, _बिंग_,
   {{0xa3d43421,0xc05a2286,0x3952229a,0xf1db0099}},	//   सेज_, пін_, nwys_, मेलन,
   {{0x7d0d010a,0x80ca0035,0x89370070,0xe937016b}},	//   _rwas, _सीखे, עריע_, עניץ_,
   {{0x6e95aa4e,0x224dc40f,0x6d56c410,0xbfaa5024}},	//   вину, beek_, _asya, ятие_,
   {{0x645ac411,0xf3ff0019,0x7d0d02d0,0xe3c70300}},	//   _hati, _đãi_, _pwas, áñez_,
   {{0x645a225e,0x225100b8,0x60c10036,0xa06a0f7e}},	//   _kati, ánků_, bolm, _нада_,
   {{0x635301c2,0x645a58b6,0x60c11d2b,0x61430214}},	//   _sənə, _jati, colm, _сеља,
   {{0x645ac412,0xaa673c29,0x5b2424ee,0x2bd60099}},	//   _mati, нтак, льта, _धरणा,
   {{0x645a032b,0x7d0dc413,0x6494009e,0xa3c800b4}},	//   _lati, _twas, _fàig, _ईडन_,
   {{0x7e6dc414,0x7d0d0848,0x7ebd00b5,0xc9840948}},	// [eeb0] _inap, _uwas, képz, луфи,
   {{0x645ac415,0x6af5081b,0x00000000,0x00000000}},	//   _nati, _изоф, --, --,
   {{0x7e6d0c80,0xf3f10019,0x9f5e02d7,0x64940211}},	//   _knap, _bạn_, mató_, _màid,
   {{0x9f5ec416,0x224dc417,0x649400f1,0x6d5a00ec}},	//   lató_, xeek_, _làid, ātav,
   {{0xdfc601cb,0x645ac418,0xddc40395,0x7e6d1476}},	//   _چي_, _bati, _iniţ, _mnap,
   {{0x645aa2bf,0x224d0173,0xb4bb00be,0x634a00a8}},	//   _cati, week_, घवे_, _mənf,
   {{0x224dc419,0x60c1c41a,0x645a470b,0x67d418cd}},	//   teek_, volm, _dati, _бору,
   {{0x9f5e006c,0xd90e00b5,0x59d50026,0x752425e2}},	//   ható_, _دیے_, _दरार, šiza,
   {{0x224d47fc,0xb3eb0ca8,0x649401da,0x645ac41b}},	//   reek_, _فعال_, _bàid, _fati,
   {{0x224d0260,0x7e6d000e,0x00000000,0x00000000}},	//   seek_, _anap, --, --,
   {{0xb4cd0026,0x765b011e,0x932702fd,0xe47a016b}},	//   रती_, _kauy, _سران, _קרעכ,
   {{0x645a0936,0xdc0a3779,0x7e6dc41c,0x64940284}},	//   _zati, वर्ड_, _cnap, _pàig,
   {{0xe1f038b7,0x50b5c41d,0x645ac41e,0x69cb033b}},	//   _اسم_, _иску, _yati, ügel,
   {{0x6494060e,0x645a0095,0x61fbbe2b,0x9f5e00b5}},	//   _gàid, _xati, lcul, gató_,
   {{0xaac60a9b,0x61fb0391,0x80ca0035,0x00000000}},	//   نترن, ocul, _सीटे, --,
   {{0x7e6d0036,0x6e461a55,0xba235f62,0x00000000}},	//   _gnap, _реиз, идск, --,
   {{0x61fb0473,0xc21200a5,0xea000023,0x66d80355}},	// [eec0] icul, יהן_, _ngất_, níke,
   {{0xe9d788c0,0x39520173,0x66ec0095,0x7c85015a}},	//   тку_, rwys_, _aşka, _буџе,
   {{0x645ac41f,0x67230009,0x00000000,0x00000000}},	//   _rati, šnjn, --, --,
   {{0x9bb70052,0x68ed00d8,0x645ac420,0x067500af}},	//   _יהיה_, _žodž, _sati, лучя,
   {{0x645ac421,0x95530037,0x00000000,0x00000000}},	//   _pati, لخوا, --, --,
   {{0x645ac422,0x00000000,0x00000000,0x00000000}},	//   _qati, --, --, --,
   {{0x645ac423,0x18a3004b,0x07a6c424,0x98a30369}},	//   _vati, _тарм, _равн, _тире,
   {{0xcb130122,0x3573006c,0x645ac425,0x1dd30066}},	//   בלה_, _چھوڑ, _wati, _सरलत,
   {{0x645ac426,0x273c6d9b,0x64940211,0x00000000}},	//   _tati, lín_, _pàid, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x273cadca,0x765b0118,0x00000000,0x00000000}},	//   nín_, _yauy, --, --,
   {{0x61fb811d,0xb28387c0,0xad9b0093,0x6f1ac427}},	//   ccul, _вышк, lbúi, rstc,
   {{0x9f5e006c,0x273c0079,0x7ae30118,0x7e6d08b7}},	//   tató_, hín_, _ènti, _vnap,
   {{0x273c6d0e,0x23b60683,0x00000000,0x00000000}},	//   kín_, _अखाद, --, --,
   {{0x9f5ec428,0x273c01ba,0x2ac70274,0x2d8d00f4}},	//   rató_, jín_, вљав, šee_,
   {{0x31660537,0x7e6d602b,0x273cc429,0x9ab400d8}},	//   _kroz_, _unap, dín_, айсц,
   {{0x2ab70484,0x224600bf,0x9f5e0453,0x00000000}},	// [eed0] għba_, _mbok_, pató_, --,
   {{0x634a0095,0x765b0345,0x7d1b21a4,0xad1c00a5}},	//   _kənd, _sauy, áusu, _חוזר,
   {{0xb8fa0fd1,0x27e701ff,0x22460035,0x229107c0}},	//   _डी_, änn_, _obok_, _láka_,
   {{0x67230a78,0x634a00a8,0xbebd00ea,0x31660065}},	//   šnjo, _zəng, drīk, _oroz_,
   {{0x4545004f,0x961d0228,0x00000000,0x00000000}},	//   انتق, _noņe, --, --,
   {{0xb4cd0e1d,0x273cc42a,0xf8b10594,0x85b80037}},	//   रते_, bín_, _اکر_, خامس_,
   {{0x44290ec4,0x273cc42b,0x00000000,0x00000000}},	//   ğa_, cín_, --, --,
   {{0x442904d4,0x3166080a,0xf3f100e2,0x00000000}},	//   şa_, _broz_, _tạo_, --,
   {{0x64940284,0x101512ea,0xddc60067,0x44f41346}},	//   _dàib, льня, zekł, _впус,
   {{0x2055606f,0x634a00a8,0x44f90118,0x00000000}},	//   утир, _bənd, _iè_, --,
   {{0x7c3806d7,0x9eaa19f0,0x44f901a5,0x25d300a1}},	//   _övri, евна_, _hè_, _तरुण,
   {{0x44f90c1f,0x00000000,0x00000000,0x00000000}},	//   _kè_, --, --, --,
   {{0x273c28f6,0x394b0069,0x25e60461,0x7c28021d}},	//   zín_, _npcs_, जेपी_, ódro,
   {{0xc1740372,0x44f9c42c,0x6cd60037,0x25d60070}},	//   _خدمت, _mè_, اقسا, טורן_,
   {{0x44f9142f,0xeb9a2294,0xa2c7112b,0x273cc42d}},	//   _lè_, хив_, ावप्, xín_,
   {{0x225f1034,0x273c01ba,0x00000000,0x00000000}},	//   nduk_, vín_, --, --,
   {{0x213f124f,0x44f9c42e,0xa2ab00b4,0x81e50033}},	// [eee0] ntuh_, _nè_, _जगन्, বুর_,
   {{0x273c0300,0xc8ca0d93,0x7d040371,0xb4cd0099}},	//   tín_, روان_, _itis, रतो_,
   {{0xbcfb00f7,0xe7f50066,0xfaa60f68,0xa6e900e2}},	//   nvén, ेड़ा_, _бано, _thự,
   {{0x225f3831,0x44f90028,0x2b5a0176,0x00000000}},	//   jduk_, _bè_, _ispc_, --,
   {{0x44f9298d,0x764200d7,0x273c6331,0x99750dc8}},	//   _cè_, rfoy, sín_, _курш,
   {{0x44f9c42f,0x2a60c430,0x273cc431,0x3940010b}},	//   _dè_, ldib_, pín_, mtis_,
   {{0x3940c432,0x9f5c0036,0x66190035,0x4394010b}},	//   ltis_, _levò_, bawk, райс,
   {{0x44f90c05,0x7d046645,0x6e242107,0xf60a0312}},	//   _fè_, _otis, _ndib, _ستره_,
   {{0x3940c433,0x225d0484,0x44f90359,0x634a00a8}},	//   ntis_, _dawk_, _gè_, _sənd,
   {{0x39570122,0x6e2406a2,0x3940010b,0x68ee003c}},	//   נשים_, _adib, itis_, _jibd,
   {{0x7d04c434,0x394000ab,0xdef700d8,0x81e50033}},	//   _atis, htis_, лыя_, বুল_,
   {{0x3940c435,0x44f902d0,0x61f60037,0x6e240282}},	//   ktis_, _yè_, _إساء, _cdib,
   {{0x2a600069,0xb5fd2ce5,0xeda7853e,0x6e24001e}},	//   ddib_, _inšt, ушно, _ddib,
   {{0x6e240095,0x68ee007a,0x00000000,0x00000000}},	//   _edib, _nibd, --, --,
   {{0x7d040075,0x3940123c,0x225d0118,0x00000000}},	//   _etis, etis_, _yawk_, --,
   {{0x8c4400a8,0x2b5a0392,0x00000000,0x00000000}},	//   əşmi, _dspc_, --, --,
   {{0x64480187,0xf807004c,0x3940010b,0xdd1400ac}},	// [eef0] _obdi, гчен, gtis_, _zúže,
   {{0xddc441d2,0x6d4d121e,0x634a0095,0x44f96c82}},	//   _uniš, _ipaa, _mənb, _rè_,
   {{0x501b0122,0x44f9c436,0x68ee0dc3,0x2a600dc3}},	//   גובו, _sè_, _dibd, bdib_,
   {{0xb4bf012f,0x44f902e9,0xb4cd1140,0x394001f7}},	//   ीत्_, _pè_, रत्_, btis_,
   {{0xa3e202e4,0xfd1f07e5,0x2987005f,0xbcfb00b5}},	//   नेस_, nsì_, _сынг, zvén,
   {{0x638500c3,0x44f9c437,0x29090086,0x656d01ba}},	//   игла, _vè_, mpaa_, ťaho,
   {{0x44f9142f,0x4375081b,0x7af7c438,0xe8d600a5}},	//   _wè_, рулт, _juxt, _כושר_,
   {{0x44f90c1f,0x3125027a,0x7af700a8,0x56941a8e}},	//   _tè_, адиг, _muxt, _ласт,
   {{0x81a800c8,0xdbe2045c,0x225f0225,0x7af70160}},	//   _খুব_, _खण्ड_, rduk_, _luxt,
   {{0xe8e000e8,0xa3e20084,0x65690159,0x7c2500e0}},	//   _địa_, नेह_, _ireh, _ndhr,
   {{0x7d04c439,0x32550352,0x66d8c43a,0x6b4c00b5}},	//   _stis, _ввер, líka, _mögö,
   {{0xbcfb006c,0x3940c43b,0x7c25c43c,0x7aef0211}},	//   rvén, ytis_, _adhr, _nict,
   {{0x76490054,0x46560070,0x69cf0260,0x9dba005f}},	//   _mbey, בױרן_, _nyce, тыну_,
   {{0xafe50086,0xab2ac43d,0xc19a00a5,0x7af7c43e}},	//   _колл, кога_, _בשני, _buxt,
   {{0x764902d0,0x44250139,0x93bc00af,0x6d4d0103}},	//   _obey, _mdl_, _scăz, _epaa,
   {{0x3940c43f,0x44255053,0x65696639,0x6926002d}},	//   ttis_, _ldl_, _oreh, имба,
   {{0x7d04c440,0x7aef1691,0xdce400ee,0x3940b2b2}},	// [ef00] _utis, _dict, _hrič, utis_,
   {{0x394021ca,0xdce43f5d,0x83fc0009,0x7649288d}},	//   rtis_, _krič, _kađe, _abey,
   {{0x3940c441,0x7aefc442,0x634a00a8,0x00000000}},	//   stis_, _fict, _mənc, --,
   {{0x3940c443,0x05660b07,0x6569c444,0x752401a0}},	//   ptis_, ивен, _breh, šizm,
   {{0x7ae4c445,0x68ee003c,0x83fc0c99,0x09e40033}},	//   mmit, _tibd, _lađe, _ফ্রা,
   {{0x656901ae,0x7ae474da,0xd70639e6,0x44250384}},	//   _dreh, lmit, _نظري, _cdl_,
   {{0x83fc0254,0x44254165,0x2d8b0963,0x6569c446}},	//   _nađe, _ddl_, zyce_, _ereh,
   {{0x7ae4c447,0x6b830443,0x59ba0325,0xa2ab0099}},	//   nmit, _ànge, _इशार, _जगण्,
   {{0x6569c448,0x7ae45497,0xbcfb008d,0x212d0118}},	//   _greh, imit, gvél, greh_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4d9de7,0x320d28c9,0xa3e2c449,0x260b0099}},	//   _spaa, bbey_, नेश_, ारची_,
   {{0x614601c8,0x2d8b0067,0x4425c44a,0x229100fe}},	//   _веда, tyce_, _zdl_, _jákl_,
   {{0xa2ab06fe,0xfd4700d8,0x3eabc44b,0xa3e20567}},	//   _जगत्, шэнн, rict_, नेर_,
   {{0x634a01c2,0x7ae4c44c,0xc0e351fe,0x69cf0067}},	//   _gənc, emit, _дочк, _ryce,
   {{0x7aefc44d,0x0b889c0a,0x8aa700d8,0xdce40a66}},	//   _pict, асти_, арад, _grič,
   {{0x7ae4043d,0xbea40798,0x69cf00d7,0xb5fd2018}},	//   gmit, _мајк, _pyce, _kaše,
   {{0x3ea90c21,0x7aefc44e,0x6b5c014e,0xdd9100d1}},	// [ef10] _imat_, _vict, _pågå, _رود_,
   {{0x290979b6,0xf8072ef5,0x7af70453,0xa3d70efd}},	//   rpaa_, рчан, _tuxt, _सरल_,
   {{0xd7f80009,0x29090054,0x7ae400a5,0x66ca00a0}},	//   руу_, spaa_, bmit, výkr,
   {{0xd24602aa,0x6569c44f,0xb87b03e6,0x60c80168}},	//   _عن_, _preh, _juíz, hodm,
   {{0x44251d40,0xbebd00ea,0x00000000,0x00000000}},	//   _pdl_, brīv, --, --,
   {{0xe7871303,0xbebd0029,0xd7fb0b25,0x58d402fb}},	//   _кубо, nsīb, _шум_, _моят,
   {{0xd7950082,0x798d05ca,0x3ea900c3,0xa2ab0b35}},	//   _الأخ, lyaw, _omat_, _जगद्,
   {{0x1634247f,0xfbb802b8,0x83fc011c,0x0bb800a5}},	//   _меся, יפות_, _rađe, ילום_,
   {{0x798dc450,0x65940798,0x320dc451,0x26cda049}},	//   nyaw, _дату, rbey_, _ikeo_,
   {{0xdce40936,0x3ea9431f,0xf1b90254,0x4425c452}},	//   _prič, _amat_, jaše_, _udl_,
   {{0xda17009a,0xb4e3964d,0xaec600d8,0xd3a7818c}},	//   तरात_, नगी_, йбол, _трап,
   {{0x2905c453,0x1d0ac454,0x24851be0,0xbebd0029}},	//   _član_, леми_, _holm_, esīb,
   {{0x6aad46e0,0x2485007c,0xb5fd05e2,0xaa7b00ac}},	//   diaf, _kolm_, _gaše, _ohýb,
   {{0xdce4024e,0xfc030546,0x3ea90118,0x6494009e}},	//   _trič, зпро, _emat_, _làin,
   {{0xeb971a12,0x634a0095,0xdca30d6e,0xb5fd3c56}},	//   бир_, _kəna, чари, _zaše,
   {{0x629b00c3,0x2d960226,0xed5a0bd7,0x3afc00e2}},	//   nhuo, _грос, _бои_, _víp_,
   {{0xe9da14a1,0x634a0095,0xf1b90207,0xc3110033}},	// [ef20] ука_, _məna, baše_, সূচি_,
   {{0xc61006bc,0xaa7b01ba,0x3afc96f8,0x961004aa}},	//   ार्य_, _chýb, _típ_, ार्ट_,
   {{0x91c90084,0xe7e300b4,0x25bf0139,0x00000000}},	//   _हुसै, केला_, _axul_, --,
   {{0x26df000e,0xb87b0391,0x64940284,0x648f03d0}},	//   _chuo_, _xuíz, _càin, _høih,
   {{0x6494009e,0xceb300a5,0x798d0027,0x68e5009e}},	//   _dàin, היא_, cyaw, bmhd,
   {{0xb8960082,0x98a0044d,0xb5fd00ac,0x248511d9}},	//   _السع, drić_, _raše, _colm_,
   {{0xa3e20b4a,0x64940284,0xa2780421,0x00000000}},	//   नें_, _fàin, ибку_, --,
   {{0xe6435a00,0x634a0095,0xb5fd03e0,0xf1b900f4}},	//   _несп, _cəna, _paše, zaše_,
   {{0xd010004f,0x66e3002d,0x66d80187,0xb5fd01fe}},	//   ولة_, _хота, líko, _inšp,
   {{0xb87b01dd,0x26df022e,0x656f01dd,0x212b6d9b}},	//   _suíz, _zhuo_, _ácha, ácha_,
   {{0x443ec455,0xf1b90b16,0x66d8024e,0xbebd00ea}},	//   _ict_, vaše_, níko, krīt,
   {{0x6602c456,0x05dc00c0,0x7d16001e,0x7ce016ad}},	//   ncok, _बराब, _bwys, hörd,
   {{0xf1b90a23,0xdceb01ba,0x443e021d,0x7d16099e}},	//   taše_, žičo, _kct_, _cwys,
   {{0xc0aa0ef5,0x672310ec,0x98a900cd,0xfaf30037}},	//   _حاصل_, šnji, trač_, كثر_,
   {{0x201ec457,0xf1b92115,0x6602012f,0x00000000}},	//   mati_, raše_, kcok, --,
   {{0x7d79006c,0x3ea96072,0x798d10cd,0x201a00be}},	//   _نمبر_, _umat_, tyaw, _õpib_,
   {{0x7ce015e5,0x443e8d52,0xf1b900f4,0x649400f1}},	// [ef30] förd, _oct_, paše_, _ràin,
   {{0x201ec458,0x798dc459,0x6d5f0024,0x7b1950f1}},	//   nati_, ryaw, _isqa, _коор_,
   {{0x23a794e2,0x798da04a,0x69c10035,0xf3f10023}},	//   _केंद, syaw, _śled, _tại_,
   {{0x3eb9309d,0x201ec45a,0x443e00a5,0xf770211b}},	//   nnst_, hati_, _act_, عال_,
   {{0x201ec45b,0xa2c702e4,0x2a3a00c2,0x3eb90122}},	//   kati_, ावस्, _דערמ, inst_,
   {{0x201ec45c,0x634a0095,0x443e026e,0x98a0011c}},	//   jati_, _səna, _cct_, vrić_,
   {{0x201e1635,0xa5c30035,0x629bc45d,0xd6db0382}},	//   dati_, _łódz, thuo, _бта_,
   {{0xd24e0098,0xcfce0083,0x443ec150,0x98a000cb}},	//   ننى_, রধান, _ect_, trić_,
   {{0x2ee0001e,0x3863009f,0x629b081b,0xdb1e00f6}},	//   _rhif_, _kajr_, rhuo, _expè,
   {{0x2ed20266,0x201ec45e,0x3eb93cd3,0x4f251422}},	//   सत्त, gati_, enst_, одоб,
   {{0x6d5f028b,0x661b0120,0x56b50070,0x629b0023}},	//   _asqa, _keuk, ַפֿן_, phuo,
   {{0x7d160297,0x25f00722,0x661b0d35,0x7af800b5}},	//   _pwys, ुँची_, _jeuk, _évti,
   {{0x7ce001ae,0x661b012f,0xb5fd023a,0x00000000}},	//   höre, _meuk, _zašc, --,
   {{0x201ec45f,0xb87b0392,0x661b809f,0x3f6901e0}},	//   cati_, _guíx, _leuk, _вико_,
   {{0xe51906bb,0x28bf1371,0x00000000,0x00000000}},	//   नीति_, ्वनि, --, --,
   {{0x83fc0a78,0x75240207,0x4af900af,0x00000000}},	//   _mađa, šizi, сэря_, --,
   {{0xed5a7c71,0xd9433ff3,0x64940284,0x7ce0c460}},	// [ef40] _топ_, мети, _bàil, törd,
   {{0x7ce0022a,0xa2a9021a,0x7e64c461,0x64940284}},	//   före, जोत्, _haip, _càil,
   {{0x661b19c1,0x7e64c462,0x6d46c463,0x160a0037}},	//   _beuk, _kaip, ltka, لياً_,
   {{0x201ec464,0x443ec465,0x0eca0026,0x7bdec466}},	//   zati_, _sct_, रविड, _izpu,
   {{0x7e641c3f,0x661bc40d,0x6d4601bc,0xddcd00c1}},	//   _maip, _deuk, ntka, _maaş,
   {{0x6d46c467,0x7e646310,0x6c7a02b5,0x6299c468}},	//   itka, _laip, שאַפ, _alwo,
   {{0x201e2a9f,0x443e0027,0x6d46018d,0x3eb9008d}},	//   vati_, _vct_, htka, ynst_,
   {{0x09de0429,0x201e2b63,0x7e642dce,0x6d4609e1}},	//   _मराठ, wati_, _naip, ktka,
   {{0x201ec469,0x443ec46a,0x6d44006d,0xa5071ade}},	//   tati_, _tct_, _nqia, _мета_,
   {{0xdb1e02e1,0x661b01d7,0xb87b01ef,0x443e04fb}},	//   _expé, _zeuk, _quíx, _uct_,
   {{0x201ec46b,0x83fc029d,0xd7d002cb,0x020601c8}},	//   rati_, _gađa, _तुमच, _дзен,
   {{0x201e1635,0x7e64c46c,0xeeabc46d,0xb5fd00cd}},	//   sati_, _caip, рток_, _kaša,
   {{0x201e253e,0xa2c71bdd,0x6fcaa4f9,0x649401a6}},	//   pati_, ावर्, _सुरू, _làim,
   {{0xcce70514,0x443c0160,0x2ff800af,0x201e01e9}},	//   تسجي, ngv_, _ункь_, qati_,
   {{0x6d46005d,0x7ce0013c,0x9b689e5f,0xf1b933ee}},	//   atka, förb, ошта_, maša_,
   {{0x201c0c06,0x7e64592a,0x64940284,0x386d0457}},	//   _hevi_, _gaip, _sàil, _şer_,
   {{0x6458c46e,0xb5fd0a78,0x14ca06bc,0x661b0a81}},	// [ef50] kevi, _naša, ाकाण, _reuk,
   {{0x64580690,0xa3cd0c67,0xf1b902dd,0x7ce0c46f}},	//   jevi, रथम_, naša_, töre,
   {{0x2bd200a1,0x6560009e,0x7e646636,0x00000000}},	//   _दुपा, _asmh, _yaip, --,
   {{0x6e3d1788,0x201c08a5,0xb5fd02c4,0x83fc0254}},	//   ngsb, _levi_, _baša, _rađa,
   {{0x260a0299,0x6494c470,0x3d0f0099,0xf1b900cd}},	//   ाड़ी_, _tàil, तीचे_, kaša_,
   {{0x64581192,0xb5fd0124,0xf1b90ce9,0x201cc471}},	//   gevi, _daša, jaša_, _nevi_,
   {{0x661b0034,0x68fd071b,0xa3570647,0xe2910037}},	//   _teuk, _husd, تیاط_, فذة_,
   {{0x644a0036,0x3bbc0122,0x68fd0298,0x661b0065}},	//   affi, ימוד, _kusd, _ueuk,
   {{0xdb0a024e,0x64582aab,0x201cacba,0x7e64145d}},	//   čnéh, bevi, _bevi_, _raip,
   {{0x6458c472,0x201c31e1,0xd24e04e8,0x765900e9}},	//   cevi, _cevi_, پنی_, lewy,
   {{0x201c02fb,0x7e6400f1,0x04c80aaa,0x6441009e}},	//   _devi_, _paip, _بولي_, _icli,
   {{0xc3321759,0xed5a4cc1,0x6d46c473,0x765900e9}},	//   _טוב_, бом_, ttka, newy,
   {{0xdd920125,0x23900029,0x6d46c474,0xa069c475}},	//   روس_, _vējš_, utka, _гала_,
   {{0x8fa50131,0x7e6408c7,0x649d01f7,0x64410392}},	//   _нале, _waip, _fèie, _jcli,
   {{0x7e64c476,0x68fdc477,0x3a20c478,0xf1af007c}},	//   _taip, _ausd, taip_, _जेतन,
   {{0x6458093f,0x68f50029,0x68fd2bb7,0x244f01fb}},	//   zevi, _aizd, _busd, lımı_,
   {{0x645801c2,0x644ac479,0x68f504d4,0x3a200037}},	// [ef60] yevi, yffi, _bizd, raip_,
   {{0x244f008f,0x68fdc47a,0x29000031,0xb5fd00e1}},	//   nımı_, _dusd, rqia_, _raša,
   {{0xabfb011d,0x64581b99,0x68f5c47b,0x3b0a0274}},	//   _להיר, vevi, _dizd, _ћемо_,
   {{0xb5fd26e3,0x61f9016e,0x644193cc,0x765903bc}},	//   _paša, _ngwl, _acli, gewy,
   {{0x2f010987,0x6458052a,0x244f01d6,0x68fd012f}},	//   _lóg_, tevi, kımı_, _gusd,
   {{0x7afe01d2,0x64a30f29,0xb5fd0129,0xb4d60325}},	//   _kupt, нача, _vaša, सते_,
   {{0x2f01c47c,0x201c0359,0x289b0319,0x644a00e9}},	//   _nóg_, _revi_, _פילא, rffi,
   {{0x6458c47d,0x201cc47e,0x4ece0033,0x77bb00a5}},	//   sevi, _sevi_, রগুল, _המלח,
   {{0x7afe0043,0x6458c47f,0xf1b90496,0xe5a300af}},	//   _lupt, pevi, taša_, _зити,
   {{0x67220080,0xf8cc0461,0x64410079,0xf99f01f7}},	//   ņoju, ़किय, _gcli, _ofèn_,
   {{0x442c4262,0xf1b904c3,0x0f2300af,0xb5fd040b}},	//   _idd_, raša_, ньям, _mašn,
   {{0x200700fb,0x3f8200cd,0x321d0b88,0x649d0176}},	//   _efni_, ćku_, _gewy_, _vèie,
   {{0x6d5d01e4,0x201c0029,0x2bd20437,0x442c0a17}},	//   uwsa, _tevi_, _दुबा, _kdd_,
   {{0xe7be0d91,0x83fc0009,0x68fdc480,0x442c00a2}},	//   ्थाप, _mađo, _rusd, _jdd_,
   {{0x442cc481,0x66d8008a,0x7afe00af,0x83fc00f4}},	//   _mdd_, ríkj, _cupt, _lađo,
   {{0x68f500d0,0x628603a6,0x7afe0176,0x68fdc482}},	//   _sizd, ökoh, _dupt, _pusd,
   {{0x68f5c483,0xa9540185,0x83fc00cd,0xf8b10416}},	// [ef70] _pizd, нкті, _nađo, نکس_,
   {{0x7d0d5ba0,0xb4d629ce,0x00000000,0x00000000}},	//   _itas, सतो_, --, --,
   {{0xf09300c2,0x59f903ad,0xb8d50e1d,0xb5fd0009}},	//   ענע_, _меня_, _जग_, _dašn,
   {{0x442c0052,0x940c01c2,0x35b54b34,0xe7300180}},	//   _add_, _ildə_, мбер, اصل_,
   {{0x68f50024,0x64410051,0x290b00b5,0xd1260fab}},	//   _tizd, _pcli, _utca_, _جم_,
   {{0x2a690006,0x3949c484,0x442c00f7,0xddcd0103}},	//   ldab_, mtas_, _cdd_, _abaŋ,
   {{0x6e2d0a78,0x22980118,0x2a790051,0x00000000}},	//   _odab, _céko_, _knsb_, --,
   {{0x2a690006,0x39496fb3,0x6e2d050f,0x7d0d0103}},	//   ndab_, otas_, _ndab, _otas,
   {{0x3949c485,0x244f00d0,0x7d0d01d5,0x26cf030d}},	//   ntas_, tımı_, _ntas, mogo_,
   {{0x3949c486,0x6e2dc487,0x64410211,0x2f010079}},	//   itas_, _adab, _ucli, _póg_,
   {{0xd251004f,0x244f00d0,0x3949c488,0x752900ac}},	//   _لنا_, rımı_, htas_, _hvez,
   {{0x3949c489,0xddcd003a,0x2a69006d,0x656d00a0}},	//   ktas_, _snaš, jdab_, ťahu,
   {{0xe0ce0ff6,0xf8bf0b35,0x7afe5f44,0x504503e6}},	//   _ав_, ्वाय, _supt, _желб,
   {{0x442cc48a,0x7ce0013c,0x26cf6f6a,0x6e2d01cb}},	//   _xdd_, föra, hogo_, _edab,
   {{0x38ad0669,0xb5fdc48b,0xcee92588,0x316dc48c}},	//   _görə_, _našo, ترین_, lvez_,
   {{0x628bc48d,0xa3e20653,0x3949c48e,0x3b0703e6}},	//   _jogo, नेट_, ftas_, ќето_,
   {{0x26cf0657,0x628b02c6,0xb5fd0a09,0x3949c48f}},	// [ef80] dogo_, _mogo, _pašn, gtas_,
   {{0x6609c490,0xddc4290b,0x316d000d,0x6d56034d}},	//   _afek, _kniž, ivez_, _ipya,
   {{0x3949c491,0x26cf1699,0xfaa6010b,0x7529027a}},	//   atas_, fogo_, _жано, _avez,
   {{0x628bc492,0x26cf6a5b,0xbc3a00b5,0x00000000}},	//   _nogo, gogo_, _اسکا_, --,
   {{0x39490b4c,0x64a623a4,0x7d0d02d7,0x6d9400a0}},	//   ctas_, мада, _xtas, _fľaš,
   {{0x628b034d,0x69c60024,0x6d56034d,0x00000000}},	//   _aogo, _ixke, _mpya, --,
   {{0x628b1c65,0xbcfb006c,0x442c0453,0x7529c493}},	//   _bogo, lvét, _vdd_, _evez,
   {{0x628b07a6,0xa68601c8,0xf99f0260,0xd048013b}},	//   _cogo, _ўлад, _ofèl_, ələy,
   {{0x628b02dd,0x041d0083,0x442c0260,0xa3e20026}},	//   _dogo, _নারী_, _tdd_, नेज_,
   {{0x442c0a8a,0x3f1429e5,0x297b016b,0x00000000}},	//   _udd_, ндос, קטיא, --,
   {{0x7529536c,0x7d0dc494,0xf8370122,0x628b00b5}},	//   _zvez, _stas, ונית_, _fogo,
   {{0xe7e6006a,0x628b0291,0x394900d8,0x634a0095}},	//   _करना_, _gogo, ytas_, _lənk,
   {{0x41e248cd,0xf1e222a7,0x39492dd3,0xa06a0274}},	//   _परिस, _परिन, xtas_, _мада_,
   {{0xa3e51a75,0xdb1e01ef,0xba1701c0,0x00000000}},	//   _नरम_, _expí, तर्फ_, --,
   {{0xdfd00082,0x1bd409c2,0xf99f0107,0x26cfc495}},	//   _حيث_, воря, _efèl_, yogo_,
   {{0x3949c496,0x2eca0d53,0x628b043f,0xdced6395}},	//   ttas_, रवृत, _xogo, _irač,
   {{0xdced024e,0x7d0dc497,0x3949266e,0xddc40bc9}},	// [ef90] _hrač, _utas, utas_, _zniž,
   {{0x7bc50d4b,0x7bc00448,0xcc2700fd,0x00000000}},	//   _txhu, ğmur, _کرکٹ, --,
   {{0x75293df7,0x26cf0371,0xea0000e2,0x870401e0}},	//   _svez, togo_, _ngặt_, вяче,
   {{0xb5fd40f0,0x3949c498,0xdced0254,0x61e200ea}},	//   _vašo, ptas_, _mrač, _ozol,
   {{0x7aedc499,0xdd320095,0x27ff0225,0x00000000}},	//   mmat, _məşq, _şunu_, --,
   {{0xb5fd07fc,0x628bc49a,0xd91a00a5,0x7ce01193}},	//   _zašl, _sogo, _מושל, hörn,
   {{0x628b1cc4,0x7aed01ed,0x7ce0c49b,0x00000000}},	//   _pogo, omat, körn, --,
   {{0xc2450f94,0x28bf159b,0x7aedc49c,0x26d901dd}},	//   хник, ्ववि, nmat, _óso_,
   {{0x316d02e1,0xddc40956,0xdced0c99,0x7529011c}},	//   uvez_, _sniž, _arač, _uvez,
   {{0xdced28c2,0x316d52d5,0x93bc002d,0x66d8008d}},	//   _brač, rvez_, _adău, víki,
   {{0x7aed06b3,0xc0a817bd,0x628b593e,0x61e2030d}},	//   kmat, بايل_, _togo, _ezol,
   {{0xed5a65c9,0xf772016b,0x00000000,0x00000000}},	//   пом_, אקט_, --, --,
   {{0x7aedc49d,0xdb0a01c0,0xb5fd040b,0x8d760037}},	//   dmat, čníh, _našm, راحا,
   {{0x66d80093,0xddc40024,0x75f60225,0x6fca02b4}},	//   ríki, _iniż, _hüzü, _सुकू,
   {{0xdced0ce9,0xb5fd00ea,0x00000000,0x00000000}},	//   _grač, _pašl, --, --,
   {{0xdce402c4,0xb8660647,0xb5fd013a,0x00000000}},	//   _orić, کارو, _bašm, --,
   {{0xdced0888,0x510c0070,0x38a4033b,0x6e260dc3}},	// [efa0] _zrač, ַהאַ, _jörg_, makb,
   {{0x7aedc49e,0x6e26c49f,0xe9df0392,0x38a40093}},	//   amat, lakb, _abús_, _mörg_,
   {{0x6f0b002d,0x3ea00a8a,0x7aed0553,0x00000000}},	//   _încă, _klit_, bmat, --,
   {{0xd7ef004f,0xe1e75b16,0x98c00225,0x7aed416a}},	//   حكم_, _مس_, ırıp_, cmat,
   {{0xbcfbc4a0,0x28bf00b4,0x3ea00069,0x00000000}},	//   lvér, ्वशि, _mlit_, --,
   {{0xf3661238,0x34ca0084,0x3ea00310,0xdc3d0009}},	//   етин, ाकेद, _llit_, ršću,
   {{0x61e20332,0xbcfb0391,0xcc3b0070,0x37e301e0}},	//   _szol, nvér, לעסט, _борг,
   {{0x290200c3,0x386a00fe,0x754900fd,0x00000000}},	//   _kuka_, _habr_, öszö, --,
   {{0x634a01c2,0x6e267c3c,0x75f6013b,0x2bdd021a}},	//   _məni, dakb, _düzü, _यर्थ,
   {{0x386a046a,0xdced0184,0x3ea000d1,0x3a2200e0}},	//   _jabr_, _prač, _alit_, _lekp_,
   {{0x7aedc4a1,0xdfd0004f,0x733600fd,0x7ce024c4}},	//   ymat, شيح_, _سرائ, törn,
   {{0xdced068b,0x76423136,0x38a40523,0x71a6010b}},	//   _vrač, ngoy, _hörd_, _паез,
   {{0x656201ae,0x7aedc4a2,0x83fc0009,0x6aa40054}},	//   nwoh, vmat, _nađk, dhif,
   {{0xdced1cc4,0x7aedc4a3,0xe04a00bf,0x2bd207b5}},	//   _trač, wmat, _رشته_, _दुहा,
   {{0x7aed41f4,0x75f601d6,0x29020bd1,0xdced011c}},	//   tmat, _yüzü, _auka_, _urač,
   {{0x290208eb,0x28d902e4,0xb5fdc4a4,0x3ea00159}},	//   _buka_, _बीजि, _pašm, _glit_,
   {{0x200b006a,0x29024572,0x634a0095,0x1958021f}},	// [efb0] ście_, _cuka_, _dəni, наты_,
   {{0x2902c06c,0x26c40c21,0x290f0029,0x64ca018d}},	//   _duka_, _ajmo_, īga_, ाकोश,
   {{0xdce4022f,0x7aed00b9,0x386a005f,0x00000000}},	//   _srić, pmat, _dabr_, --,
   {{0xd7c80413,0x6aa4c4a5,0xdce4003a,0xb5fd0009}},	//   رونه_, chif, _prić, _tašm,
   {{0xb5fd1321,0xd4690fb4,0x38a40523,0x00000000}},	//   _hašk, диле_, _börd_, --,
   {{0x64cb366c,0x2298008a,0x34cb01c0,0x5fb20ebd}},	//   िवेश, _fékk_, िवेद, ुपाल,
   {{0x64a28ab7,0x753c0029,0xf8bf00db,0x38a400a8}},	//   раща, _ārze, ्वीप, _dörd_,
   {{0xe7e60cf1,0x395901d6,0xb5fd1e85,0x386a0009}},	//   _करता_, _kpss_, _mašk, _zabr_,
   {{0x44f501f1,0x7ce05c2d,0xb5fd008b,0x98a90067}},	//   _апас, förl, _lašk, grać_,
   {{0xd3a7010e,0x2ebc02b4,0xf99f0107,0x3eb20298}},	//   _преп, ोक्त, _afèk_, _smyt_,
   {{0x6e2600a7,0x09de05f7,0xb5fd00cd,0x6494009e}},	//   takb, _मर्य, _našk, _càiu,
   {{0x2bd507ba,0x98a9004e,0x644367c9,0xddc4003c}},	//   _धड़ा, brać_, lgni, _tniż,
   {{0x614508ae,0x442701d7,0x38a402b1,0x60cd021d}},	//   _рела, oan_, _höre_, _íamo,
   {{0x29021550,0x634a0095,0x225f0009,0xfce6066d}},	//   _ruka_, _səni, leuk_, того,
   {{0x290206b3,0x4427c4a6,0x6443c4a7,0x6e26c4a8}},	//   _suka_, ian_, igni, pakb,
   {{0x2902c4a9,0xdd922e63,0x3ea000a7,0x386a0088}},	//   _puka_, _نوع_, _ulit_, _sabr_,
   {{0x4427c4aa,0x6f0336b4,0x2bd2c4ab,0xe9da0384}},	// [efc0] kan_, _hunc, _दुरा, фка_,
   {{0x27962f44,0x6f031034,0x38cb042c,0x6aa4c4ac}},	//   кшер, _kunc, والی_, shif,
   {{0x7d040903,0x6e2400d7,0xdc9b00a5,0x6f03409c}},	//   _huis, _keib, _חייל, _junc,
   {{0x6f03c4ad,0x7d04000e,0x4427c4ae,0x2a6b0211}},	//   _munc, _kuis, ean_, _gacb_,
   {{0x4427c4af,0x7d040a75,0xb5fd0097,0x764245c9}},	//   fan_, _juis, _zašk, rgoy,
   {{0x6e249e59,0x7d0413c1,0x44278fbf,0x6443022a}},	//   _leib, _muis, gan_, ggni,
   {{0x6f032140,0x7d041816,0x3940c4b0,0xf2c62f7c}},	//   _nunc, _luis, luis_, ксин,
   {{0x68fcc4b1,0x4427c4b2,0x2b5a01ef,0x83fc00cd}},	//   _hird, aan_, _mppc_, _mađi,
   {{0x4427c4b3,0x394092c9,0x7ce00742,0x7d041c9e}},	//   ban_, nuis_, törl, _nuis,
   {{0x4427449a,0x38a4022a,0x68fc0024,0x7ce006d2}},	//   can_, _före_, _jird, förm,
   {{0x38a40723,0x6f03c4b4,0xc24612f8,0xb4c0045c}},	//   _göre_, _cunc, _анек, ीवी_,
   {{0x6f03c4b5,0xb5fd042a,0x52760e6b,0x6e2407a6}},	//   _dunc, _rašk, _جائز, _ceib,
   {{0x7d04c4b6,0x614300d8,0x6f0301f7,0xb5fd023a}},	//   _cuis, _веча, _eunc, _sašk,
   {{0x7d04c4b7,0x6abd0d91,0xd1970d85,0x39402386}},	//   _duis, ्क्र, _בכדי_, duis_,
   {{0x7d04009e,0x99bf0083,0x6f03c4b8,0x83fc0009}},	//   _euis, _আরেক, _gunc, _bađi,
   {{0x4427c4b9,0x5a34798c,0x7d04c4ba,0x68fc066a}},	//   zan_, инст, _fuis, _aird,
   {{0x4427c4bb,0x3eb90ccf,0x3940c4bc,0x49751482}},	// [efd0] yan_, mist_, guis_, ылас,
   {{0x4427c4bd,0x7e6d03a6,0xb5fd4877,0x68fc0211}},	//   xan_, _haap, _tašk, _cird,
   {{0x4427a209,0x2d99c4be,0x7e6dc4bf,0x68fc36e9}},	//   van_, lyse_, _kaap, _dird,
   {{0x7e6d3784,0xb5fd0121,0x39400d35,0x68fc05b9}},	//   _jaap, _kaši, buis_, _eird,
   {{0x29840aeb,0x4427c4c0,0x6d4f2ddc,0x7e6dc4c1}},	//   _кырг, tan_, ntca, _maap,
   {{0xdfc60082,0xb5fdb4a7,0x4427128f,0x64480176}},	//   _هي_, _maši, uan_, _ccdi,
   {{0x7c253ce1,0x3eb93625,0xf1b91bd8,0x6443c4c2}},	//   _mehr, kist_, maši_, rgni,
   {{0x4427c4c3,0x7afdc4c4,0x36d5220a,0x569417c7}},	//   san_, _jist, _собр, _каст,
   {{0x6f03326f,0x6e24c4c5,0x225f0fdb,0x64940211}},	//   _sunc, _reib, reuk_, _càis,
   {{0x6f03c4c6,0x442734d1,0xb5fd4c42,0x7c25c4c7}},	//   _punc, qan_, _naši, _nehr,
   {{0x7ea64df4,0x7d04c4c8,0x69dd5c1b,0x3eb90093}},	//   _lópe, _suis, _lyse, fist_,
   {{0x7afdc4c9,0x3eb9c4ca,0x7d041777,0x4425a279}},	//   _nist, gist_, _puis, _hel_,
   {{0x7d04365e,0x4425c4cb,0x69ddc4cc,0x91840773}},	//   _quis, _kel_, _nyse, _نجوم,
   {{0x7afdc4cd,0x4425c4ce,0x3ebe006c,0xe8bf0d53}},	//   _aist, _jel_, őtt_, ्वोच,
   {{0x7afdc4cf,0x7e6d05f5,0xc0520122,0x7c25003c}},	//   _bist, _faap, _הזו_, _dehr,
   {{0x7d04c4d0,0x3eb9c4d1,0x68fcc4d2,0x39400159}},	//   _tuis, cist_, _sird, tuis_,
   {{0x6d4f0051,0x7afd1f74,0xf1a6009a,0x3edb02b5}},	// [efe0] ctca, _dist, गनयन, _אַזא,
   {{0x4425c4d3,0x3b8610d5,0x69dd008c,0x7afd001e}},	//   _nel_, _блог, _dyse, _eist,
   {{0x68fcc4d4,0x6ac60041,0xada7008d,0x656902ee}},	//   _vird, _مقدم, _trúð, _aseh,
   {{0x39401010,0x7afdc4d5,0xfbd30122,0x634a0095}},	//   puis_, _gist, _לתת_, _mənt,
   {{0x39400fcb,0x68fc0029,0xe7e60084,0x3cfd00a8}},	//   quis_, _tird, _करवा_, _üzvü_,
   {{0xb4ce065a,0x44250012,0x7afd016f,0x00000000}},	//   रवे_, _cel_, _zist, --,
   {{0x4425505d,0x64940284,0xd047013b,0x00000000}},	//   _del_, _bàir, _ölən, --,
   {{0x7afd1945,0x442500be,0x64940284,0xe20a0067}},	//   _xist, _eel_, _càir, _otóż_,
   {{0x4425c4d6,0xe6930082,0x2bdb210a,0x09c40033}},	//   _fel_, _القد, _मुना, ্ধকা,
   {{0x2e2400e8,0x7e6d0196,0x3eb924dc,0x64940211}},	//   _đườn, _saap, wist_, _eàir,
   {{0xb5fd2bbb,0x32462087,0x2d99053e,0x649401da}},	//   _raši, _مناف, wyse_, _fàir,
   {{0x6d4f0bf7,0x44250260,0xb5fd01a0,0x649400f1}},	//   ttca, _zel_, _saši, _gàir,
   {{0x7afdc4d7,0x99bf0083,0x212b004f,0xb5fd9fec}},	//   _rist, _আর্ক, ácht_, _paši,
   {{0x2d99c4d8,0x200e4c55,0x307603fa,0x3eb919a6}},	//   ryse_, _uffi_, _људс, sist_,
   {{0xb5fd232f,0x709b0070,0x2d84191b,0x7e6dc4d9}},	//   _vaši, _אױגו, ämer_, _taap,
   {{0x386101ae,0x7c25c4da,0x69352b60,0xc9871e46}},	//   wehr_, _wehr, инбу, лузи,
   {{0x7c25c4db,0x7afd09e8,0xf1b97ef3,0xa3b600b4}},	// [eff0] _tehr, _vist, taši_, _चेस_,
   {{0x7afdc4dc,0xb4ce018d,0x69dd0097,0x00000000}},	//   _wist, रवो_, _vyse, --,
   {{0x7afdc4dd,0x69dd8a3b,0xf1b905e2,0x3a2908dd}},	//   _tist, _wyse, raši_, paap_,
   {{0x7afdc4de,0xaa67224a,0x00000000,0x00000000}},	//   _uist, _сток, --, --,
   {{0x4425c4df,0xa2b30035,0xddc4010b,0x7ce001ff}},	//   _pel_, इफस्, _kaiš, förh,
   {{0xd4910023,0x442501e9,0x00000000,0x00000000}},	//   _tìm_, _qel_, --, --,
   {{0x442529f1,0x64940014,0xddc4010b,0x98a0010b}},	//   _vel_, _pàir, _maiš, usią_,
   {{0xd6c300f5,0x44251e1e,0x6595c4e0,0xddc400d8}},	//   _امری, _wel_, _кабу, _laiš,
   {{0x84470041,0x38a4013c,0xf9920070,0xf99f0107}},	//   _مخال, _höra_, ַרט_, _efèv_,
   {{0x44253638,0x40950086,0x38a4013c,0xddc40254}},	//   _uel_, ррит, _köra_, _naiš,
   {{0xaec60086,0x212d0371,0x5fcf00be,0x8e86b19d}},	//   ибол, sseh_, _सुखल, агне,
   {{0x9fa2008d,0x7bde0107,0x6494009e,0x531a024b}},	//   ríða_, _rypu, _uàir, _יועצ,
   {{0x9fa2008a,0x2bdb0084,0xee37022b,0x7c3a01ef}},	//   síða_, _मुबा, шня_, ótro,
   {{0x659a02b5,0x61e601d6,0x634a00a8,0x00000000}},	//   דישק, ükle, _tənt, --,
   {{0x8a0607bc,0x7c2200f4,0x00000000,0x00000000}},	//   изве, _đord, --, --,
   {{0x7bde0187,0x00000000,0x00000000,0x00000000}},	//   _vypu, --, --, --,

   {{0x7ce0306a,0xd9460f24,0x7bde0067,0xb5fdc4e1}},	// [f000] höri, рези, _wypu, _zašv,
   {{0xdbdf008d,0xddc41715,0x38a40282,0xb5fd00f4}},	//   _tíði, _gaiš, _böra_, _jašu,
   {{0x6e3601c0,0x61e20096,0xb5fd0207,0xad9b002a}},	//   _kdyb, _पर्ष, _mašu, scút,
   {{0x98a0011c,0xe7371b44,0xf1b900ec,0x00000000}},	//   ksić_, рец_, lašu_, --,
   {{0x25a002aa,0xa8060086,0x6aa30160,0x00000000}},	//   áil_, _взгл, _înfa, --,
   {{0x7ce0013c,0xe71a0c26,0x38a401ff,0xf1b900c7}},	//   föri, _ليست_, _föra_, našu_,
   {{0x38a406d7,0xb7da0220,0x25a08c65,0x395200c7}},	//   _göra_, _شورا_, šil_, ltys_,
   {{0xcb130122,0x634a013b,0x00000000,0x00000000}},	//   חלה_, _səns, --, --,
   {{0x395201c8,0xe5a300d4,0xdb230098,0x463b016b}},	//   ntys_, _дити, órúc, _שעמע,
   {{0xb5fd0029,0x92c80033,0xf1b900f4,0xc95300a5}},	//   _pašv, োগে_, jašu_, קמת_,
   {{0x787902b5,0x8c010083,0x645ac4e2,0xa3ca00ab}},	//   אָרו, ্রমন_, _ibti, _लखि_,
   {{0x59c6057c,0x00000000,0x00000000,0x00000000}},	//   लपार, --, --, --,
   {{0x91e33539,0x1cbb2604,0x6e3600e5,0x6dcb010b}},	//   _доце, ناسب_, _ddyb, тынг_,
   {{0x628201e8,0xfa230033,0x9d180b25,0xf1b9080a}},	//   _hnoo, _ফাইল_, рорт_, gašu_,
   {{0x62820b0d,0xb5fd00d5,0x645a01ed,0x601700a5}},	//   _knoo, _hašt, _mbti, _דחוף_,
   {{0xb3450370,0xb5fdc4e3,0x6e360035,0x201e010b}},	//   luçã, _kašt, _gdyb, lbti_,
   {{0xf807172a,0x645ac4e4,0x1c140026,0xb5fd00ee}},	// [f010] ачен, _obti, तुहल_, _jašt,
   {{0x2bd20821,0xb5fd03fd,0x6b9c008d,0x645e00ab}},	//   _दुका, _mašt, byrg, õpil,
   {{0x628201a8,0xb5fd1575,0xb06500c3,0x7ea6008d}},	//   _onoo, _lašt, lmää, _hópa,
   {{0x645aa13e,0x7ea60093,0xcfa80033,0xd6180c74}},	//   _abti, _kópa, _ওখান, لتها_,
   {{0x6c780a86,0xb5fd2d5b,0x2bdb07ba,0xc9872f7c}},	//   _صحیح_, _našt, _मुता, _туни,
   {{0x6282018e,0x645a02d7,0x38a401ff,0xb7170833}},	//   _anoo, _cbti, _hörn_, _نظرت,
   {{0xb34500c9,0xddc4002d,0x437500af,0xd7c90037}},	//   duçã, _obiş, султ, _صوره_,
   {{0x224b02c9,0x6282012f,0xb5fd00cd,0x7ce09fae}},	//   ück_, _cnoo, _bašt, röri,
   {{0x200318b0,0x765b04fb,0x5fcf02b4,0x00000000}},	//   žjim_, _ibuy, _सुजल, --,
   {{0x10a532fa,0x657b01d5,0x6282a92e,0x693d0160}},	//   сион, _iruh, _enoo, _găeş,
   {{0xb5fd00d5,0xf1b90207,0x00000000,0x00000000}},	//   _vašu, vašu_, --, --,
   {{0x395200c3,0x00000000,0x00000000,0x00000000}},	//   ytys_, --, --, --,
   {{0xe1880088,0x765b9491,0xc1080023,0xe16701cb}},	//   _نئون_, _mbuy, _hỗn_, _خداي,
   {{0x61eb25d6,0x98a7000c,0xb34503e6,0xb4f9016b}},	//   _izgl, čně_, cuçã, רפֿי,
   {{0xb5fd0537,0x38a4008a,0x765b0273,0x2bd23dd4}},	//   _zašt, _börn_, _obuy, _दुखा,
   {{0xdb1702d7,0xbebd00ea,0x8f9a00a5,0x0d862a0b}},	//   _axxó, usīt, _תיקי, _глин,
   {{0x8c46a75c,0x7bc1000d,0xf1b900f4,0x6d400841}},	// [f020] _лепе, ûlur, pašu_, ámad,
   {{0x6d46c4e5,0x395249d7,0x673e012e,0x765bc4e6}},	//   muka, rtys_, trpj, _abuy,
   {{0xeb9a095d,0x6d4b013c,0x39523122,0xe61a1a7d}},	//   _син_, _ägar, stys_, где_,
   {{0x7c2ea2ac,0x657bc4e7,0xd6d901e0,0xad9b002a}},	//   labr, _bruh, аті_, ocúp,
   {{0x7ae4009f,0x26c6009e,0x1dc800b4,0x00000000}},	//   mlit, rnoo_, रपित, --,
   {{0x7ae4c4e8,0x657b114d,0xb5fd00d8,0x9866006c}},	//   llit, _druh, _rašt, _دیئے_,
   {{0x6d46c4e9,0xf7431353,0x7ae400be,0x3e7f00c3}},	//   huka, _неро, olit, _jätä_,
   {{0x6d461201,0xb5fd01c8,0x6b830b4c,0xc1141c56}},	//   kuka, _pašt, _ánge, омиј,
   {{0xddcd15d8,0x6d46431f,0x1a9b02b5,0x95ca0ec9}},	//   _snaž, juka, טיקע, _слаб_,
   {{0x6d466cf5,0x39400094,0x7ae4c4ea,0x3f770160}},	//   duka, iris_, hlit, _bău_,
   {{0xb4e40299,0x39400211,0x7c2ec4eb,0xb3450279}},	//   नती_, hris_, dabr, ruçã,
   {{0x442ec4ec,0xdced0254,0x3940c4ed,0x6d4661c8}},	//   laf_, _krać, kris_, fuka,
   {{0xf19403ad,0x6d46a02b,0xd01200d1,0x00000000}},	//   _филь, guka, _فلش_, --,
   {{0x442eb25b,0x3940c4ee,0x7ae40453,0x7b1908d9}},	//   naf_, dris_, elit, иогр_,
   {{0x7ae40036,0x39408f60,0xb06502e2,0x905700a5}},	//   flit, eris_, smää, _הסוף_,
   {{0x6d4670fd,0xe8210e04,0x1dda252b,0x442ec4ef}},	//   buka, यर्थ_, _युवत, haf_,
   {{0x98b929dc,0x6d460a1e,0x26c70248,0xa3df0243}},	// [f030] алат_, cuka, énom_, _धुन_,
   {{0x7ae4c4f0,0xaa7b00ee,0x37ab10b4,0x00000000}},	//   alit, _chýr, лтен_, --,
   {{0x7ae402e9,0x39400955,0x442ec4f1,0x3ea92a77}},	//   blit, aris_, daf_, _klat_,
   {{0x3940c4f2,0xdced0a78,0x657b0097,0xa3be167e}},	//   bris_, _brać, _pruh, ीपन_,
   {{0x24f90104,0x4efc0070,0x61e20416,0x442e0090}},	//   анды_, אלאג, _nyol, faf_,
   {{0x2ecf00c8,0x3206011e,0x83390086,0x291901a2}},	//   রতিষ, _agoy_, ачит_, _itsa_,
   {{0x61e2001c,0x3ea20093,0x3ea90159,0x61fe00a8}},	//   _ayol, ykkt_, _olat_, əzlə,
   {{0xe2991783,0x2903048c,0x6d46c4f3,0x290b044d}},	//   раи_, _hija_, yuka, _kuca_,
   {{0x657b0232,0x442e79f0,0x2bdb0084,0x7c2e00a8}},	//   _uruh, baf_, _मुसा, yabr,
   {{0x6d46c4f4,0x3ea90452,0x442e00e9,0x290bc4f5}},	//   vuka, _alat_, caf_, _muca_,
   {{0x2903c4f6,0x290bc4f7,0x3ea9c4f8,0x61eb004e}},	//   _mija_, _luca_, _blat_, _wzgl,
   {{0x291900ab,0x60c800ab,0x7ce0033b,0x03d60070}},	//   _otsa_, andm, hört, _וועם_,
   {{0x1d0a399d,0x29190221,0x61eb48bf,0x7c2ec4f9}},	//   реги_, _ntsa_, _uzgl, tabr,
   {{0x3f9e1b66,0x6ae20aad,0x8fa514a9,0x3f77002d}},	//   bytu_, पत्र, _мале, _tău_,
   {{0x6d463829,0x7ae4c4fa,0x20070107,0x290b01f7}},	//   suka, tlit, _igni_, _auca_,
   {{0x3940c4fb,0x290b8a8d,0x7c2e9d2d,0x6aad3488}},	//   tris_, _buca_, sabr, ghaf,
   {{0x29030ae0,0x7ae4429a,0x442e0297,0xdd8f026e}},	// [f040] _bija_, rlit, yaf_, _لوي_,
   {{0x7ae4c4fc,0x23c90c03,0x3e7f0086,0x290bc4fd}},	//   slit, िपाद, _tätä_, _duca_,
   {{0x7ae4431a,0x2903c4fe,0x7659016e,0xdced0207}},	//   plit, _dija_, ffwy, _srać,
   {{0x6aadc4ff,0x3940c500,0x2f5a00c2,0x7d77064e}},	//   chaf, pris_, ידענ, _امیر_,
   {{0x20070133,0x2903c501,0x20036639,0x290b01d5}},	//   _ogni_, _fija_, žjih_, _guca_,
   {{0xdced01cc,0x6f040395,0xb4e40b4a,0x6aa40034}},	//   _vrać, _liic, नते_, lkif,
   {{0x644a0298,0x229100d5,0xe7372c4c,0x61e20027}},	//   rgfi, _háky_, _мер_, _syol,
   {{0x442e0297,0x20070118,0x3a370070,0x290b02d7}},	//   saf_, _agni_, ֿרים_, _yuca_,
   {{0x210423e3,0xa3d601c0,0xdddd0035,0x442e0027}},	//   रदेश_, _सडक_, zesł, paf_,
   {{0x61e202e9,0x3ea94222,0x442e035f,0x2ee0045e}},	//   _vyol, _slat_, qaf_, _akif_,
   {{0x7336006c,0xa2e66b30,0x4ada0099,0x4fd3010b}},	//   _ذرائ, _дожд, ढवाव, джэт,
   {{0x442cc502,0x3206010d,0x2007016e,0x7eb600ea}},	//   _hed_, _ugoy_, _egni_, kšpu,
   {{0x442c016f,0xf99f0118,0x6f040395,0x78bc00ee}},	//   _ked_, _agèn_, _diic, _omrv,
   {{0x6f04012f,0x7d1dc503,0x3f9e78ee,0xd25900ea}},	//   _eiic, rpss, pytu_, miņa_,
   {{0x442c0bf3,0x290b029d,0x6f04002d,0x6aadc504}},	//   _med_, _suca_, _fiic, thaf,
   {{0x7ce0186a,0x290b044d,0x3ea92aaf,0x442c06ae}},	//   förs, _puca_, _ulat_, _led_,
   {{0x442c0297,0x81dc0083,0x255e0029,0x6aad23b3}},	// [f050] _oed_, ণের_, nālā_, rhaf,
   {{0x6aadc505,0xab870131,0x26cd025c,0x5e35006c}},	//   shaf, _думк, _sjeo_, _بڑھا,
   {{0x6e2d0ac8,0x6aad008a,0x29035400,0x7d0dc506}},	//   _keab, phaf, _vija_, _huas,
   {{0x7d0d2a37,0x41ca00a1,0xe81b035d,0xcf930070}},	//   _kuas, ापास, _प्रा_, וטע_,
   {{0x2903c507,0xa567126b,0x442c8a61,0x6e2dc508}},	//   _tija_, تدان, _bed_, _meab,
   {{0x6e2d41e3,0x7d0dc509,0xd5ae0037,0x9848037c}},	//   _leab, _muas, طفى_, _мяса_,
   {{0x3949c50a,0x7d0dc50b,0x9505006c,0xd04e00a8}},	//   luas_, _luas, _کہتے_, _ödən,
   {{0x442cc50c,0xe3b001b2,0x6e2d00c7,0x059500fd}},	//   _eed_, خره_, _neab, _ٹارگ,
   {{0x7d0d0082,0x057700bf,0xb5fdc50d,0x6f04c50e}},	//   _nuas, _بازد, _gašp, _riic,
   {{0xdce4006a,0x442c0014,0x7fd500d8,0xa3b60fcf}},	//   _ksią, _ged_, зімі, _चेक_,
   {{0x2bdb0ca1,0x39490221,0xb5fd00d5,0x2aae00d5}},	//   _मुला, huas_, _zašp, _hýbe_,
   {{0x75290010,0x3949046a,0x63040312,0x7d0d5c13}},	//   _kwez, kuas_, _قولل, _buas,
   {{0x6e2dc50f,0x8f5205f5,0x00000000,0x00000000}},	//   _deab, ونیش, --, --,
   {{0x711a0052,0x75293f1f,0x317a0317,0xdce40035}},	//   _הוספ, _mwez, _לאנד, _osią,
   {{0x6e2d0082,0x7529030d,0x7cf201b4,0x60c1027a}},	//   _feab, _lwez, værd, milm,
   {{0x66092b62,0x7d0d7c2a,0x8f9a011d,0x6e2d12ba}},	//   _ngek, _fuas, _ליצי, _geab,
   {{0xf2d200c2,0x39494469,0x7d0dc510,0x26dd0067}},	// [f060] גען_, guas_, _guas, dowo_,
   {{0x6aa4b703,0x4d7b02b5,0x6299b8e4,0x60c104d4}},	//   skif, _פריע, _lowo, nilm,
   {{0xdc9b1899,0x442cc511,0x4c9b00a5,0xc5f600b1}},	//   _הייל, _red_, _השיע, ेश्य_,
   {{0x442cc512,0x6299004e,0x26dda4a8,0x7e760a8a}},	//   _sed_, _nowo, gowo_, _jayp,
   {{0xe5a303f5,0x442cb5f2,0x7e76006f,0x60c1c513}},	//   ници, _ped_, _mayp, kilm,
   {{0x442c048c,0x66094558,0x38a451de,0x00000000}},	//   _qed_, _egek, _mörk_, --,
   {{0x442c1879,0x26dd8eb1,0x60c104d4,0x62990118}},	//   _ved_, bowo_, dilm, _bowo,
   {{0xfa9700c2,0xb9090028,0x62998c9c,0x442cabf5}},	//   ִדיש_, _nghị_, _cowo, _wed_,
   {{0x6299004e,0x442c805e,0x15430279,0x04461783}},	//   _dowo, _ted_, _петм, _неан,
   {{0xf4841144,0x2009045e,0xd25900ea,0x7d0d01e9}},	//   _تاری, _şair_, riņa_, _ruas,
   {{0x7d0d06b3,0x2d80c514,0x085700a5,0x6e2d8d68}},	//   _suas, _arie_, הבים_, _peab,
   {{0x3949006d,0xeeab20cc,0x88c40033,0x60c102e2}},	//   yuas_, сток_, ্তিক, ailm,
   {{0x7d0dc515,0x60c1c516,0x2d80c517,0xf27b00a5}},	//   _quas, bilm, _crie_, _לראש,
   {{0x2d800903,0x649d0176,0x00000000,0x00000000}},	//   _drie_, _hèir, --, --,
   {{0x905b00a5,0xc05300a5,0x00000000,0x00000000}},	//   _הכות, _נזק_, --, --,
   {{0x39491d2b,0x7cf22b6f,0x2d800c71,0x7d0d11d9}},	//   tuas_, være, _frie_, _tuas,
   {{0x2d800260,0x00000000,0x00000000,0x00000000}},	// [f070] _grie_, --, --, --,
   {{0x3949046a,0xb4c800b8,0x75290371,0xa3cc5f2e}},	//   ruas_, ोको_, _rwez, रपा_,
   {{0x8d180ef5,0x3949006f,0x00000000,0x00000000}},	//   _وزیر_, suas_, --, --,
   {{0x7529c518,0x39490600,0x60c1c519,0x7eb60009}},	//   _pwez, puas_, zilm, lšpr,
   {{0xf6501c51,0xb6090029,0x26ddb566,0x60c1027b}},	//   ائم_, višķ, rowo_, yilm,
   {{0x7b08004f,0x629901ae,0xd0060037,0x26dd0067}},	//   _óstá, _sowo, _لل_, sowo_,
   {{0x6299004e,0x60c1c51a,0x00000000,0x00000000}},	//   _powo, vilm, --, --,
   {{0x6609008c,0x75290b13,0x00000000,0x00000000}},	//   _ugek, _twez, --, --,
   {{0x75290657,0x60c1406f,0x7ce0c51b,0x545545ae}},	//   _uwez, tilm, körp, _оват,
   {{0x6299c51c,0x7e76010d,0x7c220009,0xe7f4021a}},	//   _wowo, _sayp, _đoro, _अरमा_,
   {{0x60c13410,0x6e4600ed,0x721900af,0xf41200a5}},	//   rilm, менз, _джер_, _ספא_,
   {{0x2d8001c8,0xed5a38bb,0x00000000,0x00000000}},	//   _prie_, оом_, --, --,
   {{0xf2d80416,0x63a31032,0x60c1c51d,0x8636025a}},	//   _عظمت_, lynn, pilm, וארג_,
   {{0xeb0900b4,0x00000000,0x00000000,0x00000000}},	//   वदूत_, --, --, --,
   {{0x3a320159,0x6fb20037,0x1ae60279,0x3bd50421}},	//   tayp_, _لموا, довм, еютс,
   {{0x2d800284,0x66ec046c,0x00000000,0x00000000}},	//   _trie_, _छींक_, --, --,
   {{0x2d8001e9,0x00000000,0x00000000,0x00000000}},	// [f080] _urie_, --, --, --,
   {{0xfc060421,0xb866083a,0x6f080118,0x63a3c02e}},	//   _оппо, بارو, bèbè, kynn,
   {{0xb3a9027b,0x00000000,0x00000000,0x00000000}},	//   çılı, --, --, --,
   {{0x9f960052,0xddcd1d7d,0x00000000,0x00000000}},	//   ודעה_, _haaš, --, --,
   {{0x95530647,0x23c3074f,0x00000000,0x00000000}},	//   نخوا, _वेबद, --, --,
   {{0xf1e10084,0x6d460034,0x63a3001e,0xcdb700a5}},	//   _पड़न, irka, fynn, ופנה_,
   {{0x31a60edf,0x3878009d,0xbddb00f7,0x63a302ce}},	//   गन्ध, _iarr_, ngèr, gynn,
   {{0xd13a0086,0x3878535e,0x26c2c51e,0x00000000}},	//   охо_, _harr_, _öko_, --,
   {{0x7c3e4962,0x3878028b,0x00000000,0x00000000}},	//   _odpr, _karr_, --, --,
   {{0x63a3001e,0x634a00a8,0x6d46c51f,0x649401f7}},	//   bynn, _mənz, drka, _nàix,
   {{0xc1080028,0x6d40213c,0x38784c46,0x63a300e9}},	//   _mỗi_, áman, _marr_, cynn,
   {{0xc1080028,0x6d462190,0x7c3e007e,0xd12f0647}},	//   _lỗi_, frka, _adpr, _چمن_,
   {{0x6d406158,0x752202d0,0x6aa3002d,0x6ce701e0}},	//   šman, npoz, _înfi, діве,
   {{0xdce4004e,0x443e0065,0xfc640382,0x00000000}},	//   _księ, _jdt_, късн, --,
   {{0x6d46c520,0xc10801a5,0xad9b016f,0x7eb602c4}},	//   arka, _nỗi_, ncúz, ršpr,
   {{0x634a00a8,0x6d4600cd,0x7c3e007b,0x78ae081b}},	//   _bənz, brka, _edpr, _albv,
   {{0x19580aeb,0x3878004f,0x75220b79,0x3f58021d}},	// [f090] маты_, _barr_, jpoz, léu_,
   {{0x1b1e0083,0x2907013c,0x6b750011,0x443ea5de}},	//   _ফিরে_, öna_, _злоу, _ndt_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443e0024,0xdb1e01dd,0xdce4022f,0x387801da}},	//   _adt_, _expó, _psić, _earr_,
   {{0x38785a1b,0x2a795fd5,0x63a300e9,0x7cf203d0}},	//   _farr_, _iasb_, wynn, læra,
   {{0x38780359,0x6ef601ef,0x00000000,0x00000000}},	//   _garr_, mábe, --, --,
   {{0x25a94034,0x6ef61e15,0x998b00fe,0x00000000}},	//   šal_, lábe, _keců_, --,
   {{0x63a300e9,0x6d460044,0x38660009,0x443ec521}},	//   rynn, yrka, đore_, _edt_,
   {{0x212b02e9,0xf076006c,0x443e027a,0x4105117a}},	//   èch_, ڑیوں_, _fdt_, нзив,
   {{0x3f580279,0x7c350124,0x753b007b,0x00000000}},	//   féu_, jazr, _ivuz, --,
   {{0xd251211f,0x442702d7,0x7ea6008d,0x26cf034d}},	//   _منا_, mbn_, _hópi, ongo_,
   {{0x7ea600a0,0x037803fc,0x9f470055,0xa3cc018d}},	//   _kópi, _زحمت_, _hynë_, रपर_,
   {{0x628bc522,0x661b0054,0x0d831129,0x26cf01d7}},	//   _ingo, _mfuk, глян, ingo_,
   {{0x3f581c5b,0x6ef60042,0x753b007b,0x6d46003e}},	//   béu_, dábe, _mvuz, rrka,
   {{0xeb9ac523,0x75220f86,0x38780176,0x661b7884}},	//   чив_, zpoz, _rarr_, _ofuk,
   {{0x8a0604bf,0xc3320d85,0xb50f022e,0x6d460124}},	//   езбе, טול_, ादाय_, prka,
   {{0xd9431a1c,0xe9d719c3,0x4427012f,0x6da600af}},	// [f0a0] лети, ект_, kbn_, _чипа,
   {{0x2bdb1db9,0x661b3736,0x26cf01b7,0x00000000}},	//   _मुका, _afuk, engo_, --,
   {{0xfaa61205,0xe6661073,0x3878c524,0x753b04fb}},	//   _зано, етло, _varr_, _avuz,
   {{0xdce4010b,0x443e00e2,0x6ef64509,0x634a00a8}},	//   _priė, _sdt_, bábe, _tənz,
   {{0x1a9b00c2,0xf992064e,0x7ea603e6,0x6ef60042}},	//   _זיכע, _صبح_, _cópi, cábe,
   {{0x628bc525,0x26cfc526,0x661b030d,0x00000000}},	//   _ango, ango_, _efuk, --,
   {{0xd62a4b92,0x43944555,0x62050095,0x290a067f}},	//   _нове_, тайс, ərlə, _iiba_,
   {{0x290a00b5,0x04ca00b5,0x00000000,0x00000000}},	//   _hiba_, _کوئي_, --, --,
   {{0x443e4c32,0x290ac527,0x7ae31e60,0x25e700b4}},	//   _tdt_, _kiba_, _ínte, _छुपी_,
   {{0x628bc528,0xdfda01d3,0x290a0223,0x7e64c529}},	//   _engo, зъм_, _jiba_, _abip,
   {{0x69093ce5,0xf8b30397,0x290a0283,0x6ef6002a}},	//   _ožen, רשת_, _miba_, zábe,
   {{0x234b0e3a,0x7ae6010d,0x290ac52a,0x93250416}},	//   _رسمی_, _nkkt, _liba_, _شرمن,
   {{0x25a60e7e,0xf2370070,0xbcfb4135,0x6ef6002a}},	//   nyol_, _טראץ_, ntég, xábe,
   {{0x290a0232,0x3f580132,0xdced00d5,0x7e64001c}},	//   _niba_, péu_, _vsaď, _ebip,
   {{0x2bdb04bc,0x9a871bdc,0x1bd444a0,0xfbdb164f}},	//   _मुखा, нуал, горя, _मुखम,
   {{0x290a002d,0x6ef601dd,0xe8bb00b8,0x9f4700ac}},	//   _aiba_, tábe, ोच्च, _uzná_,
   {{0x6909c2d4,0x290a01d0,0x7e7d02b1,0xee3f00d5}},	// [f0b0] _džen, _biba_, mdsp, nkým_,
   {{0x7e7dc52b,0x5b150d30,0x6ef601dd,0x69090009}},	//   ldsp, _имот, rábe, _ežen,
   {{0xe70b1144,0x290ac52c,0x6d5dc52d,0xee3f00ac}},	//   ستان_, _diba_, ltsa, hkým_,
   {{0x26cf7d13,0xee3f00d5,0x6d5d136b,0x00000000}},	//   ungo_, kkým_, otsa, --,
   {{0x6d5dc52e,0x3a290ec0,0x7e7d746f,0x34950f7e}},	//   ntsa, mbap_, idsp, кадр,
   {{0x7aedc52f,0xe7330dc0,0xe5a26c06,0x628b011e}},	//   llat, _مصر_, риши, _sngo,
   {{0xe299946b,0x0ee10302,0x8c1c0052,0x6d5d0006}},	//   дай_, नवाड, לוגי, htsa,
   {{0x7ea600c9,0x7aedc530,0x6d4f0254,0x7e7d01b4}},	//   _tópi, nlat, kuca, jdsp,
   {{0x6d4fc531,0x6d5d019f,0x4427012f,0x7aed0065}},	//   juca, jtsa, pbn_, ilat,
   {{0x39490bb0,0x6d4fc532,0x7aed0dfa,0x7e7d0298}},	//   iras_, duca, hlat, edsp,
   {{0x6ef60332,0x6441c533,0x3255002d,0x7aedc534}},	//   vább, _idli, _авер, klat,
   {{0x38a4315b,0x628b067f,0x3949c535,0x6d5d1b5f}},	//   _hört_, _ungo, kras_, ftsa,
   {{0xee3f0076,0x2d842905,0x6d4fb6bd,0x7aedb1ad}},	//   ckým_, íme_, guca, dlat,
   {{0x10a20217,0x7e7d0345,0x00000000,0x00000000}},	//   _вишн, adsp, --, --,
   {{0x3949c536,0x1d070665,0x6ef6006c,0x6d5d1c9c}},	//   eras_, тери_, rább, atsa,
   {{0x394904a5,0xe7e50324,0x6569023a,0x6d4fc537}},	//   fras_, _कड़ा_, _opeh, buca,
   {{0x64412a9f,0x3949c538,0x81e30033,0x290a0c22}},	// [f0c0] _odli, gras_, ফের_, _piba_,
   {{0xdd310095,0x61eb05ee,0x6441c539,0x61e6018d}},	//   ləşd, _mygl, _ndli, ükli,
   {{0xdced01cc,0x7aedc53a,0x3949c53b,0x3ea000be}},	//   _građ, blat, aras_, _koit_,
   {{0x394912d1,0x7aedc53c,0x76a900d4,0x64412c4d}},	//   bras_, clat, нтів_, _adli,
   {{0x7ae403ad,0x2bbc0e6f,0x3ea00211,0x00000000}},	//   moit, ोपका, _moit_, --,
   {{0x7ae44856,0xf4d00033,0xdce40a53,0x2f1a00ea}},	//   loit, িত্ব, _opič, _līga_,
   {{0x3ea00136,0x38a4027d,0x7ea60093,0x987b0070}},	//   _ooit_, _dört_, _hópu, _קאלט,
   {{0xf77702da,0xee3f016f,0x7ae400c3,0x853403fc}},	//   _בעלי_, tkým_, noit, _مورچ,
   {{0x26c4c53d,0xb6a37902,0xbcfb000d,0x38a4017b}},	//   _immo_, _титл, ltée, _fört_,
   {{0x7ae40086,0x6d5d006d,0x7aed229f,0x320fc53e}},	//   hoit, vtsa, zlat, _eggy_,
   {{0x7ae4c53f,0x7aed00bb,0xf8370122,0xbcfb0248}},	//   koit, ylat, כנית_, ntée,
   {{0x7ae403ad,0x6d4f210b,0x3ea00211,0x6d5dc540}},	//   joit, tuca, _coit_, ttsa,
   {{0x7aed0987,0x3ea002e1,0x7ae411b1,0x00000000}},	//   vlat, _doit_, doit, --,
   {{0x4034087b,0x39490370,0x6d4fc541,0x6d5d0e45}},	//   _секс, vras_, ruca, rtsa,
   {{0x6d5dc542,0x6909042a,0x9f580086,0xc33901c0}},	//   stsa, _džel, ärä_, žívá,
   {{0x3949a372,0x6d4fc543,0x6ab600e9,0x6d5d0f8e}},	//   tras_, puca, ghyf, ptsa,
   {{0x7aed69cd,0x7ea6002a,0x3949c544,0x6f0d009e}},	// [f0d0] rlat, _cópu, uras_, _iiac,
   {{0x6ef6631b,0x8c6700af,0x00000000,0x00000000}},	//   mába, _ртид, --, --,
   {{0xdced0b16,0x7ae43f0f,0x6ef6006c,0xd12602fd}},	//   _urađ, boit, lába, _گم_,
   {{0x60c82a37,0x7ae40391,0x394904ff,0x38a4c545}},	//   hidm, coit, pras_, _börs_,
   {{0xd126234a,0x6ef64509,0x00000000,0x00000000}},	//   _دم_, nába, --, --,
   {{0x6ef601ef,0xe8070067,0x6f0d7272,0x61ebc546}},	//   iába, _वृथा_, _liac, _rygl,
   {{0x2ca102c2,0xbcfb00f7,0xd5bf00ea,0xf79400d8}},	//   _mohd_, ctée, _šādu_, _карэ,
   {{0x6aadc547,0x4ee50033,0x67d40210,0x6ef600b5}},	//   nkaf, নগুল, _тосу, kába,
   {{0x2f1a0080,0x6ef6006c,0x38a4013c,0x00e5029f}},	//   _rīga_, jába, _görs_, лжин,
   {{0x3ea01010,0x7ae4c548,0xa5da0070,0x3eb20345}},	//   _soit_, zoit, _אַבי, _slyt_,
   {{0xb5fd01c8,0x61eb004e,0x1eca075c,0x7ae4002f}},	//   _rašy, _wygl, елни_, yoit,
   {{0x1e961a09,0x7fb3013b,0x6f0dc549,0x00000000}},	//   урор, nəqə, _ciac, --,
   {{0x3ea0b590,0x6f0dc54a,0x7ae468be,0x6ef64509}},	//   _voit_, _diac, voit, gába,
   {{0xe1f002de,0x38b601b4,0x6f0d027a,0x60c802d7}},	//   _بسم_, _kære_, _eiac, cidm,
   {{0x3ea0c54b,0x0baa0312,0x6f0d009d,0x7ae4005b}},	//   _toit_, راسى_, _fiac, toit,
   {{0x6f0d02fb,0x2d9600c3,0x00000000,0x00000000}},	//   _giac, _брос, --, --,
   {{0xceb40250,0xe8fa6afc,0x7ae4c54c,0x38b6177c}},	// [f0e0] _ilə_, ела_, roit, _lære_,
   {{0x48c400c8,0x47bf0083,0xb4dd000c,0x7ae400c3}},	//   ্ত্র, ্থনী, णको_, soit,
   {{0x7ae4c54d,0xc66a02c4,0xbcfb000d,0x2d8f01f7}},	//   poit, ешле_, utée, _àger_,
   {{0xbcfb00f7,0x443800c7,0xb6365cfa,0x00000000}},	//   rtée, _žr_, اعات, --,
   {{0x8e5700c2,0x64a6149e,0x659404d9,0xbcfb000d}},	//   רינג_, лада, ралу, stée,
   {{0xbcfb00f7,0xd37a151d,0x6aa300af,0x38b601cf}},	//   ptée, ечи_, _înfr, _bære_,
   {{0x38b601b4,0x38a4013c,0x07a30336,0x6ef6c54e}},	//   _værd_, _förr_, _ларн, zába,
   {{0x57e70370,0x66e65583,0x60c87406,0x00000000}},	//   _сдсм_, _соба, widm, --,
   {{0xd0100082,0x6f0d0082,0xc05a02a4,0x6ef6002a}},	//   يلة_, _riac, нін_, xába,
   {{0x6f0d0090,0x2ee90298,0xbcfb00fd,0x00000000}},	//   _siac, _skaf_, ztéb, --,
   {{0x6f0dc54f,0x645a01c2,0x3f870254,0x09d101d1}},	//   _piac, _icti, _crnu_, _सख्य,
   {{0x6ef6c550,0x91860c26,0x7d16c551,0xb5fd023a}},	//   tába, _مجتم, _buys, _obšl,
   {{0x69090274,0x6f0d016f,0x60c80359,0x1c190066}},	//   _džej, _viac, pidm, _दलदल_,
   {{0xceb401c2,0x6ef6c552,0x62800c9c,0x91e30200}},	//   _elə_, rába, ldmo, _уоче,
   {{0x6ef6006c,0x2cb300e2,0x6f0d0341,0x00000000}},	//   sába, _vlxd_, _tiac, --,
   {{0x6ef6c54e,0x8aa473d3,0x6f0d009e,0x6280633a}},	//   pába, бруд, _uiac, ndmo,
   {{0x383508ae,0xf84b1bdc,0x6aad60d4,0x3f870124}},	// [f0f0] инар, ечей_, rkaf, _zrnu_,
   {{0x201e0260,0x25e80084,0x00000000,0x00000000}},	//   ncti_, _जड़ी_, --, --,
   {{0x29010176,0x00000000,0x00000000,0x00000000}},	//   rmha_, --, --, --,
   {{0x17f80514,0xf8bf0118,0x7c370345,0x2f1a0228}},	//   اركة_, _awét_, _hexr, _līgo_,
   {{0xa564004f,0xe61803d0,0x1c190825,0x38b60a8a}},	//   مدون, уді_, _दलाल_, _sære_,
   {{0xd4692217,0xdb1e0132,0xf8b104cd,0x62800051}},	//   тике_, _expõ, _بکر_, edmo,
   {{0x37f8002d,0x62800051,0x00000000,0x00000000}},	//   _берэ_, fdmo, --, --,
   {{0x38b61879,0xe8e001a5,0xb1457eee,0x6b88070f}},	//   _være_, _đứa_, анил, ådgi,
   {{0xe0d916fb,0xd6d8195a,0x69cb2450,0x3f870506}},	//   кви_, _стр_, _सेमी, _srnu_,
   {{0x05de0b40,0x1f650086,0x3494052a,0x90c50009}},	//   _फुटब, аком, _лаур, рбое,
   {{0x6d5f0069,0xb4fa0070,0x00000000,0x00000000}},	//   _aqqa, _ספעי, --, --,
   {{0x6e36013b,0xdee618cd,0x2d8901da,0x00000000}},	//   _qeyb, роми, _brae_, --,
   {{0x2d89487b,0x59a500a1,0xa3c900ab,0x00000000}},	//   _crae_, _गॅलर, _लेत_, --,
   {{0x690966f6,0x7cf2054e,0xb7e50354,0x3f870207}},	//   _džek, mærk, कथाम_, _trnu_,
   {{0xea5a0370,0x7e7f0118,0x46b5057c,0x3eb9009e}},	//   крај_, _faqp, ंसाह, bhst_,
   {{0x3eb902c9,0x3a260804,0x34d2022e,0x00000000}},	//   chst_, рмаг, _तद्द, --,
   {{0x213f00d7,0x2d890176,0x3b070be8,0xa96a3345}},	// [f100] nsuh_, _grae_, рето_, ضمام_,
   {{0x270e00be,0xd25900ea,0xa9671566,0x00000000}},	//   िद्र_, miņu_, рифа_, --,
   {{0x7c3cc553,0x657b8994,0x6ef600d5,0x00000000}},	//   marr, _asuh, nábo, --,
   {{0x7c3c06a2,0x9f4701c0,0x95861285,0x95cabed7}},	//   larr, _nyní_, илее, кула_,
   {{0x978400d1,0xdb1e0183,0x7c3c0065,0x00000000}},	//   _گیاه, _expô, oarr, --,
   {{0x7c3cc554,0x39400189,0x00000000,0x00000000}},	//   narr, msis_, --, --,
   {{0xa6961a31,0x394047be,0xf7430f6d,0xe73700c3}},	//   _крај, lsis_, _меро, _вес_,
   {{0x7c3cac42,0x3a20c555,0xa3c70035,0x66e3095d}},	//   harr, ncip_, _उधर_, _доса,
   {{0x7c3c03cb,0x39406560,0xf50a12f8,0x6280c556}},	//   karr, nsis_, _анал_, rdmo,
   {{0x7c3cc557,0xa0a62349,0x3940c558,0x645a00ac}},	//   jarr, ршил, isis_, _ucti,
   {{0x7c3c1d3d,0x80c80033,0x443cc559,0x200a0553}},	//   darr, রকল্, mav_, äbi_,
   {{0x394047a8,0xa18645d7,0x6efd00b5,0x2d890553}},	//   ksis_, _выкл, kébe, _prae_,
   {{0x6562c55a,0x7c3c0291,0x6efd00b5,0x00000000}},	//   ntoh, farr, jébe, --,
   {{0x7c3c03cb,0x443cc55b,0x2d890173,0x6ce70210}},	//   garr, nav_, _vrae_, ріме,
   {{0xa3cc00a1,0x00000000,0x00000000,0x00000000}},	//   रपट_, --, --, --,
   {{0x443c0189,0x25600c1f,0x2d89c55c,0x656201f4}},	//   hav_, kòl_, _trae_, ktoh,
   {{0x7bdebb13,0x443c01cc,0xae031e79,0x656200da}},	// [f110] _expu, kav_, रेशन_, jtoh,
   {{0x7c3c610a,0x443c0bc9,0x37ab2503,0x256002d0}},	//   carr, jav_, ктен_, dòl_,
   {{0x443cc55d,0xc60f06fe,0x3940c55e,0xb8cf0581}},	//   dav_, िश्य_, asis_, _ओक_,
   {{0x39400189,0x65620031,0x224600e0,0x6d4f026e}},	//   bsis_, ftoh, _ndok_, orca,
   {{0x98b30095,0x443c10c3,0x394023c8,0x3a390116}},	//   şdır_, fav_, csis_, _iesp_,
   {{0x7cf201b4,0x443cb5e9,0xf79500af,0x224600b5}},	//   værk, gav_, _лагэ, _adok_,
   {{0x67d49008,0xd25900ea,0x2919a20b,0x00000000}},	//   _дору, ziņu_, _husa_, --,
   {{0x7c3cc55f,0x6b832b83,0x29192aaf,0x6d4f0254}},	//   zarr, _ángu, _kusa_, krca,
   {{0x443c039a,0x2911037b,0x7c3c01b7,0xf8bf0118}},	//   bav_, _kiza_, yarr, _uwés_,
   {{0x291916c8,0x1ac40b35,0x7c3c9b2b,0x92c90033}},	//   _musa_, _षष्ठ, xarr, োতে_,
   {{0x14d602b8,0x29190132,0x3a390132,0x2911c560}},	//   _פועל_, _lusa_, _oesp_, _miza_,
   {{0x39407a42,0x6ef60473,0x6e3d02b3,0xd25900ea}},	//   ysis_, rábo, gasb, tiņu_,
   {{0x7c3c1d15,0xa0692725,0xe7f4065f,0x29195112}},	//   tarr, _бала_, _अर्थ_, _nusa_,
   {{0x6efdc561,0x29110254,0x00000000,0x00000000}},	//   vébe, _niza_, --, --,
   {{0x6d4fc562,0x2919043d,0x6e3d51c0,0x7cf2082b}},	//   arca, _ausa_, basb, næri,
   {{0x7c3cc563,0x29197b6e,0x25600c1f,0x29110107}},	//   sarr, _busa_, yòl_, _aiza_,
   {{0x7c3cc564,0xbcfb0037,0x443c006f,0xfaa3c565}},	// [f120] parr, stéa, yav_, чато,
   {{0xeb9a0500,0x3940c566,0x2919c567,0x7c3c035f}},	//   _био_, rsis_, _dusa_, qarr,
   {{0x3940c568,0x25600c1f,0xbb86004f,0xe7eb0084}},	//   ssis_, wòl_, _الجي, _जुदा_,
   {{0xe7372a8a,0x443c5625,0xef120070,0x2919c569}},	//   сец_, wav_, פּע_, _fusa_,
   {{0x443c96ef,0x29190232,0x6bd70919,0x00000000}},	//   tav_, _gusa_, _نویس_, --,
   {{0x2911c56a,0x656201f4,0x38b60093,0x7cf2008d}},	//   _giza_, rtoh, _færa_, færi,
   {{0x961d0080,0x6562c56b,0xf2c62725,0x03a30200}},	//   _saņe, stoh, йсин, зијо,
   {{0x656201f4,0x6d4402ee,0x29110371,0x961d00ea}},	//   ptoh, _ovia, _ziza_, _paņe,
   {{0xe0cf0220,0x5a9b0070,0x443cb78a,0xd9fa09b4}},	//   کزي_, רשפא, pav_, ्धित_,
   {{0xa3c900ab,0xf99300a5,0x6aa6038e,0x00000000}},	//   _लेव_, פרת_, _lokf, --,
   {{0x6448c56c,0xd010004f,0xb89b0070,0x6d44409c}},	//   _iddi, بلد_, אביש, _avia,
   {{0x6d4f0124,0xa3d5046c,0xb7db076b,0x00000000}},	//   trca, सपर_, רקטי, --,
   {{0x3a39c56d,0x6e3dc56e,0xfe030354,0xc0e6c56f}},	//   _resp_, rasb, रेंस_, _лодк,
   {{0xf8bfaeb3,0x3f9800ab,0x9f3401e0,0x6d440409}},	//   _atén_, ärus_, _декі, _dvia,
   {{0x29191ab5,0x6aa60e6c,0xdddd00b5,0x291110ff}},	//   _susa_, _bokf, reső, _riza_,
   {{0x2919c570,0x6282003d,0x6d4f0124,0x64480065}},	//   _pusa_, _jaoo, prca, _lddi,
   {{0x6448c571,0x29111f8a,0x1959037c,0x9999002d}},	// [f130] _oddi, _piza_, разы_, шкат_,
   {{0x3a390051,0x00000000,0x00000000,0x00000000}},	//   _wesp_, --, --, --,
   {{0x2911c572,0xb0650086,0x29190118,0x6282030d}},	//   _viza_, llää, _wusa_, _oaoo,
   {{0x35f510d4,0x6448c573,0x291926c9,0xdced010b}},	//   опер, _addi, _tusa_, _praė,
   {{0x64a541d5,0x29110c22,0x2919672e,0x454b0e9f}},	//   жала, _tiza_, _uusa_, учем_,
   {{0x7659001e,0x81cc0083,0xfbd004e8,0x29050211}},	//   sgwy, _শুভ_, _آتی_, _òla_,
   {{0x68fa0122,0x5c5c0070,0x47bf0033,0x00000000}},	//   _כלשה, אדוק, ্থহী, --,
   {{0x6448c574,0x6e3b0093,0x6282023a,0x00000000}},	//   _eddi, ðubl, _caoo, --,
   {{0x7649c575,0x26cf28e4,0x690900f4,0xb5fd0c8c}},	//   _idey, migo_, _džev, _obši,
   {{0x26cf65a6,0x7e6d01d0,0x6e240036,0xd12e00ff}},	//   ligo_, _abap, _sfib, کمی_,
   {{0x6d4401ba,0xb4e510aa,0x78a70116,0x00000000}},	//   _svia, नवी_, _mojv, --,
   {{0x2a69006d,0x26cf7c7b,0xdce400ea,0x44250282}},	//   jfab_, nigo_, _oriģ, _hfl_,
   {{0x21a50ca6,0xbcfb9718,0xe29f008a,0x00000000}},	//   _филм, rtén, öðu_, --,
   {{0x26cfc576,0x6c366f76,0x78a701f2,0x7e6d018d}},	//   higo_, تفسا, _nojv, _ebap,
   {{0xbea62e14,0x442545c4,0x26cf0027,0x7649438e}},	//   _макк, _mfl_, kigo_, _odey,
   {{0x6d40c577,0x752979f0,0x26cf008b,0x76493a35}},	//   ámas, _otez, jigo_, _ndey,
   {{0x26cfc578,0xd6cf0033,0x75290848,0xaa7b0168}},	// [f140] digo_, িকায, _ntez, _akýs,
   {{0xbcfb0348,0x0903022b,0xb4b8021a,0x00000000}},	//   ntél, дпун, _चते_, --,
   {{0xe61a0674,0xf7722e36,0xfaa646e1,0x2a6901e8}},	//   аде_, باء_, _дано, bfab_,
   {{0x26cf0371,0x00000000,0x00000000,0x00000000}},	//   gigo_, --, --, --,
   {{0x85763345,0x2cba0223,0x44256136,0x55066299}},	//   تدائ, _klpd_, _bfl_, очка,
   {{0x2d800359,0x7af60086,0xddcf002d,0x7ae9008b}},	//   _msie_, llyt, lecţ, čete,
   {{0xb4ca004e,0x26cf0927,0x752925e8,0x00000000}},	//   _लगी_, bigo_, _etez, --,
   {{0xc298c579,0x442501a2,0x2bed0066,0x6b830279}},	//   ских_, _efl_, _आँसू_, _ânge,
   {{0x44254160,0x0446034b,0x00000000,0x00000000}},	//   _ffl_, _меан, --, --,
   {{0x6448012f,0x92ca0033,0x7af600e9,0x6ef60098}},	//   _uddi, লকে_, hlyt, lábh,
   {{0xb4d60429,0x2d80c57a,0x2aae00ee,0xf4870647}},	//   ाची_, _asie_, _hýbu_, _باقی,
   {{0x216a2b9e,0xe2970c7e,0x00000000,0x00000000}},	//   _види_, _мах_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cf462e,0xf1a900ce,0x6ef60098,0xc6160831}},	//   zigo_, _دامه_, hábh, ারটা_,
   {{0x0b88b8b4,0x7af61b4b,0x8aa71b79,0xb0650421}},	//   ости_, flyt, орад, slää,
   {{0x2b4d13a6,0x3f8e01ef,0x6d480035,0x7e6d0027}},	//   čec_, _irfu_, ądar, _ubap,
   {{0x26cf137d,0x6d400bc5,0x6efd01ef,0xb95502fb}},	// [f150] vigo_, šmar, céba, яващ,
   {{0xa2ca0b35,0x3f8e0009,0x3ea95d73,0x60dac57b}},	//   तोत्, _krfu_, _hoat_, nntm,
   {{0x26cfc57c,0x78a7c57d,0x7529c57e,0xa3c907ba}},	//   tigo_, _vojv, _stez, _लें_,
   {{0x4b7a00c2,0x98a90009,0x9f4b00b5,0x758300fd}},	//   _פארו, mpač_, ülék_, ویزم,
   {{0xceb402b5,0x26cf80f4,0xd83b010b,0x00000000}},	//   ויף_, rigo_, _вэб_, --,
   {{0xdced00ac,0x7d7c0319,0x26cf0186,0x3b0900a8}},	//   _opač, ינדו, sigo_, lmaq_,
   {{0x5c380122,0x690902c4,0x163500d8,0x61e201a3}},	//   חרון_, _džet, _невя, _axol,
   {{0xe2990009,0xd36e01b2,0xc2451b0a,0x3b0900a8}},	//   саи_, اهي_, чник, nmaq_,
   {{0xddc4068b,0x00c91f39,0xdced010b,0x3f8e0069}},	//   _obiš, йлик_, _apač, _arfu_,
   {{0x64572587,0x4425008c,0x7aed00cc,0xdce4003c}},	//   óxid, _ufl_, hoat, _oriġ,
   {{0x7aed01ed,0xf1a800d1,0x3ea9c57f,0x212d1a2e}},	//   koat, مایه_, _boat_, speh_,
   {{0x3952099e,0x24853e48,0x3ea9024b,0x33580043}},	//   yrys_, _halm_, _coat_, _фацэ_,
   {{0x2485c580,0x290343c1,0x26cd034d,0x00000000}},	//   _kalm_, _ohja_, _mmeo_, --,
   {{0x67290009,0xc21200a5,0x98a000f4,0x00000000}},	//   _čejn, _נהג_, mpić_, --,
   {{0x26cd0009,0xfce310be,0xddcf002d,0x24850282}},	//   _omeo_, хоро, tecţ, _malm_,
   {{0xee3a0183,0xaa7b008a,0x395200e9,0xfaa312a2}},	//   _уни_, _skýr, trys_, насо,
   {{0x3e5b0122,0xddcf002d,0x00000000,0x00000000}},	// [f160] _הדפס, recţ, --, --,
   {{0xb4ca27bd,0xd6f60380,0x6d460e45,0xd9100416}},	//   _लगे_, ेष्ठ_, mska, ئیس_,
   {{0x6d4657d8,0x7c3e0080,0x7aed0a07,0x7af60409}},	//   lska, _iepr, boat, plyt,
   {{0x2ee0012f,0xa3e60a40,0x3952840b,0xd7ef0037}},	//   _jjif_, _युग_, prys_, دكم_,
   {{0x6d467624,0x24850602,0x7c3ec581,0x6f040874}},	//   nska, _balm_, _kepr, _mhic,
   {{0xb4d60429,0xf7460cac,0x6d46c582,0x7c3e0088}},	//   ाचे_, _него, iska, _jepr,
   {{0x2485046a,0x2ca5c583,0x69c4035f,0x7c3e0359}},	//   _dalm_, öldi_, lzie, _mepr,
   {{0x6aa4c584,0x7c3ec585,0x6d46c586,0x6266004f}},	//   njif, _lepr, kska, سابق,
   {{0x69c4c587,0x6d46942d,0xd04100a8,0xdced003d}},	//   nzie, jska, lilə, _spač,
   {{0x7c3ec588,0x6d46c589,0x6909003a,0x3ea91ef0}},	//   _nepr, dska, _užet, _soat_,
   {{0xd04101c2,0x443e0029,0x6f040284,0x6d46c58a}},	//   nilə, _iet_, _bhic, eska,
   {{0x443e34b9,0x6f04c58b,0x3b0900a8,0x248502a2}},	//   _het_, _chic, xmaq_, _zalm_,
   {{0xbcfb0076,0x443ec58c,0x6f046dad,0x7aed0009}},	//   stém, _ket_, _dhic, voat,
   {{0x69c4c58d,0x212b0037,0xd0410095,0x7c3e0116}},	//   dzie, íche_, kilə, _cepr,
   {{0x443e34b9,0x6d469fa7,0x7aed434b,0x3b090095}},	//   _met_, aska, toat, tmaq_,
   {{0x443ec58e,0xd0410095,0xcff70319,0x6f0400af}},	//   _let_, dilə, _מצוה_, _ghic,
   {{0xdd9101ca,0x3b090095,0x20c000f1,0x7c3e0069}},	// [f170] _شود_, rmaq_, _còig_, _fepr,
   {{0x443ec58f,0x7c3e1892,0x26cd042a,0xddc400f4}},	//   _net_, _gepr, _smeo_, _ubiš,
   {{0x7aed0395,0x69c40395,0xdd0200cd,0x3b09013b}},	//   poat, azie, _žućk, pmaq_,
   {{0x2485c590,0xae010035,0x443e0553,0x6ab602d7}},	//   _salm_, _ईरान_, _aet_, ckyf,
   {{0x443ec591,0xe9450416,0x6909c592,0x2485b815}},	//   _bet_, _ترجی, _džer, _palm_,
   {{0x443e284d,0x6909010b,0xfb1a00b5,0xd041013b}},	//   _cet_, _ežer, _دریں_, bilə,
   {{0x443e2172,0xd0410095,0x6d4600ea,0x68f800b5}},	//   _det_, cilə, zska, őadá,
   {{0x6d46c593,0x443ec594,0x26cd0c99,0x41b501e0}},	//   yska, _eet_, _umeo_, дсот,
   {{0x443ec595,0x661b0371,0x24854655,0x00000000}},	//   _fet_, _iguk, _talm_, --,
   {{0x443ec596,0x6d4601bc,0x2ef20298,0x999906fe}},	//   _get_, vska, _skyf_, _lesů_,
   {{0xdee6051b,0x6443c597,0x98a000cd,0x6f043909}},	//   дони, mani, spić_, _phic,
   {{0x7c3ec598,0x443e0120,0x6d463dd1,0xc2573cf2}},	//   _sepr, _zet_, tska, _رخصت,
   {{0x443e0122,0xd0410095,0x6d4662ed,0x629903c4}},	//   _yet_, zilə, uska, _inwo,
   {{0x6f0401f3,0x64432f68,0xfd5f01a5,0x6289c599}},	//   _whic, nani, _huyệ, ldeo,
   {{0x7c3e01d2,0x6d46c59a,0x64430036,0x6f04c59b}},	//   _vepr, sska, iani, _thic,
   {{0x6443c59c,0x69c4c59d,0x6289c59e,0x6d4648bd}},	//   hani, tzie, ndeo, pska,
   {{0x6443c59f,0x20e10c67,0xf2d2134d,0xda65004f}},	// [f180] kani, _पदाध, דען_, عافي,
   {{0x64431c12,0x69c4c5a0,0x7ae90a78,0xfd5f01a5}},	//   jani, rzie, četa, _luyệ,
   {{0x6443c5a1,0x443ec5a2,0x69c41bb3,0x398d00ee}},	//   dani, _ret_, szie, _eľs_,
   {{0xd0410669,0x443ec5a3,0xd6d90210,0x2d9200da}},	//   rilə, _set_, пті_, _krye_,
   {{0x6443c5a4,0x1c220066,0x443e00a5,0x628900e9}},	//   fani, _मलाल_, _pet_, ddeo,
   {{0x6299c5a5,0x65930210,0x84380037,0x649a052a}},	//   _anwo, ташу, أكثر_, ютер_,
   {{0x443ec5a6,0xd90d04e8,0xd7f2004f,0xd62a00d8}},	//   _vet_, _ایل_, _شكر_, _мове_,
   {{0x225f022e,0x2a60c5a7,0xa2e303e6,0x443e024b}},	//   gguk_, ngib_, којд, _wet_,
   {{0x29187c03,0x443e02e9,0x64570391,0xfd5f01a5}},	//   _kira_, _tet_, óxic, _duyệ,
   {{0x29184d89,0xbcfb006c,0x6299001e,0x92be0033}},	//   _jira_, rték, _enwo, ঁচে_,
   {{0x2918c5a8,0x085702b8,0x2d920371,0xf26a002d}},	//   _mira_, ובים_, _arye_, _мижл_,
   {{0x2918c5a9,0x22930037,0x7520002f,0x00000000}},	//   _lira_, _للمس, _kumz, --,
   {{0x764000d7,0x672902c4,0x291801ef,0x2f1a0228}},	//   _memy, _čejm, _oira_, _rīgu_,
   {{0xbca50037,0x3cff0067,0x00000000,0x00000000}},	//   رمزي, _शीशे_, --, --,
   {{0xbcfb0079,0xac182b4a,0x2d92030d,0x00000000}},	//   ntéi, дору_, _erye_, --,
   {{0x6443c5aa,0xe1880028,0x5f0409ea,0x7640aae6}},	//   zani, _kỳ_, _изја, _nemy,
   {{0x2bcf0907,0x98b9737f,0x2d850228,0x00000000}},	// [f190] _हेरा, плат_, āles_, --,
   {{0x6d5d2967,0x6443c5ab,0xe18800e2,0x27f803d0}},	//   musa, xani, _mỳ_, _byrn_,
   {{0x291803cb,0x644366fb,0x6909044d,0x7640c5ac}},	//   _dira_, vani, _džep, _bemy,
   {{0x64431ea2,0xcf9302b5,0x6b850409,0x7e7dc5ad}},	//   wani, כטע_, _ishg, nesp,
   {{0x6443c5ae,0x6d5dc5af,0x29184de2,0xa5640d47}},	//   tani, nusa, _fira_, ندون,
   {{0x2918c5b0,0xd0060332,0xc48400d8,0xf592006c}},	//   _gira_, _مل_, клік, الوج,
   {{0xa3c91ea2,0x6443c5b1,0x39491dc5,0x6d5dc5b2}},	//   _लेख_, rani, lsas_, husa,
   {{0x6d5dc5b3,0x715915de,0xbcfb0097,0x7e7dc5b4}},	//   kusa, прос_, stéh, jesp,
   {{0x7e7dc5b5,0x55553c96,0x6d5d28fd,0x7520002f}},	//   desp, _سپار, jusa, _gumz,
   {{0x29180391,0x3949c5b6,0x6d5dc5b7,0x7e64c5b8}},	//   _xira_, isas_, dusa, _scip,
   {{0xfd5f01a5,0x3cf30066,0x644100ea,0x9f4700ee}},	//   _tuyệ, ंकने_, _ieli, _hynú_,
   {{0x6441391b,0x7e7dad45,0x394933a9,0xee371958}},	//   _heli, gesp, ksas_, нню_,
   {{0x6441c5b9,0x6d5dc5ba,0x6b85012f,0xd0a80416}},	//   _keli, gusa, _ashg, سطین_,
   {{0x6441c5bb,0x2d92053e,0x71d6016b,0x00000000}},	//   _jeli, _vrye_, _אונד_, --,
   {{0x64413635,0x7ae918b0,0x3949c5bc,0xeabf009e}},	//   _meli, četn, esas_, _blù_,
   {{0x2918c5bd,0xfd4a01d3,0xeabf009e,0x3eb902b1}},	//   _sira_, _език_, _clù_, ckst_,
   {{0x29184374,0x09061353,0xeabf01da,0x2a6000be}},	// [f1a0] _pira_, епан, _dlù_, rgib_,
   {{0x6441c5be,0xe8f7c5bf,0x25690079,0x29180031}},	//   _neli, елу_, dúl_, _qira_,
   {{0x2918c5c0,0xf0b60070,0xeabf0211,0x39490341}},	//   _vira_, עלער_, _flù_, asas_,
   {{0x29180ad6,0x7520002f,0x7f3a016b,0x00000000}},	//   _wira_, _pumz, פענו, --,
   {{0x644180ec,0x25080647,0xf99f0107,0x00000000}},	//   _beli, ورتی_, _ogèy_, --,
   {{0x6441c5c1,0x64a30f27,0x7e7dc5c2,0x7ebf01f4}},	//   _celi, лача, zesp, _mëpa,
   {{0xc5f10083,0x6d5dc5c3,0xd4670274,0x54670200}},	//   জেলা_, zusa, хије_, хајм_,
   {{0xc6150083,0x6441007c,0xbcfb654f,0x6d5dc5c4}},	//   াড়া_, _eeli, rtéi, yusa,
   {{0xbcfb516c,0x7e7dc5c5,0x00000000,0x00000000}},	//   stéi, vesp, --, --,
   {{0x64410dcf,0xfbb20355,0x6d5d00ab,0x53a6010b}},	//   _geli, ीनाम, vusa, _пазб,
   {{0x7e7d157b,0xde5901e0,0x00000000,0x00000000}},	//   tesp, мані_, --, --,
   {{0x6d5dc5c6,0x64412676,0x828900d4,0x39490282}},	//   tusa, _zeli, _осіб_, ysas_,
   {{0x7e7dc5c7,0x6441c5c8,0x3b192c42,0x00000000}},	//   resp, _yeli, _risq_, --,
   {{0x38b60093,0x00000000,0x00000000,0x00000000}},	//   _færi_, --, --, --,
   {{0x6d5dc5c9,0xa2a420af,0xd0f700a5,0x00000000}},	//   susa, काप्, _רמות_, --,
   {{0x6d5d9131,0x3949c5ca,0x7ae900f4,0x539b00a5}},	//   pusa, tsas_, četo, הילו,
   {{0x38c9006c,0x3949c5cb,0x00000000,0x00000000}},	// [f1b0] وائی_, usas_, --, --,
   {{0x3949c5cc,0x81e20083,0x3b19003c,0x442c02a7}},	//   rsas_, _ধরা_, _wisq_, _nfd_,
   {{0x3949c5cd,0xd87402e7,0x7986c5ce,0xdced00cd}},	//   ssas_, طالب, _eskw, _usađ,
   {{0x461500d1,0x442c0a8a,0xc5d500d4,0x3949c5cf}},	//   نوار, _afd_, кіль, psas_,
   {{0x6441c5d0,0x09db0083,0xa2a409b4,0xe5692d7a}},	//   _peli, _দরকা, कान्, филд_,
   {{0x644101f4,0xbcfb00a2,0xf8bf00f6,0x6d4d034d}},	//   _qeli, buée, _buée_, _mvaa,
   {{0x61fc0095,0x00000000,0x00000000,0x00000000}},	//   ərli, --, --, --,
   {{0x1db3046c,0x932400b5,0x3cf30099,0x6d4db639}},	//   ुनात, درون, ंकडे_, _ovaa,
   {{0xc69202b5,0xa15603fa,0x0574186e,0x6d4d073a}},	//   _דאן_, вању_, _مالد, _nvaa,
   {{0x40953bd5,0x6441034d,0x84020207,0xe0d60421}},	//   трит, _ueli, žđan, квы_,
   {{0x6d4d446f,0x600900c3,0x00000000,0x00000000}},	//   _avaa, ьном_, --, --,
   {{0x38b600fb,0x62358c68,0xba3b2a5a,0x442c0027}},	//   _væri_, _реду, _moïs, _zfd_,
   {{0x008502ee,0x0d99021f,0x0d83b7fb,0xa069005f}},	//   _алло, нтры_, алян, _жала_,
   {{0x628b4204,0x6e2d01ed,0x6d4d007e,0xa1560277}},	//   _hago, _efab, _dvaa, _יבנה_,
   {{0x8c43215e,0x628b8d2d,0x316d0248,0xcb675e16}},	//   ресе, _kago, ltez_, каре_,
   {{0x7db60970,0x00000000,0x00000000,0x00000000}},	//   _асоц, --, --, --,
   {{0x628bc5d1,0x316dc5d2,0x6aafc5d3,0xd946215b}},	// [f1c0] _mago, ntez_, _docf, тези,
   {{0x628bc5d4,0xed59053d,0x6efd006c,0xbcfb000d}},	//   _lago, áže_, yébk, tuée,
   {{0x442c0345,0x6fc100b4,0x316d0065,0xa2a401d1}},	//   _rfd_, शनिं, htez_, काम्,
   {{0xb6cb00b5,0x3f870124,0x442c1140,0x645701ef}},	//   وانے_, _msnu_, _sfd_, óxin,
   {{0x64a6adf6,0xd90d00b5,0x9980010b,0x05d200b8}},	//   када, زیہ_, rbių_, _देशब,
   {{0x628b0159,0x00000000,0x00000000,0x00000000}},	//   _aago, --, --, --,
   {{0x628bc5d5,0xbcfb00f7,0x07a31f71,0xc7a3167d}},	//   _bago, quée, _карн, _кирк,
   {{0xbcfb0332,0xe7eb0084,0x628b00f6,0x00000000}},	//   ltét, _जुटा_, _cago, --,
   {{0x628b0291,0xc05a0823,0xf1a300d8,0x00000000}},	//   _dago, мін_, арэн, --,
   {{0xbcfbc5d6,0xf5070012,0x628b0103,0xf8bf00a2}},	//   ntét, _анул_, _eago, _tuée_,
   {{0xa0a300c7,0x96b60026,0x00000000,0x00000000}},	//   ршыл, _अकाउ, --, --,
   {{0x628bc5d7,0xe80a0354,0xe3160079,0x26c617b6}},	//   _gago, _वरना_, _شباب, nhoo_,
   {{0x316d02e1,0x6280c5d8,0xd1300416,0x115402fb}},	//   ctez_, memo, _امت_, _склю,
   {{0x628b2518,0x6280c5d9,0x9d180036,0x38b6008d}},	//   _zago, lemo, коят_, _kæru_,
   {{0x628b018c,0xce95027a,0x00000000,0x00000000}},	//   _yago, _байъ, --, --,
   {{0x6280c5da,0x00000000,0x00000000,0x00000000}},	//   nemo, --, --, --,
   {{0xbcfb02d7,0x6d4d023c,0x5a44010b,0x00000000}},	// [f1d0] ruéb, _uvaa, рэса, --,
   {{0x62801bb9,0x2d89007b,0x6efd021d,0x00000000}},	//   hemo, _isae_, débi, --,
   {{0x6280c5db,0x00000000,0x00000000,0x00000000}},	//   kemo, --, --, --,
   {{0x798404fb,0x7ebf0031,0x249e008e,0xaaad00be}},	//   bwiw, _mëpo, _antm_, _टकटक,
   {{0x62801fca,0x628b00e9,0x00000000,0x00000000}},	//   demo, _rago, --, --,
   {{0x628b4849,0x249e021d,0xe7332489,0x00000000}},	//   _sago, _cntm_, _نصر_, --,
   {{0x628bc5dc,0x58d405c7,0xbcfb006c,0xe7840746}},	//   _pago, _торт, ltés, _куто,
   {{0x62805fdf,0x316d00f7,0x82a40200,0x00000000}},	//   gemo, ttez_, ишње, --,
   {{0xbcfb0332,0x316d0248,0xdb15006c,0x00000000}},	//   ntés, utez_, gyzé, --,
   {{0x316dc5dd,0x628bc5de,0x3e7e00e2,0x00000000}},	//   rtez_, _wago, _ắt_, --,
   {{0x628bc5df,0x62802140,0xd0480095,0x316dc5e0}},	//   _tago, bemo, nidə, stez_,
   {{0xed5a4cc1,0x6280532a,0xa2a416f5,0x61e420dc}},	//   ном_, cemo, काण्, _žile,
   {{0xd04800a8,0x00000000,0x00000000,0x00000000}},	//   hidə, --, --, --,
   {{0x657b007b,0xa0690382,0xbfb55a37,0x00000000}},	//   _mpuh, _чака_, _محبت, --,
   {{0x4a9a00d8,0x3f870506,0x5ea60037,0x961d013a}},	//   нтаў_, _usnu_, _ممثل, _daņi,
   {{0x290a00da,0xc3320122,0x9e661a49,0x26c6006d}},	//   _shba_, מול_, _свид, xhoo_,
   {{0xaff400b5,0x1a06c5e1,0xa2a4012f,0x2ab5008c}},	// [f1e0] _مہیا_, упам, कात्, _råbt_,
   {{0x4c86c5e2,0x6280c5e3,0x33250036,0x291c01ff}},	//   _слов, zemo, _oulx_, öva_,
   {{0x3ea03a20,0x657b0159,0xf8bf0176,0x628002d7}},	//   _knit_, _apuh, _atés_, yemo,
   {{0xfaa67ba4,0x6280c5e4,0x864601fd,0xbcfbc5e5}},	//   _само, xemo, ундж, stét,
   {{0x6280b744,0x7d1eba6c,0xbcfb01ef,0x00000000}},	//   vemo, _kips, quéc, --,
   {{0x7ae4c5e6,0xbcfb00b5,0x533400d8,0x7af60159}},	//   lnit, ltér, аект, loyt,
   {{0x6280c5e7,0x27f7024e,0xbcfb008a,0x66e60d46}},	//   temo, čené_, bréf, _бова,
   {{0x7ae4087a,0x7d1e0043,0x38b6008a,0xbcfbc5e8}},	//   nnit, _lips, _væru_, ntér,
   {{0x628007d6,0x38b60093,0x7ae4c5e9,0x26c4081b}},	//   remo, _fært_, init, _ilmo_,
   {{0x7ae4c5ea,0x64a302ee,0x3ea0c5eb,0x20c000f1}},	//   hnit, _лауа, _anit_, _eòin_,
   {{0x7ae404d1,0x2018073c,0x62805cde,0x20c0009e}},	//   knit, äri_, pemo, _fòin_,
   {{0x7ae90496,0x7ae493ff,0x39420345,0x00000000}},	//   četk, jnit, _owks_, --,
   {{0x7ae4c5ec,0x3ea00183,0x3b00013b,0x00000000}},	//   dnit, _dnit_, dliq_, --,
   {{0x5f94279d,0x22460065,0xe3b100b5,0x7ae4073f}},	//   _викт, _heok_, _ارے_, enit,
   {{0x60da0ce8,0x26c4c5ed,0xdb5817e0,0x7ae41808}},	//   mitm, _olmo_, лют_, fnit,
   {{0xfebb01ca,0x5a35010c,0x644a00a8,0x60da0118}},	//   _ساعت_, рнат, hafi, litm,
   {{0x200b004e,0x195810b0,0x644ac5ee,0x7d1e0036}},	// [f1f0] ęcie_, латы_, kafi, _fips,
   {{0x7ae4c5ef,0x38780211,0xbcfb00b5,0x644a174a}},	//   anit, _cbrr_, rtés, jafi,
   {{0x64570aca,0x644ac5f0,0x6d4fc5f1,0x6f0d0023}},	//   óxim, dafi, lsca, _khac,
   {{0xbcfb2f1f,0x6d5dc5f2,0x38b63d3e,0x7ae40160}},	//   ctér, orsa, _sært_, cnit,
   {{0xe5a50cd0,0x6d4f004f,0xd46906a6,0x35a502c4}},	//   рили, nsca, виле_, ралг,
   {{0x224928c2,0x644ac5f3,0x00000000,0x00000000}},	//   _žak_, gafi, --, --,
   {{0x60da093a,0x22460345,0x38b600d4,0x6d5d02b1}},	//   ditm, _beok_, _vært_, hrsa,
   {{0x2901048c,0xe2990183,0x6f0dc5f4,0x6d5d0506}},	//   llha_, таи_, _nhac, krsa,
   {{0x91e5701f,0x645e3207,0x764bc5f5,0x65945c37}},	//   ропе, ópic, magy, _лату,
   {{0x764b0dc3,0x7ae40650,0x6f0d0371,0x660901ed}},	//   lagy, znit, _ahac, _izek,
   {{0x46b900a1,0x6f0d1a07,0x7d1e0303,0x6aad003e}},	//   _आवाह, _bhac, _rips, kjaf,
   {{0x6f0dc5f6,0x764bc5f7,0xef170043,0x672701a8}},	//   _chac, nagy, имэ_, _mujj,
   {{0x6f0d0014,0x7ae4c5f8,0x6d4f310c,0x6909a7d6}},	//   _dhac, vnit, gsca, _džez,
   {{0x1d0a0112,0x764bc5f9,0xdced0069,0x00000000}},	//   теги_, hagy, _praġ, --,
   {{0x6d5d0094,0xbcfbc5fa,0x6f0d09bb,0x6d4f17d6}},	//   arsa, ttér, _fhac, asca,
   {{0x6609012f,0x3ea000a5,0x6d4f51c7,0x644a00fd}},	//   _ozek, _unit_, bsca, zafi,
   {{0x7d1e76ca,0xbcfb4e1c,0x2d8c0029,0x20c90037}},	// [f200] _tips, rtér, ādes_, _cúig_,
   {{0xbcfbc5fb,0x7ae437c7,0xe8c70d8a,0x6727018e}},	//   stér, snit, агул_, _bujj,
   {{0x5c5b0122,0x644a0095,0xbcfbb779,0x7ae415ce}},	//   _בדיק, vafi, ptér, pnit,
   {{0x6d440035,0x644a24ed,0x65620a2d,0x6e240024}},	//   _kwia, wafi, tuoh, _jgib,
   {{0x6609004e,0xa2a40a90,0x7bce2e42,0xe4a60336}},	//   _czek, कास्, lzbu, ирко,
   {{0xd37a1456,0xc44800d1,0x6609c5fc,0xd9432028}},	//   вчи_, ایان_, _dzek, _фери,
   {{0x6609c5fd,0x48f50066,0xf2c60009,0x6727001c}},	//   _ezek, ्तरो_, исин, _gujj,
   {{0x644ac5fe,0xbcfbc5ff,0x6e24c600,0x0cb4012f}},	//   safi, prég, _ngib, ुसुम,
   {{0x60f801d3,0x644a021e,0x3cf8c601,0x60da00a2}},	//   лния_, pafi, korv_, titm,
   {{0x6d5d00cb,0x6f0d0147,0x6e2482aa,0x00000000}},	//   vrsa, _shac, _agib, --,
   {{0x6f0dc247,0x69cd0a8a,0x3f980097,0xf99f0107}},	//   _phac, zzae, íru_, _azèl_,
   {{0x644801d6,0xbcfb01ef,0xa3e30380,0x2abc0098}},	//   _hedi, guén, नपर_, _uíbh_,
   {{0x64480a99,0xa15802c4,0x6d5dc602,0xdced0069}},	//   _kedi, _салу_, ursa, _jraħ,
   {{0x64483015,0x6f0d081f,0x6d4fc603,0x91bb00a5}},	//   _jedi, _whac, rsca, _במדי,
   {{0x6f0dc604,0xaa5901e0,0x7bce0009,0xf99f0107}},	//   _thac, ливу_, gzbu, _ezèl_,
   {{0x6448495c,0x8aa4225d,0x1b1910b0,0xbcfb0453}},	//   _ledi, оруд, ужбы_, cuén,
   {{0x6d44004e,0x7e6dc605,0xdced0069,0x39b800af}},	// [f210] _gwia, _icap, _jqaċ, алтэ_,
   {{0x6448c606,0xd70f114e,0x7bce01f2,0x66090035}},	//   _nedi, िष्ठ_, bzbu, _rzek,
   {{0x660900b5,0x6d440035,0xbcfb00a2,0x00000000}},	//   _szek, _zwia, grée, --,
   {{0xf1b806fe,0x2b5e0355,0xdfc600b5,0x8b9a00a5}},	//   ेनान, átce_, _ہي_, _עברת,
   {{0x6448320a,0xd4d90a93,0x356b3961,0x764b0562}},	//   _bedi, лькі_, трен_, ragy,
   {{0xdfc6c607,0x6727018e,0x00000000,0x00000000}},	//   _في_, _tujj, --, --,
   {{0xbcfb000d,0x93bc0139,0xc6a710bb,0x00000000}},	//   crée, _sfăr, _краи, --,
   {{0x2a690fff,0x61e40121,0x660901a3,0xdced0069}},	//   ngab_, _žila, _tzek, _fraħ,
   {{0x6600c608,0xeaaa0070,0x6f180176,0xf99f0107}},	//   _gymk, רױפֿ, _èxci, _ozèm_,
   {{0x6448c609,0x7e6dc60a,0x26dd0273,0x6e24009e}},	//   _gedi, _acap, liwo_, _sgib,
   {{0x442502c4,0x25db0bc1,0x34940036,0x6d44c60b}},	//   _igl_, _खेती_, _фахр, _swia,
   {{0x7bce0187,0x644801b7,0xd49100e2,0xf6790070}},	//   vzbu, _zedi, _hà_, נאָמ,
   {{0xa2a406bc,0x7529ab30,0x644800d0,0x7649073a}},	//   कार्, _juez, _yedi, _meey,
   {{0x7649073a,0xa5da02b5,0x44250176,0x7afd0093}},	//   _leey, אַלי, _jgl_, _akst,
   {{0x752100ea,0xd4910023,0xfaa61b96,0x00000000}},	//   _milz, _mà_, баво, --,
   {{0xd4910019,0x6e2413a6,0xfe46140e,0xf8bf002a}},	//   _là_, _ugib, _унио, _quén_,
   {{0x6d44c60c,0x6720007a,0x00000000,0x00000000}},	// [f220] _uwia, _rimj, --, --,
   {{0x7afd0687,0xbcfb0248,0x6c86004f,0x75210183}},	//   _ekst, trée, _الدم, _nilz,
   {{0x64481e8b,0xdb1c01f4,0x7649018e,0x6ee800a8}},	//   _redi, nyrë, _beey, yıbl,
   {{0x644827c8,0x6efdc60d,0x6a860009,0xbcfb000d}},	//   _sedi, lébr, _улма, rrée,
   {{0x673b0a78,0x6448c60e,0x752108c8,0xd49100cc}},	//   _čuje, _pedi, _bilz, _bà_,
   {{0x6fca07ba,0x6cf80775,0xd491055c,0x00000000}},	//   ानमं, ंकिग_, _cà_, --,
   {{0x41d00581,0x6448c60f,0xa2a400b8,0xdb1c0055}},	//   _तेजस, _vedi, काल्, jyrë,
   {{0x7649073a,0x44250107,0xdd2d00d8,0x644860cc}},	//   _geey, _egl_, vėžy, _wedi,
   {{0x39527c7b,0x75213194,0xb6bb00a5,0x11d80037}},	//   nsys_, _filz, _עצמי, شودة_,
   {{0x7e6dc610,0xfbc80026,0x75217041,0x661d00ac}},	//   _scap, रनाम, _gilz, _úska,
   {{0x2d800a93,0xa5070011,0x7649018e,0x00000000}},	//   _apie_, _уефа_, _yeey, --,
   {{0x490f0b4d,0x41d907b5,0x20020228,0x814302fd}},	//   _तीनो_, _बेवस, āki_, _کنون,
   {{0x200b006a,0x7e6d0051,0x26c70055,0x00000000}},	//   ęcia_, _vcap, ënoi_, --,
   {{0x1fa63275,0x6ce70409,0x00000000,0x00000000}},	//   _григ, сіме, --, --,
   {{0x78b50076,0x2ac70274,0xac192519,0x00000000}},	//   _rozv, бљав, рову_, --,
   {{0x7e6d149f,0x7f3b0070,0x78b5023a,0x8337016b}},	//   _ucap, _געהו, _sozv, מאלס_,
   {{0x78270037,0x2a6945f8,0x00000000,0x00000000}},	// [f230] معال, rgab_, --, --,
   {{0x7649055c,0x00000000,0x00000000,0x00000000}},	//   _seey, --, --, --,
   {{0xddcd0035,0x569500c3,0x78b5023a,0x752903d0}},	//   _udał, жает, _vozv, _suez,
   {{0x8f9b00a5,0x3f9c0124,0x00000000,0x00000000}},	//   טיבי, _mrvu_, --, --,
   {{0x98c501d6,0x7521c611,0x61e40c8c,0x94256355}},	//   ştır_, _pilz, _žiln, омле,
   {{0x7649001c,0xe3590fc5,0x2d9900be,0xe3b001cb}},	//   _weey, ашиш_, ivse_, کره_,
   {{0xd4910019,0x44258ea3,0xbcfb02d7,0x00000000}},	//   _và_, _vgl_, vuél, --,
   {{0x6b830132,0xf99f0107,0x00000000,0x00000000}},	//   _ângu, _tyèd_, --, --,
   {{0x4425c612,0x3f9c00ab,0x059500d1,0xddc40024}},	//   _tgl_, _arvu_, _بازگ, _qbiż,
   {{0x443100a8,0x4425c613,0xdb1c01f4,0xe0d9547d}},	//   _üz_, _ugl_, tyrë, рво_,
   {{0xd0091a24,0x248702e9,0xbef70099,0xe9df0138}},	//   рене_, menm_, ीतून_, _seúl_,
   {{0x6e290355,0x3f8e023a,0x3f9c0124,0x0cb40096}},	//   žebn, _dsfu_, _drvu_, ुस्म,
   {{0x61ed00f4,0x00000000,0x00000000,0x00000000}},	//   _žalf, --, --, --,
   {{0x2f2500ec,0x660603d0,0x00000000,0x00000000}},	//   _bēgt_, _økke, --, --,
   {{0x6efd000d,0x2d800345,0x799d0e74,0x00000000}},	//   rébr, _wpie_, _arsw, --,
   {{0x394600d8,0xfaa330dd,0xbcfb00a2,0x00000000}},	//   жнаг, масо, tréc, --,
   {{0xa96a01f2,0xdce40024,0xcee900f8,0x00000000}},	// [f240] риза_, _esiġ, _درون_, --,
   {{0x3952016e,0x6d5604fb,0xe9d7010b,0x00000000}},	//   rsys_, _ivya, цку_, --,
   {{0xd7ff00af,0x562a7d5c,0x00000000,0x00000000}},	//   _ţări_, ажем_, --, --,
   {{0xbcfb0248,0x98af00ea,0x3952c614,0x05db00b4}},	//   préc, īgā_, psys_, _मेहब,
   {{0xddcd004e,0x94aa0268,0xf1d9021a,0x00000000}},	//   _gdań, итка_, _बेलन, --,
   {{0x4394021d,0x00000000,0x00000000,0x00000000}},	//   закс, --, --, --,
   {{0xd4670202,0x59de021a,0x925840c5,0xe71a00d1}},	//   ције_, _नेतर, байт_, _نيست_,
   {{0xfbe80023,0x1dab021a,0x00000000,0x00000000}},	//   _đề_, _चपलत, --, --,
   {{0xcb1302da,0x7642128f,0x045a0df3,0x00000000}},	//   ולה_, mboy, _نجات_, --,
   {{0xb4630949,0x3f9c0a78,0x397b1899,0x2ec306fe}},	//   _окул, _prvu_, סטינ, शस्त,
   {{0xd1b7006c,0x6d560260,0x00000000,0x00000000}},	//   مایا_, _avya, --, --,
   {{0x76420be2,0x7c2800cd,0xbcfb0118,0x00000000}},	//   nboy, ždrl, dréa, --,
   {{0xf6530122,0x171b02b5,0xdce40024,0x00000000}},	//   וצר_, יוטע, _ssiġ, --,
   {{0x61ed010b,0x20d30037,0x6fb60037,0x80a100b4}},	//   _žalg, _يتوج, _ومشا, _कोपे,
   {{0x80a300f8,0x7642022e,0xbcfb511a,0x4439013b}},	//   _زمين, kboy, gréa, _əs_,
   {{0x690b0955,0x60ca0069,0x6562c615,0x00000000}},	//   güen, _hlfm, kroh, --,
   {{0x645a507a,0x00000000,0x00000000,0x00000000}},	// [f250] _odti, --, --, --,
   {{0xf8074674,0x6562c616,0x645e01ef,0x00000000}},	//   очен, droh, ópil, --,
   {{0x37ab059d,0xbcfb000d,0x602d00b5,0xa2cd00b8}},	//   штан_, créa, _hőmé, तसम्,
   {{0x0f7b0122,0xf7700088,0x645a0a4e,0xabfa00a5}},	//   שראל, ئال_, _adti, _להתר,
   {{0x64a529d6,0x00000000,0x00000000,0x00000000}},	//   зала, --, --, --,
   {{0x6fca0785,0x645a01ed,0xab9800f8,0x2905008d}},	//   ानां, _cdti, _اخیر_, _óla_,
   {{0xaabf0ec5,0x0768010b,0x00000000,0x00000000}},	//   _एकाक, _маёй_, --, --,
   {{0xd2a903ad,0x2d8401d6,0xdffe0324,0x6562c2f8}},	//   ские_, çmek_, _उड़द_, broh,
   {{0xa3db1163,0x213901f4,0xdc180d1f,0x00000000}},	//   _ढेर_, ësh_, _दण्ड_, --,
   {{0x98bd0808,0xf8bd252c,0x753b1fe3,0xa0690dec}},	//   ोसिए, ोसिय, _ituz, љана_,
   {{0x6443c617,0x200e00ee,0x8fa5c618,0x00000000}},	//   mbni, _czfi_, чане, --,
   {{0xe29802ce,0xf99f0359,0x60ca0110,0x7b1369d3}},	//   _має_, _orè_, _elfm, nçud,
   {{0xe0ce02ce,0x7ebf0031,0x3eab00ac,0x260f0099}},	//   _зв_, _nëpu, _šité_, तेची_,
   {{0x408709ea,0x213f50e0,0x913a0122,0x5f750934}},	//   _фудб, mpuh_, _העסק, _فابر,
   {{0xf99f021e,0x00000000,0x00000000,0x00000000}},	//   _arè_, --, --, --,
   {{0x8b239765,0xaf760070,0x28de0246,0xbcfb00a2}},	//   едсе, _זעקס_, फोनि, rréa,
   {{0xf9836f95,0x798d3725,0x753b01d5,0x00000000}},	// [f260] нгто, gwaw, _ntuz, --,
   {{0x644302c4,0x2d920260,0x765b0027,0x00000000}},	//   jbni, _isye_, _aduy, --,
   {{0x7642008c,0xf99f02d0,0x753b3772,0x29e2007a}},	//   tboy, _erè_, _atuz, _sħaħ_,
   {{0x690b684f,0xf99f0c1f,0x798d01a8,0x65621e28}},	//   qüen, _frè_, bwaw, troh,
   {{0xa50a0dc8,0xf99f0107,0x765b030d,0xba9b024b}},	//   беда_, _grè_, _dduy, _הסכי,
   {{0x3940c619,0x6562c61a,0x2d9202d0,0x7afb008b}},	//   mpis_, rroh, _msye_, čute,
   {{0xb62a0023,0x3940081b,0x753b030d,0xbcfb00fd}},	//   _chợđ, lpis_, _etuz, krén,
   {{0x994c0038,0x68fe1c1c,0x65623c00,0xd13800af}},	//   _môže_, lopd, proh, озиц_,
   {{0x644301ff,0x7faa00a8,0x00000000,0x00000000}},	//   bbni, vəqq, --, --,
   {{0x26c6c61b,0x9405013b,0x00000000,0x00000000}},	//   lkoo_, _lalə_, --, --,
   {{0xb4e800a1,0xb2260fa7,0x26180026,0x2d92021e}},	//   मची_, _емел, बेरी_, _asye_,
   {{0x0b000083,0x6b9c011c,0x61ed08b7,0x26c6081b}},	//   ্দুল_, dvrg, _žale, nkoo_,
   {{0x91d4111e,0x68fe0a75,0x7faa00a8,0x7b1300a2}},	//   _बेचै, kopd, rəqq, nçue,
   {{0x32060159,0x01370319,0x2ceb6cfe,0x690b01ef}},	//   _iyoy_, _צרות_, сьмо_, güel,
   {{0x26c60328,0x2d920107,0x7ee700af,0x307b00a5}},	//   kkoo_, _esye_, _нцие, _האונ,
   {{0x59de25d8,0xf99f02d0,0xbcfb2d87,0xf1b00099}},	//   _नेहर, _prè_, ntéz, _जपान,
   {{0x05db065a,0x3ea9c61c,0x98b90132,0x3940010d}},	// [f270] _मेंब, _inat_, олат_, gpis_,
   {{0x7e7d1472,0xf99f02d0,0x798d0516,0x3ea900ee}},	//   lfsp, _vrè_, rwaw, _hnat_,
   {{0x753b07e5,0x00000000,0x00000000,0x00000000}},	//   _stuz, --, --, --,
   {{0xa63402ce,0xf99f02e9,0x672e035f,0x32e30107}},	//   енці, _trè_, _dubj, _mèyè_,
   {{0x7aed5254,0xc98417d0,0x32060159,0x8c1900d1}},	//   mnat, _пури, _nyoy_, _ديگر_,
   {{0x2eba035d,0x83392e02,0x644302b1,0xdce4013a}},	//   _उक्त, очит_, ubni, _driķ,
   {{0x20c900fb,0x6443c61d,0xe4500c74,0x33260a8a}},	//   _búin_, rbni, اضه_, _biox_,
   {{0x7aedc61e,0x569401c8,0x24800254,0x23260c46}},	//   nnat, _паст, đima_, мощи_,
   {{0xf48720b6,0x7aed437c,0x61ed0254,0xe3af00b5}},	//   _нужн, inat, _žalb, ئرڈ_,
   {{0x3ea90443,0x629d016f,0x7aed00e9,0x3b0909e7}},	//   _anat_, ôsob, hnat, hlaq_,
   {{0x656bc61f,0x3e8a07b0,0xdbcc0093,0x394051e4}},	//   lugh, ойно_, jóða, zpis_,
   {{0x32e302e9,0x39400093,0xee371667,0x00000000}},	//   _dèyè_, ypis_, мню_, --,
   {{0x7bc10a8a,0x780a0f17,0x00000000,0x00000000}},	//   ølun, _वर्क_, --, --,
   {{0x7aedc620,0x673b00f4,0x3ea90282,0x00000000}},	//   enat, _čujn, _enat_, --,
   {{0xeb974234,0x1d071558,0x26cd014c,0xa3bf178c}},	//   мир_, фери_, _oleo_, ुनि_,
   {{0x7aedc621,0x21270019,0x39400254,0x3ea901ef}},	//   gnat, _hinh_, tpis_, _gnat_,
   {{0x212700e8,0xdd8f1c64,0x09e32ab4,0x672ec622}},	// [f280] _kinh_, _نوي_, вотн, _subj,
   {{0x7aed42eb,0x3940c623,0xa3bf0fff,0x3ea928da}},	//   anat, rpis_, ुना_, _znat_,
   {{0x212700e8,0x68fe310c,0x26cd0160,0x212f1861}},	//   _minh_, ropd, _bleo_, _lugh_,
   {{0x21270028,0x656b027a,0x3940c545,0x7aed008c}},	//   _linh_, fugh, ppis_, cnat,
   {{0x7ae4c624,0x26c600ee,0x20c90079,0x98a20409}},	//   miit, rkoo_, _rúin_, _auką_,
   {{0x7ae42efa,0x21270028,0xed590187,0xb4e80099}},	//   liit, _ninh_, áži_, मचे_,
   {{0x6f04022f,0x4ad22893,0xd8236771,0x26cd0107}},	//   _okic, _सताव, _адри, _fleo_,
   {{0x78bcc625,0x7ae4c626,0x2127009e,0x6b83013c}},	//   _horv, niit, _ainh_, _änge,
   {{0x78bcc627,0x66030f9d,0x66e381dc,0x212701a5}},	//   _korv, _апта, _рота, _binh_,
   {{0x7aed0537,0x6f04306e,0x7ae409aa,0x3cf80067}},	//   znat, _akic, hiit, ंकों_,
   {{0x20c9004f,0x212701a5,0x7ae42ff3,0x7aed6dc7}},	//   _iúil_, _dinh_, kiit, ynat,
   {{0xa1c6c628,0xa3e40035,0x7ae4002f,0x79860051}},	//   _обед, _पेय_, jiit, _opkw,
   {{0x7aed0a3c,0x20070095,0x78bc053e,0x7ae4c629}},	//   vnat, _eyni_, _oorv, diit,
   {{0x6f0468a0,0xbcfb01ef,0x7c8412b9,0x00000000}},	//   _ekic, ntéx, кусе, --,
   {{0x3b09007a,0x752873c0,0x7ae4081b,0x00000000}},	//   tlaq_, _midz, fiit, --,
   {{0x3ea908dd,0xddcd0168,0x7aedc62a,0x7528c62b}},	//   _unat_, _ibaž, unat, _lidz,
   {{0x2bff0f9c,0x6282073a,0x6e2d01d5,0x3b0900a8}},	// [f290] _शुरू_, _mboo, _igab, rlaq_,
   {{0x2737048c,0x212701a5,0x6282011e,0x78bc2e65}},	//   _aħna_, _xinh_, _lboo, _corv,
   {{0xb9070026,0x78bc0260,0x7ae4018e,0x6d4d0118}},	//   _बग_, _dorv, biit, _hwaa,
   {{0x6d4dc62c,0x7ae402d4,0x442c0067,0xa29e00a9}},	//   _kwaa, ciit, _agd_, _खोल्,
   {{0xca240923,0x78bc5011,0x6e2d011e,0x2d4d0314}},	//   _афри, _forv, _mgab, nže_,
   {{0x6282018e,0x656bc62d,0x6d4dc62e,0xa8a40bfe}},	//   _aboo, rugh, _mwaa, _ирск,
   {{0x442c022e,0x29010118,0x752800e1,0x20c90079}},	//   _dgd_, moha_, _didz, _dúil_,
   {{0x212700e8,0x2901024e,0x6e2dc62f,0x2d4d05d3}},	//   _sinh_, loha_, _ngab, kže_,
   {{0x15f30f91,0x6abdc630,0x31250009,0x290100d7}},	//   _आखिर_, _mosf, ндиг, ooha_,
   {{0x6f0406d7,0x2d4d02b2,0x6e2d1939,0x628246fe}},	//   _skic, dže_, _agab, _eboo,
   {{0x212701a5,0x6d4d276d,0xf8b2011d,0x14ac063f}},	//   _vinh_, _awaa, אשי_, चारण,
   {{0x62820118,0x61ea00b5,0x6d4d018e,0x67290069}},	//   _gboo, ámlá, _bwaa, _jiej,
   {{0x6729006a,0x21270028,0x2bc800df,0x290100ab}},	//   _miej, _tinh_, रन्थ, koha_,
   {{0x6d4d2475,0x6f1d574c,0x6e2d073a,0xbcfb00ac}},	//   _dwaa, amsc, _egab, brém,
   {{0xdee61eb9,0x6299c631,0x80ac00dc,0x2d8c0107}},	//   _поки, _kawo, जारे, ňde_,
   {{0x78bcc632,0x61e4016f,0x629b00d8,0x501a02b5}},	//   _sorv, _žili, nduo, _צוקו,
   {{0xe9da292e,0xdca60091,0x66092126,0x7ae4c633}},	// [f2a0] чка_, _запи, _nyek, riit,
   {{0x6299c634,0x7ae483e7,0xf99f0260,0x00000000}},	//   _lawo, siit, _iyèl_, --,
   {{0x6abdc635,0x6d4d0120,0x75280897,0x67293c0d}},	//   _fosf, _zwaa, _ridz, _biej,
   {{0x20c9004f,0x6299c636,0xd0410095,0x6609001c}},	//   _súil_, _nawo, rhlə, _byek,
   {{0xe5a303f5,0x78bc72d5,0x442cc637,0x659488ae}},	//   лици, _torv, _pgd_, талу,
   {{0x24800506,0x66091a99,0xf99f0359,0x316d01ed}},	//   đimo_, _dyek, _myèl_, duez_,
   {{0x6abd012f,0x752800ea,0x6299c638,0x2ca70042}},	//   _yosf, _vidz, _bawo, _ónde_,
   {{0x7528004e,0xd250004f,0x629b2268,0x6e290124}},	//   _widz, جنة_, gduo, žebi,
   {{0x62996296,0x62824e8b,0x6609001c,0x00000000}},	//   _dawo, _vboo, _gyek, --,
   {{0xbcfb6089,0x6e2dc639,0x20c00211,0x00000000}},	//   trém, _sgab, _ròis_, --,
   {{0x6d4d0173,0x29180024,0x00000000,0x00000000}},	//   _swaa, _mhra_, --, --,
   {{0x20c000f1,0xf99f0260,0xbcfb000d,0x6299b64c}},	//   _còir_, _byèl_, rrém, _gawo,
   {{0x6f1d0110,0x2918035f,0x98a30359,0x00000000}},	//   rmsc, _ohra_, _sijč_, --,
   {{0x6299004e,0x62800b0d,0x2d4d1ada,0xe7e100ab}},	//   _zawo, lfmo, rže_, _गइला_,
   {{0x0b880043,0x6299073a,0x6d4d0159,0x2f1200b5}},	//   нсти_, _yawo, _wwaa, sága_,
   {{0x6d4d5331,0x2901011e,0xf99f021e,0x6e2d3729}},	//   _twaa, woha_, _fyèl_, _ugab,
   {{0xe9f80185,0x2918012f,0x2901c63a,0x68e50225}},	// [f2b0] енті_, _bhra_, toha_, tihd,
   {{0x629b010b,0x67291627,0xe4e50761,0x66090103}},	//   zduo, _siej, _औषधि_, _ryek,
   {{0xec360052,0x660976c6,0x69c100a8,0x2901c63b}},	//   _באתר_, _syek, _əley, roha_,
   {{0xb8c80534,0x29180159,0x67290055,0x66090118}},	//   _खो_, _ehra_, _qiej, _pyek,
   {{0x67290033,0x9f5c03ad,0xa3d30084,0xd006006c}},	//   _viej, _hyvä_, सैन_, _چل_,
   {{0x62990cd4,0x29180211,0x62800223,0x67290067}},	//   _sawo, _ghra_, efmo, _wiej,
   {{0xd7c90088,0x629953ed,0xef1f05f9,0xd6db0390}},	//   _غوره_, _pawo, kmü_, _ета_,
   {{0xddcd003c,0x6609021e,0x00000000,0x00000000}},	//   _bbaż, _tyek, --, --,
   {{0x629b01c8,0x36d40086,0xdced013a,0x00000000}},	//   rduo, _сотр, _braļ, --,
   {{0xb60400af,0xf99f0107,0x6299c4e6,0x316d0065}},	//   _сяск, _nyèm_, _wawo, ruez_,
   {{0xf99f02e9,0x6299c63c,0x644b0bde,0xb275b935}},	//   _syèl_, _tawo, čnič, _алеш,
   {{0xed5ac63d,0xfe720037,0xdee611a7,0x802500fd}},	//   мом_, جدد_, томи, _یرغم,
   {{0x316d02e1,0xf1d90035,0x00000000,0x00000000}},	//   quez_, _बेचन, --, --,
   {{0x71d61804,0x00000000,0x00000000,0x00000000}},	//   _בונד_, --, --, --,
   {{0xe7e100a1,0x8f1654d3,0xfd5000e2,0x20c001da}},	//   _गेला_, _ифич, nnhạ, _tòir_,
   {{0xc33202da,0x00000000,0x00000000,0x00000000}},	//   שון_, --, --, --,
   {{0x3b07075c,0xeabf0023,0x2918045b,0xbcfbc63e}},	// [f2c0] тето_, _giùm_, _phra_, gués,
   {{0x07a60131,0xba3b00f6,0x00000000,0x00000000}},	//   казн, _naïf, --, --,
   {{0xc00f0023,0xbcfb00ac,0x00000000,0x00000000}},	//   _đuối_, dréh, --, --,
   {{0xdd1100b8,0x2bf700a5,0x6d461c1c,0x00000000}},	//   mýšl, _ימין_, opka, --,
   {{0x19f900af,0x66f3073f,0x00000000,0x00000000}},	//   _зэрь_, _अदरक_, --, --,
   {{0x25a401a2,0xf8bf0019,0x80a1157d,0xbcfb0952}},	//   _vrml_, _quét_, _कोले, quét,
   {{0x289b016b,0x00000000,0x00000000,0x00000000}},	//   _קילא, --, --, --,
   {{0xb8650332,0xf1a60842,0xdced0024,0x00000000}},	//   _لاہو, врон, _msaġ, --,
   {{0xbcfb0187,0x62800051,0x00000000,0x00000000}},	//   bréh, rfmo, --, --,
   {{0x30a6c156,0x93466a63,0x6abf00b4,0x00000000}},	//   трив, _анже, _एक्र, --,
   {{0x6458c63f,0x085700a5,0x2a6202c4,0x443e0a8a}},	//   mavi, כבים_, _odkb_, _ift_,
   {{0x6458c640,0xe24600ad,0xdce60029,0x7c3e08c8}},	//   lavi, _شخصي, vukā, _afpr,
   {{0x443e0332,0x2002004e,0xbcfb006c,0x40960037}},	//   _kft_, łki_, nség, _للشر,
   {{0x64588cbe,0x6ce70210,0x31570070,0x752f0176}},	//   navi, тіме, _יידן_, _ècze,
   {{0x3ced0009,0x443e5c3c,0xf093024b,0xf99f0107}},	//   đev_, _mft_, _כנס_, _vyèm_,
   {{0xbcfb38bc,0x6458c641,0x13e50033,0xba3b00f6}},	//   guér, havi, _পুড়, _maïg,
   {{0x5a341523,0xdced0024,0xbcfb0079,0x443e3135}},	// [f2d0] рнут, _esaġ, hréi, _oft_,
   {{0x64580936,0x6d5d684e,0x2b410023,0x06ca0033}},	//   javi, mssa, _tthc_, লোমি,
   {{0x6d5d0cfc,0x05db0067,0x00000000,0x00000000}},	//   lssa, _मेजब, --, --,
   {{0xbcfba164,0x461500d1,0xf8bf0453,0x929d0035}},	//   dréi, هوار, _pués_, koła,
   {{0x6d5d36f7,0x3cf80609,0xbcfb9822,0x6458c642}},	//   nssa, _سعید_, gség, favi,
   {{0xb97a0052,0x6458c643,0x6d5d1d5e,0xf7730332}},	//   _אנשי, gavi, issa, _پاس_,
   {{0x443e0051,0x1cbc0070,0x00000000,0x00000000}},	//   _dft_, ומגע, --, --,
   {{0x81de00c8,0x6d5f0be2,0x443ec644,0xf8bf000d}},	//   _দুই_, _ovqa, _eft_, _tués_,
   {{0x64582190,0x35f5c645,0x65942a2d,0xbcfb000d}},	//   bavi, _спар, _кату, préh,
   {{0x2ecc1e18,0x7659027c,0xbcfbb362,0x443e0051}},	//   ास्त, lawy, bréi, _gft_,
   {{0xd2510082,0x6d5dc03a,0xceea0ddc,0xba3b0345}},	//   _هنا_, essa, едне_, _kaïd,
   {{0xc33201f3,0x656b0043,0x6f0f011e,0x62350370}},	//   _הוא_, orgh, glcc, _седу,
   {{0x0165195a,0x6d5d2a96,0xa0695d90,0x7afb008b}},	//   _скло, gssa, _зала_, čutl,
   {{0x515a0122,0xa3ca0035,0x7659016e,0x00000000}},	//   _טכנו, रैक_, hawy, --,
   {{0xbea6479a,0xbcfb006c,0x8c4301fd,0x6b6301e0}},	//   _байк, zség, сесе, йкра,
   {{0xd00e317b,0x6458c646,0x6d46ad94,0xbcfb00b5}},	//   _علي_, zavi, ppka, ység,
   {{0x6da659d4,0x64581684,0x200b0035,0xa967a21a}},	// [f2e0] _сипа, yavi, ęciu_, лита_,
   {{0xa90a0079,0x317f01d7,0x7b1300a8,0x645801ef}},	//   ريال_, ituz_, lçul, xavi,
   {{0x64584889,0x2f19006c,0x3f510029,0x00000000}},	//   vavi, sége_, nšu_, --,
   {{0xbcfbc647,0x93bc0160,0x6458023c,0x7b13013b}},	//   tség, _ogăr, wavi, nçul,
   {{0x6458be18,0x9c8700ac,0xbddb00a2,0x00000000}},	//   tavi, _určí, ccèd, --,
   {{0x3f5100ea,0xbcfbc648,0x2eb323db,0x00000000}},	//   kšu_, tréi, _ुक्त, --,
   {{0xbcfb0332,0xa3e400b1,0x929d0035,0x332a002d}},	//   sség, _पेश_, woła, нцин_,
   {{0x6458c649,0x7e640054,0x6d5dc64a,0xbcfb0183}},	//   savi, _ndip, yssa, rréi,
   {{0x6458c64b,0x6d4401a9,0x3f510080,0x443ec64c}},	//   pavi, _ntia, ešu_, _tft_,
   {{0x7e64c64d,0xb603024e,0xe97b02b5,0x64580095}},	//   _adip, ýšen, עניש, qavi,
   {{0x22863cab,0x3f510029,0x2ef53471,0x33f60086}},	//   _булг, gšu_, изор, _счас,
   {{0x6d5d6df5,0xbcfb00a2,0x00000000,0x00000000}},	//   tssa, isée, --, --,
   {{0x6d5dc64e,0xdced007a,0x7e6400e5,0x00000000}},	//   ussa, _jsaħ, _ddip, --,
   {{0x6722c64f,0x940c00a8,0xdced009f,0x00000000}},	//   hmoj, _sadə_, _msaħ, --,
   {{0xd5a4040d,0x6d4401ed,0xcb1b0370,0x1bd400af}},	//   _کہ_, _etia, еќа_, боря,
   {{0x3d1a0084,0x63a80506,0x6b9b0067,0x00000000}},	//   _मीठे_, _mrdn, ługo, --,
   {{0x08551470,0x286b383f,0x67220009,0xba3b2069}},	// [f2f0] иваю, ерео_, dmoj, _naïe,
   {{0x63a843f5,0xe6c00254,0xa3d4210a,0xd7fb00d8}},	//   _ordn, _čišć, हना_, нуе_,
   {{0x317f01a3,0x96352e90,0x97a70409,0xec1503fc}},	//   ztuz_, анец, ырал, _خودد,
   {{0xbcfb00f7,0xdced0069,0x98ab0160,0x61ed00d5}},	//   sséd, _bsaħ, _bucă_, _žalm,
   {{0x286b11b9,0x63a800a8,0x4a5a00a5,0xb0650421}},	//   _прво_, _ardn, _בדרו, nnää,
   {{0x64a591ab,0x9395186e,0x690b01ef,0x6722057a}},	//   рака, لجبا, güet, amoj,
   {{0xe2990bba,0x3949c650,0x32d50011,0xdb050260}},	//   вай_, lpas_, ицис, _arhé,
   {{0x05150b52,0xd05a0095,0xdced0069,0x3f5100cd}},	//   াদের_, mitə, _fsaħ, všu_,
   {{0x39491816,0x50b509f1,0x7d070c6f,0x00000000}},	//   npas_, асну, kojs, --,
   {{0x9f850df8,0xe188183b,0x317f06a2,0x39490183}},	//   агод, ائين_, rtuz_, ipas_,
   {{0x6d445007,0x2002027d,0x2bba06fe,0x7afb008b}},	//   _stia, şkin_, _उपधा, čutj,
   {{0x3f5100ea,0x733a016b,0x200e0090,0x39490298}},	//   ršu_, _סענס, _dyfi_, kpas_,
   {{0x6f060987,0x224dad11,0x20d500d4,0x823437a4}},	//   rokc, mbek_, _війс, _ارما,
   {{0xc5f20122,0x3f51c651,0x7ae6028b,0x224d5031}},	//   קדם_, pšu_, _smkt, lbek_,
   {{0x60c301a6,0xfbc3409d,0x6b8301ff,0x00000000}},	//   _ionm, обро, _ängl, --,
   {{0xaa46b32f,0x60c3012f,0x4a46082e,0x38c803fc}},	//   реал, _honm, рнав, گاری_,
   {{0x60c33786,0x7d07022f,0x61ed03ab,0x6f24006c}},	// [f300] _konm, bojs, _žalj, _پڑھن,
   {{0x38c81c0c,0x52d2c652,0xdd8f03fc,0x61e60093}},	//   داری_, _तत्स, _کوی_, úkli,
   {{0x394917bf,0x81cb0033,0x2d82c653,0x982800b5}},	//   apas_, রছি_, ltke_, اتذہ_,
   {{0x4aca2c29,0xfaa62839,0xe5c600d4,0x473301e0}},	//   _रविव, _тамо, исло, ініс,
   {{0x6722c654,0xbcfb0248,0xa5da0037,0x2d82c655}},	//   rmoj, ssée, خبار_, ntke_,
   {{0x316d2dd3,0x53340382,0x60c302d0,0xf366191f}},	//   drez_, бект, _nonm, атин,
   {{0x316dc656,0xbcfb000d,0x00000000,0x00000000}},	//   erez_, prév, --, --,
   {{0x7af60086,0x63a80009,0x316d000d,0x2489011c}},	//   nnyt, _vrdn, frez_, đama_,
   {{0x6441001e,0x60c372c2,0x63a8c657,0xbcfb000d}},	//   _ffli, _bonm, _wrdn, nséc,
   {{0x60c30f56,0xf4840148,0x753d00b5,0x63a808b7}},	//   _conm, _داری, _észa, _trdn,
   {{0x3ea0c658,0x8369006c,0x7d0701f4,0x03a3004c}},	//   _bait_, _مصنف_, vojs, _мифо,
   {{0x3ea0006b,0x26c4023c,0x3949a09a,0x27e7c659}},	//   _cait_, _jomo_, ypas_, únni_,
   {{0x25a619c1,0x60c35b15,0x316d00af,0x320f4090}},	//   nvol_, _fonm, crez_, _gygy_,
   {{0x7d020514,0x26c44380,0x705800af,0x60c30260}},	//   _íosl, _lomo_, _сакр_, _gonm,
   {{0x3ea0105d,0xd0f5035d,0xd1030ac4,0x5ba406cd}},	//   _fait_, ीकरण_, रकरण_, ортз,
   {{0x5a35075c,0x60c30051,0x25a60298,0x00000000}},	//   снат, _zonm, kvol_, --,
   {{0x7c87027a,0x7afa00fb,0xbcfb0093,0x6f0d1b68}},	// [f310] _куне, étta, frét, _ikac,
   {{0x3ea006a2,0x3949c65a,0x97a700af,0x58bb0037}},	//   _zait_, rpas_, ирел, خارج_,
   {{0xb8ff021a,0x3949c65b,0x26c402c6,0xfc460097}},	//   _तत_, spas_, _bomo_, číte_,
   {{0x26c41423,0x39490533,0x35b50036,0xd05a00a8}},	//   _como_, ppas_, йбер, ritə,
   {{0x7aedc65c,0xd05a0095,0x26c46cc9,0x644101ae}},	//   miat, sitə, _domo_, _pfli,
   {{0x316d02e1,0xbcfb0248,0x6441011e,0xf4871d41}},	//   vrez_, crét, _qfli, рудн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aedc65d,0x23691851,0x1bf802b8,0x316d0248}},	//   niat, čaj_, יצור_, trez_,
   {{0x20020095,0x3ea000b9,0x690b2cd6,0x316d00a2}},	//   şkil_, _rait_, qües, urez_,
   {{0x147718dd,0x316dc0f8,0x3ea0c65e,0x83870086}},	//   _خارج, rrez_, _sait_, _выде,
   {{0xedd00803,0x8504126b,0x3ea05d15,0xbea62a21}},	//   हन्छ, _بولن, _pait_, банк,
   {{0x661b0132,0x316d0067,0x7aed01ed,0x00000000}},	//   _kzuk, prez_, jiat, --,
   {{0x7aed0dc5,0x2bba9c57,0x21696a4d,0x799d0069}},	//   diat, _उपहा, _сили_, _nssw,
   {{0x2d82025c,0x2293006c,0x6f0d012f,0x60da86d3}},	//   rtke_, _دلچس, _ekac, chtm,
   {{0x2d82c65f,0x799d0103,0x3ea000f6,0x06f70066}},	//   stke_, _assw, _tait_, ंचाव_,
   {{0x7f3a00c2,0x7aed253e,0x6ee511c0,0x3ea00037}},	//   _געקו, giat, _وسيل, _uait_,
   {{0x5d860082,0x26c4bae3,0x2ca1c660,0x2bba0026}},	// [f320] _الخل, _romo_, _fahd_, _उपवा,
   {{0x26c45c24,0x7af601ff,0xbcfb4135,0x00000000}},	//   _somo_, snyt, rséc, --,
   {{0x661bc661,0x26c4c662,0xbcfb0093,0x2bc9022e}},	//   _azuk, _pomo_, rrét, रहणा,
   {{0x6676004f,0x673b00cd,0xbcfb0093,0xf6e501e0}},	//   إدار, _čujt, srét, оцін,
   {{0x7bce0160,0xb33c007a,0x19b900af,0xe7e8021a}},	//   lybu, _irħi, _курь_, _टेरा_,
   {{0xc9531759,0x6d56001e,0x628b0027,0x661b004b}},	//   _ממש_, _mwya, _abgo, _dzuk,
   {{0x25a603c4,0xbcfbc663,0x00000000,0x00000000}},	//   svol_, nséa, --, --,
   {{0x26c401d3,0x6aa4c664,0xbcfb0079,0x00000000}},	//   _uomo_, ndif, iséa, --,
   {{0xc05a12ea,0x7984c665,0x7bce0187,0xc5c60033}},	//   лін_, ntiw, hybu, _শেরপ,
   {{0x7aedc666,0x7afb008b,0x6f0d3b5e,0x764202d7}},	//   ziat, čuti, _skac, lcoy,
   {{0x60dac667,0xd04100a8,0x645a00ea,0x6562c668}},	//   rhtm, nklə, _ieti, lsoh,
   {{0xe3b10332,0x645ac669,0x60da01f4,0x539b0122}},	//   _کرے_, _heti, shtm, _תיאו,
   {{0x7aedc66a,0x645a4367,0xd24f004f,0x6aa4001e}},	//   viat, _keti, _أنه_, ddif,
   {{0x7aed0035,0x645a40a3,0x6e3600b5,0xf99f0260}},	//   wiat, _jeti, _egyb, _myèt_,
   {{0xd00f0037,0x2f1200b5,0x75b40099,0x00000000}},	//   _كله_, zági_, ंमुळ, --,
   {{0x61edc66b,0x645a2018,0x201c0009,0x6d56001e}},	//   _žali, _leti, _izvi_, _fwya,
   {{0x7984067f,0x1ef80037,0x273e00a2,0x645a1e2e}},	// [f330] gtiw, _دعوة_, _aïn_, _oeti,
   {{0x7aedc66c,0xa3ab00c0,0xb33c0024,0x248c0124}},	//   siat, खिम_, _erħi, _nbdm_,
   {{0x661b006a,0x7aedc66d,0x2d920a66,0x6aa40069}},	//   _szuk, piat, čneš_, bdif,
   {{0xbcfbc66e,0x1b170033,0x00000000,0x00000000}},	//   prés, _দূরে_, --, --,
   {{0x645ac66f,0x7afd0223,0x356b3cc0,0x00000000}},	//   _beti, _ijst, урен_, --,
   {{0x645a01a0,0x248900cb,0xf99f0107,0x201c00ac}},	//   _ceti, đamo_, _dyèt_, _ozvi_,
   {{0x2f12006c,0xc7c43961,0x36d50dec,0x00000000}},	//   sági_, _ести, _довр, --,
   {{0x645a00be,0x661b01ed,0xb1453029,0x00000000}},	//   _eeti, _tzuk, онил, --,
   {{0x645ac670,0xe0d93425,0x661b0027,0x00000000}},	//   _feti, иви_, _uzuk, --,
   {{0x645ac671,0x1f651858,0x7afd0009,0x78a57f62}},	//   _geti, оком, _ljst, ndhv,
   {{0x69100006,0xdbf2000c,0x28de021a,0x7afd068f}},	//   päev, _příp, फोटि, _ojst,
   {{0x753b000e,0x7afd0009,0x823400f8,0x00000000}},	//   _kuuz, _njst, _فرها, --,
   {{0x645a0dac,0x69cb054e,0x753b0103,0xfe7100fd}},	//   _yeti, øgel, _juuz, رگٹ_,
   {{0x753bc672,0x6b9e00f6,0x628901ed,0x00000000}},	//   _muuz, _pspg, lfeo, --,
   {{0xea5a03e6,0xda5a0be8,0xf99f021e,0x64430079}},	//   ирај_, ираш_, _asè_, icni,
   {{0x0a4a083e,0x225f022f,0x25adc673,0x7bce0035}},	//   рзай_, nauk_, _orel_, rybu,
   {{0x6aa4c674,0xbcfb01ef,0x00000000,0x00000000}},	// [f340] rdif, rrér, --, --,
   {{0x7984560b,0x186a03d6,0x7afd008c,0x6eef0107}},	//   rtiw, ражи_, _ejst, _tòbè,
   {{0x7984c675,0x645ac676,0x25ad0069,0xf99f021e}},	//   stiw, _reti, _arel_, _esè_,
   {{0x268a0514,0x645a3635,0xd04100a8,0x753b073a}},	//   شخصي_, _seti, rklə, _buuz,
   {{0x645ac677,0x6596004f,0xba48010b,0xd04100a8}},	//   _peti, تجار, grįž, sklə,
   {{0x53341018,0x6562c678,0xeabf0284,0x779100b5}},	//   пект, rsoh, _fiùs_, بیہا,
   {{0x39400034,0xf487042c,0x645ac679,0x00000000}},	//   lqis_, تانی, _veti, --,
   {{0x645a1080,0xe81f00b4,0x8bfc0033,0xd1410067}},	//   _weti, _भरता_, _ইরান_, knąć_,
   {{0x645ac67a,0x2c11007c,0x25ad023a,0x673c0421}},	//   _teti, _दुनू_, _grel_, _hurj,
   {{0x2a60006f,0x673cc67b,0x00000000,0x00000000}},	//   haib_, _kurj, --, --,
   {{0x673c0b67,0x225f00d7,0x320a0035,0x2d92021e}},	//   _jurj, bauk_, łby_, _apye_,
   {{0x673cc67c,0xb35700b5,0x539b076b,0x00000000}},	//   _murj, _بیٹا_, _כיבו, --,
   {{0x7b3c0009,0x673cc67d,0xc33300a5,0x00000000}},	//   _učuj, _lurj, _חוף_, --,
   {{0xd12f01c8,0xe57102b5,0x316602a7,0x00000000}},	//   _іх_, ײַך_, _ivoz_, --,
   {{0xfbe10033,0x66fc08b7,0x673c00be,0xac191368}},	//   _মুজত, jčko, _nurj, сову_,
   {{0xa3ab046c,0x7a3904d9,0x98850355,0x644c013b}},	//   खित_, спар_, _vůči_, əniş,
   {{0x49752dc3,0xb33c0024,0x09752780,0x58d5002d}},	// [f350] ялас, _irħu, ягаю, поат,
   {{0x673cc67e,0x7e7d0249,0x37ab3cc0,0x39460079}},	//   _burj, lgsp, итен_, íosa_,
   {{0xf99f02e9,0x765b012f,0x6d4f0036,0x872b00d8}},	//   _pyès_, _peuy, lpca, аўда_,
   {{0x7e7d11cb,0x673cc67f,0x753b034d,0x00000000}},	//   ngsp, _durj, _puuz, --,
   {{0xc98400af,0x2aba00a5,0x2bc92924,0x00000000}},	//   _оури, _המרא, रहवा, --,
   {{0x03a531d3,0x673c007a,0xf99f0260,0x6b850118}},	//   зико, _furj, _fyèr_, _kqhg,
   {{0x31a90168,0xf99f0260,0x00000000,0x00000000}},	//   _sĺz_, _tyès_, --, --,
   {{0xc7b201f3,0xd29900d8,0x5694002d,0x753b0103}},	//   _אבל_, сткі_, _оаст, _tuuz,
   {{0xd49b002d,0xc8ff0033,0x225f7b40,0x00000000}},	//   _вре_, ্গীত_, rauk_, --,
   {{0x225f012f,0x395908dd,0x00000000,0x00000000}},	//   sauk_, _mwss_, --, --,
   {{0xb5fd51e4,0x9f580093,0xd009622d,0xa4fa016b}},	//   _odšk, ærð_, сене_, _פלעט,
   {{0xfaff08e3,0xa3e40bc1,0x61ed0a4c,0x2a60006d}},	//   _një_, _पेट_, _žalu, xaib_,
   {{0xbddb2ddc,0xf1a72749,0x2018008d,0x00000000}},	//   scèn, _френ, ýrir_, --,
   {{0x6cd60082,0x386101ae,0xba3b00f6,0xed1700fd}},	//   أقسا, jahr_, _baïo, ےہیں_,
   {{0xd1410067,0x00000000,0x00000000,0x00000000}},	//   snąć_, --, --, --,
   {{0x3946c680,0x00000000,0x00000000,0x00000000}},	//   знаг, --, --, --,
   {{0x2a60c681,0x386101ae,0x00000000,0x00000000}},	// [f360] raib_, fahr_, --, --,
   {{0xe9d71000,0x673c03a6,0xee3f0187,0xbcfb002a}},	//   чку_, _purj, ndýn_, nsél,
   {{0x98aa002d,0x65790051,0x3f6700f4,0x394b005f}},	//   _aibă_, euwh, nđu_, _etcs_,
   {{0xfaff00da,0x41db00b4,0xeaf920af,0x66fcc682}},	//   _gjë_, यनास, ्कृत_, rčko,
   {{0xa3e4017f,0x00000000,0x00000000,0x00000000}},	//   _पेज_, --, --, --,
   {{0x673c3f60,0x00000000,0x00000000,0x00000000}},	//   _turj, --, --, --,
   {{0x6aa60282,0x3a390139,0x39860183,0x00000000}},	//   _kakf, _ygsp_, lôs_, --,
   {{0xe3af0ae7,0x00000000,0x00000000,0x00000000}},	//   ارو_, --, --, --,
   {{0xe1660037,0x00000000,0x00000000,0x00000000}},	//   أدبي, --, --, --,
   {{0x03a632a6,0x2ed50380,0xaa7b300b,0x95eb00fd}},	//   _низо, दस्त, _umýv, _طبقہ_,
   {{0x3f630086,0xb4d806fe,0xf1f700d1,0x9f580225}},	//   нтяб, ासी_, قعیت_, _özür_,
   {{0xe8b90d00,0x333b00a5,0x7b130392,0x6aa6034d}},	//   _उच्च, _התאמ, nçut, _nakf,
   {{0x628202a2,0x7e7dc683,0x2b5a00ee,0x316637cb}},	//   _icoo, rgsp, _awpc_, _uvoz_,
   {{0xdcef002d,0x2bc90067,0x00000000,0x00000000}},	//   ducă, रहला, --, --,
   {{0xa2c00517,0x9b58002d,0x6aa6244c,0x00000000}},	//   वाप्, зист_, _bakf, --,
   {{0x60cac684,0xb4d8012f,0x68ee0443,0x0f7b00a5}},	//   _hofm, ासु_, _ambd, _האהב,
   {{0x7e6da025,0x00000000,0x00000000,0x00000000}},	// [f370] _idap, --, --, --,
   {{0x6d4dc685,0x6f0f2d1e,0x7d0e48d9,0x3914002d}},	//   _itaa, locc, cobs, емур,
   {{0x6aa6012f,0xbcfb00a2,0x00000000,0x00000000}},	//   _fakf, nsém, --, --,
   {{0x6f0f0382,0xfaff01f4,0x64480223,0x39860183}},	//   nocc, _ujë_, _afdi, bôs_,
   {{0xa2c000a9,0x64a51f67,0x1a68042c,0x3e8800fd}},	//   वान्, дала, _ریلی_, lító_,
   {{0x6d4d0054,0x7e6d00fe,0x6aa60051,0x0608010b}},	//   _mtaa, _ldap, _zakf, чнік_,
   {{0xf8b202b8,0x62820024,0x7e6d00f4,0x00000000}},	//   _בשם_, _bcoo, _odap, --,
   {{0xd6d82f44,0x78a7c615,0x660d00ab,0x62820065}},	//   _ету_, _hajv, üaks, _ccoo,
   {{0x3f410176,0x6f0f539a,0xc6920317,0x30751368}},	//   _sóu_, docc, _באן_, мунс,
   {{0xbddb000d,0x60ca008c,0x65690027,0xe0d10037}},	//   rcèl, _cofm, _iveh, ئزة_,
   {{0x6d4d74b7,0x5f0600d4,0x00000000,0x00000000}},	//   _ataa, дзна, --, --,
   {{0x03780416,0x6f0f0036,0x3f6700cd,0x78a78f43}},	//   _رحمت_, gocc, rđu_, _lajv,
   {{0xa069c245,0x236000f4,0xba3b00f6,0x00000000}},	//   _дала_, ćije_, _caïm, --,
   {{0x78a70ba8,0xee3701c8,0x7e6d00e0,0xddc40395}},	//   _najv, ьня_, _edap, _adiţ,
   {{0x6f0f07e5,0x7d0ec686,0x6d4d018e,0x00000000}},	//   bocc, robs, _etaa, --,
   {{0x7b3c0254,0x629b00e9,0x98b10260,0x7d0e021d}},	//   _očuv, neuo, _dizč_, sobs,
   {{0x2bba0864,0x78a70009,0x6aa60225,0xd7f80160}},	// [f380] _उपका, _bajv, _vakf, _ţă_,
   {{0xddc4002d,0x2716112b,0x6aa69036,0x78a70160}},	//   _ediţ, तत्र_, _wakf, _cajv,
   {{0x6aa60523,0x28c402b4,0x00000000,0x00000000}},	//   _takf, लॉगि, --, --,
   {{0xe61a2661,0x39860132,0xdb0500ac,0x00000000}},	//   оде_, pôs_, _trhá, --,
   {{0x83fc00cd,0x00000000,0x00000000,0x00000000}},	//   _međe, --, --, --,
   {{0xb4d8135e,0x6282c687,0xa53301e0,0x00000000}},	//   ासे_, _scoo, вніч, --,
   {{0x779103c5,0x00000000,0x00000000,0x00000000}},	//   _میلا, --, --, --,
   {{0x83fc02c4,0x291ac688,0x416a0274,0x00000000}},	//   _neđe, llpa_, ојом_, --,
   {{0xcb130122,0x05ba0037,0x60ca009e,0xc4860200}},	//   כלה_, _بدأت_, _pofm, _олак,
   {{0xba3b0176,0x7b130055,0x00000000,0x00000000}},	//   _raïm, nçur, --, --,
   {{0x6d4dc689,0xdce4024e,0x6f0f4c55,0xb286004b}},	//   _staa, _cvič, tocc, _жылк,
   {{0x25a46cf9,0x00000000,0x00000000,0x00000000}},	//   _ksml_, --, --, --,
   {{0x6f0fc68a,0xdce400d5,0xbcfb000d,0x0cab0f8c}},	//   rocc, _evič, ssém, отви_,
   {{0x6f0f0382,0x00000000,0x00000000,0x00000000}},	//   socc, --, --, --,
   {{0xbbc9000c,0x6d34036c,0x6f0f0a11,0x1fa3010b}},	//   रहेक, терф, pocc, _арыг,
   {{0x5fcb0026,0x7e6d0027,0x6d4d018e,0x3e8800fd}},	//   ाहरल, _udap, _ttaa, rító_,
   {{0xeabf0019,0x3e88006c,0x6d4d002f,0xb5fd0e31}},	// [f390] _chùa_, sító_, _utaa, _keše,
   {{0x3ea903c4,0xb4d80066,0xa3c000be,0xb5fd023a}},	//   _haat_, ासो_, ुहा_, _ješe,
   {{0x6d402fb4,0x8c4403e6,0x656900fe,0xb5fd080a}},	//   ímav, _шеќе, _sveh, _meše,
   {{0x332600e2,0x501b00a5,0x0e9c016b,0x00000000}},	//   _nhox_, חובו, ַשול, --,
   {{0x78a7282f,0x3ea95629,0x7bd528ce,0x00000000}},	//   _tajv, _maat_, lyzu, --,
   {{0x3ea9019c,0xf77313cf,0xa3ab0d2b,0x7d020079}},	//   _laat_, _لار_, खिल_, _íost,
   {{0x29030024,0xe78400af,0x00000000,0x00000000}},	//   _ijja_, _иуто, --, --,
   {{0x3ea90260,0x515500af,0x00000000,0x00000000}},	//   _naat_, нтоу, --, --,
   {{0x7afa064b,0xddc400a0,0x629b00e9,0xb5fd0168}},	//   étti, _odiš, reuo, _beše,
   {{0x629b001e,0x62800051,0x00000000,0x00000000}},	//   seuo, agmo, --, --,
   {{0x3255022b,0x81e70083,0x3ea90b0d,0x929d0067}},	//   _звер, _মুখ_, _baat_, wołu,
   {{0x7ce20b88,0xe0bf0033,0x00000000,0x00000000}},	//   _môre, ইসেন, --, --,
   {{0x5d6700c3,0xd0d53367,0x2903018e,0x00000000}},	//   ниям_, _подъ, _ojja_, --,
   {{0x332d0453,0x00000000,0x00000000,0x00000000}},	//   lmex_, --, --, --,
   {{0x69cb1193,0xab2a6355,0x00000000,0x00000000}},	//   ägen, зова_, --, --,
   {{0x3ea904ce,0x29030273,0x2fd8035b,0xfaa35446}},	//   _gaat_, _ajja_, ørge_, ласо,
   {{0xc33202da,0xa2c00e6f,0x8c4619f0,0xa926095d}},	// [f3a0] רון_, वात्, _пепе, едал,
   {{0x6e24007b,0x7d570070,0x7e666259,0x2ee00069}},	//   _izib, _רייד_, lakp, _hlif_,
   {{0x7c3e011e,0x3ea9073a,0xb908170c,0x00000000}},	//   _igpr, _yaat_, _बत_, --,
   {{0xb4d800b4,0x7e66c68b,0x2903736e,0x00000000}},	//   ास्_, nakp, _ejja_, --,
   {{0x7ae452f1,0xb5fd0207,0x00000000,0x00000000}},	//   mhit, _odšu, --, --,
   {{0xdb0501ae,0x7ce200f6,0x6e24034d,0x00000000}},	//   _erhä, _fôre, _mzib, --,
   {{0xb5fd1848,0x969600c9,0x2f19006c,0x66e600cf}},	//   _reše, _праш, ségi_, _зова,
   {{0xaae00b54,0x6b83013c,0xa2c0022e,0x31c61d32}},	//   नसिक, _ånge, वाध्, есов,
   {{0x7e660ec0,0x343a27f6,0x3ea90345,0xb5fd19f6}},	//   dakp, _فساد_, _raat_, _peše,
   {{0x3ea9c68c,0x2ee00809,0x6f160168,0xbcfb00b5}},	//   _saat_, _alif_, _akyc, rsék,
   {{0xa2c00253,0x20180093,0x6e241642,0x32e400e2}},	//   वाद्, æri_, _azib, _đườ,
   {{0x753a0291,0x39420009,0x7e660159,0x7ae408b7}},	//   _hitz, _ouks_, gakp, jhit,
   {{0x7ae4c68d,0xc2e9004f,0xed5800d8,0x753a4cda}},	//   dhit, _تعلم_, ноў_, _kitz,
   {{0x3ea912ba,0x2ee00225,0x6ef60009,0x7ae400be}},	//   _waat_, _elif_, ršba, ehit,
   {{0x3ea93d1c,0x6e24018e,0xbcfb0079,0x6fe600f7}},	//   _taat_, _ezib, nséi, _décé,
   {{0x3da70131,0x753a06a2,0x7cd800d0,0x7ae4c68e}},	//   _зроб, _litz, _ağrı, ghit,
   {{0x5a3507c1,0xfc3000b5,0x443e0176,0x6e24023a}},	// [f3b0] тнат, لحہ_, _ogt_, _gzib,
   {{0x6f1dc68f,0x2bba0d53,0x394f0029,0x443e01ff}},	//   llsc, _उपचा, īgs_, _ngt_,
   {{0x7ae4026e,0x00000000,0x00000000,0x00000000}},	//   bhit, --, --, --,
   {{0xb5fd10a5,0x443ec690,0x753a06a2,0x7ae4c691}},	//   _odšt, _agt_, _aitz, chit,
   {{0x35a502c4,0x443e00e0,0xe5a52a0b,0x6f1d5c32}},	//   талг, _bgt_, тили, ilsc,
   {{0x443e2ddc,0xdb1c008a,0x6f1d033b,0x798d038f}},	//   _cgt_, lyrð, hlsc, mtaw,
   {{0xc1c900b8,0x753a06a2,0xdb0501ff,0x798d3184}},	//   ाङ्ग, _ditz, _erhå, ltaw,
   {{0x6aadc692,0x443ec693,0x753a1908,0x00000000}},	//   ndaf, _egt_, _eitz, --,
   {{0x26dc00ea,0x91e50b61,0x98aa005f,0x236000f4}},	//   īvot_, топе, _aibę_, ćija_,
   {{0x7659001e,0x6f1dc694,0x248502d7,0x443e005f}},	//   lbwy, elsc, _uclm_, _ggt_,
   {{0xe00b00c4,0xdee675af,0x6729006d,0x7e662aaf}},	//   _सुखद_, вони, _khej, takp,
   {{0x92eb00d2,0x753a06a2,0x7d0501f2,0x798dc695}},	//   _عراق_, _zitz, _ajhs, ktaw,
   {{0x753a012f,0x09d60083,0x798d006d,0x6aadc696}},	//   _yitz, _সেনা, jtaw, ddaf,
   {{0x6abd0bf7,0x6aad0223,0x661b0b13,0x66090024}},	//   _ansf, edaf, _myuk, _mxek,
   {{0x7ae4c697,0x2d9e024e,0x2913c698,0x61e9c699}},	//   thit, ňte_, doxa_, lzel,
   {{0x69c406a2,0x6f04022e,0x67290069,0x660903d0}},	//   txie, _ujic, _nhej, _oxek,
   {{0x61e9c69a,0xf2d202b5,0x7ae4c69b,0x661b0245}},	// [f3c0] nzel, בען_, rhit, _nyuk,
   {{0x7d7b0bed,0x7ae4255e,0x6abd0b3e,0xbebb01e9}},	//   _קניו, shit, _ensf, smët,
   {{0x5895005f,0x7ae48c80,0xcc770122,0x753ac69c}},	//   ышту, phit, _בעיה_, _ritz,
   {{0x753a02c9,0x798d006d,0xcf920070,0x6d44002f}},	//   _sitz, btaw, שטא_, _kuia,
   {{0xa2c000c0,0x673b0ce8,0x753ac69d,0x7afa0093}},	//   वास्, _diuj, _pitz, éttu,
   {{0xd90d0332,0x7e64c69e,0x61e9c69f,0x6d44c6a0}},	//   _ٹیم_, _leip, dzel, _muia,
   {{0x6609bc1c,0x61e90223,0x443e0023,0x6d440345}},	//   _exek, ezel, _vgt_, _luia,
   {{0xbcfb0312,0x753a033b,0xbebb01f4,0x67290069}},	//   rséi, _witz, hmër, _ghej,
   {{0x7f430083,0xbcfb021d,0x443e3f07,0x7ae300af}},	//   _aunq, sséi, _tgt_, _înte,
   {{0x6729c6a1,0x443ec6a2,0x753a0a75,0xa2c00066}},	//   _zhej, _ugt_, _uitz, वाह्,
   {{0x04435562,0x61e9a9da,0x7f43002a,0x03a300d4}},	//   _техн, azel, _cunq, _вихо,
   {{0x7f4302fb,0x7e6401f7,0x733615f4,0xeabf00f1}},	//   _dunq, _ceip, _شرائ, _chùl_,
   {{0x291830bc,0x6d440279,0x61e90035,0xdc3100ac}},	//   _okra_, _cuia, czel, _výči,
   {{0x09d60083,0x6fb40789,0x40a80609,0x98b10139}},	//   _সেভা, _ممتا, _سختی_, _miză_,
   {{0xb5fd02f0,0xac188468,0xa3ab0a5e,0x6d440176}},	//   _meša, вору_, खिए_, _euia,
   {{0x798dc6a3,0x386301b4,0x6d44009e,0xbebb0055}},	//   ttaw, _sejr_, _fuia, rmës,
   {{0x6d44377e,0x6aadc6a4,0xd5a400b5,0xef1f0448}},	// [f3d0] _guia, rdaf, _بہ_, mlü_,
   {{0x798dc6a5,0x661b022e,0x672901f4,0xef1f00d0}},	//   rtaw, _ryuk, _shej, llü_,
   {{0x798dc6a6,0x06750c0d,0x61e9c6a7,0x661b06d4}},	//   staw, гуля, zzel, _syuk,
   {{0xcf9302b5,0xf7700a72,0x2918009e,0x7c3800d5}},	//   יטע_, زام_, _ekra_, _úvra,
   {{0x442502d0,0x83fc0c99,0x356b0de2,0xa4d500d4}},	//   _szl_, _ređa, френ_, лоді,
   {{0xd0060082,0x2a690430,0x05740037,0x61e9008b}},	//   _هل_, laab_, شاهد, vzel,
   {{0xb5fd0f44,0xf4849cb4,0x6729c11d,0xef1f00c1}},	//   _deša, ручн, _thej, klü_,
   {{0x61e94bcb,0xd185392c,0x66093089,0x67290027}},	//   tzel, глий, _txek, _uhej,
   {{0x7f43718b,0x61e95f44,0x7e64c6a8,0xb5fd00ee}},	//   _sunq, uzel, _reip, _feša,
   {{0x61e9c6a9,0x7e64c34a,0x2a69c6aa,0x6ee601ef}},	//   rzel, _seip, haab_, _móbe,
   {{0x6441011e,0x61e9c6ab,0x7e641e7b,0xa2c00ed1}},	//   _igli, szel, _peip, वाश्,
   {{0x61e900b5,0x6d4400be,0x2a69023c,0x00000000}},	//   pzel, _puia, jaab_, --,
   {{0xa2c006bc,0xeabf367a,0xa3ab00dc,0xcdf61ac5}},	//   वार्, _chùm_, खिक_, учны,
   {{0x717200d1,0x9d4343f0,0x00000000,0x00000000}},	//   _اهوا, серд, --, --,
   {{0x3bd50086,0x75ea006c,0x64410ed3,0x7e64c6ac}},	//   аютс, _közé, _mgli, _teip,
   {{0xe7f92218,0x6d44c6ad,0x224dc6ae,0xef1f0095}},	//   ्पना_, _tuia, ncek_, clü_,
   {{0xf2d202b5,0x316dc6af,0x6441145f,0x6b9b002d}},	// [f3e0] זען_, nsez_, _ogli, ăuga,
   {{0x644100d1,0xbd5b00a5,0x2d82c6b0,0x316d00a2}},	//   _ngli, _רכיש, muke_, isez_,
   {{0xb5fd0200,0x2d820521,0x2a692206,0x3cf90066}},	//   _reša, luke_, baab_, _उगते_,
   {{0x76a900d4,0x5b7b0070,0xeabf009e,0xdd8f00f8}},	//   ктів_, _ארטא, _gnù_, _بوی_,
   {{0xb5fd0274,0x2d82c6b1,0xbcfb000d,0x00000000}},	//   _peša, nuke_, rsév, --,
   {{0x291e006c,0x64410176,0xef1f0448,0xd76600b5}},	//   _óta_, _cgli, zlü_, _مارٹ,
   {{0xb5fd0df4,0x2d82c6b2,0x6ee601ef,0xd377010b}},	//   _veša, huke_, _zóbe, гчы_,
   {{0xe73707be,0x6441c6b3,0xae040127,0xd2570043}},	//   _бес_, _egli, रपान_, лць_,
   {{0xb5fd0009,0x3ea201e4,0x638a0132,0xf50a0421}},	//   _teša, dekt_, _bênç, _знал_,
   {{0xc7af0332,0x00000000,0x00000000,0x00000000}},	//   _بڑے_, --, --, --,
   {{0x3ea28873,0xba3bc6b4,0xc91700a5,0x66da00f6}},	//   fekt_, _haït, רחית_, _aïki,
   {{0x51863471,0x78ae0228,0x753d00b5,0x6ad3198f}},	//   _бука, _labv, _észr, _सवेर,
   {{0xef1f01d6,0x2d825c03,0xb5fd068f,0x00000000}},	//   rlü_, guke_, _lešn, --,
   {{0x40340009,0x1fa63b8b,0xa3e1022e,0x3ead00b8}},	//   _келс, _бриг, नैव_, žet_,
   {{0xe8140cc5,0x2a69c6b5,0x6ee601ef,0xef1f0381}},	//   _तुला_, taab_, _sóbe, plü_,
   {{0x2d82c6b6,0x4a5562a2,0x00000000,0x00000000}},	//   buke_, ркас, --, --,
   {{0xe9750037,0x2d8241a6,0x00000000,0x00000000}},	// [f3f0] شهاد, cuke_, --, --,
   {{0x270d0785,0x940a00a8,0x5a3418e2,0x00000000}},	//   िक्र_, şmən_, снут, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8aa77275,0x35b50ae1,0x64410176,0xb5fd6893}},	//   _срод, ибер, _sgli, _dešn,
   {{0x298b4a2f,0x7cf40095,0x3949003c,0x442300d5}},	//   _ясно_, _sürə, qqas_, _šj_,
   {{0x2ee209a8,0x81d30033,0x00000000,0x00000000}},	//   _पत्त, _হইল_, --, --,
   {{0x2d82c6b7,0x3ea2013b,0x67d50210,0x00000000}},	//   zuke_, yekt_, _тову, --,
   {{0xc2452ec7,0x316d01a3,0xe3b00286,0x41b5104b}},	//   шник, tsez_, ثره_, لمعر,
   {{0x6aafc6b8,0xa4870ad9,0x00e5002d,0x398fc6b9}},	//   _macf, _مجان, ижин, nüs_,
   {{0xe0d9798e,0x2ede145a,0xd12e0fab,0x6441a1be}},	//   тво_, मस्त, ومي_, _ugli,
   {{0x316d02e1,0x037800b5,0xd00942f1,0x62750037}},	//   ssez_, _محنت_, тене_, _نهائ,
   {{0x2d82c6ba,0x6126008a,0x63bc0093,0x799d0b88}},	//   tuke_, rðla, _árna, _opsw,
   {{0x3ea2c6bb,0xb5fd0200,0xba3b0223,0xa1584747}},	//   rekt_, _mešo, _maïs, _бачу_,
   {{0xed573e62,0x2d82c6bc,0x28c906bc,0x3ea20044}},	//   рор_, ruke_, राफि, sekt_,
   {{0x3ea2c6bd,0xfaf60823,0x8e760036,0x00000000}},	//   pekt_, ачаю, _купч, --,
   {{0x80da0083,0xb5fd04d9,0x2d82bb0a,0x00000000}},	//   যোদ্, _nešo, puke_, --,

   {{0xe9d7c6be,0x78660948,0x44320023,0xa96a1403}},	// [f400] акт_, иказ, ̀y_, тиза_,
   {{0x6d560027,0x97b600af,0x98b80107,0xab66010b}},	//   _itya, исеш, _tirč_, _квол,
   {{0x6299c6bf,0x6c7b0070,0x5ea90033,0x07a67105}},	//   _obwo, _בריד, গারে, раен,
   {{0xa3a80066,0x5a962d7a,0x398f027d,0x7ce20168}},	//   खौफ_, _троф, büs_, _kôro,
   {{0x7ceb02c9,0x6aa4023c,0x7ae30395,0x00000000}},	//   _dürf, meif, _înta, --,
   {{0x6aa4c6c0,0x62990103,0xb5fd00f4,0x00000000}},	//   leif, _abwo, _tešn, --,
   {{0x2727007c,0xbddb00f7,0x00000000,0x00000000}},	//   sõna_, ncèr, --, --,
   {{0xbcfb01dd,0xa31000c0,0x6d562387,0x00000000}},	//   nsér, ावेज_, _otya, --,
   {{0xc05a256a,0x6d563729,0x64c60088,0x00000000}},	//   кін_, _ntya, _پيال, --,
   {{0x0cc100c8,0x67224b4a,0x62990359,0xba3b0298}},	//   _উত্ত, lloj, _ebwo, _kaïr,
   {{0x92e40033,0x6722c6c1,0x6d56c6c2,0x79840345}},	//   _নদী_, oloj, _atya, huiw,
   {{0x79840b88,0x00000000,0x00000000,0x00000000}},	//   kuiw, --, --, --,
   {{0xf8c908b0,0x2369044d,0x7cebc6c3,0x28c9364c}},	//   रामय, ćaje_, _jürg, रामि,
   {{0x7ceb00be,0x91bb00a5,0x22620067,0x79840298}},	//   _mürg, _שמגי, ńską_, duiw,
   {{0x7f84004f,0x6d561187,0x67221406,0x212b000d}},	//   _العن, _etya, kloj, îche_,
   {{0xdced02c4,0xb5fd012e,0x28c90b35,0x93bc0103}},	//   _ivač, _bešl, राभि, _kyăb,
   {{0x5fae0026,0x09cd0033,0x00000000,0x00000000}},	// [f410] टिकल, _রেজা, --, --,
   {{0x261a0953,0x63ba2ea7,0x398f0225,0x00000000}},	//   _बड़ी_, _ortn, rüs_, --,
   {{0xba3b12c3,0xf773004f,0x00000000,0x00000000}},	//   _païs, تاذ_, --, --,
   {{0x7ceb01ae,0xdc5600fd,0xba190037,0x67220415}},	//   _bürg, _پریک, _ميجا_, gloj,
   {{0x39460079,0x00000000,0x00000000,0x00000000}},	//   íost_, --, --, --,
   {{0xb4e10035,0xdced0009,0x64a521c3,0x7ceb02b1}},	//   दसे_, _ovač, сака, _würf,
   {{0xbcfb0248,0xe29900d8,0xdb17002a,0x28f80fa7}},	//   nséq, гай_, _arxé, _терь_,
   {{0x7ceb3a5b,0x00000000,0x00000000,0x00000000}},	//   _hürd, --, --, --,
   {{0x7ceb0644,0xeabf00e2,0x00000000,0x00000000}},	//   _kürd, _chùi_, --, --,
   {{0x70c903fa,0x25ad00e9,0xdce400f4,0x00000000}},	//   угог_, _isel_, _ivić, --,
   {{0x7984002f,0x00000000,0x00000000,0x00000000}},	//   zuiw, --, --, --,
   {{0xed5a4cc1,0x62990232,0x67170518,0x7ce201ba}},	//   лом_, _ubwo, तविक_, _pôro,
   {{0x6d4b02e1,0x225f10cd,0xddd400a0,0x93bc0103}},	//   _égal, mbuk_, ťažn, _gyăb,
   {{0x7bdc8493,0xa0690370,0x6289c6c4,0x6aa4033b}},	//   tyru, _сака_, lgeo, weif,
   {{0xcb0316d3,0xf99f0107,0x4b260037,0x6aa402b1}},	//   रचंड_, _apè_, معرف, teif,
   {{0x612f2b6f,0x9e66c6c5,0x4a4600d8,0xdce402c4}},	//   følg, _увид, снав, _ović,
   {{0x3f8501a8,0xc33202b8,0x6aa4c6c6,0x6d560027}},	// [f420] lulu_, לול_, reif, _utya,
   {{0xb4e60084,0x2caa1d07,0xac861b48,0xbcfb4a22}},	//   _पते_, _скоп_, _угол, ssér,
   {{0x6b9e1c3e,0xb900035d,0xdb150097,0x7cebc6c7}},	//   _uppg, _तव_, žbác, _sürg,
   {{0x7ceb00be,0x649106fe,0x00000000,0x00000000}},	//   _pürg, _lžič, --, --,
   {{0x3f855443,0x60c30037,0x7ceb00b5,0xdce40124}},	//   hulu_, _onnm, _fürd, _cvić,
   {{0x3f85c6c8,0x672297bc,0x28c922c7,0x317f0009}},	//   kulu_, sloj, राणि, druz_,
   {{0xdce40009,0x25ad058d,0x00000000,0x00000000}},	//   _ević, _esel_, --, --,
   {{0xa3c90953,0x63baa561,0x68fe02b3,0x3f85c6c9}},	//   _ऊपर_, _vrtn, lipd, dulu_,
   {{0xdced5334,0xb5fd02c4,0xddcd012e,0xfc460187}},	//   _svač, _lešj, _odaš, _čína_,
   {{0x291aa50e,0x7ceb027d,0x3f85030d,0x6f74195c}},	//   nopa_, _küre, fulu_, огоф,
   {{0x3f8501a8,0x28c90a64,0x8f35271c,0x3eb2258c}},	//   gulu_, राति, женц, _bayt_,
   {{0x291a017b,0x59c8142a,0xceeb1902,0x60c30260}},	//   hopa_, रमार, اردن_, _ennm,
   {{0x317f3641,0x291ab509,0x442c00ee,0x00000000}},	//   cruz_, kopa_, _hzd_, --,
   {{0xa2c001d1,0x3f85c6ca,0x80e20033,0xa2d437e8}},	//   वाक्, bulu_, _পদক্, यॉर्,
   {{0x2bc80c00,0xe0fb00a5,0x3f850a21,0x442c007e}},	//   буто_, _גלגל, culu_, _jzd_,
   {{0x7ceb00d0,0xda090088,0x00000000,0x00000000}},	//   _sürd, ليزه_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [f430] --, --, --, --,
   {{0x6e2dc6cb,0x28c90433,0x291a0860,0xfc4700b8}},	//   _izab, राधि, gopa_, číst_,
   {{0xf7702087,0x7ae30043,0x442c0139,0xdce4022f}},	//   فان_, _înto, _nzd_, _svić,
   {{0x7cebc6cc,0x25ad0009,0xdb1f00c3,0x255900af}},	//   _würd, _psel_, äväk, аркэ_,
   {{0x28c9021a,0xb5fd01c8,0x3f85c6cd,0x7aedc6ce}},	//   रादि, _iešk, zulu_, mhat,
   {{0x7aed0332,0x317f3833,0x87e74e4f,0x6e2d08c7}},	//   lhat, vruz_, _любе, _mzab,
   {{0x2ee9c6cf,0x6f0d0a66,0xb5fd00d5,0x442c023a}},	//   _olaf_, _ojac, _kešk, _czd_,
   {{0xa2c00761,0x39430223,0x7aed3993,0x442cc6d0}},	//   वाग्, _hijs_, nhat, _dzd_,
   {{0x225f0ec0,0x6e2d035a,0xe5c705c2,0xb5fd2a17}},	//   rbuk_, _nzab, _усво, _mešk,
   {{0x3f85c6d1,0x3eb20095,0x2ee91051,0x7ceb027d}},	//   tulu_, _sayt_, _alaf_, _yüre,
   {{0x7aedc6d2,0x1eca0ca6,0x6e2d0010,0x32552374}},	//   khat, ални_, _azab, _двер,
   {{0x7d1e00b9,0xf77202b5,0x3f85027d,0x823400d1}},	//   _skps, וקט_, rulu_, _کرما,
   {{0x7aedc6d3,0x3f85c6d4,0x21691b52,0x6f0d0207}},	//   dhat, sulu_, _тили_, _djac,
   {{0x39430223,0x3f85c6d5,0x6f0dc6d6,0x6491042a}},	//   _nijs_, pulu_, _ejac, _užič,
   {{0x8c4308ce,0x6e2d3483,0x7fd50823,0x7ce207c0}},	//   дере, _ezab, _філі, _hôrk,
   {{0x7aedc6d7,0x394b01f7,0x0d8600c3,0xb4e6198f}},	//   ghat, _bucs_, _длин, _पत्_,
   {{0xe8fa1279,0x7ceb0723,0x394b01f7,0xb5fd0207}},	// [f440] ала_, _süre, _cucs_, _dešk,
   {{0xe8c7010b,0x2d820009,0xed590355,0x6e242c53}},	//   огул_, mrke_, íže_, _iyib,
   {{0x7d1c7949,0x68fe00d7,0xab2a02ce,0x7aedc6d8}},	//   mors, ripd, _вона_, bhat,
   {{0x7d1c00fd,0xe5c600c3,0x68fe00cd,0x442c0168}},	//   lors, жско, sipd, _rzd_,
   {{0x7ae4c6d9,0x95530088,0x00000000,0x00000000}},	//   mkit, وخوا, --, --,
   {{0xd37a292e,0x7cebc6da,0x7ae4c6db,0x7d1c00d4}},	//   ачи_, _türe, lkit, nors,
   {{0x248001d6,0x7ae4c6dc,0x80cd00b4,0x80b20831}},	//   ğim_, okit, ताने, জাম্,
   {{0x24800723,0x7ae445d7,0x6ab60090,0x6843010b}},	//   şim_, nkit, ndyf, _інта,
   {{0x7ae401d7,0x83fc025c,0x7d1cc6dd,0x23690a78}},	//   ikit, _međi, kors, ćaja_,
   {{0x83fc044d,0x7aed006c,0x7cf00523,0x7ae4c6de}},	//   _leđi, zhat, _härf, hkit,
   {{0x6e2d0332,0x6f0d00e6,0x6448011e,0x7ae400c3}},	//   _szab, _pjac, _igdi, kkit,
   {{0x7996004e,0x6e240010,0x2246010d,0xbcfb000d}},	//   ktyw, _byib, _ugok_, ipée,
   {{0x7d1c1e54,0x6e2404fb,0x69c007e7,0xb5fd023a}},	//   fors, _cyib, _šmen, _rešk,
   {{0x7d1c7fd8,0x394b3f5a,0x61ec10b1,0x96c1021a}},	//   gors, _rucs_, ıllı, _रोनॉ,
   {{0x7aedc6df,0x2d82023a,0x394baeb3,0x00000000}},	//   that, arke_, _sucs_, --,
   {{0xb6060c21,0x7ae418ad,0x3da7c6e0,0x6d5d47a5}},	//   _kršć, gkit, _дроб, ppsa,
   {{0x7aedc6e1,0xb5fd00b8,0x6f1dc6e2,0x6e2d0010}},	// [f450] rhat, _vešk, mosc, _uzab,
   {{0x7aedaa62,0x7d1c02fb,0xa2a10785,0x80cd00b4}},	//   shat, cors, _कॉन्, ताये,
   {{0xb5fd01cc,0x7aedc6e3,0x7e6d00d7,0x6d450430}},	//   _tešk, phat, _keap, _iiha,
   {{0x6f1dc6e4,0x6d45c6e5,0x28c9046c,0x7ceb02b1}},	//   nosc, _hiha, राहि, _fürc,
   {{0x6d45c6e6,0x7cf0022a,0x7ceb01c2,0x63a1024e}},	//   _kiha, _därf, _gürc, _spln,
   {{0x6d45c6e7,0x7e6dc6e8,0x6f1da503,0xdfc60037}},	//   _jiha, _leap, hosc, _كي_,
   {{0x6d45c6e9,0x0442bef0,0x2901c6ea,0x6d4d073a}},	//   _miha, нешн, miha_, _luaa,
   {{0x6d45247e,0x2901c6eb,0x7e6dc6ec,0x6595c6ed}},	//   _liha, liha_, _neap, _набу,
   {{0x7d1c0723,0x44450332,0x6d4501d7,0x6d4d02a2}},	//   yors, _فراہ, _oiha, _nuaa,
   {{0x6d45c6ee,0xb5fd010b,0x7ae401a3,0x6ee601ef}},	//   _niha, _neši, zkit, _póbo,
   {{0x7d1cc6ef,0x7ae401c8,0x63a10187,0xef1a3efc}},	//   vors, ykit, _upln, ймо_,
   {{0x7e6dc6f0,0x6f1d38a9,0x65690103,0x6d4501ed}},	//   _ceap, gosc, _kweh, _aiha,
   {{0x7cf00006,0x6d45c6f1,0x29010027,0xb5fd080a}},	//   _järg, _biha, kiha_, _beši,
   {{0x7afdc6f2,0xeab20332,0x78b5011c,0x6d45008f}},	//   _amst, کٹر_, _nazv, _ciha,
   {{0x6d45c6f3,0x7d1c0332,0xb5fd00d8,0xa2c000a1}},	//   _diha, rors, _deši, वाच्,
   {{0x7d1cc6f4,0x68fc0881,0x6f1d027a,0x399400c3}},	//   sors, _smrd, cosc, täs_,
   {{0x7ae4c6f5,0x6d45b997,0xbebb0031,0xa2b30096}},	// [f460] rkit, _fiha, ymëz, _आसन्,
   {{0x7ae4c6f6,0x23bd035d,0x6d45c6f7,0x290102b3}},	//   skit, ्माद, _giha, giha_,
   {{0x2d8f013c,0x69cb3308,0x31a80066,0x25bf0118}},	//   _äger_, äger, _कन्ध, _arul_,
   {{0xd9460603,0xe7372235,0x6d455c03,0xd1381640}},	//   _неми, пех_, _ziha, zmą_,
   {{0x2901c6f8,0x3ea0345d,0x6d4501d5,0xd138010b}},	//   biha_, _mbit_, _yiha, ymą_,
   {{0x4425000c,0xbcfb000d,0x7ce20168,0x78b502a7}},	//   _byl_, ppée, _bôri, _gazv,
   {{0xdc3602b5,0x07a36a2d,0xdcb100e2,0x929d0067}},	//   האַט_, _парн, ổi_, ziłe,
   {{0x7ceb7a36,0x7cf0c6f9,0x78b50506,0x7649073a}},	//   _müra, _färg, _zazv, _ggey,
   {{0x6f1d02a7,0x7cf0018d,0x44250225,0x00000000}},	//   vosc, _kärd, _eyl_, --,
   {{0x60f802ce,0x3ea0c6fa,0xa2c00355,0x201900a8}},	//   іння_, _abit_, वाङ्, əsiz_,
   {{0xd13875e6,0xb5fda14f,0x69c00009,0x987e0069}},	//   rmą_, _reši, _šmel, _eħħi_,
   {{0x6d45c6fb,0x7cf001ff,0xd13800c7,0x3dc0099e}},	//   _siha, _lärd, smą_, _briw_,
   {{0x6d45c6fc,0x290104fb,0xb5fdc6fd,0x442503bc}},	//   _piha, yiha_, _peši, _zyl_,
   {{0xd12f02ce,0x31570bed,0x317b0100,0x7afd00d7}},	//   _їх_, _ציון_, _פרומ, _smst,
   {{0x78b502dd,0x50b7004f,0x6d45c6fe,0x7e6d94b3}},	//   _razv, _ردود_, _viha, _teap,
   {{0x7c25114d,0x78b56a22,0x25a4c6ff,0x2d9fc700}},	//   _vyhr, _sazv, _opml_, çues_,
   {{0x6d45c701,0xdb24006c,0xb5fdc702,0xf8c910aa}},	// [f470] _tiha, írás, _teši, रालय,
   {{0x3eab0122,0x63ad0035,0xb5fd0009,0x5fb001c0}},	//   lect_, łani, _ueši, _जनाल,
   {{0x2d8bc703,0x2901c704,0x5eb00033,0x569500c3}},	//   luce_, riha_, টারে, дает,
   {{0x2901c705,0x7afd01ae,0x3eb9054e,0x65690159}},	//   siha_, _umst, ndst_, _pweh,
   {{0x83fc0537,0xe81d0299,0x7cf0013c,0x2d99c706}},	//   _među, _बुरा_, _färd, ntse_,
   {{0xeabf01a6,0x942500af,0x2d99c707,0x4425c708}},	//   _thùs_, ммле, itse_, _pyl_,
   {{0xe7840274,0x00000000,0x00000000,0x00000000}},	//   _путо, --, --, --,
   {{0x3eab0b93,0x2d8ba7e7,0x2d9900be,0xdced0228}},	//   ject_, kuce_, ktse_, _apaļ,
   {{0x2d8bc709,0x6ed100b4,0x7cf0038e,0x4425229a}},	//   juce_, धानु, _häre, _wyl_,
   {{0x2d8b1116,0xddc400d8,0x60090267,0x7cf006c7}},	//   duce_, _neiš, жном_, _käre,
   {{0x7cf00006,0x9eaa14a1,0x2735022a,0x3eabc70a}},	//   _järe, овна_, gång_, fect_,
   {{0x441a02b5,0x141a0070,0xa2e401e0,0x7cf0081b}},	//   _וועס, _וועב, _поєд, _märe,
   {{0x2d8b003a,0x80cd00b8,0xddc4005f,0x7ceb0225}},	//   guce_, तादे, _beiš, _süra,
   {{0xc1720122,0xfaff0055,0x00000000,0x00000000}},	//   _יחד_, _amë_, --, --,
   {{0x9d430aec,0xe81d0084,0x2d99c70b,0x2ca1009e}},	//   терд, _बुला_, atse_, _dbhd_,
   {{0x3ea028da,0x41d100a1,0x2d8bc70c,0x91d106d9}},	//   _ubit_, _तपास, buce_, _तपाई,
   {{0x39463da5,0x7984002f,0x09c8012f,0x00000000}},	// [f480] днаг, uriw, रमेय, --,
   {{0x49990086,0xcc8a00f8,0x7cf08bfb,0xddc47384}},	//   ятся_, _بنده_, _bäre, _geiš,
   {{0x09d60083,0x7cf0022a,0x00000000,0x00000000}},	//   _সেখা, _värd, --, --,
   {{0xc6a37a25,0x7cf0022a,0x6fb0043b,0x2d5400be}},	//   врши, _däre, _जनसं, _käe_,
   {{0x24580804,0xbcfb01ef,0xeabf009e,0x00000000}},	//   паль_, lpéa, _thùr_, --,
   {{0x7cf00523,0x2d54018d,0x41d106fe,0x00000000}},	//   _härb, _mäe_, तमनस, --,
   {{0x96961676,0x3eab02d7,0x7cf000be,0x938a010b}},	//   _ораш, yect_, _kärb, іска_,
   {{0x7ceb01ae,0x27e710db,0xc6c33367,0x00000000}},	//   _nürn, ønne_, _ийск, --,
   {{0xd0860043,0x2d54c70d,0x69c000ac,0xb5fd0207}},	//   мыни, _näe_, _šmej, _bešu,
   {{0xf65100f5,0x1604210a,0x54361d05,0x6adb02e4}},	//   _لئے_, _शेयर_, _قرار, _यक्र,
   {{0x645a8740,0xddc400d8,0x3eabc70e,0xb4aa00b4}},	//   _ifti, _reiš, tect_, गजी_,
   {{0x2d8bc70f,0x518601f1,0x7cf01890,0x00000000}},	//   tuce_, _жука, _närb, --,
   {{0x3eabc710,0x8008006c,0x80da0033,0x7ae300af}},	//   rect_, ترکہ_, যোগ্, _înti,
   {{0x28d20084,0x2d991b37,0x273501ff,0x3eab0147}},	//   साफि, rtse_, pång_, sect_,
   {{0x2d8b020b,0x7cf00301,0x3eabc44e,0x5c04010b}},	//   suce_, _bärb, pect_, вята,
   {{0x3f8cc711,0x2d8b0c6f,0xa2a1022e,0x00000000}},	//   mudu_, puce_, क्प्, --,
   {{0xb5fd000c,0xa3b503e2,0x3f8c003c,0x44290023}},	// [f490] _ješt, _चैन_, ludu_, ́a_,
   {{0xc8c90e04,0xb5fdb09c,0xe6c70355,0x68ee009e}},	//   राइट, _mešt, रञ्ज, _clbd,
   {{0x3f8cb09c,0xb5fd0097,0x7cf002b1,0x613401f7}},	//   nudu_, _lešt, _färb, càle,
   {{0x645a617d,0x26c907a6,0xdc0300ac,0x7cf00421}},	//   _afti, ñao_, nčím, _väre,
   {{0xb5fd505f,0x7cf001ae,0xd7c900e0,0x00000000}},	//   _nešt, _wäre, _کوزه_, --,
   {{0x3f8c0034,0x98c40086,0x6aada999,0xdc3f00ac}},	//   kudu_, _иссл, leaf, _líči,
   {{0x273501ff,0xaa7b0093,0x09e40033,0x3f8c0cdf}},	//   tånd_, _flýt, _নেপা, judu_,
   {{0x645a064b,0xdb0501ae,0x09d60083,0xb5fd994a}},	//   _efti, _erhö, _সেটা, _bešt,
   {{0x31790332,0x6d5f009f,0x00000000,0x00000000}},	//   ész_, _ntqa, --, --,
   {{0x1f65737f,0xddc4233d,0x28d206bc,0x60ca0069}},	//   нком, _afiş, सायि, _cnfm,
   {{0x3f8c01d5,0x7cf0038e,0x5f06052a,0x00000000}},	//   gudu_, _lärc, езна, --,
   {{0xb5fd28da,0x327502b5,0xa3bc1a75,0xd356016b}},	//   _fešt, _װײַל_, इटर_, _טשעק_,
   {{0xc33201f3,0xfc460187,0x765b0027,0xf8d204aa}},	//   _עוד_, číme_, _mfuy, सामय,
   {{0x6ee601dd,0x61340443,0x3f8cc712,0x8b6600b5}},	//   _móbi, tàle, budu_, فارم,
   {{0xfaa63c0c,0x09c801d1,0x765b030d,0x00000000}},	//   наво, रम्य, _ofuy, --,
   {{0x6aad053e,0xbcfb0098,0x00000000,0x00000000}},	//   geaf, rpéa, --, --,
   {{0x271864db,0x08c61b50,0x00000000,0x00000000}},	// [f4a0] nčne_, нбан, --, --,
   {{0xee3701c8,0x3c660131,0xaa7b00d5,0x7ce2021d}},	//   _яны_, _яког, _blýs, _côrt,
   {{0xc6a61457,0xb89501d3,0xa6863efc,0x61f700a8}},	//   ерли, ъртъ, елед, _əxla,
   {{0x6b7b0122,0x00000000,0x00000000,0x00000000}},	//   _צרכנ, --, --, --,
   {{0x6ed1012f,0x86230eb1,0x00000000,0x00000000}},	//   धातु, льше, --, --,
   {{0xb4ea0084,0xb5fd016f,0xa3bc0066,0x00000000}},	//   मसे_, _rešt, इटल_, --,
   {{0xa3d40340,0xb5fd0116,0x779100fd,0x929d0067}},	//   тойч, _sešt, _نیلا, wiła,
   {{0xb5fd02c4,0xf743034b,0x3f8c0009,0x394aa0aa}},	//   _pešt, _бесо, vudu_, _hibs_,
   {{0x80c90033,0x6f06b548,0x00000000,0x00000000}},	//   াউন্, dikc, --, --,
   {{0xb5fdc713,0x67222bc1,0x55770070,0x00000000}},	//   _vešt, looj, _נעבן_, --,
   {{0xa0a30409,0x7ceb1505,0x612f0c71,0xa3ca046c}},	//   ушыл, _dürl, møll, _लपट_,
   {{0xb5fd0168,0x3f8cc714,0x929d0067,0x00000000}},	//   _tešt, rudu_, piła, --,
   {{0xc0e62294,0x3f8c9e68,0x00000000,0x00000000}},	//   _подк, sudu_, --, --,
   {{0x63a800d7,0x672201e8,0x7ceb1008,0x00000000}},	//   _kpdn, hooj, _gürl, --,
   {{0x672b03f4,0x80cd060a,0x00000000,0x00000000}},	//   ylgj, तारे, --, --,
   {{0xe7fa007c,0x7cf002b1,0x00000000,0x00000000}},	//   _एइजा_, _pärc, --, --,
   {{0xfeb800bf,0xdcf600a0,0x394a034d,0x6aad23e8}},	// [f4b0] _سايت_, _zvyč, _bibs_, reaf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0710ec,0x65600211,0xcc5600a5,0x00000000}},	//   mijs, _atmh, _בבתי_, --,
   {{0x7d07c715,0x39b20260,0x7ce20ddf,0xbebb0055}},	//   lijs, _fņs_, _fôrs, alëv,
   {{0x2a698fdd,0x7cf0017b,0x04b800b5,0xe7300079}},	//   mbab_, _hära, ڑپوں_, حصل_,
   {{0x7d0710ec,0x2a694519,0xf7730a86,0xf48403fa}},	//   nijs, lbab_, _مار_, гућн,
   {{0x29030031,0xc6a701ee,0x2b4b034d,0x947400f8}},	//   _imja_, _праи, _kicc_, ادها,
   {{0x7d07c716,0x63510029,0xd24e0079,0xb5fd004b}},	//   hijs, _jāni, ينى_, _dešr,
   {{0x7d076787,0x7cf0022a,0x6351013a,0x7ae30395}},	//   kijs, _lära, _māni, _întu,
   {{0xa2a11746,0xf994024b,0x00000000,0x00000000}},	//   _कॉर्, ארץ_, --, --,
   {{0x7d070888,0x7bc5006d,0x6f061047,0x12e700d4}},	//   dijs, _nrhu, tikc, _підг,
   {{0x752325b4,0x2cba0b88,0x3358002d,0x00000000}},	//   lonz, _sapd_, _чацэ_, --,
   {{0xdce403fd,0x7ceb01d6,0x7d07023a,0x3ebb0069}},	//   _sviđ, _türl, fijs, _daqt_,
   {{0x7d070bc6,0x7cf0017b,0x2b4b034d,0xda1c0387}},	//   gijs, _bära, _aicc_, _भुगत_,
   {{0xeb971c89,0xab2a3b99,0x394ac717,0x00000000}},	//   кир_, дова_, _ribs_, --,
   {{0x6a830210,0x7a380093,0x7bc501f7,0xb95b009e}},	//   илса, _nútí, _drhu, _crìo,
   {{0x7d07c718,0xee3a0133,0x6f04c719,0x7523c71a}},	// [f4c0] bijs, _юни_, _imic, konz,
   {{0xb95b00e8,0x7d0702dd,0xa2a14f13,0xbc6a02fd}},	//   _trìn, cijs, क्त्, _تمدن_,
   {{0x7523c71b,0xdce4011c,0x6f041bfa,0xdced0207}},	//   donz, _uviđ, _kmic, _svać,
   {{0x6d4b00f7,0xf1d11140,0x2903008c,0x6f040069}},	//   _égar, तमान, _emja_, _jmic,
   {{0x80b202cb,0x67222889,0x6b8301ff,0x394a0183}},	//   _असले, rooj, _ångr, _tibs_,
   {{0x26cd0657,0x75233a3c,0xb81d00b4,0x28b9002d}},	//   _eneo_, gonz, _बुकम_, _пусэ_,
   {{0x6f040382,0x2ef20345,0xe3af0037,0xc6230033}},	//   _omic, _olyf_, قري_, বেলা_,
   {{0x7d073f24,0x66e3b299,0x78bcc71c,0xdb0f00b5}},	//   zijs, _коса, _harv, ődöt,
   {{0x66e30af5,0x78bcc71d,0x09e40083,0x7ceb00d0}},	//   _тота, _karv, _নেতা, _sürm,
   {{0x6f04868c,0x30a301e0,0x75230027,0x00000000}},	//   _amic, арюв, conz, --,
   {{0x6ee620d9,0x332d02d7,0x7d0700f4,0x3af50044}},	//   _lóbu, blex_, vijs, _håpe_,
   {{0x78bcc71e,0xb5fd023a,0x442c034d,0x00000000}},	//   _larv, _kešp, _iyd_, --,
   {{0x442c02c7,0x7d0702c6,0xf0b700d1,0x62820051}},	//   _hyd_, tijs, رایش_, _idoo,
   {{0x7cf00006,0x6f04c71f,0x78bcc720,0x48bd0083}},	//   _pära, _emic, _narv, _আক্র,
   {{0x7d073957,0x69c64c46,0xa2b81ede,0x2b4b00d7}},	//   rijs, _arke, ्यप्, _picc_,
   {{0x7bc50888,0x7b64135d,0x41b61604,0x7d0718b0}},	//   _vrhu, ртре, _अनास, sijs,
   {{0x78bc16dc,0x442c0c61,0x23690254,0xb5fd063c}},	// [f4d0] _barv, _lyd_, ćaji_, _nešp,
   {{0x7cf001ff,0x6e2d04fb,0x78bcc189,0x00000000}},	//   _härn, _iyab, _carv, --,
   {{0x69c6c721,0xf770211b,0x7cf0c722,0x8cd00067}},	//   _erke, قان_, _kärn, दारो,
   {{0x7af6024e,0x7cf0013c,0x6e2d01a8,0x98b900ea}},	//   chyt, _järn, _kyab, _pusē_,
   {{0xa2b809b1,0x78bcc723,0xbebb01f4,0x75232506}},	//   ्यन्, _farv, llës, tonz,
   {{0x442c0297,0x7aedc362,0x78bcc724,0xb4bd0722}},	//   _byd_, lkat, _garv, इये_,
   {{0x67d45425,0x7523c725,0x442c001e,0x248900a8}},	//   _кору, ronz, _cyd_, ğam_,
   {{0x24890d6f,0x442cc726,0x69c61860,0xe3b00833}},	//   şam_, _dyd_, _yrke, تره_,
   {{0x7aed01c8,0x6e2dc727,0x6abd01f7,0xe0d10416}},	//   ikat, _nyab, _masf, مزد_,
   {{0x6ff30669,0x2cb100b8,0x442c00e9,0x2ee03e80}},	//   ləcə, jezd_, _fyd_, _soif_,
   {{0xdee612f3,0x6e36006a,0x7aedc728,0x442c001e}},	//   гони, _szyb, kkat, _gyd_,
   {{0x6e2d19c7,0x63050416,0x7aed03d0,0x6ff300a8}},	//   _byab, _حوصل, jkat, nəcə,
   {{0xa0a50d46,0x6e2d0010,0x2718008b,0x7aedc729}},	//   _балд, _cyab, nčna_, dkat,
   {{0x6e2dc72a,0x61e9c72b,0x61fb023c,0x00000000}},	//   _dyab, myel, mzul, --,
   {{0x92d50033,0x013600a5,0x6abd0523,0x6e2d018e}},	//   হসী_, _גרסת_, _basf, _eyab,
   {{0x78bc1209,0x7aed11e9,0x7cf0022a,0xdb1e0097}},	//   _sarv, gkat, _gärn, _trpí,
   {{0x61e9c72c,0x4a750a93,0x2b402051,0x78bcc72d}},	// [f4e0] nyel, рыст, rmic_, _parv,
   {{0x4a4354fc,0x7aedc72e,0x672900a0,0xb5fd00a0}},	//   снув, akat, _akej, _rešp,
   {{0x7e76008a,0x78bcc72f,0x28c9317c,0x99e800d5}},	//   _keyp, _varv, राजि, _brňá,
   {{0xe61a3f74,0x7aedc730,0x6d566a5b,0x66760206}},	//   нде_, ckat, _kuya, ادار,
   {{0x78bc41b7,0x442c0c66,0x673b0118,0xaad100b8}},	//   _tarv, _syd_, _dhuj, हारक,
   {{0x7ae30012,0xa2a12af7,0x69c4c731,0x6d563a34}},	//   _într, क्स्, mvie, _muya,
   {{0x69c4c732,0x6d56011e,0x7cf001ff,0x746901e0}},	//   lvie, _luya, _läro, трів_,
   {{0x673b012f,0x6d56034d,0x9f4600d5,0x81cd0033}},	//   _ghuj, _ouya, bylé_, রহন_,
   {{0x69c4c733,0x61e90332,0xdce4004e,0xa4940088}},	//   nvie, gyel, _zwią, _نیشت,
   {{0x442c0626,0x7aed06a2,0x6e2d01d5,0x26f40380}},	//   _tyd_, zkat, _ryab, _आतुर_,
   {{0x7cf00006,0x7aed00da,0x403407fa,0x6e2d00d7}},	//   _pärn, ykat, ренс, _syab,
   {{0x7ceb08ca,0x69c401c8,0x63ba004e,0x6d56c734}},	//   _türk, kvie, _istn, _buya,
   {{0x2d8bc735,0x6d561f83,0x7aedc736,0x7cf07aff}},	//   urce_, _cuya, vkat, _värn,
   {{0x69c4c737,0x6d56c738,0xe81d00ab,0x6e2d0371}},	//   dvie, _duya, _बुझा_, _vyab,
   {{0x66f40084,0x69c4882d,0x7aedc739,0x6ff30095}},	//   _आतंक_, evie, tkat, yəcə,
   {{0x7cf0013c,0x6a1513ba,0xddcd0139,0x7cebc73a}},	//   _härl, амбу, _ceaţ, _müri,
   {{0x6d56c73b,0x7aedc73c,0x7cf0022a,0x69c400ea}},	// [f4f0] _guya, rkat, _kärl, gvie,
   {{0x7aedc73d,0x6729c73e,0x673bc73f,0x2718008b}},	//   skat, _skej, _shuj, včna_,
   {{0xb8dd020c,0x7c2901ae,0x7aedc740,0x61fb7b9c}},	//   _आस_, ßerd, pkat, zzul,
   {{0xf7700082,0xf9900332,0xb8ec0653,0x6d56c741}},	//   سام_, تبہ_, _शो_, _yuya,
   {{0x6ff301c2,0x69c4c742,0x1efc016b,0x2d8000a2}},	//   rəcə, cvie, עלדע, _xvie_,
   {{0x61fb00a8,0x2eb2000c,0xbf020cc5,0x7cf0017b}},	//   vzul, _जस्त, _लग्न_, _närl,
   {{0x6ed80429,0x3ea91d86,0x6299c743,0x28d218da}},	//   यामु, _obat_, _pcwo, सारि,
   {{0xa2e50202,0xd1850714,0x61e930b7,0x61fb01a3}},	//   роид, алий, tyel, tzul,
   {{0xa2a10c67,0xf4870368,0x7e760159,0x61fb6424}},	//   क्ष्, _буен, _reyp, uzul,
   {{0x205500af,0x3ea90815,0x6ee60183,0x201c0345}},	//   штир, _abat_, _nóbr, _bxvi_,
   {{0x69c49489,0x3dc9134c,0x6d5602d7,0x798d001e}},	//   zvie, _araw_, _suya, hraw,
   {{0xed5a1306,0x6d56c744,0xfe4610be,0x69c4c745}},	//   ком_, _puya, инно, yvie,
   {{0x23690a78,0x7ceb01ae,0xde36010b,0x21671180}},	//   ćaju_, _züri, рэнь, _стег,
   {{0x50450009,0x6ee6002a,0x317f027d,0x3dc9c746}},	//   _келб, _cóbr, msuz_, _draw_,
   {{0x8c462c21,0x6ee601ef,0x317f00a8,0xdb1e00d5}},	//   реве, _dóbr, lsuz_, _arpá,
   {{0x69c40080,0xf1a90b4a,0x6d56c747,0x225fc748}},	//   tvie, _कहान, _tuya, ncuk_,
   {{0xa2b83b23,0x090601c8,0x317f04d4,0x5f44006c}},	// [f500] ्यत्, апан, nsuz_, _پچھل,
   {{0xe8f71797,0x69c452a5,0xa2cc00a1,0xdd7b0070}},	//   алу_, rvie, _दोन्, _שטיל,
   {{0x69c4c749,0xd90d0a86,0x00000000,0x00000000}},	//   svie, ریف_, --, --,
   {{0x7c650118,0x69c4c74a,0x7c29033b,0x798dc74b}},	//   _پایل, pvie, ßere, braw,
   {{0x2876325e,0x798dc74c,0x7cf02afd,0x00000000}},	//   _выбр, craw, _lärm, --,
   {{0x05140083,0x7c290225,0xa3b201c0,0xa3b40067}},	//   িত্র_, şere, टबल_, फ़िल_,
   {{0x7cf0022a,0x590750f1,0xd377010b,0x25ad0065}},	//   _närm, _терм_, ачы_, _epel_,
   {{0xf1a601c8,0x387847af,0x6b812278,0x16040099}},	//   арон, _herr_, álgi, _शेअर_,
   {{0x7cf0330b,0xb5a90037,0x59c90067,0xeabf00cc}},	//   _pärl, _مالك_, रियर, _chùy_,
   {{0x4fc6052c,0x5f9405ac,0x38780118,0x7cf00282}},	//   асма, биот, _jerr_, _bärm,
   {{0x7cf006d7,0xa2b8021a,0x387800da,0x08570122}},	//   _värl, ्यद्, _merr_, יבים_,
   {{0xd36f00f8,0x7cf0013c,0xa3c30026,0x3dc90035}},	//   _آهن_, _därm, एटर_, _praw_,
   {{0xae01143a,0x3dc90069,0x00000000,0x00000000}},	//   _लेखन_, _qraw_, --, --,
   {{0x3e750023,0x7cf0330b,0x61430274,0x00000000}},	//   ất_, _härj, _деча, --,
   {{0xc1b606d9,0x81cd0083,0x61b625d8,0x00000000}},	//   _अनुग, রহণ_, _अनुष, --,
   {{0x7cf0066e,0xa3d70907,0x3ea902c2,0x4a5500c7}},	//   _järj, ामत_, _ubat_, скас,
   {{0x13af0083,0x7e7dc74d,0x3878099e,0x4c954a10}},	// [f510] কিয়, masp, _berr_, _липс,
   {{0xd8790180,0x7e7dc74e,0x798d009e,0x854200c7}},	//   امات_, lasp, rraw, žėja,
   {{0x25ad7aaa,0x387801e9,0x00000000,0x00000000}},	//   _spel_, _derr_, --, --,
   {{0x798d006a,0x7e7dc74f,0x00000000,0x00000000}},	//   praw, nasp, --, --,
   {{0x929d0035,0x6ed80d41,0xe6100413,0xc98412b9}},	//   siłk, यातु, وشه_, _мури,
   {{0x43850037,0x7e7d9ca7,0x7cf90211,0x00000000}},	//   ملتق, hasp, _fìre, --,
   {{0x3959037d,0xf8b200a5,0x9f64013b,0x00000000}},	//   _huss_, _משם_, ətçi_, --,
   {{0x569485d7,0x7e7d1e1a,0x98b900c7,0x395916f9}},	//   _маст, jasp, _pusė_, _kuss_,
   {{0x224b013c,0x7e7dc750,0xc6920317,0xd49b0012}},	//   äck_, dasp, _מאן_, _аре_,
   {{0x395902bf,0xa3d706bb,0x9f4e00b8,0x317f045e}},	//   _muss_, ामद_, ěním_, rsuz_,
   {{0xa0c50088,0x7cf001ff,0x6b95c751,0xd25127ad}},	//   ليکو, _färj, juzg, _فنا_,
   {{0x7cf0022a,0x613d0248,0x7e7dc752,0x1efa004f}},	//   _värm, dèle, gasp, اعدة_,
   {{0xd2560bed,0x7cf001ae,0xdce40035,0x0165178e}},	//   _השנה_, _wärm, _zwię, _укло,
   {{0xed571218,0x463a0070,0x1d190352,0xa2d501d1}},	//   сор_, טערע, аюсь_, भाव्,
   {{0x6f950514,0xa3d70ed1,0x7f850082,0x7cf08bec}},	//   _العض, ामि_, _البن, _härk,
   {{0x39597aff,0x2a7900d7,0x7cf000c3,0x7e7d0471}},	//   _buss_, _cesb_, _kärk, casp,
   {{0x9f46006c,0x7cf000c3,0x00000000,0x00000000}},	// [f520] szló_, _järk, --, --,
   {{0xa3d70fa9,0x7cf0c753,0x2d8215ce,0xa85603fa}},	//   ामा_, _märk, mske_, стај,
   {{0x2d82c754,0x39590176,0x3878003e,0x7cf00523}},	//   lske_, _euss_, _verr_, _lärk,
   {{0x7d0e1525,0xe9a60b25,0xf72900d4,0x3959c755}},	//   libs, _ламп, ацій_, _fuss_,
   {{0xa2b84eee,0xd90d0332,0x941201c2,0x3878c756}},	//   ्यस्, ریہ_, əyə_, _terr_,
   {{0x26c031f1,0x6ab60093,0x7e7dc757,0x00000000}},	//   žio_, leyf, zasp, --,
   {{0x7cf00196,0x00000000,0x00000000,0x00000000}},	//   _pärj, --, --, --,
   {{0x7ae6c3bb,0x7cf00523,0x7d0ec758,0xfbd30277}},	//   _jokt, _bärk, hibs, לתו_,
   {{0x2d820888,0xe4520df3,0x63b8006d,0x7ceb027d}},	//   jske_, _فضا_, swvn, _kürt,
   {{0x2d8205e2,0x3ae700ab,0x60f7010b,0x7ae63c1f}},	//   dske_, _lõpp_, йныя_, _lokt,
   {{0x33f6487d,0xe4d70148,0xd8db02b5,0xdeb510b0}},	//   _учас, _دولت_, אקיר, обны,
   {{0x7ae6c759,0x2d82398f,0x80d60aad,0x613d000d}},	//   _nokt, fske_, बाहे, vèle,
   {{0x7cf002ee,0x290a08c7,0xa2d5143a,0x00000000}},	//   _kärh, _omba_, भार्, --,
   {{0x2b5a0176,0xc19b00a5,0x2a7901ed,0xa2b80b35}},	//   _bupc_, _עשוי, _sesb_, ्यव्,
   {{0xe7e30b52,0x3cfa0243,0x7ae6c75a,0x2d820009}},	//   _মধ্য, _उतरे_, _bokt, aske_,
   {{0x7bc7c75b,0x290ac75c,0x39596091,0x2d8203c9}},	//   rvju, _amba_, _puss_, bske_,
   {{0x6f0f0036,0x9a29055c,0x00000000,0x00000000}},	// [f530] micc, _bươm_, --, --,
   {{0x6f0faf61,0x7cf0013c,0x00000000,0x00000000}},	//   licc, _närh, --, --,
   {{0xc5e60083,0xaac42893,0x4ac4035d,0xe7b51a7c}},	//   _খেলা_, _लोकक, _लोकव, تماد,
   {{0x41a9007c,0x6f0fc75d,0x290a030d,0x2a79021d}},	//   _कहलस, nicc, _emba_, _uesb_,
   {{0x1a9a02b5,0x85a70274,0x7cf00282,0x7ceb4cf0}},	//   _דירע, сјед, _bärh, _fürt,
   {{0x92d500c8,0x6f0f0036,0x9a2900e2,0x80b700b4}},	//   _হতে_, hicc, _gươm_, _असें,
   {{0x7ae601d6,0x7cf0a1d9,0xf794010b,0x00000000}},	//   _yokt, _särk, _нарэ, --,
   {{0x2d82c75e,0x7ceb0448,0x23a10035,0x68e707c0}},	//   yske_, _kürs, rój_, _hojd,
   {{0x4429006a,0x6f0fc75f,0x6ed8022e,0x8b0806fe}},	//   ła_, dicc, यासु, _hořá,
   {{0x2d820888,0x672b01d2,0x9f85c760,0x273c00a0}},	//   vske_, logj, огод, mína_,
   {{0xef1a9a36,0xa2b80096,0x6f0fc761,0x68e70168}},	//   имо_, ्यश्, ficc, _mojd,
   {{0x2d82b2be,0x2f5408a6,0x7cf00086,0x3f8b1bd8}},	//   tske_, ятьс, _tärk, čcu_,
   {{0xa2b8020d,0xed5a5ae7,0x2d848337,0x6f1d02d7}},	//   ्यर्, рог_, éme_, érca,
   {{0x2d824c3b,0xa0694715,0x7cf011fd,0x80a70033}},	//   rske_, _така_, _käri, _কোর্,
   {{0xf0b803c5,0x6f0f027a,0x60c30211,0xfe7f00a2}},	//   _دانش_, bicc, _ianm, baï_,
   {{0x2d823957,0xed5a051b,0x629bc762,0x6f0f027a}},	//   pske_, _кои_, nguo, cicc,
   {{0xe9da27fb,0x60c302d0,0x68e702a7,0x3ea00260}},	// [f540] шка_, _kanm, _bojd, _icit_,
   {{0x60c3c763,0x92d50083,0x00000000,0x00000000}},	//   _janm, _হতো_, --, --,
   {{0x60c30c1f,0x656900da,0x7cf0258a,0x68e7af48}},	//   _manm, _ateh, _näri, _dojd,
   {{0x60c30c1f,0x27e7013c,0x7c3e0cef,0x4c3b00a5}},	//   _lanm, änna_, _izpr, _כתיב,
   {{0x60c30282,0xf5b60fab,0x1604258f,0x7ceb0225}},	//   _oanm, تصاد, _शेखर_, _gürs,
   {{0x23c502e4,0xf366095d,0x7ceb033e,0x290a002f}},	//   विंद, отин, _hürr, _umba_,
   {{0xbcfb02e1,0x3ea00176,0x6eca0387,0x00000000}},	//   mpét, _ocit_, ियाँ, --,
   {{0x60c30261,0x6569003c,0x7cf0013c,0x61340176}},	//   _aanm, _fteh, _däri, màli,
   {{0xdce40009,0x7984001e,0x60c35ab9,0x273c0187}},	//   _atič, nsiw, _banm, cína_,
   {{0x7cf00282,0x26c40159,0x60c300e9,0x104a0036}},	//   _färi, _hamo_, _canm, ияни_,
   {{0x4438c764,0x60c301cf,0x26c40f3a,0x6f0f027a}},	//   _ár_, _danm, _kamo_, ticc,
   {{0x741300bf,0x26c6c765,0x2cb802a2,0xbd6b01f2}},	//   _توما, ndoo_, eerd_, ирге_,
   {{0x60c3142f,0x6f0fc766,0xdced0254,0xdce404c3}},	//   _fanm, ricc, _svađ, _etič,
   {{0x62808610,0x6f0fc767,0x2cb8c768,0x80a10066}},	//   lamo, sicc, gerd_, _खाये,
   {{0x26110084,0x6f0f290a,0x00000000,0x00000000}},	//   _देनी_, picc, --, --,
   {{0x6280c769,0xda0c004e,0x60c30c1f,0x26c4c76a}},	//   namo, _सेहत_, _zanm, _namo_,
   {{0x3eb96edd,0x68e7c76b,0xa2a2164f,0x60c30448}},	// [f550] mest_, _pojd, _गान्, _yanm,
   {{0xa2cc0bc1,0x3eb9c76c,0x6280c76d,0x8b0801c0}},	//   _दोस्, lest_, hamo, _pořá,
   {{0x656902bf,0x6280c76e,0x2d99007c,0xb06500c3}},	//   _steh, kamo, luse_, lkää,
   {{0x6280b6ac,0x2d990391,0xf1bc0d34,0x41da0026}},	//   jamo, ouse_, ्टान, बमास,
   {{0xd5bb5ae7,0x443e00f5,0x6280c76f,0x26c4c770}},	//   рсе_, _azt_, damo, _damo_,
   {{0x7cf00006,0x2b490284,0x273cc771,0xdb1e0ea5}},	//   _päri, lmac_, rína_, _aspè,
   {{0x60c302e9,0x3eb9007c,0x2d99c772,0x26c40036}},	//   _ranm, kest_, huse_, _famo_,
   {{0x3eb9029d,0x66b40086,0x8c1c1899,0x7cf028e5}},	//   jest_, _обсу, יווי, _väri,
   {{0x443e0332,0x25bf06b3,0xdce43957,0x65696395}},	//   _ezt_, _usul_, _stič, _uteh,
   {{0x6f0dc773,0x2d99c774,0xdce404c3,0xdb1ec775}},	//   _amac, duse_, _ptič, _espè,
   {{0x62804469,0x2cb848e7,0x60c3c776,0x2d993bf3}},	//   bamo, verd_, _vanm, euse_,
   {{0x62802deb,0x7cf0c70d,0x2cb858da,0x2ca101a6}},	//   camo, _järv, werd_, _achd_,
   {{0x60c35f87,0x2d99007c,0x2cb80130,0xf2d20070}},	//   _tanm, guse_, terd_, _רעד_,
   {{0xb606031d,0xa3cf0127,0x60c3008c,0x00000000}},	//   _ukáž, शिप_, _uanm, --,
   {{0x69cfc777,0xdce41269,0x2ee907c0,0x1d0732a6}},	//   _arce, _utič, _foaf_, чери_,
   {{0x7cf0c778,0x2d997b7d,0x3ea0a01d,0x00000000}},	//   _närv, buse_, _ucit_, --,
   {{0x26c40390,0xc3320122,0x8cd90035,0x2cb80a81}},	// [f560] _ramo_, תון_, माशो, perd_,
   {{0x26c4c779,0x6280c77a,0x499903ad,0x7984001e}},	//   _samo_, zamo, ются_, rsiw,
   {{0x628b02dd,0x02bd0931,0x6280c77b,0x69cfc77c}},	//   _odgo, ्याभ, yamo, _erce,
   {{0xe73a0086,0x660201d7,0x628099f3,0x7984016e}},	//   щее_, tzok, xamo, psiw,
   {{0x6280c77d,0xbcfb0248,0x26c4c77e,0x2718008b}},	//   vamo, mpér, _vamo_, nčni_,
   {{0x7ae41942,0x628b0069,0x25a605f5,0x26c408c7}},	//   ljit, _adgo, rtol_, _wamo_,
   {{0x26c4505f,0x62801430,0x6602006c,0xd9434845}},	//   _tamo_, tamo, szok, _чери,
   {{0x7ae4c77f,0x7af600d8,0x25a60124,0x443e00d5}},	//   njit, nkyt, ptol_, _vzt_,
   {{0x6280c780,0x7cf00282,0x00000000,0x00000000}},	//   ramo, _häru, --, --,
   {{0x6280c781,0x6f0d2961,0x2d99007c,0x3eb900a5}},	//   samo, _smac, vuse_, west_,
   {{0x3eb9c782,0xdb1ec783,0x6280c784,0x6f1d0033}},	//   test_, _espé, pamo, érco,
   {{0x7f443dcb,0x2d990006,0x2b49c785,0xbebb0031}},	//   _chiq, tuse_, xmac_, llëz,
   {{0x3eb9c786,0x7ae40124,0x00000000,0x00000000}},	//   rest_, djit, --, --,
   {{0x3eb90ccf,0x2d99c787,0x91bb00a5,0x7c2902b1}},	//   sest_, ruse_, _למדי, ßero,
   {{0x3eb90332,0x6e240370,0x8fa30202,0x2d99007c}},	//   pest_, _exib, _заје, suse_,
   {{0x7ae400da,0x2d99c788,0x803700a5,0x69cfc789}},	//   gjit, puse_, _מנוע_, _prce,
   {{0xa2a10127,0xfc3000b5,0x00000000,0x00000000}},	// [f570] क्ट्, نحہ_, --, --,
   {{0x98b800c7,0x2ca10284,0x00000000,0x00000000}},	//   _mirė_, _uchd_, --, --,
   {{0x6f1dc78a,0x7e7f0031,0xbcfb00a2,0x00000000}},	//   onsc, _keqp, spés, --,
   {{0x6f1daff0,0x645ac78b,0x6d5f01e9,0x7af6005f}},	//   nnsc, _agti, _kuqa, ckyt,
   {{0x6f1dc78c,0x7cf06267,0xd13800d8,0x85570088}},	//   insc, _värv, klą_, سیار_,
   {{0x6d5f5208,0x3f85c78d,0xe5700037,0x00000000}},	//   _muqa, yslu_, اطن_, --,
   {{0x6d57c78e,0x6d5f0510,0x68e30093,0x29cd00ee}},	//   _mixa, _luqa, öndu, _hľa_,
   {{0x6d5791ea,0xa2a200a1,0x1ddd0ea3,0x7cf00f8e}},	//   _lixa, _गाण्, ममात, _härt,
   {{0xb145171d,0x765b5543,0x7afd0009,0x6594c78f}},	//   мнил, _iguy, _mlst, _пату,
   {{0x248c011e,0x7f440031,0x28e00387,0x271808b7}},	//   _gddm_, _shiq, नायि, včni_,
   {{0x7cf0007c,0x26110461,0x3afc0355,0x23c100b4}},	//   _märt, _देती_, _lípa_, _शनिद,
   {{0x644111c6,0x7c290723,0x6d45c790,0x3f85008a}},	//   _izli, ğerl, _ahha, rslu_,
   {{0x6d45009e,0x28e00096,0xa2a2022e,0x6d570065}},	//   _bhha, नामि, _गात्, _bixa,
   {{0x3e7c00e8,0x6d452d29,0xf1bc21a8,0x6f1dc791}},	//   ật_, _chha, ्टरन, ansc,
   {{0xd00e00e0,0x6aadc792,0xa3e00387,0x98b90409}},	//   _پلي_, ffaf, दमय_, _ausį_,
   {{0x765b00e8,0x6d5f046a,0x6d570310,0xff2601e0}},	//   _nguy, _fuqa, _eixa, _імпо,
   {{0x7ae4a89c,0x7af610b0,0x08c6097b,0xe8ea21a9}},	// [f580] rjit, rkyt, мбан, омад_,
   {{0x7afdc793,0x7af6c794,0x6441025c,0x28ce11b5}},	//   _elst, skyt, _ozli, _होशि,
   {{0x59ba007c,0x81e30033,0x7cf0017b,0x657b0371}},	//   _उनकर, ননি_, _därt, _awuh,
   {{0x28ce0387,0x00000000,0x00000000,0x00000000}},	//   _होरि, --, --, --,
   {{0xd5b003c7,0x5edf012f,0x4ead0070,0xe4e601e0}},	//   افت_, गात्_, מבאַ, дійн,
   {{0x81e30033,0x7cf0033b,0x28d500b4,0x765b0103}},	//   ননা_, _gärt, _डोपि, _eguy,
   {{0xec360070,0x2bd10964,0x98a300ed,0x44250069}},	//   ואַר_, हिया, _шире, _cxl_,
   {{0xa2d5210a,0x7cf0c36f,0xfbc00033,0x8afb016b}},	//   भाग्, _kärs, _উপাত, ַליז,
   {{0x7cf000be,0x6b9c40c2,0xd1b00ef2,0x00000000}},	//   _järs, hurg, ایتک, --,
   {{0x6d5f00d7,0x6b9c01d7,0x7cf0017b,0x00000000}},	//   _ruqa, kurg, _märs, --,
   {{0x39580197,0xd0104c87,0x6d571505,0x656075ce}},	//   _mirs_, الج_, _rixa, _humh,
   {{0x6d5701a2,0x6b9c0093,0x7996a3f8,0x6560002f}},	//   _sixa, durg, kryw, _kumh,
   {{0x7cf01890,0x6560012f,0x6f1d033b,0x00000000}},	//   _närs, _jumh, rnsc, --,
   {{0xa2b80d53,0x79967816,0x65600079,0x3dd2099e}},	//   ्यक्, dryw, _mumh, _dryw_,
   {{0xd00f1cba,0x7c342246,0x6b9cc795,0x4425c796}},	//   _рф_, верх, gurg, _xxl_,
   {{0xa3cf4068,0xcf2721a0,0xaf080037,0x7cf0017b}},	//   शित_, _ترتي, _يقوم_, _bärs,
   {{0x58d51456,0x6aadc797,0x79960035,0x291301b7}},	// [f590] ноат, rfaf, gryw, tixa_,
   {{0x7b670a2b,0x3eb20035,0xf1c80023,0x69cd00b9}},	//   _отме, _zbyt_, _mỡ_, rvae,
   {{0xf1c80019,0x39580069,0x6560009e,0x6b9c00af}},	//   _lỡ_, _dirs_, _aumh, curg,
   {{0x7bc58bf7,0x7afd108c,0x7cf0b3d1,0x7d15c798}},	//   _ishu, _ulst, _färs, lizs,
   {{0x6560c799,0xe57801c8,0xf1c800e2,0x6d5900e0}},	//   _cumh, дзі_, _nỡ_, _éwas,
   {{0xa3c300b8,0x395801f7,0x7cf0312a,0x7d15c79a}},	//   _září_, _girs_, _härr, nizs,
   {{0xe3b11aa6,0x291100d0,0x7cf031ea,0x442508c8}},	//   ارت_, _imza_, _kärr, _qxl_,
   {{0xa2b8012f,0xe0bb0033,0x7bc508c7,0x4425c79b}},	//   ्यग्, _অচেন, _mshu, _vxl_,
   {{0x9f5201c0,0xf1c80019,0x39580159,0x657b007b}},	//   ází_, _cỡ_, _yirs_, _uwuh,
   {{0xf48500b5,0xf1c800e2,0xa3cf00b4,0x6441228c}},	//   _سائی, _dỡ_, शिद_, _tzli,
   {{0x3ea62a67,0x79960035,0x6441b74f,0x7bc501d5}},	//   нинг, zryw, _uzli, _nshu,
   {{0x59df0d1f,0x7b03007c,0x20050207,0x00000000}},	//   नमार, _jõud, rzli_, --,
   {{0xa3d70026,0xf1c80019,0x7bc58083,0x20050067}},	//   ामक_, _gỡ_, _ashu, szli_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf0022a,0x26110084,0xdfce0312,0x1c3901e0}},	//   _särs, _देसी_, _هيو_, дять_,
   {{0x7b03007c,0x39584597,0x29110160,0xf4121804}},	//   _nõud, _sirs_, _amza_, אפל_,
   {{0x395808b7,0x2b595a52,0x7bc5073a,0x3946010b}},	// [f5a0] _pirs_, _disc_, _eshu, енаг,
   {{0xe4f4045c,0x7cf0c79c,0x02bd0567,0x6b9cc79d}},	//   _अवधि_, _värs, ्युन, purg,
   {{0xb9080084,0x2b599a82,0x7cf006d2,0x3958123c}},	//   _मच_, _fisc_, _färr, _virs_,
   {{0xb5aa0082,0x9586034b,0x2611193c,0x3cde007c}},	//   كاتك_, елде, _देही_, खावे_,
   {{0xfa3600b5,0x3958c79e,0x6d4ec79f,0x00000000}},	//   _سرحد, _tirs_, omba, --,
   {{0x69c6c7a0,0x636706d3,0xf1c80019,0x98a400c7}},	//   _iske, _sına, _rỡ_, _ėmė_,
   {{0x6d4ec7a1,0xf1c800e2,0xccf332e3,0x52bd060a}},	//   imba, _sỡ_, רכו_, ्यूस,
   {{0x26110299,0xc7d70052,0x2bd12e64,0xfbd1012f}},	//   _देवी_, _אולי_, हिता, हितम,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2d500a1,0xf1c80019,0x68eec7a2,0x6d4e0009}},	//   _मोठ्, _vỡ_, _jobd, jmba,
   {{0x7d158f13,0x00000000,0x00000000,0x00000000}},	//   vizs, --, --, --,
   {{0xa3bd045c,0x6d4e5b08,0x00000000,0x00000000}},	//   इबर_, emba, --, --,
   {{0x2b59c7a3,0x9df80102,0x00000000,0x00000000}},	//   _risc_, енят_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1e4a74,0x69c6c7a4,0x3a3f00ac,0x7d15c7a5}},	//   _espí, _aske, _šup_, rizs,
   {{0x3f9ec7a6,0x6d4e601c,0x00000000,0x00000000}},	//   mutu_, amba, --, --,
   {{0x0f5802b5,0x7b0300ab,0x7e6d0027,0x7cf001ff}},	// [f5b0] _איהם_, _nõue, _ifap, _värr,
   {{0x7bc501a9,0x613d02d0,0x68ee0176,0x2b590210}},	//   _tshu, yèlm, _cobd, _wisc_,
   {{0x3f9e0291,0x2d8b004e,0x69c60291,0x7bc5c7a7}},	//   nutu_, lsce_, _eske, _ushu,
   {{0xa3cf0d43,0x00000000,0x00000000,0x00000000}},	//   शिस_, --, --, --,
   {{0x3f9e25bf,0x64a518d9,0x26111ede,0x7cf02933}},	//   hutu_, вала, _देशी_, _kärp,
   {{0x3f9e3439,0x26c90a78,0x2d990037,0x2d8bc7a8}},	//   kutu_, žao_, irse_, isce_,
   {{0x62820244,0x26110992,0x7c29033b,0x59c90517}},	//   _beoo, _देरी_, ßerh, रिकर,
   {{0x02bd0864,0x0ed000a1,0x3f9e018d,0x7cf00282}},	//   ्येन, _तोंड, dutu_, _lärp,
   {{0xa2a20567,0x2d8b004e,0x7aef63b0,0x963500af}},	//   _गार्, jsce_, _moct, _рнац,
   {{0xd12e0ad9,0x7e6d0176,0x7aef0168,0x98b400f4}},	//   يمي_, _afap, _loct, čeću_,
   {{0x3f9e4e33,0x52b5004f,0x2d990345,0xddc40395}},	//   gutu_, _لماذ, erse_, _ofiţ,
   {{0x7aef215f,0x62820fdb,0x521502ba,0x00000000}},	//   _noct, _geoo, _идет, --,
   {{0x78b50187,0xe1ee323d,0x7cf00523,0x00000000}},	//   _obzv, _тг_, _bärp, --,
   {{0xed574e6b,0x3f9e1644,0xdfa90833,0x50c5022e}},	//   коя_, butu_, _قطعه_, _वसिष,
   {{0x6d4e00da,0x2d9935e5,0x28e00fbf,0x7cf0017b}},	//   rmba, arse_, नासि, _därp,
   {{0x38c8064e,0x00000000,0x00000000,0x00000000}},	//   کاری_, --, --, --,
   {{0x7aef1121,0x5a6350f1,0xfd120037,0xf1ca008d}},	// [f5c0] _doct, ркуб, _نجد_, mráð_,
   {{0x6b66002d,0x00000000,0x00000000,0x00000000}},	//   _икоа, --, --, --,
   {{0xc8b500d8,0x248702e9,0x2d80012f,0x00000000}},	//   ысты, danm_, _hwie_, --,
   {{0x2d80012f,0x02bd012f,0x00000000,0x00000000}},	//   _kwie_, ्योन, --, --,
   {{0x6f1d2a87,0xa2b7143a,0x68ee0009,0x05b40037}},	//   érci, ्जन्, _tobd, امتح,
   {{0x6846117a,0x3f9e027d,0x00000000,0x00000000}},	//   _анга, yutu_, --, --,
   {{0x37e306d8,0x17c74de5,0x69c4004e,0x60ca0093}},	//   _корг, _игри_, lwie, _rafm,
   {{0x6aa401e4,0x28e005f8,0x3f9e595d,0x14d20099}},	//   ngif, नावि, vutu_, _धोरण,
   {{0x4432006a,0x7c29027d,0x69c40b17,0x00000000}},	//   ły_, ğeri, nwie, --,
   {{0xa3cf0953,0x672200d8,0x3f9ec7a9,0x20180183}},	//   शिश_, lnoj, tutu_, úrio_,
   {{0x69c401ae,0x2d800a4e,0x628200be,0x889b00a5}},	//   hwie, _awie_, _teoo, וביי,
   {{0x3f9ec7aa,0x2bd10380,0xa3cf00b4,0x00000000}},	//   rutu_, हिसा, शिर_, --,
   {{0xf1941470,0x410600ed,0x3f9ec7ab,0x6aa408c8}},	//   _силь, _издв, sutu_, dgif,
   {{0x2d800035,0xdb1e0211,0xf65300a5,0x00000000}},	//   _dwie_, _aspà, יצר_, --,
   {{0x7ceb01ae,0x7aef0187,0x6aa408c8,0x8aa74cf3}},	//   _kürz, _poct, fgif, крад,
   {{0x90570122,0xdced0009,0x99800035,0x2cad00b8}},	//   _בסוף_, _itač, dził_, řed_,
   {{0xdb1e002a,0x3ea9c7ac,0x690b0067,0x561d0831}},	// [f5d0] _arpó, _icat_, dżer, _তর্ক_,
   {{0x3dc9010d,0xdb1e01f7,0x00000000,0x00000000}},	//   _isaw_, _espà, --, --,
   {{0xccf20052,0xfd13006c,0x248702e9,0xc1af04aa}},	//   _הכי_, _مجھ_, vanm_, _जङ्ग,
   {{0x07a46a01,0x69c4c7ad,0xddcd0069,0x00000000}},	//   раїн, bwie, _oeaż, --,
   {{0xf7730332,0xa6342659,0xa3c80066,0x5a9a00a5}},	//   _چار_, анці, _लैब_, _אשרא,
   {{0xdced7f6b,0xf77302e7,0x80d20825,0x00000000}},	//   _otač, _نار_, _भोले, --,
   {{0x2246006c,0x3ea90124,0xaaaa01c0,0x28e000be}},	//   _azok_, _ocat_, ङ्कक, नारि,
   {{0x2487142f,0x613d0176,0x00000000,0x00000000}},	//   sanm_, mèli, --, --,
   {{0x798d00e9,0x788800ea,0x00000000,0x00000000}},	//   nsaw, būvē, --, --,
   {{0x0cce0083,0x00000000,0x00000000,0x00000000}},	//   _রক্ত, --, --, --,
   {{0x3ce70302,0xb4cf00a1,0x2d80022e,0x69c40067}},	//   ञाने_, षयी_, _swie_, zwie,
   {{0xddc40029,0x798d0feb,0x2485345d,0x6eff0055}},	//   _afiš, ksaw, _helm_, _dëbo,
   {{0xe0ce0021,0x2903c7ae,0x333f009f,0x6aa4014e}},	//   _лв_, _olja_, mlux_, vgif,
   {{0x333f007a,0x672200ec,0x00000000,0x00000000}},	//   llux_, znoj, --, --,
   {{0x3ea90359,0xdb1e002a,0x798d00e9,0x798f0069}},	//   _fcat_, _aspá, esaw, _avcw,
   {{0xdce40c0a,0x69c4004e,0x2b4b0023,0x236500c5}},	//   _otić, twie, _chcc_, _mulj_,
   {{0x09e34640,0x6aa4652b,0x4aaa06fe,0x798d11e9}},	// [f5e0] ботн, rgif, ङ्गव, gsaw,
   {{0x69c4c7af,0x6289002a,0xa2d510aa,0x60c1c7b0}},	//   rwie, haeo, _मोस्, nelm,
   {{0x6f04c7b1,0xb8cc0fc3,0x6aa4022a,0x628900d7}},	//   _klic, _गा_, pgif, kaeo,
   {{0xbc1b02b5,0xdb9b02b8,0x2bd100a1,0x798d006d}},	//   _טויש, _אסטר, हिरा, bsaw,
   {{0x6d5ec7b2,0x6f04c7b3,0x60c1c7b4,0x6722005f}},	//   _kipa, _mlic, kelm, rnoj,
   {{0x60c103ad,0x6f0412c3,0xa786211b,0x67222a28}},	//   jelm, _llic, _مشرو, snoj,
   {{0x60c183e8,0x6d5e000e,0x6f0400ee,0xd90d006c}},	//   delm, _mipa, _olic, _تیل_,
   {{0x6d5ec7b5,0x291aad37,0xaa7b016f,0x05140033}},	//   _lipa, lipa_, _inýc, াকের_,
   {{0x171b02b5,0x8af00095,0xdced0237,0x7b0300ab}},	//   _נומע, mməd, _stač, _jõua,
   {{0x60c1c7b6,0x8af00095,0x6d5ec7b7,0x291ac7b8}},	//   gelm, lməd, _nipa, nipa_,
   {{0x6f04c7b9,0x2b4008b7,0xd36f0037,0x7c3ea4e0}},	//   _blic, klic_, _فهل_, _nypr,
   {{0x6f0409b3,0x6d5e0291,0x291a0043,0x9f3501e0}},	//   _clic, _aipa, hipa_, ремі,
   {{0x60c1c7ba,0x7b03007c,0x443ec7bb,0x291ac7bc}},	//   belm, _nõua, _hyt_, kipa_,
   {{0x6f04c7bd,0x6d5ec7be,0x656f0248,0xed5800d8}},	//   _elic, _cipa, _éche, лоў_,
   {{0x6d5e6072,0x5eba0083,0x6f04c7bf,0x798d010d}},	//   _dipa, ইয়ে, _flic, wsaw,
   {{0x7b641a24,0x6f04c7c0,0x443e5c06,0x543b0070}},	//   стре, _glic, _myt_, געלא,
   {{0xad270a72,0x6d5e0036,0x443e1b99,0x6f1d002a}},	// [f5f0] _مردو, _fipa, _lyt_, ércu,
   {{0x6fa802e4,0x6d5e0b04,0x0edd00a1,0x798dc7c1}},	//   _कमां, _gipa, याकड, rsaw,
   {{0x443ec7c2,0x2b408917,0xf770004f,0xdce4011c}},	//   _nyt_, blic_, كان_, _stić,
   {{0x1b7a02b5,0x60c15f16,0x6d5ec7c3,0x7c29033b}},	//   _שטרע, zelm, _zipa, ßeru,
   {{0xa68402ce,0x443e0159,0xb8db0033,0x442c0051}},	//   слід, _ayt_, _অফ_, _axd_,
   {{0x7aedc7c4,0x443e1396,0x2903b5b7,0x60c1093a}},	//   ljat, _byt_, _ulja_, xelm,
   {{0x60c1c7c5,0x2bd80d00,0xddca0067,0x8cad021a}},	//   velm, डिया, _łoży, _जानो,
   {{0x7aedad58,0x41b51583,0x857508ae,0xe6100919}},	//   njat, асот, _влах, _کشف_,
   {{0x60c1c7c6,0x62890297,0x54a70206,0x673b0009}},	//   telm, raeo, _محاف, _ikuj,
   {{0xa2d50567,0x6f1654b7,0x6f04c7c7,0x7aed2119}},	//   _मोर्, _smyc, _slic, hjat,
   {{0x6d5ec7c8,0x60c1c7c9,0x6f04c7ca,0x4f262701}},	//   _ripa, relm, _plic, идоб,
   {{0x6d5ec7cb,0x7f4d02e1,0x7aed6fad,0x63a3c7cc}},	//   _sipa, _chaq, jjat, munn,
   {{0x7aedc7cd,0x63a3c7ce,0x7f5f0095,0x60c19d17}},	//   djat, lunn, _diqq, pelm,
   {{0xdca611b9,0x645c002a,0x7c3e0345,0x256b008c}},	//   јави, _úric, _pypr, _møl_,
   {{0x63a30093,0x6d5ec7cf,0x673b0273,0x61fb043d}},	//   nunn, _vipa, _okuj, lyul,
   {{0x2b40c7d0,0x7c3e024e,0x672900da,0x7aedc7d1}},	//   ulic_, _vypr, _njej, gjat,
   {{0x61e9043f,0x291a055f,0x6d5ec7d2,0x63a3c7d3}},	// [f600] nxel, tipa_, _tipa, hunn,
   {{0x63a3c7d4,0xe9d75cdf,0xc8e00963,0x673bc7d5}},	//   kunn, шку_, नाइट, _akuj,
   {{0xcd2921a0,0x63a31e16,0x2b40c7d6,0x76490107}},	//   _حسين_, junn, plic_, _azey,
   {{0x7d1c1a68,0xe9a65951,0x291ac7d7,0x63a3ab31}},	//   lirs, _камп, sipa_, dunn,
   {{0x70c50084,0x6286008a,0xfb3702b5,0x8af000a8}},	//   _वसूल, ðkom, _כאטש_, rməd,
   {{0x63a30b96,0x443ec7d8,0x672902d7,0x186a2123}},	//   funn, _pyt_, _ejej, _јави_,
   {{0x63a3c7d9,0xb4e60084,0x291801f7,0x7649030d}},	//   gunn, _बची_, _imra_, _ezey,
   {{0xb6a3150d,0x672900da,0x7b03007c,0x7e640f3a}},	//   _мисл, _gjej, _lõun, _ngip,
   {{0x7d1cc7da,0xdb07006c,0x443e00e9,0x00000000}},	//   kirs, ntjá, _wyt_, --,
   {{0x7f4d0055,0x63a3c7db,0x443e00d7,0x7b0300be}},	//   _shaq, bunn, _tyt_, _nõun,
   {{0x7d1cc7dc,0x644808b3,0xd8d70070,0x52aa0043}},	//   dirs, _uzdi, בויט_, _авем_,
   {{0xd04100a8,0x7760035f,0xdb23027b,0x00000000}},	//   ndlə, _jimx, ürüc, --,
   {{0x7d1cc7dd,0x7e640160,0x273c0824,0x7e7db5ea}},	//   firs, _dgip, líns_, rbsp,
   {{0x7d1cc7de,0x6d110067,0xd041013b,0x00000000}},	//   girs, डोंग_, hdlə, --,
   {{0x9b68192f,0x7aedc7df,0x7f4d0031,0xa3cf046c}},	//   ишта_, tjat, _thaq, शिए_,
   {{0x2918009e,0x5f7310ad,0x6e2d01a3,0x2cba0107}},	//   _amra_, _باور, _txab, _ebpd_,
   {{0x7d1cc7e0,0x6f1d0b7b,0x7aedc7e1,0x9f530035}},	// [f610] birs, misc, rjat, ńców_,
   {{0x6f1dc7e2,0x7d1cc7e3,0x7aedc7e4,0xa2bd0026}},	//   lisc, cirs, sjat, _वॉन्,
   {{0x9675010b,0x8e3800f8,0x753800d5,0x3ebe00fd}},	//   былі, _مسیر_, dovz, őtte_,
   {{0xb8fe1ee0,0x6f1dc7e5,0xec360052,0x63a3c7e6}},	//   _दो_, nisc, _לאתר_, vunn,
   {{0x26110f39,0x588701c8,0x764000e9,0x00000000}},	//   _देखी_, _выба, _cymy, --,
   {{0x63a3c7e7,0x6f1dc7e5,0xa5f603fa,0xd006149c}},	//   tunn, hisc, сељу_, _فل_,
   {{0x6729013c,0xc95200a5,0x6f1d02b1,0xc7c80043}},	//   _tjej, _ממך_, kisc, _кыте_,
   {{0x63a3c7e8,0x2bd81ef5,0xa2e50009,0x61e92a1d}},	//   runn, डिता, соид, txel,
   {{0x6f1dc7e9,0x63a3c7ea,0x7d1c0095,0x764000e9}},	//   disc, sunn, yirs, _gymy,
   {{0x273c01ef,0x25bf00e0,0x6f1d0051,0x7e64016e}},	//   bíns_, _ipul_, eisc, _sgip,
   {{0x6f1dc7eb,0x68f5c7ec,0x7e64011e,0x83ab751e}},	//   fisc, _mozd, _pgip, _штаб_,
   {{0x81c600c8,0x6f1d0b7b,0x7c381217,0x65690bf7}},	//   _উপর_, gisc, _øvri, _kueh,
   {{0x2d841010,0xa3cf09b8,0x7d1cc7ed,0x2f5502ce}},	//   ème_, शिक_, tirs, ютьс,
   {{0xd37e1269,0x6f1d0037,0xa3ab1edf,0x823a0070}},	//   šćen_, aisc, कंप_, _גענצ,
   {{0x65610370,0x7d1cc7ee,0x3f9e00f4,0xd041013b}},	//   _milh, rirs, crtu_, ydlə,
   {{0x6441c7ef,0x387f0c99,0x8bc500d8,0x6e960037}},	//   _myli, _đura_, ўсёд, _الظا,
   {{0xe9da15eb,0x7d1cc7f0,0xed36005f,0x68f534c3}},	// [f620] ыка_, pirs, _гэнэ, _bozd,
   {{0xb4e60992,0xdb0700b5,0x202800f4,0x6561009f}},	//   _बचे_, rtjá, štiš_, _nilh,
   {{0x644127fe,0xdb070093,0x273c01ef,0x00000000}},	//   _nyli, stjá, xíns_, --,
   {{0x7b03007c,0xdd8f00d1,0x6561099e,0x76a901e0}},	//   _jõul, _توی_, _ailh, итів_,
   {{0x6561c7f1,0xe5a32491,0xd04100a8,0x64410448}},	//   _bilh, зичи, rdlə, _ayli,
   {{0x6441113c,0x76400187,0x68f502c6,0x2918b8af}},	//   _byli, _vymy, _gozd, _umra_,
   {{0x76400067,0x80d20355,0x00000000,0x00000000}},	//   _wymy, _भोगे, --, --,
   {{0x64410411,0xf1a6426a,0x1b7b0070,0x79860118}},	//   _dyli, брон, נטפע, _kwkw,
   {{0x656100c9,0xe29f008a,0x32022eac,0x9aeb0070}},	//   _filh, óða_, áky_, אַיִ,
   {{0x656f02e1,0x61e4003c,0x6f1d77a0,0xdce400c7}},	//   _écha, _ġild, wisc, _buič,
   {{0x6f1d3a44,0x3202024e,0x61e4010b,0x248e011e}},	//   tisc, šky_, _šild, mafm_,
   {{0x71a600d8,0x00000000,0x00000000,0x00000000}},	//   _гадз, --, --, --,
   {{0x6f1dc7f2,0x78bc1942,0x6441033b,0x00000000}},	//   risc, _obrv, _zyli, --,
   {{0x6f1dc7f3,0x6ea500e7,0xd1300037,0x00000000}},	//   sisc, _काकु, _تمت_, --,
   {{0x68f51b66,0x6f1dc7f4,0xb4fb0317,0x64410421}},	//   _rozd, pisc, נפלי, _xyli,
   {{0xae9b0037,0x802500e0,0xbebb0223,0x00000000}},	//   _إضغط_, _برهم, fiëe, --,
   {{0x68f5c7f5,0x00000000,0x00000000,0x00000000}},	// [f630] _pozd, --, --, --,
   {{0x2907c7f6,0xc8670421,0xb88201ba,0x25a64e7c}},	//   óna_, стаи, _šírk, duol_,
   {{0x25bf09a6,0xf84b392c,0x2901c7f7,0x00000000}},	//   _spul_, учай_, rkha_, --,
   {{0x17f80037,0x6441c7f8,0x00000000,0x00000000}},	//   حركة_, _ryli, --, --,
   {{0xa3ab16d3,0x65610279,0x656921d8,0x2bd11604}},	//   कून_, _pilh, _queh, हिका,
   {{0xd7c90118,0xdb1e0298,0x6eff0055,0x73990390}},	//   _پوره_, _appè, _dëbi, атис_,
   {{0x0516004f,0x6561c7f9,0x8cbb0067,0x65690118}},	//   تيوب_, _vilh, श्यो, _wueh,
   {{0x8c1c02b5,0x69dd0207,0x00000000,0x00000000}},	//   טווי, _krse, --, --,
   {{0x656176e6,0x644104fc,0x2d9e004e,0x34950183}},	//   _tilh, _wyli, ątek_, _маар,
   {{0xc105004f,0xdb0701ff,0x6441c7fa,0x3eb90051}},	//   زوجي, ltjä, _tyli, efst_,
   {{0xd8d80070,0xceea1b5d,0x00000000,0x00000000}},	//   מוזט_, адне_, --, --,
   {{0x25a00944,0x69cf027a,0x69dd8c20,0xc7d600a5}},	//   šile_, _osce, _orse, קורי_,
   {{0xee370823,0x200308b7,0x62990359,0x00000000}},	//   жня_, šji_, _idwo, --,
   {{0xac0a0a6a,0x628b01d7,0x00000000,0x00000000}},	//   анга_, _hego, --, --,
   {{0x69cf0f4f,0x628b0118,0x00000000,0x00000000}},	//   _asce, _kego, --, --,
   {{0x28ac0b1c,0x1a2a0be8,0x628b60f9,0x69dd0207}},	//   _चाहि, ажби_, _jego, _brse,
   {{0x628b0332,0xa3ab02e4,0x13a6051d,0x3b07075c}},	// [f640] _mego, कंड_, _गम्भ, цето_,
   {{0x628bc7fb,0xa3e90311,0x98a3002d,0x69dd02a7}},	//   _lego, ममा_, дифе, _drse,
   {{0x69cf249a,0x69dd01ae,0x62990035,0x00000000}},	//   _esce, _erse, _odwo, --,
   {{0x628bc7fc,0xb6030187,0x09e6002d,0xe73a00c3}},	//   _nego, _omáč, _домн, шее_,
   {{0x7ae60223,0x644500ab,0x00000000,0x00000000}},	//   _inkt, ühin, --, --,
   {{0x629902ce,0x628b1ad3,0x00000000,0x00000000}},	//   _adwo, _aego, --, --,
   {{0x261a006a,0x628bc7fd,0x689100b5,0x0eaa0026}},	//   _मेरी_, _bego, _سینئ, _कांड,
   {{0x628b2314,0xe73700af,0xc3d5010b,0xcfcf0033}},	//   _cego, _дес_, яўчы, িমান,
   {{0x628bc7fe,0x80d30033,0x629900fe,0x00000000}},	//   _dego, তান্, _ddwo, --,
   {{0xd467002d,0xe4520647,0x628b02a7,0x301416b6}},	//   _дифе_, _قضا_, _eego, здор,
   {{0xa2d5258f,0x00000000,0x00000000,0x00000000}},	//   _मोक्, --, --, --,
   {{0x628bc7ff,0x543b0070,0x00000000,0x00000000}},	//   _gego, _דעבא, --, --,
   {{0xe0cf00d1,0x3eb9c800,0x7bde00ec,0x00000000}},	//   رزی_, rfst_, _arpu, --,
   {{0x628b06a2,0x224b01ae,0x387f011c,0x7ae60031}},	//   _zego, ücke_, _đuro_, _ankt,
   {{0xcb1b0370,0x7b2c00a8,0x69dd023a,0x00000000}},	//   аќа_, rğun, _srse, --,
   {{0x290a004a,0x539b1804,0xdd910037,0x00000000}},	//   _alba_, יסלא, _كوب_, --,
   {{0x5d840037,0x290a00d5,0x00000000,0x00000000}},	// [f650] _قليل, _blba_, --, --,
   {{0x60c80159,0x2bcb00a1,0xaa7b00a0,0x69dd0207}},	//   nedm, ाबदा, _iným, _vrse,
   {{0x6d4702dd,0xb8d3303b,0x1fa83b23,0xd7fb03e6}},	//   mlja, _टा_, _कमोड, јуз_,
   {{0x2be00084,0x6d470093,0x00000000,0x00000000}},	//   _पछता, llja, --, --,
   {{0x628b3c1d,0x69dd0051,0x69cf07e5,0xdb0701ff}},	//   _rego, _urse, _usce, rtjä,
   {{0x628bc801,0xdb07013c,0xd7fb3945,0x929d0067}},	//   _sego, stjä, _куб_, dkła,
   {{0xe29994c2,0x7b03007c,0x628bc802,0x490000a1}},	//   бай_, _nõuk, _pego, _शकतो_,
   {{0x6aadc803,0x16160461,0x656f00f7,0x8cbb0035}},	//   ngaf, _देकर_, _écho, श्तो,
   {{0x6d4704c3,0x257001f7,0x91b000e2,0x628b023a}},	//   klja, _gàl_, _đại_, _vego,
   {{0xa3bb1c51,0xbef60380,0x628b0051,0xd37e0124}},	//   _ناصر_, ुघ्न_, _wego, šćan_,
   {{0x6d4703c9,0xf1c900d5,0x75370228,0x00000000}},	//   dlja, dráš_, ļazī, --,
   {{0x672b4601,0x00000000,0x00000000,0x00000000}},	//   nngj, --, --, --,
   {{0x91e51566,0x28ac02d1,0x6d4700f4,0x00000000}},	//   _холе, _चालि, flja, --,
   {{0x657b000e,0x2d9e024e,0x91f60122,0x25ee5bba}},	//   _mtuh, čte_, _ממנו_, _आपसी_,
   {{0xe8df0019,0xe9df0312,0x00000000,0x00000000}},	//   _ngực_, _arú_, --, --,
   {{0x6b634a82,0x63ae01b4,0xe9df1685,0x511b00ab}},	//   екса, _åbne, _brú_, _फगुआ_,
   {{0x6d47177a,0x6ebc0266,0x80ce0083,0x63a30097}},	// [f660] blja, ष्णु, ়ার্, hrnn,
   {{0xcdb700a5,0x6eff0055,0x7bde0207,0x00000000}},	//   _צפיה_, _dëbu, _trpu, --,
   {{0x78a3008a,0x929d0035,0x657b08c7,0xe9df00fe}},	//   ónva, zkła, _atuh, _erú_,
   {{0x60c8004e,0x25700176,0x248c0355,0xe9df008d}},	//   zedm, _pàl_, _sedm_, _frú_,
   {{0xa4d401e0,0x00000000,0x00000000,0x00000000}},	//   долі, --, --, --,
   {{0xb4d61163,0x00000000,0x00000000,0x00000000}},	//   िये_, --, --, --,
   {{0xf2140084,0x60c8082b,0x2795c804,0xfbdc046c}},	//   _तेज़_, vedm, _оштр, मटिम,
   {{0x6d470b67,0x00000000,0x00000000,0x00000000}},	//   zlja, --, --, --,
   {{0xd5c00006,0x79960035,0xd52800cc,0xbebb0055}},	//   _एहिज, nsyw, _cộn, onëv,
   {{0x6722c805,0xdce4012e,0x00000000,0x00000000}},	//   lioj, _otiđ, --, --,
   {{0x6d471851,0x8f350395,0xc4d30d85,0xe1ef0416}},	//   vlja, денц, _רגע_, نسی_,
   {{0x672200c7,0x7d1e7359,0x7bdc0345,0x00000000}},	//   nioj, _amps, dvru, --,
   {{0x6d4702dd,0x6602c806,0x7b2c0095,0x3cfa01b7}},	//   tlja, nyok, rğul, _bopv_,
   {{0xeb050fcf,0x7b0300be,0x00000000,0x00000000}},	//   रस्त_, _tõuk, --, --,
   {{0x6d470e46,0x00bb00a5,0x8af000a8,0x672200c7}},	//   rlja, _המומ, rmən, kioj,
   {{0x6d479ee9,0x5bb80421,0x00000000,0x00000000}},	//   slja, ялся_, --, --,
   {{0x6d471bfc,0x2ee90036,0x6722c807,0x6f0d76b8}},	// [f670] plja, _inaf_, dioj, _ilac,
   {{0xb4d697c4,0x8af00095,0x2bce1ca8,0x6f0d2190}},	//   ियो_, lməl, _हैवा, _hlac,
   {{0x6f0dc808,0x657b0dc4,0xf6d501e0,0x00000000}},	//   _klac, _stuh, діля, --,
   {{0xe9dfc809,0xd49100e2,0x6722b08f,0x99890067}},	//   _trú_, _còn_, gioj, rzał_,
   {{0xd5bbb95b,0xd4690ebc,0x29cd00cd,0x22460118}},	//   ссе_, оиле_, _uža_, _nyok_,
   {{0x6f0dc80a,0x1dde051d,0x63b800e2,0x00000000}},	//   _llac, मितत, ftvn, --,
   {{0x6f0d06a8,0x224600e0,0xcc78011d,0x00000000}},	//   _olac, _ayok_, הגות_, --,
   {{0x25a005e2,0x36d41578,0x672219e7,0x07090037}},	//   šila_, _поср, cioj, _بيري_,
   {{0x59e005e7,0xdcf600d5,0x0467021d,0x41b4002d}},	//   नियर, _styč, _етем, нсэт,
   {{0x6f0dc80b,0x7bc5c80c,0x22460159,0xf1d200dc}},	//   _alac, _ophu, _dyok_, तिजन,
   {{0x6f0dc80d,0x1eca1159,0x3ea648d0,0xbea68497}},	//   _blac, олни_, минг, манк,
   {{0x6f0d01a6,0x7523c80e,0xe1f10079,0x212c009e}},	//   _clac, linz, _لست_, andh_,
   {{0x6f0d004e,0x213e1808,0xee3a0746,0x00000000}},	//   _dlac, both_, інг_, --,
   {{0xcb6a415e,0x75237562,0x602503fa,0xd0090043}},	//   жаве_, ninz, _одла, _меле_,
   {{0x8c43191f,0x6f0dc80f,0xdc670fb4,0x00000000}},	//   вере, _flac, дард_, --,
   {{0x6f0dc810,0x25ee02cb,0x75230232,0x333f000d}},	//   _glac, _आपली_, hinz, noux_,
   {{0xe8fa1c1b,0x776e01dd,0x3167c811,0x75238e43}},	// [f680] ола_, _subx, _kinz_, kinz,
   {{0x6602000e,0x6f0dc812,0x2b491278,0x7d1e03d0}},	//   vyok, _zlac, alac_, _umps,
   {{0x7a6a0fc5,0x8af000a8,0x6d5c0282,0x75230036}},	//   _минг_, lməm, mmra, dinz,
   {{0xe5c660f8,0x333f0248,0xa2bd0026,0x3167c813}},	//   дско, joux_, _वॉल्, _linz_,
   {{0xe6120088,0x6722010b,0x333f00a2,0x38710098}},	//   خشا_, rioj, doux_, íorú_,
   {{0x67221040,0xd37a2ee2,0x3878021d,0x9f5f0097}},	//   sioj, очи_, _ufrr_, ryté_,
   {{0x22460034,0xe3af0934,0xbebb01e4,0x68fcc814}},	//   _syok_, لري_, diën, _iord,
   {{0x68fcc815,0x63aa31b4,0xc29803fa,0x2b40c816}},	//   _hord, rufn, чких_, noic_,
   {{0x68fc0006,0x7523c817,0x2f0200d5,0x6f0d009e}},	//   _kord, binz, _jógu_, _rlac,
   {{0x68fcc818,0x6f0dc819,0x7523027a,0x6d5c00f4}},	//   _jord, _slac, cinz, jmra,
   {{0x6f0dc81a,0x68fcc81b,0x3f98024e,0xb4bc11b5}},	//   _plac, _mord, éru_, ेजी_,
   {{0x656801f4,0x74130d47,0xe283002d,0x00000000}},	//   _hidh, _جوما, _алци, --,
   {{0x68fc0136,0x7bc50024,0x8af00095,0x2246011e}},	//   _oord, _sphu, rməl, _uyok_,
   {{0x68fc0075,0x6568003c,0xbebb01e4,0x61e201ed}},	//   _nord, _jidh, ciën, _irol,
   {{0x65680118,0x6f0d9723,0xb06503a6,0x5ec40033}},	//   _midh, _tlac, rjää, ষয়ে,
   {{0x656801d2,0x7523c81c,0x60d80b3e,0xdb1e00a2}},	//   _lidh, zinz, _havm, _appâ,
   {{0x68fcc81d,0x64488a16,0x6568111c,0x752309d6}},	// [f690] _bord, _lydi, _oidh, yinz,
   {{0x6568c81e,0x2b4918a2,0x02bc0e61,0x25a6c81f}},	//   _nidh, slac_, ्जुन, drol_,
   {{0xf7700642,0x68fcc820,0x6d4501ed,0x25a60176}},	//   لان_, _dord, _ikha, erol_,
   {{0x6568c821,0x61e2c822,0x25a64c02,0x8cbb06fe}},	//   _aidh, _orol, frol_, श्रो,
   {{0x68fcc823,0x6568c824,0x7e6d0008,0x7523c825}},	//   _ford, _bidh, _mgap, tinz,
   {{0x7afd06a0,0x65680284,0x2d99c826,0xaabb006c}},	//   _host, _cidh, isse_, _ادھر_,
   {{0x61e2001e,0x7523c827,0xe2996ac5,0x656800d1}},	//   _arol, rinz, пай_, _didh,
   {{0x7e6dc828,0xe1f90204,0x61e2c829,0x7afdc82a}},	//   _ngap, зги_, _brol, _jost,
   {{0x68fcc82b,0x333f19d2,0x61e2c82c,0x75230054}},	//   _yord, roux_, _crol, pinz,
   {{0x7afdc82d,0x6d450221,0x68fc0391,0x7e6d2fe9}},	//   _lost, _nkha, _xord, _agap,
   {{0x7afd02e6,0xff262201,0x2d99c82e,0x61e2c82f}},	//   _oost, емно, esse_, _erol,
   {{0x7afdc830,0x6da6c831,0x6d45c832,0x764901a8}},	//   _nost, нима, _akha, _kyey,
   {{0xa3ab0099,0x7769009f,0xbd3602fb,0xd00e0118}},	//   कूर_, _miex, ехвъ, للی_,
   {{0x7afdc833,0x60d80a8a,0x8af000a8,0xd19600a5}},	//   _aost, _gavm, rməm, _טכני_,
   {{0x1be75866,0x7afdc834,0x2d99c835,0x2d820009}},	//   ндри_, _bost, asse_, spke_,
   {{0x7afd6ee7,0x68fcc836,0x6d4572bf,0x7769007a}},	//   _cost, _sord, _ekha, _niex,
   {{0x4a7500c7,0x68fcc837,0x8af000a8,0xdc3c00cd}},	// [f6a0] тыст, _pord, lmək, _išča,
   {{0x38c804e8,0x290e3c0e,0x7afd0044,0x00000000}},	//   باری_, ófa_, _eost, --,
   {{0x7afdc838,0x764900d7,0x8cd91451,0xcd02004e}},	//   _fost, _ayey, _फोटो, ęść_,
   {{0x7afdc839,0x68fc0b93,0xa96a0f7a,0x6568c83a}},	//   _gost, _word, _нима_, _sidh,
   {{0x45d40c87,0x6568480a,0xd6d90067,0xd49100cc}},	//   толс, _pidh, _dał_, _bè_,
   {{0x7afd307f,0x9f590082,0x25a6c83b,0x68fc008c}},	//   _zost, árú_, rrol_, _uord,
   {{0xf36631fb,0xa3ab13ab,0x6568c83c,0x3ea00260}},	//   нтин, कूल_, _vidh, _odit_,
   {{0x61e2c83d,0x65683540,0x2d990baf,0x3ea00051}},	//   _prol, _widh, ysse_, _ndit_,
   {{0x65683c8a,0xe73711cd,0x7649001c,0x64480345}},	//   _tidh, _чет_, _gyey, _wydi,
   {{0x656801a6,0x61e209a6,0x7e6d00f1,0x64480044}},	//   _uidh, _vrol, _sgap, _tydi,
   {{0x03a30009,0x40340ce3,0xb3e90037,0x3ea00069}},	//   _бихо, тенс, _يعمل_, _bdit_,
   {{0x61e20533,0xbebb01e4,0x6fb100ab,0x7b0300be}},	//   _trol, ciël, _अमरू, _jõut,
   {{0x7afdc83e,0xc33302b8,0x2d99c83f,0x61e235f9}},	//   _rost, _גוף_, usse_, _urol,
   {{0x7afdc840,0xd24f004f,0x3ea00122,0xbd680144}},	//   _sost, _انه_, _edit_, ерсе_,
   {{0xf0930d85,0xd00f44a0,0x7e6d0159,0x645600a8}},	//   _ענק_, _сф_, _tgap, əyic,
   {{0xa3e1073f,0x7b0300ab,0x28c60026,0x7e6d0371}},	//   दित_, _nõut, _रॉबि, _ugap,
   {{0x7afdc841,0xe29f0093,0x9f5f00b5,0x3b090055}},	// [f6b0] _vost, óði_, sztó_, rkaq_,
   {{0xaa641999,0x273c0187,0x6d4508c7,0x656f00a2}},	//   утск, míny_, _ukha, _échi,
   {{0x7afdc842,0x281509b9,0x56950086,0xf0930070}},	//   _tost, خواس, вает, רנע_,
   {{0x7afdc843,0x00000000,0x00000000,0x00000000}},	//   _uost, --, --, --,
   {{0xe5780044,0xdb1ec844,0x2d800345,0x20050067}},	//   езі_, _espó, _xtie_, zyli_,
   {{0xf99202da,0xfaff053e,0x7c34027d,0x3a3901f7}},	//   _דרך_, _hoë_, _çerç, _ixsp_,
   {{0xdce5008b,0xdb070355,0x29110b88,0x00000000}},	//   _nihč, hují, _ilza_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc9006d,0x61e40037,0x26cf0035,0xbebb09a6}},	//   _npaw_, _áill, mego_, riël,
   {{0xeb0e009a,0x26cfc845,0x6009c846,0xdb0701c0}},	//   _सत्त_, lego_, дном_, dují,
   {{0x2d800043,0x7b03007c,0x3dc90159,0x61ed010b}},	//   _stie_, _jõus, _apaw_, _šald,
   {{0x26cf006a,0xe2900514,0xdcca112b,0x26dd033b}},	//   nego_, _هذه_, ाज्ञ, ndwo_,
   {{0xe0ce5f0a,0xc3320122,0x3f9c001c,0x291101ed}},	//   _кв_, _דוא_, _evvu_, _olza_,
   {{0xa3b50fd1,0x628901e4,0x26cf1dad,0xa5a9046c}},	//   _जमा_, lbeo, hego_, _घिनौ,
   {{0x7b0300ab,0xfaff0345,0xad9b00b5,0x00000000}},	//   _nõus, _boë_, nyúj, --,
   {{0x3f85c847,0x26cf004e,0x62891167,0x00000000}},	//   mplu_, jego_, nbeo, --,
   {{0x26cfc848,0x2911021d,0x273c0097,0x6b630009}},	// [f6c0] dego_, _blza_, cíny_, ркта,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cf021d,0xd9450079,0x62890345,0x3f8501b7}},	//   fego_, ائقي, kbeo, nplu_,
   {{0x6d4e0533,0xd7ef004f,0xc6a3182f,0xdb1ec849}},	//   llba, تكم_, арши, _espò,
   {{0xdb1e006a,0xe7690180,0x31bd2a06,0x6d4e94d8}},	//   _wspó, رحمن_, ्बोध, olba,
   {{0x260e0d1f,0x62890051,0xfaff01bf,0x00000000}},	//   तैषी_, ebeo, _zoë_, --,
   {{0x25ee004e,0x59e00067,0x273c0334,0x94230274}},	//   _आपकी_, निवर, zíny_, имље,
   {{0x26cf004e,0x61d80340,0x6d4e033b,0x3f770139}},	//   cego_, емия_, hlba, _păun_,
   {{0x0566c84a,0x00000000,0x00000000,0x00000000}},	//   _аван, --, --, --,
   {{0xdb070355,0x00000000,0x00000000,0x00000000}},	//   vují, --, --, --,
   {{0xd007051b,0xf6510332,0xb4ae0325,0xf8b300a5}},	//   веќе_, _نئے_, कली_, בשת_,
   {{0x25a918b0,0x6d4e0b17,0xb22600c3,0x61ed02a7}},	//   šale_, elba, _имел, _šale,
   {{0x5bcb0026,0x00000000,0x00000000,0x00000000}},	//   ाब्व, --, --, --,
   {{0x26cfbba8,0xed5801c8,0x25f500a1,0x00000000}},	//   zego_, коў_, ्हती_, --,
   {{0x212b5bee,0x26cfc84b,0x57d100be,0x2b590176}},	//   èche_, yego_, _सनेह, _phsc_,
   {{0x6d4ec84c,0xdb0700b8,0x9b58167d,0x291100d5}},	//   alba, pují, вист_, _slza_,
   {{0xba550370,0xaa550370,0x61e4011c,0x00000000}},	// [f6d0] увај, уваш, _šilj, --,
   {{0x26cfc84d,0x2bab0299,0x68ee009e,0x00000000}},	//   wego_, _छिपा, _cnbd, --,
   {{0x3d08006a,0x26cfc84e,0xb8cb021a,0xf1d90387}},	//   _सकते_, tego_, _गय_, _भनभन,
   {{0x98ba00ea,0x2bf201c0,0x59f902fb,0xa3e1018d}},	//   ropā_, ीहरू_, _земя_, दिस_,
   {{0x26cfc84f,0xe61001b2,0x64a53079,0xdb1e0093}},	//   rego_, يشه_, гала, _uppá,
   {{0xe7950a86,0x7b03007c,0x26cf1ea0,0xa9270168}},	//   _مارک, _tõus, sego_, _boľš,
   {{0xe7871a31,0xf8b202b8,0x27f700b5,0x0394010b}},	//   _југо, _לשם_, _جہاد_, арыя,
   {{0xf1b70084,0x00000000,0x00000000,0x00000000}},	//   _आमदन, --, --, --,
   {{0x7aef046a,0xc69200a5,0x60c1005f,0x00000000}},	//   _mnct, _לאן_, tflm, --,
   {{0x28c60fd0,0xe00e02e4,0xf8c600e7,0x00000000}},	//   र्पि, ानंद_, र्पय, --,
   {{0x26d901dd,0xe4f0046c,0xf1d80067,0x7aef00a2}},	//   _ósos_, चारि_, _बैठन, _onct,
   {{0x7b0a0314,0xe37a0070,0x25790260,0x00000000}},	//   _výuk, _טרער, _kèl_, --,
   {{0xe1ee02ee,0xe29f008d,0xdb1c0031,0xe1f0183b}},	//   _уг_, óðu_, strë, _وسه_,
   {{0x9d5600b2,0x25790260,0x00000000,0x00000000}},	//   انست, _mèl_, --, --,
   {{0xf99f0c1f,0xdee600af,0xfaa6c850,0xf09200a5}},	//   _avè_, _бойи, лаво, _פנה_,
   {{0x28c6111a,0x7aef021d,0x00000000,0x00000000}},	//   र्नि, _cnct, --, --,
   {{0xdb1c83ac,0x7f3b0070,0x08c61578,0x6aab0079}},	// [f6e0] ntré, _רעפו, лбан, ógfa,
   {{0xe9d71482,0x00000000,0x00000000,0x00000000}},	//   ыку_, --, --, --,
   {{0xa6860948,0x66e6244d,0x80b80033,0x2cba0160}},	//   глед, ложа, _অসম্, _icpd_,
   {{0xd6d90185,0x25790c1f,0xd5ba0012,0xb4dc0461}},	//   кті_, _bèl_, еск_, _तोड़_,
   {{0x25790310,0xb4f009b4,0x00000000,0x00000000}},	//   _cèl_, चालय_, --, --,
   {{0xb4ae142a,0x25790107,0xa92700ee,0x00000000}},	//   कले_, _dèl_, _poľš, --,
   {{0xa3f20831,0x00000000,0x00000000,0x00000000}},	//   জন্য_, --, --, --,
   {{0x6ab600e9,0xdced00a8,0x25790359,0x161f00b4}},	//   ngyf, _otağ, _fèl_, _मेकर_,
   {{0x62345fc0,0xb114c851,0x25790260,0x80cd0033}},	//   репу, имиш, _gèl_, ়যন্,
   {{0xe4240088,0x64560095,0xa3e10246,0x7ddb017b}},	//   _پکتي, əyin, दिश_, _läså,
   {{0xbf1002cb,0x5ede0083,0x58f702b5,0xf8c604aa}},	//   ासून_, যানে, אמיע_, र्यय,
   {{0xa3e100b4,0xe457016b,0x7b0300be,0xe29a0183}},	//   दिर_, _גיבט_, _nõup, _чад_,
   {{0x3fc80416,0x7b1801ef,0xe29b0070,0x656f2407}},	//   ردگی_, _míud, _טשאר, _écht,
   {{0x28c60275,0x61db035e,0x307604bf,0x69d6016e}},	//   र्मि, _נקוד, _судс, dwye,
   {{0x940501c2,0x00000000,0x00000000,0x00000000}},	//   _belə_, --, --, --,
   {{0xd5d401d1,0x3f9e05ee,0x00000000,0x00000000}},	//   _धनंज, mstu_, --, --,
   {{0x3f9ec852,0xbd6b002d,0x28c60b54,0xbf3401cb}},	// [f6f0] lstu_, _прое_, र्भि, _دروغ,
   {{0xd25700a5,0x0a68c853,0x25790359,0x00000000}},	//   רשמה_, урси_, _rèl_, --,
   {{0x2579a8b6,0x6d47c854,0xccf200a5,0x3f9ec855}},	//   _sèl_, moja, _וכי_, nstu_,
   {{0x3f9ec856,0x2579c857,0x00000000,0x00000000}},	//   istu_, _pèl_, --, --,
   {{0xdb0700fb,0x4a9a0070,0xaa9a00a5,0x50c400b4}},	//   stjó, _בירג, _בברכ, वभाष,
   {{0x3f9ebb3d,0x6d47c858,0x290f0029,0x63a500b8}},	//   kstu_, noja, īgas_, áhno,
   {{0x9992006a,0xd7e42327,0x00000000,0x00000000}},	//   czył_, _літо, --, --,
   {{0x2903c859,0x6d4702ee,0x25790359,0x00000000}},	//   _hoja_, hoja, _tèl_, --,
   {{0x29031254,0x6d47828d,0xf4d9029f,0x5ede0033}},	//   _koja_, koja, _имаш_, যামে,
   {{0x672bc85a,0xdb1c1d8a,0x644500ab,0xbfc503e6}},	//   ligj, rtré, ühis, абок,
   {{0x2903c85b,0x6d473cf1,0xdb1cc85c,0x3f9ec85d}},	//   _moja_, doja, stré, gstu_,
   {{0x29037a8e,0xf3b602b5,0x00000000,0x00000000}},	//   _loja_, _כּדי_, --, --,
   {{0x4cdf0083,0x28c60808,0x6d470453,0x6b8511d9}},	//   মানু, र्डि, foja, _athg,
   {{0xed5a03fa,0x9fc900af,0x8af0013b,0x00000000}},	//   тог_, _агка_, hmət, --,
   {{0x8b660118,0xfc031129,0x5ecb0033,0xab2a01e0}},	//   لارم, опро, িয়ে, вова_,
   {{0x25a028c2,0x672b01d2,0x61e404d9,0x2d962bfc}},	//   šili_, jigj, _šili, _крос,
   {{0xcb676b07,0xdca62e34,0x8af001c2,0xa926c85e}},	// [f700] рате_, _капи, dmət, адал,
   {{0x236f01f4,0x2ee000d7,0x290302d7,0x6d470453}},	//   _ligj_, _haif_, _coja_, coja,
   {{0x290301f4,0x1dde073f,0x00000000,0x00000000}},	//   _doja_, मिकत, --, --,
   {{0xeab2028c,0x6f04021d,0x99920067,0xfc5700a5}},	//   _بعد_, _joic, rzył_, _כביש_,
   {{0x25a0004f,0x6f040035,0x45d602fb,0x2ee03913}},	//   éil_, _moic, рцет, _maif_,
   {{0xdc19004e,0x29030031,0x3f9ec85f,0x6f04026e}},	//   _włąc, _goja_, ystu_, _loic,
   {{0xf8c632ea,0x6f16013c,0x28c61db9,0xa5072123}},	//   र्णय, _olyc, र्णि, реја_,
   {{0x25a92eaf,0x61ed53ae,0x92580714,0x6d474320}},	//   šala_, _šala, лайт_, zoja,
   {{0x8af001c2,0xf8c6045c,0x28c637dd,0x7d01008a}},	//   lməs, र्थय, र्थि, ölsk,
   {{0x30a301e0,0xdce50395,0x50661906,0x26c600a2}},	//   орюв, _mihă, итна, lfoo_,
   {{0x6d47c860,0x8af000a8,0x3f9e0355,0x6f16016e}},	//   voja, nməs, ustu_, _blyc,
   {{0x28c609b4,0x3f9ec861,0x6f04c862,0x645ac863}},	//   र्ति, rstu_, _coic, _izti,
   {{0x6d470597,0x6f04004f,0x2ee03d9c,0x63a100ac}},	//   toja, _doic, _daif_, _zvln,
   {{0x6d47010b,0xd3780124,0x00000000,0x00000000}},	//   uoja, _kuć_, --, --,
   {{0x6d47c864,0x8af001c2,0x2903c865,0x00000000}},	//   roja, ymət, _roja_, --,
   {{0x200f024e,0x3a750ffd,0x5b142698,0x212c00f1}},	//   íliš_, слар, омст, lidh_,
   {{0x212c009d,0x290300be,0x6375004b,0x00000000}},	// [f710] oidh_, _poja_, _išne, --,
   {{0x6cd50ef5,0x212c0874,0x7c3e0036,0x27ea0211}},	//   _اقدا, nidh_, _fxpr, _brbn_,
   {{0x290302c4,0x26df0027,0x28c6170c,0x672bc866}},	//   _voja_, _pauo_, र्धि, tigj,
   {{0xa3ea00c0,0x212c00f1,0x636700b5,0x35f502a4}},	//   मिन_, hidh_, _tűni, йпер,
   {{0x6ebc00b8,0x8af000a8,0x645a0065,0x672b0031}},	//   ष्टु, rmət, _azti, rigj,
   {{0x69ddc867,0x28c608b6,0xa5640698,0x6282030d}},	//   _isse, र्दि, يدون, _afoo,
   {{0x7d0500d7,0x443e01ef,0xe784081b,0x629b3491}},	//   _mohs, _cxt_, _муто, tauo,
   {{0x5c3800a5,0x8af000a8,0x7d05081c,0x00000000}},	//   ירון_, lmər, _lohs, --,
   {{0x212c004f,0x6729c868,0xdb1e01ff,0x645a01a3}},	//   fidh_, _imej, _uppå, _ezti,
   {{0x6f040037,0x212c01a6,0x2ee00090,0x443e00ee}},	//   _soic, gidh_, _saif_, _fxt_,
   {{0x6f0402fb,0xf770006c,0xdee60009,0x443e0069}},	//   _poic, _راہ_, бони, _gxt_,
   {{0x212c009c,0x6d5e00da,0x69ddc869,0x69cf022f}},	//   aidh_, _shpa, _osse, _opce,
   {{0x6f04a1a1,0xd0e200a1,0x6729023c,0x212c1c8b}},	//   _voic, _कोकण_, _mmej, bidh_,
   {{0x307900c2,0x332d0484,0x673b0009,0xd5fa011d}},	//   _גאַנ, liex_, _ljuj, אפשר,
   {{0x69ddc86a,0x672902c6,0xb09a011d,0x6299c86b}},	//   _asse, _omej, _עיקר, _kewo,
   {{0x673bc86c,0x629902e9,0x9f488a96,0x00000000}},	//   _njuj, _jewo, _orné_, --,
   {{0x61fb0160,0x62990260,0xdb0700be,0x00000000}},	// [f720] nxul, _mewo, dujä, --,
   {{0x67290054,0x8af0013b,0xd3780207,0x00000000}},	//   _amej, tməs, _zrću_, --,
   {{0x69ddc86d,0x409a0070,0x3156016b,0x309a016b}},	//   _esse, רבעס, ציען_, רשעמ,
   {{0xe61a0f08,0x7bde3903,0x63ae01b4,0x6299166c}},	//   лде_, _ispu, _åbni, _newo,
   {{0xdb1c1d2b,0xa50a097c,0x00000000,0x00000000}},	//   ntrí, леда_, --, --,
   {{0x7ae4c86e,0x69c4c86f,0x62990359,0xe0c70037}},	//   ldit, mtie, _aewo, _عز_,
   {{0x69c42c40,0x629902c0,0xd90d006c,0x61eb00e9}},	//   ltie, _bewo, _جیل_, _argl,
   {{0x80ca06fe,0x69c4c870,0x61eb023a,0x5214218b}},	//   त्ने, otie, _brgl, ждит,
   {{0x64a64738,0x629902e9,0x80dc0083,0x3a20c871}},	//   _газа, _dewo, বাস্, nzip_,
   {{0x69c4c872,0xf8d80b4a,0x7ae4c873,0xd3780124}},	//   itie, ड़िय, hdit, _tuć_,
   {{0x32ca4fa1,0x212c1093,0x332d0484,0x69c4a0ee}},	//   _было_, ridh_, biex_, htie,
   {{0x62995b0a,0x69c4c874,0x61e400d8,0x7ae4308a}},	//   _gewo, ktie, _šilu, jdit,
   {{0x7ae45612,0x5fda5a77,0xf8d80324,0x201e00b5}},	//   ddit, _बनवल, ड़ाय, szti_,
   {{0x80dc0033,0xa3ac0324,0xddcd0139,0x7e7605d6}},	//   বাহ্, _कटा_, _agaţ, _egyp,
   {{0x8aa7368f,0xb7b30083,0x69c40228,0xac188c7d}},	//   йрад, _ঘন্ট, etie, бору_,
   {{0x69c4c875,0xd1383e9a,0x15fa00ab,0x28c60433}},	//   ftie, lną_, ्हार_, र्सि,
   {{0x69c400ec,0x6f1d0079,0xa3ea00b4,0x00000000}},	// [f730] gtie, mhsc, मिड_, --,
   {{0x672938ef,0x2918009e,0x7ae4c876,0xd1380067}},	//   _smej, _clra_, adit, nną_,
   {{0x69c406c3,0x7ae4002a,0x80ca0099,0xb9010c57}},	//   atie, bdit, त्ये, _दस_,
   {{0xd3661ee1,0x69c4bf7b,0xbebb0051,0x7b2c013b}},	//   _زه_, btie, ciët, nşul,
   {{0xd24601ca,0xf7700041,0x69c404ce,0x69dd008c}},	//   _آن_, رام_, ctie, _usse,
   {{0x25a902a7,0x61ed00c5,0xd1380035,0x798d0cb9}},	//   šalo_, _šalo, jną_, mpaw,
   {{0xd138004e,0x3ea90c6f,0x6299021e,0xc4c400e0}},	//   dną_, _odat_, _pewo, ستوو,
   {{0x130900d4,0x17685187,0x61fb01d7,0xd138010b}},	//   рний_, _груп_, txul, eną_,
   {{0x28c60ebd,0x6594c877,0x2d890176,0xdb1c0132}},	//   र्वि, _нату, _ntae_, ltrã,
   {{0x7ae40a66,0xe9df07c0,0x61eb0116,0x62990103}},	//   zdit, _msú_, _vrgl, _wewo,
   {{0x69c40291,0x61e48a0e,0xf8b2011d,0x5ede0033}},	//   ztie, _šilt, ושי_, যাসে,
   {{0x798d010d,0xd1380035,0x657bbf36,0x69c4c878}},	//   kpaw, aną_, _kuuh, ytie,
   {{0x69c40484,0x657b0044,0x3ea9099e,0xd1380067}},	//   xtie, _juuh, _ddat_, bną_,
   {{0x3f660248,0x3ea90443,0x61e903d0,0xa069081b}},	//   _cœur_, _edat_, mvel, _кала_,
   {{0xeb9a32dc,0x61e90d36,0x3ea9c879,0x7e7b0124}},	//   риб_, lvel, _fdat_, župa,
   {{0x1609065a,0xa3ea09b4,0x6f1d02c9,0x6ec1258f}},	//   वहार_, मित_, chsc, _वायु,
   {{0x7ae4c87a,0xfce6262f,0x69c4c87b,0xf2d20100}},	// [f740] rdit, _допо, utie, וען_,
   {{0xe8f7340a,0x61e90223,0x7ae4ba12,0xb8560274}},	//   олу_, ivel, sdit, ођењ,
   {{0x28c60567,0x7bde03fd,0xdb1e03d0,0x15df021a}},	//   र्षि, _uspu, _oppø, _खैबर_,
   {{0x69c4c87c,0xd1380035,0x61e9c87d,0x68e50211}},	//   ptie, zną_, kvel, adhd,
   {{0xbebb01f4,0xe5a30043,0x2ba80099,0xd1382854}},	//   shëg, дичи, गळवा, yną_,
   {{0x28c64068,0xb7da006c,0x61e9c87e,0xbebb19c1}},	//   र्शि, _پورا_, dvel, niër,
   {{0x61e9213d,0x00000000,0x00000000,0x00000000}},	//   evel, --, --, --,
   {{0xf1a610a9,0xe73a01d3,0xd1380035,0x28c60067}},	//   орон, _теб_, wną_, र्रि,
   {{0xd138004e,0xdce402c4,0xd13a0949,0x59e000b4}},	//   tną_, _luiđ, ихо_, निटर,
   {{0x4fc645ae,0x00000000,0x00000000,0x00000000}},	//   осма, --, --, --,
   {{0x6f1dc87f,0xd1382854,0xdb0e00b5,0xf2ac0033}},	//   thsc, rną_, ntbó, ক্ষণ,
   {{0xd1380035,0x3f66000d,0xd12f0647,0xdced0124}},	//   sną_, _sœur_, _یمن_, _kuać,
   {{0x63b8024e,0x224b01ae,0x6375010b,0xbebb02a2}},	//   luvn, ückt_, _išna, fiër,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc04f3ac1,0x2a7000a8,0x31bc0831,0x00000000}},	//   _ці_, ənbə_, _অনিশ, --,
   {{0x3ea90afb,0x00000000,0x00000000,0x00000000}},	//   _udat_, --, --, --,
   {{0xdce70a21,0xbebb0298,0x00000000,0x00000000}},	// [f750] şlıg, biër, --, --,
   {{0x28c60026,0x798d012f,0x29070093,0xbebb0051}},	//   र्लि, rpaw, ðna_, ciër,
   {{0x798dc880,0x61e9c881,0x5ede0033,0xbf7800e2}},	//   spaw, zvel, যারে, _đuợc_,
   {{0x80ca227d,0x5ead0083,0x63b802c4,0xdb0700a0}},	//   त्ते, ট্রে, duvn, hujú,
   {{0xd618017e,0xbafa00a5,0x8afa00a5,0x00000000}},	//   يتها_, _ההרש, _הפרק, --,
   {{0x03953a53,0x2db800a5,0xb4d500ab,0xb97a00a5}},	//   прия, קלון_, िजे_, _לנשי,
   {{0x8ccd0534,0x7bc7c882,0xdb07016f,0xdb1c609a}},	//   द्यो, ntju, dujú, ltrá,
   {{0x11d9004f,0xd3d80037,0x25b00225,0x61e9c883}},	//   موعة_, تبها_, üllü_, tvel,
   {{0xdb1c0079,0x61e92432,0x8cdc0067,0x94ab0079}},	//   ntrá, uvel, _फसलो, _نطاق_,
   {{0x44b45544,0x00000000,0x00000000,0x00000000}},	//   _обус, --, --, --,
   {{0x4acb1dc1,0x61e974e4,0xdee600ca,0x7bc501e8}},	//   ाभाव, svel, пони, _nqhu,
   {{0xdb1c0187,0xdbd00187,0xba3b0b88,0xd6cf0210}},	//   ktrá, užív, _geïg, етi_,
   {{0xee3700d4,0x5ede0033,0x427a024b,0x00000000}},	//   зня_, যালে, _האנג, --,
   {{0xc0e50421,0x3f770395,0xf1b9343a,0x00000000}},	//   _хокк, _băut_, muš_, --,
   {{0xeb971b96,0xf1b900d5,0xbebb19c1,0x00000000}},	//   зис_, luš_, riër, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x777c8165,0x61ed0a78,0x3b07547d,0xbebb0130}},	// [f760] _surx, _šalj, чето_, piër,
   {{0xddcd05e2,0xb4d500be,0xb60300ee,0x3ea2c884}},	//   _ugaš, िजो_, _mláč, lakt_,
   {{0xf1b900d5,0x00000000,0x00000000,0x00000000}},	//   huš_, --, --, --,
   {{0x6d4ec885,0xdb0700a0,0xd048013b,0x940c013b}},	//   loba, zujú, gedə, _gedə_,
   {{0x5fdd00b1,0xb0bd0096,0xf1b90207,0x7ae6017b}},	//   _फैसल, ्भाग, juš_, _iakt,
   {{0x6d4e3250,0x3ea2b228,0xad9b01ef,0xf1b900f4}},	//   noba, hakt_, lxúc, duš_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e3395b,0xa6b50086,0x7ae6014e,0x6d4ec886}},	//   _поса, _осущ, _jakt, hoba,
   {{0x7ae600d4,0xcad70319,0x6d4ec887,0x63b80187}},	//   _makt, לוקת_, koba, suvn,
   {{0xf55a004f,0x28cf0785,0xdced0024,0xf99300a5}},	//   _الطب_, स्पि, _iwaħ, ערת_,
   {{0x6d4ec888,0x25a6010d,0x290a0124,0x7ae60523}},	//   doba, lsol_, _moba_, _oakt,
   {{0x3f8a0ae0,0x7ae626e3,0xc7b30122,0x290ac889}},	//   ību_, _nakt, עבר_, _loba_,
   {{0x6d4e6d0e,0x25a6c88a,0xdb0701ba,0xdced0024}},	//   foba, nsol_, pujú, _jwaħ,
   {{0x6d4e8cd0,0x601801d3,0x61e22e0f,0x98ba00b8}},	//   goba, _моля_, _isol, ropě_,
   {{0x7ae63ede,0x3d0d00ab,0xb5fd0116,0x60da013b}},	//   _bakt, _सकीं_, _izše, metm,
   {{0xe7f00fbf,0x7ae600da,0x290a0009,0x60dac88b}},	//   घटना_, _cakt, _aoba_, letm,
   {{0x6d4ec88c,0x7bc70c75,0x3da400af,0x61e20024}},	// [f770] boba, stju, _прэб, _jsol,
   {{0x290a16ab,0x60da01d6,0x61e208c7,0xdb1c0098}},	//   _coba_, netm, _msol, rtrá,
   {{0x7ae6c88d,0x290a824d,0xdb1cc88e,0x8af000a8}},	//   _fakt, _doba_, strá, mlən,
   {{0x61e20a69,0x7c3a008e,0xb4d506fe,0x00000000}},	//   _osol, útre, िज्_, --,
   {{0x84e58de1,0x60da1c6c,0x6365002a,0xa509692c}},	//   долж, ketm, lóng, жела_,
   {{0x290ac88f,0x8af0013b,0x00000000,0x00000000}},	//   _goba_, nlən, --, --,
   {{0x67d4c890,0x61e2c891,0x7ae60225,0xa3d20166}},	//   _пору, _asol, _yakt, војч,
   {{0x68e76ca9,0x27f80187,0xf1b956f1,0x290ac892}},	//   _hajd, šený_, tuš_, _zoba_,
   {{0xd36e00f3,0xc24500aa,0x6d4ec893,0x3ea25c3a}},	//   جهي_, ьник, yoba, vakt_,
   {{0x80bd00a1,0x6d4e01b7,0xb6030097,0x68e70024}},	//   _शाळे, xoba, _vláč, _jajd,
   {{0x68e7c894,0x3ea2be26,0x6d4e737c,0x932700b5}},	//   _majd, takt_, voba, _ٹران,
   {{0x68e7168a,0x61e2009f,0x6375005f,0x00000000}},	//   _lajd, _fsol, _išno, --,
   {{0x6d4ec895,0x3ea204ca,0x7ae60802,0x4900021a}},	//   toba, rakt_, _rakt, रामो_,
   {{0x68e70a0b,0x28cf0266,0x3ea2c896,0xf8cf0b35}},	//   _najd, स्मि, sakt_, स्मय,
   {{0x6d4ebb13,0x290ac897,0x7ae600da,0x3ea2c898}},	//   roba, _roba_, _pakt, pakt_,
   {{0x6d4e0232,0xc0520052,0x290a0620,0x8f9a011d}},	//   soba, _שזה_, _soba_, _ויקי,
   {{0xc3320122,0x7ae6c899,0x68e7af62,0x6d4e0ce0}},	// [f780] דון_, _vakt, _bajd, poba,
   {{0x7ae61201,0x68e7006d,0x3ea01441,0x8af00095}},	//   _wakt, _cajd, _heit_, clən,
   {{0x7ae6c89a,0x3ce7074f,0x46ea02f2,0x3ea04f2d}},	//   _takt, _छोटे_, жден_, _keit_,
   {{0x3a3f3257,0xe73711ab,0x60da2d61,0x290a018e}},	//   _župe_, мех_, zetm, _woba_,
   {{0x290ac89b,0xa5da1b15,0x6ec10ac4,0xd6e00033}},	//   _toba_, تبار_, _वासु, ণালয,
   {{0xa3ea0953,0x3ea02cce,0x68e7c89c,0xa50703fa}},	//   मिल_, _leit_, _gajd, деља_,
   {{0x25a64a7b,0xdb1c01b4,0x2d800223,0xba3b0176}},	//   ssol_, rtræ, _luie_, _veïe,
   {{0x3ea0c89d,0x8af00095,0xdb1c4ce5,0x68e71a0c}},	//   _neit_, zlən, stræ, _zajd,
   {{0x6722002f,0xdb1c01ff,0x00000000,0x00000000}},	//   mhoj, mträ, --, --,
   {{0x6aa4002f,0xdb1c0301,0x3d0d0354,0xa3b604aa}},	//   haif, lträ, _सकें_, _जिप_,
   {{0x2018c89e,0x60da01d6,0x3d0202e4,0x398401ff}},	//   ári_, retm, शाने_, _lös_,
   {{0xdb1c3230,0x7d1e6fc9,0x3ea00284,0x61e20079}},	//   nträ, _alps, _ceit_, _tsol,
   {{0x3ea001a6,0x8af000a8,0xdb1c033b,0x2d800139}},	//   _deit_, tlən, iträ, _cuie_,
   {{0x2d800298,0x660201ed,0x00000000,0x00000000}},	//   _duie_, ixok, --, --,
   {{0x3ea0152b,0x69a414ab,0xead51bdc,0x8af000a8}},	//   _feit_, _चौबी, новь, rlən,
   {{0x61edc89f,0x25a902dd,0x80ca0099,0x68e7c8a0}},	//   _šali, šali_, त्रे, _sajd,
   {{0x68e7c8a1,0xf1bc0083,0xda340409,0x672201f4}},	// [f790] _pajd, _অনুভ, веты, dhoj,
   {{0x3ea002bf,0x80dc0033,0x6f0d00e2,0x8af0013b}},	//   _zeit_, বাক্, _hoac, lləl,
   {{0x68e7c8a2,0x672202c4,0xdb1c033b,0x213e01ef}},	//   _vajd, fhoj, fträ, inth_,
   {{0x1995086c,0x6f0d24d3,0x81d50033,0x39840093}},	//   _памя, _joac, হিত_, _fös_,
   {{0x25a90082,0x2ee926fb,0x6f0d747a,0x39842af1}},	//   éal_, _maaf_, _moac, _gös_,
   {{0x2366024e,0x2edc0240,0x490007df,0x9f9f0298}},	//   _ahoj_, _बस्त, राणो_, _wéét_,
   {{0xc7c42235,0x437500af,0x3f8e0051,0x7d0802b1}},	//   _исти, нуит, _ntfu_, ödsi,
   {{0x2366006f,0x645f0095,0x6722002f,0x2ee90223}},	//   _choj_, əqil, choj, _naaf_,
   {{0x28cf142a,0xe1f10071,0x26dd0c1f,0x28c609b4}},	//   स्थि, اسب_, mewo_, र्कि,
   {{0x3ea002bf,0x63657f86,0x2d800345,0x00000000}},	//   _seit_, dóne, _ruie_, --,
   {{0x6f0d021d,0x2ee9099e,0x2d800139,0x00000000}},	//   _boac, _baaf_, _suie_, --,
   {{0x28cf0518,0xe1f108cf,0x2ee90036,0x2d800160}},	//   स्ति, _مست_, _caaf_, _puie_,
   {{0x3ea02129,0x2d800138,0x6f0d0952,0x78a5c8a3}},	//   _veit_, _quie_, _doac, kahv,
   {{0x3ea001ae,0xc0e20166,0x2ee901ef,0x81d50033}},	//   _weit_, _бошк, _eaaf_, হিদ_,
   {{0x6aa419c6,0x8c4306e4,0x636501ef,0x6c360079}},	//   taif, гере, pónd, رفرا,
   {{0x8af00095,0x6289c8a4,0x2ee90fdb,0x236d0009}},	//   lməz, nceo, _gaaf_, nmej_,
   {{0xe9d72ad7,0x6aa4c8a5,0x6df30037,0xc18c0070}},	// [f7a0] нкт_, raif, _مكيا, ַטאָ,
   {{0xd5da0067,0xebe64ed5,0x30bd0033,0xbd4604a3}},	//   _मैगज, _зооп, _অসুস, _سنجي,
   {{0xe50318da,0xdb1c1193,0x67220055,0x28c60f17}},	//   लानि_, tträ, thoj, र्गि,
   {{0xe5c610d7,0xf8b0006c,0x660201d7,0x6f0d002a}},	//   еско, _چکا_, txok, _xoac,
   {{0xdb1c306a,0xceb302b8,0x8af000a8,0x4900021a}},	//   rträ, ריד_, nləm, रादो_,
   {{0x53e642c2,0xdb1cc8a6,0x628b03bc,0x2b40c8a7}},	//   ециа, strä, _afgo, lnic_,
   {{0xbebb01f4,0xe3af0037,0xdb1c01ff,0x6ec1057c}},	//   dhën, مري_, pträ, _वालु,
   {{0xdb1c0031,0x8af000a8,0xdc3c00ee,0x6d5c02b1}},	//   durë, kləm, _ošľa, hlra,
   {{0x2ee9b25b,0x1ddf0066,0x2b401d4a,0xa3ac0354}},	//   _raaf_, _पैंत, inic_, _कटक_,
   {{0x2b407398,0x6f0d00af,0xeb0d00b4,0x00000000}},	//   hnic_, _soac, _िक्त_, --,
   {{0x44386c3e,0x6f0d289c,0x2366006f,0x6e950352}},	//   _är_, _poac, _thoj_, кину,
   {{0x78a500cd,0x9f3503d0,0x6d5c55c8,0x00000000}},	//   zahv, темі, elra, --,
   {{0xe33702b5,0x657a47e7,0x61ed168a,0x2b40c8a8}},	//   _אראפ_, _kith, _šalv, dnic_,
   {{0x63651111,0x645a0097,0x645600a8,0x657a009f}},	//   róne, _kyti, əyir, _jith,
   {{0x8af00095,0x657ac8a9,0x602600f7,0x6f0d0395}},	//   lməy, _mith, _démé, _toac,
   {{0x67d301c0,0x63750009,0x2b4001f2,0xdbdc0138}},	//   nějš, _ašnj, gnic_, _cáña,
   {{0x3a7538bb,0x645a010b,0x7b6400c3,0x8af000a8}},	// [f7b0] тлар, _lyti, утре, nməy,
   {{0x657a111c,0xb4df00a1,0x97a701f5,0x00000000}},	//   _nith, _तसे_, ердл, --,
   {{0x81d60033,0xe8df0023,0x78a53f1a,0x645ac8aa}},	//   াটি_, _ngục_, rahv, _nyti,
   {{0xf7700071,0x657a09e3,0x2b40c8ab,0x8ccd1db1}},	//   مان_, _aith, cnic_, द्रो,
   {{0x645a0107,0x657a09bb,0x7aed00af,0x61240260}},	//   _ayti, _bith, mdat, _gòlg,
   {{0x7aed6284,0x81d60083,0x657a00d1,0x645ac571}},	//   ldat, াটা_, _cith, _byti,
   {{0x657ac8ac,0x7aed6a63,0xdb1c071b,0x69cd10be}},	//   _dith, odat, strå, ltae,
   {{0xf99f0c1f,0x657a1f06,0x6448008c,0x52752746}},	//   _kwè_, _eith, _dxdi, купу,
   {{0xf99f02e9,0x7aedc8ad,0x6289c8ae,0x69cda692}},	//   _jwè_, idat, rceo, ntae,
   {{0x657ac8af,0x7aed0421,0xdb1c01f4,0x62890079}},	//   _gith, hdat, turë, sceo,
   {{0x7afd41eb,0x28c60518,0x69cd1b43,0x7aedc8b0}},	//   _onst, र्टि, htae, kdat,
   {{0x657a04f4,0x6d4502c4,0xa29500d4,0xfaff0031}},	//   _zith, _ajha, _раді, _shën_,
   {{0xd00e0105,0x2b40c8b1,0xf99f021e,0x00000000}},	//   ملی_, vnic_, _nwè_, --,
   {{0x7afdc8b2,0x7aed0051,0xdbdc008d,0x00000000}},	//   _anst, edat, _báða, --,
   {{0xdca3182f,0x2b40c8b3,0xf99f0107,0x636501ef}},	//   раси, tnic_, _awè_, cónc,
   {{0x7aed00a7,0xf99f02e9,0x3a3f2df4,0x0b4317b7}},	//   gdat, _bwè_, _župa_, ансн,
   {{0x2b40c8b4,0x1ce7006c,0xe8ea02ee,0x7afd03d0}},	// [f7c0] rnic_, رکیٹ_, ммад_, _dnst,
   {{0x7afdc8b5,0xa92319b3,0x2b40c8b6,0x48760118}},	//   _enst, адул, snic_, نداس,
   {{0x657ac8b7,0x25adc8b8,0x7aed0139,0xb8ca0246}},	//   _rith, _avel_, bdat, _गज_,
   {{0x28c60fbf,0x657a00d1,0xf8c6012f,0xeabf009e}},	//   र्जि, _sith, र्जय, _clùd_,
   {{0x67d301c0,0x657a00f8,0x5f031140,0xd7070382}},	//   vějš, _pith, षात्_, ънце_,
   {{0xd9464981,0xa3b60066,0x5ede0033,0x00000000}},	//   _реги, _जिद_, যাটে, --,
   {{0xc7a31b17,0x7bce92d2,0x67d300b8,0x657a1bba}},	//   _виск, ntbu, tějš, _vith,
   {{0x657a0052,0x645a3320,0x8af000a8,0x77690024}},	//   _with, _vyti, tməy, _ghex,
   {{0x216614d0,0x28cf0b35,0xdb1c00a2,0x2d920103}},	//   ктог, स्वि, guré, _ntye_,
   {{0x8af00095,0x657a11cc,0x28c61365,0x00000000}},	//   rməy, _uith, र्चि, --,
   {{0x61ed00d8,0x7aed0035,0xc49b00a5,0x2d920103}},	//   _šalt, ydat, _חשבת, _atye_,
   {{0x612402e9,0x7aed13ee,0xdd950763,0xdbdc0093}},	//   _sòld, xdat, ламы, _ráða,
   {{0xa3ea08b6,0x7aedc8b9,0xa3de0035,0x57df0354}},	//   मिक_, vdat, दौर_, _नन्ह,
   {{0xc27b0c37,0xdd9400c7,0xba3b11cc,0x7aed055c}},	//   _חרדי, рары, _beïn, wdat,
   {{0xd1380e18,0xf99f021e,0x7aed190f,0x00000000}},	//   mią_, _swè_, tdat, --,
   {{0xc8c604aa,0xd13817a9,0x7aed027a,0x69cd0086}},	//   र्घट, lią_, udat, ttae,
   {{0x7aedc8ba,0x6d45012f,0x28a700c3,0x58d53e10}},	// [f7d0] rdat, _tjha, вшег, лоат,
   {{0x7aed1949,0x69cd01d7,0xd138297a,0x7d1c01ed}},	//   sdat, rtae, nią_, ckrs,
   {{0x76b900af,0x7aed0d0f,0x6d551980,0xba3b0c7c}},	//   елер_, pdat, moza, _geïn,
   {{0x69cd0079,0x6f1dc8bb,0x7afdc8bc,0x8c1a00a5}},	//   ptae, nksc, _unst, _נורי,
   {{0xd13800d8,0x63650093,0xb0c2021a,0x00000000}},	//   kią_, jóna, _शांग, --,
   {{0xd469465e,0x8cd60026,0xf1b90009,0x044504b2}},	//   ниле_, म्पो, vrš_, лелн,
   {{0x888202fd,0x2b59005f,0x69120a8a,0x00000000}},	//   _ایمن, _kksc_, _tæer, --,
   {{0xdb1cc8bd,0x224001a0,0x6375023a,0x6d55c8be}},	//   turé, _žika_, _kšni, hoza,
   {{0xa3e30299,0x6d55c8bf,0x78b2008a,0x3f590132}},	//   _पैर_, koza, _ákvö, héus_,
   {{0x60095c36,0x29110124,0xbebb0031,0x6f1dc8c0}},	//   еном_, _joza_, shël, eksc,
   {{0x3ea60073,0x2911c8c1,0xdb1c00f7,0x6d5500b5}},	//   линг, _moza_, suré, doza,
   {{0x2911c8c2,0xdb1cc8c3,0x51f52499,0xba3b213d}},	//   _loza_, strú, _مستر, _reïn,
   {{0x2d840248,0xd1382854,0x629b0159,0xef170421}},	//   ême_, bią_, mbuo, умя_,
   {{0x6d55c8c4,0xfaff01f4,0x6f1d0051,0xc6360070}},	//   goza, _anë_, aksc, אָלק_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1c0bec,0xa3b6004e,0xba3b12c3,0xb0cf0569}},	//   skrs, _जिस_, _veïn, त्रग,
   {{0x7bcec8c5,0x6d55c8c6,0x80ca0355,0x00000000}},	// [f7e0] stbu, boza, त्के, --,
   {{0x28cf0d00,0x8ca50035,0x00000000,0x00000000}},	//   स्लि, करणो, --, --,
   {{0x2911c8c7,0x9b4606c9,0xa3e20067,0x00000000}},	//   _doza_, _مندو, _कैंप_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3636004f,0x35b60a2b,0x75380009,0x00000000}},	//   دراس, ущес, tivz, --,
   {{0x2cb312ee,0xb5fd08b7,0x00000000,0x00000000}},	//   _xdxd_, _izšl, --, --,
   {{0xd37a1412,0x1867c8c8,0xfaff01f4,0xd49901e0}},	//   нчи_, _бари_, _ynë_, трі_,
   {{0x798618a6,0xd378025c,0xdc080029,0xd1380035}},	//   _kukw, _opće_, dēļa, wią_,
   {{0x7986000e,0x6d55c8c9,0x2be100b8,0x86460274}},	//   _jukw, yoza, _पन्थ, _снаж,
   {{0x8af00095,0x79860186,0x68ee0069,0x6365764c}},	//   sləh, _mukw, _jabd, róna,
   {{0x68ee0ec7,0xd1383e96,0x39570d85,0x798625b4}},	//   _mabd, rią_, רשים_, _lukw,
   {{0x68eec8ca,0xd24f00d1,0xd13800d8,0x6aa60345}},	//   _labd, _کنه_, sią_, _nekf,
   {{0x6d55c8cb,0x6f1dc8cc,0x835300b5,0x7986007b}},	//   toza, rksc, _اپنا, _nukw,
   {{0xceb40095,0xdfec0461,0xd528055c,0x00000000}},	//   _edə_, _जनपद_, _bổn, --,
   {{0x6d55c8cd,0x6aa60345,0xdc21035f,0xdbe30042}},	//   roza, _bekf, _iċċe, téñe,
   {{0x9b580e0a,0xab6206d3,0x6d55b2f9,0x79863a34}},	//   гист_, şünc, soza, _bukw,
   {{0x2911c8ce,0xba3b2069,0x1da9aaa2,0x2caa0118}},	// [f7f0] _poza_, _geïl, _कबित, babd_,
   {{0x68ee4b86,0x798601d5,0x3f590183,0x00000000}},	//   _cabd, _dukw, péus_, --,
   {{0x1a6500d1,0x7aee00c3,0x291100cd,0x645e00be}},	//   _چیزی_, öntä, _voza_, üpil,
   {{0xfaff01d2,0xef1f008f,0x36d5052c,0x6282317e}},	//   _unë_, nkü_, родр, _ngoo,
   {{0x660514b4,0x5fa623db,0x636500a0,0x7986251e}},	//   рпла, _कौसल, fónn, _gukw,
   {{0x6282c8cf,0x7aef099e,0x27ea0282,0x66190067}},	//   _agoo, _hact, _fsbn_, rywk,
   {{0x629b055c,0x59a900dc,0x5eab0033,0x79860027}},	//   tbuo, _चौतर, _কানে, _zukw,
   {{0xdc210484,0x78a77526,0x7aef014c,0x11d90037}},	//   _aċċe, _hejv, _jact, نوعة_,
   {{0x7aef0608,0x629b00d8,0x862701c8,0x13060086}},	//   _mact, rbuo, _сьве, рный_,
   {{0xdb1c0249,0x6282030d,0x8574094f,0x00000000}},	//   strø, _egoo, _глух, --,
   {{0x80a70083,0x5f069959,0x63480355,0x00000000}},	//   _খাদ্, азна, měnn, --,
   {{0x539a0122,0x69dd0910,0x25a00043,0x8503007c}},	//   _ייעו, _opse, ţile_, लावट_,
   {{0x78b50b67,0xe3c70033,0x00000000,0x00000000}},	//   _odzv, _শনিব, --, --,
   {{0xdca34745,0x78a7000c,0x59a909b1,0x40870166}},	//   жари, _nejv, _चौधर, _судб,
   {{0xbb56004f,0x68eec8d0,0x79862e2c,0x69ddc8d1}},	//   لنسب, _rabd, _sukw, _apse,
   {{0x0d8628cc,0x68ee06d4,0x79860298,0x00000000}},	//   _клин, _sabd, _pukw, --,

   {{0xddcd00f4,0x78a7007e,0x9f4800ee,0x00000000}},	// [f800] _zgaž, _bejv, _ornú_, --,
   {{0x68ee007a,0xba3b1192,0x637500c7,0xd52800e2}},	//   _qabd, _geïm, _išnu, _tổn,
   {{0x7aef0f00,0x78a7c8d2,0x3f870200,0xc6a60183}},	//   _fact, _dejv, _junu_, арли,
   {{0x7a2c00f7,0x3f870093,0x7986313a,0x7bde035f}},	//   _côté, _munu_, _tukw, _ippu,
   {{0x7ae4c8d3,0x1a9b02b5,0x5506558e,0x3f87c8d4}},	//   meit, _ביכע, ичка, _lunu_,
   {{0x7ae4c8d5,0xb7960274,0x636500a0,0x291c80c4}},	//   leit, _враћ, fóno, övad_,
   {{0x66e6290e,0xb226008a,0x69c41e83,0x61eb099e}},	//   _кова, kvæð, luie, _asgl,
   {{0xb024098b,0x7ae4c8d6,0xdb1c0055,0x6b8300e0}},	//   _ngườ, neit, drrë, _ènge,
   {{0x69c4c8d7,0xe57a0036,0x3f87013a,0x00000000}},	//   nuie, _аза_, _aunu_, --,
   {{0x3f870092,0x7bde01d3,0x7ae40a48,0xdb1c0831}},	//   _bunu_, _oppu, heit, durí,
   {{0x7ae4c8d8,0x25ec0084,0x77620391,0x61eb12c3}},	//   keit, _आईडी_, olox, _esgl,
   {{0xe29a4bf1,0x7ae4702b,0x3f870009,0x69c4c8d9}},	//   _рад_, jeit, _dunu_, kuie,
   {{0x7bdec8da,0x3eabc8db,0x7ae400e9,0x61240014}},	//   _appu, ract_, deit, _eòla,
   {{0x2d99c8dc,0x69c4c8dd,0x00000000,0x00000000}},	//   rpse_, duie, --, --,
   {{0x7ae4c8de,0x7aef3d46,0x06bc00c8,0x0b880ece}},	//   feit, _pact, _ইউনি, исти_,
   {{0x7ae401d7,0x307b011d,0xbb2800d8,0x609500b5}},	//   geit, _באונ, ацуе_, _پچیس_,
   {{0x69c400c8,0x7bde0382,0x00000000,0x00000000}},	// [f810] guie, _eppu, --, --,
   {{0x3ea900a5,0x256905ee,0x00000000,0x00000000}},	//   _heat_, kúla_, --, --,
   {{0x7ae4c8df,0x6d470254,0x3ea900d7,0x8d74026e}},	//   beit, mnja, _keat_, _بايا,
   {{0x7ae4c8e0,0x14c900a1,0x6d470620,0x02a5046c}},	//   ceit, _राहण, lnja, _गजेन,
   {{0x6aad128f,0x69c4002d,0x8af000a8,0x67f000b5}},	//   maaf, cuie, tləv, tójá,
   {{0x3ea9bb09,0x6aad5ca0,0x6365c0f4,0x649802fb}},	//   _leat_, laaf, tóno, атър_,
   {{0xd7c900d1,0x2d8102a7,0x00000000,0x00000000}},	//   _حوزه_, _mihe_, --, --,
   {{0x6aad566f,0x14c905f8,0x68e50086,0x6365c8e1}},	//   naaf, _रावण, lehd, róno,
   {{0x6594145c,0x3f87c8e2,0x6d47942e,0x612401da}},	//   _мату, _sunu_, knja, _sòla,
   {{0x7ae402c9,0x6aad13ee,0x8af00095,0x3f875185}},	//   zeit, haaf, llət, _punu_,
   {{0x6d470496,0x14190037,0x3ea9c8e3,0x6aad08b8}},	//   dnja, _حياة_, _beat_, kaaf,
   {{0x7ae4043f,0xdb1c2b01,0x2d810086,0x643a0070}},	//   xeit, turí, _aihe_, _געענ,
   {{0x7ae4c8e4,0x320900d0,0x21750043,0x2d8101d5}},	//   veit, _çay_, _лукр, _bihe_,
   {{0x7ae42b77,0x4095004f,0x2d9e024e,0x61e9c8e5}},	//   weit, _الغر, ďte_, mwel,
   {{0x7ae4c8e6,0xab2a01ee,0xdb0a0187,0x61e9345d}},	//   teit, гова_, šník, lwel,
   {{0x6aadc8e7,0x69c4c8e8,0x6d475556,0x3ea90211}},	//   gaaf, tuie, anja, _geat_,
   {{0x7ae42a39,0x6d470254,0x61e9c8e9,0x81d50033}},	// [f820] reit, bnja, nwel, হিক_,
   {{0x7ae402c9,0x2d81070b,0x6f16b207,0x6d47011c}},	//   seit, _gihe_, _hoyc, cnja,
   {{0x61e9c8ea,0x7ae4c8eb,0x6f04c8ec,0x7bde00be}},	//   hwel, peit, _knic, _uppu,
   {{0x61e9c8ed,0xd378022f,0x7b1801ef,0x69c400a2}},	//   kwel, _opća_, _víus, puie,
   {{0x69c4c8ee,0x6f04c8ef,0x85030067,0x2d810027}},	//   quie, _mnic, लांट_, _yihe_,
   {{0x61e93571,0x25690037,0x6f16073a,0x2ba5021a}},	//   dwel, túla_, _loyc, गीवा,
   {{0x63a40254,0xb4e800dc,0x6f042c7b,0x33260088}},	//   ćino, _बसी_, _onic, _plox_,
   {{0x070c0567,0x6d470e5e,0xfbd300a5,0xaaba1ef5}},	//   _सचिव_, znja, פתח_, ेलिक,
   {{0x44200029,0x8af000a8,0x61e9c8f0,0xc8cf0127}},	//   ņi_, lləs, gwel, स्कट,
   {{0xa3e30084,0x644f0035,0x80d300a1,0x67222917}},	//   _पैक_, _ście, ब्ले, lkoj,
   {{0x6d4733c7,0xb5fd053d,0xf1b901ba,0x2d810027}},	//   vnja, _vyše, vyše_, _rihe_,
   {{0x0dcb3804,0x395a2cdc,0x6722021f,0x6f04014c}},	//   луги_, hops_, nkoj, _cnic,
   {{0x6d4715d7,0x6f0463db,0xe2870df3,0x5eab0033}},	//   tnja, _dnic, _اطمی, _কাদে,
   {{0xc8c70026,0x303900d1,0x6aad034d,0x6722085f}},	//   _लाइट, اتیک_, waaf, hkoj,
   {{0x6d472676,0x6aad0054,0xc2eb0083,0x3ea90107}},	//   rnja, taaf, কারি_, _teat_,
   {{0x6d4719cd,0x6f0484fa,0x61240107,0x6d5e0282}},	//   snja, _gnic, _kòlo, _ekpa,
   {{0x8af001c2,0x593900d8,0x6d470293,0xa2d005fc}},	// [f830] vlət, азаў_, pnja, _धान्,
   {{0x6d4002e1,0x213ec8f1,0x6aad030d,0xa3e80026}},	//   émat, nith_, saaf, यबा_,
   {{0x61e9c8f2,0xdbe301ef,0xdb050523,0x61240107}},	//   zwel, _téña, _avhå, _lòlo,
   {{0xcf9302b5,0x7bc7a6e2,0x61e9c8f3,0x9599c8f4}},	//   לטע_, muju, ywel, атку_,
   {{0xd5bb87c0,0x7bd501a3,0x74cd07df,0x00000000}},	//   усе_, ltzu, _सादृ, --,
   {{0x201e01c8,0x03951172,0x85030127,0x00000000}},	//   kyti_, ория, लाइट_, --,
   {{0xdb1c09ab,0x7bd503cb,0x8af001c2,0x7bc70a1e}},	//   ctró, ntzu, mlər, nuju,
   {{0x201e01c8,0x8af001c2,0xb06500c3,0x61e9679e}},	//   dyti_, llər, hdää, twel,
   {{0x7bc737db,0xe613004f,0x213e012f,0x61e901e4}},	//   huju, _عشر_, fith_, uwel,
   {{0x61e9c8f5,0x8af001c2,0x7bc72638,0x6f04017b}},	//   rwel, nlər, kuju, _snic,
   {{0xa0691e46,0x201e010b,0xdf4a1d13,0xa93a00a5}},	//   рана_, gyti_, изод_, שתתפ,
   {{0xdb1c00ac,0x61e98ff9,0x3cf30069,0x2b490009}},	//   kurá, pwel, _aaxv_, jnac_,
   {{0x8af001c2,0x926700bf,0x20d501e0,0x7e6d0067}},	//   klər, _ادام, _дійс, _czap,
   {{0x53dd26d4,0xdb1c027d,0x83dd0026,0x67290024}},	//   _महाश, strü, _महाआ, _llej,
   {{0x8af00095,0x67291298,0x30790070,0x7bc7435f}},	//   dlər, _olej, _דאַנ, guju,
   {{0x612d3de8,0x2b49c8f6,0xff5202fd,0x6f0409e8}},	//   _búlg, gnac_, _تخت_, _unic,
   {{0x8af00095,0xdb1c72c5,0xbebb0031,0x00000000}},	// [f840] flər, gurá, thëv, --,
   {{0x6729c8f7,0xd91009b9,0x9d460b00,0x673b0c4f}},	//   _alej, ریز_, _феод, _amuj,
   {{0x395ac8f8,0x57ea0fc5,0x672947e0,0x6d5c1adb}},	//   rops_, рдем_, _blej, mora,
   {{0x2b491d35,0x6d5c1114,0xd6d900d4,0xf7430c06}},	//   cnac_, lora, йті_, мехо,
   {{0x672200da,0x6729006d,0x8af00095,0x7d170095}},	//   rkoj, _dlej, blər, _yoxs,
   {{0xdb1c0955,0x7af600d8,0x6729006c,0x6d5c7605}},	//   ctrò, ldyt, _elej, nora,
   {{0x61240176,0x6729c8f9,0x6d5c0065,0x00000000}},	//   _dòll, _flej, iora, --,
   {{0x2918c8fa,0x6d5cc8fb,0x213e00e9,0x7af6c8fc}},	//   _hora_, hora, with_, ndyt,
   {{0x6d5cc8fd,0x2918c8fe,0x69b202e4,0x69d6c8ff}},	//   kora, _kora_, ेंटी, ntye,
   {{0x6d5cc900,0x201e01c8,0x2b4d011c,0xe9ff00e2}},	//   jora, tyti_, čeci_, _liếc_,
   {{0x2918c901,0x28cf04cc,0x213e0341,0x27fa184b}},	//   _mora_, स्टि, rith_, nvpn_,
   {{0x8af001c2,0x201e01c8,0xeeab002d,0x7bc7c902}},	//   zlər, ryti_, шток_, vuju,
   {{0x7bc7072e,0x6d5cc903,0x8af00095,0x201e010b}},	//   wuju, fora, ylər, syti_,
   {{0x7bc735c5,0x6d5c5e03,0x2918c904,0x61e20987}},	//   tuju, gora, _nora_, _ipol,
   {{0x8af00095,0xb5fd00ee,0xe9ff00e2,0x00000000}},	//   vlər, _myša, _biếc_, --,
   {{0x7bc70452,0x28dd52cf,0x7bd506a2,0x2918c905}},	//   ruju, न्नि, rtzu, _aora_,
   {{0x29180657,0x8af001c2,0x7bc732c6,0x5a350265}},	// [f850] _bora_, tlər, suju, чнат,
   {{0x25fe0e04,0x7bc7c906,0x61e2276d,0xc8670ea0}},	//   लिनी_, puju, _mpol, отеи,
   {{0x8af00669,0x6729c907,0x2918c908,0xf770042c}},	//   rlər, _plej, _dora_, چان_,
   {{0xd36600bf,0xf7701b15,0x61e2004e,0x8af00095}},	//   _سه_, نان_, _opol, slər,
   {{0xd2460514,0x291832fb,0xe5a50377,0xfa960317}},	//   _أن_, _fora_, чили, _מדרש_,
   {{0xd0060514,0x63652cad,0x2918c909,0x7e6000ab}},	//   _كل_, móni, _gora_, ümpi,
   {{0x63650168,0x61e2c90a,0xd36e0088,0x00000000}},	//   lóni, _apol, گهي_, --,
   {{0x6d5c263f,0x130901e0,0x673b0010,0x61240176}},	//   zora, сний_, _umuj, _dòlm,
   {{0x68f5c90b,0x63650b4c,0x5159010b,0xdafe021d}},	//   _kazd, nóni, йшоў_, _pãºb,
   {{0x68f59200,0x2cb11cca,0x81dc0033,0x7e640027}},	//   _jazd, jazd_, ডিং_, _ryip,
   {{0x6d5c972f,0x4acb1604,0xb4e70864,0xaacb0761}},	//   vora, िलाव, यजी_, िलाक,
   {{0xd343006c,0xbebb01f4,0x68f5857a,0x3a200225}},	//   _تفصی, dhës, _lazd, yyip_,
   {{0x63650093,0x00000000,0x00000000,0x00000000}},	//   jóni, --, --, --,
   {{0x68f50393,0x6365365c,0xf8dd012f,0x28c7051d}},	//   _nazd, dóni, न्मय, _लागि,
   {{0xf0920122,0x6d5c0425,0xeb9a02ee,0x7f5d0138}},	//   _אנו_, rora, сиб_, bosq,
   {{0x6d5c9457,0x63650300,0xa0263115,0xacf7006c}},	//   sora, fóni, stöö, _ہسپت,
   {{0x6d5c3c5d,0x61fbc90c,0x29189502,0x63650138}},	// [f860] pora, nvul, _pora_, góni,
   {{0x0e570bed,0x38c802fd,0x69d602ee,0x00000000}},	//   _משפט_, تاری_, rtye, --,
   {{0xe9ff0019,0x2918c90d,0xb5fd00ac,0x3a2602c4}},	//   _tiếc_, _vora_, _ryša, šop_,
   {{0x69d6011e,0x00000000,0x00000000,0x00000000}},	//   ptye, --, --, --,
   {{0x2918c90e,0x6286010b,0xaad50066,0x6365002a}},	//   _tora_, žkok, _डॉटक, cóni,
   {{0x68f5c90f,0x644f0035,0x63a80159,0xf99f0260}},	//   _gazd, _ścia, _pwdn, _brèf_,
   {{0x61e2c910,0x69c4c911,0x00000000,0x00000000}},	//   _spol, lrie, --, --,
   {{0x2249912d,0xe73a01d3,0xdb24000d,0x68f5c912}},	//   _žaka_, _уеб_, érès, _zazd,
   {{0x68f506d0,0x05760e6b,0x5eab0033,0x61fb1192}},	//   _yazd, _فائد, _কালে, gvul,
   {{0x859b0122,0x3a3702b8,0x6fc0021a,0x69c4b9be}},	//   _לשמו, פרים_, _विदू, irie,
   {{0x69c402bf,0xbebb01f4,0x63ad0c99,0x63650138}},	//   hrie, dhër, ćanc, zóni,
   {{0x69c4c913,0x612d0098,0x66000207,0x00000000}},	//   krie, _cúlb, _krmk, --,
   {{0xc3330122,0x9f480176,0x61e2c914,0xada400d8}},	//   _אוף_, _arnó_, _upol, наўл,
   {{0x14df017f,0x69c4c915,0xc16f02ce,0xbebb00da}},	//   प्पण, drie, _її_, thës,
   {{0x68f51851,0x69c48143,0x60db00a5,0x50db00a5}},	//   _razd, erie, _הקונ, _החוצ,
   {{0x69c4c916,0xae9b004f,0x636509ca,0x6b860a4e}},	//   frie, _اضغط_, tóni, _cikg,
   {{0x69c4c917,0x6b86060b,0x23950029,0xdebc00a5}},	// [f870] grie, _dikg, _māja_, _המחל,
   {{0x63654efb,0x98b9005f,0x3f8e0103,0x00000000}},	//   róni, ілет_, _kufu_, --,
   {{0x290706a8,0x68f52c3f,0x69c4c918,0x63650300}},	//   ına_, _vazd, arie, sóni,
   {{0x63650391,0xcfae0033,0x3a3f0506,0x6d8b0069}},	//   póni, _কমান, _župu_, _iżab,
   {{0xa3cf02cb,0xb8d300c8,0x69c4c919,0x5eb20033}},	//   वून_, _টা_, crie, _ঝামে,
   {{0x98b0022f,0xba3b0176,0x25de08a9,0xf9920317}},	//   _ćaća_, _deït, _गहरी_, _ברך_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf77303c5,0x61240260,0x6aaf0069,0x798f0103}},	//   _ساز_, _fòlk, _jecf, _kucw,
   {{0x4cb300c8,0x20180086,0xdb2400b5,0x28dd06bc}},	//   _জানু, ärin_, érés, न्थि,
   {{0x61fbb528,0x70c70099,0x3f8e0103,0x00000000}},	//   rvul, ललेल, _bufu_, --,
   {{0x69c4016f,0xceeac91a,0x61fbc91b,0x00000000}},	//   zrie, одне_, svul, --,
   {{0xe28ec91c,0xf8dd1b8f,0x28dd000c,0x26cfc91d}},	//   _ја_, न्तय, न्ति, nggo_,
   {{0xee370f92,0x799d006f,0xc33200a5,0xb5fd07c0}},	//   дня_, _ntsw, _בוא_, _myšo,
   {{0x69c4c91e,0xd00e00b5,0x25e507b5,0x00000000}},	//   vrie, _چلو_, _टहनी_, --,
   {{0xeb971566,0x69c4c91f,0x28c700b4,0x00000000}},	//   дис_, wrie, _लाजि, --,
   {{0x69c4c920,0x61ed00d8,0xbebb01f4,0x798f030d}},	//   trie, _šaly, shër, _bucw,
   {{0xf2d202b5,0xaa431d88,0x79870120,0x09e60033}},	// [f880] כען_, ветл, _bijw, নিভা,
   {{0x69c4c921,0x6d8b00ea,0x00000000,0x00000000}},	//   rrie, _pļav, --, --,
   {{0x28dd1ae9,0x69c4c922,0x62990103,0x00000000}},	//   न्धि, srie, _ofwo, --,
   {{0x69c4c923,0x9f5d01ba,0x6fc500a1,0x78aea5fc}},	//   prie, _prvé_, _विनं, _webv,
   {{0x6d4e0d35,0xf99f0176,0x6ed620af,0xba3b0345}},	//   onba, _crèd_, _भानु, _deïs,
   {{0x28dd1f57,0x6d4ec924,0x6299021e,0x61240260}},	//   न्दि, nnba, _afwo, _vòlk,
   {{0x6d4e1bc9,0x00000000,0x00000000,0x00000000}},	//   inba, --, --, --,
   {{0xba3b32c5,0x79870223,0x05000033,0x6d4e02b1}},	//   _geïs, _zijw, ্সের_, hnba,
   {{0x9663702b,0x63ad0c99,0xa3ba00a1,0x63650093}},	//   _акте, ćana, _अटक_, jónu,
   {{0xb5fd053d,0x62990260,0x628b001c,0xe5060413}},	//   _myšl, _efwo, _eggo, _تبري,
   {{0xe29a010b,0x00000000,0x00000000,0x00000000}},	//   _дае_, --, --, --,
   {{0x6d4e380d,0x00000000,0x00000000,0x00000000}},	//   enba, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1a90118,0xdb1500b5,0x00000000,0x00000000}},	//   _راهه_, mszé, --, --,
   {{0xd30f0019,0x79870223,0x1bd41172,0x212b00a2}},	//   _mệnh_, _rijw, коря, êche_,
   {{0x290a0c1f,0x91f20299,0xa3cf083f,0xd30f0019}},	//   _anba_, _अनाज_, वंत_, _lệnh_,
   {{0x6365c925,0x49751279,0x00000000,0x00000000}},	// [f890] mónt, елас, --, --,
   {{0x5fc50e61,0x61240176,0xe6a70127,0x6e200c75}},	//   _विमल, _bòli, खर्ज, ämbe,
   {{0xe61000d1,0x61240176,0x00000000,0x00000000}},	//   یشه_, _còli, --, --,
   {{0x63650079,0xcaa74a57,0x2b4d01ed,0x00000000}},	//   nónt, _تصدي, _ñec_, --,
   {{0xd30f0028,0x7aedc926,0xae0f046c,0x61240310}},	//   _bệnh_, meat, ामिन_, _eòli,
   {{0x7aedc927,0x293502b5,0x67d50212,0x61240fc6}},	//   leat, _טאָן_, _погу, _fòli,
   {{0xf8b21804,0xba3b1472,0x3b0b0118,0x00000000}},	//   _תשל_, _geïr, _kncq_, --,
   {{0xdb1c0e81,0xfe0f00b4,0x7aed1116,0x644e00f4}},	//   strö, ामास_, neat, _žbic,
   {{0xa2d00fbf,0x6d4ec928,0x15e300ab,0xd5bb2a2d}},	//   _धार्, ynba, _गहिर_, _фсб_,
   {{0xf8af0066,0x63ba01ed,0xb6cc0448,0x00000000}},	//   टरिय, _fvtn, _çürü, --,
   {{0x7aedc929,0xd009c92a,0xdcfe0160,0x3f890090}},	//   keat, чене_, _lipă, _biau_,
   {{0xdb1c02e1,0x6fc00266,0xf99f02d0,0x25ad0298}},	//   ntrô, _विरू, _otè_, _kwel_,
   {{0x7aed06a2,0x3f890090,0x00000000,0x00000000}},	//   deat, _diau_, --, --,
   {{0xdd8f7cf8,0x82340841,0xf99f021e,0x6d8b00ec}},	//   صوف_, _جرما, _orèb_, _aļas,
   {{0x6d4e17ad,0xf99f02e9,0xed57059d,0x98ba00af}},	//   rnba, _atè_, хор_, hipă_,
   {{0x63650391,0x7aed8b47,0x28dd00b4,0x628600a0}},	//   cónt, geat, न्सि, ľkov,
   {{0xa2d70ea3,0x6286024e,0xb0b60084,0x6fc500a1}},	// [f8a0] _यान्, žkov, _आजमग, _विडं,
   {{0xb5fd0187,0x8cd70af9,0xf99f0260,0x61240392}},	//   _vyšl, _बायो, _dtè_, _pòli,
   {{0xacd702b5,0x46ea05c7,0x6146000d,0x2d9204fb}},	//   _אויפ_, зден_, _hélè, _huye_,
   {{0xbbe90609,0x2d92030d,0x7bcec92b,0x7aedc92c}},	//   _کریم_, _kuye_, mubu, ceat,
   {{0x7d1ec92d,0x00000000,0x00000000,0x00000000}},	//   _kops, --, --, --,
   {{0x66030274,0x7d1e023a,0x2d92030d,0x6ab6008e}},	//   упља, _jops, _muye_, layf,
   {{0x7bcec92e,0x636505ee,0x00000000,0x00000000}},	//   nubu, jóns, --, --,
   {{0xd37700c7,0x7d1e189c,0x2d920107,0x00000000}},	//   нчы_, _lops, _ouye_, --,
   {{0x32020076,0x7bcec92f,0x3f893829,0xf8dd09b1}},	//   íky_, hubu, _riau_, न्वय,
   {{0x7bcec930,0xb27302ee,0xc05a00c7,0x3f8901f7}},	//   kubu, ылыш, зім_, _siau_,
   {{0x39964d3e,0x41c202cb,0x64a34268,0xb60600ac}},	//   _læs_, _शिवस, _саха, _dláž,
   {{0xe2920082,0xd378025c,0xdb07003e,0x15f4007c}},	//   _إذا_, _opći_, ssjú, _इनार_,
   {{0x61460248,0x16030035,0x3d9400af,0x5ce701e0}},	//   _célè, लियर_, лияр, нюва,
   {{0x7d1e1599,0x59c70026,0x7bdcc931,0xc05a01e0}},	//   _cops, _लिबर, ftru, _ній_,
   {{0x7aed6590,0x81dc0083,0x7bce01a2,0xf4220033}},	//   teat, ডিও_, gubu, _ভেতর_,
   {{0xdcfe0160,0xdb6800af,0x9f5d007e,0x00000000}},	//   _pipă, ерул_, _krví_, --,
   {{0x98c7c932,0xf99318dd,0x6f0d142b,0x7aed09c1}},	// [f8b0] فغان, ابر_, _inac, reat,
   {{0x7bcec1c1,0x7aed0065,0x6f0d00ac,0x00000000}},	//   bubu, seat, _hnac, --,
   {{0x6d472b69,0x80d80fd0,0x6f0d40d1,0x7aed92e9}},	//   mija, _माने, _knac, peat,
   {{0x2366006f,0xdcfe002d,0xa3cf00b4,0x25ad0260}},	//   _nkoj_, _tipă, वंस_, _pwel_,
   {{0xf77003c7,0x6f0dc933,0x39962a7d,0x63653346}},	//   حال_, _mnac, _gæs_, zóns,
   {{0x6d4711c6,0x28dd009a,0xd46910ac,0xcd980122}},	//   nija, न्शि, миле_, עדות_,
   {{0x63ad011c,0x6f0d1c5d,0xb5fd00ee,0x00000000}},	//   ćano, _onac, _kyšk, --,
   {{0x490502cb,0x05c90d34,0x070910ab,0x6f0d034d}},	//   _होतो_, _रिपब, _تيري_, _nnac,
   {{0xc6920052,0x6595631a,0x6d47c934,0x44290080}},	//   _כאן_, _разу, kija, ņa_,
   {{0x6f0dc935,0x41c200e7,0x7bdcc936,0x00000000}},	//   _anac, _शिरस, ytru, --,
   {{0x7bdc5812,0x7d1e011c,0x65630183,0x3cfa0345}},	//   xtru, _rops, monh, _rapv_,
   {{0x7d1ec937,0x0caa06bc,0x4427c938,0x65630204}},	//   _sops, कर्म, myn_, lonh,
   {{0x6d472cf6,0x7d1ec939,0x733a02b5,0xb6ba0122}},	//   fija, _pops, _קענס, וצרי,
   {{0x6da3c93a,0x7bcec93b,0x6d47708c,0x236010ec}},	//   рира, tubu, gija, čije_,
   {{0x4427c93c,0x7d1e002d,0xdc670dfc,0x6f0d000d}},	//   nyn_, _vops, вард_, _fnac,
   {{0x7bce37e0,0x629b17d8,0x2ca50225,0x200b00f4}},	//   rubu, ncuo, ılda_, čkić_,
   {{0xcb67c93d,0xe8fa0369,0xe9da2780,0x7bcec93e}},	// [f8c0] тате_, мла_, ька_, subu,
   {{0x6d47176d,0x6f0dc93f,0x6ab60723,0x98a60384}},	//   cija, _znac, sayf, тиже,
   {{0x8cd70035,0x2cb8000d,0x6563c940,0x776201ef}},	//   _बातो, mard_, donh, toox,
   {{0xdd8f00e0,0x44270297,0xe5c6c941,0x2cb8c942}},	//   _دوی_, dyn_, вско, lard_,
   {{0xca750bbc,0x7ae90176,0x61240260,0x00000000}},	//   _буры, _ñeta, _kòlt, --,
   {{0x2cb8c943,0x2366c944,0x4427bf3f,0x65630539}},	//   nard_, _skoj_, fyn_, gonh,
   {{0xd9438fa3,0x442700e9,0x61240176,0x68fc026e}},	//   _тери, gyn_, _mòlt, _iard,
   {{0x6d47c945,0x51f80086,0x236d02c6,0x27f80282}},	//   zija, ению_, glej_, _isrn_,
   {{0x875501d3,0xc0ca0e9f,0x25ec017f,0xcb13011d}},	//   _сърц, муне_, _आईटी_, שלח_,
   {{0x68fcc946,0x6f0dc947,0x44270297,0x65630370}},	//   _jard, _snac, byn_, conh,
   {{0x44380b87,0x68fcc948,0x63a43b12,0x6d470121}},	//   _år_, _mard, ćins, vija,
   {{0x645a0095,0x6d47c949,0x68fcc94a,0xc246140e}},	//   _ixti, wija, _lard, _инек,
   {{0xa2d7c1c2,0x6286016f,0x6602c94b,0xb5fd010b}},	//   _यात्, ľkos, nvok, _ryšk,
   {{0xd24f0118,0x61430fc5,0xe8cc0035,0x2cb8c94c}},	//   _بنه_, _кеча, ालोच, gard_,
   {{0xa5cc0461,0x256900b5,0xd00f0c74,0x00000000}},	//   _समझौ, múlt_, _وله_, --,
   {{0x6d47c94d,0x68fc17ff,0x7f5600da,0x6f0dc94e}},	//   sija, _aard, _gjyq, _unac,
   {{0x68fcc94f,0x3a75c950,0x3eb9c951,0x27ea00e7}},	// [f8d0] _bard, улар, mast_, _apbn_,
   {{0xacf502cc,0x6602c952,0x442700c3,0x6d470055}},	//   _спољ, dvok, yyn_, qija,
   {{0x68fc4fad,0x6d45c953,0xdb1500b5,0x81e80033}},	//   _dard, _imha, lszí, মটি_,
   {{0x3eb9c954,0x68fc009e,0xdbd1007c,0xa56400f8}},	//   nast_, _eard, _müüg, یدون,
   {{0x68fcc955,0x4427c956,0x67202d00,0x2d9c008b}},	//   _fard, wyn_, _domj, _čvek_,
   {{0x4427c957,0x68fcc958,0x7afdc959,0x3eb900ab}},	//   tyn_, _gard, _hast, hast_,
   {{0xe2990a93,0x3eb9c95a,0xd6db0210,0x6563c95b}},	//   най_, kast_, _ота_, ronh,
   {{0x4427c95c,0x3eb973ff,0x7afdb640,0xe1f956f6}},	//   ryn_, jast_, _jast, еги_,
   {{0x3eb9c95d,0x3a290ec0,0x7afdc95e,0x44270044}},	//   dast_, nyap_, _mast, syn_,
   {{0x7afd800f,0x68fc0391,0x629b4c55,0x60330095}},	//   _last, _xard, scuo, ləmə,
   {{0x5eab0083,0x777b006d,0x7afd0139,0x236d35e2}},	//   _কাজে, _khux, _oast, plej_,
   {{0x7afd0936,0x6d45c95f,0x3eb93bd1,0x752101ae}},	//   _nast, _amha, gast_, _holz,
   {{0xd4910023,0xc0e50be8,0x7e6d0371,0x75210069}},	//   _làm_, _болк, _cyap, _kolz,
   {{0x7afd0ccf,0x78b514a6,0x6ed60ccf,0x2d8cc960}},	//   _aast, _nezv, _भावु, öde_,
   {{0x7afd7ab4,0x68fc6dcf,0x7e6d0103,0x3eb900be}},	//   _bast, _rard, _eyap, bast_,
   {{0x68fcc961,0x7afd409c,0x765b0095,0x2cb80248}},	//   _sard, _cast, _oxuy, sard_,
   {{0x68fcc962,0x7afdc963,0x78b5a6a1,0xa3b30f8a}},	// [f8e0] _pard, _dast, _bezv, जीत_,
   {{0x63ad01cc,0x68fc0095,0x7afdc964,0x00000000}},	//   ćanj, _qard, _east, --,
   {{0x68fcc386,0x8caa04cc,0x78b50012,0xddcd0a78}},	//   _vard, _ज्यो, _dezv, _izaš,
   {{0x3165033b,0x8af000a8,0x61eb0051,0x478901e0}},	//   holz_, yləy, _opgl, всім_,
   {{0x75213194,0x15d9006c,0xe4e60402,0xbb3b0070}},	//   _bolz, ندوں_, гійн, _טעטי,
   {{0x7afd704b,0x25a614cc,0x7ae4a745,0x7521c965}},	//   _zast, rpol_, lfit, _colz,
   {{0xc61c00c8,0xf3660c8d,0x7521003d,0x25a6c966}},	//   _দেখা_, лтин, _dolz, spol_,
   {{0x7afd002a,0x7ae4c967,0x60c3002a,0x6136000d}},	//   _xast, nfit, _adnm, _mâle,
   {{0x64a6c968,0x3eb9c969,0x14d60416,0x200700e9}},	//   _база, vast_, _مزاح, _arni_,
   {{0x2007023a,0x249e021d,0x06bc0033,0x7e6d0027}},	//   _brni_, _uftm_, _ইউটি, _ryap,
   {{0x04930082,0x3eb92e40,0x20070254,0xb5fd00d8}},	//   _المح, tast_, _crni_, _ryši,
   {{0x798e0103,0x6d8b0069,0x6fc50099,0x7bc100f4}},	//   _libw, _eżal, _विरं, šluk,
   {{0x3eb9c96a,0x7afdc96b,0x3b008f53,0x88cc0083}},	//   rast_, _rast, ddiq_, র্যক,
   {{0x3eb9c96c,0x798e0010,0x61360160,0x7e6d023c}},	//   sast_, _nibw, _bâle, _vyap,
   {{0x7afdc96d,0x3eb9c96e,0x8ca40035,0x9f6b0b00}},	//   _past, past_, कड़ो, _приз_,
   {{0x443c0009,0x7afdc96f,0x798e034d,0x00000000}},	//   izv_, _qast, _aibw, --,
   {{0x7afd5ea2,0x2b49c970,0xa2d7035d,0x798ec971}},	// [f8f0] _vast, riac_, _यास्, _bibw,
   {{0x2b49016f,0x6d458fbc,0x7afdc972,0x29dd027a}},	//   siac_, _umha, _wast, rìa_,
   {{0x63ad012e,0xe79600b5,0x29dd0036,0x603300a8}},	//   ćank, لانک, sìa_, təmə,
   {{0x7afd0037,0x7521c973,0x00000000,0x00000000}},	//   _uast, _solz, --, --,
   {{0xfad60779,0xeef802b5,0x7521c974,0x4993006c}},	//   _דורך_, טמאר_, _polz, _طیار,
   {{0x69cd02c7,0xc7b70841,0x6d558639,0x00000000}},	//   mrae, _مصرع, nnza, --,
   {{0xc293006c,0xc6a7192f,0x29110118,0x75216cb3}},	//   میاب, _брзи, _inza_, _volz,
   {{0x130910be,0x0325316d,0x798e0b13,0x00000000}},	//   тний_, рдин, _zibw, --,
   {{0xd24e00e0,0x6515006c,0x20070c99,0x5f090067}},	//   وچه_, _پوائ, _srni_, ियन्_,
   {{0x60092217,0x2901c975,0x660906a2,0x236015d7}},	//   вном_, ndha_, _irek, čija_,
   {{0xa2f50e0a,0xdb0705ee,0xb4c305f7,0x69cd0103}},	//   _впеч, nsjó, ्ली_, hrae,
   {{0x6609c976,0x6d55c977,0x9f5d01ba,0x8c0b0033}},	//   _krek, enza, _prvá_, রহান_,
   {{0x471a00a5,0x6d8b035f,0x8e76002d,0x29110138}},	//   דורג, _eżam, рунч, _onza_,
   {{0x69cdb8b1,0x66094dbf,0x4f951765,0xd13843e8}},	//   drae, _mrek, _криу, chą_,
   {{0x29011034,0x798e0027,0x8cd7021a,0x200702a7}},	//   ddha_, _ribw, _बारो, _urni_,
   {{0x6d551111,0x9f5d0187,0x6609c978,0x2911c979}},	//   anza, _trvá_, _orek, _anza_,
   {{0x7ae401f4,0x3ead0300,0x3946010b,0xc8960214}},	// [f900] rfit, ñete_, анаг, арењ,
   {{0xf09202b5,0x78bb0248,0x3b000095,0xddcd0124}},	//   ַנד_, _œuvr, sdiq_, _uzaš,
   {{0x6609c97a,0xdb07008d,0x98aa0395,0x798e023c}},	//   _arek, gsjó, _albă_, _vibw,
   {{0x66e60bbc,0x6609a88d,0x69cdc97b,0x29114d67}},	//   рода, _brek, brae, _enza_,
   {{0x6b840a45,0xb4c30299,0x22a600b8,0x3958c97c}},	//   mmig, ्लू_, níků_, _tjrs_,
   {{0x6609c97d,0x6b840d89,0x03c6224a,0x00000000}},	//   _drek, lmig, асим, --,
   {{0xc4480220,0xdb1500b5,0x81d20033,0xd49901e0}},	//   دیان_, lszá, _হৈং_, урі_,
   {{0x6609c97e,0x6b84c97f,0x661600c3,0x80d80ec5}},	//   _frek, nmig, äyks, _माहे,
   {{0xe5a3c980,0x24f6519c,0x6609c981,0xdb1c25a8}},	//   _мити, _вчер, _grek, luró,
   {{0xf8b302b5,0x99b10083,0x6b8401ae,0x92d60033}},	//   ֿשר_, _চমৎক, hmig, াজে_,
   {{0x3d0a009a,0xb4d20f9f,0x66094a9c,0x41c20066}},	//   ायने_, वली_, _zrek, _शिकस,
   {{0x91e60b46,0x61360139,0xb5fd00d5,0xdb1500fd}},	//   _воде, _bâlc, _vyšv, kszá,
   {{0x6b840069,0x51f63b94,0x7bce0051,0x9757024b}},	//   dmig, _خسار, erbu, שיכו_,
   {{0xa3b38833,0xc04600b5,0x6b8400be,0x2b590069}},	//   जीव_, _پختو, emig, _sjsc_,
   {{0xdb6b081b,0xb17b100a,0xf99f0107,0x00000000}},	//   врал_, _שטור, _erèl_, --,
   {{0x69cd410f,0x9e67006c,0x6b846b9d,0x4ea70166}},	//   trae, _پابن, gmig, _трка,
   {{0x63ad0254,0x7bce011e,0x61360160,0x6ce71645}},	// [f910] ćani, arbu, _gâlc, _кіне,
   {{0x69cd001e,0xf80707bc,0x637e01f4,0x28a7010b}},	//   rrae, ичен, lënd, ршаг,
   {{0x69cdc982,0x2901c983,0xf99f00e2,0x2b590183}},	//   srae, rdha_, _trèo_, _tjsc_,
   {{0x66096bea,0x69cdc984,0xdb070093,0x7bd59ab2}},	//   _prek, prae, rsjó, muzu,
   {{0x6605c985,0x64a5c986,0xdb07008a,0xaae60416}},	//   спла, бала, ssjó, _اسپو,
   {{0xdb1c27c2,0x637e01f4,0xd5670e9f,0x660901bf}},	//   buró, hënd, штеп, _vrek,
   {{0x237d006d,0xdb1c002a,0x637e0031,0x66090051}},	//   _phwj_, curó, kënd, _wrek,
   {{0x6609c987,0x612d0093,0xa9270168,0xfc58076b}},	//   _trek, _túlk, _daľš, יבוש_,
   {{0x7985006d,0xe1f10037,0x66092e4d,0x130600c3}},	//   omhw, سسة_, _urek, сный_,
   {{0x23e700d4,0x7bd53772,0x64a40274,0x637e0298}},	//   _відв, kuzu, _мађа, eënd,
   {{0x612d0332,0xe8df0028,0x4049c988,0x237d006f}},	//   _júli, _ngọc_, упно_, _thwj_,
   {{0x22950082,0x7bd51cc9,0x22490124,0x998900cd}},	//   _الإس, duzu, _žaku_, jzaž_,
   {{0x5285004f,0xa3b30026,0xf99f0107,0x00000000}},	//   _الشك, जीर_, _brèm_, --,
   {{0xdca308ce,0x613600af,0x7bd5c989,0x7bce0207}},	//   зари, _vâlc, fuzu, trbu,
   {{0xd4910023,0x20180421,0x7bd501b7,0x00000000}},	//   _bài_, ärit_, guzu, --,
   {{0x2b9c01c0,0xdb1500b5,0x61360160,0xd49100cc}},	//   _víc_, tszá, _tâlc, _cài_,
   {{0x3b0702fb,0xf99f0260,0x00000000,0x00000000}},	// [f920] щето_, _frèm_, --, --,
   {{0xdb150332,0xb4c33874,0x6b841915,0x3f920118}},	//   rszá, ्लो_, smig, _hiyu_,
   {{0x6d4e5a6d,0xdb1500b5,0xc6250033,0x02f907df}},	//   miba, sszá, _মেলা_, ्याह_,
   {{0x3f92022e,0x98b804d4,0xd6d90185,0x00000000}},	//   _jiyu_, ızın_, иті_, --,
   {{0x3f9200d7,0x239500ea,0x7c2e51c7,0x80d809b8}},	//   _miyu_, _māju_, lybr, _माले,
   {{0xb4d2c98a,0x6d4ec98b,0xe9a30de2,0xdb0500a2}},	//   वले_, niba, _харп, _athè,
   {{0x69d6c98c,0xa3b30035,0x29370070,0x15f400ab}},	//   luye, जील_, _פאלן_, _इनकर_,
   {{0xe44f0514,0x6d4e0b04,0x7af6008a,0x66e3c98d}},	//   عضو_, hiba, neyt, _носа,
   {{0x5f1c5d5b,0x69d6c98e,0x00000000,0x00000000}},	//   यान्_, nuye, --, --,
   {{0x6d4e2745,0x3b0201f7,0x00000000,0x00000000}},	//   jiba, _lakq_, --, --,
   {{0x28dd06bb,0x5eaa00c8,0x6d4ec98f,0x160302e4}},	//   न्टि, _কয়ে, diba, लिअर_,
   {{0xe29a8662,0x3f805790,0x69d6251e,0x6d8b0024}},	//   _сад_, _chiu_, kuye, _iżai,
   {{0x13ad00c8,0x518601c8,0x637e00da,0x6d4e8af6}},	//   _গিয়, _лука, rënd, fiba,
   {{0x7bd5c990,0x6d4ec991,0x394a0051,0x2018018d}},	//   tuzu, giba, _nmbs_, äris_,
   {{0x3f800211,0xdfa60698,0x3f920103,0x491701c0}},	//   _fhiu_, _احتي, _fiyu_, नासो_,
   {{0x63a8c992,0x905700a5,0x7bd5c993,0x6d4e32c5}},	//   _mtdn, _לסוף_, ruzu, aiba,
   {{0x7bd50010,0x6d4ec994,0x69d6c995,0xd49100cc}},	// [f930] suzu, biba, guye, _vài_,
   {{0x2be20b4a,0xaa7b024e,0x127b0070,0x27050023}},	//   _पहचा, _obýv, ראמע, _ồn_,
   {{0xd4910023,0x60c70067,0xf99f0260,0x00000000}},	//   _tài_, ójmi, _krèk_, --,
   {{0x69d6c996,0x2d9b0031,0x00000000,0x00000000}},	//   buye, _kuqe_, --, --,
   {{0x2cb2022a,0x35e702ce,0xceb400a5,0xf77300b5}},	//   _ändå_, сцев, ליף_, _ہار_,
   {{0x2c8300f7,0x612d888f,0x00000000,0x00000000}},	//   cédé_, _túli, --, --,
   {{0xe3b20332,0x3d0a07df,0xdb05c997,0xa3b31b8f}},	//   ورٹ_, ायते_, _athé, जीं_,
   {{0x2903c998,0x6d4ec999,0x637e0223,0x644f0067}},	//   _haja_, ziba, eënb, _ścis,
   {{0x6d4e01d5,0x612d00b5,0xf1a80088,0x00000000}},	//   yiba, _múlv, یایه_, --,
   {{0x290337ac,0x4fe90009,0x955716a4,0x3f800031}},	//   _jaja_, амон_, _اخرا, _shiu_,
   {{0x3d1d10a6,0x6d4e055c,0x24552abf,0x3f804564}},	//   माने_, viba, _بناس, _phiu_,
   {{0x6d4ec99a,0x2d9301ed,0x3f6ac99b,0x00000000}},	//   wiba, _aixe_, римо_, --,
   {{0x5fc519db,0xc3320122,0x7c2e00e9,0x3ead5f9e}},	//   _विकल, _קוד_, wybr, ñeta_,
   {{0x2903c99c,0x61fb1476,0x69d601d5,0xf99f0107}},	//   _naja_, mwul, vuye, _erèk_,
   {{0x69cb0083,0x6d4ec99d,0x3116007e,0x3326c99e}},	//   ágen, riba, तारः_, _yoox_,
   {{0x6d4e0771,0x69d6c99f,0xdb1c008a,0x2d931ae3}},	//   siba, tuye, gurð, _eixe_,
   {{0x2903432a,0x6d4ec9a0,0x2d93c9a1,0x7af60093}},	// [f940] _baja_, piba, _fixe_, reyt,
   {{0x38cb1c0c,0x29030033,0x69d6c9a2,0x2d4d0187}},	//   لامی_, _caja_, ruye, nžel_,
   {{0x6f040024,0xdb1c0093,0x29033497,0x69d641c3}},	//   _kaic, burð, _daja_, suye,
   {{0x69d600f7,0x941100a8,0x7c230211,0xeab20079}},	//   puye, _üzə_, _ànra, _تعد_,
   {{0x6f049f6c,0x2903c9a3,0x442e00e9,0xd49100e2}},	//   _maic, _faja_, wyf_, _màu_,
   {{0x442e0298,0x69c4c9a4,0x2d93c700,0x3d1d073f}},	//   tyf_, msie, _xixe_, माये_,
   {{0x69c4c9a5,0xb4ba0461,0x78bc0036,0x6d8b009f}},	//   lsie, _अजी_, _ierv, _eżaw,
   {{0x44200537,0x442e250a,0x78bcc9a6,0x31c60ebb}},	//   ći_, ryf_, _herv, осов,
   {{0x78bcc9a7,0x442e099e,0x290308c7,0x00000000}},	//   _kerv, syf_, _yaja_, --,
   {{0x78bc00d7,0x69c461ff,0x00000000,0x00000000}},	//   _jerv, isie, --, --,
   {{0x28e2009a,0x78bcc9a8,0xa2e603fa,0x6f04c9a9}},	//   _पानि, _merv, _можд, _baic,
   {{0x69c4c9aa,0x93fb00a5,0x6722018f,0x6aa400d5}},	//   ksie, _כלבי, njoj, jcif,
   {{0x7642c9ab,0x6f048541,0xada4010b,0x78bc0345}},	//   nzoy, _daic, маўл, _oerv,
   {{0x69c4c9ac,0x3af50023,0x23690121,0x399f0160}},	//   dsie, _ấp_, čaje_, _rîs_,
   {{0x29030452,0xeb4b1813,0x6f0401a6,0x69c419ac}},	//   _raja_, ачак_, _faic, esie,
   {{0x290302cb,0x31a002e9,0x6d5e0176,0x6f0401da}},	//   _saja_, _kòz_, _ejpa, _gaic,
   {{0x78bcc9ad,0x67226203,0x31a00107,0x753a0065}},	// [f950] _berv, djoj, _jòz_, _oltz,
   {{0x4905007c,0x7528c9ae,0x48ab40b4,0x26df034d}},	//   _होखो_, _nodz, ртам_, _scuo_,
   {{0x78bcc9af,0x2903c9b0,0xb8e300b4,0x6f0408c7}},	//   _derv, _vaja_, _एज_, _yaic,
   {{0x2903c9b1,0x753a01d7,0x672201f4,0x7d050069}},	//   _waja_, _altz, gjoj, _hahs,
   {{0x5f1c0b35,0x78bc80f4,0x2903c9b2,0x64a58cda}},	//   यात्_, _ferv, _taja_, пала,
   {{0x78bcc9b3,0x75280035,0x7d05c9b4,0x64a54ee3}},	//   _gerv, _codz, _jahs, чака,
   {{0x7d05c9b5,0xc7c40c7e,0x0edbc9b6,0x61360160}},	//   _mahs, _ости, _भांड, _pâln,
   {{0xbfa30023,0x31a0021e,0x799d4179,0x753a01b7}},	//   _diễ, _bòz_, _kusw, _eltz,
   {{0x6f04c9b7,0xe4e700ef,0xda0e11b5,0x4cd30083}},	//   _raic, _міжн, सियत_, দ্যু,
   {{0x7528006a,0xa2d70026,0x799da6ab,0xb7ff0066}},	//   _godz, _याक्, _musw, _ईनाम_,
   {{0x63ad003a,0xa0691b3a,0x7995012f,0x6f04026e}},	//   ćans, сана_, _mizw, _paic,
   {{0xe3b0097f,0x7528010b,0x69c4c9b8,0x67291491}},	//   _شرم_, _zodz, ysie, _joej,
   {{0x7d05027d,0xe1ee0210,0x6f042a28,0x799d01cb}},	//   _bahs, _яг_, _vaic, _nusw,
   {{0xcfe901ca,0x7aef0069,0x644303c9,0x612d0079}},	//   _هفته_, _abct, ozni, _cúlt,
   {{0x799d02c9,0x7d050ec0,0x5f1c012f,0x6f0401a6}},	//   _ausw, _dahs, याद्_, _taic,
   {{0x69c4c9b9,0x3f6701d3,0x799dc9ba,0x6abd3850}},	//   tsie, _нищо_, _busw, _cesf,
   {{0x78bcc9bb,0x6abd9d83,0x7995c9bc,0x69c42143}},	// [f960] _perv, _desf, _bizw, usie,
   {{0x01bd0b52,0x69c4c9bd,0x6aa4acf6,0x3d1d00a1}},	//   _আমাদ, rsie, scif, माणे_,
   {{0x7528006a,0x78bcc9be,0xcc8a01cb,0x7e760526}},	//   _rodz, _verv, _دنده_, _hyyp,
   {{0xe61a4c16,0x673b002d,0x78bcada7,0x7d050009}},	//   йде_, _cluj, _werv, _zahs,
   {{0x78bcc9bf,0x75280803,0x60c10332,0x7d050345}},	//   _terv, _podz, kalm, _yahs,
   {{0x3ae80332,0x6d5cc9c0,0x60c1035f,0x994f037a}},	//   _ابھی_, nnra, jalm, müş_,
   {{0x8af001c2,0x60c1006c,0x673b0831,0xe3af11c0}},	//   ynəl, dalm, _fluj, هري_,
   {{0xdce70a78,0x320f08dd,0xd7d10026,0x75280067}},	//   vojč, _brgy_, _हितच, _wodz,
   {{0x6443c9c1,0x257600d1,0x3f9c0c99,0x60c11476}},	//   azni, _فهرس, _suvu_, falm,
   {{0xe1ef22c4,0x60c1c9c2,0x64a303e6,0x6d5c96fe}},	//   اسي_, galm, _зафа, jnra,
   {{0x6443006a,0x06e300c8,0x7d053382,0xf99f0107}},	//   czni, _নোটি, _rahs, _frèw_,
   {{0x987b0122,0x7d05c9c3,0x60c100ab,0x085700a5}},	//   מריק, _sahs, aalm, לבים_,
   {{0x6abdc9c4,0x7d05011e,0x2918009e,0x00000000}},	//   _resf, _pahs, _onra_, --,
   {{0xe6b90380,0x6d5c0a8a,0x799d01d5,0xa3d0000c}},	//   _उज्ज, gnra, _rusw, _वटा_,
   {{0x7e640391,0x961d00ea,0x7995007b,0x6abd00ee}},	//   _exip, _izņe, _rizw, _pesf,
   {{0x79950345,0x905b00a5,0x2b400098,0x7d05096c}},	//   _sizw, _לכות, ghic_, _wahs,
   {{0x433b02b5,0x78a51736,0x7d05c9c5,0x2d4d0207}},	// [f970] צעמב, tchv, _tahs, nžek_,
   {{0x673b002d,0x6729012f,0x28e20b35,0x8cd701c0}},	//   _sluj, _soej, _पाणि, _बाटो,
   {{0x973500f8,0x673b0443,0x6abd0b3e,0x2b400211}},	//   وکرا, _pluj, _tesf, bhic_,
   {{0xf7700125,0x78a514f0,0x64430097,0x6d8b035f}},	//   هان_, schv, vzni, _eżat,
   {{0xc178010b,0xb0dd2135,0x00000000,0x00000000}},	//   klė_, _मालग, --, --,
   {{0x80d80577,0x00000000,0x00000000,0x00000000}},	//   _मागे, --, --, --,
   {{0x60c1127d,0x28e2018d,0xc4c40312,0x67290afc}},	//   valm, _पाति, رتوو, _toej,
   {{0x7aedb048,0x6443c9c6,0x3b09bb84,0x673b012f}},	//   nfat, rzni, ndaq_, _uluj,
   {{0x26cd023a,0x7aed001e,0x64432e2f,0x45d42123}},	//   _ideo_, ifat, szni, _потс,
   {{0xe51e021a,0xe12500d4,0x3ea90031,0xefc9083e}},	//   पाणि_, ємни, _afat_, олол_,
   {{0xf7700332,0xb4b90808,0xf99f0359,0x25ad0124}},	//   _شاہ_, चरी_, _grèv_, _htel_,
   {{0xd24e3872,0x60c1c9c7,0x612d0079,0x994f05f9}},	//   انی_, salm, _cúlr, yüş_,
   {{0x60c1c9c8,0x612d0098,0x00000000,0x00000000}},	//   palm, _dúlr, --, --,
   {{0x61e9c9c9,0xdd920ef2,0xeb9a036f,0x00000000}},	//   mtel, ئوس_, жив_, --,
   {{0x7aedc9ca,0xdca30a46,0x8b9603e6,0x26cd0065}},	//   ffat, таси, драч, _odeo_,
   {{0xb0dd0084,0x25adc9cb,0x7e760086,0x61e961f2}},	//   _माँग, _otel_, _tyyp, otel,
   {{0x61e99d29,0x7940033b,0xdb1c008d,0x092a1d41}},	// [f980] ntel, _löwe, gsrá, ожай_,
   {{0xe9d72eb3,0x994f0463,0x23600bc6,0x61e9c9cc}},	//   ьку_, rüş_, čiji_, itel,
   {{0x61e9c9cd,0xad1b0317,0x2b40c9ce,0x3b86107b}},	//   htel, _וויר, phic_, _олог,
   {{0x48fa4092,0x00000000,0x00000000,0x00000000}},	//   _उसको_, --, --, --,
   {{0xb0dd0953,0x7bdc3635,0x80c30083,0xa2d70096}},	//   _मांग, luru, _শান্, _याज्,
   {{0x61e96af5,0xf99f02d0,0x00000000,0x00000000}},	//   dtel, _prèv_, --, --,
   {{0x7bdc1201,0xc7660312,0x61e9c9cf,0xdce700ea}},	//   nuru, _قارى, etel, nojā,
   {{0x61e94293,0xa3c10066,0xbebb0031,0x00000000}},	//   ftel, _्टर_, gjël, --,
   {{0x7bdcc9d0,0x05761062,0x61e9c9d1,0xa2ca022e}},	//   huru, _قائد, gtel, सृष्,
   {{0x7bdc442e,0x23691851,0x3ea900af,0xf99f0107}},	//   kuru, čaja_, _sfat_, _trèv_,
   {{0x61e907c0,0xd36f0043,0x7bdcc9d2,0xe8d700a5}},	//   atel, _ач_, juru, וויר_,
   {{0x7bdc00d1,0xa3b314ab,0xf99f0260,0x69d60031}},	//   duru, जीओ_, _krèt_, krye,
   {{0x61e90043,0x7e2b010b,0x00000000,0x00000000}},	//   ctel, ціна_, --, --,
   {{0xd0100e3a,0x7bc7017b,0x961d0029,0x7bdcc9d3}},	//   _ملت_, tsju, _uzņe, furu,
   {{0xdd9400d8,0x7bdcc9d4,0x00000000,0x00000000}},	//   тары, guru, --, --,
   {{0xd1382854,0x7bc70e6c,0x6ab60345,0x00000000}},	//   lką_, rsju, gbyf, --,
   {{0x7aed02df,0xf99f0955,0x0dbb09b9,0x25fe2450}},	// [f990] rfat, _què_, _باعث_, _शैली_,
   {{0x7aedc9d5,0x7bdcc9d6,0xd1383e96,0x98a300ea}},	//   sfat, buru, nką_, _bojā_,
   {{0x25ad0903,0x61e9c9d7,0x7bdc0232,0x7aedb048}},	//   _stel_, ztel, curu, pfat,
   {{0x29070888,0x61e9c9d8,0x98bf033e,0xdc36016b}},	//   žna_, ytel, ırın_, _נארט_,
   {{0xd2460082,0x6b8dc9d9,0x79a438c3,0x61e9b695}},	//   _إن_, mmag, _арсе, xtel,
   {{0x6b8dc9da,0x3878008a,0x060800d8,0xf99f0260}},	//   lmag, _fyrr_, ьнік_, _drèt_,
   {{0x36d52b9e,0x644e00ac,0xd1380067,0x00000000}},	//   _повр, _žbir, dką_, --,
   {{0x61e9c9db,0x26cd0200,0x6d558fab,0x02050012}},	//   ttel, _udeo_, hiza, езин,
   {{0x61e903c4,0x7bdc9a51,0x76740043,0x51554bfe}},	//   utel, zuru, _алтф, етну,
   {{0x7bdc06d3,0x7fd50208,0x6d55c9dc,0x320d00a5}},	//   yuru, німі, jiza, rvey_,
   {{0x61e9c9dd,0x6d55c9de,0xdee6365b,0xdbd703a6}},	//   stel, diza, нони, _jääv,
   {{0x61e9c9df,0x7bdcc9e0,0x9f4801b4,0x083a016b}},	//   ptel, vuru, _opnå_, פערל,
   {{0x6d550260,0xee37c9e1,0x6b8d079a,0x5ee13f52}},	//   fiza, еня_, dmag, _कार्_,
   {{0x7bdcad76,0x6d55c9e2,0x63a1c9e3,0xd1380e18}},	//   turu, giza, _kuln, cką_,
   {{0x6b66107b,0xd00e0934,0x629c0355,0x6b8d0093}},	//   еква, _هلو_, ěrov, fmag,
   {{0x28e2255b,0xab27c9e4,0x6b8dc9e5,0x39510116}},	//   _पाहि, носа_, gmag, _amzs_,
   {{0x2d962860,0x6b632dc3,0xe9da188d,0x6d55c9e6}},	// [f9a0] _прос, укта, яка_, biza,
   {{0x6d55a37e,0x7bdc06a2,0xf40500e2,0x69d6c9e7}},	//   ciza, puru, _đãng_, rrye,
   {{0x313602b5,0x3d1d00a1,0x6b8d0a8a,0x5975010b}},	//   ענעם_, मारे_, bmag, тыту,
   {{0xf99f02e9,0x6b8d021d,0xe7b300fd,0x02be0761}},	//   _prèt_, cmag, امند, _एजेन,
   {{0x6a9b011d,0x63a1000d,0x2d9a04fb,0xdd8f01cb}},	//   _משכנ, _auln, _kipe_, _خوی_,
   {{0x83f80142,0x963300d8,0x2d9ac9e8,0xf99f0260}},	//   декс_, ыніц, _jipe_, _erès_,
   {{0x76960723,0x63a10118,0x290a0103,0x00000000}},	//   _büyü, _culn, _iaba_, --,
   {{0x290a7dbe,0xf99f0359,0x2d9a00c5,0x6d55159c}},	//   _haba_, _grès_, _lipe_, ziza,
   {{0x290ac9e9,0x05667383,0x6d55a0a6,0xd25000bf}},	//   _kaba_, _зван, yiza, شند_,
   {{0x290a01cb,0x660260e8,0x31340f08,0xd138010b}},	//   _jaba_, mwok, теор, uką_,
   {{0xd138c9ea,0x2013002a,0x63a15bd7,0x6b8d05f5}},	//   rką_, _áxil_, _guln, ymag,
   {{0x290a51d7,0xd1381648,0xdb1c00a6,0x6d550096}},	//   _laba_, ską_, nsrä, wiza,
   {{0x6b4300ab,0xb7f60033,0x82332604,0x00000000}},	//   _jõge, ঘটিত_, _مروا, --,
   {{0x2d9ac9eb,0x2360011c,0x290a6600,0x463b0070}},	//   _cipe_, čiju_, _naba_, לעכע,
   {{0x291f01a5,0x68fe0345,0x00000000,0x00000000}},	//   _đua_, depd, --, --,
   {{0x6d55c9ec,0x6b8d0a2d,0xcf270088,0x290ac9ed}},	//   siza, umag, _سربي, _aaba_,
   {{0x290a7092,0xdb1c013c,0x2d9a0183,0x49757b96}},	// [f9b0] _baba_, dsrä, _fipe_, влас,
   {{0x3eb902c9,0x602a0095,0xdbd700c3,0x0aeb132d}},	//   lbst_, həmm, _pääv, _کردي_,
   {{0xb909134b,0x290abee2,0x3f89c9ee,0xf99f75ab}},	//   _या_, _daba_, _khau_, _près_,
   {{0xf8680098,0x613f00a2,0x63a1008c,0x00000000}},	//   رمني_, _mêla, _ruln, --,
   {{0xa5091f6a,0x290a01ef,0x5b1401d3,0x3eb902b1}},	//   дела_, _faba_, _смят, ibst_,
   {{0x290ac9ef,0x3f89006d,0xf99f0107,0x00000000}},	//   _gaba_, _lhau_, _frèr_, --,
   {{0xf99f1010,0x3ce90f9c,0x3206043d,0xe4c80413}},	//   _très_, _जाने_, _asoy_, ربون_,
   {{0xe2995bda,0x3f890028,0x9f5d016f,0x8c1c011d}},	//   май_, _nhau_, _prvý_, לווי,
   {{0x290a0232,0x3392004f,0x13060086,0xd49b0200}},	//   _yaba_, جليز, тный_, _ере_,
   {{0x63a100ab,0x00000000,0x00000000,0x00000000}},	//   _tuln, --, --, --,
   {{0x3f6a03fa,0xef861c80,0x3f89009e,0x854400af}},	//   дино_, клоп, _bhau_, _сэте,
   {{0x6da60e9f,0xbebb00da,0x3f89c9f0,0xada6005f}},	//   кима, njëh, _chau_, камл,
   {{0x3f8901a9,0x28e210aa,0x9105002d,0x2d9ac9f1}},	//   _dhau_, _पालि, _апле, _pipe_,
   {{0x3afc00e2,0x00000000,0x00000000,0x00000000}},	//   _ập_, --, --, --,
   {{0x290aae06,0x2d9a023a,0x00000000,0x00000000}},	//   _raba_, _vipe_, --, --,
   {{0x290ac9f2,0x3f89028b,0xf8b900e2,0x2d9a4c19}},	//   _saba_, _ghau_, _đũa_, _wipe_,
   {{0x2d9ac9f3,0x60c30d35,0x290a010d,0x9e6600d4}},	// [f9c0] _tipe_, _kenm, _paba_, _швид,
   {{0x3ce91163,0x290a0510,0x637e0031,0xb33c0069}},	//   _जाये_, _qaba_, gënj, _muħa,
   {{0x290a007c,0x60c302d0,0x8c469b5f,0xdb1c1193}},	//   _vaba_, _menm, _рене, tsrä,
   {{0x290a01d0,0x60c3c9f4,0x6b4300ab,0xf99f0118}},	//   _waba_, _lenm, _põge, _isèn_,
   {{0x290ac9f5,0x7ae4010d,0x00000000,0x00000000}},	//   _taba_, mgit, --, --,
   {{0xcdb70122,0x7ae4007c,0x660216ab,0x461600b5}},	//   דפסה_, lgit, rwok, _یوزر,
   {{0xa3dd00b4,0xf1d400ab,0x00000000,0x00000000}},	//   थूल_, _दिहन, --, --,
   {{0xd5b200bf,0x7ae43cc2,0x68e1c9f6,0x00000000}},	//   _نفر_, ngit, _öldr, --,
   {{0x35a619f8,0xe5a64619,0x799c04fb,0x60c30a21}},	//   _разг, _ризи, _kirw, _benm,
   {{0x3ea00248,0x26c40042,0xc3d600d8,0x6fb8021d}},	//   _agit_, _hemo_, _аўды, нгор_,
   {{0x41d410aa,0x3f890189,0x9f350208,0x64a30036}},	//   _दिवस, _phau_, гені, _таха,
   {{0x62070282,0x60c30c7c,0x3f89006d,0x799c8ec9}},	//   ärlä, _eenm, _qhau_, _lirw,
   {{0x3eb9033b,0x60c3021e,0x776200f6,0x7ae4027c}},	//   rbst_, _fenm, inox, dgit,
   {{0x60c32aab,0x61e03c9a,0xc6931804,0x799cb769}},	//   _genm, muml, יאר_, _nirw,
   {{0x2d4d103a,0x3f89c9f7,0x60c80cfc,0x00000000}},	//   džet_, _thau_, madm, --,
   {{0xeab30082,0x7ae4c9f8,0x98a30067,0x60c8c9f9}},	//   شعر_, ggit, _moją_, ladm,
   {{0x799c024c,0x6f0d0139,0x61e04a81,0x14b400e7}},	// [f9d0] _birw, _iaac, numl, ुराण,
   {{0x58b80082,0x60c8c9fa,0x3ad30019,0x6f0dc9fb}},	//   نامج_, nadm, ệp_, _haac,
   {{0x637e0031,0x26c40f5d,0x799c00e9,0x61e0045e}},	//   rënj, _bemo_, _dirw, huml,
   {{0x236601cc,0x26c40c21,0x61e00029,0x799c0090}},	//   _njoj_, _cemo_, kuml, _eirw,
   {{0x6f0d00ec,0x61e0c9fc,0x799cc9fd,0x80c30033}},	//   _maac, juml, _firw, _শাস্,
   {{0x6f0d00ec,0x6b9d11e9,0x2366003d,0xa3e910d5}},	//   _laac, _hisg, _ajoj_, едка_,
   {{0x60c30c1f,0x29014398,0x60c8765c,0xe4e401e0}},	//   _renm, meha_, dadm, річн,
   {{0x44290537,0x2901046a,0x60c3021e,0x13050274}},	//   ća_, leha_, _senm, узим,
   {{0x6b9dc9fe,0x60c3a502,0x69cdc9ff,0xdb1500b5}},	//   _misg, _penm, nsae, lszó,
   {{0x814500f8,0x2901ca00,0x66094191,0x60c80ba4}},	//   اندن, neha_, _isek, gadm,
   {{0x68e5066a,0x6f0dca01,0x60c30107,0x00000000}},	//   ighd, _baac, _venm, --,
   {{0x29cf0029,0xe1f100bf,0x8af000a8,0xdb1500b5}},	//   kļa_, _هست_, nnət, gszü,
   {{0x60c3213d,0x27e11228,0x8e561958,0x29016343}},	//   _tenm, huhn_, утні, keha_,
   {{0x29010c21,0x6da30610,0x6b9d0315,0x98e20803}},	//   jeha_, сира, _aisg, _पाइए,
   {{0x8c43014d,0x09cc0099,0x200700cd,0x6b9d4486}},	//   бере, ाळ्य, _usni_, _bisg,
   {{0x6b9d0036,0x799c18f9,0x00000000,0x00000000}},	//   _cisg, _sirw, --, --,
   {{0xc3320397,0x27ff0124,0x6b9d25a6,0x66099ebd}},	// [f9e0] זון_, _ćuna_, _disg, _nsek,
   {{0x26c4027a,0x00000000,0x00000000,0x00000000}},	//   _semo_, --, --, --,
   {{0x3ce90821,0x61e015d7,0x6b9d1db8,0x6f0d01ec}},	//   _जाते_, zuml, _fisg, _yaac,
   {{0x6aad027a,0x7bce0044,0x799c0051,0x61e028ae}},	//   ccaf, msbu, _wirw, yuml,
   {{0x60c8616d,0x7bce09e1,0x26c408b7,0x6609ca02}},	//   yadm, lsbu, _vemo_, _csek,
   {{0x18a318f0,0x245831ee,0x15b9010b,0x26c40027}},	//   _гарм, каль_, тыцы_, _wemo_,
   {{0x7bceca03,0x26c4108a,0xec3602b5,0x6609ca04}},	//   nsbu, _temo_, טאַר_, _esek,
   {{0x2d4d00f4,0xb04200cc,0x9c87007e,0xe9ff055c}},	//   nžer_, _ngưở, _hučí, _chặc_,
   {{0x6f0d4fb4,0xf2e701cb,0x602a013b,0x25a48ca9}},	//   _raac, اکمه_, məmi, _uuml_,
   {{0x61e02024,0x7f444831,0x7bce9640,0x215400d8}},	//   ruml, _aliq, ksbu, ркоў,
   {{0x637e00da,0xb4e00964,0xd8db0070,0xf5930037}},	//   hëni, थली_, עקטר, _اللج,
   {{0x7f44ca05,0x7bce6147,0x395a3b19,0x60c823c2}},	//   _cliq, dsbu, hips_, sadm,
   {{0x2d4d0254,0x60c80168,0x7bdc12ba,0x6b9dca06}},	//   džer_, padm, erru, _risg,
   {{0x3d0f0035,0x6f0d0054,0xdb1500b5,0x6b9d021d}},	//   ायें_, _waac, sszü, _sisg,
   {{0x602a0095,0x7bceca07,0xbc950370,0xa2d8021a}},	//   kəmi, gsbu, равј, नःप्,
   {{0x6d47ca08,0x2901023c,0x00000000,0x00000000}},	//   shja, weha_, --, --,
   {{0xa3e40d91,0x6b9dca09,0xb95502fb,0x00000000}},	// [f9f0] भूत_, _visg, аващ, --,
   {{0xdb1500b5,0x395a91a5,0x6b9d7119,0x66090298}},	//   tszó, gips_, _wisg, _rsek,
   {{0x6d45ca0a,0xa3a90907,0x2901ca0b,0xd6d10312}},	//   _ilha, _गंध_, reha_, ققا_,
   {{0x6b9d01a6,0x657a0024,0x66090065,0xa6150421}},	//   _uisg, _akth, _psek, имеч,
   {{0x290131e1,0x3d0a00a1,0xe4c50f9e,0xceb41804}},	//   peha_, ायचे_, айли, ציס_,
   {{0xdfc60c36,0x8cba02e4,0x6609008b,0x2b49ca0c}},	//   _وي_, ्रयो, _vsek, lhac_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6609ca0d,0x2b4900e2,0x657a0044,0x613f0183}},	//   _tsek, nhac_, _ekth, _pêlo,
   {{0x6d4503e6,0xdc020084,0x8cba0067,0xb145a259}},	//   _olha, _लन्ड_, ्रमो, инил,
   {{0xe9ff0019,0x59da0026,0x3d0f0067,0x00000000}},	//   _giấc_, यूटर, ायों_, --,
   {{0xb4d10099,0xff26182f,0x7f440176,0x00000000}},	//   वणी_, амно, _pliq, --,
   {{0x6d45ca0e,0x2f5601e0,0x2ba907b5,0x8bfd0831}},	//   _alha, ртос, _कढ़ा, ুমান_,
   {{0x93940332,0x6d45006d,0x6da6622d,0x733a016b}},	//   _اجلا, _blha, рига, _שענס,
   {{0x2d9eca0f,0x823400bf,0x7bce03c1,0xc0e2311c}},	//   öte_, _درما, tsbu, _дошк,
   {{0x307900c2,0xb7b00083,0x20790070,0x9c8700d5}},	//   _באַנ, _চট্ট, _באַא, _ručí,
   {{0x6d45006c,0x35c600b4,0xbb430279,0x224d01ed}},	//   _elha, रीड़, оеск, ozek_,
   {{0xeb9704de,0x395a0557,0x3b07075c,0x09e6ca10}},	// [fa00] рит_, tips_, шето_, розн,
   {{0x1aee0083,0x7bce864e,0x224d0065,0x00000000}},	//   _চোখে_, psbu, izek_, --,
   {{0xc796010b,0x6d5c10d3,0x602a00a8,0x395aca11}},	//   арды, mira, təmi, rips_,
   {{0x6d5c99b8,0x28e24d99,0x09e61c36,0x2b490067}},	//   lira, _पाकि, _комн, chac_,
   {{0x613f0298,0x00000000,0x00000000,0x00000000}},	//   _pêll, --, --, --,
   {{0xb4c2022e,0xd94627e9,0xb4e029b6,0x00000000}},	//   ्णे_, _теги, थले_, --,
   {{0xb7da0118,0x0fe000c8,0x4aaa0099,0x224d01ed}},	//   _جوزا_, _বন্ধ, _कलाव, ezek_,
   {{0x6d5c3b4a,0x320a0035,0x2b40012f,0x00000000}},	//   hira, łbym_, nkic_, --,
   {{0x6d5c043c,0x00000000,0x00000000,0x00000000}},	//   kira, --, --, --,
   {{0x6d5c016a,0x09f700a5,0x3253010b,0x657a00e0}},	//   jira, סמים_, івэр, _ukth,
   {{0x940601ca,0x130601d3,0x506603e6,0x2d4d0009}},	//   _خواه, _взем, ртпа, džep_,
   {{0x6d5c0f84,0xd4910023,0xc2e90037,0x00000000}},	//   eira, _này_, _معهم_, --,
   {{0x6d5cca12,0x224d004e,0x6d450221,0x443c01ba}},	//   fira, czek_, _plha, lyv_,
   {{0x6d5cca13,0x657d08e3,0x00000000,0x00000000}},	//   gira, _ësht, --, --,
   {{0x443c006c,0x5f95002d,0xb0b700a5,0xd491055c}},	//   nyv_, _ликт, _דפוס_, _bày_,
   {{0x7e6d06a2,0x4fb305bc,0x6e220009,0x63a857e7}},	//   _txap, _بصور, _šobe, _mudn,
   {{0x6d5cca14,0x63a8ca15,0x2df500fd,0xe293016b}},	// [fa10] bira, _ludn, _آخر, ַװע_,
   {{0x6d5c0888,0x236902dd,0xb4c207df,0x00000000}},	//   cira, čaji_, ्णो_, --,
   {{0x2d830496,0x69c00031,0x63a80c3d,0x00000000}},	//   mlje_, _çmen, _nudn, --,
   {{0xd36601b2,0x2d839fbd,0x7f5d00f6,0x00000000}},	//   _ره_, llje_, nisq, --,
   {{0xa9970df3,0x201a0693,0x00000000,0x00000000}},	//   _نشست, _špil_, --, --,
   {{0x63a8040b,0x3a360397,0xd4692ecf,0xb4d10099}},	//   _budn, _הרשם_, лиле_, वणे_,
   {{0x63a8c16f,0x58d40171,0xbebb01f4,0x3f8200fe}},	//   _cudn, _фост, njës, ylku_,
   {{0x6d5cca16,0x1309002d,0x224d01a3,0xe80400dc}},	//   zira, уний_, tzek_, रबरा_,
   {{0x6d5c0232,0x2911ca17,0x2d83011c,0x00000000}},	//   yira, _kaza_, klje_, --,
   {{0x77b30024,0x661b3499,0x2911023c,0x6d5cca18}},	//   _eħxe, _iruk, _jaza_, xira,
   {{0x9327006c,0x224d1f11,0x2911ca19,0x2d830169}},	//   _پران, szek_, _maza_, dlje_,
   {{0x6d5c5542,0x661b5030,0x29119089,0x2d830051}},	//   wira, _kruk, _laza_, elje_,
   {{0x6d5cca1a,0xf1a70948,0x2374004f,0xe28e3537}},	//   tira, _трен, _بالح, _ха_,
   {{0x628b0496,0x7c3c0c61,0x2911ca1b,0x661bca1c}},	//   _izgo, tyrr, _naza_, _mruk,
   {{0x8c435c79,0x92e90083,0xbebb00da,0x00000000}},	//   пере, য়ী_, gjës, --,
   {{0x7f5d0024,0x661b001c,0x6d5c7605,0x6b8f009e}},	//   cisq, _oruk, sira, _chcg,
   {{0x2911ca1d,0x2d8310ec,0xe8fa5084,0x6ebe0569}},	// [fa20] _baza_, blje_, лла_, _व्यु,
   {{0xeeeb01a5,0x29110b4c,0x4a430370,0xc8ca00f8}},	//   ượng_, _caza_, чнув, اوان_,
   {{0x3eadca1e,0x9b460934,0x291102d7,0x661b6ead}},	//   žete_, _هندو, _daza_, _aruk,
   {{0x63a81977,0x661b6a01,0xab2a0d46,0x29110160}},	//   _rudn, _bruk, _сома_, _eaza_,
   {{0x6b84022a,0x991602ce,0x63a80af1,0x3d1d0099}},	//   mlig, _льві, _sudn, माचे_,
   {{0x6b841cd4,0x38cb04a3,0xbebb0031,0x28e202b4}},	//   llig, _مافی_, njër, _पाटि,
   {{0x68e3ca1f,0x661b88d6,0xd37a4697,0x6b841fe7}},	//   ónde, _eruk, лчи_, olig,
   {{0x6b8404ca,0x661b9ccd,0xe71a414b,0x35a6061c}},	//   nlig, _fruk, _حيرت_, _гааг,
   {{0xcb130122,0x3ce900ab,0x2911817c,0x00000000}},	//   ללה_, _जाले_, _yaza_, --,
   {{0x3a370052,0x63a8006c,0x6b84b69c,0x637e0051}},	//   צרים_, _tudn, hlig, eënt,
   {{0x2d830496,0x6b84b257,0xe97b02b5,0xe1ef0df3}},	//   vlje_, klig, רניש, وسی_,
   {{0x6b8433fd,0x8f470086,0x88ae0083,0x398f033b}},	//   jlig, сход, গরিক, müse_,
   {{0x6b840bf3,0x7f5dca20,0x2d8301a0,0x81a60079}},	//   dlig, risq, tlje_, _احصل,
   {{0x63a2004f,0x6b65010b,0x61e0012e,0xbebb0031}},	//   _hion, mėgi, mrml, gjër,
   {{0x63a2000e,0x7bda6395,0x291154cf,0x6fb40a72}},	//   _kion, štun, _raza_, _بمبا,
   {{0x6b840bf3,0x2d83025c,0x63a20054,0x200e012f}},	//   glig, slje_, _jion, _isfi_,
   {{0x63a2ca21,0x2d8315d7,0x291100af,0x9e9501cb}},	// [fa30] _mion, plje_, _paza_, _باغچ,
   {{0x39474a07,0x63a2ca22,0x201cca23,0x6b84ca24}},	//   óns_, _lion, _krvi_, alig,
   {{0x6b844341,0x29110009,0xe7871958,0x7d0703c9}},	//   blig, _vaza_, будо, mejs,
   {{0x2911012f,0x201c0124,0x4ded073f,0x501b00a5}},	//   _waza_, _mrvi_, _जमाई_, טובו,
   {{0x62820189,0x2911ca25,0xd6290cc7,0x00000000}},	//   _nyoo, _taza_, роле_, --,
   {{0x81b700c8,0xf2b308b0,0x7d070a69,0x63a2ca26}},	//   _ছিল_, ीर्घ, nejs, _aion,
   {{0xf8ae09b9,0xc7c40043,0x62828ec9,0x00000000}},	//   _شکل_, _нсти, _ayoo, --,
   {{0xf7730df3,0x63a2009c,0x661bca27,0x661d008d}},	//   _راز_, _cion, _truk, _ásko,
   {{0x63a2ca28,0x661b0232,0x7d0737cb,0x6b6500c7}},	//   _dion, _uruk, kejs, gėgi,
   {{0x92e912eb,0x26cfca29,0x628b02c6,0x6b846de5}},	//   য়ে_, lago_, _vzgo, zlig,
   {{0x5f062462,0x63a2066a,0x6b845053,0x7d07ca2a}},	//   озна, _fion, ylig, dejs,
   {{0x26cfca2b,0x7c2a0443,0x63a2ca2c,0x6b840051}},	//   nago_, _àfri, _gion, xlig,
   {{0x80bab46f,0x6b840b6c,0x628b6707,0x237800b5}},	//   _श्वे, vlig, _uzgo, _írja_,
   {{0x236910ec,0x7afdca2d,0x6b840069,0x26cfca2e}},	//   čaju_, _abst, wlig, hago_,
   {{0x6b841e8b,0x26cfca2f,0xdca3ca30,0x00000000}},	//   tlig, kago_, дари, --,
   {{0x63a201e8,0xeeeb0019,0x26cf5010,0xf09200a5}},	//   _xion, ưỡng_, jago_, _קנה_,
   {{0x6b840bf3,0x62820189,0x26cf01d7,0x00000000}},	// [fa40] rlig, _xyoo, dago_, --,
   {{0x6b84ca31,0x7afd010d,0xf99f0107,0x00000000}},	//   slig, _ebst, _krèy_, --,
   {{0xb9020755,0xfaa603d6,0xc6a62101,0x6b84ca32}},	//   _नए_, _мано, орли, plig,
   {{0x34b40380,0xe61a0cd0,0x6b841505,0x068621be}},	//   ुर्द, иде_, qlig, оген,
   {{0x63a24132,0x2b470395,0x00000000,0x00000000}},	//   _rion, _înca_, --, --,
   {{0x6d4eca33,0x00000000,0x00000000,0x00000000}},	//   nhba, --, --, --,
   {{0x26cfca34,0xf746bab4,0x18671b50,0x53e6010b}},	//   bago_, _дево, _дари_, іцка,
   {{0x70e200b4,0x26cfc000,0x7d07bcdc,0x03770118}},	//   पल्ल, cago_, zejs, يحيت_,
   {{0x63a20657,0x416a03fa,0x6600028b,0x6d4e00d7}},	//   _vion, ијом_, _upmk, khba,
   {{0x201cca35,0x321d0297,0x929d004e,0xd13a052a}},	//   _prvi_, _drwy_, pełn, рхи_,
   {{0x63a2ca36,0x6d4e004f,0xf8b30d85,0x28cb018d}},	//   _tion, dhba, ושת_, िरति,
   {{0x80ba0567,0x23270210,0x71a600d8,0xd24600af}},	//   _श्रे, _мохи_, _дадз, _мэли,
   {{0x3326ca37,0x7d07ca38,0x079b0317,0xdcf70024}},	//   _inox_, tejs, יסטל, _jixħ,
   {{0x26cf01a3,0x656a0079,0xdcf70069,0x00000000}},	//   zago_, nnfh, _mixħ, --,
   {{0x7d071fe5,0x26cfca39,0x93bc00af,0xf99f021e}},	//   rejs, yago_, _drăg, _trèz_,
   {{0x7d071a8a,0x386d0207,0x6719046c,0x00000000}},	//   sejs, _ćer_, _नोंक_, --,
   {{0xaf4b09b9,0x7d07004e,0x3ea96bfd,0x1a6500fd}},	// [fa50] _مشکل_, pejs, _igat_, سیسی_,
   {{0x6d4e02c9,0xcd00004e,0x26cf3998,0x929d0067}},	//   chba, ęści_, wago_, zeło,
   {{0x26cfca3a,0xb8d302e4,0x00000000,0x00000000}},	//   tago_, _ऑल_, --, --,
   {{0x475801e0,0x00000000,0x00000000,0x00000000}},	//   орія_, --, --, --,
   {{0x26cfca3b,0x98aa0035,0x59e200ab,0x00000000}},	//   rago_, _sobą_, _पियर, --,
   {{0x7aedca3c,0x25bd00e9,0x80ba012f,0x93bc0139}},	//   lgat, rpwl_, _श्ले, _orăd,
   {{0x26cfca3d,0x2b4b0fef,0x64a20274,0x7aed0036}},	//   pago_, _klcc_, наша, ogat,
   {{0x7aed5875,0x3f9902c4,0x00000000,0x00000000}},	//   ngat, jmsu_, --, --,
   {{0x020200af,0x93bc0395,0xc2e80037,0x00000000}},	//   езын, _arăd, زعيم_, --,
   {{0x3ea90082,0x2eb61729,0xf8cb0387,0x93bc0160}},	//   _agat_, ूर्त, िरिय, _brăd,
   {{0x48fd045c,0x7aedca3e,0xf3f0004f,0x00000000}},	//   र्यो_, kgat, _لأن_, --,
   {{0x321d0297,0x23fa00a5,0x3f6a2dbb,0x25a5ca3f}},	//   _trwy_, _לפעמ, симо_, _hill_,
   {{0x9f468469,0x7aedca40,0x25a584d8,0x23b11534}},	//   nulé_, dgat, _kill_, _háj_,
   {{0x7aedca41,0xb226008a,0x61e9ca42,0xdb1c00f7}},	//   egat, stæð, muel, mpré,
   {{0xa06610cc,0x3eadca43,0x93bc002d,0xed57021d}},	//   _наша_, žeta_, _grăd, чор_,
   {{0x6d4eca44,0x25a50484,0x8b95ca45,0x7aedca46}},	//   shba, _lill_, друч, ggat,
   {{0x61e9ca47,0x93bc0139,0x00000000,0x00000000}},	// [fa60] nuel, _trăg, --, --,
   {{0x7aed01d7,0xef1800ea,0x9f461f55,0x00000000}},	//   agat, ēļu_, dulé_, --,
   {{0xdb24006c,0x0d3b00a5,0x5d3b00a5,0x6d3b00a5}},	//   _ہوگی, _הגיב, _התיא, _התינ,
   {{0x25a51600,0x61e9ca48,0x00000000,0x00000000}},	//   _aill_, kuel, --, --,
   {{0xd6cf0125,0x1dbe012f,0xceb302b8,0x61e90453}},	//   اقه_, ्ठित, גיד_, juel,
   {{0x25a509c3,0x6f1600d7,0x394a0160,0x00000000}},	//   _cill_, _layc, _ulbs_, --,
   {{0xb4ac0084,0xa84a0037,0x533401af,0x00000000}},	//   _गली_, _الأم_, дейт, --,
   {{0xe3af00d1,0x25adca49,0xf1dd00b4,0x98a30d13}},	//   درو_, _fuel_, _मिशन, _чисе,
   {{0x6d5eca4a,0xdb1c5469,0x69d6ca4b,0x25a5ca4c}},	//   _ompa, rprè, nsye, _fill_,
   {{0x25fb009a,0x7aed006c,0x93bc0139,0x3ea901da}},	//   ोबरी_, zgat, _prăd, _sgat_,
   {{0xc05a005f,0x7bda15d7,0x93bc0160,0x7aed055c}},	//   сіп_, štuj, _brăe, ygat,
   {{0x6d5eca4d,0x69d6ca4e,0x6f16009e,0x753a01d7}},	//   _ampa, ksye, _cayc, _hotz,
   {{0x61e9ca4f,0x7642ca50,0x753a56e9,0xd337011d}},	//   cuel, nyoy, _kotz, _מראה_,
   {{0x753a06a2,0x7bd5ca51,0x93bc0395,0x61db024b}},	//   _jotz, tszu, _trăd, _פקוד,
   {{0x01331629,0x317e06a2,0x753aca52,0x7aed5322}},	//   _سعود, motz_, _motz, tgat,
   {{0x3ce9007c,0x7aed002d,0x753a01d7,0x3ea92326}},	//   _जाके_, ugat, _lotz, _ugat_,
   {{0x7aedca53,0x7bd5006c,0x7f4d2318,0xad2700b2}},	// [fa70] rgat, sszu, _ilaq, _فردو,
   {{0x7aedca54,0x48ab5699,0x25ad0159,0xa41c0066}},	//   sgat, стам_, _ruel_, पटाप_,
   {{0x61e9ca55,0xf7700647,0x00000000,0x00000000}},	//   zuel, گال_, --, --,
   {{0xf1dd0f9c,0xf7732e36,0x25a5586b,0x61e9215f}},	//   _मिलन, راض_, _sill_, yuel,
   {{0x25ad8cec,0x61e9ca56,0x1a6800b5,0x7642010d}},	//   _quel_, xuel, _ٹیلی_, gyoy,
   {{0x7f4d0176,0x61e90831,0x59e21371,0x6d47ca57}},	//   _llaq, vuel, _पितर, nkja,
   {{0x25a54d77,0xe9ff01a5,0x753a1da0,0x93bc0160}},	//   _vill_, _khắc_, _dotz, _arăb,
   {{0x25a501f3,0x96f80036,0x7528ca58,0xb2252b4b}},	//   _will_, _нест_, _endz, дмил,
   {{0x25a51304,0x6d47ca59,0xf77004e8,0xecbf0026}},	//   _till_, kkja, _صاف_, ्राफ,
   {{0xdb1c3e0a,0x0ee60026,0x7f4dca5a,0x48f2000c}},	//   rpré, कल्स_, _alaq, ुभयो_,
   {{0xdee69d83,0x65630370,0xdb1c0955,0x673b00d7}},	//   мони, minh, spré, _kouj,
   {{0x6563ca5b,0xe9ff0019,0xe8050035,0x7f4d000d}},	//   linh, _nhắc_, _रहना_, _claq,
   {{0x61e9ca5c,0x5155ca5d,0x236d3d3f,0x7d170be2}},	//   quel, _отку, mnej_, _baxs,
   {{0x236d9200,0x6563ca5e,0x2480027d,0x6ebe0026}},	//   lnej_, ninh, şime_, _व्रु,
   {{0x6da30b46,0x628f0254,0xe1f9010b,0x6729ca5f}},	//   тира, škoć, ltų_, _onej,
   {{0xe9ff01a5,0x236dca60,0x69d61ec8,0x6563ca61}},	//   _chắc_, nnej_, tsye, hinh,
   {{0xe1f901c8,0x6563ca62,0xed5a6c07,0x2d960036}},	// [fa80] ntų_, kinh, _мои_, _орос,
   {{0xb4ac0084,0x6d5eca63,0x69d62244,0x65631699}},	//   _गले_, _umpa, rsye, jinh,
   {{0x6563ca64,0x673b02e9,0xf99f02d0,0x753a0a8d}},	//   dinh, _bouj, _rsèt_, _rotz,
   {{0xe1f901c8,0x6443ca65,0x236dca66,0x753a0065}},	//   ktų_, dyni, jnej_, _sotz,
   {{0x7d17013b,0x236dca67,0x65630132,0x776201a3}},	//   _yaxs, dnej_, finh, riox,
   {{0x6563ca68,0x6443001e,0x67290107,0xf8b207b5}},	//   ginh, fyni, _enej, _जलिय,
   {{0x29181e6d,0x8af000a8,0x6443ca69,0x00000000}},	//   _iara_, biət, gyni, --,
   {{0x52140091,0x27f7000c,0x29188d15,0x673b8e83}},	//   едит, žení_, _hara_, _gouj,
   {{0x2918ca6a,0x6d4700fb,0x6563ca6b,0x26c6ca6c}},	//   _kara_, ykja, binh, mboo_,
   {{0x2918003c,0x291aca6d,0x65630279,0x270e0174}},	//   _jara_, ndpa_, cinh, _ससुर_,
   {{0x2918ca6e,0x7f4dca6f,0x236dca70,0xc05700d4}},	//   _mara_, _plaq, bnej_, дія_,
   {{0x29183a35,0x122a00c3,0x236d94da,0x6b510523}},	//   _lara_, _моей_, cnej_, _kåge,
   {{0x291800af,0x3ead9c6b,0x00000000,0x00000000}},	//   _oara_, žeto_, --, --,
   {{0x2918ca71,0x6b51008c,0x00000000,0x00000000}},	//   _nara_, _måge, --, --,
   {{0x6d47a0f6,0x5ba70b90,0xf99f0118,0x6b51362b}},	//   rkja, драз, _osèr_, _låge,
   {{0x65630370,0x6d47ca72,0x3cfb00ab,0x00000000}},	//   zinh, skja, _लउके_, --,
   {{0x2918ca73,0x64430035,0x68e301ef,0xd91b0421}},	// [fa90] _bara_, zyni, óndo, жье_,
   {{0x2918ca74,0x6563ca75,0xa3df0084,0x67292038}},	//   _cara_, xinh, _तिल_, _snej,
   {{0x2918ca76,0xe9ff01a5,0x6563ca77,0x5c74002d}},	//   _dara_, _thắc_, vinh, _алэт,
   {{0x2918009e,0xe1f9010b,0x6b510282,0x644300c7}},	//   _eara_, ytų_, _båge, vyni,
   {{0x2918ca78,0x6563ca79,0x236d016f,0x6443001e}},	//   _fara_, tinh, vnej_, wyni,
   {{0x2918ca7a,0xfbd00e3a,0x6443ca7b,0x236d0035}},	//   _gara_, _حتی_, tyni, wnej_,
   {{0x673bca7c,0xd88300bf,0x6563ca7d,0x236d307f}},	//   _touj, _شهری, rinh, tnej_,
   {{0x6563ca7e,0x2918ca7f,0x3cff0035,0x6b51013c}},	//   sinh, _zara_, श्ते_, _fåge,
   {{0x236dca80,0x65630279,0x2918ca81,0xdb060118}},	//   rnej_, pinh, _yara_, _dikè,
   {{0xdb0600da,0xe1f900d8,0x236dca66,0x00000000}},	//   _pikë, rtų_, snej_, --,
   {{0xe1f900d8,0x236d15da,0x1ee801cb,0x00000000}},	//   stų_, pnej_, وودی_, --,
   {{0xe8cb0380,0xe1f9010b,0x20bf157d,0x6b510523}},	//   िरुच, ptų_, _श्रध, _lågb,
   {{0x3ea4013c,0x290302c4,0xe1170831,0x00000000}},	//   ämt_, _obja_, ়াবহ_, --,
   {{0x98aa01c0,0xdb0500b5,0x61fb0327,0xdd924a57}},	//   _době_, _ruhá, mtul, اوس_,
   {{0x61fbca82,0xeb9a1c76,0xab2a0aec,0x3b9603e6}},	//   ltul, зив_, пова_, ејат,
   {{0x2918ca83,0xdbd6007c,0xdcfc022f,0x2be1022e}},	//   _sara_, _rääg, morč, _फिरा,
   {{0x2918ca84,0x61fbca85,0x6f040010,0x0d86002d}},	// [faa0] _para_, ntul, _ibic, _плин,
   {{0x5e5700c2,0x29180095,0x6e24ca86,0x3f82ca87}},	//   _נייע_, _qara_, _irib, loku_,
   {{0x2918ca88,0x363600e0,0x6e24008b,0xdb060097}},	//   _vara_, کراس, _hrib, _liké,
   {{0x2918048c,0x3ae80332,0x7d0eca89,0x6e24ca8a}},	//   _wara_, _کبھی_, lebs, _krib,
   {{0x2918ca8b,0x8af000a8,0x6f041766,0xa3a9021a}},	//   _tara_, rhəd, _mbic, _गंज_,
   {{0x59b50821,0x69c4ca8c,0x3f8222be,0xdb0601cb}},	//   _अंतर, mpie, hoku_, _sikè,
   {{0x6f04ca8d,0x66e62b05,0xf8a70f3d,0x3f820124}},	//   _obic, _пова, _कृपय, koku_,
   {{0x31c6263d,0xe80508a9,0x6e2403f3,0x6b510542}},	//   нсов, _रहता_, _orib, _tåge,
   {{0xa3b002e4,0x61fb0d0d,0x69c4ca8e,0x6e240176}},	//   _टूर_, gtul, npie, _nrib,
   {{0x09f70122,0x6f04ca8f,0x2ee01d75,0x69c4c8bd}},	//   עמים_, _abic, _adif_, ipie,
   {{0xb4cc0821,0xf65f00fb,0x6e240010,0xdcfc0a18}},	//   लरी_, _þær_, _arib, gorč,
   {{0x98aa00b8,0x3f82ca90,0x21f900bf,0x3ead082b}},	//   _sobě_, goku_, bèh_, øet_,
   {{0x61460373,0x61fb0043,0x69c4004e,0x31650065}},	//   _педа, ctul, jpie, bilz_,
   {{0x2d8500f7,0xc6930317,0xf99f021e,0x2ee002d7}},	//   ôle_, טאר_, _apèn_, _edif_,
   {{0xef1f06d3,0x3f82a984,0x64585fd5,0xc04f27ac}},	//   nlük_, boku_, nzvi, _сі_,
   {{0xa3e80534,0x59b50066,0xfaff0055,0x3f8200e0}},	//   _बिन_, _अंदर, _ajër_, coku_,
   {{0x6e24ca91,0x69c46d38,0x6b74022c,0x6f0fca92}},	// [fab0] _grib, gpie, улту, mecc,
   {{0x6f0f374e,0xa3c200c4,0x6f1d7121,0xe81d046c}},	//   lecc, ्ठा_, ldsc, फिला_,
   {{0xfe7004cd,0x2d837cb0,0x69c407e5,0x0cbf09b4}},	//   _ندی_, moje_, apie, ्रीम,
   {{0x645888aa,0xdc3602b5,0x2d83ca93,0x6f0f014c}},	//   dzvi, _סארט_, loje_, necc,
   {{0xd7740180,0x6b8d3d98,0xdcfc0690,0x6f1d0a8d}},	//   دالع, mlag, zorč, idsc,
   {{0x2d83ca94,0x3f8200d7,0x6b8dca95,0x00000000}},	//   noje_, zoku_, llag, --,
   {{0xe8940328,0x4375116b,0x6b8d01ed,0x00000000}},	//   _барь, куит, olag, --,
   {{0x6b8d1949,0x61fbca96,0x6f0f0443,0x6f1d01e4}},	//   nlag, ttul, jecc, jdsc,
   {{0x2d83ca97,0x11d60037,0x29cf405d,0x6b8d0110}},	//   koje_, نوية_, nża_, ilag,
   {{0x2d8301c8,0x6b8d3230,0xd684ca98,0xb8820097}},	//   joje_, hlag, _сусп, číva,
   {{0x61fbca99,0x69c4006a,0xf8b202da,0x6f0f0aaf}},	//   stul, zpie, ישי_, fecc,
   {{0x7d0eca9a,0x6b8d6af0,0x61fbca9b,0x44255466}},	//   webs, jlag, ptul, _irl_,
   {{0x6b8dca9c,0x780d0e62,0xee3700d4,0x2d83a0db}},	//   dlag, सबुक_, вня_, foje_,
   {{0x4d150f92,0x2d83ca9d,0xd138004e,0x0cb00083}},	//   льст, goje_, cją_, কর্ত,
   {{0x69ddca9e,0x6b8dca9f,0xdbcc002a,0x61e93be1}},	//   _avse, flag, _póñe, lrel,
   {{0x6f04caa0,0x6b8dcaa1,0x6e2414bc,0x63ab1b70}},	//   _ubic, glag, _trib, _jign,
   {{0xf2d200c2,0x6e24caa2,0x61e90a2d,0xef1f01d6}},	// [fac0] יען_, _urib, nrel, zlük_,
   {{0x63ab643a,0x69c4caa3,0x08c30c65,0x2d83caa4}},	//   _lign, rpie, ибун, coje_,
   {{0x69c4caa5,0x660911e9,0x07a67732,0x63ab00f7}},	//   spie, _apek, важн, _oign,
   {{0x0bb70122,0x66e638ea,0x6b8dcaa6,0x93bc0139}},	//   _שלכם_, тода, clag, _brăn,
   {{0x6b840248,0x628e0035,0x44250381,0x00000000}},	//   moig, ębok, _arl_, --,
   {{0xa8061714,0x61e9434f,0x63ab47a4,0x6f0f07e5}},	//   _изгл, drel, _aign, zecc,
   {{0x6f0f0831,0x63ab0f38,0x66091c3f,0x86ea0037}},	//   yecc, _bign, _epek, _يعرف_,
   {{0x6f0f01dd,0x63ab5c1d,0xb6c8006c,0x628b2e0c}},	//   xecc, _cign, _سارے_, _bygo,
   {{0x63abcaa7,0x6f0f72ce,0xf7430370,0x93bc0160}},	//   _dign, vecc, _тето, _grăn,
   {{0x63ab2129,0x6b8d008b,0x4a9b0070,0x2d830031}},	//   _eign, zlag, ויפג, xoje_,
   {{0x6f0f4df4,0x2d83caa8,0x61e90ad8,0x63ab0260}},	//   tecc, voje_, arel, _fign,
   {{0x6b8400f7,0xf99f02d0,0x2d5400ab,0x63abcaa9}},	//   joig, _apèl_, _näeb_, _gign,
   {{0x6f0f2993,0x2d83caaa,0x61e90225,0x06d70033}},	//   recc, toje_, crel, _হামি,
   {{0xe9ff00e8,0xac190370,0x644501ae,0x0cbf09b8}},	//   _nhạc_, ногу_, ähig, ्रेम,
   {{0x2d83caab,0x6b8d18f7,0x6f0f66ea,0x7bdc01ff}},	//   roje_, tlag, pecc, gsru,
   {{0x2d83caac,0x6b8d03d0,0x6b510523,0x00000000}},	//   soje_, ulag, _båga, --,
   {{0x4975087b,0x6b8d1949,0x2d8393de,0xdd9b5f6e}},	// [fad0] глас, rlag, poje_, _ошо_,
   {{0x6b8dcaad,0x29cfb7dc,0x2919250f,0xef1f00d0}},	//   slag, rża_, عقاد_, ldü_,
   {{0xd9ef009a,0x61e95ffc,0x6b8d21cc,0x6c351d05}},	//   _चमकत_, zrel, plag, _صفحا,
   {{0x7bc7caae,0x61e9caaf,0xc2e800c8,0x7c2a00fb}},	//   mpju, yrel, ক্তি_, _áfra,
   {{0x4425cab0,0x63ab0093,0x6b5104c1,0x9f4600d5}},	//   _srl_, _rign, _gåga, nulá_,
   {{0x63ab3104,0x61e9cab1,0x75d20037,0xdb1c0138}},	//   _sign, vrel, حيوا, mprá,
   {{0x97a70409,0x63ab72eb,0xad9b0138,0xdcfc00ea}},	//   _арал, _pign, ctúe, norā,
   {{0xb8822ab5,0x3f89006d,0x93bc01a5,0xaad30035}},	//   číta, _nkau_, _trăn, तरिक,
   {{0x63abcab2,0x28a70af6,0xe500007c,0x660974b6}},	//   _vign, _कृति, ल्हि_, _upek,
   {{0x74ca022e,0x63abcab3,0x4425023c,0x344b07e5}},	//   _स्पृ, _wign, _trl_, _очен_,
   {{0x63abcab4,0x628b0035,0x4ad30099,0x00000000}},	//   _tign, _wygo, तराव, --,
   {{0x69c1308b,0x628b004e,0x61e9cab5,0xd04800a8}},	//   _člen, _tygo, prel, nadə,
   {{0xcdf645d7,0x91e516e2,0x00000000,0x00000000}},	//   ычны, _соле, --, --,
   {{0x7bdccab6,0xd048013b,0x00000000,0x00000000}},	//   tsru, hadə, --, --,
   {{0x24d80083,0x00000000,0x00000000,0x00000000}},	//   _সামহ, --, --, --,
   {{0x13d101c0,0x7bdccab7,0x4906021a,0x6b514a11}},	//   _सबैभ, rsru, स्नो_, _påga,
   {{0x0eaa02ce,0x7bdc01ff,0x8d760427,0x00000000}},	// [fae0] _який_, ssru, _مادا, --,
   {{0xe6cc1856,0x6b510364,0xdb05008c,0x7bda00fd}},	//   ार्ज, _våga, _ruhå, átus,
   {{0xd04801c2,0x46ea0dc8,0x3cfb0122,0x25ac00d7}},	//   fadə, еден_, _אלינ, _ridl_,
   {{0x27e7cab8,0x291c4f18,0x7d1ecab9,0xcc3b0070}},	//   ánna_, žva_, _haps, _נעכט,
   {{0x7d1ecaba,0xe9ff0023,0x16347bd6,0xd91001df}},	//   _kaps, _thạc_, реля, _ویر_,
   {{0x7af6010b,0x00000000,0x00000000,0x00000000}},	//   lgyt, --, --, --,
   {{0x4ab80953,0x6d4e2193,0x97b503e6,0xb7960274}},	//   _अलाव, ikba, _всуш, _браћ,
   {{0x7d1e087a,0xb6a632fa,0x3ead00ec,0x75d60413}},	//   _laps, _библ, žeti_, _ميرا,
   {{0x316a0ece,0x39b20260,0x25ac0b3e,0x00000000}},	//   ешно_, _fņse_, _tidl_, --,
   {{0x7d1e01c0,0x6d4e0120,0x845acabb,0x3d0e0067}},	//   _naps, jkba, _прет_, ाजों_,
   {{0x893702b5,0xb4c213ab,0xdb1c016f,0x4906046c}},	//   אריע_, ूरी_, zprá, स्यो_,
   {{0x60c40723,0x3cfa01f7,0x7d1e0298,0xdb0600ee}},	//   _şimd, _acpv_, _aaps, _bikí,
   {{0xe2920082,0x246e01c2,0x5ce700d4,0xef1f04d4}},	//   _اذا_, _həm_, люва, rdü_,
   {{0x7c870be8,0xe805007c,0xd048013b,0x00000000}},	//   губе, _रहला_, zadə, --,
   {{0x07040fbf,0x7d1e0409,0x00000000,0x00000000}},	//   रभाव_, _daps, --, --,
   {{0xae220026,0x60dacabc,0x6d4ecabd,0x00000000}},	//   मिशन_, latm, akba, --,
   {{0x5a3506c2,0x13cd0033,0x5f7400f8,0x7bda008d}},	// [faf0] шнат, রওয়, _داور, átur,
   {{0xdd92006c,0x2907cabe,0x93bc0160,0x60dacabf}},	//   _ووٹ_, ýna_, _arăm, natm,
   {{0x6aa60083,0x8ccb11b5,0xdb1ccac0,0xa8150132}},	//   গুলো, _त्यो, sprá, рдеш,
   {{0x7bc501ed,0x7d1e00b8,0x644a0035,0x00000000}},	//   _ithu, _zaps, dyfi, --,
   {{0x7d1e0225,0xa3d70067,0x00000000,0x00000000}},	//   _yaps, ़ीन_, --, --,
   {{0xa5091654,0xe5a53392,0x00000000,0x00000000}},	//   тека_, шили, --, --,
   {{0x93bc0395,0x36d5010b,0x60dacac1,0x7bc50282}},	//   _frăm, _вобр, datm, _jthu,
   {{0x2913cac2,0x93bc0139,0x00000000,0x00000000}},	//   lexa_, _grăm, --, --,
   {{0x6d4e03bc,0x6b51017b,0x00000000,0x00000000}},	//   ykba, _lågo, --, --,
   {{0xe61010ad,0x29131c02,0x661b01d5,0xa3b00066}},	//   _عشق_, nexa_, _isuk, _टूक_,
   {{0x6b514b47,0x7bc5006f,0x764b00e9,0xb4c10325}},	//   _någo, _nthu, lygy, ंडी_,
   {{0x3f6a9b5f,0x00000000,0x00000000,0x00000000}},	//   тимо_, --, --, --,
   {{0x7bc500fb,0x43840082,0x7d1ecac3,0x3cfa0176}},	//   _athu, _النق, _paps, _pcpv_,
   {{0xa0a5cac4,0x39433dc8,0x661b002f,0xb5fd00d5}},	//   _калд, _nojs_, _msuk, _dxšx,
   {{0xdca60525,0xdfd10037,0x7bc5026e,0x291300f6}},	//   рави, _بيع_, _cthu, dexa_,
   {{0x207a0070,0xc4d102b4,0x3a2d02a7,0x00000000}},	//   _באצא, हरुख, _šepa_, --,
   {{0x4aaa0390,0xc3320bed,0xe8faa4da,0x44200023}},	// [fb00] ткан_, חון_, кла_, ̉i_,
   {{0xe8c700af,0x9f460079,0xad9b0098,0x38cb0647}},	//   игул_, irlí_, rtúc, نامی_,
   {{0x661bcac5,0x00000000,0x00000000,0x00000000}},	//   _asuk, --, --, --,
   {{0xe73900e9,0x6c7b011d,0xe5c6124a,0x00000000}},	//   _siŵr_, _יריד, аско, --,
   {{0x799c00e9,0x6b5800ee,0xb4c10099,0x5ea80831}},	//   _thrw, _cíge, ंडू_, কুরে,
   {{0x6e3b033b,0xe5e50037,0x6b5115e4,0x69c684e0}},	//   äubi, إثني, _lågl, _itke,
   {{0xa96700af,0xd37a027a,0x661bcac6,0x6c7a0070}},	//   _тира_, кчи_, _esuk, כאַפ,
   {{0x644acac7,0x00000000,0x00000000,0x00000000}},	//   ryfi, --, --, --,
   {{0x644a599b,0xd1300037,0x67200069,0xdb0f00f6}},	//   syfi, كمة_, _iamj, _bicê,
   {{0x66026801,0x62990035,0x6720002f,0x71740037}},	//   mtok, _dzwo, _hamj, إهدا,
   {{0x60daae4d,0x733600b5,0x6602cac8,0x6299021e}},	//   ratm, _پرائ, ltok, _ezwo,
   {{0x6722c4fe,0x49060803,0x6602cac9,0x31bb021d}},	//   ndoj, स्तो_, otok, _fêz_,
   {{0x60dacaca,0x6602cacb,0x7a0a00ea,0x290a073a}},	//   patm, ntok, nētā, _obba_,
   {{0xd24f00e0,0x8d87021d,0x66020421,0x00000000}},	//   _تنه_, румд, itok, --,
   {{0x06d700c8,0x39430df4,0x61e20093,0x7b6700c3}},	//   _হাসি, _rojs_, _hvol, атае,
   {{0x6720029d,0x290acacc,0x68fc01ef,0x61e2cacd}},	//   _namj, _abba_, _acrd, _kvol,
   {{0x200e008c,0x65680118,0x2913002a,0x00000000}},	// [fb10] _hpfi_, _omdh, texa_, --,
   {{0x98c71d1f,0xe9ff00e2,0x93bc00af,0x1bef00ab}},	//   рсал, _nhấc_, _vrăj, _छिपल_,
   {{0x2913043f,0x7d1501d6,0xad9b0300,0x6d459390}},	//   rexa_, mezs, ctúa, _ioha,
   {{0x61e2011c,0x290a1b4b,0x200e021d,0x29130d06}},	//   _ovol, _ebba_, _mpfi_, sexa_,
   {{0x6d450006,0x672004c3,0x7afd011e,0x61e20024}},	//   _koha, _damj, _icst, _nvol,
   {{0x6d45cace,0xb4c10ca1,0x5dda0070,0x60d8023a}},	//   _joha, ंडे_, אַקס, _nevm,
   {{0x6d456b81,0x04451fd7,0x61e2cacf,0x6b510523}},	//   _moha, сейн, _avol, _lågm,
   {{0xe2992133,0x2129cad0,0x2d540303,0xcc7800a5}},	//   лай_, _şah_, _näen_, יגות_,
   {{0x7769035f,0x661bcad1,0x48fe01c0,0x00000000}},	//   _imex, _usuk, _लामो_, --,
   {{0x672003fd,0x6d45807f,0x61e20e5e,0x26dd0273}},	//   _zamj, _noha, _dvol, lawo_,
   {{0x04950082,0x60d80183,0x5edc0033,0xdb0f021d}},	//   _الاح, _devm, _ভাবে, _vicê,
   {{0x48fe0302,0x09cd0083,0x2f5600d4,0x8c490095}},	//   _लाभो_, _লিনা, стос, _maşı,
   {{0xa3b00299,0x6d452d88,0x877a02b5,0x7521cad2}},	//   _टूट_, _boha, רארי, _kalz,
   {{0x6d4529e0,0x7afd007e,0xd49100e2,0x3c180260}},	//   _coha, _acst, _kỳ_, _pōv_,
   {{0x61e20076,0x224d006c,0x752101d6,0x6d452b8f}},	//   _zvol, lyek_, _malz, _doha,
   {{0x236d004e,0xdb0d033b,0x6e470031,0xf3f90831}},	//   niej_, rmaß, ërbë, _আনার_,
   {{0x224d006c,0xbb4303fa,0x26dd0103,0xeb971a72}},	// [fb20] nyek_, четк, dawo_, сит_,
   {{0x8c4906d0,0x6720cad3,0xb4e6046c,0x75210009}},	//   _başı, _samj, _भये_, _nalz,
   {{0x236d006a,0x6d5c1093,0x672001f4,0x60da0070}},	//   kiej_, mhra, _pamj, רקענ,
   {{0x8c490095,0x2d8a00ee,0x6602cad4,0x46a6cad5}},	//   _daşı, lobe_, ttok, баев,
   {{0x6d45cad6,0x6722cad7,0xdb1c09af,0x66020421}},	//   _yoha, rdoj, rprä, utok,
   {{0x75214239,0x6602cad8,0xdb1c01ae,0x2d8a4c29}},	//   _calz, rtok, sprä, nobe_,
   {{0xf8631e46,0x61e2cad9,0xf366111d,0x06d70083}},	//   _евро, _svol, йтин, _হারি,
   {{0x60d8037a,0x236d0035,0x2b40080a,0x0877016b}},	//   _sevm, giej_, njic_, _העלט_,
   {{0x2d8acada,0x75210024,0x224d006c,0xdb0f00e0}},	//   kobe_, _falz, gyek_, _dicè,
   {{0x8c4906d0,0xceeb0118,0x46470369,0x00000000}},	//   _yaşı, گردن_, _узун_, --,
   {{0x6d45222e,0xaab8020d,0x2d8a4644,0x442700e2}},	//   _roha, _अलंक, dobe_, cvn_,
   {{0x6d4500fd,0x442ccadb,0x236d0035,0x224d0932}},	//   _soha, _ird_, ciej_, byek_,
   {{0x6d4500cd,0x6e220029,0x8af00095,0x442c0088}},	//   _poha, _šobr, rhəl, _hrd_,
   {{0x6d5c025b,0x63ba0edf,0x2d8a214a,0xb4e6000c}},	//   ghra, _kutn, gobe_, _भयो_,
   {{0x93bc00af,0x7d1500ee,0x6d45cadc,0x71650098}},	//   _brăi, rezs, _voha, _بانك,
   {{0x63ba003a,0x442c0110,0x93bc0139,0x6d45cadd}},	//   _mutn, _mrd_, _crăi, _woha,
   {{0x6d5c1093,0x6d451849,0x8b0400b8,0x63ba0523}},	// [fb30] bhra, _toha, ířat, _lutn,
   {{0x6d5c7f85,0x236d006a,0x442c0c7d,0x6e2d89a2}},	//   chra, ziej_, _ord_, _irab,
   {{0x6e2d3015,0x63ba033a,0x26ddcade,0x44270023}},	//   _hrab, _nutn, tawo_, xvn_,
   {{0x7521cadf,0x2a6001e8,0x93bc0139,0xd7f80fc5}},	//   _salz, bzib_, _grăi, суф_,
   {{0x442ccae0,0x26dd01a8,0x6f0d01cb,0xdb0f002a}},	//   _ard_, rawo_, _mbac, _nicé,
   {{0x67d5cae1,0x8c4901d6,0x63ba043d,0x442ccae2}},	//   _могу, _taşı, _butn, _brd_,
   {{0x58d43f20,0x64a233ed,0x6b582edc,0x75210036}},	//   _хост, маша, _híga, _valz,
   {{0x225f0291,0x6d5c0187,0x3b09012f,0xc178010b}},	//   tzuk_, zhra, nfaq_, enė_,
   {{0x2489006a,0x3dc901e8,0xa3e50084,0x60c40095}},	//   łam_, _ntaw_, _भटक_, _şima,
   {{0x6f0d2540,0x60090721,0x442712ec,0x00000000}},	//   _abac, аном_, pvn_, --,
   {{0x236d004e,0x442c8a36,0xd00957af,0x6e2d35f9}},	//   piej_, _grd_, шене_, _arab,
   {{0x5ea800c8,0x6e2dcae3,0x9eaa14a1,0xa6d70033}},	//   _ক্ষে, _brab, ивна_, _হাঁট,
   {{0x6d5c009c,0x200a01d6,0xe28e2ccc,0x25b2027d}},	//   thra, çbir_, _ца_, _ünlü_,
   {{0x6e2dcae4,0x127a0070,0xad9b7b74,0xf1c1023a}},	//   _drab, _דאנע, stún, _vešč_,
   {{0x6e2d03cb,0x2d8acae5,0x8b2603e6,0x00000000}},	//   _erab, robe_, одве, --,
   {{0x6e2dcae6,0x2d8a0371,0x5aca19af,0x2b5900f6}},	//   _frab, sobe_, рлам_, _clsc_,
   {{0x2480027d,0x3946010b,0x5ea80033,0x2619046c}},	// [fb40] ğimi_, онаг, _ক্রে, _मैली_,
   {{0x6f0d0129,0x6b58cae7,0x2480027d,0xad9b06ee}},	//   _zbac, _díga, şimi_, ntúl,
   {{0x93bc002d,0xa6ca05f5,0x3ebf093f,0x20058dfd}},	//   _trăi, لوال_, žute_, ntli_,
   {{0x6b58cae8,0xab2a0dfc,0xad9b0079,0x00000000}},	//   _fíga, _тома_, htúl, --,
   {{0xe53401c8,0x395801ef,0x6b8100b5,0x88840416}},	//   зель, _tlrs_, élge, _کیان,
   {{0x63ba25d6,0x442c02d7,0x03c63265,0x00000000}},	//   _putn, _prd_, осим, --,
   {{0xdb1701ef,0x398fcae9,0x399400c3,0x00000000}},	//   _suxé, rüst_, jäsi_, --,
   {{0x4906000c,0xdb170042,0x442ccaea,0x320a0036}},	//   स्रो_, _puxé, _vrd_, ахон_,
   {{0xdb0400f7,0x2fc9023a,0xdd0e013b,0x00000000}},	//   rmiè, _čaga_, xışd, --,
   {{0x3a370122,0x442c80e2,0x6f0d0036,0x63bacaeb}},	//   קרים_, _trd_, _sbac, _tutn,
   {{0x40343bd5,0x442c0088,0xb8bb0070,0x399b016b}},	//   ченс, _urd_, יזיש, שייד,
   {{0x6e2d1d86,0xc17800d8,0xdb0f0037,0xdb0800e0}},	//   _prab, snė_, _ticé, _èlèk,
   {{0xdb060086,0x2005009e,0x637e00ea,0x628e02b1}},	//   _mikä, atli_, cīna, ßbod,
   {{0xc5f30bed,0x6ad30461,0x224b1193,0xdd0e00a8}},	//   ודש_, तर्र, äcke_, rışd,
   {{0x63a2caec,0xdb6b031a,0x6b58caed,0x5c04010b}},	//   _khon, арал_, _síga, мята,
   {{0xa3dc09b1,0x6f0d0a78,0x5ed50083,0x6b960a8a}},	//   तीय_, _ubac, _থাকে, glyg,
   {{0x63a2caee,0x6e2d01d5,0xecf9010b,0x00000000}},	// [fb50] _mhon, _urab, _лепш_, --,
   {{0xceb400a5,0xe7390090,0x00000000,0x00000000}},	//   _קיץ_, _chŵn_, --, --,
   {{0xd7fb02c4,0x63a2001e,0xdce70029,0x6b9600e9}},	//   руз_, _ohon, cijā, blyg,
   {{0xdb0f0160,0x69cd3f60,0x00000000,0x00000000}},	//   _zicî, ppae, --, --,
   {{0xeb3a02b5,0xbc6800bf,0xd62900af,0x6b8d0065}},	//   _הערש, _همین_, соле_, moag,
   {{0x6b8dcaef,0x63a2caf0,0x399402ee,0x6d550051}},	//   loag, _ahon, yäsi_, nkza,
   {{0x63a2009d,0xc79600b5,0x20051505,0x00000000}},	//   _bhon, _کھلا_, xtli_, --,
   {{0x63a2caf1,0xc2450439,0x85b91714,0x6b8dcaf2}},	//   _chon, зник, _глас_, noag,
   {{0x63a2caf3,0xe1f1004f,0xddc6004e,0x95c8caf4}},	//   _dhon, رسة_, zykł, _духа_,
   {{0xc69202b5,0x0ef400b4,0x44f42344,0x00000000}},	//   _טאן_, अल्स_, _опус, --,
   {{0x63a2004f,0x6b8d0b3d,0x047701df,0x746b051a}},	//   _fhon, koag, _بلاک_, _трав_,
   {{0x7c2a4a74,0xe80e074f,0x6b8d012f,0x63a2caf5}},	//   _áfri, _सहसा_, joag, _ghon,
   {{0x63a9caf6,0x80cc02e4,0xc6090083,0x200501c0}},	//   mmen, _द्वे, লিকা_, stli_,
   {{0xc1040037,0x63a2caf7,0x9f430334,0x00000000}},	//   _يوني, _zhon, čká_, --,
   {{0xc6180907,0x63a9010b,0x6b960409,0x7bce0051}},	//   _धन्य_, omen, tlyg, upbu,
   {{0xbb431c56,0x63a9caf8,0xdce700ea,0xdb0500d5}},	//   неск, nmen, rijā, _tuhý,
   {{0x63a9caf9,0x80de0083,0x6b964777,0xb18300b8}},	// [fb60] imen, _মাত্, rlyg, šťuj,
   {{0xdca61906,0x63a902c9,0x0d830d8a,0xa923019e}},	//   _напи, hmen, _плын, ндул,
   {{0x63a9cafa,0x28a7021a,0x6b8d0065,0x00000000}},	//   kmen, केलि, boag, --,
   {{0x63a9807f,0x1fbd0033,0x2d9801ff,0x00000000}},	//   jmen, _আবাস, llre_, --,
   {{0x63a2cafb,0x63a9cafc,0xba7606ca,0x271c073f}},	//   _rhon, dmen, _راحت, _नसीर_,
   {{0xd5b91bda,0x63a902e1,0x63a217dd,0x00000000}},	//   ісі_, emen, _shon, --,
   {{0x63a2cafd,0x29370070,0x63a90345,0x00000000}},	//   _phon, _צאלן_, fmen, --,
   {{0x80de00c8,0x987b02b5,0x63a9cafe,0x291acaff}},	//   _মাধ্, _האלט, gmen, lepa_,
   {{0xa3dc0299,0x93bc002d,0xd066013b,0xa3e8017f}},	//   _तौर_, _arăt, əqəs, _बिक_,
   {{0x63a9c515,0x461300fd,0x394acb00,0x291acb01}},	//   amen, _سومر, _jobs_, nepa_,
   {{0xf2db0083,0x1aa907df,0x130a00af,0x63a21b00}},	//   _ধারণ, _कण्ठ, _гней_, _thon,
   {{0x389b02b5,0x62820189,0x643b0070,0x63a9cb02}},	//   מיינ, _txoo, _לעבנ, cmen,
   {{0x7d03022a,0xa3c20035,0x4cd40033,0xad9b002a}},	//   _önsk, _एंड_, _তাজু, stúm,
   {{0x61431c6b,0x291a0c21,0x8bc71962,0x00000000}},	//   _печа, jepa_, зсад, --,
   {{0x6d550120,0xab9500d4,0x93bc0139,0x00000000}},	//   rkza, диві, _grăt, --,
   {{0x6b580042,0x6b510523,0x00000000,0x00000000}},	//   _dígo, _lågv, --, --,
   {{0xa3dc00a1,0x6b8d01d7,0x394a00ec,0x00000000}},	// [fb70] तीत_, roag, _bobs_, --,
   {{0xa8a70cda,0x6b5801f7,0x291a021d,0xb6060207}},	//   прек, _fígo, gepa_, _mušć,
   {{0xf9904e26,0xaf200083,0x63a9cb03,0xa3e800b4}},	//   ابق_, ধারণ_, ymen, _बिग_,
   {{0x998000f4,0x60c40139,0x00000000,0x00000000}},	//   rviš_, _şiml, --, --,
   {{0x9a842aff,0x63a94398,0x93bc0160,0x5a341645}},	//   _зурл, vmen, _orăs, _знят,
   {{0xdb17002a,0xe61801e0,0x63a91651,0x00000000}},	//   _muxí, яді_, wmen, --,
   {{0x63a9cb04,0xa3d70722,0xdb0f021d,0x2b4b0069}},	//   tmen, ़ीं_, _licí, _kocc_,
   {{0x63a9cb05,0x3f990009,0x67c50409,0x00000000}},	//   umen, jlsu_, _gėja, --,
   {{0x10f5010b,0xf8e10067,0x00000000,0x00000000}},	//   мяня, _फ़ाय, --, --,
   {{0xe9e700ee,0xd5b103fc,0x00000000,0x00000000}},	//   _grúň_, _شفا_, --, --,
   {{0x63a96e7e,0xdb170279,0x24550fab,0xdbf200b8}},	//   pmen, _auxí, _تناس, třít,
   {{0x83670164,0xdb1701ef,0x25bf00ab,0xdb0f00d5}},	//   _عدال, _buxí, _kuul_, _bicí,
   {{0x25bfcb06,0xb60600cd,0x00000000,0x00000000}},	//   _juul_, _gušć, --, --,
   {{0xdb0f01dd,0x61fb4179,0x93bc0395,0x25bf00be}},	//   _dicí, muul, _grăs, _muul_,
   {{0x6b5800d5,0x61fbcb07,0x394acb08,0xdbf20355}},	//   _fígl, luul, _robs_, přít,
   {{0xf0920052,0xe9da10d5,0x21270019,0xdb17002a}},	//   _שנה_, жка_, _hanh_, _fuxí,
   {{0x13d600c8,0x0d860036,0x6f041c35,0x61fb01a8}},	// [fb80] সওয়, _олин, _icic, nuul,
   {{0x6e24cb09,0xdb1e0031,0x66061130,0x44c70055}},	//   _isib, _kupë, _äkki, _nё_,
   {{0xb8f60006,0x291acb0a,0x21270019,0x8cd40066}},	//   _सभ_, repa_, _manh_, _ब्यो,
   {{0x61fb46f0,0x21270019,0x7d1c08ee,0x25bf0345}},	//   kuul, _lanh_, lers, _buul_,
   {{0x7ae4cb0b,0x291a0312,0x21270023,0x61fb2ff3}},	//   mait, pepa_, _oanh_, juul,
   {{0x7ae4cb0c,0x2ee054b2,0x25bf043d,0x6e24002f}},	//   lait, _leif_, _duul_, _msib,
   {{0xc10e0019,0x7d1c3d84,0x13941172,0xd823cb0d}},	//   _bỗng_, iers, никю, _идри,
   {{0x18a3021d,0x7ae430d8,0x61fb01a8,0x25bfb88d}},	//   _расм, nait, fuul, _fuul_,
   {{0x7d1c5d95,0x61fb7dee,0x2127cb0e,0x51865229}},	//   kers, guul, _banh_, дуна,
   {{0x7ae4cb0f,0x7d1ccb10,0x212701a5,0x224b01ff}},	//   hait, jers, _canh_, äcka_,
   {{0x7ae46f02,0x212700e8,0xb226008a,0x6e24001c}},	//   kait, _danh_, fræð, _asib,
   {{0x6d5ecb11,0x61fb0273,0x7ae400c3,0xb226008d}},	//   _alpa, buul, jait, græð,
   {{0x7ae4004f,0x7d1ccb12,0xad9b0079,0x7f88013b}},	//   dait, fers, ltúi, dıqd,
   {{0x6f04262d,0xdb0f0098,0x6b510044,0x212700cc}},	//   _ecic, _vicí, _lågt, _ganh_,
   {{0x7ae4a95e,0x6e246372,0xad9b0037,0xeb9314ac}},	//   fait, _esib, ntúi, نظر_,
   {{0x6d5e112c,0x7ae4cb13,0x00000000,0x00000000}},	//   _elpa, gait, --, --,
   {{0x753abe87,0x9f460187,0xad9b0079,0x2903023a}},	// [fb90] _ontz, nulý_, htúi, _pcja_,
   {{0x752890e7,0x212701a5,0x7d1ccb14,0x00000000}},	//   _nadz, _xanh_, cers, --,
   {{0x9cd60052,0x2d91cb15,0x6ec311b5,0x7ae4cb16}},	//   _אותה_, moze_, रखपु, bait,
   {{0x6f1dcb17,0x753a0291,0x2d91cb18,0x7c250254}},	//   nesc, _antz, loze_, _ishr,
   {{0xc10e00e2,0x8f9c00a5,0x60ca0044,0x7528cb19}},	//   _rỗng_, קידי, _offm, _badz,
   {{0x64a538d2,0xd6d70033,0x2d91a72f,0xf56800b5}},	//   нала, _হাওয, noze_, ومنٹ_,
   {{0x6f1d90cb,0x21270023,0x68e50421,0x3d11012f}},	//   kesc, _ranh_, mahd, द्ये_,
   {{0x753acb1a,0x2d910232,0x61fb01a8,0x2127cb1b}},	//   _entz, hoze_, tuul, _sanh_,
   {{0x2d910b55,0x75280a4e,0x49060fcf,0x44c70031}},	//   koze_, _fadz, स्को_, _tё_,
   {{0x2901cb1c,0xa3dc018d,0x7d1c01ef,0x6f04cb1d}},	//   ngha_, तीह_, xers, _scic,
   {{0x61fb09d6,0x67290118,0x7ae4023c,0xdb0f021d}},	//   suul, _kaej, yait, _xicã,
   {{0x7d1ccb1e,0x6f1d0b7b,0x6d890038,0x7d05033b}},	//   wers, gesc, hľad, _achs,
   {{0x80de0b52,0x7ae445d7,0x7d1c2a45,0x3f9e0080}},	//   _মার্, vait, ters, ētu_,
   {{0x61e9cb1f,0x7ae4529a,0xd1380035,0x7d1c033b}},	//   msel, wait, gląd_, uers,
   {{0x61e9cb20,0x69cf0080,0x7ae4cb21,0x6f1d3cd3}},	//   lsel, _atce, tait, besc,
   {{0x6f1d00af,0x6e24b4b9,0x28d200b4,0xbea66299}},	//   cesc, _tsib, दुनि, _пайк,
   {{0x7ae4cb22,0xf2d20100,0x6e2401d5,0x2d91024c}},	// [fba0] rait, טען_, _usib, boze_,
   {{0x7ae4cb23,0x61e9cb24,0x4425cb25,0x673b0118}},	//   sait, isel, _osl_, _anuj,
   {{0x7528cb26,0x6299001e,0x7ae4cb27,0x06d70033}},	//   _radz, _lywo, pait, _হাজি,
   {{0x61e9cb28,0xaa462246,0xdc7702b5,0x7528cb29}},	//   ksel, _земл, _טעיפ_, _sadz,
   {{0x44257bb8,0x61e9cb2a,0x75280228,0x67c50409}},	//   _asl_, jsel, _padz, _fėjo,
   {{0x61e9692d,0x6f1dcb2b,0xdb1e0fc6,0x95c30079}},	//   dsel, zesc, _supè, ديوه,
   {{0x98a3027a,0x18a33537,0x93bc0139,0x752802ff}},	//   _бире, _барм, _crăp, _vadz,
   {{0x4425cb2c,0x629989ce,0xdb1c0079,0x23a100b5}},	//   _dsl_, _bywo, mpró, tója_,
   {{0x36672217,0x6f1dcb2d,0xd130004f,0x61e9cb2e}},	//   _зато_, vesc, لمة_, gsel,
   {{0x04180083,0x753a01a3,0xbebb0031,0x50660d6e}},	//   থিবী_, _untz, ndëv, етма,
   {{0xa3dc0299,0x74132499,0x2d912381,0xdb0f0138}},	//   तीश_, _مولا, voze_, _licá,
   {{0xb286002d,0x62990090,0x00000000,0x00000000}},	//   _пылк, _fywo, --, --,
   {{0x6f1d05c0,0x2d9115c2,0xa3dc29ad,0xdb0f021d}},	//   resc, toze_, तीर_, _nicá,
   {{0x6b5106d7,0x6f1d0043,0x301401c8,0xac190823}},	//   _någr, sesc, _адкр, могу_,
   {{0x6f1dcb2f,0x442501e0,0xac95cb30,0x4c95cb31}},	//   pesc, _xsl_, тавш, тивс,
   {{0xdb0f01ef,0xdb17002a,0x409b00a5,0xddd00355}},	//   _bicá, _buxá, _מבוס, řeši,
   {{0x2d9102e9,0x238500ea,0x00000000,0x00000000}},	// [fbb0] poze_, nēja_, --, --,
   {{0xfbd00332,0x99980043,0xbebb0298,0x00000000}},	//   شتہ_, екут_, geëe, --,
   {{0x2d54007c,0xb8080037,0xdb1c00b5,0x9f4602d7}},	//   _päev_, فيلم_, gpró, culó_,
   {{0x61e90935,0x5727004f,0x45d50573,0x067562a2}},	//   ysel, عراق, водс, куля,
   {{0x4425cb32,0x00000000,0x00000000,0x00000000}},	//   _ssl_, --, --, --,
   {{0x4a5a0052,0x2b490254,0x442517a9,0x61e9b3d2}},	//   _חדשו, ljac_, _psl_, vsel,
   {{0xa3dc0429,0xdb1e0248,0xd7f803fa,0x649801d3}},	//   तील_, _supé, _пут_, нтър_,
   {{0x61e92119,0x2b49011c,0x9f5f0421,0x44250116}},	//   tsel, njac_, nttä_, _vsl_,
   {{0xe7843ac3,0xdb0603b4,0x35b501c8,0x61e9061c}},	//   _суро, _shkë, _абар, usel,
   {{0x0467002d,0xfa98016b,0x00000000,0x00000000}},	//   _птем, עדזש_, --, --,
   {{0xe53602b5,0x44253cba,0x61e948e6,0x2a69012f}},	//   _שטעט_, _usl_, ssel, hzab_,
   {{0x50d1035d,0x61e9968c,0x78ba2919,0x3f8400be}},	//   _द्रष, psel, _útve, õmu_,
   {{0xc7b202b5,0xdb1c01ae,0xfe2500d8,0x00000000}},	//   יבט_, rprü, льён, --,
   {{0xdb1c01ae,0xf1ba00e2,0x9f46445a,0x2d540421}},	//   sprü, _giơ_, tuló_, _näet_,
   {{0xeb9a39db,0x69cbcb33,0x3d11022e,0xfce31036}},	//   див_, ígen, द्धे_, росо,
   {{0x332dcb34,0x4914012f,0x00000000,0x00000000}},	//   ndex_, न्नो_, --, --,
   {{0xeb976877,0x320d1628,0xdd8a03e6,0x6b51029e}},	// [fbc0] тит_, ntey_, _обид_, _pågr,
   {{0xa3c10967,0x3d113893,0xe8f70664,0x00000000}},	//   ंदा_, द्दे_, клу_, --,
   {{0xabaa0183,0x311300e7,0x6b580183,0x23850228}},	//   _овоз_, त्यः_, _lígi, zēja_,
   {{0x6d5ccb35,0xe8130066,0x656151f7,0x6e3611cb}},	//   lkra, _ठहरा_, _allh, _kryb,
   {{0xc44800e0,0x3f82008e,0x660f01ff,0xdb1c008d}},	//   کیان_, inku_, _äckl, spró,
   {{0x6d5ccb36,0xdb1c008e,0x6b830d99,0x238500ea}},	//   nkra, ppró, _íngr, vēja_,
   {{0x8af000a8,0xd7060ea0,0xa3dc08a9,0x6f163d3a}},	//   hkəm, _изви, तीं_, _obyc,
   {{0x040d0028,0xd3770409,0x2d5400ab,0x6d5c0f5e}},	//   _hướn, кчы_, _käes_, hkra,
   {{0x2492004e,0x6d5ccb37,0x60cd05f9,0xf1a60009}},	//   łym_, kkra, _şama, крон,
   {{0xd5ae00f5,0x6d5c4382,0x6b580747,0x6f1600b8}},	//   _بہت_, jkra, _dígi, _abyc,
   {{0x39570122,0x9346059b,0x250b006c,0x9f5f0086}},	//   דשים_, _инже, _ترقی_, yttä_,
   {{0x6d5ccb38,0x28a70d1f,0xe479016b,0x00000000}},	//   ekra, केटि, _אָנש, --,
   {{0x645801c8,0x6d5ccb39,0x6e36cb3a,0x8d7700f8}},	//   lyvi, fkra, _cryb, ناسا,
   {{0xd12f0082,0x3f82046a,0x6fca10aa,0x040d0019}},	//   _ومن_, anku_, _संपू, _nướn,
   {{0xc04f00d4,0x30a302fb,0x07130fbf,0x9f5f0055}},	//   _ті_, _кръв, ण्डव_, nutë_,
   {{0xe0b702b5,0xfaff0c6f,0x00000000,0x00000000}},	//   _בלוט_, _amër_, --, --,
   {{0x5f740919,0x6e36b612,0x3915b82f,0x040d00e2}},	// [fbd0] _خاور, _gryb, лмар, _bướn,
   {{0x6d5ccb3b,0x7bc100b5,0x64580bfc,0x6cd5026b}},	//   ckra, ílus, kyvi, _حقدا,
   {{0x2d830254,0x1aef0083,0xc7f50274,0x00000000}},	//   mnje_, ঙ্গে_, узећ, --,
   {{0x29076689,0xe505009a,0xfaff01f4,0x2bb400a1}},	//   żna_, _राहि_, _emër_, ंगणा,
   {{0xd24615f4,0xb90900c8,0x7bc5cb3c,0xa3e5238a}},	//   _ان_, _যা_, _huhu, बीन_,
   {{0x7bc519c6,0x24091c6b,0x6b5850a1,0x69aa0f17}},	//   _kuhu, енки_, _rígi, _जीपी,
   {{0x7bc54303,0x3f820067,0x37c40279,0x645806dc}},	//   _juhu, ynku_, _вљуб, gyvi,
   {{0xbebb01d2,0x7bc5cb3d,0x320d0526,0x03253626}},	//   ndës, _muhu, ttey_, удин,
   {{0x7bc516ec,0x2d830627,0xd9e30963,0xdb0600ac}},	//   _luhu, knje_, गठित_, _niký,
   {{0x320d0103,0x7fd5291f,0x2d830254,0xdb0f0279}},	//   rtey_, лімі, jnje_, _ficç,
   {{0x2d8302dd,0xdee630ca,0xc4d20122,0x7bc50c6f}},	//   dnje_, лони, _הגב_, _nuhu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f600093,0x823400fd,0x00000000,0x00000000}},	//   _þrír_, _پرنا, --, --,
   {{0x31790070,0x7bc5cb3e,0x2d8301a0,0x8af000a8}},	//   _ראַד, _buhu, gnje_, rkəm,
   {{0x6d5ccb3f,0x0cbe00dc,0xd00e06c9,0x06e30387}},	//   rkra, ्डौम, _فلو_, खराव_,
   {{0x7bc5cb40,0x040d0019,0xa09a0317,0x6e360035}},	//   _duhu, _sướn, _איצט, _tryb,
   {{0xa3ab08d1,0x2d8308b7,0xa84a3c96,0x2bc00a90}},	// [fbe0] _गठन_, bnje_, کلام_, _शंका,
   {{0x61fb00d7,0x6d5a00be,0x645d013b,0x00000000}},	//   irul, ötad, _əsir, --,
   {{0x7bc50232,0x040d0023,0x4c36002d,0x00000000}},	//   _guhu, _vướn, _сэпт, --,
   {{0x23850029,0x00000000,0x00000000,0x00000000}},	//   dējo_, --, --, --,
   {{0xe5050953,0x040d01a5,0x7bc5cb41,0x88e80033}},	//   _राशि_, _tướn, _zuhu, _পাঠক,
   {{0x7ae60600,0xad9bcb42,0x645800d8,0x6b84cb43}},	//   _hekt, ltúr, tyvi, lnig,
   {{0xbebb00da,0x98a30029,0x6b8400ab,0xa92800ea}},	//   ndër, _tajā_, onig, režģ,
   {{0x69c61d14,0xf363010b,0xad9b016f,0x2d831942}},	//   _kuke, йтын, ntúr, znje_,
   {{0xa6863bd5,0x6b84cb44,0x7ae6cb45,0x61fbcb46}},	//   _слад, inig, _mekt, grul,
   {{0xb4260609,0xd130064e,0x69c6cb47,0x8cd40035}},	//   _معصو, آمد_, _muke, _ब्लो,
   {{0x69c643a3,0xad9b4b1d,0xddd000cb,0x2d830a16}},	//   _luke, ktúr, _češl, vnje_,
   {{0x4914021a,0xa3c12c29,0x7bc5cb48,0x7ae6cb49}},	//   न्तो_, ंदर_, _ruhu, _nekt,
   {{0x29185988,0x2d830496,0x69c6cb4a,0x9f5f024e}},	//   _obra_, tnje_, _nuke, nuté_,
   {{0x7bc5cb4b,0xa90300b4,0xbd450037,0x6b5801ef}},	//   _puhu, _लाइफ_, جنسي, _mígu,
   {{0x69c60291,0x7ae6cb4c,0x2d830496,0x6b58081d}},	//   _auke, _bekt, rnje_, _lígu,
   {{0x69c6cb4d,0x29182278,0x2d83c08c,0x6602cb4e}},	//   _buke, _abra_, snje_, kuok,
   {{0x49750fa4,0x6722cb4f,0x2d831038,0x6602037c}},	// [fbf0] алас, deoj, pnje_, juok,
   {{0x69c651bd,0x7bc5000e,0x6b84018d,0x660200c7}},	//   _duke, _tuhu, anig, duok,
   {{0x69c60065,0x290f0035,0x61e2030d,0x7ae6cb50}},	//   _euke, ęga_, _lwol, _fekt,
   {{0x963573b2,0x661b0009,0x98140037,0x290a00ee}},	//   инец, _ppuk, إبلا, _ecba_,
   {{0x69c60010,0xa50997bf,0x25be0260,0x3f89013a}},	//   _guke, вела_, _bitl_, _mjau_,
   {{0xa3c10026,0x49140355,0x61fb6482,0x499300fd}},	//   ंदल_, न्दो_, vrul, _ایئر,
   {{0x67d403ad,0x7ae601cb,0x97a718f0,0x69c601b7}},	//   _госу, _yekt, _брал, _zuke,
   {{0xe2990a93,0x78ba40ea,0x249e00d7,0x27fc01ba}},	//   кай_, _útva, _dytm_, ávne_,
   {{0xe667434c,0x69c0000d,0x1634262e,0x68e700fe}},	//   _ство, _émet, _летя, _kejd,
   {{0x3f89afc0,0x68e7cb51,0xdb0a00a0,0x746b2afc}},	//   _ajau_, _jejd, ľnéh, _прев_,
   {{0xa0a50e05,0x68e7cb52,0xdb0a0187,0x9f863f6c}},	//   ранд, _mejd, žnéh, игод,
   {{0x7523cb53,0xbebb0031,0x683000b5,0x00000000}},	//   lenz, vdër, lódá, --,
   {{0x614569f7,0x91e50272,0x3a2b01ef,0x442700e9}},	//   _вела, _толе, _nscp_, lwn_,
   {{0xa3dc009a,0x68e7033a,0x7523cb54,0x69c6cb55}},	//   तीक_, _nejd, nenz, _ruke,
   {{0xad9b008a,0x69c6cb56,0x61e2cb57,0x66020eba}},	//   ttúr, _suke, _zwol, zuok,
   {{0x7523cb58,0x69c600c3,0x6a860fc5,0x6b84033b}},	//   henz, _puke, алба, unig,

   {{0xdb1d3253,0x7ae618d4,0x8d76097f,0x4a465455}},	// [fc00] _misè, _vekt, _نادا, шнав,
   {{0x2fc71188,0xebe610a4,0x75238c2a,0x7ae600bf}},	//   _kung_, _кооп, jenz, _wekt,
   {{0x2d98cb59,0x752307c9,0x8c460a26,0x6b580831}},	//   more_, denz, _тене, _sígu,
   {{0x2fc701ca,0x69c60086,0x6602cb5a,0x2d980a1f}},	//   _mung_, _tuke, tuok, lore_,
   {{0x2fc7024b,0x68e7008c,0x00000000,0x00000000}},	//   _lung_, _fejd, --, --,
   {{0x75233370,0x660215eb,0x2bb400b4,0x2d98cb5b}},	//   genz, ruok, ंगवा, nore_,
   {{0xf8aa0299,0x2fc70269,0x66e60409,0xa6ca0011}},	//   _करिय, _nung_, _воба, _алба_,
   {{0xe3af211b,0x9f5f00f7,0x3ebf0506,0x61e20359}},	//   وري_, puté_, žuti_, _pwol,
   {{0x2d98cb5c,0x2fc7cb5d,0xdb1d64b3,0x00000000}},	//   kore_, _aung_, _disè, --,
   {{0x7523b072,0xf8aa74d7,0x2fc7cb5e,0xe50610ab}},	//   cenz, _कराय, _bung_, _خبري,
   {{0x2fc70028,0x656a0315,0x3ea00107,0xdb1d021e}},	//   _cung_, mhfh, _ayit_, _fisè,
   {{0x2fc70028,0x442c0160,0xdb1d00a2,0x61e2073a}},	//   _dung_, _isd_, _gisè, _twol,
   {{0x2d980052,0x7c220506,0x15fc0067,0x98a700cd}},	//   fore_, _ćora, उंटर_, _čiča_,
   {{0x2d98070b,0x2366006d,0x7f8800a8,0xa15718d9}},	//   gore_, _hloj_, lıql, _вашу_,
   {{0x2fc700e0,0x92e80033,0x6c540a80,0x00000000}},	//   _gung_, বলী_, окру, --,
   {{0x7523cb5f,0x68e7cb60,0x3ea901b7,0xdb680043}},	//   zenz, _sejd, _tzat_, арул_,
   {{0x98a3004e,0x78eb0f22,0x68e70478,0x752301d5}},	// [fc10] _mają_, вьев_, _pejd, yenz,
   {{0xb4e50302,0x2d981010,0x2fc7134c,0x236600da}},	//   _भजे_, core_, _yung_, _lloj_,
   {{0x7523046f,0x2fc70019,0xd879036b,0x442c017b}},	//   venz, _xung_, دمات_, _nsd_,
   {{0xf7701d05,0x3f996c67,0x75237040,0x7bd701d7}},	//   وان_, nosu_, wenz, _itxu,
   {{0x7523cb61,0x7aedcb62,0xfb1a0122,0x9a840183}},	//   tenz, maat, _גורמ, _дурл,
   {{0x7aedcb63,0x6e2d08c7,0x2ee9024b,0xdb1e021d}},	//   laat, _msab, _leaf_, _tupã,
   {{0x7523cb64,0x3a2900d7,0x6f0d0453,0xdb1dcb65}},	//   renz, lwap_, _ocac, _aisé,
   {{0x7523cb66,0x7aedcb67,0x2fc7cb68,0x2d98cb69}},	//   senz, naat, _rung_, zore_,
   {{0x7523cb6a,0x6e2d2f38,0x2d980260,0xaab70803}},	//   penz, _nsab, yore_, अधिक,
   {{0x7aedcb6b,0x0fd93122,0x2fc7c296,0x01650f7a}},	//   haat, льмы_, _pung_, скоо,
   {{0x7aedcb6c,0x6e2d01d0,0x7bd70189,0x442c0210}},	//   kaat, _asab, _ntxu, _gsd_,
   {{0x32044474,0x2fc7cb6d,0x7aed135c,0x6b580176}},	//   bumy_, _vung_, jaat, _lígr,
   {{0x2d98cb6e,0xd00e0df3,0x7aed21bc,0x6e2dcb6f}},	//   tore_, ولی_, daat, _csab,
   {{0x61d60052,0x2fc7cb70,0x5fcf00a1,0x236600f4}},	//   _הוסף_, _tung_, _संपल, _zloj_,
   {{0x2d98cb71,0x645c007c,0x7aed018e,0x442c03d0}},	//   rore_, _ürit, faat, _xsd_,
   {{0xd1130821,0x2d98cb72,0x2005cb73,0x7aedcb74}},	//   त्रण_, sore_, muli_, gaat,
   {{0x2d98cb75,0x2005cb76,0x7f440036,0x6e2d0159}},	// [fc20] pore_, luli_, _iniq, _gsab,
   {{0xfe370070,0xeaaf00b5,0x7f880510,0xad9b01dd}},	//   _פריי_, رٹل_, zıql, trúe,
   {{0xb17a0779,0x7aedcb77,0x2005011c,0x7d570070}},	//   נטער, baat, nuli_, _הייד_,
   {{0x7aed929f,0x7bdccb78,0x442c2423,0xb8ff0066}},	//   caat, mpru, _rsd_, _ध्_,
   {{0x2005cb79,0xa3e50324,0xdcf500ea,0x68f800fd}},	//   huli_, बीस_, lizā, _نکاح_,
   {{0x442ccb7a,0x2005a1ff,0x23660bc6,0x78ba00b5}},	//   _psd_, kuli_, _sloj_, _útvo,
   {{0x88840609,0xdcf50029,0x23660189,0xb97b0070}},	//   _بیان, nizā, _ploj_, _ענלי,
   {{0xd3260a55,0x2005cb7b,0x51f80086,0xcc3b0070}},	//   ськи, duli_, анию_, רעקט,
   {{0x637e010b,0x442c00ee,0xdc3c00ac,0x425400f8}},	//   gūna, _wsd_, dáče, زندر,
   {{0x7178141d,0x7f440138,0x3d1a007c,0x6f0d0382}},	//   рбор_, _aniq, म्मे_, _scac,
   {{0x2005cb7c,0x7aed030d,0x6e2d0273,0x442ccb7d}},	//   guli_, yaat, _ssab, _usd_,
   {{0xd0410095,0x67c50409,0x3f675ad1,0x00000000}},	//   nclə, _gėju, стоб, --,
   {{0x7aed9b86,0x88c00083,0x225a16a4,0x2bbe1140}},	//   vaat, েরিক, _حجاب_, ्दना,
   {{0x20050273,0x7aed276d,0x5f05035d,0xdb0d0098}},	//   buli_, waat, _वाक्_, rmaí,
   {{0x200532a3,0xd0b20095,0x317b00a5,0x6fcf02b4}},	//   culi_, yğəm, _תרומ, _संयं,
   {{0x317ecb7e,0x3d1a0825,0x6e2d0312,0x28db0355}},	//   litz_, म्बे_, _tsab, मुनि,
   {{0x7aed086b,0x6e2dc3d3,0x99551558,0x6568cb7f}},	// [fc30] raat, _usab, окац, _oldh,
   {{0x7aed127d,0x317ecb80,0xb882053d,0x98c70328}},	//   saat, nitz_, čína, ссал,
   {{0x7aed8dc5,0x6d4502d8,0x00000000,0x00000000}},	//   paat, _inha, --, --,
   {{0x317e01a3,0x27fc00a0,0xf1c8035d,0x657a00cc}},	//   hitz_, ávna_, रदान, _amth,
   {{0x2005cb81,0xf8ae0609,0xad9b0098,0x00000000}},	//   zuli_, _یکم_, crúc, --,
   {{0xdfc601cb,0x9989004e,0x637e010b,0x23d52d7a}},	//   _يي_, stał_, vūna, оцир,
   {{0x317e71b3,0x657a009e,0x6d570c6f,0x256b03d0}},	//   ditz_, _dmth, _moxa, _nøle_,
   {{0xe1f91ade,0x6fcf10a6,0x2005002f,0x65683315}},	//   аги_, _संबं, vuli_, _eldh,
   {{0x20052973,0x77690042,0x6d45cb82,0xc79600b5}},	//   wuli_, _ilex, _onha, _بھلا_,
   {{0x2005cb83,0x7f5600a8,0x7bdc010d,0x317e0065}},	//   tuli_, _soyq, ypru, gitz_,
   {{0xcea91899,0xdb04004f,0x7c2202c4,0x92f900b5}},	//   _סי_, rmiú, _ćoro, _نفاذ_,
   {{0x60dc0dac,0x6d45cb84,0x25f01edf,0x317e0065}},	//   ırma, _anha, ुंची_, aitz_,
   {{0x317ecb85,0xa3e502e4,0xd10900bf,0x2005cb86}},	//   bitz_, बीर_, _نقشه_, suli_,
   {{0x2005cb87,0xafe51bdf,0xdcf500ea,0x6d570952}},	//   puli_, _докл, tizā, _coxa,
   {{0xdb0600b5,0xeb7a0279,0x6da3224a,0x00000000}},	//   _mikö, асај_, фира, --,
   {{0xe80d0429,0x7f4420ac,0x6d45cb88,0xdcf500ea}},	//   ांना_, _uniq, _enha, rizā,
   {{0x7bdccb89,0xfaa3cb8a,0x2bbe0026,0x6d57002a}},	// [fc40] spru, дато, ्दबा, _foxa,
   {{0x7bdc003c,0x291c00a0,0x2cad0355,0x6d570065}},	//   ppru, ýva_, ředa_, _goxa,
   {{0x1c1e065a,0xad9b0079,0xd70a002d,0x00000000}},	//   _पहिल_, srúc, инже_, --,
   {{0x236dcb8b,0x998000c7,0x00000000,0x00000000}},	//   jhej_, tvių_, --, --,
   {{0x9b8a006c,0xd0410095,0x236d01f4,0x7d1e0118}},	//   _منگل_, rclə, dhej_, _kbps,
   {{0x77691fdc,0x9633010b,0x224d0065,0x00000000}},	//   _elex, ьніц, dxek_, --,
   {{0x317ea4ce,0xdcf5002d,0x7769cb8c,0x3d120066}},	//   vitz_, liză, _flex, _ताने_,
   {{0x395802e1,0x938a192f,0x7c220124,0xdb0600c3}},	//   _hors_, јска_, _ćorl, _eikö,
   {{0x914a9a98,0x3958cb8d,0x317e01b7,0xa50a0274}},	//   ачна_, _kors_, titz_, _веза_,
   {{0x55032374,0x00000000,0x00000000,0x00000000}},	//   _опуб, --, --, --,
   {{0x6d571be4,0x3958cb8e,0x317ecb8f,0x6aa707b5}},	//   _roxa, _mors_, ritz_, _खर्र,
   {{0x395802e1,0x443ecb90,0x236d15da,0x317e033b}},	//   _lors_, _irt_, chej_, sitz_,
   {{0x443e19cd,0x3ead054e,0x6d57002a,0x224b01ff}},	//   _hrt_, ået_, _poxa, äckt_,
   {{0x395801c8,0x7d1b0a78,0x443ecb91,0xdb0414e1}},	//   _nors_, đuso, _krt_, lliè,
   {{0xaac600b4,0x7d1e00fe,0x6602c89d,0x5bc5022e}},	//   वशंक, _dbps, hrok, वदेव,
   {{0x443ecb92,0x3a22022e,0xe8e00019,0x23850228}},	//   _mrt_, _bpkp_, _đền_, tēji_,
   {{0x39589221,0x443ecb93,0x4fb4097f,0x60cd027b}},	// [fc50] _bors_, _lrt_, _تصور, _şami,
   {{0x443ecb94,0xc4c40332,0xad9b00fb,0x3958cb95}},	//   _ort_, _لے_, brúa, _cors_,
   {{0x3958cb96,0x443e0107,0x00000000,0x00000000}},	//   _dors_, _nrt_, --, --,
   {{0xe80c3914,0x6602cb97,0x00000000,0x00000000}},	//   _हमरा_, frok, --, --,
   {{0x8af001c2,0x6627004f,0x98ab0095,0x8d7400d1}},	//   rkət, تراك, ılıb_, _رایا,
   {{0x443e021d,0xbc380118,0x00000000,0x00000000}},	//   _brt_, _اسیا_, --, --,
   {{0x2b590375,0x00000000,0x00000000,0x00000000}},	//   _kosc_, --, --, --,
   {{0x66027476,0x3f8b02c4,0x224d01a3,0x443e021d}},	//   brok, jncu_, txek_, _drt_,
   {{0x443e00fb,0x0ca80939,0x00000000,0x00000000}},	//   _ert_, _गर्म, --, --,
   {{0x8af00095,0x60092c72,0x236d0055,0x2b5900a2}},	//   nkər, бном_, shej_, _losc_,
   {{0xb4e7cb98,0x225f012f,0x443e0223,0xdb1d0079}},	//   परी_, syuk_, _grt_, _aisí,
   {{0x88d10033,0x5275002d,0x9f5f0176,0x78a803d0}},	//   িরিক, _нулу, gutà_, _ødve,
   {{0xe28ecac4,0x443e00b5,0x3ea40093,0x00000000}},	//   _ча_, _zrt_, æmt_, --,
   {{0xd25602b8,0xe80c13a0,0xad9b0093,0x5bb400b4}},	//   _משנה_, _हमला_, trúa, ंग्व,
   {{0xdb1d004f,0x2b590443,0x8c43002d,0x93bc00af}},	//   _eisí, _bosc_, нере, _isăr,
   {{0x3958cb99,0x2b590037,0xaffa02b5,0x5aca0370}},	//   _sors_, _cosc_, _פּוי, слам_,
   {{0x3f82cb9a,0x9b46006c,0xe8fa07bc,0x3958cb9b}},	// [fc60] miku_, _ہندو, йла_, _pors_,
   {{0x238500ea,0x00000000,0x00000000,0x00000000}},	//   mēju_, --, --, --,
   {{0x2b593576,0xc7261583,0x3958bf33,0x7e60033b}},	//   _fosc_, здей, _vors_, ämpf,
   {{0x660260de,0x443ecb9c,0xe5c6192f,0x39580b88}},	//   trok, _rrt_, пско, _wors_,
   {{0xe5340086,0x395844ed,0x7ae4951f,0x9f5f0097}},	//   дель, _tors_, mbit, nutá_,
   {{0x7bc601a2,0x660249b4,0x2bb405e7,0x00000000}},	//   _hiku, rrok, ंगका, --,
   {{0x66e68357,0x7bc62eb8,0x6ba703e6,0xe73a0112}},	//   _нова, _kiku, _órgã, _лев_,
   {{0x443ecb9d,0x61d81f08,0x07a304e7,0xe76a46c4}},	//   _vrt_, омия_, _засн, _احسن_,
   {{0x3f82cb9e,0xa6aa46c4,0x7ae42d1e,0x784e00b5}},	//   diku_, _طارق_, ibit, _fővá,
   {{0x7bc6cb9f,0x443ecba0,0x26c0010b,0x00000000}},	//   _liku, _trt_, žios_, --,
   {{0x3f82cba1,0x6e24010b,0x443ecba2,0xfbbe1cce}},	//   fiku_, _apib, _urt_, ्दाम,
   {{0x7ae41d4d,0xdb040248,0x69da01c0,0x7bc6cba3}},	//   jbit, blié, _čten, _niku,
   {{0x63a2cba4,0x6146cba5,0x62343f27,0xe3ce0033}},	//   _ikon, _неда, _целу, _রবিব,
   {{0xdb1d0015,0x7bc60086,0x5bc50b35,0x7ae42759}},	//   _visí, _aiku, वद्व, ebit,
   {{0xaeec00c8,0x3f822d3d,0x7bc601d0,0x2ca50d50}},	//   _কারণ_, biku_, _biku, æld_,
   {{0xdb1d0076,0x7bc6046a,0x7ae4cba6,0x00000000}},	//   _tisí, _ciku, gbit, --,
   {{0x2aab1099,0x63a20657,0x3d1a0084,0x89d90c74}},	// [fc70] ство_, _mkon, म्हे_, زوار_,
   {{0xd13817a9,0x799e80cb,0x9ce7002d,0x38c900fd}},	//   ndą_, gopw, _эцил, زائی_,
   {{0x2d83954b,0x63a25e41,0xd138010b,0xdb1d021d}},	//   mije_, _okon, idą_, _cisã,
   {{0xd36600f8,0x2d830a31,0x7bc6c00e,0x63a23a34}},	//   _شه_, lije_, _giku, _nkon,
   {{0x6b8d50e5,0x443c0051,0x00000000,0x00000000}},	//   mnag, evv_, --, --,
   {{0x2d830bc6,0x64a58f55,0x63a26854,0x3f820d77}},	//   nije_, мала, _akon, ziku_,
   {{0x26d20723,0x2fdc0223,0x7bc604fb,0x76400103}},	//   ıyor_, _ntvg_, _yiku, _ermy,
   {{0x6b8dcba7,0x2d83cba8,0xc245280a,0x69c76ca5}},	//   nnag, hije_, дник, _hije,
   {{0x69c7cba9,0x2d830010,0x69cfcbaa,0x6b8d643c}},	//   _kije, kije_, _juce, inag,
   {{0x69cf0af3,0x2d836e3a,0x7aef7557,0x672b01f4}},	//   _muce, jije_, _lect, legj,
   {{0x3f82cbab,0x7afd3e39,0x69c76fa9,0x2d830496}},	//   tiku_, _odst, _mije, dije_,
   {{0x69c70280,0x69dd00ab,0x63a20027,0xdb0400a2}},	//   _lije, _otse, _gkon, plié,
   {{0x3f82cbac,0x69dd0d4b,0x2d8302dd,0x7bc6cbad}},	//   riku_, _ntse, fije_, _riku,
   {{0x2d831f65,0x7bc6cbae,0x69c7cbaf,0xa0695caf}},	//   gije_, _siku, _nije, _мала_,
   {{0xdca35562,0x69dd9374,0x7bc6cbb0,0x7ae4cbb1}},	//   вари, _atse, _piku, tbit,
   {{0x6b8dcbb2,0x63a9bbd9,0x672b00da,0x69cfcbb3}},	//   gnag, nlen, jegj, _buce,
   {{0x2d83cbb4,0x7bc6cbb5,0x69c7cbb6,0x7ae42b02}},	// [fc80] bije_, _viku, _bije, rbit,
   {{0x2d830888,0x69c70280,0x69cf00af,0x63a93adb}},	//   cije_, _cije, _duce, hlen,
   {{0x69c7cbb7,0x63a9cbb8,0xb8f65b7f,0x44250088}},	//   _dije, klen, _हल_, _npl_,
   {{0x66e60036,0xadeb00b4,0xdb1d03e6,0x63bb047d}},	//   фода, जीवन_, _visã, jmun,
   {{0x63a98ac3,0x69c7521c,0xbddb000d,0x63bbcbb9}},	//   dlen, _fije, rvèg, dmun,
   {{0x63a2cbba,0x69c7012f,0x6b84cbbb,0x64410124}},	//   _skon, _gije, liig, _brli,
   {{0x63a9001e,0x672b01cb,0x00000000,0x00000000}},	//   flen, begj, --, --,
   {{0xdb0d051b,0x6d5a007c,0x44251ea7,0xf62611b9}},	//   rmaç, ötaj, _dpl_, _одбо,
   {{0x6441cbbc,0x442500ab,0x2005027a,0x69c704fb}},	//   _erli, _epl_, erli_, _yije,
   {{0x7bde0254,0xbe140033,0x6b8400b9,0x6441023a}},	//   _otpu, িবাদ_, hiig, _frli,
   {{0x2d830496,0x63a9259f,0x4425cbbd,0x2005003a}},	//   vije_, blen, _gpl_, grli_,
   {{0x63a2cbbe,0x63a94051,0x224900cd,0xdb0f01f7}},	//   _ukon, clen, _šake_, _licò,
   {{0x2d8305e2,0x200507e5,0x7aef409c,0x7bde1eef}},	//   tije_, arli_, _rect, _atpu,
   {{0x7aef1121,0x63a0cbbf,0x6e3d08c8,0x009400af}},	//   _sect, lomn, rvsb, _пилэ,
   {{0x69c7cbc0,0x7aefcbc1,0xe57102b5,0x4425011e}},	//   _rije, _pect, אַן_, _xpl_,
   {{0x69c7cbc2,0x63a08445,0x2d831851,0x69cfcbc3}},	//   _sije, nomn, sije_, _puce,
   {{0x9ccb002d,0x69c7cbc4,0x200c003c,0x2d830496}},	// [fc90] _мына_, _pije, ludi_, pije_,
   {{0x63a9cbc5,0x9f5f0037,0x63bbcbc6,0xdb0f0138}},	//   zlen, irtí_, zmun, _picó,
   {{0x69c7039a,0x2fc90189,0x63a9cbc7,0x672b01f4}},	//   _vije, _kiag_, ylen, tegj,
   {{0x28df114e,0x7afd054e,0x2fc9006d,0x44251491}},	//   _प्रि, _udst, _jiag_, _rpl_,
   {{0x69c70280,0x200c56a6,0xf7730416,0x69dd1d2f}},	//   _tije, hudi_, _یار_, _utse,
   {{0x2fc9cbc8,0x660b152b,0x212c01f4,0x644103c9}},	//   _liag_, rugk, jedh_, _prli,
   {{0x63a9cbc9,0x03a5bfa2,0x43691346,0x64a22860}},	//   tlen, нико, зайн_, лаша,
   {{0x2fc9006f,0x200c8552,0x64410a23,0x238500ea}},	//   _niag_, dudi_, _vrli, vējs_,
   {{0x63a991a2,0x3ea901cb,0x29cd0207,0x442503d0}},	//   rlen, _nyat_, _užad_, _wpl_,
   {{0x63bbcbca,0xd5b108cf,0x80da0387,0x2b4b021d}},	//   smun, _صفا_, पुले, _lncc_,
   {{0x3ea92bab,0x63bbcbcb,0x6441cbcc,0x2fc908dd}},	//   _ayat_, pmun, _urli, _biag_,
   {{0x63a00051,0xc2750bfe,0xa3bb00b4,0x00000000}},	//   comn, _плеј, _ेंट_, --,
   {{0x2fc901da,0xdb0f00fe,0x670d00b4,0x98b00207}},	//   _diag_, _chcí, _हाईक_, _čača_,
   {{0x200ccbcd,0x200508b7,0xa2ae021a,0x00000000}},	//   budi_, prli_, ुधर्, --,
   {{0x6ea00266,0xc4d200a5,0x3f6acbce,0xe1f900c7}},	//   _गुरु, רגל_, _нико_, lsų_,
   {{0x92c30083,0xe9da20cc,0xdb1d00d5,0x645c01f7}},	//   ্রী_, зка_, _pisá, _àrie,
   {{0x6b846edd,0xe1f9010b,0x3946010b,0x00000000}},	// [fca0] riig, nsų_, ннаг, --,
   {{0x850e13ab,0x2fc901e8,0xdff307b5,0x6b9b0009}},	//   _साइट_, _ziag_, _आबाद_, čuga,
   {{0x2fc901e8,0xc8960274,0x636e00f1,0x290701ef}},	//   _yiag_, храњ, _lùna, ónaa_,
   {{0x68e306d0,0x09e64471,0x6d5e0225,0x65ad00a0}},	//   ında, _помн, _hopa, súhl,
   {{0x6d5ecbcf,0x16346cac,0x7af6055c,0x4aa700b4}},	//   _kopa, теля, mayt, _कुपव,
   {{0x7af6cbd0,0x2adc0825,0x26cd0036,0x6d5e36cc}},	//   layt, गुरु_, _egeo_, _jopa,
   {{0x6d5ecbd1,0x69d601f4,0x63a0cbd2,0x533402fb}},	//   _mopa, lqye, tomn, вейт,
   {{0x31c80d1f,0xd377171d,0x63750079,0x7af60be2}},	//   रद्ध, ечь_, _lánf, nayt,
   {{0xc2983121,0x320d0260,0x200c01a8,0x6d5e01ef}},	//   ьких_, guey_, wudi_, _oopa,
   {{0x63a001ba,0x02e0017a,0x6d5ecbd3,0x200ccbd4}},	//   somn, _ग्रह_, _nopa, tudi_,
   {{0x63a0cbd5,0xb4cc0325,0x69d60031,0x00000000}},	//   pomn, रखी_, hqye, --,
   {{0x20020496,0x200c8330,0x4ea7cbd6,0x753a4976}},	//   čki_, rudi_, ерга, _hatz,
   {{0x753a01ae,0x200cb0f6,0x51860800,0x98b100ea}},	//   _katz, sudi_, _пука, _mazā_,
   {{0x6d5ecbd7,0x238c00b8,0x753a0065,0x00000000}},	//   _copa, ději_, _jatz, --,
   {{0x2fc901a9,0x3d12046c,0xfbd90083,0x1fa7326d}},	//   _tiag_, _तारे_, ধীনত, _приг,
   {{0x7af631dc,0x753a01a3,0x00000000,0x00000000}},	//   gayt, _latz, --, --,
   {{0x7f4d007a,0x28c30067,0x3a9800af,0xbebb0345}},	// [fcb0] _inaq, वेनि, ектэ_, geët,
   {{0x7cd900c3,0x753a3305,0x7ac40210,0x93bc00af}},	//   _юмор_, _natz, уссе, _spăl,
   {{0x7f4d0055,0xb8d902b4,0xed62013a,0x00000000}},	//   _knaq, _चर_, _dažā_, --,
   {{0xdddd004e,0x6d5e7ca1,0x638700f8,0x7f4d007a}},	//   mysł, _zopa, _mènè, _jnaq,
   {{0x753a03cb,0x7f4d007a,0x00000000,0x00000000}},	//   _batz, _mnaq, --, --,
   {{0x753a0160,0xa2c409b1,0x6d5e0176,0x636e00f1}},	//   _catz, ाइन्, _xopa, _rùna,
   {{0x753acbd8,0x63870118,0xd4e401e0,0x00000000}},	//   _datz, _nènè, уючи, --,
   {{0x78b50116,0x7f4d0069,0x00000000,0x00000000}},	//   _izzv, _nnaq, --, --,
   {{0xa5353d35,0x45d500d4,0x753a6e0e,0x3d120066}},	//   _инач, _розс, _fatz, _ताले_,
   {{0x673b01a9,0x753a01a3,0xeeeb0023,0x7f4d0138}},	//   _hauj, _gatz, ướng_, _anaq,
   {{0xdee61362,0x92c30083,0x7f5f0024,0x638700e0}},	//   кони, ্রে_, _boqq, _cènè,
   {{0x6d5ecbd9,0x2d9102fb,0x673b48a6,0x6e360211}},	//   _sopa, enze_, _jauj, _psyb,
   {{0x6d5ebcdc,0x9f5f0086,0x4de20033,0x673b87ab}},	//   _popa, yttö_, _বিহং, _mauj,
   {{0xdb1d0d36,0x602501c8,0x673b006d,0x00000000}},	//   _lisä, _адка, _lauj, --,
   {{0xdca63312,0xdb0f009e,0x61fbcbda,0xa3e501c0}},	//   тави, _bhcà, lsul, बीच_,
   {{0x673b0a93,0x5bbe021a,0x98a701c0,0x2d91cbdb}},	//   _nauj, ्देव, žně_, anze_,
   {{0xee37005f,0x6d5ecbdc,0x81e50083,0x2bd2022e}},	// [fcc0] _аны_, _topa, _ফিড_, _दूरा,
   {{0x7af60159,0xbc66002d,0x61fb136b,0xdb0401ef}},	//   sayt, _авок, isul, rmiñ,
   {{0x61fb0095,0x673b033b,0x7f880510,0x00000000}},	//   hsul, _bauj, lıqq, --,
   {{0x6a861f39,0x86c60088,0x61fbcbdd,0x753a033b}},	//   _алма, نيان, ksul, _satz,
   {{0x9f590248,0x63755ab6,0x673b0409,0x753acbde}},	//   éré_, _mánd, _dauj, _patz,
   {{0x77b80391,0xb4cc00a1,0x636e0211,0x6e29027d}},	//   díxe, रखे_, _cùnn, çebi,
   {{0xe9df01a5,0x29180716,0xbef200a1,0x61fb005f}},	//   _trúc_, _icra_, _अजून_, esul,
   {{0x44200484,0x60cd027d,0x2249cbdf,0xdcee01ba}},	//   ċi_, _şamp, _šaka_, jobľ,
   {{0x171b00c2,0x61fb6c97,0x7582042c,0xdddd0035}},	//   _קומע, gsul, _پیغم, zysł,
   {{0x673b0d88,0x717400ad,0x67220009,0x638700e0}},	//   _zauj, اهدا, lfoj, _pènè,
   {{0x7bda0300,0x61fb030d,0x25700211,0x63750098}},	//   ítul, asul, _gàla_, _bánd,
   {{0x63750300,0xbb1b0139,0xbebb0b88,0x00000000}},	//   _cánd, _amîn, deër, --,
   {{0x5f942a66,0x63750b4c,0x76420e55,0x33260069}},	//   рият, _dánd, nvoy, _ibox_,
   {{0x7e6001ff,0x61ed00c1,0x61e2cbe0,0xdd8700af}},	//   ämpa, _çala, _itol, тымп,
   {{0x7f5f00a8,0x08f10083,0x637500ee,0xbebb0298}},	//   _toqq, _চালু_, _fánd, geër,
   {{0x2246a41f,0x7f4d0310,0x6375002a,0x2918cbe1}},	//   _krok_, _unaq, _gánd, _acra_,
   {{0x33268901,0xdb040093,0x291802d7,0x201ecbe2}},	// [fcd0] _mbox_, rmið, _bcra_, ltti_,
   {{0xdb1d03ad,0xd7e702ce,0x673bcbe3,0x201e290a}},	//   _sisä, відо, _sauj, otti_,
   {{0x201e0086,0x68f7013b,0xa9c407f5,0x48ab005f}},	//   ntti_, raxd, рстк, фтам_,
   {{0x201e03ad,0x61e2cbe4,0x224601a3,0x6d5a1b43}},	//   itti_, _otol, _orok_, ötav,
   {{0xf7700164,0x63b90297,0x98b1002d,0x61fb013b}},	//   غام_, _rhwn, _bază_, xsul,
   {{0xe9df0300,0xa9790070,0xf7830069,0x00000000}},	//   _grúa_, _טאָכ, _saħħ_, --,
   {{0x22460932,0xdb0400b5,0x3d1b07b5,0x33f4010b}},	//   _arok_, lliá, _बाने_, ачыс,
   {{0x61fb9524,0x332600fe,0x28b8018d,0x77b80042}},	//   tsul, _cbox_, _अरति, tíxe,
   {{0x68f50332,0xe7840ff6,0x201e1172,0x2a698981}},	//   _kezd, _туро, etti_, nyab_,
   {{0x61fbcbe5,0x68f50803,0x77b801dd,0x637500b5}},	//   rsul, _jezd, ríxe, _sánd,
   {{0x61fb7353,0xa0698d59,0xbfc602fb,0x00000000}},	//   ssul, хана_, лбок, --,
   {{0xeeeb00e8,0x201812c3,0x3326b897,0x2a69011e}},	//   ường_, ària_, _gbox_, kyab_,
   {{0x5fcf0fcf,0x6561cbe6,0x201e3367,0x22460069}},	//   _संकल, _kolh, atti_, _grok_,
   {{0x68f50a69,0x5bbe1f57,0x904500bc,0x236d00ac}},	//   _nezd, ्द्व, _منته, lkej_,
   {{0xab2a0525,0xd011004f,0x65610279,0x2cac008d}},	//   нова_, _الع_, _molh, ædd_,
   {{0xf0920052,0x33266983,0x2903042c,0xfaa600af}},	//   _לנו_, _xbox_, _adja_, габо,
   {{0xf2d2012b,0x68f52575,0xeb97002d,0x3a390345}},	// [fce0] מען_, _bezd, уит_, _cssp_,
   {{0x65610282,0x00000000,0x00000000,0x00000000}},	//   _nolh, --, --, --,
   {{0x9d1b02b5,0x7760006d,0xa806cbe7,0x98b10139}},	//   _אויט, _pomx, узел, _rază_,
   {{0xe9df07a6,0x637502d7,0x2ee003d0,0x00000000}},	//   _irún_, _yáne, _jfif_, --,
   {{0x656102c6,0xe9df0093,0x98b10395,0x2918023c}},	//   _bolh, _trúa_, _pază_, _tcra_,
   {{0x656103e6,0xad9b0037,0x660401ba,0x3326011e}},	//   _colh, trúi, šiko, _sbox_,
   {{0x3a20cbe8,0xb426006c,0x65610589,0x28c300e7}},	//   ltip_, اعتو, _dolh, वेदि,
   {{0x2b40cbe9,0x2d8a42ed,0x6f04829c,0xfaff0031}},	//   ndic_, hibe_, _ndic, _ulët_,
   {{0x69cecbea,0x65610370,0xc17488f0,0x3a20cbeb}},	//   _kibe, _folh, илищ, ntip_,
   {{0x2ee0012f,0xe8e00023,0xaa370070,0xdb1e0097}},	//   _afif_, _đớn_, נטיק_, _kupó,
   {{0x69cecbec,0x224612ba,0x2570009e,0x05770037}},	//   _mibe, _wrok_, _hàlo_, _حملة_,
   {{0x236d016f,0x201ecbed,0x998901d6,0x644817f0}},	//   ckej_, rtti_, ktaş_, _irdi,
   {{0x1154225d,0xf1ba0028,0x61e20332,0x442c5530}},	//   _вклю, _thơ_, _utol, _hpd_,
   {{0x6f044df4,0x3a200009,0x2d8a021d,0xe9df6993}},	//   _edic, dtip_, gibe_, _brún_,
   {{0x80db00a5,0x00000000,0x00000000,0x00000000}},	//   _אחוז, --, --, --,
   {{0x69ce1867,0x68f50950,0x6ecc00ec,0x00000000}},	//   _aibe, _sezd, _bēbī, --,
   {{0x8d870346,0x3f8bcbee,0x3d9500d4,0x2c150033}},	// [fcf0] _бунд, micu_, _випр, াবেই_,
   {{0x2d8a0f56,0x3f8b6207,0x644809e8,0x6e2d1fd9}},	//   cibe_, licu_, _ordi, _ipab,
   {{0x69ce49c2,0xdb1e0453,0x442ccbef,0x38352e50}},	//   _dibe, _cupó, _npd_, рнер,
   {{0x3f8b0ba8,0x3d1b007c,0x656103c1,0xdb0407a6}},	//   nicu_, _बाडे_, _solh, pliá,
   {{0x69ce09b3,0xe8010084,0x656125ff,0x8afa00a5}},	//   _fibe, _लटका_, _polh, _בהרי,
   {{0x442ccbf0,0x69cecbf1,0x7aed8d9d,0x644818b0}},	//   _bpd_, _gibe, lbat, _brdi,
   {{0x3f8b022f,0x6561cbf2,0xf99f0359,0x7bcf04fb}},	//   kicu_, _volh, _avèg_, _kicu,
   {{0x7aed06a2,0x442c022e,0x3f8b0254,0x7bd701b7}},	//   nbat, _dpd_, jicu_, _muxu,
   {{0xe1f602ee,0x644806a2,0x3f8b0254,0x7bcfcbf3}},	//   агы_, _erdi, dicu_, _micu,
   {{0x7bcf01f7,0x236d016f,0xb0df021a,0x69ce01b7}},	//   _licu, skej_, पुंग, _xibe,
   {{0x8af001c2,0x6e2d2a37,0x63754f85,0x2d8a0176}},	//   rkəz, _apab, _cánc, vibe_,
   {{0x7649142f,0x8fa62ad7,0x7bcf87bd,0x3f8b0124}},	//   _krey, раме, _nicu, gicu_,
   {{0x6d89b09c,0x200ccbf4,0x7aed314b,0x672900e0}},	//   ržan, ardi_, dbat, _mbej,
   {{0xeeeb0028,0x63a4232f,0x427a00a5,0x7aed1268}},	//   ưởng_, čine, _באנג, ebat,
   {{0x2d8acbf5,0x69ce1ec5,0xed5700af,0x672907b3}},	//   ribe_, _ribe, шор_, _obej,
   {{0x69ce57fc,0x7aed2487,0x3f8b022f,0x6f040e31}},	//   _sibe, gbat, cicu_, _udic,
   {{0x7bcf1034,0xdb1e043f,0x5986005f,0x61e9a6fb}},	// [fd00] _dicu, _supó, алаб, npel,
   {{0x6729cbf6,0x7aed61ee,0x29cd0009,0x61ed003c}},	//   _abej, abat, _džao_, _ħall,
   {{0x7aed1f4a,0x9856021d,0x69ce13dc,0x3a2001e4}},	//   bbat, шташ, _vibe, stip_,
   {{0x76495c63,0x7bcf0010,0x70d2258f,0x61e9cbf7}},	//   _brey, _gicu, _सल्ल, kpel,
   {{0x7bc4081b,0x7649cbf8,0x644802b2,0x442c01ae}},	//   mmiu, _crey, _srdi, _spd_,
   {{0x7649cbf9,0x3f8b025c,0x64480124,0x7bd700a8}},	//   _drey, zicu_, _prdi, _yuxu,
   {{0x7649288d,0x9cd70122,0x61e99b50,0x6d891a8a}},	//   _erey, בוצה_, epel, džal,
   {{0x7649cbfa,0x200c011c,0x320d5bad,0x00000000}},	//   _frey, vrdi_, frey_, --,
   {{0x7649cbfb,0x63750b4c,0x3f8b2ba3,0x61ed0c6f}},	//   _grey, _sánc, vicu_, _çall,
   {{0x7aed002d,0x442c7380,0x6448008b,0x200c08b7}},	//   zbat, _tpd_, _trdi, trdi_,
   {{0x644801d7,0x403402fb,0xbddb0176,0x64a6021d}},	//   _urdi, щенс, avèl, _тажа,
   {{0x7e7d02b1,0xde59010b,0x00000000,0x00000000}},	//   tzsp, гамі_, --, --,
   {{0xa11601ca,0x3f8b2ee4,0x7bc441c7,0x7bcfcbfc}},	//   _نوشت, ricu_, dmiu, _ricu,
   {{0x7bcf0133,0x3f8b0506,0x090c0033,0xac190f68}},	//   _sicu, sicu_, স্তু_, логу_,
   {{0x3f8bcbfd,0x00000000,0x00000000,0x00000000}},	//   picu_, --, --, --,
   {{0xdb1e798f,0x00000000,0x00000000,0x00000000}},	//   _supò, --, --, --,
   {{0x7aedcbfe,0x497500d8,0x4aa700dc,0xf1ba0035}},	// [fd10] rbat, блас, _कुशव, _उठान,
   {{0x6375008a,0x7aed01b7,0x7bcfcbff,0x00000000}},	//   _mána, sbat, _wicu, --,
   {{0xd24603c5,0x320d00d7,0x6375cc00,0xab5bcc01}},	//   _کن_, zrey_, _lána, _diür,
   {{0x7649ade8,0xdc360070,0x07080037,0x9b5900af}},	//   _prey, _פארט_, ليمي_, _симт_,
   {{0x637500fb,0xd6d90035,0xa50941f8,0x00000000}},	//   _nána, _cała_, гела_, --,
   {{0xa8050391,0x2a3a0070,0xdcfe0160,0x77b801ef}},	//   _coñé, _געשמ, _impă, ríxa,
   {{0x69c59d1e,0x28c30096,0x00000000,0x00000000}},	//   mmhe, वेशि, --, --,
   {{0x6b8d30cb,0x7649cc02,0x6d89cc03,0x61e9005f}},	//   niag, _trey, džam, tpel,
   {{0x63750037,0x81df0033,0x00000000,0x00000000}},	//   _cána, ধীন_, --, --,
   {{0x6b8d03cb,0x320d1f83,0xc5170286,0x515500af}},	//   hiag, rrey_, _خبرت, стиу,
   {{0xa0a57dc2,0x6d8901a0,0x69c501a6,0x6b8dcc04}},	//   санд, ržal, imhe, kiag,
   {{0x61e9cc05,0x6375cc06,0x34b600a5,0x2579021e}},	//   ppel, _fána, _הפעם_, _dèle_,
   {{0x100922a7,0x4129081b,0x63a9cc07,0x4aa70066}},	//   _विवश_, _боло_, moen, _कुलव,
   {{0xfce37ef0,0x3f89099e,0x3d120387,0x61e693ee}},	//   зоро, _emau_, ़लें_, íkle,
   {{0xdd8f2087,0x69c504e6,0xc0c80274,0x6b8dcc08}},	//   روف_, dmhe, _куће_, fiag,
   {{0xa3b7012f,0x63a90065,0x6b8dcc09,0xef1a00c3}},	//   छति_, noen, giag, _сми_,
   {{0x9f5f0187,0x3de20033,0x2d9a0183,0x00000000}},	// [fd20] nutý_, _বিকল, _tjpe_, --,
   {{0x63a9648e,0x9cf60043,0xd910042c,0xe8f7022b}},	//   hoen, _учиш, بیس_, йлу_,
   {{0x63a9cc0a,0xa3b70026,0x6b8d1ab5,0xdc6a0036}},	//   koen, छता_, biag, _санд_,
   {{0x7c3e41d2,0x69c503c4,0xdc3a0069,0x63a90088}},	//   _ispr, amhe, _aħħj, joen,
   {{0x2d980831,0x63a903c4,0x6d890009,0xa8050042}},	//   onre_, doen, džaj, _poñé,
   {{0xf8dc7f73,0x637c00e0,0x9633010b,0x3ea00b88}},	//   _बलिय, _kéng, яніц, _mxit_,
   {{0xe3af02fd,0xf74616ed,0x637c00e0,0xad9b01ef}},	//   کرو_, _лево, _jéng, nsúa,
   {{0x637c00e0,0x63a906a2,0x68fe6eee,0x2b42023a}},	//   _méng, goen, lapd, _jakc_,
   {{0x637c0118,0xf1a662a2,0x056601fd,0x3ea00055}},	//   _léng, йрон, _лван, _nxit_,
   {{0xe80d02cb,0x7c3eb1a4,0x0ef10026,0x3f890036}},	//   ांचा_, _ospr, चर्स_, _smau_,
   {{0xa3df0299,0x63a9cc0b,0x2fc0006b,0x649a08ce}},	//   _धूप_, boen, _bhig_, _стар_,
   {{0x443e328b,0x63a901a2,0x68fe0cca,0x289b0317}},	//   _ist_, coen, hapd, ריטא,
   {{0x6b8d12a2,0x7c3e2423,0x66021363,0x82b60647}},	//   viag, _aspr, nsok, _احاط,
   {{0x2366006d,0x637c0118,0x6143cc0c,0x00000000}},	//   _hooj_, _béng, _неча, --,
   {{0x236601e8,0x443e008b,0x00000000,0x00000000}},	//   _kooj_, _jst_, --, --,
   {{0x2366022f,0x7c3e008c,0x00000000,0x00000000}},	//   _jooj_, _dspr, --, --,
   {{0x7c3e0db2,0x6b8dcc0d,0x236601e8,0xaa580274}},	// [fd30] _espr, riag, _mooj_, биту_,
   {{0x23660221,0x443e4d0a,0x63a9cc0e,0x6b8d0065}},	//   _looj_, _ost_, zoen, siag,
   {{0x69c50082,0xc8c30026,0xa3d40026,0xdb0d0037}},	//   rmhe, वेंट, _िंग_, llaí,
   {{0xdb0d004f,0x637c00e0,0x00000000,0x00000000}},	//   olaí, _jénd, --, --,
   {{0x637c9457,0x00000000,0x00000000,0x00000000}},	//   _ménd, --, --, --,
   {{0xd5af006c,0xa3e93cab,0x6375002a,0x68fe04cb}},	//   رہا_, адка_, _cánn, capd,
   {{0xdcf50029,0x2bbf1856,0x984800af,0xd7c90312}},	//   lizē, ्षपा, _лята_, _نوسه_,
   {{0x2366006d,0x9f5f0079,0x42090200,0x43690d46}},	//   _cooj_, artú_, анио_, раин_,
   {{0x443e168b,0x63a9cc0f,0xe2991646,0xdcf50029}},	//   _est_, roen, рап_, nizē,
   {{0x63a415d7,0x63a9cc10,0x443e6def,0x3f9900e2}},	//   čina, soen, _fst_, ensu_,
   {{0x25a00082,0x7dc000b5,0x63a9cc11,0x98b80139}},	//   éile_, nöse, poen, _iară_,
   {{0x200b1cbe,0xd6d90035,0x5275002d,0x1eca0ef3}},	//   čci_, _mało_, _мулу, илни_,
   {{0xdb0d0079,0x256b11cb,0x00000000,0x00000000}},	//   glaí, _følt_, --, --,
   {{0x9f46004f,0x2fc0012f,0x29cd0009,0x236601e8}},	//   mplí_, _whig_, _džak_, _zooj_,
   {{0x3d1b1033,0x8c433d35,0x23660189,0x2fc00014}},	//   _बारे_, мере, _yooj_, _thig_,
   {{0xdb04004f,0x203205f5,0xe8e000e2,0x3ea001b7}},	//   lliú, _آفيس, _đốn_, _txit_,
   {{0xe8fa5049,0xc3320bed,0x3943cc12,0xdb0d0037}},	// [fd40] ила_, וון_, _bajs_, claí,
   {{0x61e4004f,0x9f5f0453,0xad9bcc13,0x637c00e0}},	//   _éile, butó_, lsún, _téng,
   {{0xb17a02b5,0x7c3e6707,0xdb040037,0x68fecc14}},	//   סטער, _uspr, iliú, rapd,
   {{0xe51c2fa9,0xd37801cc,0x3943011e,0x68fecc15}},	//   _नाहि_, _kuće_, _eajs_, sapd,
   {{0x23660189,0xe5c62a24,0x98b80139,0xddcd063c}},	//   _rooj_, оско, _bară_, _braň,
   {{0x1dbc08d1,0x637553b1,0x98b80160,0x53e6188d}},	//   ोगित, _báno, _cară_, оциа,
   {{0x236601e8,0x475a07b4,0x443e07e5,0xd37a34d4}},	//   _pooj_, _края_, _qst_, ичи_,
   {{0x68fccc16,0x7ae47297,0x93bc0043,0x637501ef}},	//   _herd, ncit, _apăr, _dáno,
   {{0xa5f700c9,0x2e240093,0x637c3762,0x1dbc0f17}},	//   _меѓу_, jöf_, _rénd, ोगात,
   {{0x68fc00d7,0x443ecc17,0x637c002a,0x98b80139}},	//   _jerd, _tst_, _sénd, _gară_,
   {{0x23660189,0x443ecc18,0x2bbf0355,0xd8db0070}},	//   _tooj_, _ust_, ्षमा, יקיר,
   {{0x65680031,0x68fc54a2,0x7ae400d5,0x637c00f6}},	//   _hodh, _lerd, jcit, _béne,
   {{0x644a093a,0x31670051,0x637c0042,0x68fc34d7}},	//   lvfi, _fonz_, _vénd, _oerd,
   {{0x68fcb029,0xdb0d0037,0x656801cb,0xad9b0079}},	//   _nerd, rlaí, _jodh, asún,
   {{0x6568b48a,0x637c002a,0x00000000,0x00000000}},	//   _modh, _ténd, --, --,
   {{0xdb0d008d,0x65686acf,0xdcf500ea,0x7ae4081b}},	//   gmað, _lodh, tizē, gcit,
   {{0x68fccc19,0x637c22d3,0x49752872,0x29d5004f}},	// [fd50] _berd, _géne, плас, سياس,
   {{0x68fccc1a,0xdcf500ea,0xf84b291e,0xad9b0138}},	//   _cerd, rizē, ичей_, crúp,
   {{0x2d91cc1b,0x4735487d,0x39437f6b,0x7ae400f6}},	//   mize_, знес, _vajs_, bcit,
   {{0x6d45482f,0x6f1d1d8b,0x68fc0a45,0x657a91f0}},	//   _haha, ngsc, _eerd, _alth,
   {{0x6d45cc1c,0x6568cc1d,0x637c043f,0x68fccc1e}},	//   _kaha, _bodh, _xéne, _ferd,
   {{0x2d914c8a,0x68fccc1f,0x7afd3fee,0x6d473660}},	//   nize_, _gerd, _hest, ndja,
   {{0x6d45cc20,0x2901cc21,0x7afd68de,0x69dd0bf3}},	//   _maha, maha_, _kest, _huse,
   {{0x6d45134c,0x7afd0632,0x2901cc22,0x69ddcc23}},	//   _laha, _jest, laha_, _kuse,
   {{0x68fc0092,0x2d9172d4,0x69d508a0,0x656800f1}},	//   _yerd, kize_, _kize, _fodh,
   {{0x6d45cc24,0x61e60076,0x6568cc25,0x057745fd}},	//   _naha, íkla, _godh, _بارد,
   {{0x7afd061b,0x2d911b71,0xfbdb29ad,0xcea90317}},	//   _oest, dize_, _मूलम, _עי_,
   {{0x69d5cc26,0x7afd79f7,0x2901482f,0x69dd01ef}},	//   _lize, _nest, haha_, _ouse,
   {{0x6d45cc27,0xe8b80026,0x2d9102e9,0x2901685e}},	//   _baha, _अर्च, fize_, kaha_,
   {{0x6d45cc28,0x2d910232,0x69d5cc29,0x2901009f}},	//   _caha, gize_, _nize, jaha_,
   {{0x7afdcc2a,0x2901cc2b,0x6d45cc2c,0x307902b5}},	//   _best, daha_, _daha, _לאַנ,
   {{0x7afd0e6a,0x69ddcc2d,0x68fccc2e,0x6d571561}},	//   _cest, _buse, _serd, _enxa,
   {{0x7ae4a9af,0x6d45cc2f,0x7afd1f73,0x2d8402e1}},	// [fd60] rcit, _faha, _dest, èmes_,
   {{0x7afd3914,0x7ae4cc30,0xdb0d0093,0x290158f9}},	//   _eest, scit, smað, gaha_,
   {{0x69d5cc31,0x656801cb,0x443c006f,0x68e70345}},	//   _dize, _rodh, xwv_, _dfjd,
   {{0x68fc0446,0x69dd8b6e,0x6d45709d,0x68e5004a}},	//   _werd, _fuse, _zaha, achd,
   {{0x6d450010,0x68fc5a95,0x69d5cc32,0x2901cc33}},	//   _yaha, _terd, _fize, baha_,
   {{0x7bdecc34,0x7afdcc35,0x6d45003c,0x69d543a0}},	//   _kupu, _zest, _xaha, _gize,
   {{0x777b98bc,0xd46703fa,0x798e01d5,0x20050009}},	//   _flux, зије_, _imbw, jsli_,
   {{0x63a40169,0x7afd0391,0xfaff2c60,0x2d9101d5}},	//   čino, _xest, _noël_, zize_,
   {{0x7bde53f3,0x6441cc36,0x2007cc37,0x65680315}},	//   _lupu, _esli, _avni_, _todh,
   {{0xad9b0082,0x442703da,0x04460192,0x25790118}},	//   gsúl, btn_, _незн, _tèla_,
   {{0x6d45cc38,0x2d919e39,0x636e009e,0x7bdecc39}},	//   _raha, vize_, _bùnt, _nupu,
   {{0x6d45cc3a,0x929d004e,0x29010371,0x2d917675}},	//   _saha, wałe, zaha_, wize_,
   {{0x29010232,0x2d91cc3b,0x6e3d0a75,0x0ec702e4}},	//   yaha_, tize_, uwsb, रेंड,
   {{0x69ddcc3c,0x5bb50380,0x3d170066,0x39580211}},	//   _ruse, ंत्व, तलें_, _nnrs_,
   {{0x2d91cc3d,0x69ddcc3e,0x6d47cc3f,0x29010097}},	//   rize_, _suse, rdja, vaha_,
   {{0x6d45304a,0x2d91cc40,0x69ddcc41,0x2901cc42}},	//   _waha, size_, _puse, waha_,
   {{0x6d45cc43,0x7afdcc44,0x2901cc45,0xda34004b}},	// [fd70] _taha, _vest, taha_, неты,
   {{0x7afd1f8c,0x39584b2f,0x682700d8,0x98c70714}},	//   _west, _cnrs_, зьдз, псел,
   {{0x290148d4,0xb4bb964d,0x69d5cc46,0x68e502b1}},	//   raha_, _घरे_, _vize, rchd,
   {{0x69ddcc47,0x78b50187,0x569500c3,0x68e53109}},	//   _tuse, _vyzv, мает, schd,
   {{0x69d500b5,0x395801ef,0x8b080355,0x2b59021d}},	//   _tize, _fnrs_, stří, _insc_,
   {{0x2901046a,0xdcf002c4,0x2bb5021a,0x00000000}},	//   qaha_, čeći, ंतका, --,
   {{0x98b81627,0x64a20409,0x00000000,0x00000000}},	//   _parą_, каша, --, --,
   {{0x770500f8,0xfbbf00ab,0x2b490160,0x637c00e0}},	//   _آژان, ्षिम, ndac_, _rénc,
   {{0x3a290ec0,0x4427023a,0xd34601cb,0xa5f80421}},	//   ntap_, stn_, بینه_, _нету_,
   {{0x6009190a,0x4427028b,0xfaff03bc,0x66090124}},	//   оном_, ptn_, _leë_, _ivek,
   {{0x6441466b,0xfbbf7a51,0x8fa60bff,0x46e1021a}},	//   _usli, ्षाम, дане, _फलाह,
   {{0x6f0d0176,0x224900cb,0xdc3c00ee,0x3a290345}},	//   _cdac, _šaku_, _páľa, ktap_,
   {{0x7bdebb13,0xe28e408d,0xfaff03bc,0x00000000}},	//   _supu, _ра_, _voël_, --,
   {{0x7bde0ec1,0x6f0d0176,0x59d800b4,0xd1313181}},	//   _pupu, _edac, _भूगर, _شمع_,
   {{0x224d7b79,0x6ec20066,0x21a25454,0x2d8400c7}},	//   lvek_, रेजु, _шишм, ėme_,
   {{0xd3780a78,0x05dd1fe0,0x66090478,0x2b590160}},	//   _kuća_, मदाब, _ovek, _cnsc_,
   {{0xaec6218b,0xef190035,0x00000000,0x00000000}},	// [fd80] _юбил, óże_, --, --,
   {{0x7bde95eb,0x637ccc48,0x851c2516,0x00000000}},	//   _tupu, _ména, _नाइट_, --,
   {{0xfaff0345,0x637c453a,0xcb6a43af,0x00000000}},	//   _feë_, _léna, _дане_, --,
   {{0x2907003e,0x00000000,0x00000000,0x00000000}},	//   ónar_, --, --, --,
   {{0x6d8901cc,0xeb3b00a5,0x9f6500fd,0x00000000}},	//   ržav, _ועכש, áték_, --,
   {{0x798e2a13,0x00000000,0x00000000,0x00000000}},	//   _umbw, --, --, --,
   {{0xbddb0176,0x224d01ed,0x660905f5,0x00000000}},	//   lvèt, evek_, _evek, --,
   {{0x637c00a2,0x5f1a021a,0x00000000,0x00000000}},	//   _béna, _भाग्_, --, --,
   {{0xc29810be,0x25fd0067,0x6f0d01da,0x99890067}},	//   яких_, रीदी_, _rdac, brań_,
   {{0x636e009e,0x637c6634,0x99de010b,0x00000000}},	//   _cùnr, _déna, вiка_, --,
   {{0x660900cd,0xf99300a5,0x6e36004b,0xa0a6051a}},	//   _zvek, כרז_, _apyb, ьшил,
   {{0x201105f6,0xf99f0260,0x77b80176,0x98b8013a}},	//   ázia_, _avèl_, fíxi, _anrī_,
   {{0xdb0d0955,0x7af600ac,0x63a2cc49,0x6234002d}},	//   llaç, dbyt, _ijon, _челу,
   {{0x63ad20ee,0xfaff0298,0x00000000,0x00000000}},	//   čane, _seë_, --, --,
   {{0x1fa7195a,0x5f950043,0xdb6b3d52,0x00000000}},	//   _ориг, _пикт, орал_, --,
   {{0x9b584697,0x6f0d0027,0x7af61d8d,0x00000000}},	//   мист_, _udac, gbyt, --,
   {{0x2bc3021a,0x63750168,0x00000000,0x00000000}},	// [fd90] _वीणा, _sánk, --, --,
   {{0x2eaa02b5,0xc17800d8,0x3a29cc4a,0xfaff03bc}},	//   _משפּ, nkė_, rtap_, _weë_,
   {{0x63a401cc,0x660903d0,0x4c950043,0x3a29cc4b}},	//   činj, _svek, _чинс, stap_,
   {{0x8c1a00c2,0x63a25eb3,0x3a29cc4c,0x637500d5}},	//   _צורי, _njon, ptap_, _vánk,
   {{0xaaa70a44,0x659521c3,0x7bcd02ee,0x00000000}},	//   _कुचक, наду, mmau, --,
   {{0xdb0d0279,0x63a200c3,0x7bcd4cdf,0x637c000d}},	//   flaç, _ajon, lmau, _réna,
   {{0x637c1f96,0x23d5b8b5,0x63a2cc4d,0xf8690037}},	//   _séna, нцир, _bjon, _عمري_,
   {{0x130902ce,0xc2450948,0x6609013c,0x637c00f7}},	//   чний_, еник, _tvek, _péna,
   {{0x2609162b,0x56150098,0x461518dd,0x63a20260}},	//   _सिटी_, _سواء, _سوار, _djon,
   {{0xb145036e,0x7af600b8,0x91b400e2,0x80651172}},	//   хнол, zbyt, _đẹp_, евож,
   {{0x2d8301d2,0x6375003e,0x00000000,0x00000000}},	//   dhje_, _láni, --, --,
   {{0x92bd00c8,0xf1b90672,0xa3c2073f,0x63a201f4}},	//   _আলী_, duše_, ूषण_, _gjon,
   {{0x69c703ad,0xf99f0107,0x98b8005f,0x99800207}},	//   _ohje, _avèm_, _darę_, htiš_,
   {{0x63bbcc4e,0x7bc601d2,0x3f8200da,0x66d601d6}},	//   llun, _shku, shku_, _hükü,
   {{0xdca323d7,0x6d89010b,0x7af6cc4f,0xf1b90207}},	//   гари, ežas, tbyt, guše_,
   {{0x63bb21c2,0xbb43c4e0,0x00000000,0x00000000}},	//   nlun, леск, --, --,
   {{0xfce60ecb,0x63bb02c9,0x6ea8006c,0x637501ef}},	// [fda0] _попо, ilun, _زندہ_, _cáni,
   {{0x63bb02c9,0x2d830051,0xe9df01f7,0x637500fd}},	//   hlun, chje_, _arús_, _dáni,
   {{0x69c700da,0x6d894bef,0xa3df0084,0xad1b0070}},	//   _dhje, ržat, _धूल_, _צוטר,
   {{0xdd20056a,0x66e61f67,0xb6a610bb,0x929d0067}},	//   _बाँध_, хода, ниел, zała,
   {{0x63bb4617,0x2bbf21b2,0xfbbf0b35,0x00000000}},	//   dlun, ्षरा, ्षरम, --,
   {{0x63a2cc50,0x6f0600d7,0xb6cb00fd,0x63bb0b74}},	//   _sjon, hakc, سانے_, elun,
   {{0xc8b5004b,0x63bbcc51,0xe9a30009,0x63750097}},	//   _асты, flun, _сарп, _záni,
   {{0x32660cda,0x63bbcc52,0x394acc53,0x929d0035}},	//   етов, glun, _habs_, wała,
   {{0xdb0400b5,0xe1ef0148,0xdb0d0370,0xdd2002e4}},	//   llió, یسی_, slaç, _बांध_,
   {{0xdb0d8b45,0x82330037,0x394a0260,0x3f800031}},	//   plaç, اريا, _jabs_, _aliu_,
   {{0x6b84011e,0x63a2cc54,0x63bb40a4,0x98b80035}},	//   khig, _tjon, blun, _parę_,
   {{0x6722cc55,0xf1b9012e,0x63a20fef,0x63bb2461}},	//   ngoj, vuše_, _ujon, clun,
   {{0x6b84009e,0x59b000a1,0x2d8301f4,0x6d8903ab}},	//   dhig, जकार, thje_, džar,
   {{0x224601cb,0xd3780207,0x00000000,0x00000000}},	//   _isok_, _kućo_, --, --,
   {{0x41c30c36,0x61e203ad,0x213e00fd,0x66d6033e}},	//   _حقوق, _huol, meth_, _yükü,
   {{0x213e4b59,0x61e2cc56,0x2d8300da,0x201ecc57}},	//   leth_, _kuol, shje_, muti_,
   {{0x201ecc58,0x7bcdcc59,0x4fd80122,0x394a03bc}},	// [fdb0] luti_, rmau, _אוהב_, _babs_,
   {{0x3d1b0ccf,0xf1b90124,0x7bcdbb04,0x25a00079}},	//   _बाटे_, puše_, smau, éill_,
   {{0x201e093d,0x39a4192f,0x6b841c8b,0x63bb016e}},	//   nuti_, уштв, bhig, ylun,
   {{0x6722012f,0x6b84cc5a,0x98140079,0x00000000}},	//   ggoj, chig, ابلا, --,
   {{0x69c701d2,0x998004c3,0x61e21db7,0x213e0159}},	//   _thje, stiš_, _nuol, keth_,
   {{0x201e0f1a,0xe4e702ce,0x7d071916,0xa9990070}},	//   kuti_, хідн, najs, _חבֿר,
   {{0xad9b0079,0x2246cc5b,0x63bbcc5c,0x2b4b034d}},	//   gsúi, _asok_, tlun, _kacc_,
   {{0x201e15a1,0x637c0248,0x9f5f0187,0x7d070069}},	//   duti_, _déno, ystá_, hajs,
   {{0x63bb4e0b,0x29cd044d,0x2d810132,0xd36e0037}},	//   rlun, _užas_, _olhe_, تهي_,
   {{0x63bb7966,0x201ecc5d,0x637c600b,0x7d07783c}},	//   slun, futi_, _féno, jajs,
   {{0xa0a53cef,0xf99f142f,0x7d070076,0x201ecc5e}},	//   танд, _avèk_, dajs, guti_,
   {{0x213e0297,0x229200f8,0x2911023a,0x290309f0}},	//   aeth_, الیس, _ldza_, _leja_,
   {{0x213ecc5f,0x333f00f7,0x7d070031,0xa2cd0808}},	//   beth_, meux_, fajs, देश्,
   {{0x201ecc60,0x333f00f7,0xc0e21667,0x7d0701e9}},	//   buti_, leux_, _кошк, gajs,
   {{0x5c1517e0,0x201ecc61,0xab2a0f29,0x1c391470}},	//   льту, cuti_, мова_, нять_,
   {{0x26df0054,0x29110a4e,0x333f00f7,0xbebb01f4}},	//   _nguo_, _adza_, neux_, rfër,
   {{0xe9dac5e2,0x2903cc62,0xbb432770,0x6abe073f}},	// [fdc0] дка_, _beja_, шетк, ्धेर,
   {{0x63a40690,0x6b84a72f,0x7d5602b5,0x6f04cc63}},	//   čini, shig, _ייִד_, _heic,
   {{0x2903cc64,0x2d985926,0x92bd0083,0x6f0400c7}},	//   _deja_, mire_, _আলো_, _keic,
   {{0x8a062e87,0x2d98cc65,0x6d4e3026,0x637c0248}},	//   _изме, lire_, ldba, _réno,
   {{0x290301f4,0x6722cc66,0x6f04cc67,0x25fd0066}},	//   _feja_, rgoj, _meic, रीली_,
   {{0x2d98cc68,0x6f04cc69,0x637500fb,0x61e202fb}},	//   nire_, _leic, _mánu, _ruol,
   {{0x7c2ecc6a,0x61e26dc0,0x7642022e,0x43940c98}},	//   ntbr, _suol, swoy, лакс,
   {{0x2d98cc6b,0x61e203ad,0x18a30336,0x201ecc6c}},	//   hire_, _puol, _тасм, vuti_,
   {{0x69dc44fa,0x2d984368,0x2fc9001e,0x55e601e0}},	//   _kire, kire_, _rhag_, _розб,
   {{0x69dc40a4,0xa545250f,0x61e2b75f,0x201ecc6d}},	//   _jire, _مضمو, _vuol, tuti_,
   {{0x213ecc6e,0x6f0400e9,0xf9930122,0xd91b0070}},	//   reth_, _beic, שרת_, וויל,
   {{0x6d5ecc6f,0x6448cc70,0x6d4e32c5,0x201ecc71}},	//   _anpa, _isdi, edba, ruti_,
   {{0x6f0402a8,0x2d98cc72,0x69dc8e72,0x201ecc73}},	//   _deic, fire_, _oire, suti_,
   {{0x201e94bd,0x2d98cc74,0x69dccc75,0x2fc90159}},	//   puti_, gire_, _nire, _whag_,
   {{0x290300da,0x6f0438fd,0x7d07cc76,0x403406a9}},	//   _reja_, _feic, rajs, _сейс,
   {{0x69dccc77,0x290300c9,0x6d5eb94b,0x3a3900d7}},	//   _aire, _seja_, _enpa, _ppsp_,
   {{0x69dc3dc6,0x2d9868f7,0x2903cc78,0x26170099}},	// [fdd0] _bire, bire_, _peja_, _निधी_,
   {{0x6ac3cc79,0x69dccc7a,0x2d98cc7b,0x6f0402c9}},	//   _शरीर, _cire, cire_, _zeic,
   {{0x290300c9,0xe719004f,0x333fcc7c,0xf1b90168}},	//   _veja_, فيات_, yeux_, nuša_,
   {{0xf77017bd,0x69dccc7d,0xdb040042,0xcc5632e3}},	//   يان_, _eire, bliñ, _עברי_,
   {{0x7bdd00af,0x333f0248,0x2903cc7e,0x637c002a}},	//   _iisu, veux_, _teja_, _vénl,
   {{0x64a51f67,0x7aed07f2,0x69dccc7f,0xf1b901a0}},	//   лала, lcat, _gire, kuša_,
   {{0x7bddcc80,0x7aed0036,0x27e3022e,0x333f8b93}},	//   _kisu, ocat, _uujn_, teux_,
   {{0x69dccc81,0x2d98cc82,0x2a6d004e,0xf1b900cd}},	//   _zire, zire_, _żeby_, duša_,
   {{0x7bddcc83,0x333f02e1,0x6f04cc84,0x9f5f0086}},	//   _misu, reux_, _reic, istä_,
   {{0x6f04cc85,0x7bdd02b3,0x69dc009e,0x2d9801dd}},	//   _seic, _lisu, _xire, xire_,
   {{0x93f55562,0x2d98c1f6,0x6e2d046a,0x6f04a253}},	//   _спец, vire_, _aqab, _peic,
   {{0x2d98cc86,0x7bdd01f4,0x63750b06,0x32452499}},	//   wire_, _nisu, _cánt, _منصف,
   {{0x6f04cc87,0x7aed55e9,0x877a02b5,0x2d98cc88}},	//   _veic, dcat, גארי, tire_,
   {{0x6f04c345,0xf1b900a0,0x7c2ecc89,0x9f5f00c3}},	//   _weic, buša_, ttbr, estä_,
   {{0x6f04cc8a,0x2d98cc8b,0x7bddcc8c,0x6abe0edf}},	//   _teic, rire_, _bisu, ्ध्र,
   {{0x7aed0858,0x69dccc8d,0x2d98cc8e,0x76490359}},	//   gcat, _sire, sire_, _osey,
   {{0x7bdd0452,0x320dc634,0x49ca294d,0x7c2e0210}},	// [fde0] _disu, nsey_, елан_, stbr,
   {{0x6d5ecc8f,0xed463a52,0x7aedcc90,0x7d0502b1}},	//   _unpa, _сноп, acat, _gehs,
   {{0x7649011e,0x7bdda019,0xe81f0066,0xb17a0070}},	//   _asey, _fisu, मूला_, עטער,
   {{0x7aed01d3,0x06861126,0xdc9b0100,0x7bdd03be}},	//   ccat, лген, _טייל, _gisu,
   {{0xd5ba45d7,0x442c00d7,0x4a760043,0x6375cc91}},	//   нск_, _sqd_, _сынт, _láns,
   {{0x69dc00f1,0x75d311c0,0x3f990009,0x64484331}},	//   _uire, مينا, zisu_, _psdi,
   {{0x764902e9,0x7bdd01d5,0xf99f0260,0xf9839e1e}},	//   _esey, _yisu, _avèw_, _угро,
   {{0x087700c2,0xf1b9025c,0x52140011,0x33740009}},	//   _געלט_, vuša_, адит, ргир,
   {{0xbb3b02b5,0x779103fc,0xdb060c6f,0x00000000}},	//   געפי, _بینا, _ajkë, --,
   {{0xceeb01cb,0x7aed01ef,0xf1b900f4,0xc33900fd}},	//   کردن_, zcat, tuša_, áírá,
   {{0x7aed1c7f,0xc0570131,0x9f5f0086,0x40340112}},	//   ycat, гія_, ystä_, шенс,
   {{0xe81c0953,0xf1b91bd8,0x63750187,0x7dc001ff}},	//   _पटना_, ruša_, _dáns, lösh,
   {{0x7bdd0133,0x957c004e,0x7aed0393,0x5f9401d3}},	//   _risu, _ciąg, vcat, сият,
   {{0x091a0b52,0x7bdd1c55,0x7aed00d7,0x00000000}},	//   ন্তু_, _sisu, wcat, --,
   {{0x3f99cc92,0x7bddcc93,0x637501ef,0x7aed055c}},	//   pisu_, _pisu, _gáns, tcat,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aedcc94,0xbda718dd,0x7bddc691,0xdb040093}},	// [fdf0] rcat, _محدو, _visu, rlið,
   {{0x7aed16ac,0x3b090024,0xdb040093,0x48ab0043}},	//   scat, saaq_, slið, нтем_,
   {{0x7bdd029d,0x98c71558,0x00000000,0x00000000}},	//   _tisu, усал, --, --,
   {{0x290e1685,0x205700a5,0x7bdd018d,0xf99f021e}},	//   ófar_, טיבל_, _uisu, _swèd_,
   {{0xd2460789,0x96b80210,0xd1380067,0x00000000}},	//   _بن_, лушу_, ciąg_, --,
   {{0xd00621a0,0x27150019,0x61e900a8,0x35f800d1}},	//   _ول_, ền_, vqel, ارند_,
   {{0x260602b4,0x64980382,0x00000000,0x00000000}},	//   सीबी_, лтър_, --, --,
   {{0x63ad11d7,0x091a0083,0x320d1505,0x7dc0cc95}},	//   čano, ন্দু_, tsey_, tösk,
   {{0x998001ba,0x6375002a,0x161c00ab,0x417501df}},	//   stiť_, _sáns, _नियर_, لادس,
   {{0x6375024e,0x217504de,0x320dcc96,0x59c5018d}},	//   _páns, руир, rsey_, वतिर,
   {{0xd7a900a1,0xe7a90ed1,0x00000000,0x00000000}},	//   _कदाच, _कदाप, --, --,
   {{0x20188e32,0x62352374,0x320d0298,0xa3cc0963}},	//   ária_, _веду, psey_, _शीप_,
   {{0x59c529ad,0x3984013c,0xde3600d8,0xbb1b0139}},	//   वतार, _lösa_, шэнь, _plîn,
   {{0x8cb10461,0xe2c800d4,0x00000000,0x00000000}},	//   _आँखो, _слід_, --, --,
   {{0x1d073c29,0x6da30610,0x412600d4,0xeb9a5fec}},	//   реси_, цира, _тощо_, вив_,
   {{0x237fcc97,0x2bbf0084,0x6fb30037,0xdca301e0}},	//   nkuj_, ्षगा, _وموا, іати,
   {{0x1d1a0eb1,0x6da602ce,0x0906002d,0x00000000}},	// [fe00] _июнь_, _випа, ипан, --,
   {{0x9f5f04ca,0xe8f7748e,0x00000000,0x00000000}},	//   rstå_, илу_, --, --,
   {{0xd11600a5,0xa6e6002d,0x00000000,0x00000000}},	//   שקעה_, ажел, --, --,
   {{0xf1b9a1d1,0x7c3e003c,0x257900f8,0xfbdf00e2}},	//   kušo_, _ippr, _mèlu_, _giê_,
   {{0xf1b90228,0x00000000,0x00000000,0x00000000}},	//   jušo_, --, --, --,
   {{0x5e5702b5,0x7b3e0035,0x61e40037,0x00000000}},	//   יינע_, _dłuż, _éili, --,
   {{0x98a305d2,0xe4b800d8,0x18a35a80,0x3a32cc98}},	//   _дире, ылкі_, _дарм, ltyp_,
   {{0xd3780a78,0xea000028,0xfaff053e,0x236d0055}},	//   _kući_, _luật_, _hoër_, gjej_,
   {{0x68e9002d,0xe3af00b2,0x056622a9,0x3a320110}},	//   _şedi, برو_, _кван, ntyp_,
   {{0x7c3e02ce,0x637c000d,0xd3780207,0x00000000}},	//   _oppr, _méni, _mući_, --,
   {{0x049601c8,0x637c5b69,0x00000000,0x00000000}},	//   _траў, _léni, --, --,
   {{0x63a4245d,0x1df90733,0x8af00095,0xa2da0518}},	//   čins, лемы_, ndəd, _पृथ्,
   {{0x7c3e3104,0x6f1600e9,0x3ead0055,0x98b1005f}},	//   _appr, _ddyc, çet_, _fazė_,
   {{0x6f160035,0x2d850035,0x127b0070,0x61ed0079}},	//   _edyc, óle_, _באדע, _éala,
   {{0x25b90037,0x3cec0097,0xdcfe013a,0xd0f700a5}},	//   _ísle_, _živý_, _ampē, _דמות_,
   {{0x443ecc99,0xdb0400f7,0xdb23cc9a,0x637c00f7}},	//   _mpt_, nniè, _örül, _béni,
   {{0x637c002a,0x3a320110,0x00000000,0x00000000}},	// [fe10] _céni, gtyp_, --, --,
   {{0x637c00bf,0x2907cc9b,0xdebc00a5,0xd7fb08ce}},	//   _déni, úna_, _במחל, вуд_,
   {{0x6f160297,0x443e54a9,0x7b3e004e,0xa3c80e04}},	//   _ydyc, _npt_, _służ, ोगा_,
   {{0x30d902b5,0x60d902b5,0x637ccc9c,0x10370070}},	//   אַנע, אַנג, _féni, שטאם_,
   {{0x98a706a8,0xf7702087,0xbb3a02b5,0x637c7620}},	//   ını_, بال_, _גערי, _géni,
   {{0x99850082,0xd90f07e4,0x00000000,0x00000000}},	//   _السو, _آیا_, --, --,
   {{0x645a044d,0xaadb045c,0x637c00a2,0xd7fb0fb4}},	//   _crti, _मृतक, _zéni, _југ_,
   {{0x645a1dab,0x201e0207,0x00000000,0x00000000}},	//   _drti, drti_, --, --,
   {{0x645c0093,0x645a1585,0xd24e381f,0xe7eb0722}},	//   _árin, _erti, فني_, _जूता_,
   {{0x05740180,0x443e01a5,0x237fcc9d,0x7e7dcc9e}},	//   _والد, _fpt_, skuj_, dysp,
   {{0x200302d0,0x201e0009,0xfbc70355,0x00000000}},	//   èji_, grti_, लताम, --,
   {{0x083a0070,0x00000000,0x00000000,0x00000000}},	//   נערל, --, --, --,
   {{0x201ecc9f,0x443e012f,0xf38c0070,0xddc40395}},	//   arti_, _zpt_, _בראָ, _criş,
   {{0x61fb431f,0xa3e60084,0xea0000e2,0xd256011d}},	//   mpul, _यूँ_, _quật_, _לשנה_,
   {{0x7ff506ca,0x673b01a8,0xddc4027d,0x6ff502e7}},	//   _استا, _obuj, _eriş, _استط,
   {{0x637c0640,0x7bcf0211,0xddc40160,0xeb9708ce}},	//   _péni, _chcu, _friş, бис_,
   {{0xe80a009a,0x5f761328,0x61fbcca0,0x00000000}},	// [fe20] हीना_, _ناکر, npul, --,
   {{0x186a0500,0xbd460833,0x673b4583,0xd3780506}},	//   лази_, _اندي, _abuj, _vući_,
   {{0x63ad068b,0x7c3e0cba,0x6e260d6c,0xeb9a05a1}},	//   čanj, _uppr, lukb, _бин_,
   {{0xdc3b02b5,0xcb6a709a,0xd70a0ea7,0x765b8420}},	//   _געטר, _саме_, унде_, _bruy,
   {{0x941201c2,0x765b01f7,0xa4f8006c,0x8af000a8}},	//   əcək_, _cruy, لکار_, rdəd,
   {{0x8607004f,0x645a02a7,0x7d0ecca1,0x673b0103}},	//   حقوق_, _prti, nabs, _ebuj,
   {{0x7e7d0067,0x00000000,0x00000000,0x00000000}},	//   zysp, --, --, --,
   {{0x645a9ee9,0x7d0e3eb7,0x799e0054,0x9378002d}},	//   _vrti, habs, lipw, рбит_,
   {{0xdb041010,0xa68601c8,0x7d0ecca2,0x61fb85f9}},	//   rniè, _улад, kabs, gpul,
   {{0x2018051b,0x21660525,0x301454d6,0x64a60948}},	//   ário_, стиг, одор, _лаза,
   {{0x64c600e0,0xc32a004f,0xdb0f006c,0x645a8b46}},	//   _ايال, _مكان_, ődés, _urti,
   {{0x2d9acca3,0x7e7d54aa,0x3a2042d1,0x00000000}},	//   _ampe_, tysp, krip_, --,
   {{0x6ff30139,0x00000000,0x00000000,0x00000000}},	//   _răce, --, --, --,
   {{0x290acca4,0x291c006c,0xc6930317,0x7bc4708c}},	//   _neba_, óval_, לאר_, eliu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc43a11,0x6e26012f,0xce6b00ed,0x637c0051}},	//   gliu, bukb, _брод_, _eénv,
   {{0x9999125e,0x290a00cb,0x3a20cca5,0x6f0f027a}},	// [fe30] акат_, _beba_, grip_, macc,
   {{0x3f89006f,0x6f0fcca6,0x290acca7,0x7bc4cca8}},	//   _hlau_, lacc, _ceba_, aliu,
   {{0x290aaf46,0x7bc4004b,0x6d47cca9,0x260608b6}},	//   _deba_, bliu, meja, सीसी_,
   {{0x6f0fccaa,0xd3780a78,0x5fc92f41,0x6d47ccab}},	//   nacc, _kuću_, रतिल, leja,
   {{0xf770500b,0x3669095d,0x2d830051,0x6bd700fd}},	//   عام_, рало_, okje_, _پتھر,
   {{0xce380122,0x9f4800da,0x6fe801c0,0xdb1600f7}},	//   צאות_, _punë_, _těch, voyé,
   {{0x290101cb,0x25fd0b4d,0xf8bf05f8,0xa2d600b4}},	//   mbha_, रीजी_, _्रिय, मेस्,
   {{0x765b00e8,0x69c5a243,0x7dc0152c,0x6d5500d7}},	//   _truy, llhe, löst, hdza,
   {{0x6f0f3d46,0x64581de4,0xe6671645,0xe78400af}},	//   dacc, avvi, _утво, _эуро,
   {{0x61fbccac,0x6d479cb8,0x2d8301e4,0x7dc02f06}},	//   rpul, jeja, jkje_, nöst,
   {{0x6f0fccad,0x3f899847,0x6d47ccae,0xd1380067}},	//   facc, _blau_, deja, wiąc_,
   {{0x6f0f0036,0x4427c216,0x3f8912c3,0x2d8301e4}},	//   gacc, mun_, _clau_, ekje_,
   {{0x4427ccaf,0x63bbccb0,0x3f89006d,0x63a9ccb1}},	//   lun_, moun, _dlau_, mnen,
   {{0x6d47007c,0x63bbccb2,0x63a9ccb3,0x637c000d}},	//   geja, loun, lnen, _dénu,
   {{0x4427ccb4,0xfce3036e,0x63a92ccd,0x3b000095}},	//   nun_, доро, onen, tbiq_,
   {{0x61eb176a,0x63a95f71,0x6f0f027a,0xbea6ccb5}},	//   _kugl, nnen, cacc, _майк,
   {{0x44274150,0x61ebccb6,0x7bc400c7,0x6d477091}},	// [fe40] hun_, _jugl, rliu, beja,
   {{0x4427ccb7,0x6441213d,0x61e30069,0x63a9033b}},	//   kun_, _opli, _jinl, hnen,
   {{0x4427ccb8,0x61eb0133,0x61e3ccb9,0x7bc400c7}},	//   jun_, _lugl, _minl, pliu,
   {{0xe73a5514,0x6b8dccba,0x442763c0,0x63a9ccbb}},	//   ред_, chag, dun_, jnen,
   {{0x63bb333f,0x61eb04d9,0x63a901ba,0x290a01ba}},	//   doun, _nugl, dnen, _teba_,
   {{0xa2da463f,0x4427ccbc,0x8c4301d6,0xdb1d01cb}},	//   _पृष्, fun_, ışve, _aksè,
   {{0x61eb00fb,0x69b9112b,0x442735f9,0x7dc0ccbd}},	//   _augl, ्तरी, gun_, löss,
   {{0x63a9ccbe,0x2fc001e8,0x63bb3762,0x6b84ccbf}},	//   gnen, _nkig_, goun, nkig,
   {{0xfbd30122,0x6f0f38c0,0x7dc0ccc0,0xb6a300d4}},	//   ותה_, vacc, nöss, _житл,
   {{0xc05a00d8,0x61eb9b5e,0xba9b1804,0x00000000}},	//   аім_, _dugl, יספי, --,
   {{0x6f0f01d3,0x4427ccc1,0x61e30d6f,0x6b849e4b}},	//   tacc, cun_, _dinl, kkig,
   {{0x61eb76e6,0x63bbccc2,0x91e602ad,0x61e3345c}},	//   _fugl, coun, _доде, _einl,
   {{0x6d47ccc3,0x61eb286f,0xb7db00a5,0xa3b70127}},	//   teja, _gugl, יקטי, चकर_,
   {{0x3cdc018d,0x6f0fccc4,0x2d830051,0x26c40036}},	//   _गृहे_, sacc, ukje_, _mymo_,
   {{0xfe6e09b9,0x672baac7,0x6b8dccc5,0x2d83b901}},	//   نگی_, yggj, thag, rkje_,
   {{0x63a02276,0x6d477197,0x8e152d4d,0x6b84043d}},	//   nimn, seja, _едиц, gkig,
   {{0x4427ccc6,0x6d47ccc7,0x61e31505,0x6ce71645}},	// [fe50] zun_, peja, _yinl, _міне,
   {{0x63ad0936,0x4427ccc8,0x63a9920b,0x6b8dccc9}},	//   čani, yun_, znen, shag,
   {{0x7dc0315b,0x63a0b862,0x2366044d,0x2901006b}},	//   röst, kimn, _onoj_, rbha_,
   {{0x4427ccca,0x63a000d7,0x637c01ef,0x6b8419ee}},	//   vun_, jimn, _méns, ckig,
   {{0x4427cccb,0x64414e48,0x63bb01dd,0x63a9cccc}},	//   wun_, _spli, voun, vnen,
   {{0x6f0dcccd,0x61eb0093,0x62800409,0xa3e6012f}},	//   _leac, _rugl, dymo, पदं_,
   {{0x61eb093d,0x63bbccce,0x63a9016f,0x7985006d}},	//   _sugl, toun, tnen, mkhw,
   {{0x6f0d004a,0x61eb02fb,0x059500d1,0x27e4012f}},	//   _neac, _pugl, _کارگ, _gimn_,
   {{0x4427cccf,0xe299021d,0x26cd0254,0x13060086}},	//   sun_, сап_, _uzeo_, чный_,
   {{0x442706d4,0x6b8401d7,0x63a9ccd0,0x637c002a}},	//   pun_, zkig, snen, _sént,
   {{0x63a91ed1,0x7dc0006c,0x6f0dccd1,0x637c006c}},	//   pnen, zöss, _beac, _pént,
   {{0x66099b78,0x6f0d0037,0xa3c807df,0x61e3099e}},	//   _kwek, _ceac, ोगः_, _winl,
   {{0x6f0d148b,0xee37a601,0x203200b5,0x1e836195}},	//   _deac, пня_, وفیس, елям,
   {{0x66096020,0x23660e46,0xf1b900ea,0x201100b5}},	//   _mwek, _znoj_, kuši_, ázis_,
   {{0xaffe00e8,0x6f0d02a8,0xf1b90029,0x6609001c}},	//   _trướ, _feac, juši_, _lwek,
   {{0xeb973649,0x6f0d648e,0x33f11c98,0x6616010b}},	//   пис_, _geac, _máx_, šyki,
   {{0x6b849de2,0x6b9d0024,0xada62c72,0x00000000}},	// [fe60] rkig, _dmsg, _наил, --,
   {{0x63a0ccd2,0x6b84330b,0x998002a7,0x7dc0ccd3}},	//   zimn, skig, stiž_, röss,
   {{0x98a3ccd4,0x62805ca1,0x66092d69,0xf1b902d4}},	//   нифе, zymo, _awek, guši_,
   {{0x660901a8,0xdb24103b,0x09e614d0,0xc0ac016b}},	//   _bwek, _توحی, _номн, סיאָ,
   {{0x83fc02c4,0xdb0d05ee,0xad9b02d7,0x628000f6}},	//   _mrđe, mlað, spúe, xymo,
   {{0xf1b9029d,0xdb0d008a,0xbbe901cb,0x00000000}},	//   buši_, llað, _دریم_, --,
   {{0x9f590031,0xc44801cb,0x66090a81,0xf99f0260}},	//   ërë_, تیان_, _ewek, _mwèl_,
   {{0x7af66375,0x66090260,0xa7a700af,0xa3cc0067}},	//   ncyt, _fwek, _екса_, _शीश_,
   {{0x6f0d809f,0x63a0ccd5,0xbebb01f4,0x6609073a}},	//   _reac, rimn, ngët, _gwek,
   {{0x6f0d41e3,0xb603000c,0x59be065f,0x637c01dd}},	//   _seac, ášen, ्तिर, _péns,
   {{0x6568ccd6,0x6f0d9346,0x628000e9,0x6ff300af}},	//   _indh, _peac, symo, _păca,
   {{0xfaff01f4,0x657a8541,0x637c2fba,0x00000000}},	//   _anën_, _hoth, _véns, --,
   {{0x59be1bc6,0x657a00d1,0x6f0d0395,0x51182fb8}},	//   ्तार, _koth, _veac, _долю_,
   {{0xd12f0118,0x637c01ef,0x6b9d0051,0x657a0103}},	//   _ممه_, _téns, _smsg, _joth,
   {{0x6f0d59d2,0x657a6512,0x215727f6,0x00000000}},	//   _teac, _moth, _رجوع_, --,
   {{0x09c500e7,0x8bc4052c,0xf1b9ccd7,0x657a290f}},	//   वत्य, есуд, vuši_, _loth,
   {{0x2b490874,0xb5fd0bc6,0xadb516b8,0x656800e0}},	// [fe70] reac_, _krše, _обиш, _ondh,
   {{0x657a00a5,0x3a2900d7,0xba746f4e,0x61ef002a}},	//   _noth, ruap_, راقت, ícli,
   {{0xdb0d008a,0x3a29046a,0x4735ccd8,0xa3cc0099}},	//   blað, suap_, днес, ळता_,
   {{0x656800d1,0xb9040243,0xa3cc00b4,0x6d57094c}},	//   _andh, _पृ_, _शील_, _haxa,
   {{0xe6180210,0xa3c00d1f,0x6d57ad74,0xcd340df3}},	//   зді_, ंकन_, _kaxa, _غریب,
   {{0x657a1093,0x33f101dd,0xf1b96f67,0x09e400d8}},	//   _coth, _páx_, puši_, _поўн,
   {{0x6d570282,0x657accd9,0x00000000,0x00000000}},	//   _maxa, _doth, --, --,
   {{0xe1f94684,0x27fc01ba,0x656800f8,0x2913a358}},	//   оги_, ívne_, _endh, laxa_,
   {{0x6d5705c9,0x66090054,0x657a0315,0x00000000}},	//   _oaxa, _uwek, _foth, --,
   {{0x83fc0009,0x297a0070,0x00000000,0x00000000}},	//   _srđe, ַטרא, --, --,
   {{0x2938016b,0xff260421,0x98b8004b,0xeb9f008c}},	//   לאזן_, ммно, _darė_, _omø_,
   {{0x6375002a,0x6b8300af,0x657a0051,0x3f6a0200}},	//   _lánz, _îngh, _zoth, цимо_,
   {{0x6d5700a8,0xceb401c2,0xa3b8126b,0xf99f0260}},	//   _baxa, _edən_, _عامر_, _pwèl_,
   {{0x2d9e02e9,0xf0b800d1,0x6d570015,0x777b00f6}},	//   òte_, _کاهش_, _caxa, _loux,
   {{0xef1f0463,0xdb0d0093,0xdca60421,0x00000000}},	//   mkün_, tlað, фави, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3320052,0xed5a4c81,0x291301ed,0xf99f0260}},	// [fe80] כון_, _доп_, faxa_, _twèl_,
   {{0xe9d73e0c,0x7769ccda,0x261709f9,0x00000000}},	//   дку_, _anex, _निजी_, --,
   {{0x657accdb,0x2d0a00a1,0x00000000,0x00000000}},	//   _roth, वरील_, --, --,
   {{0x6ff30160,0x00000000,0x00000000,0x00000000}},	//   _lăco, --, --, --,
   {{0x657accdc,0xeb9700af,0x6d5700a8,0x9f4f021d}},	//   _poth, _ция_, _yaxa, _bufê_,
   {{0x29130453,0x77690051,0x6d5701ed,0x6ff30160}},	//   caxa_, _enex, _xaxa, _răcn,
   {{0xb17601a5,0xd46703fa,0xd6d90035,0x9f5f0036}},	//   _nhượ, дије_, _mały_, istò_,
   {{0x44201851,0x7c37027d,0x39583184,0x00000000}},	//   či_, _çarş, _hars_, --,
   {{0x657a12c3,0x07a303fa,0x998901ba,0x9f480392}},	//   _toth, _ратн, stať_, _cuní_,
   {{0x6602ccdd,0x9f5f00a2,0x656800f8,0x00000000}},	//   mpok, mpté_, _undh, --,
   {{0xb5fd0d7e,0x2018ccde,0x6375006c,0x395814f9}},	//   _vrše, éri_, _lány, _mars_,
   {{0x59d00953,0x6d570282,0x39584409,0x6e9518ea}},	//   _तीसर, _saxa, _lars_, еиму,
   {{0x6d5701dd,0x6d40003a,0x660201d7,0xdb0600c3}},	//   _paxa, đman, npok, _ykkö,
   {{0xea0000e8,0x39580c47,0xd6d9004e,0x2cfb0e6f}},	//   _xuất_, _nars_, _cały_, ्रेल_,
   {{0xb5fd0207,0xe0d4016b,0x00000000,0x00000000}},	//   _kršc, _אײַ_, --, --,
   {{0x69d4043b,0x213e8ecf,0x395811cb,0x2b42021d}},	//   _बीबी, lfth_, _aars_, _cbkc_,
   {{0x3958ccdf,0xbebb0055,0x92ac0831,0x7769035f}},	// [fe90] _bars_, rgës, _গরু_, _rnex,
   {{0xc4c4040d,0x6602024e,0x395800a5,0xe29f003e}},	//   _نے_, dpok, _cars_, úði_,
   {{0x7d152c7c,0x3958cce0,0x29130510,0x00000000}},	//   mazs, _dars_, raxa_, --,
   {{0xea0001a5,0x8af00095,0x39580f00,0x00000000}},	//   _suất_, ndəl, _ears_, --,
   {{0x776901a5,0x6602011e,0x2b590079,0x3958cce1}},	//   _vnex, gpok, _iasc_, _fars_,
   {{0x3958cce2,0x6fd600a0,0xea000023,0x00000000}},	//   _gars_, máce, _quất_, --,
   {{0xf99200a5,0x22460069,0x291101a3,0x6fd6cce3}},	//   _גרם_, _apok_, _ieza_, láce,
   {{0x58d40f92,0x291104fb,0x7769cce4,0x00000000}},	//   _рост, _heza_, _unex, --,
   {{0xb5c90332,0xb5fd0009,0x2911cce5,0x11e5002d}},	//   _فورم_, _dršc, _keza_, нжим,
   {{0xf99202b5,0xb1760019,0x3cfb0035,0x29110881}},	//   ָרט_, _phượ, ्रों_, _jeza_,
   {{0x2cfb0953,0x2911b595,0x28a50026,0x224639ab}},	//   ्रैल_, _meza_, _गेमि, _epok_,
   {{0x63ad0672,0x2b59004f,0xdef901c8,0xf8b202b5}},	//   čans, _nasc_, дыё_, רשט_,
   {{0xe28ecce6,0x8db601e0,0x00000000,0x00000000}},	//   _са_, есві, --, --,
   {{0x2911070b,0xc6920317,0xef1f006c,0x442709a6}},	//   _neza_, ראך_, lkül_, orn_,
   {{0x2054002d,0x8fa61578,0x8c432374,0x2b590310}},	//   _атыр, _паке, лере, _basc_,
   {{0xffd601c8,0x4427cce7,0x2b590392,0xf1b92acc}},	//   _яўля, irn_, _casc_, rušu_,
   {{0xa3c0009a,0x2911cce8,0x44273879,0xeab707bc}},	// [fea0] ंकत_, _beza_, hrn_, ейт_,
   {{0x2911027d,0x3958013b,0x00000000,0x00000000}},	//   _ceza_, _qars_, --, --,
   {{0x3958cce9,0x2911ccea,0x661bcceb,0x6d5c0051}},	//   _vars_, _deza_, _avuk, mdra,
   {{0x6d5c7710,0x3958a81c,0x6fd601ef,0x29070093}},	//   ldra, _wars_, báce, ðnar_,
   {{0xe5c624b6,0xb8f600c8,0x7bc6ccec,0x442701ae}},	//   нско, _হল_, _ikku, ern_,
   {{0x6d4eb603,0x7e6400f8,0x00000000,0x00000000}},	//   neba, _mrip, --, --,
   {{0x68460086,0x7c2e8f22,0x66020e7c,0x6d5ccced}},	//   _янва, nubr, spok, idra,
   {{0x6d4e1389,0xddcd002d,0x2b4000cc,0x7e64be1b}},	//   heba, _oraş, nfic_, _orip,
   {{0x4427ccee,0x6d5cb091,0xb5fd00cd,0x29110027}},	//   arn_, kdra, _vršc, _yeza_,
   {{0x6d5cccef,0x6d4eccf0,0x3a37011d,0x1a9b016b}},	//   jdra, jeba, ערים_, פייע,
   {{0x7bc659a0,0xddcd0092,0x6d5c2c68,0x68fc00d7}},	//   _okku, _araş, ddra, _mfrd,
   {{0x671000c0,0xddcd002d,0x6d5cccf1,0x7c2e0207}},	//   ारिक_, _braş, edra, dubr,
   {{0x63a22922,0x442e5afd,0x443cccf2,0xb5fd0124}},	//   _imon, luf_, ltv_, _krša,
   {{0x63a2006f,0x7bc6a04b,0x6d4eccf3,0x6d5cccf4}},	//   _hmon, _akku, geba, gdra,
   {{0x3ce506d7,0x443cccf5,0xb5fd003a,0x7e643f1a}},	//   älv_, ntv_, _mrša, _erip,
   {{0xa3c01db6,0x5ba41a6d,0x29110359,0xa3c200b1}},	//   ंकि_, груз, _seza_, ृति_,
   {{0x6d4e0464,0x2911ccf6,0xb5fd0009,0x61ea2443}},	// [feb0] beba, _peza_, _orša, _kifl,
   {{0x6d4e0139,0x442e7729,0x63a2011e,0x7bc60273}},	//   ceba, kuf_, _lmon, _ekku,
   {{0x29110274,0x63a2ccf7,0xa3c04f52,0x7c2e1111}},	//   _veza_, _omon, ंका_, cubr,
   {{0x443cccf8,0x291108c7,0x8c1a011d,0x6a150421}},	//   dtv_, _weza_, _קורי, _имму,
   {{0x7bcdccf9,0x8d7403fc,0x64483b48,0x61ea009e}},	//   mlau, _شایا, _apdi, _oifl,
   {{0x64a54651,0x63a2ccfa,0x201c027a,0x83fc011c}},	//   кала, _amon, _ovvi_, _srđa,
   {{0x7bc6008a,0x58d40bfc,0x69c70055,0x443c7771}},	//   _ykku, _борт, _ikje, gtv_,
   {{0xc245395b,0x7bcdccfb,0x4427ccfc,0xf3f100e2}},	//   вник, nlau, rrn_, _vụ_,
   {{0x661b03a4,0x6d4501a6,0x24890029,0x7bcd102f}},	//   _uvuk, _obha, ņam_, ilau,
   {{0x443cccfd,0x63a2ccfe,0x7bcdccff,0x6d4e01a3}},	//   btv_, _emon, hlau, xeba,
   {{0x7bcdcd00,0xe0cf0083,0x6d4e0a8c,0x61ea00e9}},	//   klau, রশ্ন, veba, _difl,
   {{0x7e64501f,0x6d45cd01,0x8fa601d3,0x6e3d8dcf}},	//   _prip, _abha, таме, ftsb,
   {{0x277602b5,0x6d5ccd02,0x6d450118,0x7bcdcd03}},	//   דערש_, tdra, _bbha, dlau,
   {{0x63a200d8,0x7e640051,0x6d5ccd04,0x61ea95e1}},	//   _zmon, _vrip, udra, _gifl,
   {{0x6d4ecd05,0x6d5c5b6b,0x6e3d06e1,0x711a1804}},	//   reba, rdra, atsb, _חוצפ,
   {{0x7bcdcd06,0x2005cd07,0x398400a6,0x7c2ecd08}},	//   glau, mpli_, _löst_, rubr,
   {{0x6f091a71,0x6d5c8877,0x6a830f27,0x20050381}},	// [fec0] ñece, pdra, алта, lpli_,
   {{0xa2d600b4,0x7afd008d,0x660002a7,0xaa430036}},	//   मेट्, _efst, _rtmk, рефл,
   {{0x200502e9,0x8af00095,0x38cb006c,0x7bcdcd09}},	//   npli_, ndək, وامی_, blau,
   {{0xe7d00083,0x7bcd1599,0x3a298847,0x00000000}},	//   িদ্য, clau, brap_, --,
   {{0x442e0ac8,0x63a20024,0xb5fd07c0,0x00000000}},	//   wuf_, _rmon, _prša, --,
   {{0xdb0d02e1,0x63a2cd0a,0x443ccd0b,0xbddb00a2}},	//   nnaî, _smon, ttv_, rtèg,
   {{0xb5fd0c99,0x61ea65be,0x7f860183,0xdb040183}},	//   _vrša, _rifl, _hóqu, gniç,
   {{0x442ecd0c,0x443c0149,0x61ea021e,0x00000000}},	//   ruf_, rtv_, _sifl, --,
   {{0x442e05ca,0x443ccd0d,0xd251006c,0x61ea98a6}},	//   suf_, stv_, منٹ_, _pifl,
   {{0xceb40095,0x69c302c6,0x443ccd0e,0xb5fd0124}},	//   _edək_, čneg, ptv_, _kršn,
   {{0xb42518dd,0x442e022e,0x61ea0160,0x00000000}},	//   _معنو, quf_, _vifl, --,
   {{0x331a0357,0x69d402e4,0x838300c3,0x63a2034d}},	//   _آزاد_, _बीसी, _выше, _umon,
   {{0x61ea38a0,0xa2da0b35,0x7bcdcd0f,0xdd910037}},	//   _tifl, _पृच्, vlau, موح_,
   {{0x6e3d2c9a,0x2ed30026,0x3984017b,0x00000000}},	//   rtsb, _सरीत, _möss_, --,
   {{0x3a293c8f,0x7bcd0093,0xebc70274,0x39840282}},	//   wrap_, tlau, вљан, _löss_,
   {{0x3a29cd10,0xf1b90254,0x33f80453,0x69c702ce}},	//   trap_, vrši_, _méx_, _skje,
   {{0x7bcdcd11,0x7d02b695,0x6d4100be,0x00000000}},	// [fed0] rlau, _şose, õlas, --,
   {{0x7bcd01c8,0x6d4519fd,0x6d4101a6,0x5d553417}},	//   slau, _ubha, òlad, _скот,
   {{0xa2c90311,0x398401ff,0x76499b74,0x7bcd7605}},	//   _हुन्, _röst_, _spey, plau,
   {{0x2d8101ae,0x7e6252c2,0x6b96012f,0xb8eb07b5}},	//   _hohe_, _šopi, chyg, _लड_,
   {{0x2d81cd12,0x8af0013b,0x00000000,0x00000000}},	//   _kohe_, zdək, --, --,
   {{0xc9871126,0x6b8d0210,0x69c70044,0x00000000}},	//   _руми, lkag, _ukje, --,
   {{0x03a5103e,0x69c5cd13,0x2d810069,0x80d1021a}},	//   лико, mohe, _mohe_, _हरें,
   {{0x2fc90189,0x69c5c64f,0xdb040183,0x2d8100b9}},	//   _nkag_, lohe, rniç, _lohe_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c500da,0x27ed00e2,0x60090086,0x93bc0160}},	//   nohe, _hien_, нном_, _avăd,
   {{0x27ed048c,0x6b8dcd14,0x05840369,0xf3350079}},	//   _kien_, kkag, _тутм, _مفاج,
   {{0x27ed0484,0x69c5cd15,0x8af0013b,0x6b8d0223}},	//   _jien_, hohe, rdək, jkag,
   {{0x63a94943,0x61457bcb,0xa3c00380,0x69c500da}},	//   mien, _бела, ंकर_, kohe,
   {{0x27edcd16,0x69c500da,0x20050069,0x621a016b}},	//   _lien_, johe, ppli_, _טונק,
   {{0x6b96001e,0xf1cf0026,0x69c5cd17,0x62890159}},	//   thyg, _सीएन, dohe, lyeo,
   {{0x09be2095,0x6b8d18ad,0x27ed1e9d,0x7f8602d7}},	//   ्त्य, gkag, _nien_, _póqu,
   {{0x3996054e,0x629bcd18,0xb5fd00d5,0x69c501e9}},	// [fee0] _læse_, nzuo, _sršn, fohe,
   {{0x63a9cd19,0x7a470080,0x69c501f4,0x6b8d41c7}},	//   hien, dītā, gohe, akag,
   {{0x27edcd1a,0x6f160602,0x63a9cd1b,0x6bd60206}},	//   _bien_, _keyc, kien, _متحر,
   {{0x63a9b798,0x27edcd1c,0x6d5ecd1d,0x6b8dcd1e}},	//   jien, _cien_, _hapa, ckag,
   {{0x6d5ecd1f,0x27edcd20,0x63a9cd21,0xca750d8a}},	//   _kapa, _dien_, dien, _куры,
   {{0x63a909a6,0x6b83002d,0x8e570319,0x9f9900f7}},	//   eien, _îngr, טינג_, réé_,
   {{0x69dc02bf,0x6d5ecd22,0x63a9cd23,0xa3c00066}},	//   _ihre, _mapa, fien, ंकल_,
   {{0x291acd24,0x6d5ecd25,0x27ed2bdf,0xb5fd0009}},	//   lapa_, _lapa, _gien_, _kršl,
   {{0x69dc01ef,0x171b0070,0x51861f14,0xbddb0176}},	//   _khre, _רומע, гуна, ntèc,
   {{0x6d5ecd26,0x27edcd27,0x291a00bf,0x63a9cd28}},	//   _napa, _zien_, napa_, aien,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645acd29,0x63a9cd2a,0x69c500da,0x291a91f7}},	//   _isti, cien, zohe, hapa_,
   {{0x6d5e06d4,0x291acd2b,0x69dccd2c,0x69c510a2}},	//   _bapa, kapa_, _ohre, yohe,
   {{0xf99f02e9,0xf23702b8,0x69c50031,0x69dc016e}},	//   _jwèt_, _ערוץ_, xohe, _nhre,
   {{0x6d5e9dac,0x6fd6024e,0x291acd2d,0xee3f0314}},	//   _dapa, mácn, dapa_, stý_,
   {{0x9b584a7c,0x6d5e0159,0xb5fd0881,0x7c280079}},	//   лист_, _eapa, _bršl, ádra,
   {{0x27ed02e1,0x69c501d2,0xa2aa02e4,0x69dc009c}},	// [fef0] _rien_, tohe, _जेम्, _bhre,
   {{0x7f5f0669,0x27ed250a,0x69dccd2e,0x63a9cd2f}},	//   _haqq, _sien_, _chre, zien,
   {{0x69c5cb72,0x69dc09c3,0x629b07e5,0x201ecd30}},	//   rohe, _dhre, zzuo, nsti_,
   {{0x69c500da,0x201ecd03,0x4b7902b5,0x7a470029}},	//   sohe, isti_, _סאָו, tītā,
   {{0x63a9cd31,0x6d5e0723,0x645acd32,0x27edcd33}},	//   vien, _yapa, _asti, _vien_,
   {{0x201e4953,0x63a9006a,0x69dc09c3,0x27ed01ae}},	//   ksti_, wien, _ghre, _wien_,
   {{0x27edcd34,0x63a9cd35,0x7a470080,0x7bdd012f}},	//   _tien_, tien, sītā, _khsu,
   {{0x7f5f007a,0x637c006c,0x63a90183,0x629b01a3}},	//   _naqq, _kény, uien, tzuo,
   {{0xe2998038,0x201ecd36,0xa5f90217,0xf99f021e}},	//   тап_, esti_, _резу_, _fwèt_,
   {{0x63a9cd37,0xd49b0202,0x645a0176,0xf1cf0035}},	//   sien, _пре_, _fsti, _सीखन,
   {{0x637c006c,0x201ecd38,0x645a0282,0x00000000}},	//   _lény, gsti_, _gsti, --,
   {{0x6d5e640d,0xdee633c9,0xe47a0070,0x800a00b5}},	//   _sapa, иони, _ברעכ, کریہ_,
   {{0x2d98004f,0x6f0900de,0x201e0086,0x291ac290}},	//   thre_, ñeca, asti_, yapa_,
   {{0xc0e517e3,0xf2d20122,0xf1b900cb,0x6d5e00a8}},	//   _колк, _ועד_, gršt_, _qapa,
   {{0x6d5e03ad,0xfce62515,0x4032052c,0x99890187}},	//   _vapa, рово, _дејс, mpaň_,
   {{0x6d5e000e,0x291a000e,0xb5fd3716,0x00000000}},	//   _wapa, wapa_, _pršl, --,
   {{0x6d5ecd39,0x637c0332,0x291acd3a,0x69dccd3b}},	// [ff00] _tapa, _pénz, tapa_, _phre,
   {{0x9d4612dc,0xdcfe18a8,0xa2dd0461,0xb5fd0009}},	//   _теод, _kopč, _परन्, _vršl,
   {{0x291a120d,0x7d1ccd3c,0x765b0027,0x48d40033}},	//   rapa_, mars, _asuy, ়শ্র,
   {{0x637c006c,0xf7467352,0x291a1872,0x80ac0070}},	//   _fény, редо, sapa_, עסאַ,
   {{0x69dccd3d,0xf99f0107,0x44d500cc,0x00000000}},	//   _thre, _pwèt_, _á_, --,
   {{0x7d1c78d7,0xceb300a5,0x23ba00ea,0x201ecd3e}},	//   nars, חיד_, dīja_, ysti_,
   {{0x9f4f0176,0x7d1c002a,0xe73a00af,0x29180160}},	//   _sufí_, iars, _иев_, _iera_,
   {{0x7d1ccd3f,0x2918cd40,0x00000000,0x00000000}},	//   hars, _hera_, --, --,
   {{0x3a20cd41,0x2918cd42,0x1dc62135,0x179b0317}},	//   nsip_, _kera_, लकात, _סימב,
   {{0x64a69f4f,0x7f5f7838,0x7d1ccd43,0x3a2000a7}},	//   _каза, _saqq, jars, isip_,
   {{0x7d1c03ab,0x645acd44,0x2918cd45,0xf487006c}},	//   dars, _usti, _mera_, _پالی,
   {{0x29184460,0x27f8023a,0x00000000,0x00000000}},	//   _lera_, _murn_, --, --,
   {{0x6d8b0095,0x7d1c104f,0x7642cd46,0xd01000b5}},	//   _müav, fars, ntoy, _کلب_,
   {{0x7d1c12bd,0x29183da5,0xdb040037,0x32061296}},	//   gars, _nera_, cniú, _itoy_,
   {{0x5ba70409,0xb057004f,0x7f5f7b11,0xe6d3164f}},	//   араз, _نشيط_, _taqq, _तर्ज,
   {{0x5bb80086,0xa2dd2e99,0x386d0355,0x271500ab}},	//   ался_, _परम्, _čer_, _ढ़ेर_,
   {{0xa90715dc,0x6f1dcd47,0x2918cd48,0xdad90274}},	// [ff10] لبان, masc, _bera_, умац_,
   {{0x6f1dcd49,0x7d1ccd4a,0xd13800d8,0xfaff0031}},	//   lasc, cars, ngą_, _anët_,
   {{0x6d55cd4b,0x29185fcf,0x6ff30043,0xfbd0006c}},	//   meza, _dera_, _făcu, ستہ_,
   {{0x6f1dcd4c,0x6d552891,0x637c006c,0xf568006c}},	//   nasc, leza, _tény, یمنٹ_,
   {{0x291863fd,0x442e0223,0x6f1d002d,0xf77002e7}},	//   _fera_, erf_, iasc, ظام_,
   {{0x2918a205,0x6d55cd4d,0x00000000,0x00000000}},	//   _gera_, neza, --, --,
   {{0xf8e50b52,0x88e50b52,0xb8950082,0xe8df0028}},	//   _প্রথ, _প্রক, _الأع, _trực_,
   {{0x44292209,0x61b100dc,0x7d1ccd4e,0x23ba0029}},	//   ča_, ीक्ष, zars, tīja_,
   {{0x6d55cd4f,0x6f1d0443,0x957c004e,0x7d1ccd50}},	//   keza, dasc, _piąt, yars,
   {{0x29012d44,0x2a6b00d7,0x2918cd51,0x7d1c8165}},	//   ncha_, _mrcb_, _xera_, xars,
   {{0x6f1dcd52,0x4fea0009,0x6d558e28,0x69ba00b4}},	//   fasc, лмон_, deza, ्वती,
   {{0x6f1dcd53,0x7d1ccd54,0xd498002d,0x6441013b}},	//   gasc, wars, _тру_, _iqli,
   {{0x6443cd55,0x656100b8,0x61fb1505,0x6e290355}},	//   ltni, _kalh, qqul, šebn,
   {{0xdcfe9035,0x6d552107,0x7e620009,0xdd920037}},	//   _topč, geza, _šops, أوس_,
   {{0x64430688,0x7d1ccd56,0xab2a2896,0x6561cd57}},	//   ntni, rars, лова_, _malh,
   {{0x2918cd58,0xa3c906fe,0x7d1ccd59,0xfbdf0019}},	//   _sera_, ोति_, sars, _chê_,
   {{0xa92615d6,0x291800a7,0xb5fd0129,0x6d553973}},	// [ff20] йдал, _pera_, _dršk, beza,
   {{0xf2d200c2,0x6443026a,0x3a20012f,0x8af00095}},	//   לען_, ktni, rsip_, ddət,
   {{0x29182129,0xa3ca1ea9,0xa3c9073f,0xa2c9017f}},	//   _vera_, लकम_, ोता_, _हुस्,
   {{0x2901cd5a,0x2918cd5b,0x76420248,0xbddbcd5c}},	//   acha_, _wera_, ttoy, ntèn,
   {{0x2918cd5d,0x6443cd5e,0x6561cd5f,0x29010088}},	//   _tera_, etni, _balh, bcha_,
   {{0xb996004f,0x7642022e,0x2901cd60,0x6443cd61}},	//   _السب, rtoy, ccha_, ftni,
   {{0x65610dc3,0x764231cf,0x6443035b,0x320602d7}},	//   _dalh, stoy, gtni, _stoy_,
   {{0x6d55cd62,0xf743cd63,0xbebb0055,0x00000000}},	//   zeza, _несо, rgëz, --,
   {{0x656103e6,0x6b860345,0x27e60122,0x6d5570f4}},	//   _falh, _mokg, mmon_, yeza,
   {{0x6f04cd64,0x65610132,0xd138010b,0x6f1dcd65}},	//   _afic, _galh, ugą_, wasc,
   {{0x6d55068b,0x2b8e01ba,0x6f0900de,0x6f1d02b1}},	//   veza, _tých_, ñeco, tasc,
   {{0x46dc29ad,0x8af000a8,0x6d554179,0x00000000}},	//   _बराह, ndəs, weza, --,
   {{0x6f1d004f,0x41e62659,0x7e620009,0x3206010d}},	//   rasc, _ліка, _šopr, _utoy_,
   {{0x27e6cd66,0xd01007f8,0xf99fcd67,0x7c350207}},	//   hmon_, _قلت_, _atèn_, tuzr,
   {{0x6d55cd68,0xfbdf01a5,0x6d470093,0x6f1dcd69}},	//   reza, _phê_, rfja, pasc,
   {{0x6ab402cb,0x27e60009,0x6d5543ce,0x00000000}},	//   ंपूर, jmon_, seza, --,
   {{0x6d550f56,0x2901cd6a,0x7528004e,0x8af000a8}},	// [ff30] peza, tcha_, _oddz, ddəs,
   {{0x7e6dcd6b,0xf99f0107,0x9f990176,0x00000000}},	//   _irap, _etèn_, léà_, --,
   {{0x7e6d5e4e,0x1bf20066,0xfbdf0023,0x1dc600b4}},	//   _hrap, _आंचल_, _thê_, लकरत,
   {{0xbd450987,0x9be40eb9,0x69cecd6c,0x6561cd6d}},	//   _انھي, _ніяк, _ekbe, _salh,
   {{0xbb3a02b5,0xeb3a02b5,0x65610279,0xb5fd177a}},	//   _דערי, _דערש, _palh, _krši,
   {{0x6443cd6e,0x998000a0,0x69ce0345,0x2409272c}},	//   ttni, triť_, _gkbe, анки_,
   {{0x81c30033,0xb5fd0124,0x6ff30139,0xe51a00ab}},	//   ্ষম_, _mrši, _lăcr, _नजरि_,
   {{0x65611ea7,0x02050dee,0x2441cd6f,0x64433587}},	//   _walh, озин, róm_, rtni,
   {{0x0cd60b40,0x59bf012f,0x7e6d0118,0xd17901e0}},	//   _धर्म, ्वपर, _nrap, асні_,
   {{0x6609cd70,0x6d8b0095,0x059502fd,0x6729009f}},	//   _itek, _müas, _بارگ, _hdej,
   {{0x6e240280,0x8af001c2,0xadf30035,0xa2c90803}},	//   _svib, ndər, _इंजन_, _हुर्,
   {{0x35af0243,0xa2aa00a1,0x98b300c7,0x6729007a}},	//   _झगड़, _जेव्, ždės_, _jdej,
   {{0x67290024,0x6fd600d5,0x00000000,0x00000000}},	//   _mdej, láck, --, --,
   {{0x7e6dcd71,0xbddb12c3,0xac0a4bf9,0xa06903e6}},	//   _drap, stèn, инга_, _вака_,
   {{0xa0a50036,0x67297602,0x27e60096,0x7e6dcd72}},	//   _файд, _odej, ymon_, _erap,
   {{0x7e6d5bee,0x6609a92e,0x6729b8a6,0x6f04023c}},	//   _frap, _otek, _ndej, _ufic,
   {{0x44250080,0xeb971558,0x7e6d50ea,0x660901d5}},	// [ff40] _lvl_, цит_, _grap, _ntek,
   {{0x3f820254,0xbddbcd73,0x672902d7,0x6f2400b5}},	//   ljku_, ntèl, _adej, _بڑھن,
   {{0x6609bf97,0x6729035f,0x20cf0ea3,0xfce60377}},	//   _atek, _bdej, _सुमध, _фоно,
   {{0x69ba021a,0x3f8200f4,0x6fca0387,0x5fca01d1}},	//   ्वही, njku_, रविं, रविल,
   {{0x442513dc,0x16a7097c,0x67290024,0x00000000}},	//   _avl_, овци_, _ddej, --,
   {{0x27e6016e,0x69ce01a3,0xa2aa00a9,0x83f80036}},	//   smon_, _ukbe, _जेष्, бекс_,
   {{0x6609cd74,0x6fdd00a2,0x5fca1365,0x00000000}},	//   _etek, héca, रवाल, --,
   {{0x4ade009a,0x248001cc,0x050a0033,0xe7370f6d}},	//   _मराव, ćim_, রণের_, _мес_,
   {{0xef1f0d6f,0xd25000bf,0xc17a00d4,0xf99f0359}},	//   kkür_, رند_, аїн_, _otèl_,
   {{0x7e6d21e7,0x6729164f,0x6fd60097,0x00000000}},	//   _rrap, _zdej, lách, --,
   {{0x7e6d0159,0x9f520359,0x00000000,0x00000000}},	//   _srap, _kiyè_, --, --,
   {{0x7e6dcd75,0xd36f004f,0x9f5202e9,0x2d9acd76}},	//   _prap, _لهم_, _jiyè_, _alpe_,
   {{0x35df0299,0x80ca09a8,0x51860f24,0x442500d5}},	//   _पीड़, _सुरे, _мука, _zvl_,
   {{0x7e6dcd77,0x0dcb4715,0x8af0013b,0x00000000}},	//   _vrap, руми_, ydər, --,
   {{0xfbab1357,0x5f950086,0xb5fd0bc6,0x2bd900b5}},	//   атай_, _никт, _vrši, مارک_,
   {{0x81c30083,0x2d9a00ee,0x00000000,0x00000000}},	//   ্ষণ_, _elpe_, --, --,
   {{0x3a32053e,0x8d870009,0x5a350382,0xb4d7021a}},	// [ff50] gryp_, _дунд, янат, _सर्_,
   {{0xa2dd39f2,0x35df0067,0x89370037,0xadd900af}},	//   _परस्, _पीढ़, تعرا, _ымпу_,
   {{0xa3cacd78,0x2b9c01ba,0x2a6900ab,0x9f520260}},	//   लका_, _síce_, svab_, _biyè_,
   {{0xb8f3007c,0x6fd60187,0xf7730af8,0x00000000}},	//   _हँ_, váck, باط_, --,
   {{0xddc403fa,0x4b7a00a5,0x442500ee,0xdb0d0132}},	//   _hriš, _הארו, _svl_, enaç,
   {{0x2b9c000c,0xce3800a5,0x05a801e0,0x7bcdcd79}},	//   _více_, קאות_, овій_, loau,
   {{0xdb0d0279,0x80ca0bdd,0x9f480a8a,0x00000000}},	//   gnaç, _सुले, _tunø_, --,
   {{0x7bcd0183,0x7dd23d3e,0x77540a7c,0x672936a5}},	//   noau, læst, _оксф, _udej,
   {{0x660904f7,0x3e7200e2,0x461505f5,0xfbd400a5}},	//   _utek, _môtô_, _روار, ותק_,
   {{0x10a53d1a,0x6fd6795c,0xdb1600b5,0x00000000}},	//   зион, máci, rnyé, --,
   {{0x6fd6016f,0xfbbd0355,0x98780506,0x00000000}},	//   láci, ्काम, ršća_, --,
   {{0x09b80b35,0x320d03d0,0x00000000,0x00000000}},	//   _आद्य, ppey_, --, --,
   {{0x6fd6cd7a,0x644b10a5,0x63bb9a51,0x7bcd02d7}},	//   náci, žnič, mnun, doau,
   {{0xddc40bc6,0x661d008d,0x00000000,0x00000000}},	//   _briš, _æsku, --, --,
   {{0x6ab437e8,0x00000000,0x00000000,0x00000000}},	//   ंप्र, --, --, --,
   {{0x63bbcd7b,0x6fd6cd7c,0x501a00a5,0x60dc82a7}},	//   nnun, káci, _פופו, ürme,
   {{0x63bb3695,0xdcfe0139,0x00000000,0x00000000}},	// [ff60] inun, _copă, --, --,
   {{0x63bb02c9,0xddc4cd7d,0x6fd601ba,0x291c2314}},	//   hnun, _friš, dáci, úva_,
   {{0xacfb00a5,0xddc42b26,0x63bb4a12,0x7bc100a2}},	//   _להיכ, _griš, knun, éluc,
   {{0x63bb0484,0x7d1e01d6,0xe73a2aa9,0x6fd60132}},	//   jnun, _heps, сед_, fáci,
   {{0x6fd6cd7e,0x63bb04c9,0x28ac0035,0x7d1e0eba}},	//   gáci, dnun, _टेरि, _keps,
   {{0xe5a3294d,0x2fc00009,0x7d1e0a8a,0x7dd201b4}},	//   ничи, _ljig_, _jeps, mæss,
   {{0x63bbace6,0x81c300c8,0x09e30131,0x65d900d8}},	//   fnun, ্ষা_, _чорн, цьцё_,
   {{0x58bb0122,0x7d1e7f38,0x48e100a1,0xdb0d0a39}},	//   _המלצ, _leps, _करतो_, rnaç,
   {{0x46a306a5,0xdcfc0029,0x6fd60279,0x877b0070}},	//   _затв, nkrē, cáci, _פאמי,
   {{0x63bbcd7f,0x7d1ecd80,0x3f5700cc,0x00000000}},	//   anun, _neps, _ầu_, --,
   {{0xd2500609,0x9f350746,0x6805010b,0x53fa00f8}},	//   رنگ_, мені, _kėda, _طراح_,
   {{0x2d8c06ed,0x67220054,0x00000000,0x00000000}},	//   öden_, naoj, --, --,
   {{0xbddb02e1,0xe8b90ed1,0x4cd60033,0x00000000}},	//   stèm, _आश्च, _দলগু, --,
   {{0xddc42ce5,0xf8be04aa,0x61e30211,0x7d1eb893}},	//   _priš, ्थाय, _ghnl, _ceps,
   {{0x6fd6cd7c,0x28ac09b1,0x7bcdcd81,0x672211e7}},	//   záci, _टेलि, toau, kaoj,
   {{0xddc4003a,0x23cc74d7,0xb5fd0254,0x6b8401e9}},	//   _vriš, ाविद, _kršt, gjig,
   {{0x6fdd0248,0x7bcd02b1,0x00000000,0x00000000}},	// [ff70] léco, roau, --, --,
   {{0x127b02b5,0x59bf0b35,0x213e0122,0x6fd618fa}},	//   זאמע, ्वधर, ngth_, váci,
   {{0x4af91b0a,0x27e4012f,0x23cc052b,0x6fdd000d}},	//   _меню_, _bhmn_, ावाद, néco,
   {{0x6fd64681,0x27e4009e,0x9f5200f8,0x00000000}},	//   táci, _chmn_, _piyé_, --,
   {{0xb8d470a4,0x59bf00b4,0x05740d4f,0x68050409}},	//   _जे_, ्वदर, کاند, _dėda,
   {{0x6fd60038,0x00000000,0x00000000,0x00000000}},	//   ráci, --, --, --,
   {{0xa3e92634,0x26c40183,0x6fd601ef,0xcabf0033}},	//   одка_, _exmo_, sáci, _আরিফ,
   {{0xb5fd0009,0x6fdd000d,0x00000000,0x00000000}},	//   _bršt, déco, --, --,
   {{0x63bbcd82,0x6fdd21a4,0xb5fd1942,0x45d500af}},	//   rnun, técn, _pršu, _жоас,
   {{0x38713e5a,0x59bf2798,0x35b4002d,0xcabf0033}},	//   _krzr_, ्विर, _збур, _আরাফ,
   {{0x7523cd83,0x6aa40036,0x2b9c00ee,0xd49b6299}},	//   manz, zzif, _líca_, _ура_,
   {{0x7d1e01d2,0x7523cd84,0x26140035,0x68ec00a8}},	//   _seps, lanz, नीकी_, ündə,
   {{0x59bf0d91,0x61452294,0xa3ca2188,0x69c364db}},	//   ्वार, _жела, लकर_, čnej,
   {{0x7523cd85,0x61fd0076,0xe9ff0028,0xfce6324a}},	//   nanz, íslu, _hoặc_, дого,
   {{0x8c4305a1,0x9f5d02d0,0x45220033,0xe5020d55}},	//   кере, _ouvè_, _নামক_, रुटि_,
   {{0xee3a089e,0x752301d5,0x4427cd86,0x09c6111b}},	//   _дни_, hanz, isn_, वव्य,
   {{0x75238e43,0x6d4f0093,0x7d1e38f1,0x3167023a}},	// [ff80] kanz, únað, _teps, _kanz_,
   {{0x7e64b924,0x7523cd87,0x8e370070,0x998900cd}},	//   _isip, janz, _קניא_, traš_,
   {{0x75234266,0x395a2d29,0x776601d3,0x661b0371}},	//   danz, reps_, дълж, _awuk,
   {{0x7c3ccd88,0x44270069,0x6d4e0cfc,0x661b0027}},	//   murr, dsn_, lfba, _bwuk,
   {{0x6f091a71,0x7523cd89,0xe5c61073,0x7c3c01d7}},	//   ñeci, fanz, мско, lurr,
   {{0x7523c413,0x61c70066,0x2d9800b5,0xdb0401ef}},	//   ganz, रकोष, nkre_, mniñ,
   {{0x3e85071f,0xd94305a1,0x6d5ccd8a,0x290a021d}},	//   _këtë_, _шери, iera, _ifba_,
   {{0x6d5ccd8b,0x16190084,0xb5fd0124,0x7e640b1a}},	//   hera, _नौकर_, _pršt, _osip,
   {{0x6d5c62c8,0x75230232,0xfd650023,0x7c3c56e7}},	//   kera, banz, _chuồ, hurr,
   {{0x75234266,0x7c3c0291,0x30148d30,0x3cfa0067}},	//   canz, kurr, ндор, ्डों_,
   {{0x6600cd8c,0x7e6491f7,0x130a0086,0x80d60083}},	//   _humk, _asip, _дней_, ডেন্,
   {{0x65682edd,0x7c3ccd8d,0x6600a73e,0x6d4e0e54}},	//   _hadh, durr, _kumk, efba,
   {{0x6d5ccd8e,0x02e20f39,0x65686d8e,0x6720046a}},	//   fera, _परिभ, _kadh, _memj,
   {{0x6d5cc93b,0x316702bf,0x660028ae,0x7019006c}},	//   gera, _ganz_, _mumk, _کروڑ_,
   {{0x6568cd8f,0x0cd400d4,0x80a3026e,0x3da401fd}},	//   _madh, ворю, _لمون, тряб,
   {{0x02e200a1,0x75230054,0x65683991,0x6720cd90}},	//   _पराभ, zanz, _ladh, _nemj,
   {{0x6d5c975a,0x657a0d26,0x443c01e8,0x7523010a}},	// [ff90] bera, _onth, huv_, yanz,
   {{0x6d5c06d7,0xf77001ca,0x443c9792,0x6568000e}},	//   cera, یان_, kuv_, _nadh,
   {{0xb9073ded,0x7523cd91,0x4735cd92,0xa3be0035}},	//   _पर_, vanz, енес, ँचा_,
   {{0x752301d5,0x7f5dcd93,0x657acd94,0xaff90070}},	//   wanz, nesq, _anth, פּעי,
   {{0x752377e5,0x656800bf,0xa509cd95,0x6e3d8049}},	//   tanz, _badh, пела_, nusb,
   {{0x6568cd96,0x6e20cd97,0x6fd60300,0xd469178e}},	//   _cadh, âmbi, láct, зике_,
   {{0x7523cd98,0x6d450657,0x656839e2,0x33f50036}},	//   ranz, _mcha, _dadh, нчис,
   {{0x61c70567,0x22150012,0x6d5ccd99,0x75230a74}},	//   रक्ष, нфор, zera, sanz,
   {{0x6568cd9a,0x7c3ccd9b,0x6d5ccd9c,0x75230547}},	//   _fadh, zurr, yera, panz,
   {{0x6d5ccd9d,0x6d4501e8,0x656800bf,0x67200fdf}},	//   xera, _ncha, _gadh, _zemj,
   {{0x61f80a78,0x6d5c7f04,0x644a2ea2,0xd00e03c5}},	//   _divl, vera, ctfi, یلی_,
   {{0x6d45cd9e,0x3494147a,0x6d5ccd9f,0x7afd0210}},	//   _acha, _шахр, wera, _ngst,
   {{0x6fd60b4c,0xa19500d8,0x3167033b,0x65682206}},	//   dáct, _падч, _tanz_, _yadh,
   {{0x6145cda0,0x7c3ccda1,0x752100b5,0x7afd0298}},	//   _чека, turr, _jelz, _agst,
   {{0x6d5ccda2,0xc4d202b5,0x16dc19b7,0x6d450211}},	//   rera, ָגן_, _बर्ब, _dcha,
   {{0x6d5ccda3,0x6d45cda4,0xef1a02ee,0xd00e0082}},	//   sera, _echa, _эми_, _الي_,
   {{0xfaa34674,0x443c00ee,0x7e64002f,0xdb0f00b5}},	// [ffa0] гато, zuv_, _usip, ájár,
   {{0xe9d7340a,0x6720cda5,0x7c3ccda6,0x752100b8}},	//   еку_, _semj, purr, _nelz,
   {{0x6568cda7,0x644acda8,0x77690051,0x00000000}},	//   _radh, xtfi, _baex, --,
   {{0x69d5cda9,0xd6d9006a,0xa3de0006,0x656800d1}},	//   _ekze, _był_, _दीं_, _sadh,
   {{0x656801ca,0x777b0118,0x00000000,0x00000000}},	//   _padh, _dnux, --, --,
   {{0x65680034,0xceb302b5,0x6d45cdaa,0x644a0a6d}},	//   _qadh, ניג_, _xcha, ttfi,
   {{0x6fd6006c,0xb0cf0066,0x656805f5,0x6720cdab}},	//   nács, _सुलग, _vadh, _temj,
   {{0x644acdac,0x65689527,0x443c0d3b,0xff5f000d}},	//   rtfi, _wadh, ruv_, noît_,
   {{0x644acdad,0x6568cdae,0x7f5d00a2,0x443ccdaf}},	//   stfi, _tadh, vesq, suv_,
   {{0xe4d6004f,0x75210b5e,0x00000000,0x00000000}},	//   _كتاب, _gelz, --, --,
   {{0x89370070,0x7f5d123d,0xc95300a5,0xfaff0345}},	//   ערטע_, tesq, אמת_, _baël_,
   {{0x6d45aea0,0x6e3dcdb0,0x75210051,0x00000000}},	//   _scha, tusb, _zelz, --,
   {{0x7f5d643c,0x93cb00b5,0x6d455702,0x00000000}},	//   resq, _عامہ_, _pcha, --,
   {{0x127b02b5,0x6e3d3ffc,0xc29700d8,0x81de0033}},	//   _מאדע, rusb, _якіх_, _দূর_,
   {{0xe0d400c2,0x21670274,0x013321b6,0x6fd60138}},	//   _בײַ_, _чији_, _صعود, táct,
   {{0x442c02d4,0x9f5500af,0x00000000,0x00000000}},	//   _mvd_, _рвич, --, --,
   {{0x6fd60f56,0x6d45cdb1,0x998900a0,0x3a2908dd}},	// [ffb0] ráct, _tcha, hrať_, usap_,
   {{0x6d45a961,0xa3e75f12,0x98c71692,0xddc400a0}},	//   _ucha, _मीन_, нсел, _priť,
   {{0x99d4026e,0xbb1b0248,0x6e2d008c,0xa9c401e0}},	//   اتقا, _boît, _hvab, устк,
   {{0x75210069,0xdb0700c3,0x3b1e00e2,0x1ab5010b}},	//   _selz, ämät, _đtqg_, _абмя,
   {{0x442c3356,0x75210110,0x00000000,0x00000000}},	//   _avd_, _pelz, --, --,
   {{0x442c1d87,0x6e2d0027,0x00000000,0x00000000}},	//   _bvd_, _mvab, --, --,
   {{0x65920274,0xd466046e,0x75210051,0x00000000}},	//   рају, вище_, _velz, --,
   {{0x58d4cdb2,0x34e10035,0x752101e4,0x77d70079}},	//   _сост, _फरीद, _welz, _أغسط,
   {{0xdcfe029d,0x35f52b0f,0x422200c3,0xfaff0345}},	//   _uopć, _апар, адыв, _raël_,
   {{0x6fdd1010,0x6f0d0043,0x998901ba,0x21757044}},	//   léch, _afac, brať_, туир,
   {{0x8fa60133,0x442c0051,0xd49b29d6,0x00000000}},	//   ване, _gvd_, _эра_, --,
   {{0x200500a8,0xb4cd2450,0x4f961403,0x853c0409}},	//   rqli_, रथी_, троу, _glėb,
   {{0xe28e6a01,0x59d122f2,0x9e6300d8,0x442c0051}},	//   _та_, तकार, авяд, _zvd_,
   {{0xfaff0c6f,0x6f0dac90,0x00000000,0x00000000}},	//   _agë_, _efac, --, --,
   {{0x224d006c,0x6f0d00e9,0x798e0371,0x442c0118}},	//   ltek_, _ffac, _robw, _xvd_,
   {{0x25e80f8a,0x224d04ca,0x236d01f4,0x6fd600b5}},	//   _चीनी_, otek_, ndej_, rács,
   {{0x224dcdb3,0xff5f00a2,0x00000000,0x00000000}},	// [ffc0] ntek_, roît_, --, --,
   {{0x224d01d7,0x957c0067,0x8d5600af,0x00000000}},	//   itek_, _wiąz, _ртич, --,
   {{0x98b101d6,0xdca601ee,0x574a00d8,0x7e76007e}},	//   _bazı_, _рани, дзем_, _hryp,
   {{0x224dcdb4,0x6f0d0036,0x2d8a00cd,0xb5fd023a}},	//   ktek_, _xfac, ljbe_, _pršp,
   {{0x442ccdb5,0x224dcdb6,0xe53403d4,0x4a94002d}},	//   _svd_, jtek_, гель, _сынӂ,
   {{0x569354b8,0xd69303fa,0x442c00ec,0x224d00b5}},	//   рашт, ришћ, _pvd_, dtek_,
   {{0x03c60145,0xd90d1328,0x67e3018d,0x00000000}},	//   ксим, _رین_, sõja, --,
   {{0x68e3cdb7,0x442c01e4,0x236d006d,0x317c023a}},	//   ünde, _vvd_, gdej_, _snvz_,
   {{0x05660192,0xe3af1ee1,0x6f0dcdb8,0x78af00f4}},	//   _иван, ترو_, _rfac, ćivš,
   {{0xa3e75a77,0x6f0d1f26,0xbddb0392,0x00000000}},	//   _मीठ_, _sfac, ntèt, --,
   {{0x98b106d3,0x6e2d1b2a,0x493b00a5,0x993b32e3}},	//   _yazı_, _svab, וגיו, ותיה,
   {{0x645a0069,0x00000000,0x00000000,0x00000000}},	//   _ipti, --, --, --,
   {{0x539b0bed,0x28d90067,0x6fdd021d,0x00000000}},	//   _קידו, _बुनि, néci, --,
   {{0x7e760b3e,0x7bc600f4,0x6b8f0160,0x00000000}},	//   _dryp, _ajku, _socg, --,
   {{0x1df800c3,0x6fd601ef,0x8ccd0067,0x00000000}},	//   теры_, rácr, _दुखो, --,
   {{0x7e76010b,0xddcd00af,0x63a20118,0x6fdd01ef}},	//   _fryp, _braţ, _jlon, xéch,
   {{0x98b10644,0x7e762bda,0x63a247e7,0x00000000}},	// [ffd0] _razı_, _gryp, _mlon, --,
   {{0x6fdd63f0,0x63a200e9,0x3f8b0124,0xdd9100b5}},	//   déci, _llon, ljcu_, _چوک_,
   {{0x63a2cdb9,0x224db28e,0x7bc8000d,0x6fdd00a2}},	//   _olon, ztek_, éduc, téch,
   {{0x224dcdba,0xe7d10083,0x3f8b3f22,0xc0530070}},	//   ytek_, িষ্য, njcu_, יזע_,
   {{0xf77018dd,0x26c903e6,0x6fdd399b,0xddcd0395}},	//   تال_, çao_, réch, _graţ,
   {{0x63a2024b,0x59a70803,0x7c3a343a,0x69cb00b5}},	//   _alon, _गतिर, štre, éged,
   {{0x26d2027d,0x5fd30bdd,0x00000000,0x00000000}},	//   üyor_, सवाल, --, --,
   {{0x24890470,0x224d006c,0x0456004f,0x6fdd2902}},	//   ćam_, ttek_, الية_, béci,
   {{0xe1f9516d,0x645a0176,0xf794002d,0x63a2cdbb}},	//   нги_, _epti, _татэ, _dlon,
   {{0xd49bcdbc,0x224dcdbd,0x63a2cdbe,0x00000000}},	//   _оре_, rtek_, _elon, --,
   {{0x224dcdbf,0x00000000,0x00000000,0x00000000}},	//   stek_, --, --, --,
   {{0x63a2cdc0,0x224d00b5,0x6d57013b,0x201100ea}},	//   _glon, ptek_, _abxa, īzi_,
   {{0x2bc76ecd,0x69c7001c,0x00000000,0x00000000}},	//   रचना, _ojje, --, --,
   {{0x8c460183,0xde03cdc1,0xa3e70992,0x63a20169}},	//   леге, спри, _मीत_, _zlon,
   {{0xdca37e78,0x00000000,0x00000000,0x00000000}},	//   бари, --, --, --,
   {{0x399632df,0x69c70103,0x7e76cdc2,0x6d8b013b}},	//   _læst_, _ajje, _tryp, _müay,
   {{0x4e1d004e,0x6e290124,0x39ea0274,0x99870207}},	// [ffe0] बीआई_, šebr, едао_, _šišo_,
   {{0x8d668b9c,0x39960093,0x680c00a8,0x4d662a21}},	//   _свое, _næst_, _ağda, _сков,
   {{0x765b2505,0xf99f0310,0x485a010b,0x3f920225}},	//   _apuy, _atès_, эраў_, _koyu_,
   {{0x46a6cdc3,0x69c78036,0xddcd245d,0x7c2e5bd9}},	//   лаев, _ejje, _iraš, msbr,
   {{0xddcd0cc1,0x7c2e3bd1,0x9f8b00be,0x52e200ab}},	//   _hraš, lsbr, _tööl_, _परेस,
   {{0x7bc401c8,0x63a20169,0xddcd3980,0x6fdd2948}},	//   lniu, _slon, _kraš, réci,
   {{0x69c3029d,0x7794103b,0x2ee1035d,0x00000000}},	//   čnet, _پیشا, _नर्त, --,
   {{0x6fdd03e6,0x684300af,0x61ea0031,0x779101cb}},	//   péci, _ынса, _shfl, _ویلا,
   {{0xf1265431,0x3996008d,0x7bc4cdc4,0x63a2cdc5}},	//   льно, _fæst_, iniu, _vlon,
   {{0xddcd044d,0x865b0319,0x399608c8,0x7c2e1d92}},	//   _oraš, _אדמי, _gæst_, ksbr,
   {{0x3f920644,0x7c2e0051,0x63a20118,0x00000000}},	//   _boyu_, jsbr, _tlon, --,
   {{0x7c2e054e,0xdb0d0279,0xdfd500af,0x63a23599}},	//   dsbr, miaç, ромы, _ulon,
   {{0xdb0d0370,0x22161018,0x9f92008a,0x3f800035}},	//   liaç, _сфер, ráð_, _dniu_,
   {{0xddcdcdc6,0xa6d10083,0x394a0069,0x1619021a}},	//   _braš, ়েকট, _ncbs_, नीटर_,
   {{0x2b9c01a5,0x442e0260,0x7c2e5750,0x7c8420a6}},	//   _kích_, nsf_, gsbr, буте,
   {{0x7bc44cef,0x09bf0b35,0xddcd05e2,0x9b24081b}},	//   gniu, ्व्य, _draš, йфул,
   {{0x776201dd,0x52e20084,0x645c00be,0x399603d0}},	// [fff0] deox, _परोस, _ärif, _næss_,
   {{0xa2c509b1,0xddcd00d5,0x6d41008d,0x00000000}},	//   ापत्, _fraš, ólad, --,
   {{0xddcd003d,0x31570070,0x00000000,0x00000000}},	//   _graš, ריבן_, --, --,
   {{0x2d93043f,0xbddb0248,0xdb0d6dbf,0x6d471cfd}},	//   _hoxe_, ctèr, diaç, lgja,
   {{0x366907be,0x32060159,0x6f1d5c35,0x00000000}},	//   тало_, _nuoy_, ibsc, --,
   {{0x6d47cdc7,0xae1d004e,0x2d9301d7,0x6b8d4581}},	//   ngja, बीएन_, _joxe_, ljag,
   {{0x6fddcdc8,0xcd980122,0x2b9c0019,0x69d70042}},	//   lécu, רדות_, _bích_, moxe,
   {{0x43751018,0x6b8d4381,0x69d701dd,0x59bf012f}},	//   рукт, njag, loxe, ्वकर,
   {{0x69c5cdc9,0x395800d7,0x6aad0036,0x672bcdca}},	//   onhe, _ybrs_, nzaf, magj,
   {{0x69c5ab08,0x69d7002a,0x2d930139,0x672bcdcb}},	//   nnhe, noxe, _noxe_, lagj,
   {{0xdb0d0370,0x6563cdcc,0x27ed0019,0x6e3d939d}},	//   ciaç, menh, _khen_, ersb,
   {{0x6563cdcd,0xe519022e,0x33260036,0x3cdf046c}},	//   lenh, _न्ति_, _geox_, _गरजे_,
   {{0x64430297,0x539a0122,0x7c2e0223,0x63a90093}},	//   luni, _שינו, wsbr, mhen,
   {{0xddcd1001,0x6d47aac7,0x7c2e9ccd,0x6aad028b}},	//   _praš, ggja, tsbr, dzaf,
   {{0xab2a356c,0x1c391470,0x7bc4cdce,0x672b4c69}},	//   кова_, лять_, tniu, kagj,
   {{0x63bb4776,0x63a9cdcf,0x3f80cdd0,0x2b9c0023}},	//   niun, nhen, _uniu_, _xích_,

  };
  // table_hash = 9fdb-c519, unused_entries = 21650 (8.26%)

static const uint32 kQuadChrome0715SizeOne = 52689;    // Bucket count one-lang
static const uint32 kQuadChrome0715Ind[52689] = {
  // [0000]
  0x00000000, 0x00000000, 0x0a04070c, 0x08060c12,   // -- --  bg.ru.mk_543 sv.de.no_654
  0x0c0803a4, 0x01002a07, 0x0000131c, 0x6e23050b,   // nl.no.sv_433 mt.en.un_420  et.un.un_800 fr.ca.blu_542
  0x00006b0a, 0x00001701, 0x2d29160c, 0x06003f07,   // ceb.un.un_500 sr.un.un_200  hr.sl.sk_543 af.de.un_420
  0x00000d1c, 0x00000506, 0x00002815, 0x1a210e08,   // ne.un.un_800 fr.un.un_400  sw.un.un_700 is.jw.tl_443
  // [0010]
  0x00005515, 0x17070aa4, 0x0000111c, 0x02212060,   // rw.un.un_700 mk.bg.sr_433  ro.un.un_800 sq.jw.da_664
  0x0000271c, 0x19000a05, 0x0c080a09, 0x1f2864af,   // gd.un.un_800 pt.gl.un_330  pt.no.sv_444 lg.sw.cy_655
  0x05190b08, 0x00002b0f, 0x25131a07, 0x0d001904,   // es.gl.fr_443 vi.un.un_600  tl.et.eu_432 gl.cs.un_320
  0x0000640a, 0x11000721, 0x00001f15, 0x170a07a9,   // lg.un.un_500 it.ro.un_860  cy.un.un_700 bg.mk.sr_544
  // [0020]
  0x19000b0c, 0x00000724, 0x0000021c, 0x00002b0a,   // es.gl.un_530 bg.un.un_900  da.un.un_800 vi.un.un_500
  0x00002a03, 0x211a11ad, 0x1c000909, 0x00005501,   // mt.un.un_300 ro.tl.jw_643  hi.mr.un_440 rw.un.un_200
  0x00002b1c, 0x00000f15, 0x00001903, 0x1e6407a0,   // vi.un.un_800 lv.un.un_700  gl.un.un_300 it.lg.ms_322
  0x5309060c, 0x0000110f, 0x080410ee, 0x0000280a,   // de.pl.ht_543 ro.un.un_600  be.ru.uk_422 sw.un.un_500
  // [0030]
  0x10002d07, 0x0000200a, 0x3f001f0d, 0x00000b0f,   // sk.lt.un_420 sq.un.un_500  cy.af.un_540 bn.un.un_600
  0x1e001c05, 0x0000090f, 0x00000701, 0x0000180f,   // id.ms.un_330 pl.un.un_600  it.un.un_200 ar.un.un_600
  0x00002d1c, 0x20000e14, 0x1700160c, 0x18002723,   // sk.un.un_800 is.sq.un_660  hr.sr.un_530 gd.ga.un_880
  0x00002a15, 0x29001604, 0x00000e06, 0x1c131e07,   // mt.un.un_700 hr.sl.un_320  is.un.un_400 ms.et.id_432
  // [0040]
  0x1b2825ee, 0x182112af, 0x00001906, 0x00001115,   // eu.sw.tr_422 ur.fa.ar_655  gl.un.un_400 ro.un.un_700
  0x00000806, 0x1c002007, 0x25196ba0, 0x03080208,   // uk.un.un_400 sq.id.un_420  ceb.gl.eu_322 da.no.nl_443
  0x532b1f0b, 0x1f0c0604, 0x00002724, 0x00001006,   // cy.vi.ht_542 de.sv.cy_332  gd.un.un_900 be.un.un_400
  0x0400110d, 0x04552855, 0x00000915, 0x00001815,   // ro.ru.un_540 sw.rw.fi_442  pl.un.un_700 ar.un.un_700
  // [0050]
  0x121920ac, 0x00000301, 0x0000011c, 0x21000808,   // sq.gl.hu_632 nl.un.un_200  en.un.un_800 no.jw.un_430
  0x0000280f, 0x00002006, 0x201a010c, 0x06030ca6,   // sw.un.un_600 sq.un.un_400  en.tl.sq_543 sv.nl.de_521
  0x18002729, 0x06080a08, 0x09211c05, 0x1300040e,   // gd.ga.un_960 pt.no.de_443  id.jw.pl_333 fi.et.un_550
  0x0a071707, 0x1e001c14, 0x092125a4, 0x00001001,   // sr.bg.mk_432 id.ms.un_660  eu.jw.pl_433 lt.un.un_200
  // [0060]
  0x171620a4, 0x6b101112, 0x530517a0, 0x16291008,   // sq.hr.sr_433 ro.lt.ceb_654  sr.fr.ht_322 lt.sl.hr_443
  0x11002002, 0x00002503, 0x13000909, 0x0000090a,   // sq.ro.un_220 eu.un.un_300  hi.bh.un_440 hi.un.un_500
  0x0421250c, 0x00002a01, 0x0000091c, 0x1800270d,   // eu.jw.fi_543 mt.un.un_200  pl.un.un_800 gd.ga.un_540
  0x00001215, 0x00006e06, 0x27001822, 0x00006e15,   // hu.un.un_700 blu.un.un_400  ga.gd.un_870 blu.un.un_700
  // [0070]
  0x0000240f, 0x181221af, 0x0a040808, 0x04071705,   // yi.un.un_600 fa.ur.ar_655  uk.ru.mk_443 sr.bg.ru_333
  0x11002504, 0x0c08020d, 0x2d000d1b, 0x0f006e0d,   // eu.ro.un_320 da.no.sv_554  cs.sk.un_770 blu.lv.un_540
  0x2d0d2aa0, 0x0000180a, 0x00002a0a, 0x00005506,   // mt.cs.sk_322 ga.un.un_500  mt.un.un_500 rw.un.un_400
  0x00001315, 0x060804a7, 0x00000d03, 0x282a1804,   // bh.un.un_700 fi.no.de_532  cs.un.un_300 ga.mt.sw_332
  // [0080]
  0x00000f1c, 0x08001007, 0x0000181c, 0x00000b15,   // lv.un.un_800 be.uk.un_420  ar.un.un_800 bn.un.un_700
  0x1300090e, 0x0a04170d, 0x00000415, 0x0c0225ee,   // hi.bh.un_550 sr.ru.mk_554  ru.un.un_700 eu.da.sv_422
  0x00002101, 0x0410110c, 0x00000e15, 0x0000290f,   // fa.un.un_200 ro.be.ru_543  is.un.un_700 sl.un.un_600
  0x00000201, 0x00000e0a, 0x00000e01, 0x31001b19,   // da.un.un_200 is.un.un_500  is.un.un_200 tr.az.un_750
  // [0090]
  0x00001f03, 0x07080409, 0x1b00311b, 0x00000e0f,   // cy.un.un_300 ru.uk.bg_444  az.tr.un_770 is.un.un_600
  0x1800271a, 0x00003115, 0x00000903, 0x2d000d09,   // gd.ga.un_760 az.un.un_700  hi.un.un_300 cs.sk.un_440
  0x00001806, 0x00001c0f, 0x1c001309, 0x64006e07,   // ga.un.un_400 mr.un.un_600  bh.mr.un_440 blu.lg.un_420
  0x2700181b, 0x27001814, 0x00002701, 0x00002a06,   // ga.gd.un_770 ga.gd.un_660  gd.un.un_200 mt.un.un_400
  // [00a0]
  0x00002d0a, 0x00001c15, 0x00000503, 0x31001b08,   // sk.un.un_500 mr.un.un_700  fr.un.un_300 tr.az.un_430
  0x10070408, 0x0000010f, 0x06000c0d, 0x00001a15,   // ru.bg.be_443 iw.un.un_600  sv.de.un_540 tl.un.un_700
  0x0000310f, 0x091c0dad, 0x04000814, 0x0000130f,   // az.un.un_600 ne.mr.hi_643  uk.ru.un_660 et.un.un_600
  0x2d000d05, 0x21001819, 0x1b003105, 0x0000110a,   // cs.sk.un_330 ar.fa.un_750  az.tr.un_330 ro.un.un_500
  // [00b0]
  0x1b000208, 0x130d0914, 0x181221ad, 0x10041ca0,   // da.tr.un_430 hi.ne.bh_666  fa.ur.ar_643 id.fi.lt_322
  0x1c000905, 0x0000120f, 0x07170a0d, 0x10080c0c,   // hi.mr.un_330 ur.un.un_600  mk.sr.bg_554 sv.no.lt_543
  0x00000d0f, 0x00001303, 0x0a1007a9, 0x3f010904,   // ne.un.un_600 et.un.un_300  bg.be.mk_544 pl.en.af_332
  0x1800210e, 0x02080e13, 0x0000130a, 0x0000211c,   // fa.ar.un_550 is.no.da_665  et.un.un_500 fa.un.un_800
  // [00c0]
  0x13090daf, 0x31001b0e, 0x0000241c, 0x0000040f,   // ne.hi.bh_655 tr.az.un_550  yi.un.un_800 ru.un.un_600
  0x09001305, 0x291716a0, 0x070a10ee, 0x0000100a,   // bh.hi.un_330 hr.sr.sl_322  be.mk.bg_422 lt.un.un_500
  0x00000b1c, 0x00000a1c, 0x17040aa4, 0x17001608,   // bn.un.un_800 mk.un.un_800  mk.ru.sr_433 hr.sr.un_430
  0x00002b03, 0x17001605, 0x18002104, 0x070804ee,   // vi.un.un_300 hr.sr.un_330  fa.ar.un_320 ru.uk.bg_422
  // [00d0]
  0x31001b13, 0x00002115, 0x18211211, 0x17080460,   // tr.az.un_650 fa.un.un_700  ur.fa.ar_653 ru.uk.sr_664
  0x00000815, 0x2d000d02, 0x1e1c2105, 0x00001e01,   // uk.un.un_700 cs.sk.un_220  jw.id.ms_333 ms.un.un_200
  0x00001015, 0x052001a0, 0x00002015, 0x13000d09,   // be.un.un_700 en.sq.fr_322  sq.un.un_700 ne.bh.un_440
  0x0d000909, 0x18006b02, 0x00000b06, 0x1c0d0955,   // hi.ne.un_440 ceb.ga.un_220  es.un.un_400 hi.ne.mr_442
  // [00e0]
  0x00002106, 0x0f00100d, 0x00002b06, 0x081716a4,   // fa.un.un_400 lt.lv.un_540  vi.un.un_400 hr.sr.no_433
  0x0e00120d, 0x00001f06, 0x16002a04, 0x00001c06,   // hu.is.un_540 cy.un.un_400  mt.hr.un_320 id.un.un_400
  0x00002b24, 0x00001f0f, 0x00000f0f, 0x09051bee,   // vi.un.un_900 cy.un.un_600  lv.un.un_600 tr.fr.pl_422
  0x00000f03, 0x0a001713, 0x00002d01, 0x10000822,   // lv.un.un_300 sr.mk.un_650  sk.un.un_200 uk.be.un_870
  // [00f0]
  0x0a040712, 0x0000270f, 0x17000d04, 0x18002108,   // bg.ru.mk_654 gd.un.un_600  cs.sr.un_320 fa.ar.un_430
  0x17001602, 0x00001224, 0x00000501, 0x0000050a,   // hr.sr.un_220 ur.un.un_900  fr.un.un_200 fr.un.un_500
  0x0000210f, 0x04005504, 0x1c130913, 0x00000e1c,   // fa.un.un_600 rw.fi.un_320  hi.bh.mr_665 is.un.un_800
  0x182112ac, 0x0000120a, 0x00000d01, 0x12002107,   // ur.fa.ar_632 ur.un.un_500  cs.un.un_200 fa.ur.un_420
  // [0100]
  0x01002419, 0x0300090e, 0x04000711, 0x00006401,   // yi.iw.un_750 pl.nl.un_550  bg.ru.un_630 lg.un.un_200
  0x0400100d, 0x1200210e, 0x211827a0, 0x00005301,   // be.ru.un_540 fa.ur.un_550  gd.ga.jw_322 ht.un.un_200
  0x040a11af, 0x07000409, 0x64005512, 0x0000100f,   // ro.mk.ru_655 ru.bg.un_440  rw.lg.un_640 be.un.un_600
  0x08070a08, 0x00001a03, 0x170a0709, 0x285564ec,   // mk.bg.uk_443 tl.un.un_300  bg.mk.sr_444 lg.rw.sw_644
  // [0110]
  0x00000603, 0x31051ba4, 0x0a040704, 0x2d0809a0,   // de.un.un_300 tr.fr.az_433  bg.ru.mk_332 pl.no.sk_322
  0x182a6b08, 0x070631ad, 0x00002906, 0x09205304,   // ceb.mt.ga_443 az.de.it_643  sl.un.un_400 ht.sq.pl_332
  0x00002103, 0x64000413, 0x0d01030c, 0x211c0ba0,   // jw.un.un_300 fi.lg.un_650  nl.en.cs_543 es.id.jw_322
  0x17001609, 0x24000112, 0x00006b06, 0x111c0407,   // hr.sr.un_440 iw.yi.un_640  ceb.un.un_400 fi.id.ro_432
  // [0120]
  0x0000030f, 0x29171609, 0x00000115, 0x061f0204,   // nl.un.un_600 hr.sr.sl_444  iw.un.un_700 da.cy.de_332
  0x00001603, 0x1800211a, 0x11000d07, 0x1c00090d,   // hr.un.un_300 fa.ar.un_760  cs.ro.un_420 hi.mr.un_540
  0x0c052aa4, 0x16001708, 0x280355a4, 0x0000242d,   // mt.fr.sv_433 sr.hr.un_430  rw.nl.sw_433 yi.un.un_A00
  0x0b000104, 0x022908a0, 0x17001607, 0x00001c01,   // en.es.un_320 no.sl.da_322  hr.sr.un_420 id.un.un_200
  // [0130]
  0x3f00030c, 0x1000081b, 0x00000a06, 0x0000071c,   // nl.af.un_530 uk.be.un_770  pt.un.un_400 bg.un.un_800
  0x1f0e0ca9, 0x0c060809, 0x03003f1a, 0x06000805,   // sv.is.cy_544 no.de.sv_444  af.nl.un_760 no.de.un_330
  0x19000b02, 0x00001103, 0x00000f01, 0x0000310a,   // es.gl.un_220 ro.un.un_300  lv.un.un_200 az.un.un_500
  0x00000c0f, 0x05003f02, 0x05000402, 0x04130e04,   // sv.un.un_600 af.fr.un_220  fi.fr.un_220 is.et.fi_332
  // [0140]
  0x0c00200d, 0x131c09ec, 0x08070405, 0x556b2807,   // sq.sv.un_540 hi.mr.bh_644  ru.bg.uk_333 sw.ceb.rw_432
  0x1000110c, 0x0704170c, 0x12000e0d, 0x00000103,   // ro.be.un_530 sr.ru.bg_543  is.hu.un_540 en.un.un_300
  0x12002121, 0x120a23a0, 0x12002118, 0x0e086b04,   // fa.ur.un_860 ca.pt.hu_322  fa.ur.un_740 ceb.no.is_332
  0x0b000a02, 0x040a0708, 0x08000c13, 0x1e1c1f05,   // pt.es.un_220 bg.mk.ru_443  sv.no.un_650 cy.id.ms_333
  // [0150]
  0x08040a08, 0x08060ea4, 0x190a0ba9, 0x07080a04,   // mk.ru.uk_443 is.de.no_433  es.pt.gl_544 mk.uk.bg_332
  0x0e3f0508, 0x12006408, 0x16002d02, 0x090d08a4,   // fr.af.is_443 lg.hu.un_430  sk.hr.un_220 no.cs.pl_433
  0x23280ba0, 0x00001a01, 0x17000a19, 0x2a0801a4,   // es.sw.ca_322 tl.un.un_200  mk.sr.un_750 en.no.mt_433
  0x080a0755, 0x0c2304a0, 0x190b0502, 0x110a28a0,   // bg.mk.uk_442 fi.ca.sv_322  fr.es.gl_222 sw.pt.ro_322
  // [0160]
  0x00001101, 0x0e080c11, 0x1c0d0912, 0x06642807,   // ro.un.un_200 sv.no.is_653  hi.ne.mr_654 sw.lg.de_432
  0x21001221, 0x080a1707, 0x17000a13, 0x130d09a9,   // ur.fa.un_860 sr.mk.uk_432  mk.sr.un_650 hi.ne.bh_544
  0x00002d03, 0x171629a4, 0x641e2807, 0x0000240a,   // sk.un.un_300 sl.hr.sr_433  sw.ms.lg_432 yi.un.un_500
  0x230b1208, 0x0d000302, 0x00001f0a, 0x00002d15,   // hu.es.ca_443 nl.cs.un_220  cy.un.un_500 sk.un.un_700
  // [0170]
  0x0c060404, 0x0a001107, 0x18001212, 0x00003f15,   // fi.de.sv_332 ro.mk.un_420  ur.ar.un_640 af.un.un_700
  0x09001318, 0x0b2305ad, 0x00002301, 0x28002b02,   // bh.hi.un_740 fr.ca.es_643  ca.un.un_200 vi.sw.un_220
  0x1a001308, 0x190b0aec, 0x1c0913af, 0x00000c06,   // et.tl.un_430 pt.es.gl_644  bh.hi.mr_655 sv.un.un_400
  0x041005a4, 0x27001f05, 0x21001813, 0x0d00090d,   // fr.lt.fi_433 cy.gd.un_330  ar.fa.un_650 hi.ne.un_540
  // [0180]
  0x21121812, 0x190a0ba0, 0x1e211ca7, 0x00000a03,   // ar.ur.fa_654 es.pt.gl_322  id.jw.ms_532 pt.un.un_300
  0x2d000d07, 0x0000080a, 0x55006419, 0x2d000d0e,   // cs.sk.un_420 uk.un.un_500  lg.rw.un_750 cs.sk.un_550
  0x1a646b0c, 0x00006e1c, 0x10001102, 0x1f1b2708,   // ceb.lg.tl_543 blu.un.un_800  ro.lt.un_220 gd.tr.cy_443
  0x64005513, 0x00001306, 0x0000640f, 0x64000404,   // rw.lg.un_650 et.un.un_400  lg.un.un_600 fi.lg.un_320
  // [0190]
  0x212018af, 0x033f0107, 0x040a0705, 0x1f3f27a4,   // ga.sq.jw_655 en.af.nl_432  bg.mk.ru_333 gd.af.cy_433
  0x20080eee, 0x28006409, 0x13000412, 0x0f001002,   // is.no.sq_422 lg.sw.un_440  fi.et.un_640 lt.lv.un_220
  0x55006422, 0x20002b13, 0x6b000807, 0x10000834,   // lg.rw.un_870 vi.sq.un_650  no.ceb.un_420 uk.be.un_A80
  0x03003f2b, 0x12000402, 0x0a170702, 0x12006e07,   // af.nl.un_980 fi.hu.un_220  bg.sr.mk_222 blu.hu.un_420
  // [01a0]
  0x29171604, 0x202304a0, 0x00006b03, 0x0000250a,   // hr.sr.sl_332 fi.ca.sq_322  ceb.un.un_300 eu.un.un_500
  0x0e0608a4, 0x00002b15, 0x00002715, 0x09001f0d,   // no.de.is_433 vi.un.un_700  gd.un.un_700 cy.pl.un_540
  0x00006415, 0x00006e24, 0x04002314, 0x040613a0,   // lg.un.un_700 blu.un.un_900  ca.fi.un_660 et.de.fi_322
  0x12005504, 0x083f02a4, 0x0000060f, 0x04000708,   // rw.hu.un_320 da.af.no_433  de.un.un_600 bg.ru.un_430
  // [01b0]
  0x2a0304ee, 0x02000307, 0x18002113, 0x080420a9,   // fi.nl.mt_422 nl.da.un_420  fa.ar.un_650 sq.fi.no_544
  0x0000020f, 0x3100550d, 0x643f0307, 0x00002506,   // da.un.un_600 rw.az.un_540  nl.af.lg_432 eu.un.un_400
  0x07000a1b, 0x20190407, 0x00002d0f, 0x1300010d,   // mk.bg.un_770 fi.gl.sq_432  sk.un.un_600 en.et.un_540
  0x0c000807, 0x530523a7, 0x200b1f02, 0x03003f04,   // no.sv.un_420 ca.fr.ht_532  cy.es.sq_222 af.nl.un_320
  // [01c0]
  0x00000d15, 0x1a002a07, 0x0000311c, 0x010c060c,   // cs.un.un_700 mt.tl.un_420  az.un.un_800 de.sv.en_543
  0x2b1218ee, 0x1a0621ac, 0x162d0d55, 0x0b0e13a0,   // ga.hu.vi_422 jw.de.tl_632  cs.sk.hr_442 et.is.es_322
  0x0000101c, 0x0723190c, 0x00002124, 0x0000210a,   // be.un.un_800 gl.ca.it_543  fa.un.un_900 jw.un.un_500
  0x1700161b, 0x3f190b09, 0x051f0107, 0x0800020c,   // hr.sr.un_770 es.gl.af_444  en.cy.fr_432 da.no.un_530
  // [01d0]
  0x6400551a, 0x00001c0a, 0x0000201c, 0x00000715,   // rw.lg.un_760 mr.un.un_500  sq.un.un_800 bg.un.un_700
  0x1100050d, 0x0000550f, 0x00001b15, 0x0000250f,   // fr.ro.un_540 rw.un.un_600  tr.un.un_700 eu.un.un_600
  0x120220ee, 0x1b003f05, 0x00002706, 0x08041013,   // sq.da.hu_422 af.tr.un_330  gd.un.un_400 be.ru.uk_665
  0x27210111, 0x0000190a, 0x271801a4, 0x2100120c,   // en.jw.gd_653 gl.un.un_500  en.ga.gd_433 ur.fa.un_530
  // [01e0]
  0x0000080f, 0x27181faf, 0x033f0613, 0x130304a0,   // uk.un.un_600 cy.ga.gd_655  de.af.nl_665 fi.nl.et_322
  0x0000030a, 0x182a27ac, 0x132104ee, 0x04003f09,   // nl.un.un_500 gd.mt.ga_632  fi.jw.et_422 af.fi.un_440
  0x00006e0a, 0x00002003, 0x072004a6, 0x0b072307,   // blu.un.un_500 sq.un.un_300  fi.sq.it_521 ca.it.es_432
  0x1e002805, 0x00002501, 0x070a170c, 0x00001901,   // sw.ms.un_330 eu.un.un_200  sr.mk.bg_543 gl.un.un_200
  // [01f0]
  0x17040808, 0x10001112, 0x00001706, 0x00000124,   // uk.ru.sr_443 ro.be.un_640  sr.un.un_400 iw.un.un_900
  0x0000200f, 0x04000809, 0x17080413, 0x00002303,   // sq.un.un_600 uk.ru.un_440  ru.uk.sr_665 ca.un.un_300
  0x1801270c, 0x08002b05, 0x6b271807, 0x31001b0c,   // gd.en.ga_543 vi.no.un_330  ga.gd.ceb_432 tr.az.un_530
  0x210501ee, 0x0700110c, 0x29002d13, 0x00000c0a,   // en.fr.jw_422 ro.bg.un_530  sk.sl.un_650 sv.un.un_500
  // [0200]
  0x0000170a, 0x03002004, 0x0000171c, 0x1c002804,   // sr.un.un_500 sq.nl.un_320  sr.un.un_800 sw.id.un_320
  0x0a000404, 0x27002804, 0x12211813, 0x00001601,   // ru.mk.un_320 sw.gd.un_320  ar.fa.ur_665 hr.un.un_200
  0x1000080d, 0x170810a0, 0x08041705, 0x16002d0c,   // uk.be.un_540 be.uk.sr_322  sr.ru.uk_333 sk.hr.un_530
  0x1c130908, 0x1c0913a9, 0x29000d0c, 0x06002305,   // hi.bh.mr_443 bh.hi.mr_544  cs.sl.un_530 ca.de.un_330
  // [0210]
  0x00000801, 0x00002703, 0x0a041704, 0x2b000307,   // uk.un.un_200 gd.un.un_300  sr.ru.mk_332 nl.vi.un_420
  0x0a001712, 0x12002d09, 0x12000311, 0x07040804,   // sr.mk.un_640 sk.hu.un_440  nl.hu.un_630 uk.ru.bg_332
  0x030802ec, 0x182a0802, 0x1c000902, 0x07001120,   // da.no.nl_644 no.mt.ga_222  hi.mr.un_220 ro.bg.un_850
  0x53550aa0, 0x00000a01, 0x00005306, 0x04001013,   // pt.rw.ht_322 pt.un.un_200  ht.un.un_400 be.ru.un_650
  // [0220]
  0x1200210c, 0x00006e0f, 0x1b00120e, 0x00000303,   // fa.ur.un_530 blu.un.un_600  hu.tr.un_550 nl.un.un_300
  0x211e1c11, 0x00001b0a, 0x080717a0, 0x170a0704,   // id.ms.jw_653 tr.un.un_500  sr.bg.uk_322 bg.mk.sr_332
  0x00000f0a, 0x126b1009, 0x00000c15, 0x1004080c,   // lv.un.un_500 lt.ceb.hu_444  sv.un.un_700 uk.ru.be_543
  0x070a1709, 0x01001c04, 0x00001c03, 0x00001606,   // sr.mk.bg_444 id.en.un_320  id.un.un_300 hr.un.un_400
  // [0230]
  0x20000c08, 0x080704a7, 0x0000551c, 0x6b043f07,   // sv.sq.un_430 ru.bg.uk_532  rw.un.un_800 af.fi.ceb_432
  0x033f0407, 0x04000818, 0x55530a09, 0x0d002d13,   // fi.af.nl_432 uk.ru.un_740  pt.ht.rw_444 sk.cs.un_650
  0x04001a19, 0x53001a08, 0x00002901, 0x6b0403a9,   // tl.fi.un_750 tl.ht.un_430  sl.un.un_200 nl.fi.ceb_544
  0x00002803, 0x6b3f04ad, 0x2b0413ec, 0x04001308,   // sw.un.un_300 fi.af.ceb_643  et.fi.vi_644 et.fi.un_430
  // [0240]
  0x13090d12, 0x05130304, 0x556b1aad, 0x09001313,   // ne.hi.bh_654 nl.et.fr_332  tl.ceb.rw_643 bh.hi.un_650
  0x3f00031a, 0x21002813, 0x1c091305, 0x64001a21,   // nl.af.un_760 sw.jw.un_650  bh.hi.mr_333 tl.lg.un_860
  0x0000050f, 0x0800020d, 0x28001808, 0x0000010a,   // fr.un.un_600 da.no.un_540  ga.sw.un_430 iw.un.un_500
  0x64005509, 0x64133faf, 0x2d000d14, 0x2000280c,   // rw.lg.un_440 af.et.lg_655  cs.sk.un_660 sw.sq.un_530
  // [0250]
  0x0000312d, 0x070817ee, 0x292d0d08, 0x09001c12,   // az.un.un_A00 sr.uk.bg_422  cs.sk.sl_443 mr.hi.un_640
  0x1700160e, 0x0e006b07, 0x16033f12, 0x1e001c12,   // hr.sr.un_550 ceb.is.un_420  af.nl.hr_654 id.ms.un_640
  0x212827ad, 0x10080404, 0x0100240c, 0x1f001822,   // gd.sw.jw_643 ru.uk.be_332  yi.iw.un_530 ga.cy.un_870
  0x0000160a, 0x036e640e, 0x2b6b64a0, 0x0f001013,   // hr.un.un_500 lg.blu.nl_555  lg.ceb.vi_322 lt.lv.un_650
  // [0260]
  0x00005303, 0x3f000321, 0x1e1c31ec, 0x11080413,   // ht.un.un_300 nl.af.un_860  az.id.ms_644 ru.uk.ro_665
  0x6b3f04a7, 0x07000a14, 0x1c090da9, 0x04001713,   // fi.af.ceb_532 mk.bg.un_660  ne.hi.mr_544 sr.ru.un_650
  0x08040aa0, 0x00001a1c, 0x08000c08, 0x00001206,   // mk.ru.uk_322 tl.un.un_800  sv.no.un_430 ur.un.un_400
  0x1a046bee, 0x10001311, 0x00001803, 0x6b001a05,   // ceb.fi.tl_422 et.lt.un_630  ga.un.un_300 tl.ceb.un_330
  // [0270]
  0x012704ee, 0x00003137, 0x17070a05, 0x0000641c,   // fi.gd.en_422 az.un.un_B00  mk.bg.sr_333 lg.un.un_800
  0x0000170f, 0x0d091c09, 0x3f0313af, 0x2400010c,   // sr.un.un_600 mr.hi.ne_444  et.nl.af_655 iw.yi.un_530
  0x1b033faf, 0x00000a0a, 0x00000703, 0x1b00310d,   // af.nl.tr_655 pt.un.un_500  it.un.un_300 az.tr.un_540
  0x1c002104, 0x00001b0f, 0x09002d08, 0x10000a02,   // jw.id.un_320 tr.un.un_600  sk.pl.un_430 mk.be.un_220
  // [0280]
  0x0000161c, 0x040717ee, 0x00000c01, 0x28005302,   // hr.un.un_800 sr.bg.ru_422  sv.un.un_200 ht.sw.un_220
  0x0000270a, 0x05120304, 0x21001807, 0x1c130d09,   // gd.un.un_500 nl.hu.fr_332  ar.fa.un_420 ne.bh.mr_444
  0x16000908, 0x17001620, 0x12032012, 0x00001e03,   // pl.hr.un_430 hr.sr.un_850  sq.nl.hu_654 ms.un.un_300
  0x211812af, 0x09033f0c, 0x040f10a7, 0x18001209,   // ur.ar.fa_655 af.nl.pl_543  lt.lv.fi_532 ur.ar.un_440
  // [0290]
  0x20001b13, 0x0000251c, 0x29000d05, 0x17162904,   // tr.sq.un_650 eu.un.un_800  cs.sl.un_330 sl.hr.sr_332
  0x19000a12, 0x042110a6, 0x02003f02, 0x00001f1c,   // pt.gl.un_640 lt.jw.fi_521  af.da.un_220 cy.un.un_800
  0x00003f03, 0x13000914, 0x07001722, 0x0e000c12,   // af.un.un_300 hi.bh.un_660  sr.bg.un_870 sv.is.un_640
  0x13006b04, 0x00001615, 0x0c000204, 0x0a000714,   // ceb.et.un_320 hr.un.un_700  da.sv.un_320 bg.mk.un_660
  // [02a0]
  0x0d001109, 0x290d5312, 0x00000306, 0x2b000607,   // ro.cs.un_440 ht.cs.sl_654  nl.un.un_400 de.vi.un_420
  0x08001012, 0x0c000214, 0x2a180cee, 0x00002903,   // be.uk.un_640 da.sv.un_660  sv.ga.mt_422 sl.un.un_300
  0x18002714, 0x3f002b04, 0x0000182d, 0x10000513,   // gd.ga.un_660 vi.af.un_320  ga.un.un_A00 fr.lt.un_650
  0x121107a9, 0x08170a11, 0x2a0c2004, 0x03020c09,   // it.ro.hu_544 mk.sr.uk_653  sq.sv.mt_332 sv.da.nl_444
  // [02b0]
  0x1b000c02, 0x00000606, 0x17162da0, 0x00006b15,   // sv.tr.un_220 de.un.un_400  sk.hr.sr_322 ceb.un.un_700
  0x1c00090c, 0x00002415, 0x13180655, 0x2a002304,   // hi.mr.un_530 yi.un.un_700  de.ga.et_442 ca.mt.un_320
  0x24000119, 0x083f02ec, 0x170407ee, 0x17000813,   // iw.yi.un_750 da.af.no_644  bg.ru.sr_422 uk.sr.un_650
  0x092806af, 0x062103ad, 0x3f0c1f07, 0x0000061c,   // de.sw.pl_655 nl.jw.de_643  cy.sv.af_432 de.un.un_800
  // [02c0]
  0x06033faf, 0x080a0705, 0x00001e0f, 0x162003a0,   // af.nl.de_655 bg.mk.uk_333  ms.un.un_600 nl.sq.hr_322
  0x00001703, 0x3f0321a9, 0x00002915, 0x00001f24,   // sr.un.un_300 jw.nl.af_544  sl.un.un_700 cy.un.un_900
  0x17000a05, 0x00000615, 0x13001f12, 0x00001c1c,   // mk.sr.un_330 de.un.un_700  cy.et.un_640 mr.un.un_800
  0x0000172d, 0x01001e08, 0x0000081c, 0x29000f20,   // sr.un.un_A00 ms.en.un_430  uk.un.un_800 lv.sl.un_850
  // [02d0]
  0x0000530f, 0x13000d07, 0x2b0521ee, 0x06272b55,   // ht.un.un_600 ne.bh.un_420  jw.fr.vi_422 vi.gd.de_442
  0x00000f06, 0x17080404, 0x04000805, 0x00000b01,   // lv.un.un_400 ru.uk.sr_332  uk.ru.un_330 es.un.un_200
  0x0600010d, 0x312055a0, 0x24000121, 0x08023fa4,   // en.de.un_540 rw.sq.az_322  iw.yi.un_860 af.da.no_433
  0x2b006b05, 0x171629af, 0x122118ec, 0x0c080213,   // ceb.vi.un_330 sl.hr.sr_655  ar.fa.ur_644 da.no.sv_665
  // [02e0]
  0x0a1704ad, 0x00000515, 0x1300040d, 0x00000a2d,   // ru.sr.mk_643 fr.un.un_700  fi.et.un_540 mk.un.un_A00
  0x1c00090e, 0x021808a4, 0x3f000314, 0x12001812,   // hi.mr.un_550 no.ga.da_433  nl.af.un_660 ar.ur.un_640
  0x290f10ee, 0x00005315, 0x04006404, 0x2008190c,   // lt.lv.sl_422 ht.un.un_700  lg.fi.un_320 gl.no.sq_543
  0x27002104, 0x18211208, 0x00000403, 0x04080a08,   // jw.gd.un_320 ur.fa.ar_443  fi.un.un_300 mk.uk.ru_443
  // [02f0]
  0x17002914, 0x3f1629a0, 0x0a04075a, 0x070a1713,   // sl.sr.un_660 sl.hr.af_322  bg.ru.mk_553 sr.mk.bg_665
  0x64001c07, 0x06182707, 0x17162905, 0x081206a6,   // id.lg.un_420 gd.ga.de_432  sl.hr.sr_333 de.hu.no_521
  0x04645504, 0x0d130404, 0x53171605, 0x0000070f,   // rw.lg.fi_332 fi.et.cs_332  hr.sr.ht_333 bg.un.un_600
  0x02000c05, 0x12002113, 0x07001714, 0x10000f02,   // sv.da.un_330 fa.ur.un_650  sr.bg.un_660 lv.lt.un_220
  // [0300]
  0x19000b05, 0x06000c0c, 0x1c001305, 0x0400130d,   // es.gl.un_330 sv.de.un_530  bh.mr.un_330 et.fi.un_540
  0x0c020812, 0x27001602, 0x10001304, 0x08020caf,   // no.da.sv_654 hr.gd.un_220  et.lt.un_320 sv.da.no_655
  0x0e000f07, 0x020c0f07, 0x29171605, 0x13046409,   // lv.is.un_420 lv.sv.da_432  hr.sr.sl_333 lg.fi.et_444
  0x08000c18, 0x00006403, 0x12000411, 0x1c09130b,   // sv.no.un_740 lg.un.un_300  fi.hu.un_630 bh.hi.mr_542
  // [0310]
  0x0000230a, 0x00000d24, 0x00001801, 0x3f0c0807,   // ca.un.un_500 cs.un.un_900  ga.un.un_200 no.sv.af_432
  0x2d000d12, 0x27001812, 0x23016ba0, 0x01002412,   // cs.sk.un_640 ga.gd.un_640  ceb.en.ca_322 yi.iw.un_640
  0x2700180b, 0x01002413, 0x07000a08, 0x2d000d21,   // ga.gd.un_520 yi.iw.un_650  mk.bg.un_430 cs.sk.un_860
  0x0f0b100c, 0x2d000d0d, 0x1a005521, 0x0e170ca0,   // lt.es.lv_543 cs.sk.un_540  rw.tl.un_860 sv.sr.is_322
  // [0320]
  0x12000507, 0x3f0f1702, 0x2d1307a0, 0x170413ad,   // fr.hu.un_420 sr.lv.af_222  it.et.sk_322 et.fi.sr_643
  0x0900130d, 0x13091caf, 0x080c21ee, 0x11002802,   // bh.hi.un_540 mr.hi.bh_655  jw.sv.no_422 sw.ro.un_220
  0x00000406, 0x0e0c08ad, 0x0d1a0fa0, 0x21000104,   // fi.un.un_400 no.sv.is_643  lv.tl.cs_322 en.jw.un_320
  0x2a000112, 0x0300210b, 0x0a2855af, 0x10170804,   // en.mt.un_640 jw.nl.un_520  rw.sw.pt_655 uk.sr.be_332
  // [0330]
  0x0864120c, 0x3f1364a9, 0x0000121c, 0x2d000d18,   // hu.lg.no_543 lg.et.af_544  ur.un.un_800 cs.sk.un_740
  0x0d002d12, 0x64003f1a, 0x17000a02, 0x01002b02,   // sk.cs.un_640 af.lg.un_760  mk.sr.un_220 vi.en.un_220
  0x080704a9, 0x21531a04, 0x2d000d19, 0x0000060a,   // ru.bg.uk_544 tl.ht.jw_332  cs.sk.un_750 de.un.un_500
  0x2a000602, 0x1b645508, 0x31001b12, 0x53001e0d,   // de.mt.un_220 rw.lg.tr_443  tr.az.un_640 ms.ht.un_540
  // [0340]
  0x0400070e, 0x18002704, 0x3f002108, 0x0e0c0807,   // bg.ru.un_550 gd.ga.un_320  jw.af.un_430 no.sv.is_432
  0x53080208, 0x00003f01, 0x070a1107, 0x080c6e07,   // da.no.ht_443 af.un.un_200  ro.mk.bg_432 blu.sv.no_432
  0x0500120c, 0x02000e04, 0x532d0d04, 0x0a001702,   // hu.fr.un_530 is.da.un_320  cs.sk.ht_332 sr.mk.un_220
  0x1e006e08, 0x00002801, 0x01000608, 0x060713a7,   // blu.ms.un_430 sw.un.un_200  de.en.un_430 et.it.de_532
  // [0350]
  0x091202ee, 0x01072308, 0x08000413, 0x1f002904,   // da.hu.pl_422 ca.it.en_443  ru.uk.un_650 sl.cy.un_320
  0x1300090d, 0x00000d0a, 0x07001212, 0x12002122,   // hi.bh.un_540 cs.un.un_500  hu.it.un_640 fa.ur.un_870
  0x53000702, 0x0000530a, 0x28005513, 0x08000212,   // it.ht.un_220 ht.un.un_500  rw.sw.un_650 da.no.un_640
  0x1b000205, 0x09001c08, 0x24000120, 0x00002a0f,   // da.tr.un_330 mr.hi.un_430  iw.yi.un_850 mt.un.un_600
  // [0360]
  0x070508ee, 0x08020711, 0x08000a0c, 0x05291602,   // no.fr.it_422 it.da.no_653  mk.uk.un_530 hr.sl.fr_222
  0x08000c12, 0x21001802, 0x172d0d05, 0x2a070e02,   // sv.no.un_640 ar.fa.un_220  cs.sk.sr_333 is.it.mt_222
  0x070a1704, 0x07001702, 0x31001b23, 0x21181212,   // sr.mk.bg_332 sr.bg.un_220  tr.az.un_880 ur.ar.fa_654
  0x08000408, 0x2b002304, 0x0a0408a4, 0x0a0408a9,   // ru.uk.un_430 ca.vi.un_320  uk.ru.mk_433 uk.ru.mk_544
  // [0370]
  0x00000a15, 0x00005503, 0x1218210c, 0x041008a4,   // mk.un.un_700 rw.un.un_300  fa.ar.ur_543 uk.be.ru_433
  0x07170a04, 0x09002d02, 0x11170408, 0x170804a0,   // mk.sr.bg_332 sk.pl.un_220  ru.sr.ro_443 ru.uk.sr_322
  0x09001c1a, 0x100a0760, 0x31001b14, 0x28005507,   // mr.hi.un_760 bg.mk.be_664  tr.az.un_660 rw.sw.un_420
  0x0400100e, 0x02000c02, 0x0d002a13, 0x062a04ee,   // lt.fi.un_550 sv.da.un_220  mt.cs.un_650 fi.mt.de_422
  // [0380]
  0x1c0913a4, 0x00001b03, 0x0000070a, 0x11006b13,   // bh.hi.mr_433 tr.un.un_300  it.un.un_500 ceb.ro.un_650
  0x07000a02, 0x2a00161a, 0x0f21130c, 0x09001307,   // mk.bg.un_220 hr.mt.un_760  et.jw.lv_543 bh.hi.un_420
  0x211e1c5a, 0x070911ee, 0x171b2d07, 0x6b000c05,   // id.ms.jw_553 ro.pl.it_422  sk.tr.sr_432 sv.ceb.un_330
  0x1100210c, 0x0c080205, 0x06000c04, 0x1f002808,   // jw.ro.un_530 da.no.sv_333  sv.de.un_320 sw.cy.un_430
  // [0390]
  0x07000a04, 0x0000190f, 0x00002306, 0x162d0d04,   // mk.bg.un_320 gl.un.un_600  ca.un.un_400 cs.sk.hr_332
  0x1e1c0ba4, 0x00001106, 0x13002921, 0x24000118,   // es.id.ms_433 ro.un.un_400  sl.et.un_860 iw.yi.un_740
  0x03000c02, 0x28002b13, 0x17001621, 0x08020c05,   // sv.nl.un_220 vi.sw.un_650  hr.sr.un_860 sv.da.no_333
  0x291617ec, 0x1329110c, 0x07040a04, 0x23001907,   // sr.hr.sl_644 ro.sl.et_543  mk.ru.bg_332 gl.ca.un_420
  // [03a0]
  0x171621ec, 0x0e550614, 0x6b001a22, 0x040e25ec,   // jw.hr.sr_644 de.rw.is_666  tl.ceb.un_870 eu.is.fi_644
  0x17165504, 0x0b171604, 0x04001313, 0x132a0808,   // rw.hr.sr_332 hr.sr.es_332  et.fi.un_650 no.mt.et_443
  0x29001213, 0x210e0811, 0x53043f04, 0x1716290c,   // hu.sl.un_650 no.is.jw_653  af.fi.ht_332 sl.hr.sr_543
  0x212a1607, 0x0000041c, 0x06023f07, 0x1227060c,   // hr.mt.jw_432 fi.un.un_800  af.da.de_432 de.gd.hu_543
  // [03b0]
  0x0f001707, 0x0a0708a4, 0x10080405, 0x06003f0c,   // sr.lv.un_420 uk.bg.mk_433  ru.uk.be_333 af.de.un_530
  0x08002019, 0x033f1a05, 0x1f002313, 0x09000f0d,   // sq.no.un_750 tl.af.nl_333  ca.cy.un_650 lv.pl.un_540
  0x2a001214, 0x0f001a04, 0x0f002908, 0x20002a19,   // hu.mt.un_660 tl.lv.un_320  sl.lv.un_430 mt.sq.un_750
  0x00003f0a, 0x160917ec, 0x00006b1c, 0x0f0413ad,   // af.un.un_500 sr.pl.hr_644  ceb.un.un_800 et.fi.lv_643
  // [03c0]
  0x11182712, 0x0c000804, 0x25001902, 0x211c1ead,   // gd.ga.ro_654 no.sv.un_320  gl.eu.un_220 ms.id.jw_643
  0x03003f13, 0x1200211a, 0x17000704, 0x18211212,   // af.nl.un_650 fa.ur.un_760  bg.sr.un_320 ur.fa.ar_654
  0x21130408, 0x171629a0, 0x071104af, 0x00002524,   // fi.et.jw_443 sl.hr.sr_322  ru.ro.bg_655 eu.un.un_900
  0x0e020ca4, 0x08021fa9, 0x080102a4, 0x25001912,   // sv.da.is_433 cy.da.no_544  da.en.no_433 gl.eu.un_640
  // [03d0]
  0x00000803, 0x131e1c14, 0x29162aa7, 0x07100811,   // no.un.un_300 id.ms.et_666  mt.hr.sl_532 uk.be.bg_653
  0x080410ec, 0x1e002804, 0x0a071704, 0x010c1fee,   // be.ru.uk_644 sw.ms.un_320  sr.bg.mk_332 cy.sv.en_422
  0x0e080213, 0x041b0ea4, 0x1e002104, 0x02000819,   // da.no.is_665 is.tr.fi_433  jw.ms.un_320 no.da.un_750
  0x29002a22, 0x2025060c, 0x0d001c12, 0x3f04250c,   // mt.sl.un_870 de.eu.sq_543  mr.ne.un_640 eu.fi.af_543
  // [03e0]
  0x2d0d29a0, 0x170816a0, 0x1c091311, 0x12162aa4,   // sl.cs.sk_322 hr.no.sr_322  bh.hi.mr_653 mt.hr.hu_433
  0x0c080255, 0x10081707, 0x00000a0f, 0x2d0d1b12,   // da.no.sv_442 sr.uk.be_432  pt.un.un_600 tr.cs.sk_654
  0x021a3fad, 0x2500010d, 0x04020c04, 0x16290c0c,   // af.tl.da_643 en.eu.un_540  sv.da.fi_332 sv.sl.hr_543
  0x18211204, 0x060b0113, 0x082d0d08, 0x6b011fa6,   // ur.fa.ar_332 en.es.de_665  cs.sk.no_443 cy.en.ceb_521
  // [03f0]
  0x20032a55, 0x09001f09, 0x25001314, 0x53001104,   // mt.nl.sq_442 cy.pl.un_440  et.eu.un_660 ro.ht.un_320
  0x0e00080e, 0x07170a0c, 0x16001311, 0x3f001b19,   // no.is.un_550 mk.sr.bg_543  et.hr.un_630 tr.af.un_750
  0x17101104, 0x232705a4, 0x00001715, 0x121821a4,   // ro.be.sr_332 fr.gd.ca_433  sr.un.un_700 fa.ar.ur_433
  0x1200210d, 0x17001613, 0x0700041a, 0x5553280e,   // fa.ur.un_540 hr.sr.un_650  ru.bg.un_760 sw.ht.rw_555

  // [0400]
  0x27001102, 0x0c16290c, 0x08001014, 0x1f0c0207,   // ro.gd.un_220 sl.hr.sv_543  be.uk.un_660 da.sv.cy_432
  0x28551fa4, 0x12001808, 0x211e1cec, 0x1e000307,   // cy.rw.sw_433 ar.ur.un_430  id.ms.jw_644 nl.ms.un_420
  0x06000804, 0x00001003, 0x3f000207, 0x172916a0,   // no.de.un_320 lt.un.un_300  da.af.un_420 hr.sl.sr_322
  0x17002504, 0x00001237, 0x102d0d13, 0x122d0d05,   // eu.sr.un_320 ur.un.un_B00  cs.sk.lt_665 cs.sk.hu_333
  // [0410]
  0x090d0204, 0x0c001f19, 0x1f0a07a9, 0x1800210d,   // da.cs.pl_332 cy.sv.un_750  it.pt.cy_544 fa.ar.un_540
  0x17102912, 0x10090fa7, 0x21001213, 0x64003104,   // sl.lt.sr_654 lv.pl.lt_532  ur.fa.un_650 az.lg.un_320
  0x2000550d, 0x180827ad, 0x29172da9, 0x64005519,   // rw.sq.un_540 gd.no.ga_643  sk.sr.sl_544 rw.lg.un_750
  0x0b205508, 0x6b212a0c, 0x12001b0e, 0x122d0dee,   // rw.sq.es_443 mt.jw.ceb_543  tr.hu.un_550 cs.sk.hu_422
  // [0420]
  0x2a001208, 0x0000040a, 0x29172d55, 0x080407a4,   // hu.mt.un_430 ru.un.un_500  sk.sr.sl_442 bg.ru.uk_433
  0x17000802, 0x10005505, 0x17070408, 0x12182108,   // uk.sr.un_220 rw.lt.un_330  ru.bg.sr_443 fa.ar.ur_443
  0x2855640c, 0x00001c24, 0x16001707, 0x08270e05,   // lg.rw.sw_543 mr.un.un_900  sr.hr.un_420 is.gd.no_333
  0x21001212, 0x10171613, 0x06100e04, 0x09002d0d,   // ur.fa.un_640 hr.sr.lt_665  is.lt.de_332 sk.pl.un_540
  // [0430]
  0x1a006b07, 0x0a001714, 0x170407a0, 0x1c090d12,   // ceb.tl.un_420 sr.mk.un_660  bg.ru.sr_322 ne.hi.mr_654
  0x190a1fa4, 0x10000205, 0x011c040c, 0x1c09130c,   // cy.pt.gl_433 da.lt.un_330  fi.id.en_543 bh.hi.mr_543
  0x05255308, 0x07040808, 0x205553a7, 0x1c0d0960,   // ht.eu.fr_443 uk.ru.bg_443  ht.rw.sq_532 hi.ne.mr_664
  0x55001c08, 0x00006b0f, 0x2d0d29ad, 0x00001915,   // id.rw.un_430 ceb.un.un_600  sl.cs.sk_643 gl.un.un_700
  // [0440]
  0x13000907, 0x213f64a4, 0x6e0205ee, 0x0000230f,   // hi.bh.un_420 lg.af.jw_433  fr.da.blu_422 ca.un.un_600
  0x531a2da0, 0x040a070d, 0x00000624, 0x64000405,   // sk.tl.ht_322 bg.mk.ru_554  de.un.un_900 fi.lg.un_330
  0x31001b0d, 0x290c0860, 0x010603a9, 0x100f0608,   // tr.az.un_540 no.sv.sl_664  nl.de.en_544 de.lv.lt_443
  0x211a1f09, 0x1700160d, 0x2710010b, 0x060e050c,   // cy.tl.jw_444 hr.sr.un_540  en.lt.gd_542 fr.is.de_543
  // [0450]
  0x1a216b07, 0x55001a1b, 0x211e1c14, 0x00000b03,   // ceb.jw.tl_432 tl.rw.un_770  id.ms.jw_666 es.un.un_300
  0x13000c0c, 0x64101a0c, 0x1c001312, 0x1b003109,   // sv.et.un_530 tl.lt.lg_543  bh.mr.un_640 az.tr.un_440
  0x556b1a0c, 0x03133f14, 0x1a536b10, 0x1e1c2102,   // tl.ceb.rw_543 af.et.nl_666  ceb.ht.tl_642 jw.id.ms_222
  0x0d00090e, 0x19110402, 0x1b00310e, 0x0428190c,   // hi.ne.un_550 fi.ro.gl_222  az.tr.un_550 gl.sw.fi_543
  // [0460]
  0x1e1c1a09, 0x13000912, 0x551a64a9, 0x1b00311a,   // tl.id.ms_444 hi.bh.un_640  lg.tl.rw_544 az.tr.un_760
  0x211e1c13, 0x130428ee, 0x04100aa0, 0x19211c05,   // id.ms.jw_665 sw.fi.et_422  mk.be.ru_322 id.jw.gl_333
  0x28001a04, 0x210c0812, 0x1e001c02, 0x0e001704,   // tl.sw.un_320 no.sv.jw_654  id.ms.un_220 sr.is.un_320
  0x09001308, 0x55001e04, 0x070408ec, 0x2a000714,   // bh.hi.un_430 ms.rw.un_320  uk.ru.bg_644 it.mt.un_660
  // [0470]
  0x17001619, 0x31001b04, 0x211a550d, 0x0b0a1905,   // hr.sr.un_750 tr.az.un_320  rw.tl.jw_554 gl.pt.es_333
  0x211b6b04, 0x16005505, 0x3f000214, 0x06000205,   // ceb.tr.jw_332 rw.hr.un_330  da.af.un_660 da.de.un_330
  0x29001704, 0x06000302, 0x23052d07, 0x06006e0c,   // sr.sl.un_320 nl.de.un_220  sk.fr.ca_432 blu.de.un_530
  0x236e0508, 0x1720160d, 0x1f050107, 0x230105ec,   // fr.blu.ca_443 hr.sq.sr_554  en.fr.cy_432 fr.en.ca_644
  // [0480]
  0x110717a4, 0x1225550c, 0x1708060c, 0x1a645509,   // sr.bg.ro_433 rw.eu.hu_543  de.no.sr_543 rw.lg.tl_444
  0x00002a1c, 0x25001904, 0x12006b04, 0x21001a04,   // mt.un.un_800 gl.eu.un_320  ceb.hu.un_320 tl.jw.un_320
  0x53001819, 0x0b191312, 0x1e09210b, 0x28641c07,   // ga.ht.un_750 et.gl.es_654  jw.pl.ms_542 id.lg.sw_432
  0x00002a24, 0x28002512, 0x0a23050c, 0x1b003108,   // mt.un.un_900 eu.sw.un_640  fr.ca.pt_543 az.tr.un_430
  // [0490]
  0x2a002502, 0x55311ca4, 0x0a2305af, 0x21001218,   // eu.mt.un_220 id.az.rw_433  fr.ca.pt_655 ur.fa.un_740
  0x55312809, 0x2300051a, 0x29171613, 0x0710170c,   // sw.az.rw_444 fr.ca.un_760  hr.sr.sl_665 sr.be.bg_543
  0x191a6b12, 0x10040804, 0x06000207, 0x1c0421ad,   // ceb.tl.gl_654 uk.ru.be_332  da.de.un_420 jw.fi.id_643
  0x13090d0e, 0x06006e04, 0x18040807, 0x0a1711ee,   // ne.hi.bh_555 blu.de.un_320  no.fi.ga_432 ro.sr.mk_422
  // [04a0]
  0x0b002314, 0x0a170813, 0x6b050607, 0x12002102,   // ca.es.un_660 uk.sr.mk_665  de.fr.ceb_432 fa.ur.un_220
  0x02001e0c, 0x0b0a190e, 0x1f000904, 0x08002011,   // ms.da.un_530 gl.pt.es_555  pl.cy.un_320 sq.no.un_630
  0x1b00090c, 0x55002108, 0x09000d0d, 0x02206ea6,   // pl.tr.un_530 jw.rw.un_430  ne.hi.un_540 blu.sq.da_521
  0x19230ba0, 0x08066ea0, 0x2305190c, 0x3f0229ec,   // es.ca.gl_322 blu.de.no_322  gl.fr.ca_543 sl.da.af_644
  // [04b0]
  0x2305010c, 0x086e0607, 0x070a170d, 0x12281fa7,   // en.fr.ca_543 de.blu.no_432  sr.mk.bg_554 cy.sw.hu_532
  0x06000a02, 0x0b23050c, 0x041f060c, 0x060916ad,   // pt.de.un_220 fr.ca.es_543  de.cy.fi_543 hr.pl.de_643
  0x05001113, 0x23000521, 0x6e0628ec, 0x552305ad,   // ro.fr.un_650 fr.ca.un_860  sw.de.blu_644 fr.ca.rw_643
  0x1c091309, 0x13001108, 0x2100280d, 0x17000a1a,   // bh.hi.mr_444 ro.et.un_430  sw.jw.un_540 mk.sr.un_760
  // [04c0]
  0x0f1108ad, 0x0c000208, 0x286e2bee, 0x171629a9,   // no.ro.lv_643 da.sv.un_430  vi.blu.sw_422 sl.hr.sr_544
  0x17002a04, 0x0c003f04, 0x1e005507, 0x2a002305,   // mt.sr.un_320 af.sv.un_320  rw.ms.un_420 ca.mt.un_330
  0x12022707, 0x12000612, 0x0c080214, 0x2b002302,   // gd.da.hu_432 de.hu.un_640  da.no.sv_666 ca.vi.un_220
  0x1c000908, 0x21001208, 0x0000031c, 0x0b04050c,   // hi.mr.un_430 ur.fa.un_430  nl.un.un_800 fr.fi.es_543
  // [04d0]
  0x130b04a7, 0x162d2908, 0x04002713, 0x066b0104,   // fi.es.et_532 sl.sk.hr_443  gd.fi.un_650 en.ceb.de_332
  0x1b003114, 0x04000104, 0x27001823, 0x230802a4,   // az.tr.un_660 en.fi.un_320  ga.gd.un_880 da.no.ca_433
  0x31043f09, 0x10001702, 0x05000804, 0x190b0411,   // af.fi.az_444 sr.be.un_220  no.fr.un_320 fi.es.gl_653
  0x2d0d1aa0, 0x01033f08, 0x0a04110c, 0x126428a7,   // tl.cs.sk_322 af.nl.en_443  ro.ru.mk_543 sw.lg.hu_532
  // [04e0]
  0x31001702, 0x08005508, 0x6b2b010c, 0x181b2007,   // sr.az.un_220 rw.no.un_430  en.vi.ceb_543 sq.tr.ga_432
  0x2900121a, 0x6b001c0c, 0x1800270e, 0x17081008,   // hu.sl.un_760 id.ceb.un_530  gd.ga.un_550 be.uk.sr_443
  0x21001219, 0x091c0da4, 0x0701270c, 0x0d001c19,   // ur.fa.un_750 ne.mr.hi_433  gd.en.it_543 mr.ne.un_750
  0x2a18280c, 0x2000080c, 0x04005302, 0x13001c18,   // sw.ga.mt_543 no.sq.un_530  ht.fi.un_220 mr.bh.un_740
  // [04f0]
  0x2a000808, 0x2b006e07, 0x08000211, 0x2902070c,   // no.mt.un_430 blu.vi.un_420  da.no.un_630 it.da.sl_543
  0x01000302, 0x285553ee, 0x1e1c210e, 0x55002808,   // nl.en.un_220 ht.rw.sw_422  jw.id.ms_555 sw.rw.un_430
  0x281b31af, 0x312518a4, 0x1a000c0e, 0x0000550a,   // az.tr.sw_655 ga.eu.az_433  sv.tl.un_550 rw.un.un_500
  0x09001f13, 0x1b04310c, 0x531b310c, 0x0f001005,   // cy.pl.un_650 az.fi.tr_543  az.tr.ht_543 lt.lv.un_330
  // [0500]
  0x00001724, 0x0d002d0c, 0x01000707, 0x09162902,   // sr.un.un_900 sk.cs.un_530  it.en.un_420 sl.hr.pl_222
  0x0408025a, 0x0b07250c, 0x17001604, 0x065305ac,   // da.no.fi_553 eu.it.es_543  hr.sr.un_320 fr.ht.de_632
  0x13000607, 0x0b1304a9, 0x2d0d0a0c, 0x3f6b01ee,   // de.et.un_420 fi.et.es_544  pt.cs.sk_543 en.ceb.af_422
  0x120b040c, 0x2b000713, 0x170708ec, 0x6400551b,   // fi.es.hu_543 it.vi.un_650  uk.bg.sr_644 rw.lg.un_770
  // [0510]
  0x00003103, 0x2500070d, 0x6b020812, 0x020523a4,   // az.un.un_300 it.eu.un_540  no.da.ceb_654 ca.fr.da_433
  0x00001824, 0x55001b13, 0x1e1c64a0, 0x1c000d09,   // ar.un.un_900 tr.rw.un_650  lg.id.ms_322 ne.mr.un_440
  0x1c0d09af, 0x0a001908, 0x0400080d, 0x00000a24,   // hi.ne.mr_655 gl.pt.un_430  uk.ru.un_540 pt.un.un_900
  0x1b252a0c, 0x13090dec, 0x09000d22, 0x2b110ba7,   // mt.eu.tr_543 ne.hi.bh_644  ne.hi.un_870 es.ro.vi_532
  // [0520]
  0x0f001604, 0x21171613, 0x1b211ea0, 0x00000c03,   // hr.lv.un_320 hr.sr.jw_665  ms.jw.tr_322 sv.un.un_300
  0x0b0a0cee, 0x17070a09, 0x086e6ba0, 0x0e080202,   // sv.pt.es_422 mk.bg.sr_444  ceb.blu.no_322 da.no.is_222
  0x1716290e, 0x2b211ca0, 0x04000804, 0x091c0dec,   // sl.hr.sr_555 id.jw.vi_322  uk.ru.un_320 ne.mr.hi_644
  0x17000a14, 0x1307120c, 0x2b001c04, 0x091c1307,   // mk.sr.un_660 hu.it.et_543  id.vi.un_320 bh.mr.hi_432
  // [0530]
  0x0b171609, 0x06121b07, 0x0c020807, 0x0c000808,   // hr.sr.es_444 tr.hu.de_432  no.da.sv_432 no.sv.un_430
  0x1c130960, 0x0b1c1ea0, 0x0b0a23ee, 0x17001623,   // hi.bh.mr_664 ms.id.es_322  ca.pt.es_422 hr.sr.un_880
  0x0e0c02a0, 0x2b000a02, 0x12552a07, 0x29000702,   // da.sv.is_322 pt.vi.un_220  mt.rw.hu_432 it.sl.un_220
  0x0c00081a, 0x2d000d13, 0x00003f0f, 0x27001804,   // no.sv.un_760 cs.sk.un_650  af.un.un_600 ga.gd.un_320
  // [0540]
  0x25001e07, 0x09002504, 0x02000c0d, 0x19000721,   // ms.eu.un_420 eu.pl.un_320  sv.da.un_540 it.gl.un_860
  0x55166405, 0x04170808, 0x081007a4, 0x2d0d5505,   // lg.hr.rw_333 uk.sr.ru_443  bg.be.uk_433 rw.cs.sk_333
  0x12102555, 0x02046b04, 0x0b000c02, 0x64002504,   // eu.lt.hu_442 ceb.fi.da_332  sv.es.un_220 eu.lg.un_320
  0x641825a7, 0x19000b0b, 0x00000215, 0x2100200c,   // eu.ga.lg_532 es.gl.un_520  da.un.un_700 sq.jw.un_530
  // [0550]
  0x531a6b08, 0x2b100405, 0x0d000105, 0x00001301,   // ceb.tl.ht_443 fi.lt.vi_333  en.cs.un_330 et.un.un_200
  0x1a536b07, 0x0c000f04, 0x53172da4, 0x08020ca4,   // ceb.ht.tl_432 lv.sv.un_320  sk.sr.ht_433 sv.da.no_433
  0x2b04050c, 0x1000530d, 0x31556407, 0x0c080e07,   // fr.fi.vi_543 ht.lt.un_540  lg.rw.az_432 is.no.sv_432
  0x00002b01, 0x1f001e1a, 0x29285309, 0x162917a0,   // vi.un.un_200 ms.cy.un_760  ht.sw.sl_444 sr.sl.hr_322
  // [0560]
  0x08001021, 0x110d12ad, 0x12006402, 0x051f010b,   // be.uk.un_860 hu.cs.ro_643  lg.hu.un_220 en.cy.fr_542
  0x53286404, 0x5500281b, 0x18002504, 0x1c090daf,   // lg.sw.ht_332 sw.rw.un_770  eu.ga.un_320 ne.hi.mr_655
  0x08000223, 0x091c0d08, 0x090d13ec, 0x6b0425a7,   // da.no.un_880 ne.mr.hi_443  bh.ne.hi_644 eu.fi.ceb_532
  0x171625a0, 0x0b272511, 0x18120e5a, 0x550810a0,   // eu.hr.sr_322 eu.gd.es_653  is.hu.ga_553 lt.no.rw_322
  // [0570]
  0x0c1c1f0c, 0x0327180c, 0x04100813, 0x0a070408,   // cy.id.sv_543 ga.gd.nl_543  uk.be.ru_665 ru.bg.mk_443
  0x190d0b0c, 0x1300270c, 0x06001209, 0x1c000d12,   // es.cs.gl_543 gd.et.un_530  hu.de.un_440 ne.mr.un_640
  0x051f010c, 0x06080fa7, 0x0400100c, 0x083f0607,   // en.cy.fr_543 lv.no.de_532  be.ru.un_530 de.af.no_432
  0x1c000d07, 0x20000b22, 0x0f000913, 0x020c0804,   // ne.mr.un_420 es.sq.un_870  pl.lv.un_650 no.sv.da_332
  // [0580]
  0x21001207, 0x091c135a, 0x1b006e07, 0x0c000e1a,   // ur.fa.un_420 bh.mr.hi_553  blu.tr.un_420 is.sv.un_760
  0x27060204, 0x251218ee, 0x092555a7, 0x1c0d1314,   // da.de.gd_332 ga.hu.eu_422  rw.eu.pl_532 bh.ne.mr_666
  0x02060807, 0x29001102, 0x1c092907, 0x532520a4,   // no.de.da_432 ro.sl.un_220  sl.pl.id_432 sq.eu.ht_433
  0x20002a04, 0x06003f08, 0x09000e04, 0x170a07ee,   // mt.sq.un_320 af.de.un_430  is.pl.un_320 bg.mk.sr_422
  // [0590]
  0x04002d08, 0x13091c14, 0x17081107, 0x02050112,   // sk.fi.un_430 mr.hi.bh_666  ro.uk.sr_432 en.fr.da_654
  0x21001204, 0x135504a0, 0x3f271f0c, 0x0f001021,   // ur.fa.un_320 fi.rw.et_322  cy.gd.af_543 lt.lv.un_860
  0x0c081207, 0x1f05010c, 0x092521ee, 0x17040705,   // hu.no.sv_432 en.fr.cy_543  jw.eu.pl_422 bg.ru.sr_333
  0x05000407, 0x08001702, 0x01551f0c, 0x1b063f0c,   // fi.fr.un_420 sr.uk.un_220  cy.rw.en_543 af.de.tr_543
  // [05a0]
  0x12006404, 0x07170aa0, 0x1c0d1307, 0x17080707,   // lg.hu.un_320 mk.sr.bg_322  bh.ne.mr_432 bg.uk.sr_432
  0x21001f08, 0x1f000c07, 0x0d000904, 0x0c0e0808,   // cy.jw.un_430 sv.cy.un_420  hi.ne.un_320 no.is.sv_443
  0x0900550c, 0x1a080211, 0x0c000604, 0x1a09550b,   // rw.pl.un_530 da.no.tl_653  de.sv.un_320 rw.pl.tl_542
  0x17040704, 0x55641b04, 0x04001f04, 0x13002a0c,   // bg.ru.sr_332 tr.lg.rw_332  cy.fi.un_320 mt.et.un_530
  // [05b0]
  0x163f0402, 0x2928110e, 0x6b2a310b, 0x04122aa9,   // fi.af.hr_222 ro.sw.sl_555  az.mt.ceb_542 mt.hu.fi_544
  0x20001114, 0x04552505, 0x03006b07, 0x1c000d19,   // ro.sq.un_660 eu.rw.fi_333  ceb.nl.un_420 ne.mr.un_750
  0x2811550c, 0x1f002704, 0x5564280c, 0x091229ee,   // rw.ro.sw_543 gd.cy.un_320  sw.lg.rw_543 sl.hu.pl_422
  0x12182112, 0x2016110c, 0x27002004, 0x21550ba0,   // fa.ar.ur_654 ro.hr.sq_543  sq.gd.un_320 es.rw.jw_322
  // [05c0]
  0x070a1108, 0x2a00180d, 0x07170a08, 0x13122aa4,   // ro.mk.bg_443 ga.mt.un_540  mk.sr.bg_443 mt.hu.et_433
  0x0407110b, 0x2d271f0d, 0x231e1c0c, 0x0a000705,   // ro.bg.ru_542 cy.gd.sk_554  id.ms.ca_543 bg.mk.un_330
  0x0e1a6b12, 0x19000b07, 0x21001c04, 0x5300270b,   // ceb.tl.is_654 es.gl.un_420  id.jw.un_320 gd.ht.un_520
  0x1f00270d, 0x292d0d60, 0x1f0155a0, 0x162112a9,   // gd.cy.un_540 cs.sk.sl_664  rw.en.cy_322 hu.jw.hr_544
  // [05d0]
  0x21000302, 0x2d0d09a4, 0x08070a09, 0x2d000d1a,   // nl.jw.un_220 pl.cs.sk_433  mk.bg.uk_444 cs.sk.un_760
  0x036b0807, 0x55001107, 0x08000108, 0x021113ee,   // no.ceb.nl_432 ro.rw.un_420  en.no.un_430 et.ro.da_422
  0x08041007, 0x11171608, 0x31272d02, 0x64002813,   // be.ru.uk_432 hr.sr.ro_443  sk.gd.az_222 sw.lg.un_650
  0x09001304, 0x31001a04, 0x29551155, 0x1b0b0a04,   // bh.hi.un_320 tl.az.un_320  ro.rw.sl_442 pt.es.tr_332
  // [05e0]
  0x2d0d010e, 0x040711af, 0x29171608, 0x281855a0,   // en.cs.sk_555 ro.bg.ru_655  hr.sr.sl_443 rw.ga.sw_322
  0x11645513, 0x033f27a9, 0x29551107, 0x1c000912,   // rw.lg.ro_665 gd.af.nl_544  ro.rw.sl_432 hi.mr.un_640
  0x1704070c, 0x040e060c, 0x080411af, 0x04001e04,   // bg.ru.sr_543 de.is.fi_543  ro.ru.uk_655 ms.fi.un_320
  0x033f1f0c, 0x0d002d08, 0x00000e03, 0x032d29a7,   // cy.af.nl_543 sk.cs.un_430  is.un.un_300 sl.sk.nl_532
  // [05f0]
  0x05000104, 0x312864ee, 0x0a0717a4, 0x12000e02,   // en.fr.un_320 lg.sw.az_422  sr.bg.mk_433 is.hu.un_220
  0x1707040d, 0x00001201, 0x122d0d09, 0x0d001c08,   // ru.bg.sr_554 hu.un.un_200  cs.sk.hu_444 mr.ne.un_430
  0x09001c07, 0x1b003112, 0x2d0d12af, 0x092d1707,   // mr.hi.un_420 az.tr.un_640  hu.cs.sk_655 sr.sk.pl_432
  0x090d1c11, 0x12012da0, 0x2b000302, 0x27000307,   // mr.ne.hi_653 sk.en.hu_322  nl.vi.un_220 nl.gd.un_420
  // [0600]
  0x1e001c08, 0x6b000213, 0x01006b04, 0x170a1105,   // id.ms.un_430 da.ceb.un_650  ceb.en.un_320 ro.mk.sr_333
  0x020e0c14, 0x20122aa0, 0x1b6e3fa4, 0x10170a08,   // sv.is.da_666 mt.hu.sq_322  af.blu.tr_433 mk.sr.be_443
  0x18002707, 0x21001214, 0x1c0913ee, 0x1b003f02,   // gd.ga.un_420 ur.fa.un_660  bh.hi.mr_422 af.tr.un_220
  0x13122a07, 0x25081e0c, 0x0000272d, 0x6b2801a7,   // mt.hu.et_432 ms.no.eu_543  gd.un.un_A00 en.sw.ceb_532
  // [0610]
  0x17070aaf, 0x6e001f13, 0x29001605, 0x6e020c5a,   // mk.bg.sr_655 cy.blu.un_650  hr.sl.un_330 sv.da.blu_553
  0x211e1c12, 0x06000812, 0x1f0511ad, 0x530801ad,   // id.ms.jw_654 no.de.un_640  ro.fr.cy_643 en.no.ht_643
  0x2d291607, 0x080219ee, 0x0c002308, 0x0b190a08,   // hr.sl.sk_432 gl.da.no_422  ca.sv.un_430 pt.gl.es_443
  0x04001004, 0x280c55ad, 0x6b005512, 0x06006e11,   // be.ru.un_320 rw.sv.sw_643  rw.ceb.un_640 blu.de.un_630
  // [0620]
  0x17162907, 0x230a19ee, 0x112d06ee, 0x21551e0c,   // sl.hr.sr_432 gl.pt.ca_422  de.sk.ro_422 ms.rw.jw_543
  0x6e6b0107, 0x01000b02, 0x00003f1c, 0x17291655,   // en.ceb.blu_432 es.en.un_220  af.un.un_800 hr.sl.sr_442
  0x2300110b, 0x3f000107, 0x0e020c13, 0x1c3f05a0,   // ro.ca.un_520 en.af.un_420  sv.da.is_665 fr.af.id_322
  0x6b000104, 0x2d5525a4, 0x0d230207, 0x190a31ee,   // en.ceb.un_320 eu.rw.sk_433  da.ca.cs_432 az.pt.gl_422
  // [0630]
  0x130d090d, 0x6b276e0c, 0x09000d1a, 0x21001f0c,   // hi.ne.bh_554 blu.gd.ceb_543  ne.hi.un_760 cy.jw.un_530
  0x05192305, 0x25001c0d, 0x1b081a08, 0x3100200d,   // ca.gl.fr_333 id.eu.un_540  tl.no.tr_443 sq.az.un_540
  0x0b2b23a0, 0x13006e09, 0x16201708, 0x16002902,   // ca.vi.es_322 blu.et.un_440  sr.sq.hr_443 sl.hr.un_220
  0x0d002d04, 0x1200180d, 0x040c2da0, 0x13001c07,   // sk.cs.un_320 ar.ur.un_540  sk.sv.fi_322 id.et.un_420
  // [0640]
  0x1200050d, 0x233f050c, 0x21181213, 0x53132aee,   // fr.hu.un_540 fr.af.ca_543  ur.ar.fa_665 mt.et.ht_422
  0x1b003113, 0x07100413, 0x3f201bee, 0x2100120d,   // az.tr.un_650 ru.be.bg_665  tr.sq.af_422 ur.fa.un_540
  0x1e0f1bee, 0x31006b02, 0x25000404, 0x00000e24,   // tr.lv.ms_422 ceb.az.un_220  fi.eu.un_320 is.un.un_900
  0x1b00060d, 0x02250e07, 0x2100121b, 0x131b31b3,   // de.tr.un_540 is.eu.da_432  ur.fa.un_770 az.tr.et_743
  // [0650]
  0x2d162904, 0x55006418, 0x0a07040c, 0x13000908,   // sl.hr.sk_332 lg.rw.un_740  ru.bg.mk_543 hi.bh.un_430
  0x19000d14, 0x2800180d, 0x64080c04, 0x0000281c,   // cs.gl.un_660 ga.sw.un_540  sv.no.lg_332 sw.un.un_800
  0x072d0d08, 0x1b0631ee, 0x1c00130e, 0x0d0907ee,   // cs.sk.it_443 az.de.tr_422  bh.mr.un_550 it.pl.cs_422
  0x18281302, 0x010206a0, 0x1b3106a4, 0x0d001c09,   // et.sw.ga_222 de.da.en_322  de.az.tr_433 mr.ne.un_440
  // [0660]
  0x20160b02, 0x2a005504, 0x551b64a9, 0x17161c02,   // es.hr.sq_222 rw.mt.un_320  lg.tr.rw_544 id.hr.sr_222
  0x17000805, 0x07040aa4, 0x0b000c04, 0x2b271802,   // uk.sr.un_330 mk.ru.bg_433  sv.es.un_320 ga.gd.vi_222
  0x0d171611, 0x00003124, 0x2700181a, 0x10080708,   // hr.sr.cs_653 az.un.un_900  ga.gd.un_760 bg.uk.be_443
  0x29092d12, 0x040a1707, 0x13000422, 0x080a1712,   // sk.pl.sl_654 sr.mk.ru_432  fi.et.un_870 sr.mk.uk_654
  // [0670]
  0x13121ba0, 0x100711ad, 0x17160daf, 0x06003113,   // tr.hu.et_322 ro.bg.be_643  cs.hr.sr_655 az.de.un_650
  0x070a17af, 0x1a00280e, 0x11000707, 0x1000110e,   // sr.mk.bg_655 sw.tl.un_550  it.ro.un_420 ro.be.un_550
  0x17100807, 0x09556404, 0x0d000b09, 0x2d0d290c,   // uk.be.sr_432 lg.rw.pl_332  es.cs.un_440 sl.cs.sk_543
  0x1b641ca0, 0x1905210c, 0x53021b0c, 0x00001a0a,   // id.lg.tr_322 jw.fr.gl_543  tr.da.ht_543 tl.un.un_500
  // [0680]
  0x2127230c, 0x0207080c, 0x2921200d, 0x1c130d08,   // ca.gd.jw_543 no.it.da_543  sq.jw.sl_554 ne.bh.mr_443
  0x2d050d0c, 0x0311080c, 0x060120a9, 0x3f02080c,   // cs.fr.sk_543 no.ro.nl_543  sq.en.de_544 no.da.af_543
  0x171602a4, 0x0703080c, 0x110a53a4, 0x171629ec,   // da.hr.sr_433 no.nl.it_543  ht.pt.ro_433 sl.hr.sr_644
  0x64080213, 0x232d0d02, 0x20002908, 0x17002904,   // da.no.lg_665 cs.sk.ca_222  sl.sq.un_430 sl.sr.un_320
  // [0690]
  0x17160da4, 0x171621a0, 0x020711af, 0x171629ee,   // cs.hr.sr_433 jw.hr.sr_322  ro.it.da_655 sl.hr.sr_422
  0x060e3f55, 0x1716210e, 0x53063f0c, 0x181221ee,   // af.is.de_442 jw.hr.sr_555  af.de.ht_543 fa.ur.ar_422
  0x2100180d, 0x01000c04, 0x2900530d, 0x08020714,   // ar.fa.un_540 sv.en.un_320  ht.sl.un_540 it.da.no_666
  0x120b190c, 0x3f001e04, 0x3f6455af, 0x080c0e0d,   // gl.es.hu_543 ms.af.un_320  rw.lg.af_655 is.sv.no_554
  // [06a0]
  0x2d0d01a4, 0x080255ec, 0x00002515, 0x0d190aee,   // en.cs.sk_433 rw.da.no_644  eu.un.un_700 pt.gl.cs_422
  0x0607080c, 0x07080a09, 0x170a11af, 0x11075308,   // no.it.de_543 mk.uk.bg_444  ro.mk.sr_655 ht.it.ro_443
  0x1b003123, 0x10040805, 0x05000b04, 0x11002102,   // az.tr.un_880 uk.ru.be_333  es.fr.un_320 jw.ro.un_220
  0x0800270c, 0x1c001e34, 0x06000112, 0x1e001004,   // gd.no.un_530 ms.id.un_A80  en.de.un_640 lt.ms.un_320
  // [06b0]
  0x2b27010c, 0x6428550b, 0x060311ee, 0x211e1c08,   // en.gd.vi_543 rw.sw.lg_542  ro.nl.de_422 id.ms.jw_443
  0x1c2b64a0, 0x06000113, 0x100a0409, 0x0f100812,   // lg.vi.id_322 en.de.un_650  ru.mk.be_444 no.lt.lv_654
  0x061b120c, 0x25000507, 0x3f000322, 0x0d000914,   // hu.tr.de_543 fr.eu.un_420  nl.af.un_870 hi.ne.un_660
  0x09000d08, 0x282b03a0, 0x290413a7, 0x210604a7,   // ne.hi.un_430 nl.vi.sw_322  et.fi.sl_532 fi.de.jw_532
  // [06c0]
  0x3f0b01ec, 0x1e2009a6, 0x07000a1a, 0x06033f08,   // en.es.af_644 pl.sq.ms_521  mk.bg.un_760 af.nl.de_443
  0x31002002, 0x0e003f02, 0x06000104, 0x0c001304,   // sq.az.un_220 af.is.un_220  en.de.un_320 et.sv.un_320
  0x12190b05, 0x1800120e, 0x121821ad, 0x0c00131b,   // es.gl.hu_333 ur.ar.un_550  fa.ar.ur_643 et.sv.un_770
  0x2900160d, 0x04001107, 0x12200508, 0x1a080a60,   // hr.sl.un_540 ro.ru.un_420  fr.sq.hu_443 pt.no.tl_664
  // [06d0]
  0x31001b1b, 0x06000108, 0x06000c12, 0x31001b1a,   // tr.az.un_770 en.de.un_430  sv.de.un_640 tr.az.un_760
  0x1e1c21ec, 0x111001a0, 0x0608025a, 0x00000c1c,   // jw.id.ms_644 en.lt.ro_322  da.no.de_553 sv.un.un_800
  0x04001002, 0x09000d19, 0x25081807, 0x251f0505,   // be.ru.un_220 ne.hi.un_750  ga.no.eu_432 fr.cy.eu_333
  0x1000120d, 0x2000210d, 0x21042ba9, 0x211e1ca4,   // hu.lt.un_540 jw.sq.un_540  vi.fi.jw_544 id.ms.jw_433
  // [06e0]
  0x250418ad, 0x3f030604, 0x2d0d17a4, 0x64000b0c,   // ga.fi.eu_643 de.nl.af_332  sr.cs.sk_433 es.lg.un_530
  0x04000a04, 0x292d03ec, 0x3f0e2107, 0x3f2d0d04,   // mk.ru.un_320 nl.sk.sl_644  jw.is.af_432 cs.sk.af_332
  0x0c000a02, 0x031f01a0, 0x06000c1b, 0x3f00061b,   // pt.sv.un_220 en.cy.nl_322  sv.de.un_770 de.af.un_770
  0x27170112, 0x04060c0c, 0x1800120d, 0x21000d02,   // en.sr.gd_654 sv.de.fi_543  ur.ar.un_540 cs.jw.un_220
  // [06f0]
  0x0c3f08ee, 0x08200cad, 0x2b000a04, 0x53000604,   // no.af.sv_422 sv.sq.no_643  pt.vi.un_320 de.ht.un_320
  0x1b062905, 0x01082dee, 0x04130c55, 0x0c001a04,   // sl.de.tr_333 sk.no.en_422  sv.et.fi_442 tl.sv.un_320
  0x0b1905a7, 0x552164a9, 0x1a00040e, 0x13060cee,   // fr.gl.es_532 lg.jw.rw_544  fi.tl.un_550 sv.de.et_422
  0x190b1809, 0x2a001604, 0x00000d06, 0x1b645504,   // ga.es.gl_444 hr.mt.un_320  ne.un.un_400 rw.lg.tr_332
  // [0700]
  0x2b006e2a, 0x09002a09, 0x08020ea0, 0x21001c08,   // blu.vi.un_970 mt.pl.un_440  is.da.no_322 id.jw.un_430
  0x2d001208, 0x0a1711ec, 0x04100fee, 0x3f02040c,   // hu.sk.un_430 ro.sr.mk_644  lv.lt.fi_422 fi.da.af_543
  0x2b00040d, 0x08002b12, 0x0c00041d, 0x00005524,   // fi.vi.un_540 vi.no.un_640  fi.sv.un_820 rw.un.un_900
  0x6b040aad, 0x21000202, 0x27002b34, 0x0c0802ad,   // pt.fi.ceb_643 da.jw.un_220  vi.gd.un_A80 da.no.sv_643
  // [0710]
  0x2b0a1aa0, 0x020c0702, 0x09001c22, 0x2a005322,   // tl.pt.vi_322 it.sv.da_222  mr.hi.un_870 ht.mt.un_870
  0x04000702, 0x080b1807, 0x1b003119, 0x041318a7,   // bg.ru.un_220 ga.es.no_432  az.tr.un_750 ga.et.fi_532
  0x0e2101a4, 0x2700180d, 0x02001708, 0x08020c0e,   // en.jw.is_433 ga.gd.un_540  sr.da.un_430 sv.da.no_555
  0x0402050d, 0x0400071b, 0x06001702, 0x00002024,   // fr.da.fi_554 bg.ru.un_770  sr.de.un_220 sq.un.un_900
  // [0720]
  0x0b230107, 0x04081713, 0x09001312, 0x00001b1c,   // en.ca.es_432 sr.uk.ru_665  bh.hi.un_640 tr.un.un_800
  0x026408af, 0x20002102, 0x0d13090d, 0x27111807,   // no.lg.da_655 jw.sq.un_220  hi.bh.ne_554 ga.ro.gd_432
  0x18062011, 0x18000708, 0x1b290f05, 0x10002119,   // sq.de.ga_653 it.ga.un_430  lv.sl.tr_333 jw.lt.un_750
  0x0b000a07, 0x20002d1a, 0x1c211e12, 0x016e07a0,   // pt.es.un_420 sk.sq.un_760  ms.jw.id_654 it.blu.en_322
  // [0730]
  0x2112640c, 0x642d13a4, 0x0b0a1105, 0x1000041b,   // lg.hu.jw_543 et.sk.lg_433  ro.pt.es_333 ru.be.un_770
  0x06171609, 0x05171604, 0x212d0d05, 0x1f002504,   // hr.sr.de_444 hr.sr.fr_332  cs.sk.jw_333 eu.cy.un_320
  0x2d13100c, 0x6e2b2107, 0x00006406, 0x1b2b0c02,   // lt.et.sk_543 jw.vi.blu_432  lg.un.un_400 sv.vi.tr_222
  0x13000414, 0x1b201807, 0x04000a13, 0x13000905,   // fi.et.un_660 ga.sq.tr_432  mk.ru.un_650 hi.bh.un_330
  // [0740]
  0x28060b04, 0x1a25290c, 0x12001b12, 0x01031f07,   // es.de.sw_332 sl.eu.tl_543  tr.hu.un_640 cy.nl.en_432
  0x21016ba0, 0x3100190d, 0x1000080e, 0x0b0a2305,   // ceb.en.jw_322 gl.az.un_540  uk.be.un_550 ca.pt.es_333
  0x200f29a4, 0x0d2d1012, 0x1f25190d, 0x2a071aa4,   // sl.lv.sq_433 lt.sk.cs_654  gl.eu.cy_554 tl.it.mt_433
  0x1220080b, 0x131b200c, 0x02000a19, 0x09001c0d,   // no.sq.hu_542 sq.tr.et_543  pt.da.un_750 mr.hi.un_540
  // [0750]
  0x290f2da0, 0x131716a0, 0x12000a0c, 0x282101a0,   // sk.lv.sl_322 hr.sr.et_322  pt.hu.un_530 en.jw.sw_322
  0x1821120c, 0x00000924, 0x28131aee, 0x041008ee,   // ur.fa.ar_543 hi.un.un_900  tl.et.sw_422 uk.be.ru_422
  0x31111bee, 0x2916170c, 0x1700110e, 0x0e1a08a0,   // tr.ro.az_422 sr.hr.sl_543  ro.sr.un_550 no.tl.is_322
  0x0a00071a, 0x200d2d0c, 0x296b1a07, 0x09000614,   // bg.mk.un_760 sk.cs.sq_543  tl.ceb.sl_432 de.pl.un_660
  // [0760]
  0x070a1008, 0x09000d12, 0x020e1302, 0x10000404,   // be.mk.bg_443 ne.hi.un_640  et.is.da_222 ru.be.un_320
  0x25050704, 0x0f080e04, 0x2d001919, 0x27001808,   // it.fr.eu_332 is.no.lv_332  gl.sk.un_750 ga.gd.un_430
  0x6b000405, 0x05190b0e, 0x05000e22, 0x2400010d,   // fi.ceb.un_330 es.gl.fr_555  is.fr.un_870 iw.yi.un_540
  0x05001902, 0x230d20a0, 0x09002904, 0x12000f07,   // gl.fr.un_220 sq.cs.ca_322  sl.pl.un_320 lv.hu.un_420
  // [0770]
  0x29002d07, 0x6b641007, 0x19082055, 0x12182109,   // sk.sl.un_420 lt.lg.ceb_432  sq.no.gl_442 fa.ar.ur_444
  0x201827a4, 0x0900130b, 0x12052da0, 0x3f1a6bee,   // gd.ga.sq_433 bh.hi.un_520  sk.fr.hu_322 ceb.tl.af_422
  0x0b001107, 0x00002424, 0x0d09290d, 0x10120fa7,   // ro.es.un_420 yi.un.un_900  sl.pl.cs_554 lv.hu.lt_532
  0x07080e0b, 0x23160eee, 0x6b2a1a14, 0x02001f0c,   // is.no.it_542 is.hr.ca_422  tl.mt.ceb_666 cy.da.un_530
  // [0780]
  0x1105530b, 0x532a3fa4, 0x170e0c04, 0x0b051904,   // ht.fr.ro_542 af.mt.ht_433  sv.is.sr_332 gl.fr.es_332
  0x19120a0c, 0x09001c13, 0x07170a0e, 0x6b006e07,   // pt.hu.gl_543 mr.hi.un_650  mk.sr.bg_555 blu.ceb.un_420
  0x292d1204, 0x21121860, 0x12001104, 0x20002702,   // hu.sk.sl_332 ar.ur.fa_664  ro.hu.un_320 gd.sq.un_220
  0x040a08af, 0x20100fad, 0x170a1111, 0x1c131e04,   // uk.mk.ru_655 lv.lt.sq_643  ro.mk.sr_653 ms.et.id_332
  // [0790]
  0x181a27a4, 0x2d000d04, 0x1f3f120c, 0x2a006402,   // gd.tl.ga_433 cs.sk.un_320  hu.af.cy_543 lg.mt.un_220
  0x1f1104a7, 0x05002111, 0x00002137, 0x112902a0,   // fi.ro.cy_532 jw.fr.un_630  fa.un.un_B00 da.sl.ro_322
  0x17000a1b, 0x170a1005, 0x0c080202, 0x12002909,   // mk.sr.un_770 be.mk.sr_333  da.no.sv_222 sl.hu.un_440
  0x09110d12, 0x04170704, 0x0a102507, 0x0f000b02,   // cs.ro.pl_654 bg.sr.ru_332  eu.lt.pt_432 es.lv.un_220
  // [07a0]
  0x03020807, 0x1f080e04, 0x1800050d, 0x0d0913a0,   // no.da.nl_432 is.no.cy_332  fr.ga.un_540 bh.hi.ne_322
  0x0c0e1b04, 0x1b02135a, 0x0b001904, 0x53002304,   // tr.is.sv_332 et.da.tr_553  gl.es.un_320 ca.ht.un_320
  0x0000122d, 0x1218210b, 0x122307ee, 0x2b00270b,   // ur.un.un_A00 fa.ar.ur_542  it.ca.hu_422 gd.vi.un_520
  0x210231ee, 0x041c1ea9, 0x09110f07, 0x11072a13,   // az.da.jw_422 ms.id.fi_544  lv.ro.pl_432 mt.it.ro_665
  // [07b0]
  0x04000714, 0x10001f0d, 0x10070455, 0x0d000918,   // bg.ru.un_660 cy.lt.un_540  ru.bg.be_442 hi.ne.un_740
  0x04000719, 0x0900130c, 0x06033f07, 0x2d0f2105,   // bg.ru.un_750 bh.hi.un_530  af.nl.de_432 jw.lv.sk_333
  0x3f0e06a4, 0x05110107, 0x13000919, 0x0a000405,   // de.is.af_433 en.ro.fr_432  hi.bh.un_750 ru.mk.un_330
  0x080704a4, 0x3f001302, 0x0a0417a4, 0x64311ba7,   // ru.bg.uk_433 et.af.un_220  sr.ru.mk_433 tr.az.lg_532
  // [07c0]
  0x00002d06, 0x0a00071b, 0x11040760, 0x0a0807a4,   // sk.un.un_400 bg.mk.un_770  bg.ru.ro_664 bg.uk.mk_433
  0x0e171608, 0x010b06a9, 0x212701ee, 0x07081707,   // hr.sr.is_443 de.es.en_544  en.gd.jw_422 sr.uk.bg_432
  0x05002012, 0x2a000722, 0x2000051a, 0x290d2d07,   // sq.fr.un_640 it.mt.un_870  fr.sq.un_760 sk.cs.sl_432
  0x162d0d0e, 0x1b001319, 0x28002012, 0x09001212,   // cs.sk.hr_555 et.tr.un_750  sq.sw.un_640 hu.pl.un_640
  // [07d0]
  0x08022a02, 0x2100050e, 0x1a0c295a, 0x551e10a0,   // mt.da.no_222 fr.jw.un_550  sl.sv.tl_553 lt.ms.rw_322
  0x1e211c04, 0x02212055, 0x0b0a01a0, 0x2300251b,   // id.jw.ms_332 sq.jw.da_442  en.pt.es_322 eu.ca.un_770
  0x0f211fa4, 0x212d16a4, 0x64071112, 0x040f055a,   // cy.jw.lv_433 hr.sk.jw_433  ro.it.lg_654 fr.lv.fi_553
  0x07000905, 0x3f2a6bee, 0x091617ec, 0x00000901,   // pl.it.un_330 ceb.mt.af_422  sr.hr.pl_644 hi.un.un_200
  // [07e0]
  0x1c171608, 0x1610280c, 0x16002012, 0x28002a08,   // hr.sr.id_443 sw.lt.hr_543  sq.hr.un_640 mt.sw.un_430
  0x21001223, 0x00000706, 0x550410ad, 0x29001602,   // ur.fa.un_880 it.un.un_400  lt.fi.rw_643 hr.sl.un_220
  0x071021ac, 0x2d0d64ee, 0x17202da7, 0x092d16a4,   // jw.lt.it_632 lg.cs.sk_422  sk.sq.sr_532 hr.sk.pl_433
  0x1a271860, 0x0c00121a, 0x1e211c07, 0x12311ca0,   // ga.gd.tl_664 hu.sv.un_760  id.jw.ms_432 id.az.hu_322
  // [07f0]
  0x3100190c, 0x112d0d60, 0x07001105, 0x090625ee,   // gl.az.un_530 cs.sk.ro_664  ro.it.un_330 eu.de.pl_422
  0x121b31ad, 0x04081012, 0x122118ad, 0x06006b09,   // az.tr.hu_643 be.uk.ru_654  ar.fa.ur_643 ceb.de.un_440
  0x12001819, 0x012028ee, 0x070a17a0, 0x216b1a07,   // ar.ur.un_750 sw.sq.en_422  sr.mk.bg_322 tl.ceb.jw_432
  0x292d0d55, 0x12160bee, 0x201323a0, 0x312d0d0d,   // cs.sk.sl_442 es.hr.hu_422  ca.et.sq_322 cs.sk.az_554

  // [0800]
  0x07000a12, 0x03002102, 0x12001014, 0x09000d13,   // mk.bg.un_640 jw.nl.un_220  lt.hu.un_660 ne.hi.un_650
  0x08001004, 0x29211ca0, 0x04001329, 0x07100404,   // be.uk.un_320 id.jw.sl_322  et.fi.un_960 fi.lt.it_332
  0x1c090da4, 0x1c211e04, 0x29171602, 0x10071208,   // ne.hi.mr_433 ms.jw.id_332  hr.sr.sl_222 hu.it.lt_443
  0x1f0705ad, 0x041064a0, 0x0f090da4, 0x17162aa0,   // fr.it.cy_643 lg.lt.fi_322  cs.pl.lv_433 mt.hr.sr_322
  // [0810]
  0x04081008, 0x1b001702, 0x07000402, 0x112d0d11,   // be.uk.ru_443 sr.tr.un_220  ru.bg.un_220 cs.sk.ro_653
  0x0a001104, 0x05002304, 0x1918230d, 0x0a000d04,   // ro.pt.un_320 ca.fr.un_320  ca.ga.gl_554 cs.pt.un_320
  0x1f001a02, 0x0a001705, 0x531a100c, 0x00000401,   // tl.cy.un_220 sr.mk.un_330  lt.tl.ht_543 ru.un.un_200
  0x06000202, 0x23001902, 0x0a0408a0, 0x01003f04,   // da.de.un_220 gl.ca.un_220  uk.ru.mk_322 af.en.un_320
  // [0820]
  0x08041712, 0x1c00091b, 0x2b000712, 0x10000814,   // sr.ru.uk_654 hi.mr.un_770  it.vi.un_640 uk.be.un_660
  0x0e001905, 0x0d091305, 0x13000904, 0x130c04ad,   // gl.is.un_330 bh.hi.ne_333  hi.bh.un_320 fi.sv.et_643
  0x17002304, 0x202a55ad, 0x07100aa0, 0x0800020e,   // ca.sr.un_320 rw.mt.sq_643  mk.be.bg_322 da.no.un_550
  0x20001904, 0x29001702, 0x040710a0, 0x640f3fee,   // gl.sq.un_320 sr.sl.un_220  be.bg.ru_322 af.lv.lg_422
  // [0830]
  0x080c020c, 0x00000b0a, 0x64200604, 0x18002112,   // da.sv.no_543 bn.un.un_500  de.sq.lg_332 fa.ar.un_640
  0x04070a12, 0x1c0d095a, 0x0a001719, 0x042a0711,   // mk.bg.ru_654 hi.ne.mr_553  sr.mk.un_750 it.mt.fi_653
  0x2a0f0713, 0x0e001308, 0x1812210d, 0x04000612,   // it.lv.mt_665 et.is.un_430  fa.ur.ar_554 de.fi.un_640
  0x64001b20, 0x6b005509, 0x04000704, 0x09001c14,   // tr.lg.un_850 rw.ceb.un_440  bg.ru.un_320 mr.hi.un_660
  // [0840]
  0x04033f5a, 0x1800120c, 0x0a000802, 0x25043f0c,   // af.nl.fi_553 ur.ar.un_530  uk.mk.un_220 af.fi.eu_543
  0x252d5313, 0x06040c07, 0x03000408, 0x17080aa4,   // ht.sk.eu_665 sv.fi.de_432  fi.nl.un_430 mk.uk.sr_433
  0x2800550d, 0x25280904, 0x28171ca9, 0x1c090d07,   // rw.sw.un_540 pl.sw.eu_332  id.sr.sw_544 ne.hi.mr_432
  0x0e0d2d11, 0x163f17a0, 0x04082507, 0x212909a9,   // sk.cs.is_653 sr.af.hr_322  eu.no.fi_432 pl.sl.jw_544
  // [0850]
  0x05645305, 0x0428030c, 0x01001905, 0x3f002505,   // ht.lg.fr_333 nl.sw.fi_543  gl.en.un_330 eu.af.un_330
  0x070a1104, 0x04006407, 0x03130404, 0x2d0d2baf,   // ro.mk.bg_332 lg.fi.un_420  fi.et.nl_332 vi.cs.sk_655
  0x28002104, 0x08170aa9, 0x1e1c31ee, 0x3f2564ec,   // jw.sw.un_320 mk.sr.uk_544  az.id.ms_422 lg.eu.af_644
  0x092a28ad, 0x532012ee, 0x09002905, 0x20000409,   // sw.mt.pl_643 hu.sq.ht_422  sl.pl.un_330 fi.sq.un_440
  // [0860]
  0x1b002813, 0x20001702, 0x08100412, 0x0e001a04,   // sw.tr.un_650 sr.sq.un_220  ru.be.uk_654 tl.is.un_320
  0x091c130c, 0x092d0d09, 0x283f640c, 0x08000a12,   // bh.mr.hi_543 cs.sk.pl_444  lg.af.sw_543 mk.uk.un_640
  0x3f0413a0, 0x3f1364a0, 0x5525280c, 0x3f130408,   // et.fi.af_322 lg.et.af_322  sw.eu.rw_543 fi.et.af_443
  0x04001022, 0x2d000d22, 0x0c002d13, 0x3f0301a4,   // be.ru.un_870 cs.sk.un_870  sk.sv.un_650 en.nl.af_433
  // [0870]
  0x040c080c, 0x09100d08, 0x29005521, 0x0413100c,   // no.sv.fi_543 cs.lt.pl_443  rw.sl.un_860 lt.et.fi_543
  0x18002712, 0x55002823, 0x23001908, 0x291716ec,   // gd.ga.un_640 sw.rw.un_880  gl.ca.un_430 hr.sr.sl_644
  0x043f10ad, 0x282521a4, 0x13000423, 0x07040a09,   // lt.af.fi_643 jw.eu.sw_433  fi.et.un_880 mk.ru.bg_444
  0x64552807, 0x250604ec, 0x3f1e1ca4, 0x011213ee,   // sw.rw.lg_432 fi.de.eu_644  id.ms.af_433 et.hu.en_422
  // [0880]
  0x10001c05, 0x17291604, 0x042d0d08, 0x04005304,   // id.lt.un_330 hr.sl.sr_332  cs.sk.fi_443 ht.fi.un_320
  0x53042012, 0x040c2105, 0x0e1225a4, 0x0300231b,   // sq.fi.ht_654 jw.sv.fi_333  eu.hu.is_433 ca.nl.un_770
  0x17162914, 0x100a08a4, 0x2d0d09ee, 0x3f002002,   // sl.hr.sr_666 uk.mk.be_433  pl.cs.sk_422 sq.af.un_220
  0x0b0a290c, 0x2d0d090c, 0x17110a09, 0x25100705,   // sl.pt.es_543 pl.cs.sk_543  mk.ro.sr_444 it.lt.eu_333
  // [0890]
  0x23190b05, 0x0d2d290c, 0x17161c05, 0x061e02a0,   // es.gl.ca_333 sl.sk.cs_543  id.hr.sr_333 da.ms.de_322
  0x082755a0, 0x2128550c, 0x17070a13, 0x11001e04,   // rw.gd.no_322 rw.sw.jw_543  mk.bg.sr_665 ms.ro.un_320
  0x042d0d13, 0x2000110d, 0x111753ad, 0x6400210c,   // cs.sk.fi_665 ro.sq.un_540  ht.sr.ro_643 jw.lg.un_530
  0x063f0305, 0x28005307, 0x04000721, 0x212529a4,   // nl.af.de_333 ht.sw.un_420  bg.ru.un_860 sl.eu.jw_433
  // [08a0]
  0x55002809, 0x00001b24, 0x1f00100d, 0x10000108,   // sw.rw.un_440 tr.un.un_900  lt.cy.un_540 en.lt.un_430
  0x0400641b, 0x29005308, 0x0400081a, 0x64550b02,   // lg.fi.un_770 ht.sl.un_430  uk.ru.un_760 es.rw.lg_222
  0x09000e09, 0x13000913, 0x1e0f21ee, 0x556453a7,   // is.pl.un_440 hi.bh.un_650  jw.lv.ms_422 ht.lg.rw_532
  0x0e286b02, 0x25000623, 0x0a1711a4, 0x0d2b010c,   // ceb.sw.is_222 de.eu.un_880  ro.sr.mk_433 en.vi.cs_543
  // [08b0]
  0x1c001307, 0x061e1caf, 0x071811a7, 0x1017160d,   // bh.mr.un_420 id.ms.de_655  ro.ga.it_532 hr.sr.lt_554
  0x033f02ad, 0x02006404, 0x0d000908, 0x0000290a,   // da.af.nl_643 lg.da.un_320  pl.cs.un_430 sl.un.un_500
  0x0e006404, 0x01001b04, 0x1c1b21a7, 0x0a1708a4,   // lg.is.un_320 tr.en.un_320  jw.tr.id_532 uk.sr.mk_433
  0x2a1f0960, 0x28005519, 0x040a1713, 0x190b23a0,   // pl.cy.mt_664 rw.sw.un_750  sr.mk.ru_665 ca.es.gl_322
  // [08c0]
  0x190b0a0e, 0x0e2011a0, 0x2d0d16a4, 0x01006402,   // pt.es.gl_555 ro.sq.is_322  hr.cs.sk_433 lg.en.un_220
  0x1c640fa0, 0x28552aee, 0x28005509, 0x00002806,   // lv.lg.id_322 mt.rw.sw_422  rw.sw.un_440 sw.un.un_400
  0x0000020a, 0x04110aa4, 0x31001b2b, 0x190b0aee,   // da.un.un_500 mk.ro.ru_433  tr.az.un_980 pt.es.gl_422
  0x6b1a2d11, 0x1b3101a0, 0x17070a04, 0x1812210c,   // sk.tl.ceb_653 en.az.tr_322  mk.bg.sr_332 fa.ur.ar_543
  // [08d0]
  0x01000d0d, 0x13090d11, 0x31001b2c, 0x2b040707,   // cs.en.un_540 ne.hi.bh_653  tr.az.un_990 it.fi.vi_432
  0x25001a04, 0x0700100b, 0x29002521, 0x1b000804,   // tl.eu.un_320 lt.it.un_520  eu.sl.un_860 no.tr.un_320
  0x130410af, 0x07000802, 0x0e0f2a09, 0x1b0208a4,   // lt.fi.et_655 uk.bg.un_220  mt.lv.is_444 no.da.tr_433
  0x25001a0c, 0x00001a06, 0x250813ac, 0x0b000a1b,   // tl.eu.un_530 tl.un.un_400  et.no.eu_632 pt.es.un_770
  // [08e0]
  0x1307530c, 0x64285512, 0x11311ba7, 0x0000202d,   // ht.it.et_543 rw.sw.lg_654  tr.az.ro_532 sq.un.un_A00
  0x0c1a6b08, 0x25191ba9, 0x111827a9, 0x0a2d0504,   // ceb.tl.sv_443 tr.gl.eu_544  gd.ga.ro_544 fr.sk.pt_332
  0x100f6407, 0x11136ba4, 0x06270daf, 0x1e1c21ee,   // lg.lv.lt_432 ceb.et.ro_433  cs.gd.de_655 jw.id.ms_422
  0x0b003119, 0x281b21a6, 0x1b000104, 0x092d0d0b,   // az.es.un_750 jw.tr.sw_521  en.tr.un_320 cs.sk.pl_542
  // [08f0]
  0x29000219, 0x17001113, 0x0a110107, 0x3f0306a4,   // da.sl.un_750 ro.sr.un_650  en.ro.pt_432 de.nl.af_433
  0x08020e0b, 0x02070ca0, 0x2a2d6404, 0x3f032507,   // is.da.no_542 sv.it.da_322  lg.sk.mt_332 eu.nl.af_432
  0x1f000108, 0x0c00061a, 0x18051102, 0x201107a9,   // en.cy.un_430 de.sv.un_760  ro.fr.ga_222 it.ro.sq_544
  0x25311b60, 0x27000e21, 0x230501ec, 0x29001621,   // tr.az.eu_664 is.gd.un_860  en.fr.ca_644 hr.sl.un_860
  // [0900]
  0x316b1baf, 0x1e1c6b0c, 0x2d16170c, 0x03003f1b,   // tr.ceb.az_655 ceb.id.ms_543  sr.hr.sk_543 af.nl.un_770
  0x08001912, 0x0c311bec, 0x25285513, 0x1c09130e,   // gl.no.un_640 tr.az.sv_644  rw.sw.eu_665 bh.hi.mr_555
  0x1b005512, 0x0200081a, 0x25311b0d, 0x02000702,   // rw.tr.un_640 no.da.un_760  tr.az.eu_554 it.da.un_220
  0x2a002d1a, 0x25311b13, 0x25001b14, 0x011a1bec,   // sk.mt.un_760 tr.az.eu_665  tr.eu.un_660 tr.tl.en_644
  // [0910]
  0x3f17160d, 0x122118a7, 0x17162daf, 0x25005312,   // hr.sr.af_554 ar.fa.ur_532  sk.hr.sr_655 ht.eu.un_640
  0x13001c19, 0x53020ca4, 0x075501a0, 0x0d001912,   // mr.bh.un_750 sv.da.ht_433  en.rw.it_322 gl.cs.un_640
  0x06091f04, 0x12002112, 0x1a1b0108, 0x131a10a7,   // cy.pl.de_332 fa.ur.un_640  en.tr.tl_443 lt.tl.et_532
  0x162a21a4, 0x0a081907, 0x28640507, 0x0f2128a0,   // jw.mt.hr_433 gl.no.pt_432  fr.lg.sw_432 sw.jw.lv_322
  // [0920]
  0x0b001b09, 0x1625170c, 0x25190b0d, 0x07170aa4,   // tr.es.un_440 sr.eu.hr_543  es.gl.eu_554 mk.sr.bg_433
  0x210955a9, 0x060501a9, 0x2d171609, 0x6b001a07,   // rw.pl.jw_544 en.fr.de_544  hr.sr.sk_444 tl.ceb.un_420
  0x17162d0c, 0x11002105, 0x1b000a07, 0x0d0818ee,   // sk.hr.sr_543 jw.ro.un_330  pt.tr.un_420 ga.no.cs_422
  0x18000509, 0x041905a0, 0x25001909, 0x0c002d0c,   // fr.ga.un_440 fr.gl.fi_322  gl.eu.un_440 sk.sv.un_530
  // [0930]
  0x130d1cec, 0x1c000d13, 0x21001c09, 0x160c29a0,   // mr.ne.bh_644 ne.mr.un_650  id.jw.un_440 sl.sv.hr_322
  0x1800210c, 0x08022da4, 0x17162da4, 0x07111aa0,   // fa.ar.un_530 sk.da.no_433  sk.hr.sr_433 tl.ro.it_322
  0x06000808, 0x130d09ad, 0x0c000202, 0x11000709,   // no.de.un_430 hi.ne.bh_643  da.sv.un_220 it.ro.un_440
  0x0800041b, 0x171607a4, 0x10000813, 0x17161002,   // ru.uk.un_770 it.hr.sr_433  uk.be.un_650 lt.hr.sr_222
  // [0940]
  0x0717165a, 0x13040cad, 0x1b1107a0, 0x29161b0c,   // hr.sr.it_553 sv.fi.et_643  it.ro.tr_322 tr.hr.sl_543
  0x17160d05, 0x04000713, 0x17070d07, 0x17110a05,   // cs.hr.sr_333 bg.ru.un_650  cs.it.sr_432 mk.ro.sr_333
  0x070a1708, 0x08000702, 0x1123075a, 0x0f1001a0,   // sr.mk.bg_443 bg.uk.un_220  it.ca.ro_553 en.lt.lv_322
  0x0d001902, 0x0c021cee, 0x0a001802, 0x08100405,   // gl.cs.un_220 id.da.sv_422  ga.pt.un_220 ru.be.uk_333
  // [0950]
  0x1b001602, 0x53002108, 0x19000a02, 0x1300091b,   // hr.tr.un_220 jw.ht.un_430  pt.gl.un_220 hi.bh.un_770
  0x0417100c, 0x0000231c, 0x17160dec, 0x2118120d,   // be.sr.ru_543 ca.un.un_800  cs.hr.sr_644 ur.ar.fa_554
  0x0b0c0807, 0x27006e09, 0x06003f02, 0x0b001f12,   // no.sv.es_432 blu.gd.un_440  af.de.un_220 cy.es.un_640
  0x28001f09, 0x070a17a4, 0x11190b04, 0x1b002104,   // cy.sw.un_440 sr.mk.bg_433  es.gl.ro_332 jw.tr.un_320
  // [0960]
  0x1b07310c, 0x1a006e12, 0x020711a0, 0x09000d0e,   // az.it.tr_543 blu.tl.un_640  ro.it.da_322 ne.hi.un_550
  0x0d001304, 0x2a00160e, 0x16110704, 0x0d091caf,   // bh.ne.un_320 hr.mt.un_550  it.ro.hr_332 mr.hi.ne_655
  0x3f0c08ee, 0x10080408, 0x12211860, 0x212d0d08,   // no.sv.af_422 ru.uk.be_443  ar.fa.ur_664 cs.sk.jw_443
  0x1c006402, 0x0c001f04, 0x081231a0, 0x2d162908,   // lg.id.un_220 cy.sv.un_320  az.hu.no_322 sl.hr.sk_443
  // [0970]
  0x070a08a4, 0x3f311b04, 0x0500190e, 0x25000302,   // uk.mk.bg_433 tr.az.af_332  gl.fr.un_550 nl.eu.un_220
  0x0400060d, 0x04130608, 0x180306af, 0x1c1b53a9,   // de.fi.un_540 de.et.fi_443  de.nl.ga_655 ht.tr.id_544
  0x31001f0c, 0x6400550c, 0x071008ad, 0x080a07a0,   // cy.az.un_530 rw.lg.un_530  uk.be.bg_643 bg.mk.uk_322
  0x0a1707af, 0x06080ca0, 0x1a000d04, 0x182112a9,   // bg.sr.mk_655 sv.no.de_322  cs.tl.un_320 ur.fa.ar_544
  // [0980]
  0x21162808, 0x19002104, 0x31532104, 0x211f010c,   // sw.hr.jw_443 jw.gl.un_320  jw.ht.az_332 en.cy.jw_543
  0x2a001004, 0x552564a9, 0x1f0127ee, 0x00001203,   // lt.mt.un_320 lg.eu.rw_544  gd.en.cy_422 hu.un.un_300
  0x130564a0, 0x0d002505, 0x0e0201ee, 0x00002b2d,   // lg.fr.et_322 eu.cs.un_330  en.da.is_422 vi.un.un_A00
  0x06253f13, 0x1e001f0c, 0x3f011fa6, 0x231105a4,   // af.eu.de_665 cy.ms.un_530  cy.en.af_521 fr.ro.ca_433
  // [0990]
  0x080c025a, 0x552d0d13, 0x09001319, 0x02123f04,   // da.sv.no_553 cs.sk.rw_665  bh.hi.un_750 af.hu.da_332
  0x08070408, 0x0a190b55, 0x1f001b14, 0x06022109,   // ru.bg.uk_443 es.gl.pt_442  tr.cy.un_660 jw.da.de_444
  0x101f2107, 0x250b55a4, 0x0c0604ad, 0x06002507,   // jw.cy.lt_432 rw.es.eu_433  fi.de.sv_643 eu.de.un_420
  0x2300030c, 0x13000609, 0x00001f01, 0x18122108,   // nl.ca.un_530 de.et.un_440  cy.un.un_200 fa.ur.ar_443
  // [09a0]
  0x13090d05, 0x043107a0, 0x06001f04, 0x00000d2d,   // ne.hi.bh_333 it.az.fi_322  cy.de.un_320 ne.un.un_A00
  0x011e13ee, 0x17080405, 0x3f00030e, 0x171008a4,   // et.ms.en_422 ru.uk.sr_333  nl.af.un_550 uk.be.sr_433
  0x090d1c13, 0x3f002702, 0x06006402, 0x19000b1b,   // mr.ne.hi_665 gd.af.un_220  lg.de.un_220 es.gl.un_770
  0x21001f1a, 0x063f0308, 0x040c0eac, 0x0c000608,   // cy.jw.un_760 nl.af.de_443  is.sv.fi_632 de.sv.un_430
  // [09b0]
  0x3f03060c, 0x1c090dec, 0x1f0103a7, 0x01000804,   // de.nl.af_543 ne.hi.mr_644  nl.en.cy_532 no.en.un_320
  0x1c090d0c, 0x080a0708, 0x2a125504, 0x2d002504,   // ne.hi.mr_543 bg.mk.uk_443  rw.hu.mt_332 eu.sk.un_320
  0x090d1cec, 0x1200211b, 0x2b002104, 0x18002719,   // mr.ne.hi_644 fa.ur.un_770  jw.vi.un_320 gd.ga.un_750
  0x3f1820a4, 0x0e000804, 0x25001119, 0x04000c21,   // sq.ga.af_433 no.is.un_320  ro.eu.un_750 sv.fi.un_860
  // [09c0]
  0x07040813, 0x182701a4, 0x080704af, 0x18002713,   // uk.ru.bg_665 en.gd.ga_433  ru.bg.uk_655 gd.ga.un_650
  0x08060ea9, 0x11002502, 0x190b25a0, 0x02003f0c,   // is.de.no_544 eu.ro.un_220  eu.es.gl_322 af.da.un_530
  0x11001c04, 0x080405ee, 0x0b190a04, 0x08120a07,   // id.ro.un_320 fr.fi.no_422  pt.gl.es_332 pt.hu.no_432
  0x040a1702, 0x25112009, 0x07001107, 0x06002719,   // sr.mk.ru_222 sq.ro.eu_444  ro.bg.un_420 gd.de.un_750
  // [09d0]
  0x170a11a4, 0x25001114, 0x552021ee, 0x040206a9,   // ro.mk.sr_433 ro.eu.un_660  jw.sq.rw_422 de.da.fi_544
  0x2b080102, 0x0e0f130b, 0x00006424, 0x53033f04,   // en.no.vi_222 et.lv.is_542  lg.un.un_900 af.nl.ht_332
  0x10001312, 0x55042812, 0x202104ec, 0x21646ba4,   // et.lt.un_640 sw.fi.rw_654  fi.jw.sq_644 ceb.lg.jw_433
  0x1e1c20ee, 0x2d0d08a0, 0x55286ba9, 0x1e1c21a4,   // sq.id.ms_422 no.cs.sk_322  ceb.sw.rw_544 jw.id.ms_433
  // [09e0]
  0x2500110e, 0x08020ca0, 0x031801a0, 0x1800272a,   // ro.eu.un_550 sv.da.no_322  en.ga.nl_322 gd.ga.un_970
  0x041711ac, 0x12020702, 0x3f210302, 0x1e1c21a0,   // ro.sr.ru_632 it.da.hu_222  nl.jw.af_222 jw.id.ms_322
  0x07000104, 0x040a17af, 0x17000a22, 0x00001124,   // en.it.un_320 sr.mk.ru_655  mk.sr.un_870 ro.un.un_900
  0x2164550d, 0x0f002d02, 0x200f1ca0, 0x06033f04,   // rw.lg.jw_554 sk.lv.un_220  id.lv.sq_322 af.nl.de_332
  // [09f0]
  0x0f002004, 0x0a041007, 0x6b212da7, 0x2500111a,   // sq.lv.un_320 be.ru.mk_432  sk.jw.ceb_532 ro.eu.un_760
  0x1a280aaf, 0x171c2d07, 0x552853a4, 0x202511ad,   // pt.sw.tl_655 sk.id.sr_432  ht.sw.rw_433 ro.eu.sq_643
  0x530b1112, 0x130d0960, 0x2500090c, 0x53110b07,   // ro.es.ht_654 hi.ne.bh_664  pl.eu.un_530 es.ro.ht_432
  0x033f28a4, 0x080613ad, 0x55000202, 0x04171604,   // sw.af.nl_433 et.de.no_643  da.rw.un_220 hr.sr.fi_332
  // [0a00]
  0x5300550c, 0x55292105, 0x270806a4, 0x10162907,   // rw.ht.un_530 jw.sl.rw_333  de.no.gd_433 sl.hr.lt_432
  0x55002104, 0x17160909, 0x19001302, 0x01000a04,   // jw.rw.un_320 pl.hr.sr_444  et.gl.un_220 pt.en.un_320
  0x232128ee, 0x0f001008, 0x176b160c, 0x29000d08,   // sw.jw.ca_422 lt.lv.un_430  hr.ceb.sr_543 cs.sl.un_430
  0x13210f07, 0x5300551a, 0x10131c07, 0x1e0921a0,   // lv.jw.et_432 rw.ht.un_760  id.et.lt_432 jw.pl.ms_322
  // [0a10]
  0x09120404, 0x12000704, 0x28001e04, 0x21000407,   // fi.hu.pl_332 it.hu.un_320  ms.sw.un_320 fi.jw.un_420
  0x0b005512, 0x645528ec, 0x29171607, 0x23000b04,   // rw.es.un_640 sw.rw.lg_644  hr.sr.sl_432 es.ca.un_320
  0x17291607, 0x08001707, 0x0800050c, 0x3f0219a0,   // hr.sl.sr_432 sr.uk.un_420  fr.no.un_530 gl.da.af_322
  0x170920a4, 0x6b27180d, 0x21001e04, 0x07000108,   // sq.pl.sr_433 ga.gd.ceb_554  ms.jw.un_320 en.it.un_430
  // [0a20]
  0x0b0a19ee, 0x00001b01, 0x08170a02, 0x2917165a,   // gl.pt.es_422 tr.un.un_200  mk.sr.uk_222 hr.sr.sl_553
  0x27001821, 0x28000b05, 0x07041104, 0x55005312,   // ga.gd.un_860 es.sw.un_330  ro.ru.bg_332 ht.rw.un_640
  0x556428a0, 0x0c12040c, 0x13001814, 0x07000419,   // sw.lg.rw_322 fi.hu.sv_543  ga.et.un_660 ru.bg.un_750
  0x20295304, 0x1a006b04, 0x3f0301a0, 0x0c00061b,   // ht.sl.sq_332 ceb.tl.un_320  en.nl.af_322 de.sv.un_770
  // [0a30]
  0x55002811, 0x17165309, 0x27001819, 0x0b55530c,   // sw.rw.un_630 ht.hr.sr_444  ga.gd.un_750 ht.rw.es_543
  0x0b5311ec, 0x532921a0, 0x102021ee, 0x16002814,   // ro.ht.es_644 jw.sl.ht_322  jw.sq.lt_422 sw.hr.un_660
  0x0b1153a0, 0x19000a0c, 0x061c0307, 0x19001f02,   // ht.ro.es_322 pt.gl.un_530  nl.id.de_432 cy.gl.un_220
  0x2d0d2905, 0x28002a13, 0x2723180c, 0x122a20a9,   // sl.cs.sk_333 mt.sw.un_650  ga.ca.gd_543 sq.mt.hu_544
  // [0a40]
  0x1c130955, 0x2d0d0caf, 0x18002109, 0x13033fa9,   // hi.bh.mr_442 sv.cs.sk_655  fa.ar.un_440 af.nl.et_544
  0x091c1308, 0x3f00031b, 0x0a1704a0, 0x21001312,   // bh.mr.hi_443 nl.af.un_770  ru.sr.mk_322 et.jw.un_640
  0x04000608, 0x063f0204, 0x19000a07, 0x161710a4,   // de.fi.un_430 da.af.de_332  pt.gl.un_420 lt.sr.hr_433
  0x2d290d07, 0x03093fa7, 0x00001e06, 0x23000a08,   // cs.sl.sk_432 af.pl.nl_532  ms.un.un_400 pt.ca.un_430
  // [0a50]
  0x102028ad, 0x27101812, 0x08282107, 0x2d0d1605,   // sw.sq.lt_643 ga.lt.gd_654  jw.sw.no_432 hr.cs.sk_333
  0x0a001907, 0x00000824, 0x2800211a, 0x27180112,   // gl.pt.un_420 no.un.un_900  jw.sw.un_760 en.ga.gd_654
  0x1c1f21a4, 0x271813ee, 0x09005502, 0x040e1207,   // jw.cy.id_433 et.ga.gd_422  rw.pl.un_220 hu.is.fi_432
  0x17040aa9, 0x0c00111a, 0x130d0913, 0x21001f04,   // mk.ru.sr_544 ro.sv.un_760  hi.ne.bh_665 cy.jw.un_320
  // [0a60]
  0x1c1f21ec, 0x291716a9, 0x133f6ba0, 0x06001304,   // jw.cy.id_644 hr.sr.sl_544  ceb.af.et_322 et.de.un_320
  0x090d1ca4, 0x1629100c, 0x16002904, 0x64001008,   // mr.ne.hi_433 lt.sl.hr_543  sl.hr.un_320 lt.lg.un_430
  0x06005314, 0x292d0d04, 0x17041002, 0x21002802,   // ht.de.un_660 cs.sk.sl_332  be.ru.sr_222 sw.jw.un_220
  0x19003f0d, 0x0c080607, 0x551e1c04, 0x17001f07,   // af.gl.un_540 de.no.sv_432  id.ms.rw_332 cy.sr.un_420
  // [0a70]
  0x2300051b, 0x08070413, 0x182112ec, 0x6b1101a4,   // fr.ca.un_770 ru.bg.uk_665  ur.fa.ar_644 en.ro.ceb_433
  0x64005521, 0x00000315, 0x03000e04, 0x25100808,   // rw.lg.un_860 nl.un.un_700  is.nl.un_320 no.lt.eu_443
  0x17001614, 0x181c1e0c, 0x55646ba4, 0x1b3f3107,   // hr.sr.un_660 ms.id.ga_543  ceb.lg.rw_433 az.af.tr_432
  0x070a1702, 0x130208a0, 0x1c001e0c, 0x53641eee,   // sr.mk.bg_222 no.da.et_322  ms.id.un_530 ms.lg.ht_422
  // [0a80]
  0x04170aa0, 0x03003f07, 0x2b00050c, 0x640501af,   // mk.sr.ru_322 af.nl.un_420  fr.vi.un_530 en.fr.lg_655
  0x030828ee, 0x12005312, 0x2100121a, 0x0a0717af,   // sw.no.nl_422 ht.hu.un_640  ur.fa.un_760 sr.bg.mk_655
  0x062a01ec, 0x03003f0b, 0x00000203, 0x12005304,   // en.mt.de_644 af.nl.un_520  da.un.un_300 ht.hu.un_320
  0x08000205, 0x06000305, 0x2d290dee, 0x010d2d0c,   // da.no.un_330 nl.de.un_330  cs.sl.sk_422 sk.cs.en_543
  // [0a90]
  0x091c0d5a, 0x0e072aaf, 0x170f1002, 0x00001024,   // ne.mr.hi_553 mt.it.is_655  lt.lv.sr_222 be.un.un_900
  0x1c281308, 0x25190b09, 0x0e0f06a7, 0x28311ba4,   // et.sw.id_443 es.gl.eu_444  de.lv.is_532 tr.az.sw_433
  0x100b21ad, 0x1b1e1c08, 0x04281ca4, 0x1800212a,   // jw.es.lt_643 id.ms.tr_443  id.sw.fi_433 fa.ar.un_970
  0x04641ba4, 0x64281b11, 0x1b1e1ca4, 0x0804170c,   // tr.lg.fi_433 tr.sw.lg_653  id.ms.tr_433 sr.ru.uk_543
  // [0aa0]
  0x641b5307, 0x131b5504, 0x0e1b2a12, 0x0e1f2a5a,   // ht.tr.lg_432 rw.tr.et_332  mt.tr.is_654 mt.cy.is_553
  0x551c64a4, 0x1c311b11, 0x31071baf, 0x2925040b,   // lg.id.rw_433 tr.az.id_653  tr.it.az_655 fi.eu.sl_542
  0x2a311f05, 0x0e2a0d07, 0x12001804, 0x0800030d,   // cy.az.mt_333 cs.mt.is_432  ar.ur.un_320 nl.no.un_540
  0x17162a02, 0x1c000d14, 0x2a001f1a, 0x23190b0d,   // mt.hr.sr_222 ne.mr.un_660  cy.mt.un_760 es.gl.ca_554
  // [0ab0]
  0x17161004, 0x08171107, 0x0f2a1313, 0x1b0453a4,   // lt.hr.sr_332 ro.sr.uk_432  et.mt.lv_665 ht.fi.tr_433
  0x110e1f07, 0x13002904, 0x06001b13, 0x0e001814,   // cy.is.ro_432 sl.et.un_320  tr.de.un_650 ga.is.un_660
  0x0c000213, 0x06001b02, 0x060d21ad, 0x1b211c08,   // da.sv.un_650 tr.de.un_220  jw.cs.de_643 id.jw.tr_443
  0x55250202, 0x2155280d, 0x10000904, 0x21041ca4,   // da.eu.rw_222 sw.rw.jw_554  pl.lt.un_320 id.fi.jw_433
  // [0ac0]
  0x1c000c02, 0x1a642855, 0x31051104, 0x1f0d01a4,   // sv.id.un_220 sw.lg.tl_442  ro.fr.az_332 en.cs.cy_433
  0x09001c09, 0x1e1c1b0c, 0x53281c0b, 0x0e062aa0,   // mr.hi.un_440 tr.id.ms_543  id.sw.ht_542 mt.de.is_322
  0x1e001c09, 0x032821ee, 0x190b0a14, 0x081107a4,   // id.ms.un_440 jw.sw.nl_422  pt.es.gl_666 bg.ro.uk_433
  0x2a1b3112, 0x25000621, 0x1b090d07, 0x070a110e,   // az.tr.mt_654 de.eu.un_860  cs.pl.tr_432 ro.mk.bg_555
  // [0ad0]
  0x17161ba0, 0x101e250c, 0x1a006407, 0x20211e04,   // tr.hr.sr_322 eu.ms.lt_543  lg.tl.un_420 ms.jw.sq_332
  0x641f0455, 0x293f55a7, 0x1c211e0c, 0x17160e0c,   // fi.cy.lg_442 rw.af.sl_532  ms.jw.id_543 is.hr.sr_543
  0x050711ee, 0x2100181a, 0x1b112aaf, 0x04070a04,   // ro.it.fr_422 ar.fa.un_760  mt.ro.tr_655 mk.bg.ru_332
  0x091823a0, 0x16005504, 0x08170704, 0x216425a0,   // ca.ga.pl_322 rw.hr.un_320  bg.sr.uk_332 eu.lg.jw_322
  // [0ae0]
  0x00000f24, 0x08071104, 0x2a3f1302, 0x11215507,   // lv.un.un_900 ro.bg.uk_332  et.af.mt_222 rw.jw.ro_432
  0x0b00210d, 0x0f000a02, 0x070a0408, 0x181221a9,   // jw.es.un_540 pt.lv.un_220  ru.mk.bg_443 fa.ur.ar_544
  0x200f1308, 0x08071155, 0x27182302, 0x1000040d,   // et.lv.sq_443 ro.bg.uk_442  ca.ga.gd_222 ru.be.un_540
  0x0a0717a0, 0x11000113, 0x28556408, 0x170a10a0,   // sr.bg.mk_322 en.ro.un_650  lg.rw.sw_443 be.mk.sr_322
  // [0af0]
  0x55002813, 0x2d171608, 0x115516a0, 0x16001104,   // sw.rw.un_650 hr.sr.sk_443  hr.rw.ro_322 ro.hr.un_320
  0x0a001709, 0x0a0711a4, 0x13090da4, 0x052d0d04,   // sr.mk.un_440 ro.bg.mk_433  ne.hi.bh_433 cs.sk.fr_332
  0x1221180c, 0x09000d04, 0x1c090d0b, 0x16001102,   // ar.fa.ur_543 ne.hi.un_320  ne.hi.mr_542 ro.hr.un_220
  0x03003f02, 0x0a0704a9, 0x21005505, 0x170b11a0,   // af.nl.un_220 ru.bg.mk_544  rw.jw.un_330 ro.es.sr_322
  // [0b00]
  0x0704080c, 0x13006b19, 0x036413ee, 0x122813ad,   // uk.ru.bg_543 ceb.et.un_750  et.lg.nl_422 et.sw.hu_643
  0x00006b24, 0x122513ad, 0x0b001908, 0x0717080c,   // ceb.un.un_900 et.eu.hu_643  gl.es.un_430 uk.sr.bg_543
  0x03133f04, 0x11000519, 0x6b00641b, 0x1a6e2008,   // af.et.nl_332 fr.ro.un_750  lg.ceb.un_770 sq.blu.tl_443
  0x1200180b, 0x03003f0d, 0x211c1eec, 0x3f0308a9,   // ga.hu.un_520 af.nl.un_540  ms.id.jw_644 no.nl.af_544
  // [0b10]
  0x27080e12, 0x1b000e14, 0x070a0808, 0x64005504,   // is.no.gd_654 is.tr.un_660  uk.mk.bg_443 rw.lg.un_320
  0x1e1c08ec, 0x1a006409, 0x1600170c, 0x03000604,   // no.id.ms_644 lg.tl.un_440  sr.hr.un_530 de.nl.un_320
  0x0e005305, 0x033f06af, 0x0f171602, 0x172d03a4,   // ht.is.un_330 de.af.nl_655  hr.sr.lv_222 nl.sk.sr_433
  0x0d000921, 0x033f25af, 0x036406ec, 0x033f06ee,   // hi.ne.un_860 eu.af.nl_655  de.lg.nl_644 de.af.nl_422
  // [0b20]
  0x3f0208a4, 0x0a641304, 0x0e00120e, 0x28006407,   // no.da.af_433 et.lg.pt_332  hu.is.un_550 lg.sw.un_420
  0x20000204, 0x08040704, 0x20002802, 0x170f1005,   // da.sq.un_320 bg.ru.uk_332  sw.sq.un_220 lt.lv.sr_333
  0x03286404, 0x08000a02, 0x2a001207, 0x2d0d01af,   // lg.sw.nl_332 mk.uk.un_220  hu.mt.un_420 en.cs.sk_655
  0x063f21ee, 0x0b190ead, 0x3f64030e, 0x0706010c,   // jw.af.de_422 is.gl.es_643  nl.lg.af_555 en.de.it_543
  // [0b30]
  0x110a0705, 0x1300640d, 0x040a0713, 0x20280111,   // bg.mk.ro_333 lg.et.un_540  bg.mk.ru_665 en.sw.sq_653
  0x64136bee, 0x09001c04, 0x171331a0, 0x3f0603af,   // ceb.et.lg_422 mr.hi.un_320  az.et.sr_322 nl.de.af_655
  0x0900060c, 0x1c00131b, 0x080407a9, 0x17000814,   // de.pl.un_530 bh.mr.un_770  bg.ru.uk_544 uk.sr.un_660
  0x06033fa4, 0x1c002507, 0x00000206, 0x23002508,   // af.nl.de_433 eu.id.un_420  da.un.un_400 eu.ca.un_430
  // [0b40]
  0x091c0d14, 0x02000808, 0x06005505, 0x16001002,   // ne.mr.hi_666 no.da.un_430  rw.de.un_330 lt.hr.un_220
  0x060c0804, 0x010712a0, 0x170a0713, 0x0d130912,   // no.sv.de_332 hu.it.en_322  bg.mk.sr_665 hi.bh.ne_654
  0x05000107, 0x2d0d01ec, 0x1300091a, 0x29001207,   // en.fr.un_420 en.cs.sk_644  hi.bh.un_760 hu.sl.un_420
  0x19000b0e, 0x09001311, 0x180801ee, 0x21002808,   // es.gl.un_550 bh.hi.un_630  en.no.ga_422 sw.jw.un_430
  // [0b50]
  0x18080213, 0x21002504, 0x00000b24, 0x23002519,   // da.no.ga_665 eu.jw.un_320  bn.un.un_900 eu.ca.un_750
  0x13000d05, 0x64005522, 0x64171613, 0x091c13a9,   // ne.bh.un_330 rw.lg.un_870  hr.sr.lg_665 bh.mr.hi_544
  0x0c0e080b, 0x16292508, 0x081e2d07, 0x17162805,   // no.is.sv_542 eu.sl.hr_443  sk.ms.no_432 sw.hr.sr_333
  0x281b10a0, 0x31001105, 0x10001704, 0x101b0aa4,   // lt.tr.sw_322 ro.az.un_330  sr.lt.un_320 pt.tr.lt_433
  // [0b60]
  0x0200082a, 0x04080704, 0x19000a21, 0x02060ea4,   // no.da.un_970 bg.uk.ru_332  pt.gl.un_860 is.de.da_433
  0x100a1712, 0x64002805, 0x04170aaf, 0x16002905,   // sr.mk.be_654 sw.lg.un_330  mk.sr.ru_655 sl.hr.un_330
  0x23000b08, 0x64005514, 0x060e2804, 0x07080a12,   // es.ca.un_430 rw.lg.un_660  sw.is.de_332 mk.uk.bg_654
  0x08020c12, 0x09001904, 0x3f030ca9, 0x18055310,   // sv.da.no_654 gl.pl.un_320  sv.nl.af_544 ht.fr.ga_642
  // [0b70]
  0x12172902, 0x016b21ee, 0x09131c5a, 0x20000104,   // sl.sr.hu_222 jw.ceb.en_422  mr.bh.hi_553 en.sq.un_320
  0x13000604, 0x0c002d02, 0x642a065a, 0x1f002a04,   // de.et.un_320 sk.sv.un_220  de.mt.lg_553 mt.cy.un_320
  0x170a08a0, 0x0d171608, 0x13091c12, 0x0300061a,   // uk.mk.sr_322 hr.sr.cs_443  mr.hi.bh_654 de.nl.un_760
  0x0a001e04, 0x08000421, 0x100d2904, 0x1710160c,   // ms.pt.un_320 ru.uk.un_860  sl.cs.lt_332 hr.lt.sr_543
  // [0b80]
  0x0c0208a7, 0x2900091a, 0x12211811, 0x1e000d0d,   // no.da.sv_532 pl.sl.un_760  ar.fa.ur_653 cs.ms.un_540
  0x06001f22, 0x0f532a55, 0x11100f07, 0x08020c14,   // cy.de.un_870 mt.ht.lv_442  lv.lt.ro_432 sv.da.no_666
  0x00003f06, 0x0d181209, 0x0c0811a0, 0x0500190c,   // af.un.un_400 hu.ga.cs_444  ro.no.sv_322 gl.fr.un_530
  0x0e293104, 0x1218215a, 0x0c270ea9, 0x05002321,   // az.sl.is_332 fa.ar.ur_553  is.gd.sv_544 ca.fr.un_860
  // [0b90]
  0x08170405, 0x1e1c200c, 0x0e00251a, 0x0300011a,   // ru.sr.uk_333 sq.id.ms_543  eu.is.un_760 en.nl.un_760
  0x2700060c, 0x06005514, 0x0c080ead, 0x080711ac,   // de.gd.un_530 rw.de.un_660  is.no.sv_643 ro.bg.uk_632
  0x190a2dee, 0x19062709, 0x29092da9, 0x11002507,   // sk.pt.gl_422 gd.de.gl_444  sk.pl.sl_544 eu.ro.un_420
  0x0c070e08, 0x192d0dad, 0x271808a0, 0x0a00190c,   // is.it.sv_443 cs.sk.gl_643  no.ga.gd_322 gl.pt.un_530
  // [0ba0]
  0x04002707, 0x08012a07, 0x2d3f0d11, 0x532d0dec,   // gd.fi.un_420 mt.en.no_432  cs.af.sk_653 cs.sk.ht_644
  0x21000804, 0x0e130608, 0x09202d0c, 0x53002d13,   // no.jw.un_320 de.et.is_443  sk.sq.pl_543 sk.ht.un_650
  0x17162da9, 0x2d190d0c, 0x270464a6, 0x3f0708a4,   // sk.hr.sr_544 cs.gl.sk_543  lg.fi.gd_521 no.it.af_433
  0x3f060305, 0x1c090dee, 0x190a53ee, 0x05000808,   // nl.de.af_333 ne.hi.mr_422  ht.pt.gl_422 no.fr.un_430
  // [0bb0]
  0x19000a1b, 0x0e080609, 0x0908110c, 0x64041308,   // pt.gl.un_770 de.no.is_444  ro.no.pl_543 et.fi.lg_443
  0x12002129, 0x2d092909, 0x2d0d3f09, 0x28272307,   // fa.ur.un_960 sl.pl.sk_444  af.cs.sk_444 ca.gd.sw_432
  0x16092da4, 0x2d190a14, 0x040710ad, 0x08171605,   // sk.pl.hr_433 pt.gl.sk_666  lt.it.fi_643 hr.sr.no_333
  0x04001008, 0x2811160e, 0x111901a4, 0x29000813,   // be.ru.un_430 hr.ro.sw_555  en.gl.ro_433 no.sl.un_650
  // [0bc0]
  0x0e002502, 0x0d091314, 0x0a001911, 0x0c0e25ad,   // eu.is.un_220 bh.hi.ne_666  gl.pt.un_630 eu.is.sv_643
  0x012d3f08, 0x171610a0, 0x2917160d, 0x0b2519ec,   // af.sk.en_443 lt.hr.sr_322  hr.sr.sl_554 gl.eu.es_644
  0x19000a14, 0x29002d0d, 0x0d002d0d, 0x190a53a9,   // pt.gl.un_660 sk.sl.un_540  sk.cs.un_540 ht.pt.gl_544
  0x29002d08, 0x080e0612, 0x11001008, 0x06005308,   // sk.sl.un_430 de.is.no_654  lt.ro.un_430 ht.de.un_430
  // [0bd0]
  0x2d080212, 0x0e000807, 0x12000e19, 0x0a0d190c,   // da.no.sk_654 no.is.un_420  is.hu.un_750 gl.cs.pt_543
  0x16292009, 0x641017a0, 0x53190d07, 0x04070aa9,   // sq.sl.hr_444 sr.lt.lg_322  cs.gl.ht_432 mk.bg.ru_544
  0x07010b13, 0x1b162da4, 0x09001320, 0x0300051a,   // es.en.it_665 sk.hr.tr_433  bh.hi.un_850 fr.nl.un_760
  0x041364ad, 0x1c090d09, 0x291716a7, 0x18002114,   // lg.et.fi_643 ne.hi.mr_444  hr.sr.sl_532 fa.ar.un_660
  // [0be0]
  0x041364a0, 0x0b19180c, 0x00003106, 0x136404a9,   // lg.et.fi_322 ga.gl.es_543  az.un.un_400 fi.lg.et_544
  0x0410085a, 0x6e311ba9, 0x130464af, 0x05000604,   // uk.be.ru_553 tr.az.blu_544  lg.fi.et_655 de.fr.un_320
  0x0a000713, 0x11236ea9, 0x091f6b02, 0x0a111705,   // bg.mk.un_650 blu.ca.ro_544  ceb.cy.pl_222 sr.ro.mk_333
  0x16001712, 0x2400011a, 0x201b1ca4, 0x07041005,   // sr.hr.un_640 iw.yi.un_760  id.tr.sq_433 lt.fi.it_333
  // [0bf0]
  0x29001e04, 0x2d000909, 0x10071702, 0x0c0208af,   // ms.sl.un_320 pl.sk.un_440  sr.bg.be_222 no.da.sv_655
  0x31002007, 0x12182107, 0x02000520, 0x00000601,   // sq.az.un_420 fa.ar.ur_432  fr.da.un_850 de.un.un_200
  0x13110511, 0x020305af, 0x0817110c, 0x1108050c,   // fr.ro.et_653 fr.nl.da_655  ro.sr.uk_543 fr.no.ro_543
  0x1008040c, 0x021105ee, 0x17000a0e, 0x10000712,   // ru.uk.be_543 fr.ro.da_422  mk.sr.un_550 bg.be.un_640

  // [0c00]
  0x040811a7, 0x170a1160, 0x6b551aa4, 0x090d1cad,   // ro.uk.ru_532 ro.mk.sr_664  tl.rw.ceb_433 mr.ne.hi_643
  0x1c001323, 0x0000532d, 0x04001704, 0x640801a0,   // bh.mr.un_880 ht.un.un_A00  sr.ru.un_320 en.no.lg_322
  0x2d0d2504, 0x640153a0, 0x17001612, 0x1f005504,   // eu.cs.sk_332 ht.en.lg_322  hr.sr.un_640 rw.cy.un_320
  0x17000422, 0x04100808, 0x1700071b, 0x1200091a,   // ru.sr.un_870 uk.be.ru_443  bg.sr.un_770 pl.hu.un_760
  // [0c10]
  0x550711a4, 0x1b532104, 0x0c1107af, 0x09041007,   // ro.it.rw_433 jw.ht.tr_332  it.ro.sv_655 lt.fi.pl_432
  0x0410080d, 0x1800550d, 0x09001f2a, 0x55251b5a,   // uk.be.ru_554 rw.ga.un_540  cy.pl.un_970 tr.eu.rw_553
  0x182d0d13, 0x21551c12, 0x080c555a, 0x28645511,   // cs.sk.ga_665 id.rw.jw_654  rw.sv.no_553 rw.lg.sw_653
  0x2100031b, 0x3f0c1107, 0x0c001305, 0x0000531c,   // nl.jw.un_770 ro.sv.af_432  et.sv.un_330 ht.un.un_800
  // [0c20]
  0x070c08a0, 0x0000160f, 0x0b005304, 0x2d230511,   // no.sv.it_322 hr.un.un_600  ht.es.un_320 fr.ca.sk_653
  0x0a230707, 0x02200705, 0x21001814, 0x11311bad,   // it.ca.pt_432 it.sq.da_333  ar.fa.un_660 tr.az.ro_643
  0x10000409, 0x021308ee, 0x09531212, 0x100708ec,   // ru.be.un_440 no.et.da_422  hu.ht.pl_654 uk.bg.be_644
  0x080213a0, 0x16552109, 0x1103550c, 0x28006408,   // et.da.no_322 jw.rw.hr_444  rw.nl.ro_543 lg.sw.un_430
  // [0c30]
  0x07001123, 0x1f1101a6, 0x092a3fa6, 0x07100a07,   // ro.it.un_880 en.ro.cy_521  af.mt.pl_521 pt.lt.it_432
  0x21002021, 0x01002507, 0x12182111, 0x01002420,   // sq.jw.un_860 eu.en.un_420  fa.ar.ur_653 yi.iw.un_850
  0x1c5323a0, 0x1f2125af, 0x55002004, 0x252113ec,   // ca.ht.id_322 eu.jw.cy_655  sq.rw.un_320 et.jw.eu_644
  0x043f64a0, 0x2d0d09a9, 0x0d091311, 0x190b21a4,   // lg.af.fi_322 pl.cs.sk_544  bh.hi.ne_653 jw.es.gl_433
  // [0c40]
  0x1a6b1c0c, 0x281b55ad, 0x081a21a0, 0x3f002d04,   // id.ceb.tl_543 rw.tr.sw_643  jw.tl.no_322 sk.af.un_320
  0x0c00110d, 0x020c070c, 0x07000413, 0x1a006b0d,   // ro.sv.un_540 it.sv.da_543  fi.it.un_650 ceb.tl.un_540
  0x0c2d0dee, 0x07201109, 0x3f002d07, 0x1716290b,   // cs.sk.sv_422 ro.sq.it_444  sk.af.un_420 sl.hr.sr_542
  0x100a1704, 0x050308a9, 0x110708a0, 0x21556408,   // sr.mk.be_332 no.nl.fr_544  no.it.ro_322 lg.rw.jw_443
  // [0c50]
  0x110105af, 0x21072508, 0x070c1108, 0x53000804,   // fr.en.ro_655 eu.it.jw_443  ro.sv.it_443 no.ht.un_320
  0x20003104, 0x03063f04, 0x6e0c6b02, 0x0d130913,   // az.sq.un_320 af.de.nl_332  ceb.sv.blu_222 hi.bh.ne_665
  0x030601a0, 0x0b00280c, 0x0a040702, 0x280802a0,   // en.de.nl_322 sw.es.un_530  bg.ru.mk_222 da.no.sw_322
  0x3f0608ec, 0x12000d0d, 0x0520110d, 0x130e04a7,   // no.de.af_644 cs.hu.un_540  ro.sq.fr_554 fi.is.et_532
  // [0c60]
  0x0c0208ec, 0x08000214, 0x08020aa4, 0x102d0dec,   // no.da.sv_644 da.no.un_660  pt.da.no_433 cs.sk.lt_644
  0x25001c07, 0x08170a04, 0x080c0212, 0x091c0d13,   // id.eu.un_420 mk.sr.uk_332  da.sv.no_654 ne.mr.hi_665
  0x0e0208a0, 0x536b280b, 0x281a6b07, 0x211c27a4,   // no.da.is_322 sw.ceb.ht_542  ceb.tl.sw_432 gd.id.jw_433
  0x53001105, 0x1e1c2014, 0x0d001604, 0x00002001,   // ro.ht.un_330 sq.id.ms_666  hr.cs.un_320 sq.un.un_200
  // [0c70]
  0x12116405, 0x08000213, 0x5528640d, 0x13000704,   // lg.ro.hu_333 da.no.un_650  lg.sw.rw_554 it.et.un_320
  0x21001812, 0x13000c04, 0x551e1c09, 0x310904a4,   // ar.fa.un_640 sv.et.un_320  id.ms.rw_444 fi.pl.az_433
  0x1e000223, 0x03063fa4, 0x03063f55, 0x3f006b05,   // da.ms.un_880 af.de.nl_433  af.de.nl_442 ceb.af.un_330
  0x3f000313, 0x020c08a4, 0x04170702, 0x292d16a0,   // nl.af.un_650 no.sv.da_433  bg.sr.ru_222 hr.sk.sl_322
  // [0c80]
  0x060c0808, 0x1a0b0a55, 0x19231fa0, 0x1c1e3f0c,   // no.sv.de_443 pt.es.tl_442  cy.ca.gl_322 af.ms.id_543
  0x17000a2a, 0x0f000309, 0x6b001a12, 0x07170aad,   // mk.sr.un_970 nl.lv.un_440  tl.ceb.un_640 mk.sr.bg_643
  0x08100404, 0x0813040c, 0x1000110d, 0x040e0807,   // ru.be.uk_332 fi.et.no_543  ro.be.un_540 no.is.fi_432
  0x0d002904, 0x041711ee, 0x2d00120c, 0x27172912,   // sl.cs.un_320 ro.sr.ru_422  hu.sk.un_530 sl.sr.gd_654
  // [0c90]
  0x04170aee, 0x04001020, 0x13002809, 0x100807a0,   // mk.sr.ru_422 be.ru.un_850  sw.et.un_440 bg.uk.be_322
  0x170a0755, 0x07170a02, 0x08000308, 0x09001c18,   // bg.mk.sr_442 mk.sr.bg_222  nl.no.un_430 mr.hi.un_740
  0x070a1707, 0x16001704, 0x02002a04, 0x060c0907,   // sr.mk.bg_432 sr.hr.un_320  mt.da.un_320 pl.sv.de_432
  0x02000604, 0x081004ad, 0x211218ad, 0x17000a08,   // de.da.un_320 ru.be.uk_643  ar.ur.fa_643 mk.sr.un_430
  // [0ca0]
  0x01002004, 0x13091cec, 0x12001112, 0x21250912,   // sq.en.un_320 mr.hi.bh_644  ro.hu.un_640 pl.eu.jw_654
  0x13000d19, 0x25000108, 0x0a170714, 0x18250707,   // ne.bh.un_750 en.eu.un_430  bg.sr.mk_666 it.eu.ga_432
  0x121821ec, 0x1a1f27ee, 0x0b001913, 0x230725a4,   // fa.ar.ur_644 gd.cy.tl_422  gl.es.un_650 eu.it.ca_433
  0x07000a22, 0x3f112da4, 0x0a3f0304, 0x07033fee,   // mk.bg.un_870 sk.ro.af_433  nl.af.pt_332 af.nl.it_422
  // [0cb0]
  0x09002d35, 0x080725a6, 0x09000e12, 0x27000505,   // sk.pl.un_A90 eu.it.no_521  is.pl.un_640 fr.gd.un_330
  0x110507a4, 0x080a1708, 0x0f09010b, 0x1e1c2505,   // it.fr.ro_433 sr.mk.uk_443  en.pl.lv_542 eu.id.ms_333
  0x0f003f22, 0x2a006404, 0x0e000c14, 0x0d102904,   // af.lv.un_870 lg.mt.un_320  sv.is.un_660 sl.lt.cs_332
  0x2d0d1ea0, 0x11050da4, 0x13172907, 0x0700251a,   // ms.cs.sk_322 cs.fr.ro_433  sl.sr.et_432 eu.it.un_760
  // [0cc0]
  0x03113f12, 0x16002d04, 0x2d171602, 0x3f2d09ad,   // af.ro.nl_654 sk.hr.un_320  hr.sr.sk_222 pl.sk.af_643
  0x08041755, 0x13001c1a, 0x09002d2b, 0x0400170c,   // sr.ru.uk_442 mr.bh.un_760  sk.pl.un_980 sr.ru.un_530
  0x25001908, 0x190b07a4, 0x1a006b08, 0x12000702,   // gl.eu.un_430 it.es.gl_433  ceb.tl.un_430 it.hu.un_220
  0x1e1c25ee, 0x11001002, 0x1b000a02, 0x00001324,   // eu.id.ms_422 lt.ro.un_220  pt.tr.un_220 bh.un.un_900
  // [0cd0]
  0x070a11a4, 0x2112180c, 0x07090da4, 0x1c1e2508,   // ro.mk.bg_433 ar.ur.fa_543  cs.pl.it_433 eu.ms.id_443
  0x21005304, 0x3f000104, 0x0a2d010b, 0x08060911,   // ht.jw.un_320 en.af.un_320  en.sk.pt_542 pl.de.no_653
  0x2d110312, 0x0e0c08a0, 0x0417070c, 0x060501a0,   // nl.ro.sk_654 no.sv.is_322  bg.sr.ru_543 en.fr.de_322
  0x2d093f12, 0x252305a0, 0x3f090d07, 0x53002807,   // af.pl.sk_654 fr.ca.eu_322  cs.pl.af_432 sw.ht.un_420
  // [0ce0]
  0x07002807, 0x13251907, 0x020c0e55, 0x11040805,   // sw.it.un_420 gl.eu.et_432  is.sv.da_442 uk.ru.ro_333
  0x0c0301a4, 0x6b1c1e0c, 0x1b001a0e, 0x285564a4,   // en.nl.sv_433 ms.id.ceb_543  tl.tr.un_550 lg.rw.sw_433
  0x211e1c0d, 0x29171655, 0x1c0d0905, 0x13001c09,   // id.ms.jw_554 hr.sr.sl_442  hi.ne.mr_333 mr.bh.un_440
  0x1a000104, 0x0a110707, 0x1f082102, 0x29000f13,   // en.tl.un_320 bg.ro.mk_432  jw.no.cy_222 lv.sl.un_650
  // [0cf0]
  0x6b020c55, 0x131c0960, 0x2a6b1a0c, 0x642513ad,   // sv.da.ceb_442 hi.mr.bh_664  tl.ceb.mt_543 et.eu.lg_643
  0x083f1f04, 0x1a051b04, 0x191b1f0c, 0x311f19a0,   // cy.af.no_332 tr.fr.tl_332  cy.tr.gl_543 gl.cy.az_322
  0x6b2001a4, 0x08070409, 0x031f3f04, 0x1a1e1c08,   // en.sq.ceb_433 ru.bg.uk_444  af.cy.nl_332 id.ms.tl_443
  0x020c08a0, 0x3f000204, 0x2d0d0805, 0x1f1e1c60,   // no.sv.da_322 da.af.un_320  no.cs.sk_333 id.ms.cy_664
  // [0d00]
  0x1c0d0914, 0x0e001319, 0x1e1c0c07, 0x170c13ad,   // hi.ne.mr_666 et.is.un_750  sv.id.ms_432 et.sv.sr_643
  0x06001f0d, 0x076412ad, 0x0c001907, 0x1704110c,   // cy.de.un_540 hu.lg.it_643  gl.sv.un_420 ro.ru.sr_543
  0x1f00550d, 0x0c005305, 0x1b3f1a04, 0x17040aee,   // rw.cy.un_540 ht.sv.un_330  tl.af.tr_332 mk.ru.sr_422
  0x0e000a09, 0x6b001a1a, 0x21011a04, 0x0c000823,   // pt.is.un_440 tl.ceb.un_760  tl.en.jw_332 no.sv.un_880
  // [0d10]
  0x10041702, 0x2b001f07, 0x1c13090b, 0x04000812,   // sr.ru.be_222 cy.vi.un_420  hi.bh.mr_542 uk.ru.un_640
  0x092d0d04, 0x0a081704, 0x011f6ba0, 0x0a070411,   // cs.sk.pl_332 sr.uk.mk_332  ceb.cy.en_322 ru.bg.mk_653
  0x18001304, 0x13000104, 0x190a1fa0, 0x0a070805,   // et.ga.un_320 en.et.un_320  cy.pt.gl_322 uk.bg.mk_333
  0x211e1cad, 0x16001804, 0x111e1c55, 0x0d000905,   // id.ms.jw_643 ga.hr.un_320  id.ms.ro_442 hi.ne.un_330
  // [0d20]
  0x09001807, 0x063f0313, 0x0a2a01a4, 0x64063fa0,   // ga.pl.un_420 nl.af.de_665  en.mt.pt_433 af.de.lg_322
  0x05000302, 0x27002807, 0x03003f22, 0x050c01a0,   // nl.fr.un_220 sw.gd.un_420  af.nl.un_870 en.sv.fr_322
  0x170a0760, 0x55000402, 0x1c13090e, 0x13091c0c,   // bg.mk.sr_664 fi.rw.un_220  hi.bh.mr_555 mr.hi.bh_543
  0x1c000d20, 0x0c000a08, 0x23190b04, 0x130301a0,   // ne.mr.un_850 pt.sv.un_430  es.gl.ca_332 en.nl.et_322
  // [0d30]
  0x0a000721, 0x121329a7, 0x53003119, 0x01061fad,   // bg.mk.un_860 sl.et.hu_532  az.ht.un_750 cy.de.en_643
  0x091c0d0d, 0x3f000304, 0x00000424, 0x0c000307,   // ne.mr.hi_554 nl.af.un_320  fi.un.un_900 nl.sv.un_420
  0x13171613, 0x17100a05, 0x1f000807, 0x130c0808,   // hr.sr.et_665 mk.be.sr_333  no.cy.un_420 no.sv.et_443
  0x06000502, 0x1704100c, 0x0e000c02, 0x052301ee,   // fr.de.un_220 be.ru.sr_543  sv.is.un_220 en.ca.fr_422
  // [0d40]
  0x0408105a, 0x1c000d0e, 0x12002314, 0x0d001312,   // be.uk.ru_553 ne.mr.un_550  ca.hu.un_660 bh.ne.un_640
  0x17000a23, 0x1716110c, 0x17000402, 0x21001805,   // mk.sr.un_880 ro.hr.sr_543  ru.sr.un_220 ar.fa.un_330
  0x0c080211, 0x0c131209, 0x09001f0c, 0x00006e2d,   // da.no.sv_653 hu.et.sv_444  cy.pl.un_530 blu.un.un_A00
  0x0400131b, 0x10131ca7, 0x130d090e, 0x21001205,   // et.fi.un_770 id.et.lt_532  hi.ne.bh_555 ur.fa.un_330
  // [0d50]
  0x0e000211, 0x02000804, 0x1710040e, 0x091c0daf,   // da.is.un_630 no.da.un_320  ru.be.sr_555 ne.mr.hi_655
  0x0a001708, 0x0d00090c, 0x2a0e1f0c, 0x0e003f05,   // sr.mk.un_430 hi.ne.un_530  cy.is.mt_543 af.is.un_330
  0x0f130e04, 0x2d0d13ee, 0x080c0e13, 0x230b05a9,   // is.et.lv_332 et.cs.sk_422  is.sv.no_665 fr.es.ca_544
  0x17160da0, 0x02000d08, 0x2a000f1a, 0x0b255307,   // cs.hr.sr_322 cs.da.un_430  lv.mt.un_760 ht.eu.es_432
  // [0d60]
  0x091c0dee, 0x07003f02, 0x0e001f1b, 0x10080a13,   // ne.mr.hi_422 af.it.un_220  cy.is.un_770 mk.uk.be_665
  0x040212a4, 0x190b0a13, 0x2d0d160e, 0x03001313,   // hu.da.fi_433 pt.es.gl_665  hr.cs.sk_555 et.nl.un_650
  0x2a2827a4, 0x081221a0, 0x201013a0, 0x16022da4,   // gd.sw.mt_433 jw.hu.no_322  et.lt.sq_322 sk.da.hr_433
  0x1a001c02, 0x25230107, 0x17000a0d, 0x31001b22,   // id.tl.un_220 en.ca.eu_432  mk.sr.un_540 tr.az.un_870
  // [0d70]
  0x060e2807, 0x1a00120e, 0x28001313, 0x10081705,   // sw.is.de_432 hu.tl.un_550  et.sw.un_650 sr.uk.be_333
  0x061011a4, 0x1b00530d, 0x21001113, 0x0f171608,   // ro.lt.de_433 ht.tr.un_540  ro.jw.un_650 hr.sr.lv_443
  0x0f0410a0, 0x0f00130d, 0x1727180c, 0x180307a0,   // lt.fi.lv_322 et.lv.un_540  ga.gd.sr_543 it.nl.ga_322
  0x21171608, 0x05032007, 0x0d16170c, 0x0900120d,   // hr.sr.jw_443 sq.nl.fr_432  sr.hr.cs_543 hu.pl.un_540
  // [0d80]
  0x01230aa9, 0x2000280e, 0x1821120e, 0x021b0e04,   // pt.ca.en_544 sw.sq.un_550  ur.fa.ar_555 is.tr.da_332
  0x041710a4, 0x24000113, 0x55202813, 0x0908120c,   // be.sr.ru_433 iw.yi.un_650  sw.sq.rw_665 hu.no.pl_543
  0x0d002d21, 0x13002105, 0x10001113, 0x18001702,   // sk.cs.un_860 jw.et.un_330  ro.be.un_650 sr.ga.un_220
  0x64212804, 0x080711a4, 0x13002713, 0x13000a04,   // sw.jw.lg_332 ro.bg.uk_433  gd.et.un_650 pt.et.un_320
  // [0d90]
  0x6b100755, 0x091c0d12, 0x06002a02, 0x181221ec,   // it.lt.ceb_442 ne.mr.hi_654  mt.de.un_220 fa.ur.ar_644
  0x6b1a2111, 0x09005512, 0x0d00131a, 0x0e001f13,   // jw.tl.ceb_653 rw.pl.un_640  bh.ne.un_760 cy.is.un_650
  0x10001307, 0x0a002304, 0x0b002304, 0x190a0b02,   // et.lt.un_420 ca.pt.un_320  ca.es.un_320 es.pt.gl_222
  0x080a0407, 0x2a00550c, 0x04000a07, 0x281e1c07,   // ru.mk.uk_432 rw.mt.un_530  mk.ru.un_420 id.ms.sw_432
  // [0da0]
  0x2a1127ad, 0x040807ec, 0x0e0602a0, 0x1000080c,   // gd.ro.mt_643 bg.uk.ru_644  da.de.is_322 uk.be.un_530
  0x27041f55, 0x1b215304, 0x23250b07, 0x1300122b,   // cy.fi.gd_442 ht.jw.tr_332  es.eu.ca_432 hu.et.un_980
  0x281f0807, 0x1f001307, 0x21001308, 0x04001909,   // no.cy.sw_432 et.cy.un_420  et.jw.un_430 gl.fi.un_440
  0x1b003122, 0x23000419, 0x0a002819, 0x070a08af,   // az.tr.un_870 fi.ca.un_750  sw.pt.un_750 uk.mk.bg_655
  // [0db0]
  0x311b1213, 0x28000808, 0x05000708, 0x051f0408,   // hu.tr.az_665 no.sw.un_430  it.fr.un_430 fi.cy.fr_443
  0x11000504, 0x042a020c, 0x12000c02, 0x0507010c,   // fr.ro.un_320 da.mt.fi_543  sv.hu.un_220 en.it.fr_543
  0x6b1f010c, 0x12082055, 0x04000808, 0x0700010d,   // en.cy.ceb_543 sq.no.hu_442  no.fi.un_430 en.it.un_540
  0x06002304, 0x08060c07, 0x081f0e07, 0x070a1705,   // ca.de.un_320 sv.de.no_432  is.cy.no_432 sr.mk.bg_333
  // [0dc0]
  0x211218ec, 0x07081b07, 0x3f092aec, 0x00001a0f,   // ar.ur.fa_644 tr.no.it_432  mt.pl.af_644 tl.un.un_600
  0x20000605, 0x050701a4, 0x0c000704, 0x04013fa0,   // de.sq.un_330 en.it.fr_433  it.sv.un_320 af.en.fi_322
  0x17070a0c, 0x0c001e02, 0x04091fec, 0x020e1fa0,   // mk.bg.sr_543 ms.sv.un_220  cy.pl.fi_644 cy.is.da_322
  0x06110707, 0x0c0e07a0, 0x53091008, 0x06031b0c,   // it.ro.de_432 it.is.sv_322  lt.pl.ht_443 tr.nl.de_543
  // [0dd0]
  0x0a081107, 0x05061204, 0x12182114, 0x2800081a,   // ro.uk.mk_432 hu.de.fr_332  fa.ar.ur_666 no.sw.un_760
  0x08002313, 0x07050107, 0x02001c02, 0x1f010605,   // ca.no.un_650 en.fr.it_432  id.da.un_220 de.en.cy_333
  0x040601a4, 0x1e311b13, 0x64002102, 0x25000b04,   // en.de.fi_433 tr.az.ms_665  jw.lg.un_220 es.eu.un_320
  0x070417a0, 0x1906040c, 0x07170aa9, 0x3f000804,   // sr.ru.bg_322 fi.de.gl_543  mk.sr.bg_544 no.af.un_320
  // [0de0]
  0x10081704, 0x0711040c, 0x071711ee, 0x170a0708,   // sr.uk.be_332 ru.ro.bg_543  ro.sr.bg_422 bg.mk.sr_443
  0x09110d07, 0x13062a0c, 0x070a0404, 0x31161ba0,   // cs.ro.pl_432 mt.de.et_543  ru.mk.bg_332 tr.hr.az_322
  0x13000d02, 0x100408af, 0x20002704, 0x170a07a7,   // ne.bh.un_220 uk.ru.be_655  gd.sq.un_320 bg.mk.sr_532
  0x0a00170d, 0x08170aa0, 0x07000a13, 0x0e00101a,   // sr.mk.un_540 mk.sr.uk_322  mk.bg.un_650 lt.is.un_760
  // [0df0]
  0x28000409, 0x1f001904, 0x21000408, 0x12002114,   // fi.sw.un_440 gl.cy.un_320  fi.jw.un_430 fa.ur.un_660
  0x0f001704, 0x2b13530e, 0x170804ac, 0x0c00080e,   // sr.lv.un_320 ht.et.vi_555  ru.uk.sr_632 no.sv.un_550
  0x10040709, 0x2b1f2704, 0x13000407, 0x1f003f21,   // bg.ru.be_444 gd.cy.vi_332  fi.et.un_420 af.cy.un_860
  0x0a1707a0, 0x1a000e04, 0x0c0820ac, 0x1800212b,   // bg.sr.mk_322 is.tl.un_320  sq.no.sv_632 fa.ar.un_980
  // [0e00]
  0x0c002d07, 0x03090604, 0x10040708, 0x2d082912,   // sk.sv.un_420 de.pl.nl_332  bg.ru.be_443 sl.no.sk_654
  0x1c0913ec, 0x04070a05, 0x2d000d11, 0x21182011,   // bh.hi.mr_644 mk.bg.ru_333  cs.sk.un_630 sq.ga.jw_653
  0x216b1a12, 0x1929230c, 0x0a040713, 0x2a002702,   // tl.ceb.jw_654 ca.sl.gl_543  bg.ru.mk_665 gd.mt.un_220
  0x18122160, 0x23070f05, 0x06001305, 0x1f271813,   // fa.ur.ar_664 lv.it.ca_333  et.de.un_330 ga.gd.cy_665
  // [0e10]
  0x041f0a08, 0x1c0913a6, 0x05070112, 0x0e191804,   // pt.cy.fi_443 bh.hi.mr_521  en.it.fr_654 ga.gl.is_332
  0x2311100c, 0x0500011a, 0x231119ad, 0x19000402,   // lt.ro.ca_543 en.fr.un_760  gl.ro.ca_643 fi.gl.un_220
  0x1000090d, 0x1a0a6b04, 0x1f1a280c, 0x08042711,   // pl.lt.un_540 ceb.pt.tl_332  sw.tl.cy_543 gd.fi.no_653
  0x2920170c, 0x1c091314, 0x271304ad, 0x0907120c,   // sr.sq.sl_543 bh.hi.mr_666  fi.et.gd_643 hu.it.pl_543
  // [0e20]
  0x211a6ea0, 0x1f0e0607, 0x211827af, 0x100c6b02,   // blu.tl.jw_322 de.is.cy_432  gd.ga.jw_655 ceb.sv.lt_222
  0x2705010c, 0x27202113, 0x19110da4, 0x010c18ee,   // en.fr.gd_543 jw.sq.gd_665  cs.ro.gl_433 ga.sv.en_422
  0x0b231aa0, 0x18000405, 0x071127ad, 0x101123a4,   // tl.ca.es_322 fi.ga.un_330  gd.ro.it_643 ca.ro.lt_433
  0x16645507, 0x0200070b, 0x2019235a, 0x1a17165a,   // rw.lg.hr_432 it.da.un_520  ca.gl.sq_553 hr.sr.tl_553
  // [0e30]
  0x04190a55, 0x2d001604, 0x1011190c, 0x11092d08,   // pt.gl.fi_442 hr.sk.un_320  gl.ro.lt_543 sk.pl.ro_443
  0x06000e19, 0x190712a4, 0x311b1aa4, 0x6b071a05,   // is.de.un_750 hu.it.gl_433  tl.tr.az_433 tl.it.ceb_333
  0x132801a0, 0x182721a9, 0x12002119, 0x1c0d13a0,   // en.sw.et_322 jw.gd.ga_544  fa.ur.un_750 bh.ne.mr_322
  0x0f00100c, 0x16291711, 0x2b2028ac, 0x08001f21,   // lt.lv.un_530 sr.sl.hr_653  sw.sq.vi_632 cy.no.un_860
  // [0e40]
  0x31002023, 0x1900231a, 0x29002d05, 0x3100201a,   // sq.az.un_880 ca.gl.un_760  sk.sl.un_330 sq.az.un_760
  0x11191005, 0x0c02080c, 0x291716a4, 0x55002014,   // lt.gl.ro_333 no.da.sv_543  hr.sr.sl_433 sq.rw.un_660
  0x272018ad, 0x111923ad, 0x161a6ba9, 0x1b1853a0,   // ga.sq.gd_643 ca.gl.ro_643  ceb.tl.hr_544 ht.ga.tr_322
  0x20000d04, 0x041e1004, 0x09002807, 0x2011100d,   // cs.sq.un_320 lt.ms.fi_332  sw.pl.un_420 lt.ro.sq_554
  // [0e50]
  0x0b011aa7, 0x171604ec, 0x6e2055a9, 0x232d100c,   // tl.en.es_532 fi.hr.sr_644  rw.sq.blu_544 lt.sk.ca_543
  0x06033fa0, 0x551b0507, 0x31132007, 0x2d11100e,   // af.nl.de_322 fr.tr.rw_432  sq.et.az_432 lt.ro.sk_555
  0x6b1a5508, 0x1a166ba9, 0x27012aa0, 0x3f001a02,   // rw.tl.ceb_443 ceb.hr.tl_544  mt.en.gd_322 tl.af.un_220
  0x276b0104, 0x13060402, 0x172916ee, 0x16291c08,   // en.ceb.gd_332 fi.de.et_222  hr.sl.sr_422 id.sl.hr_443
  // [0e60]
  0x0a0704a4, 0x091c0d0c, 0x1c0d09ec, 0x0928205a,   // ru.bg.mk_433 ne.mr.hi_543  hi.ne.mr_644 sq.sw.pl_553
  0x3100641b, 0x552164ac, 0x20130b13, 0x1a060c04,   // lg.az.un_770 lg.jw.rw_632  es.et.sq_665 sv.de.tl_332
  0x0d091ca4, 0x07050605, 0x292d0d13, 0x18001219,   // mr.hi.ne_433 de.fr.it_333  cs.sk.sl_665 ur.ar.un_750
  0x08000c0d, 0x02000107, 0x131020a9, 0x09000d09,   // sv.no.un_540 en.da.un_420  sq.lt.et_544 ne.hi.un_440
  // [0e70]
  0x551304a4, 0x110710ad, 0x20003109, 0x0913040e,   // fi.et.rw_433 be.bg.ro_643  az.sq.un_440 fi.et.pl_555
  0x1c001f07, 0x07040809, 0x04090ead, 0x3f1c0302,   // cy.id.un_420 uk.ru.bg_444  is.pl.fi_643 nl.id.af_222
  0x0e001307, 0x041117ec, 0x0d120ca0, 0x0717040b,   // et.is.un_420 sr.ro.ru_644  sv.hu.cs_322 ru.sr.bg_542
  0x2d0d090e, 0x092d0d08, 0x1e1c2309, 0x1c0d0911,   // pl.cs.sk_555 cs.sk.pl_443  ca.id.ms_444 hi.ne.mr_653
  // [0e80]
  0x0e000c13, 0x0e040c0c, 0x12003f02, 0x551e1c08,   // sv.is.un_650 sv.fi.is_543  af.hu.un_220 id.ms.rw_443
  0x17071108, 0x28005505, 0x1e101caf, 0x040608a0,   // ro.bg.sr_443 rw.sw.un_330  id.lt.ms_655 no.de.fi_322
  0x17041104, 0x281e1c08, 0x18000502, 0x080a07a9,   // ro.ru.sr_332 id.ms.sw_443  fr.ga.un_220 bg.mk.uk_544
  0x12000504, 0x07080a55, 0x1b001607, 0x01001904,   // fr.hu.un_320 mk.uk.bg_442  hr.tr.un_420 gl.en.un_320
  // [0e90]
  0x645508a4, 0x645553a0, 0x081b0d07, 0x231f25ac,   // no.rw.lg_433 ht.rw.lg_322  cs.tr.no_432 eu.cy.ca_632
  0x55005319, 0x23001004, 0x13000d08, 0x17160802,   // ht.rw.un_750 lt.ca.un_320  ne.bh.un_430 no.hr.sr_222
  0x1e551c0c, 0x101e1c13, 0x551e1c13, 0x090d1ca9,   // id.rw.ms_543 id.ms.lt_665  id.ms.rw_665 mr.ne.hi_544
  0x531e1c04, 0x16002d08, 0x160c02a0, 0x1700110c,   // id.ms.ht_332 sk.hr.un_430  da.sv.hr_322 ro.sr.un_530
  // [0ea0]
  0x0a170705, 0x07080414, 0x05000809, 0x091c0d07,   // bg.sr.mk_333 ru.uk.bg_666  no.fr.un_440 ne.mr.hi_432
  0x070a0813, 0x53002104, 0x0a1707ad, 0x0407110c,   // uk.mk.bg_665 jw.ht.un_320  bg.sr.mk_643 ro.bg.ru_543
  0x16005304, 0x01110302, 0x0e0c0612, 0x1b00312c,   // ht.hr.un_320 nl.ro.en_222  de.sv.is_654 az.tr.un_990
  0x0f171604, 0x0c0208a6, 0x11005507, 0x0b050107,   // hr.sr.lv_332 no.da.sv_521  rw.ro.un_420 en.fr.es_432
  // [0eb0]
  0x1b0c020d, 0x08000412, 0x060413a7, 0x010511ee,   // da.sv.tr_554 ru.uk.un_640  et.fi.de_532 ro.fr.en_422
  0x0a080705, 0x080704ec, 0x171f16a0, 0x31005508,   // bg.uk.mk_333 ru.bg.uk_644  hr.cy.sr_322 rw.az.un_430
  0x10001f0c, 0x0800101a, 0x21001004, 0x04000819,   // cy.lt.un_530 be.uk.un_760  lt.jw.un_320 uk.ru.un_750
  0x0a00110c, 0x091c0d0e, 0x162d010c, 0x2b000509,   // ro.mk.un_530 ne.mr.hi_555  en.sk.hr_543 fr.vi.un_440
  // [0ec0]
  0x1e001c0e, 0x21001a08, 0x28110fa4, 0x12000a05,   // id.ms.un_550 tl.jw.un_430  lv.ro.sw_433 pt.hu.un_330
  0x1b003121, 0x13091ca9, 0x0d120aa0, 0x1c006b08,   // az.tr.un_860 mr.hi.bh_544  pt.hu.cs_322 ceb.id.un_430
  0x1a17160d, 0x0a071107, 0x03001607, 0x170a1108,   // hr.sr.tl_554 ro.bg.mk_432  hr.nl.un_420 ro.mk.sr_443
  0x23190a5a, 0x07040802, 0x170a07a4, 0x07001002,   // pt.gl.ca_553 uk.ru.bg_222  bg.mk.sr_433 be.bg.un_220
  // [0ed0]
  0x2000070e, 0x09001c05, 0x0410080c, 0x09001a02,   // it.sq.un_550 mr.hi.un_330  uk.be.ru_543 tl.pl.un_220
  0x06000c0e, 0x09283107, 0x1a00550e, 0x11041713,   // sv.de.un_550 az.sw.pl_432  rw.tl.un_550 sr.ru.ro_665
  0x2d0d0aa9, 0x530d060c, 0x061e1c08, 0x08060eee,   // pt.cs.sk_544 de.cs.ht_543  id.ms.de_443 is.de.no_422
  0x0e002919, 0x210431a0, 0x1b0e04a4, 0x09000d07,   // sl.is.un_750 az.fi.jw_322  fi.is.tr_433 ne.hi.un_420
  // [0ee0]
  0x0f290ca0, 0x171004a9, 0x2900280d, 0x290c09a7,   // sv.sl.lv_322 ru.be.sr_544  sw.sl.un_540 pl.sv.sl_532
  0x25641e04, 0x010c1f04, 0x0a17100e, 0x6b211aec,   // ms.lg.eu_332 cy.sv.en_332  be.sr.mk_555 tl.jw.ceb_644
  0x033f6407, 0x0c0e20a7, 0x122118ee, 0x1710085a,   // lg.af.nl_432 sq.is.sv_532  ar.fa.ur_422 uk.be.sr_553
  0x29132108, 0x3f0208a9, 0x07170a05, 0x171603ec,   // jw.et.sl_443 no.da.af_544  mk.sr.bg_333 nl.hr.sr_644
  // [0ef0]
  0x06000c07, 0x2d132908, 0x21001209, 0x170a070d,   // sv.de.un_420 sl.et.sk_443  ur.fa.un_440 bg.mk.sr_554
  0x061c2105, 0x21001222, 0x21012004, 0x07001019,   // jw.id.de_333 ur.fa.un_870  sq.en.jw_332 be.bg.un_750
  0x2d0c060c, 0x29080c02, 0x1c000907, 0x1f00530c,   // de.sv.sk_543 sv.no.sl_222  hi.mr.un_420 ht.cy.un_530
  0x09006b08, 0x130d0911, 0x06310f0c, 0x1c0d0904,   // ceb.pl.un_430 hi.ne.bh_653  lv.az.de_543 hi.ne.mr_332
  // [0f00]
  0x00000106, 0x08002512, 0x0e001909, 0x292d2512,   // en.un.un_400 eu.no.un_640  gl.is.un_440 eu.sk.sl_654
  0x04003f04, 0x2d291608, 0x1c13090d, 0x64105305,   // af.fi.un_320 hr.sl.sk_443  hi.bh.mr_554 ht.lt.lg_333
  0x0a001704, 0x13000918, 0x08000202, 0x530208ec,   // sr.mk.un_320 hi.bh.un_740  da.no.un_220 no.da.ht_644
  0x212916a4, 0x1c090dad, 0x100f250b, 0x10000202,   // hr.sl.jw_433 ne.hi.mr_643  eu.lv.lt_542 da.lt.un_220
  // [0f10]
  0x311e04a0, 0x1a250e55, 0x1c000e12, 0x0a041713,   // fi.ms.az_322 is.eu.tl_442  is.id.un_640 sr.ru.mk_665
  0x11190b0b, 0x6b281aa4, 0x080410a0, 0x1c0d0909,   // es.gl.ro_542 tl.sw.ceb_433  be.ru.uk_322 hi.ne.mr_444
  0x1e131a07, 0x1300090c, 0x1e001c1b, 0x0c1f53ee,   // tl.et.ms_432 pl.et.un_530  id.ms.un_770 ht.cy.sv_422
  0x07001c04, 0x011f5312, 0x01033fa0, 0x19000708,   // id.it.un_320 ht.cy.en_654  af.nl.en_322 it.gl.un_430
  // [0f20]
  0x1a1e1c04, 0x286b10ee, 0x04001113, 0x10040808,   // id.ms.tl_332 lt.ceb.sw_422  ro.ru.un_650 uk.ru.be_443
  0x041708a0, 0x64002808, 0x09290da9, 0x17001007,   // uk.sr.ru_322 sw.lg.un_430  cs.sl.pl_544 be.sr.un_420
  0x07080413, 0x081710a4, 0x08070a02, 0x0d00130c,   // ru.uk.bg_665 be.sr.uk_433  mk.bg.uk_222 et.cs.un_530
  0x11001e07, 0x19001204, 0x04070a5a, 0x07002a19,   // ms.ro.un_420 hu.gl.un_320  mk.bg.ru_553 mt.it.un_750
  // [0f30]
  0x1f190a0e, 0x0c001002, 0x29001707, 0x641728ee,   // pt.gl.cy_555 lt.sv.un_220  sr.sl.un_420 sw.sr.lg_422
  0x102825ee, 0x170b25ee, 0x0a04070e, 0x0e002d12,   // eu.sw.lt_422 eu.es.sr_422  bg.ru.mk_555 sk.is.un_640
  0x07005304, 0x0d0913af, 0x1a006b13, 0x12041ba7,   // ht.it.un_320 bh.hi.ne_655  ceb.tl.un_650 tr.fi.hu_532
  0x0e0b1204, 0x0d1c0912, 0x170d160c, 0x230b12ad,   // hu.es.is_332 hi.mr.ne_654  hr.cs.sr_543 hu.es.ca_643
  // [0f40]
  0x0e120b07, 0x186b01a7, 0x2100640e, 0x18005304,   // es.hu.is_432 en.ceb.ga_532  lg.jw.un_550 ht.ga.un_320
  0x16001713, 0x120b0a09, 0x2700182b, 0x0b001221,   // sr.hr.un_650 pt.es.hu_444  ga.gd.un_980 hu.es.un_860
  0x27311fad, 0x2a002704, 0x12111605, 0x071710a0,   // cy.az.gd_643 gd.mt.un_320  hr.ro.hu_333 be.sr.bg_322
  0x311b2155, 0x12230baf, 0x0f2120a0, 0x190b01a0,   // jw.tr.az_442 es.ca.hu_655  sq.jw.lv_322 en.es.gl_322
  // [0f50]
  0x16000913, 0x211c640c, 0x0c002a02, 0x12060c07,   // pl.hr.un_650 lg.id.jw_543  mt.sv.un_220 sv.de.hu_432
  0x10002d02, 0x2d0b1211, 0x19000b14, 0x6b1308a0,   // sk.lt.un_220 hu.es.sk_653  es.gl.un_660 no.et.ceb_322
  0x2d0d21a0, 0x1600090c, 0x6b286e04, 0x3f120c0b,   // jw.cs.sk_322 pl.hr.un_530  blu.sw.ceb_332 sv.hu.af_542
  0x2b1304ad, 0x1c002105, 0x06001308, 0x02000c21,   // fi.et.vi_643 jw.id.un_330  et.de.un_430 sv.da.un_860
  // [0f60]
  0x13006e14, 0x0c00021a, 0x10040755, 0x640b1907,   // blu.et.un_660 da.sv.un_760  bg.ru.be_442 gl.es.lg_432
  0x2b6e1aa0, 0x065303a7, 0x531b04a0, 0x1300041a,   // tl.blu.vi_322 nl.ht.de_532  fi.tr.ht_322 fi.et.un_760
  0x08041704, 0x16002a0e, 0x21001607, 0x0f000409,   // sr.ru.uk_332 mt.hr.un_550  hr.jw.un_420 fi.lv.un_440
  0x12230b05, 0x07000408, 0x09000113, 0x12230b0e,   // es.ca.hu_333 ru.bg.un_430  en.pl.un_650 es.ca.hu_555
  // [0f70]
  0x040f01a6, 0x01000c02, 0x0e120b04, 0x550a1b0c,   // en.lv.fi_521 sv.en.un_220  es.hu.is_332 tr.pt.rw_543
  0x2b110107, 0x066e0107, 0x21006e14, 0x095505ec,   // en.ro.vi_432 en.blu.de_432  blu.jw.un_660 fr.rw.pl_644
  0x11000413, 0x090b010c, 0x17000707, 0x250701a0,   // ru.ro.un_650 en.es.pl_543  bg.sr.un_420 en.it.eu_322
  0x12192d0c, 0x161301a0, 0x100417a0, 0x080c02af,   // sk.gl.hu_543 en.et.hr_322  sr.ru.be_322 da.sv.no_655
  // [0f80]
  0x11001804, 0x6e000b05, 0x3f25060b, 0x21016eee,   // ga.ro.un_320 es.blu.un_330  de.eu.af_542 blu.en.jw_422
  0x19000a0e, 0x01182ba0, 0x2d0d09af, 0x1f000911,   // pt.gl.un_550 vi.ga.en_322  pl.cs.sk_655 pl.cy.un_630
  0x04000a02, 0x2a23010c, 0x1c1309ec, 0x27005508,   // mk.ru.un_220 en.ca.mt_543  hi.bh.mr_644 rw.gd.un_430
  0x07000a0d, 0x1a1f0107, 0x0c00060c, 0x10000408,   // mk.bg.un_540 en.cy.tl_432  de.sv.un_530 ru.be.un_430
  // [0f90]
  0x0b2312ec, 0x0d091312, 0x100804af, 0x28000104,   // hu.ca.es_644 bh.hi.ne_654  ru.uk.be_655 en.sw.un_320
  0x0a040708, 0x2a160aa0, 0x18530404, 0x0a10110c,   // bg.ru.mk_443 pt.hr.mt_322  fi.ht.ga_332 ro.be.mk_543
  0x122118a4, 0x1000040e, 0x20002b02, 0x202a2107,   // ar.fa.ur_433 ru.be.un_550  vi.sq.un_220 jw.mt.sq_432
  0x130d09ec, 0x10000702, 0x0708040c, 0x13001c08,   // hi.ne.bh_644 bg.be.un_220  ru.uk.bg_543 mr.bh.un_430
  // [0fa0]
  0x2a001c02, 0x2d0d1fa9, 0x21001211, 0x161b1255,   // id.mt.un_220 cy.cs.sk_544  ur.fa.un_630 hu.tr.hr_442
  0x040810af, 0x311b1212, 0x291b130c, 0x0400110c,   // be.uk.ru_655 hu.tr.az_654  et.tr.sl_543 ro.ru.un_530
  0x08000c04, 0x09000d2a, 0x2d120d05, 0x121821af,   // sv.no.un_320 ne.hi.un_970  cs.hu.sk_333 fa.ar.ur_655
  0x21181f5a, 0x1b001209, 0x06002b07, 0x0a0807a9,   // cy.ga.jw_553 hu.tr.un_440  vi.de.un_420 bg.uk.mk_544
  // [0fb0]
  0x04171605, 0x1c280f04, 0x55002b04, 0x02090612,   // hr.sr.fi_333 lv.sw.id_332  vi.rw.un_320 de.pl.da_654
  0x0a00170e, 0x122d0d02, 0x3f002107, 0x112a1eee,   // sr.mk.un_550 cs.sk.hu_222  jw.af.un_420 ms.mt.ro_422
  0x2a00131a, 0x28270804, 0x0c0810ac, 0x0a07110c,   // et.mt.un_760 no.gd.sw_332  lt.no.sv_632 ro.bg.mk_543
  0x03005304, 0x1b123112, 0x12001b1b, 0x09000d05,   // ht.nl.un_320 az.hu.tr_654  tr.hu.un_770 ne.hi.un_330
  // [0fc0]
  0x172d2905, 0x010528ad, 0x28006b04, 0x0d09130c,   // sl.sk.sr_333 sw.fr.en_643  ceb.sw.un_320 bh.hi.ne_543
  0x3100121a, 0x17000a04, 0x23005307, 0x121b2d0c,   // hu.az.un_760 mk.sr.un_320  ht.ca.un_420 sk.tr.hu_543
  0x1b162904, 0x033f230c, 0x1b16290c, 0x0b230507,   // sl.hr.tr_332 ca.af.nl_543  sl.hr.tr_543 fr.ca.es_432
  0x1e2118ad, 0x091c1311, 0x53000504, 0x1c0d09a4,   // ga.jw.ms_643 bh.mr.hi_653  fr.ht.un_320 hi.ne.mr_433
  // [0fd0]
  0x0d0913a4, 0x1c130914, 0x250f07ee, 0x0c3f030e,   // bh.hi.ne_433 hi.bh.mr_666  it.lv.eu_422 nl.af.sv_555
  0x11003f07, 0x162917af, 0x17550f02, 0x182b27a7,   // af.ro.un_420 sr.sl.hr_655  lv.rw.sr_222 gd.vi.ga_532
  0x040e1307, 0x182a0a07, 0x181221a0, 0x03003f09,   // et.is.fi_432 pt.mt.ga_432  fa.ur.ar_322 af.nl.un_440
  0x09005308, 0x07001112, 0x08002104, 0x16000f07,   // ht.pl.un_430 ro.bg.un_640  jw.no.un_320 lv.hr.un_420
  // [0fe0]
  0x0a001812, 0x1b205507, 0x09000804, 0x2d001608,   // ga.pt.un_640 rw.sq.tr_432  no.pl.un_320 hr.sk.un_430
  0x19000108, 0x183f27a0, 0x0e551312, 0x07110a05,   // en.gl.un_430 gd.af.ga_322  et.rw.is_654 mk.ro.bg_333
  0x03002308, 0x0a100409, 0x2000550e, 0x21001c05,   // ca.nl.un_430 ru.be.mk_444  rw.sq.un_550 id.jw.un_330
  0x03090704, 0x2a000719, 0x171653a0, 0x1c001e04,   // it.pl.nl_332 it.mt.un_750  ht.hr.sr_322 ms.id.un_320
  // [0ff0]
  0x1100070d, 0x12000207, 0x10003f04, 0x0c290207,   // it.ro.un_540 da.hu.un_420  af.lt.un_320 da.sl.sv_432
  0x551a6b02, 0x2b000807, 0x080411a0, 0x1a280804,   // ceb.tl.rw_222 no.vi.un_420  ro.ru.uk_322 no.sw.tl_332
  0x0e0d13a4, 0x170a11a6, 0x200955a0, 0x0e000219,   // et.cs.is_433 ro.mk.sr_521  rw.pl.sq_322 da.is.un_750
  0x1a000d0e, 0x10000704, 0x20001f0d, 0x13001c04,   // cs.tl.un_550 bg.be.un_320  cy.sq.un_540 mr.bh.un_320

  // [1000]
  0x04001709, 0x1716100c, 0x0d1716a4, 0x53000302,   // sr.ru.un_440 lt.hr.sr_543  hr.sr.cs_433 nl.ht.un_220
  0x040305ee, 0x27000704, 0x17081005, 0x120820a4,   // fr.nl.fi_422 it.gd.un_320  be.uk.sr_333 sq.no.hu_433
  0x00001b06, 0x11001023, 0x01002411, 0x1200080d,   // tr.un.un_400 be.ro.un_880  yi.iw.un_630 no.hu.un_540
  0x04170a12, 0x1200101b, 0x04061304, 0x16006e22,   // mk.sr.ru_654 lt.hu.un_770  et.de.fi_332 blu.hr.un_870
  // [1010]
  0x0000051c, 0x126b1aad, 0x08000a1a, 0x28011fa7,   // fr.un.un_800 tl.ceb.hu_643  mk.uk.un_760 cy.en.sw_532
  0x23001109, 0x211812a9, 0x20001f04, 0x27170208,   // ro.ca.un_440 ur.ar.fa_544  cy.sq.un_320 da.sr.gd_443
  0x100408a4, 0x09001f07, 0x092512ec, 0x09001f04,   // uk.ru.be_433 cy.pl.un_420  hu.eu.pl_644 cy.pl.un_320
  0x1a000411, 0x1b000a04, 0x112718ad, 0x1f000c13,   // fi.tl.un_630 pt.tr.un_320  ga.gd.ro_643 sv.cy.un_650
  // [1020]
  0x00006e37, 0x2a07080c, 0x1c0d0907, 0x04001007,   // blu.un.un_B00 no.it.mt_543  hi.ne.mr_432 be.ru.un_420
  0x25000804, 0x101308a0, 0x121821a7, 0x2d090da7,   // no.eu.un_320 no.et.lt_322  fa.ar.ur_532 cs.pl.sk_532
  0x05110807, 0x11006e22, 0x092106a0, 0x27006e18,   // no.ro.fr_432 blu.ro.un_870  de.jw.pl_322 blu.gd.un_740
  0x051827a9, 0x05182711, 0x3f086eee, 0x06002102,   // gd.ga.fr_544 gd.ga.fr_653  blu.no.af_422 jw.de.un_220
  // [1030]
  0x0c6e3f09, 0x05182712, 0x09001f02, 0x13000922,   // af.blu.sv_444 gd.ga.fr_654  cy.pl.un_220 hi.bh.un_870
  0x1e1c21af, 0x033f2307, 0x080a0408, 0x02060c0c,   // jw.id.ms_655 ca.af.nl_432  ru.mk.uk_443 sv.de.da_543
  0x16002913, 0x1f000c19, 0x291617a7, 0x2100120e,   // sl.hr.un_650 sv.cy.un_750  sr.hr.sl_532 ur.fa.un_550
  0x21001604, 0x0f002802, 0x08041709, 0x1300092c,   // hr.jw.un_320 sw.lv.un_220  sr.ru.uk_444 hi.bh.un_990
  // [1040]
  0x28001013, 0x0e3f1a04, 0x2000210b, 0x20002519,   // lt.sw.un_650 tl.af.is_332  jw.sq.un_520 eu.sq.un_750
  0x120c6ba4, 0x64100f0c, 0x201a6bad, 0x21001c02,   // ceb.sv.hu_433 lv.lt.lg_543  ceb.tl.sq_643 id.jw.un_220
  0x551a2502, 0x28002504, 0x0d001008, 0x1200180c,   // eu.tl.rw_222 eu.sw.un_320  lt.cs.un_430 ga.hu.un_530
  0x641f09a0, 0x28002121, 0x00001e0a, 0x28000e08,   // pl.cy.lg_322 jw.sw.un_860  ms.un.un_500 is.sw.un_430
  // [1050]
  0x01071eee, 0x1c001e07, 0x170a07a0, 0x070a0405,   // ms.it.en_422 ms.id.un_420  bg.mk.sr_322 ru.mk.bg_333
  0x230b2108, 0x2d0d12a4, 0x0a070808, 0x0e002a13,   // jw.es.ca_443 hu.cs.sk_433  uk.bg.mk_443 mt.is.un_650
  0x0c00020d, 0x03023f09, 0x10042d0c, 0x11200212,   // da.sv.un_540 af.da.nl_444  sk.fi.lt_543 da.sq.ro_654
  0x170711a0, 0x00000524, 0x1c292a04, 0x29082012,   // ro.bg.sr_322 fr.un.un_900  mt.sl.id_332 sq.no.sl_654
  // [1060]
  0x3f0a03a4, 0x2d090da4, 0x211812ad, 0x3f060a09,   // nl.pt.af_433 cs.pl.sk_433  ur.ar.fa_643 pt.de.af_444
  0x2b000f05, 0x0408070d, 0x04132013, 0x13002109,   // lv.vi.un_330 bg.uk.ru_554  sq.et.fi_665 jw.et.un_440
  0x042113ec, 0x16640e08, 0x291608a4, 0x08200c0c,   // et.jw.fi_644 is.lg.hr_443  no.hr.sl_433 sv.sq.no_543
  0x033f270c, 0x0c060307, 0x3f0403a4, 0x0308200c,   // gd.af.nl_543 nl.de.sv_432  nl.fi.af_433 sq.no.nl_543
  // [1070]
  0x08033fa9, 0x211a1ea6, 0x280664a4, 0x0a041707,   // af.nl.no_544 ms.tl.jw_521  lg.de.sw_433 sr.ru.mk_432
  0x28200b07, 0x162d0d08, 0x086e0ca7, 0x111906a9,   // es.sq.sw_432 cs.sk.hr_443  sv.blu.no_532 de.gl.ro_544
  0x033f1104, 0x18000521, 0x08170a08, 0x07040805,   // ro.af.nl_332 fr.ga.un_860  mk.sr.uk_443 uk.ru.bg_333
  0x230821a0, 0x09000108, 0x291c1e0c, 0x12002508,   // jw.no.ca_322 en.pl.un_430  ms.id.sl_543 eu.hu.un_430
  // [1080]
  0x3f005304, 0x0b230711, 0x1c3f0c05, 0x1900230d,   // ht.af.un_320 it.ca.es_653  sv.af.id_333 ca.gl.un_540
  0x64001214, 0x29200913, 0x092d0d11, 0x05083fa0,   // hu.lg.un_660 pl.sq.sl_665  cs.sk.pl_653 af.no.fr_322
  0x5300021a, 0x11000714, 0x0000291c, 0x1c001e0d,   // da.ht.un_760 it.ro.un_660  sl.un.un_800 ms.id.un_540
  0x20000804, 0x18273fa4, 0x060409a4, 0x280f100e,   // no.sq.un_320 af.gd.ga_433  pl.fi.de_433 lt.lv.sw_555
  // [1090]
  0x03063fa9, 0x09200308, 0x0e063fa4, 0x18002722,   // af.de.nl_544 nl.sq.pl_443  af.de.is_433 gd.ga.un_870
  0x2920030c, 0x292d1004, 0x1c001e19, 0x06000a04,   // nl.sq.sl_543 lt.sk.sl_332  ms.id.un_750 pt.de.un_320
  0x081017a0, 0x0a0407a9, 0x09002914, 0x18070508,   // sr.be.uk_322 bg.ru.mk_544  sl.pl.un_660 fr.it.ga_443
  0x55001f11, 0x55003108, 0x2d0d01a0, 0x031805a4,   // cy.rw.un_630 az.rw.un_430  en.cs.sk_322 fr.ga.nl_433
  // [10a0]
  0x1e010c07, 0x55005311, 0x2800550c, 0x2d0d01a9,   // sv.en.ms_432 ht.rw.un_630  rw.sw.un_530 en.cs.sk_544
  0x04070807, 0x2d002904, 0x131c0913, 0x18000104,   // uk.bg.ru_432 sl.sk.un_320  hi.mr.bh_665 en.ga.un_320
  0x29090c0b, 0x04000822, 0x0d091cec, 0x18001208,   // sv.pl.sl_542 uk.ru.un_870  mr.hi.ne_644 ur.ar.un_430
  0x0a17110c, 0x18122111, 0x2d0d010c, 0x21005312,   // ro.sr.mk_543 fa.ur.ar_653  en.cs.sk_543 ht.jw.un_640
  // [10b0]
  0x04001014, 0x31001b09, 0x0e001214, 0x06001b09,   // be.ru.un_660 tr.az.un_440  hu.is.un_660 tr.de.un_440
  0x17000a0c, 0x060e04ee, 0x6400530c, 0x09000d21,   // mk.sr.un_530 fi.is.de_422  ht.lg.un_530 ne.hi.un_860
  0x070a17a7, 0x21001e02, 0x0d122dee, 0x0a00070d,   // sr.mk.bg_532 ms.jw.un_220  sk.hu.cs_422 bg.mk.un_540
  0x063f2a04, 0x0600120c, 0x04000813, 0x010318a0,   // mt.af.de_332 hu.de.un_530  uk.ru.un_650 ga.nl.en_322
  // [10c0]
  0x0c000607, 0x042a08ad, 0x03293f0c, 0x01005302,   // de.sv.un_420 no.mt.fi_643  af.sl.nl_543 ht.en.un_220
  0x0a0217a0, 0x1a2555ad, 0x2b066eee, 0x2d0d28a6,   // sr.da.pt_322 rw.eu.tl_643  blu.de.vi_422 sw.cs.sk_521
  0x17642112, 0x292017a0, 0x190a1a0e, 0x0b001204,   // jw.lg.sr_654 sr.sq.sl_322  tl.pt.gl_555 hu.es.un_320
  0x0408100c, 0x1e1c2109, 0x1e006b07, 0x29006422,   // be.uk.ru_543 jw.id.ms_444  ceb.ms.un_420 lg.sl.un_870
  // [10d0]
  0x06002d04, 0x16001721, 0x10001b29, 0x171601a0,   // sk.de.un_320 sr.hr.un_860  tr.lt.un_960 en.hr.sr_322
  0x040811a4, 0x04100709, 0x28001a02, 0x0717040c,   // ro.uk.ru_433 bg.be.ru_444  tl.sw.un_220 ru.sr.bg_543
  0x04100908, 0x09000702, 0x17040702, 0x02000813,   // pl.lt.fi_443 it.pl.un_220  bg.ru.sr_222 no.da.un_650
  0x04000a0c, 0x020c0808, 0x6b0210ee, 0x0e0f28a0,   // mk.ru.un_530 no.sv.da_443  lt.da.ceb_422 sw.lv.is_322
  // [10e0]
  0x130e0805, 0x2a0506a9, 0x53000e07, 0x080417a0,   // no.is.et_333 de.fr.mt_544  is.ht.un_420 sr.ru.uk_322
  0x10002b04, 0x172916ad, 0x6b0c10a0, 0x1b006402,   // vi.lt.un_320 hr.sl.sr_643  lt.sv.ceb_322 lg.tr.un_220
  0x192b0304, 0x0b000723, 0x216b0660, 0x2916170b,   // nl.vi.gl_332 it.es.un_880  de.ceb.jw_664 sr.hr.sl_542
  0x29171660, 0x16100609, 0x18002121, 0x07052d07,   // hr.sr.sl_664 de.lt.hr_444  fa.ar.un_860 sk.fr.it_432
  // [10f0]
  0x250c08a4, 0x190a18a4, 0x1b1e1c12, 0x16091ba0,   // no.sv.eu_433 ga.pt.gl_433  id.ms.tr_654 tr.pl.hr_322
  0x29231ba0, 0x29190b5a, 0x12001919, 0x230e0ba4,   // tr.ca.sl_322 es.gl.sl_553  gl.hu.un_750 es.is.ca_433
  0x132a07a0, 0x2d1b1102, 0x08020c0d, 0x06033fa9,   // it.mt.et_322 ro.tr.sk_222  sv.da.no_554 af.nl.de_544
  0x095325a0, 0x11201607, 0x0a070809, 0x1b002004,   // eu.ht.pl_322 hr.sq.ro_432  uk.bg.mk_444 sq.tr.un_320
  // [1100]
  0x0f3113a0, 0x011211ee, 0x080a1007, 0x231901a0,   // et.az.lv_322 ro.hu.en_422  be.mk.uk_432 en.gl.ca_322
  0x1b1e1c60, 0x11292307, 0x231925a9, 0x0c001702,   // id.ms.tr_664 ca.sl.ro_432  eu.gl.ca_544 sr.sv.un_220
  0x0a1704a4, 0x070408af, 0x07040a0c, 0x106b2007,   // ru.sr.mk_433 uk.ru.bg_655  mk.ru.bg_543 sq.ceb.lt_432
  0x1b1064a4, 0x10040704, 0x07002d04, 0x02001113,   // lg.lt.tr_433 bg.ru.be_332  sk.it.un_320 ro.da.un_650
  // [1110]
  0x11000904, 0x19000b09, 0x0800101b, 0x1b000705,   // pl.ro.un_320 es.gl.un_440  be.uk.un_770 it.tr.un_330
  0x230b01a0, 0x11161b07, 0x11000108, 0x062801ad,   // en.es.ca_322 tr.hr.ro_432  en.ro.un_430 en.sw.de_643
  0x16002b04, 0x1c090d0e, 0x1c0d090e, 0x13090da9,   // vi.hr.un_320 ne.hi.mr_555  hi.ne.mr_555 ne.hi.bh_544
  0x18002721, 0x070804af, 0x1c0913ad, 0x27001811,   // gd.ga.un_860 ru.uk.bg_655  bh.hi.mr_643 ga.gd.un_630
  // [1120]
  0x281c1e0c, 0x110501a4, 0x1a213f04, 0x02000821,   // ms.id.sw_543 en.fr.ro_433  af.jw.tl_332 no.da.un_860
  0x0c002007, 0x6e000802, 0x17000702, 0x070403af,   // sq.sv.un_420 no.blu.un_220  bg.sr.un_220 nl.fi.it_655
  0x1a0701a4, 0x070408a4, 0x1a005307, 0x1c000d08,   // en.it.tl_433 uk.ru.bg_433  ht.tl.un_420 ne.mr.un_430
  0x25000b07, 0x06000412, 0x010a0707, 0x0d100109,   // es.eu.un_420 fi.de.un_640  it.pt.en_432 en.lt.cs_444
  // [1130]
  0x1300040c, 0x12000419, 0x2a1e1c0c, 0x2d100f14,   // fi.et.un_530 fi.hu.un_750  id.ms.mt_543 lv.lt.sk_666
  0x11010502, 0x0a642a07, 0x09000307, 0x110f2304,   // fr.en.ro_222 mt.lg.pt_432  nl.pl.un_420 ca.lv.ro_332
  0x21006408, 0x1c1e1a07, 0x6b641a02, 0x04131b09,   // lg.jw.un_430 tl.ms.id_432  tl.lg.ceb_222 tr.et.fi_444
  0x092d0d05, 0x0a005507, 0x0900040c, 0x6b002119,   // cs.sk.pl_333 rw.pt.un_420  fi.pl.un_530 jw.ceb.un_750
  // [1140]
  0x00000906, 0x0f000704, 0x04081060, 0x1e001802,   // pl.un.un_400 it.lv.un_320  be.uk.ru_664 ga.ms.un_220
  0x1200212b, 0x536b1b08, 0x05011ea0, 0x0b2531ee,   // fa.ur.un_980 tr.ceb.ht_443  ms.en.fr_322 az.eu.es_422
  0x6b092107, 0x0900110c, 0x645309ad, 0x0600041b,   // jw.pl.ceb_432 ro.pl.un_530  pl.ht.lg_643 fi.de.un_770
  0x3f0e0414, 0x2d000d23, 0x1c090d14, 0x55126407,   // fi.is.af_666 cs.sk.un_880  ne.hi.mr_666 lg.hu.rw_432
  // [1150]
  0x1707040c, 0x1e640713, 0x051e0ea0, 0x1a001304,   // ru.bg.sr_543 it.lg.ms_665  is.ms.fr_322 et.tl.un_320
  0x2a3f0214, 0x6b1a210b, 0x08170aee, 0x1b1e2104,   // da.af.mt_666 jw.tl.ceb_542  mk.sr.uk_422 jw.ms.tr_332
  0x17080408, 0x170a0712, 0x062931a0, 0x1c281a07,   // ru.uk.sr_443 bg.mk.sr_654  az.sl.de_322 tl.sw.id_432
  0x0d091cad, 0x230b0a09, 0x020c0d07, 0x162017a6,   // mr.hi.ne_643 pt.es.ca_444  cs.sv.da_432 sr.sq.hr_521
  // [1160]
  0x201c3102, 0x530109a0, 0x061e1c04, 0x0900131a,   // az.id.sq_222 pl.en.ht_322  id.ms.de_332 bh.hi.un_760
  0x29001609, 0x0f0410af, 0x19000b23, 0x06000304,   // hr.sl.un_440 lt.fi.lv_655  es.gl.un_880 nl.de.un_320
  0x21181260, 0x041707a4, 0x230c1902, 0x170a11a7,   // ur.ar.fa_664 bg.sr.ru_433  gl.sv.ca_222 ro.mk.sr_532
  0x0b00191a, 0x2d171655, 0x18001307, 0x0c2519a0,   // gl.es.un_760 hr.sr.sk_442  et.ga.un_420 gl.eu.sv_322
  // [1170]
  0x0711010c, 0x060c040c, 0x0400070d, 0x06000c09,   // en.ro.it_543 fi.sv.de_543  bg.ru.un_540 sv.de.un_440
  0x081004a4, 0x19000b2c, 0x28002507, 0x08032307,   // ru.be.uk_433 es.gl.un_990  eu.sw.un_420 ca.nl.no_432
  0x03170d07, 0x0a230711, 0x07170aaf, 0x120d0307,   // cs.sr.nl_432 it.ca.pt_653  mk.sr.bg_655 nl.cs.hu_432
  0x29000d02, 0x081017ad, 0x27000507, 0x29001709,   // cs.sl.un_220 sr.be.uk_643  fr.gd.un_420 sr.sl.un_440
  // [1180]
  0x080a0704, 0x07041755, 0x03062555, 0x28001b04,   // bg.mk.uk_332 sr.ru.bg_442  eu.de.nl_442 tr.sw.un_320
  0x13000105, 0x06030a08, 0x12002302, 0x64001a02,   // en.et.un_330 pt.nl.de_443  ca.hu.un_220 tl.lg.un_220
  0x1a006b36, 0x061b0312, 0x10042011, 0x0f171609,   // ceb.tl.un_AA0 nl.tr.de_654  sq.fi.lt_653 hr.sr.lv_444
  0x04002908, 0x1a271904, 0x0b070aa0, 0x2a071605,   // sl.fi.un_430 gl.gd.tl_332  pt.it.es_322 hr.it.mt_333
  // [1190]
  0x31006407, 0x0411070c, 0x3f000308, 0x06000c08,   // lg.az.un_420 bg.ro.ru_543  nl.af.un_430 sv.de.un_430
  0x0a001222, 0x17080a04, 0x2800030c, 0x55001204,   // hu.pt.un_870 mk.uk.sr_332  nl.sw.un_530 hu.rw.un_320
  0x2400010e, 0x070a170e, 0x1c000c07, 0x08000607,   // iw.yi.un_550 sr.mk.bg_555  sv.id.un_420 de.no.un_420
  0x0d040cad, 0x0f1306ee, 0x0700050e, 0x0d060404,   // sv.fi.cs_643 de.et.lv_422  fr.it.un_550 fi.de.cs_332
  // [11a0]
  0x03232ba4, 0x6400100d, 0x16000605, 0x1a211207,   // vi.ca.nl_433 lt.lg.un_540  de.hr.un_330 hu.jw.tl_432
  0x022b1a0c, 0x2a0d200c, 0x160f29ad, 0x170708a4,   // tl.vi.da_543 sq.cs.mt_543  sl.lv.hr_643 uk.bg.sr_433
  0x06001a04, 0x05070108, 0x10040814, 0x041017a0,   // tl.de.un_320 en.it.fr_443  uk.ru.be_666 sr.be.ru_322
  0x290a2aa0, 0x03003f12, 0x27003f04, 0x17022a04,   // mt.pt.sl_322 af.nl.un_640  af.gd.un_320 mt.da.sr_332
  // [11b0]
  0x17210c05, 0x11000408, 0x0710045a, 0x6b0901a7,   // sv.jw.sr_333 ru.ro.un_430  ru.be.bg_553 en.pl.ceb_532
  0x1b001004, 0x0d09130e, 0x6b2a010c, 0x08060fad,   // lt.tr.un_320 bh.hi.ne_555  en.mt.ceb_543 lv.de.no_643
  0x07000507, 0x0a00171b, 0x25180107, 0x1e040604,   // fr.it.un_420 sr.mk.un_770  en.ga.eu_432 de.fi.ms_332
  0x0a2d290c, 0x0f100709, 0x18000108, 0x1c5321a0,   // sl.sk.pt_543 it.lt.lv_444  en.ga.un_430 jw.ht.id_322
  // [11c0]
  0x2100180e, 0x11040812, 0x28000f04, 0x040817ec,   // ar.fa.un_550 uk.ru.ro_654  lv.sw.un_320 sr.uk.ru_644
  0x2a001005, 0x0804100c, 0x17160fa4, 0x2d0d1fee,   // lt.mt.un_330 be.ru.uk_543  lv.hr.sr_433 cy.cs.sk_422
  0x0e2a0f11, 0x04033f55, 0x04070a09, 0x08000209,   // lv.mt.is_653 af.nl.fi_442  mk.bg.ru_444 da.no.un_440
  0x03003f0e, 0x040a07a7, 0x0804100d, 0x21001808,   // af.nl.un_550 bg.mk.ru_532  be.ru.uk_554 ar.fa.un_430
  // [11d0]
  0x07170a07, 0x64002a1a, 0x29162a12, 0x18032707,   // mk.sr.bg_432 mt.lg.un_760  mt.hr.sl_654 gd.nl.ga_432
  0x0e001005, 0x251b3111, 0x09100faf, 0x17162dee,   // lt.is.un_330 az.tr.eu_653  lv.lt.pl_655 sk.hr.sr_422
  0x1c252804, 0x2700180c, 0x1000120c, 0x1b1e1ca9,   // sw.eu.id_332 ga.gd.un_530  hu.lt.un_530 id.ms.tr_544
  0x13112807, 0x20000f02, 0x0709100c, 0x0f292a60,   // sw.ro.et_432 lv.sq.un_220  lt.pl.it_543 mt.sl.lv_664
  // [11e0]
  0x1f1229a4, 0x032513a4, 0x032718af, 0x292a16a0,   // sl.hu.cy_433 et.eu.nl_433  ga.gd.nl_655 hr.mt.sl_322
  0x250c08af, 0x172d0908, 0x64001f1b, 0x04002804,   // no.sv.eu_655 pl.sk.sr_443  cy.lg.un_770 sw.fi.un_320
  0x25001221, 0x6b001a0d, 0x210b25a0, 0x04081009,   // hu.eu.un_860 tl.ceb.un_540  eu.es.jw_322 be.uk.ru_444
  0x070a0455, 0x290f2aaf, 0x5300250d, 0x1c001904,   // ru.mk.bg_442 mt.lv.sl_655  eu.ht.un_540 gl.id.un_320
  // [11f0]
  0x11000104, 0x0400291a, 0x03271804, 0x05002008,   // en.ro.un_320 sl.fi.un_760  ga.gd.nl_332 sq.fr.un_430
  0x290e2aa9, 0x13292aa0, 0x18033f12, 0x161b3107,   // mt.is.sl_544 mt.sl.et_322  af.nl.ga_654 az.tr.hr_432
  0x290f2a08, 0x171625ec, 0x19002307, 0x311b1309,   // mt.lv.sl_443 eu.hr.sr_644  ca.gl.un_420 et.tr.az_444
  0x0c091007, 0x04130c04, 0x033f2812, 0x272d10ee,   // lt.pl.sv_432 sv.et.fi_332  sw.af.nl_654 lt.sk.gd_422
  // [1200]
  0x25000704, 0x1e001c23, 0x31000804, 0x0200250c,   // it.eu.un_320 id.ms.un_880  no.az.un_320 eu.da.un_530
  0x04000a22, 0x17080407, 0x105318a6, 0x2a110fa0,   // mk.ru.un_870 ru.uk.sr_432  ga.ht.lt_521 lv.ro.mt_322
  0x08101107, 0x10041304, 0x082a01a4, 0x17530208,   // ro.lt.no_432 et.fi.lt_332  en.mt.no_433 da.ht.sr_443
  0x07180404, 0x1e001c2c, 0x23190ba6, 0x0300210d,   // fi.ga.it_332 id.ms.un_990  es.gl.ca_521 jw.nl.un_540
  // [1210]
  0x17001307, 0x64050407, 0x1700100b, 0x04131b0c,   // et.sr.un_420 fi.fr.lg_432  be.sr.un_520 tr.et.fi_543
  0x05000a04, 0x1f201b07, 0x1f110107, 0x0200080d,   // pt.fr.un_320 tr.sq.cy_432  en.ro.cy_432 no.da.un_540
  0x0a0704ee, 0x1b003f21, 0x07641b08, 0x03000108,   // ru.bg.mk_422 af.tr.un_860  tr.lg.it_443 en.nl.un_430
  0x2311120b, 0x3f031b0d, 0x6b001a13, 0x21040702,   // hu.ro.ca_542 tr.nl.af_554  tl.ceb.un_650 it.fi.jw_222
  // [1220]
  0x062827ad, 0x211c1e0c, 0x21131b13, 0x25003f0d,   // gd.sw.de_643 ms.id.jw_543  tr.et.jw_665 af.eu.un_540
  0x16201ba4, 0x0e0b19a7, 0x311b5508, 0x07641b07,   // tr.sq.hr_433 gl.es.is_532  rw.tr.az_443 tr.lg.it_432
  0x06001c04, 0x05060107, 0x232119a0, 0x06002723,   // id.de.un_320 en.de.fr_432  gl.jw.ca_322 gd.de.un_880
  0x211b1c07, 0x122d0d14, 0x2100100c, 0x10002105,   // id.tr.jw_432 cs.sk.hu_666  lt.jw.un_530 jw.lt.un_330
  // [1230]
  0x046b10a0, 0x0e000d13, 0x09000302, 0x6b1a21ee,   // lt.ceb.fi_322 cs.is.un_650  nl.pl.un_220 jw.tl.ceb_422
  0x642006a9, 0x13002508, 0x311b04a6, 0x07201b0b,   // de.sq.lg_544 eu.et.un_430  fi.tr.az_521 tr.sq.it_542
  0x04080aa4, 0x05000109, 0x10000719, 0x042701a4,   // mk.uk.ru_433 en.fr.un_440  it.lt.un_750 en.gd.fi_433
  0x10000f13, 0x01000502, 0x130723a4, 0x64001f13,   // lv.lt.un_650 fr.en.un_220  ca.it.et_433 cy.lg.un_650
  // [1240]
  0x061b040c, 0x553f030c, 0x3f000620, 0x130411ee,   // fi.tr.de_543 nl.af.rw_543  de.af.un_850 ro.fi.et_422
  0x19000608, 0x0d530907, 0x1300041b, 0x200e0460,   // de.gl.un_430 pl.ht.cs_432  fi.et.un_770 fi.is.sq_664
  0x64211c12, 0x20311bad, 0x07171004, 0x00002d24,   // id.jw.lg_654 tr.az.sq_643  be.sr.bg_332 sk.un.un_900
  0x080c06a4, 0x17001611, 0x0c0704a4, 0x211e1c60,   // de.sv.no_433 hr.sr.un_630  fi.it.sv_433 id.ms.jw_664
  // [1250]
  0x1e000204, 0x55071b0c, 0x0b231912, 0x200f1ba4,   // da.ms.un_320 tr.it.rw_543  gl.ca.es_654 tr.lv.sq_433
  0x1700162c, 0x1e130408, 0x04172807, 0x1e1c2112,   // hr.sr.un_990 fi.et.ms_443  sw.sr.fi_432 jw.id.ms_654
  0x17132904, 0x0c27010c, 0x27181355, 0x18282bad,   // sl.et.sr_332 en.gd.sv_543  et.ga.gd_442 vi.sw.ga_643
  0x0d0506ec, 0x17292d11, 0x10001104, 0x0c0306ad,   // de.fr.cs_644 sk.sl.sr_653  ro.lt.un_320 de.nl.sv_643
  // [1260]
  0x2b0a280d, 0x020618ec, 0x193123a6, 0x3f03040c,   // sw.pt.vi_554 ga.de.da_644  ca.az.gl_521 fi.nl.af_543
  0x0d061fee, 0x2b000804, 0x17162b14, 0x2a2016a0,   // cy.de.cs_422 no.vi.un_320  vi.hr.sr_666 hr.sq.mt_322
  0x64002505, 0x1600170d, 0x041b01a4, 0x18001213,   // eu.lg.un_330 sr.hr.un_540  en.tr.fi_433 ur.ar.un_650
  0x1b043105, 0x04201314, 0x08040702, 0x0c211ca0,   // az.fi.tr_333 et.sq.fi_666  bg.ru.uk_222 id.jw.sv_322
  // [1270]
  0x201310a6, 0x17096ba0, 0x1108040c, 0x1e282912,   // lt.et.sq_521 ceb.pl.sr_322  ru.uk.ro_543 sl.sw.ms_654
  0x641629a4, 0x0a002b2a, 0x27291b11, 0x6e17160e,   // sl.hr.lg_433 vi.pt.un_970  tr.sl.gd_653 hr.sr.blu_555
  0x09171605, 0x041017a9, 0x0b0a1fa4, 0x190a2bac,   // hr.sr.pl_333 sr.be.ru_544  cy.pt.es_433 vi.pt.gl_632
  0x2b001a29, 0x04001314, 0x25005508, 0x101f0c07,   // tl.vi.un_960 et.fi.un_660  rw.eu.un_430 sv.cy.lt_432
  // [1280]
  0x31002008, 0x0c000813, 0x1c1309ad, 0x07041107,   // sq.az.un_430 no.sv.un_650  hi.bh.mr_643 ro.ru.bg_432
  0x3f171609, 0x04000705, 0x170a11a9, 0x10002104,   // hr.sr.af_444 bg.ru.un_330  ro.mk.sr_544 jw.lt.un_320
  0x08006405, 0x2a006407, 0x121331a0, 0x1218210e,   // lg.no.un_330 lg.mt.un_420  az.et.hu_322 fa.ar.ur_555
  0x02000407, 0x18122155, 0x0e00181a, 0x211e1c04,   // fi.da.un_420 fa.ur.ar_442  ga.is.un_760 id.ms.jw_332
  // [1290]
  0x10002d04, 0x131c0907, 0x6b001a09, 0x1a186ba0,   // sk.lt.un_320 hi.mr.bh_432  tl.ceb.un_440 ceb.ga.tl_322
  0x08100407, 0x1a216bec, 0x1a006b12, 0x0f002504,   // ru.be.uk_432 ceb.jw.tl_644  ceb.tl.un_640 eu.lv.un_320
  0x2d0d0914, 0x010d0907, 0x130d0907, 0x210f0ea0,   // pl.cs.sk_666 pl.cs.en_432  hi.ne.bh_432 is.lv.jw_322
  0x08250e0c, 0x1a006b0e, 0x040a07ee, 0x17162912,   // is.eu.no_543 ceb.tl.un_550  bg.mk.ru_422 sl.hr.sr_654
  // [12a0]
  0x07040aa9, 0x1f002719, 0x0a000704, 0x03100fee,   // mk.ru.bg_544 gd.cy.un_750  bg.mk.un_320 lv.lt.nl_422
  0x0c200fec, 0x0c001f21, 0x2d130ba0, 0x27021f04,   // lv.sq.sv_644 cy.sv.un_860  es.et.sk_322 cy.da.gd_332
  0x120a080b, 0x3f002104, 0x25002708, 0x10111205,   // no.pt.hu_542 jw.af.un_320  gd.eu.un_430 hu.ro.lt_333
  0x2d0d02a9, 0x2d0d09ec, 0x08006435, 0x07033f08,   // da.cs.sk_544 pl.cs.sk_644  lg.no.un_A90 af.nl.it_443
  // [12b0]
  0x03003f21, 0x04000a05, 0x08020309, 0x070411a4,   // af.nl.un_860 mk.ru.un_330  nl.da.no_444 ro.ru.bg_433
  0x021b1f04, 0x13111ca4, 0x29000f08, 0x0b002818,   // cy.tr.da_332 id.ro.et_433  lv.sl.un_430 sw.es.un_740
  0x2d0d09a0, 0x11000a0e, 0x3f000302, 0x31290f0c,   // pl.cs.sk_322 pt.ro.un_550  nl.af.un_220 lv.sl.az_543
  0x021b5307, 0x100817a4, 0x211a2702, 0x31000f05,   // ht.tr.da_432 sr.uk.be_433  gd.tl.jw_222 lv.az.un_330
  // [12c0]
  0x291e1c55, 0x55002012, 0x17161ba9, 0x00002315,   // id.ms.sl_442 sq.rw.un_640  tr.hr.sr_544 ca.un.un_700
  0x27311f55, 0x12100fa0, 0x1b020807, 0x1e061c04,   // cy.az.gd_442 lv.lt.hu_322  no.da.tr_432 id.de.ms_332
  0x6b0d2dee, 0x09000314, 0x13000605, 0x531b31a0,   // sk.cs.ceb_422 nl.pl.un_660  de.et.un_330 az.tr.ht_322
  0x0f1b1909, 0x6b551a12, 0x0b0a070b, 0x11060807,   // gl.tr.lv_444 tl.rw.ceb_654  it.pt.es_542 no.de.ro_432
  // [12d0]
  0x1c002505, 0x0a190b13, 0x25043f07, 0x080302a7,   // eu.id.un_330 es.gl.pt_665  af.fi.eu_432 da.nl.no_532
  0x1b53230c, 0x03000b04, 0x272a0ea7, 0x1a006b2b,   // ca.ht.tr_543 es.nl.un_320  is.mt.gd_532 ceb.tl.un_980
  0x080c02a6, 0x06000702, 0x040a1104, 0x55006b1a,   // da.sv.no_521 it.de.un_220  ro.mk.ru_332 ceb.rw.un_760
  0x071711a4, 0x1a0c6b04, 0x122118a9, 0x1a3f01ad,   // ro.sr.bg_433 ceb.sv.tl_332  ar.fa.ur_544 en.af.tl_643
  // [12e0]
  0x1c001e0b, 0x06001f12, 0x19000607, 0x04100a05,   // ms.id.un_520 cy.de.un_640  de.gl.un_420 mk.be.ru_333
  0x556b2aa0, 0x02131f13, 0x312d0d13, 0x130d090c,   // mt.ceb.rw_322 cy.et.da_665  cs.sk.az_665 hi.ne.bh_543
  0x0a000718, 0x1f2d0d08, 0x08001013, 0x00000b2d,   // bg.mk.un_740 cs.sk.cy_443  be.uk.un_650 bn.un.un_A00
  0x18002b07, 0x1a2d31ee, 0x07002302, 0x133f03a0,   // vi.ga.un_420 az.sk.tl_422  ca.it.un_220 nl.af.et_322
  // [12f0]
  0x250c08a0, 0x2a006b08, 0x2a072312, 0x170a1104,   // no.sv.eu_322 ceb.mt.un_430  ca.it.mt_654 ro.mk.sr_332
  0x18002111, 0x06080cad, 0x55126b0c, 0x1e002704,   // fa.ar.un_630 sv.no.de_643  ceb.hu.rw_543 gd.ms.un_320
  0x08041107, 0x162955ee, 0x0a000409, 0x07041705,   // ro.ru.uk_432 rw.sl.hr_422  ru.mk.un_440 sr.ru.bg_333
  0x1f200e0c, 0x04110707, 0x08101708, 0x2a001802,   // is.sq.cy_543 bg.ro.ru_432  sr.be.uk_443 ga.mt.un_220
  // [1300]
  0x53270e07, 0x2100180c, 0x6b1a6ea9, 0x0400080e,   // is.gd.ht_432 ar.fa.un_530  blu.tl.ceb_544 uk.ru.un_550
  0x00000c2d, 0x2b001c05, 0x080417af, 0x6e000804,   // sv.un.un_A00 id.vi.un_330  sr.ru.uk_655 no.blu.un_320
  0x0a000818, 0x07040a02, 0x6e6b1a0d, 0x10001f02,   // uk.mk.un_740 mk.ru.bg_222  tl.ceb.blu_554 cy.lt.un_220
  0x19000a2c, 0x27190a0c, 0x6b000111, 0x19000a23,   // pt.gl.un_990 pt.gl.gd_543  en.ceb.un_630 pt.gl.un_880
  // [1310]
  0x28006e12, 0x122d0da7, 0x2b182707, 0x190a1805,   // blu.sw.un_640 cs.sk.hu_532  gd.ga.vi_432 ga.pt.gl_333
  0x0e080255, 0x07001104, 0x02002b02, 0x19120aa4,   // da.no.is_442 ro.bg.un_320  vi.da.un_220 pt.hu.gl_433
  0x1f190a13, 0x09290aa4, 0x01050705, 0x03006e14,   // pt.gl.cy_665 pt.sl.pl_433  it.fr.en_333 blu.nl.un_660
  0x1c0d0913, 0x1e1c6ea0, 0x12001f0c, 0x12060d0c,   // hi.ne.mr_665 blu.id.ms_322  cy.hu.un_530 cs.de.hu_543
  // [1320]
  0x120e0a12, 0x0d171604, 0x11062307, 0x6e200d0c,   // pt.is.hu_654 hr.sr.cs_332  ca.de.ro_432 cs.sq.blu_543
  0x0d122909, 0x28002702, 0x1f0a1911, 0x27196e04,   // sl.hu.cs_444 gd.sw.un_220  gl.pt.cy_653 blu.gl.gd_332
  0x12002105, 0x063f0208, 0x1a006b35, 0x230d0904,   // fa.ur.un_330 da.af.de_443  ceb.tl.un_A90 pl.cs.ca_332
  0x13210aad, 0x12002108, 0x0d6e5307, 0x1f3f1a60,   // pt.jw.et_643 fa.ur.un_430  ht.blu.cs_432 tl.af.cy_664
  // [1330]
  0x010706a0, 0x0a230d08, 0x2d210d07, 0x19006e04,   // de.it.en_322 cs.ca.pt_443  cs.jw.sk_432 blu.gl.un_320
  0x170a1107, 0x19000a19, 0x190b10a0, 0x1f0920ac,   // ro.mk.sr_432 pt.gl.un_750  lt.es.gl_322 sq.pl.cy_632
  0x080a0712, 0x0f120da0, 0x312d0dee, 0x64190a12,   // bg.mk.uk_654 cs.hu.lv_322  cs.sk.az_422 pt.gl.lg_654
  0x190a08a0, 0x0e000c22, 0x6e1b2107, 0x0a0d2307,   // no.pt.gl_322 sv.is.un_870  jw.tr.blu_432 ca.cs.pt_432
  // [1340]
  0x17160bee, 0x0a290daf, 0x17160d0c, 0x0d1c09a4,   // es.hr.sr_422 cs.sl.pt_655  cs.hr.sr_543 hi.mr.ne_433
  0x2b062304, 0x20001705, 0x08040708, 0x110708a4,   // ca.de.vi_332 sr.sq.un_330  bg.ru.uk_443 uk.bg.ro_433
  0x29060da4, 0x29090d07, 0x11090d07, 0x00001c2d,   // cs.de.sl_433 cs.pl.sl_432  cs.pl.ro_432 mr.un.un_A00
  0x00001a24, 0x01002418, 0x25002812, 0x1a0564a7,   // tl.un.un_900 yi.iw.un_740  sw.eu.un_640 lg.fr.tl_532
  // [1350]
  0x552d0d0e, 0x0b1219a4, 0x2d0d0faf, 0x170408a0,   // cs.sk.rw_555 gl.hu.es_433  lv.cs.sk_655 uk.ru.sr_322
  0x16190b02, 0x17070a55, 0x16290909, 0x0407100c,   // es.gl.hr_222 mk.bg.sr_442  pl.sl.hr_444 be.bg.ru_543
  0x0800640c, 0x0f100908, 0x3f0c0604, 0x170a0705,   // lg.no.un_530 pl.lt.lv_443  de.sv.af_332 bg.mk.sr_333
  0x28000404, 0x170411a4, 0x0d001308, 0x0f13040d,   // fi.sw.un_320 ro.ru.sr_433  bh.ne.un_430 fi.et.lv_554
  // [1360]
  0x020e08a0, 0x6404130c, 0x07170a13, 0x12000404,   // no.is.da_322 et.fi.lg_543  mk.sr.bg_665 fi.hu.un_320
  0x12002808, 0x1c130909, 0x0e000c0c, 0x162917ec,   // sw.hu.un_430 hi.bh.mr_444  sv.is.un_530 sr.sl.hr_644
  0x0800170d, 0x2b1617ee, 0x11001714, 0x13000408,   // sr.uk.un_540 sr.hr.vi_422  sr.ro.un_660 fi.et.un_430
  0x170807a0, 0x0400132b, 0x04033fec, 0x0f033fa0,   // bg.uk.sr_322 et.fi.un_980  af.nl.fi_644 af.nl.lv_322
  // [1370]
  0x25001f04, 0x09001c02, 0x1311280b, 0x1a1311a4,   // cy.eu.un_320 id.pl.un_220  sw.ro.et_542 ro.et.tl_433
  0x21000904, 0x251a0e0c, 0x17002923, 0x11002904,   // pl.jw.un_320 is.tl.eu_543  sl.sr.un_880 sl.ro.un_320
  0x162529a0, 0x08000914, 0x0b002002, 0x3f00032b,   // sl.eu.hr_322 pl.no.un_660  sq.es.un_220 nl.af.un_980
  0x07081004, 0x190b07ee, 0x09001204, 0x1a5509a4,   // be.uk.bg_332 it.es.gl_422  hu.pl.un_320 pl.rw.tl_433
  // [1380]
  0x0c2512a7, 0x120d53a0, 0x6b2a1255, 0x10000914,   // hu.eu.sv_532 ht.cs.hu_322  hu.mt.ceb_442 pl.lt.un_660
  0x2d0d10a9, 0x04001009, 0x08110408, 0x12002907,   // lt.cs.sk_544 be.ru.un_440  ru.ro.uk_443 sl.hu.un_420
  0x09006402, 0x2b1e1c04, 0x16291107, 0x53293f04,   // lg.pl.un_220 id.ms.vi_332  ro.sl.hr_432 af.sl.ht_332
  0x16002504, 0x130c1f13, 0x090306ac, 0x19003f04,   // eu.hr.un_320 cy.sv.et_665  de.nl.pl_632 af.gl.un_320
  // [1390]
  0x17291105, 0x2b3f01a9, 0x64005312, 0x250411a4,   // ro.sl.sr_333 en.af.vi_544  ht.lg.un_640 ro.fi.eu_433
  0x06001604, 0x13292d07, 0x0c2d0d5a, 0x10000414,   // hr.de.un_320 sk.sl.et_432  cs.sk.sv_553 ru.be.un_660
  0x2d110da4, 0x120929a7, 0x12002912, 0x05005307,   // cs.ro.sk_433 sl.pl.hu_532  sl.hu.un_640 ht.fr.un_420
  0x03000b02, 0x16172912, 0x12000221, 0x130c02a0,   // es.nl.un_220 sl.sr.hr_654  da.hu.un_860 da.sv.et_322
  // [13a0]
  0x0d130960, 0x07080aa4, 0x29162da0, 0x29121604,   // hi.bh.ne_664 mk.uk.bg_433  sk.hr.sl_322 hr.hu.sl_332
  0x0c3f0807, 0x1f172002, 0x16002908, 0x25000c04,   // no.af.sv_432 sq.sr.cy_222  sl.hr.un_430 sv.eu.un_320
  0x12000c1a, 0x170d16ee, 0x050c2107, 0x0d130908,   // sv.hu.un_760 hr.cs.sr_422  jw.sv.fr_432 hi.bh.ne_443
  0x093f13a0, 0x08100413, 0x216b13a0, 0x1b002913,   // et.af.pl_322 ru.be.uk_665  et.ceb.jw_322 sl.tr.un_650
  // [13b0]
  0x29165304, 0x2d291604, 0x06003112, 0x02001104,   // ht.hr.sl_332 hr.sl.sk_332  az.de.un_640 ro.da.un_320
  0x161229ec, 0x1c005304, 0x23002104, 0x19252755,   // sl.hu.hr_644 ht.id.un_320  jw.ca.un_320 gd.eu.gl_442
  0x06000404, 0x161229ad, 0x04100804, 0x0825180c,   // fi.de.un_320 sl.hu.hr_643  uk.be.ru_332 ga.eu.no_543
  0x02232907, 0x12162907, 0x160929a0, 0x04002504,   // sl.ca.da_432 sl.hr.hu_432  sl.pl.hr_322 eu.fi.un_320
  // [13c0]
  0x182725af, 0x28000421, 0x0d0913ac, 0x2500180b,   // eu.gd.ga_655 fi.sw.un_860  bh.hi.ne_632 ga.eu.un_520
  0x3f0704a9, 0x27251812, 0x1b001707, 0x10000705,   // fi.it.af_544 ga.eu.gd_654  sr.tr.un_420 bg.be.un_330
  0x21006e07, 0x11001e0b, 0x2800041b, 0x250627a4,   // blu.jw.un_420 ms.ro.un_520  fi.sw.un_770 gd.de.eu_433
  0x04002512, 0x18001114, 0x6400120e, 0x12002104,   // eu.fi.un_640 ro.ga.un_660  hu.lg.un_550 fa.ur.un_320
  // [13d0]
  0x31006b04, 0x2109080c, 0x2a190705, 0x090a07ee,   // ceb.az.un_320 no.pl.jw_543  it.gl.mt_333 it.pt.pl_422
  0x64011104, 0x0c25180c, 0x31001a02, 0x313f030c,   // ro.en.lg_332 ga.eu.sv_543  tl.az.un_220 nl.af.az_543
  0x53000419, 0x6b0e010c, 0x3f001105, 0x55310504,   // fi.ht.un_750 en.is.ceb_543  ro.af.un_330 fr.az.rw_332
  0x08000204, 0x23000505, 0x090d1c04, 0x04000a0d,   // da.no.un_320 fr.ca.un_330  mr.ne.hi_332 mk.ru.un_540
  // [13e0]
  0x1827250c, 0x03020ea4, 0x0113250c, 0x0818010c,   // eu.gd.ga_543 is.da.nl_433  eu.et.en_543 en.ga.no_543
  0x1100280b, 0x07002105, 0x082701af, 0x08210107,   // sw.ro.un_520 jw.it.un_330  en.gd.no_655 en.jw.no_432
  0x01006e07, 0x12002a02, 0x01030655, 0x053f1307,   // blu.en.un_420 mt.hu.un_220  de.nl.en_442 et.af.fr_432
  0x641a3f55, 0x043f1308, 0x06000307, 0x1e001902,   // af.tl.lg_442 et.af.fi_443  nl.de.un_420 gl.ms.un_220
  // [13f0]
  0x130d0909, 0x3f000120, 0x0b002322, 0x060b04a4,   // hi.ne.bh_444 en.af.un_850  ca.es.un_870 fi.es.de_433
  0x01040704, 0x100417ec, 0x55000e04, 0x16111704,   // it.fi.en_332 sr.ru.be_644  is.rw.un_320 sr.ro.hr_332
  0x08170aa4, 0x040817a4, 0x080c2908, 0x11000704,   // mk.sr.uk_433 sr.uk.ru_433  sl.sv.no_443 it.ro.un_320
  0x64001218, 0x08016ba4, 0x041710ee, 0x100e08a0,   // hu.lg.un_740 ceb.en.no_433  be.sr.ru_422 no.is.lt_322

  // [1400]
  0x070a11ee, 0x040a10a0, 0x07000404, 0x070408a0,   // ro.mk.bg_422 be.mk.ru_322  fi.it.un_320 uk.ru.bg_322
  0x1c001313, 0x0d002908, 0x0f001012, 0x211b5302,   // bh.mr.un_650 sl.cs.un_430  lt.lv.un_640 ht.tr.jw_222
  0x0b00231a, 0x030b6b08, 0x086b06ee, 0x1e002302,   // ca.es.un_760 ceb.es.nl_443  de.ceb.no_422 ca.ms.un_220
  0x07000f08, 0x2b2103a0, 0x170a11ad, 0x1f000b09,   // lv.it.un_430 nl.jw.vi_322  ro.mk.sr_643 es.cy.un_440
  // [1410]
  0x1a0b07a9, 0x102a0212, 0x170a11a0, 0x21002804,   // it.es.tl_544 da.mt.lt_654  ro.mk.sr_322 sw.jw.un_320
  0x011653a4, 0x6400552c, 0x28101802, 0x190b0aa4,   // ht.hr.en_433 rw.lg.un_990  ga.lt.sw_222 pt.es.gl_433
  0x532821a0, 0x27006411, 0x18286eec, 0x6b000705,   // jw.sw.ht_322 lg.gd.un_630  blu.sw.ga_644 it.ceb.un_330
  0x21001b0e, 0x04001702, 0x23001f09, 0x29172d0c,   // tr.jw.un_550 sr.ru.un_220  cy.ca.un_440 sk.sr.sl_543
  // [1420]
  0x252864a0, 0x16001c04, 0x04170807, 0x0b0a1914,   // lg.sw.eu_322 id.hr.un_320  uk.sr.ru_432 gl.pt.es_666
  0x640e2aa4, 0x1e1c01a4, 0x0f0e25ad, 0x1a006e19,   // mt.is.lg_433 en.id.ms_433  eu.is.lv_643 blu.tl.un_750
  0x12270707, 0x07006b0e, 0x1c000d0d, 0x09000104,   // it.gd.hu_432 ceb.it.un_550  ne.mr.un_540 en.pl.un_320
  0x0400082c, 0x10130f0d, 0x04002a0e, 0x00005324,   // uk.ru.un_990 lv.et.lt_554  mt.fi.un_550 ht.un.un_900
  // [1430]
  0x190b0a08, 0x2a2d0d55, 0x19000a13, 0x2a641f5a,   // pt.es.gl_443 cs.sk.mt_442  pt.gl.un_650 cy.lg.mt_553
  0x13190b0c, 0x31001102, 0x200f2a07, 0x020e11a0,   // es.gl.et_543 ro.az.un_220  mt.lv.sq_432 ro.is.da_322
  0x2d000a07, 0x091f530c, 0x09001c0c, 0x050a0107,   // pt.sk.un_420 ht.cy.pl_543  mr.hi.un_530 en.pt.fr_432
  0x6e1f1aad, 0x1f1807ad, 0x0e2d0d05, 0x21001902,   // tl.cy.blu_643 it.ga.cy_643  cs.sk.is_333 gl.jw.un_220
  // [1440]
  0x190c1007, 0x06000e07, 0x25002302, 0x23006e19,   // lt.sv.gl_432 is.de.un_420  ca.eu.un_220 blu.ca.un_750
  0x07052a07, 0x10002107, 0x1b1231ec, 0x02001307,   // mt.fr.it_432 jw.lt.un_420  az.hu.tr_644 et.da.un_420
  0x061b3108, 0x0e00190d, 0x1f311b08, 0x040a0712,   // az.tr.de_443 gl.is.un_540  tr.az.cy_443 bg.mk.ru_654
  0x2d2a0d0c, 0x12311ba4, 0x07041009, 0x6e6b1204,   // cs.mt.sk_543 tr.az.hu_433  be.ru.bg_444 hu.ceb.blu_332
  // [1450]
  0x04000d0d, 0x0d091c0c, 0x310f1ba9, 0x0a001723,   // cs.fi.un_540 mr.hi.ne_543  tr.lv.az_544 sr.mk.un_880
  0x136b0807, 0x2a1f6eec, 0x0a000804, 0x17040a04,   // no.ceb.et_432 blu.cy.mt_644  uk.mk.un_320 mk.ru.sr_332
  0x04000c19, 0x0b000a04, 0x09001302, 0x0e0213ee,   // sv.fi.un_750 pt.es.un_320  bh.hi.un_220 et.da.is_422
  0x100a0704, 0x13000404, 0x1b0b120c, 0x0700110d,   // bg.mk.be_332 fi.et.un_320  hu.es.tr_543 ro.bg.un_540
  // [1460]
  0x0a0711af, 0x0a080702, 0x08311212, 0x04171002,   // ro.bg.mk_655 bg.uk.mk_222  hu.az.no_654 be.sr.ru_222
  0x2000100e, 0x1b1231a4, 0x20100404, 0x040f1013,   // lt.sq.un_550 az.hu.tr_433  fi.lt.sq_332 lt.lv.fi_665
  0x23001b05, 0x2000040d, 0x041020ac, 0x17000712,   // tr.ca.un_330 fi.sq.un_540  sq.lt.fi_632 bg.sr.un_640
  0x0f001602, 0x21121814, 0x20311ba9, 0x2b1a01a9,   // hr.lv.un_220 ar.ur.fa_666  tr.az.sq_544 en.tl.vi_544
  // [1470]
  0x0800041a, 0x011e1c02, 0x03003f05, 0x1b005322,   // ru.uk.un_760 id.ms.en_222  af.nl.un_330 ht.tr.un_870
  0x10041704, 0x130c04a0, 0x5300280c, 0x060c130c,   // sr.ru.be_332 fi.sv.et_322  sw.ht.un_530 et.sv.de_543
  0x106b1aa4, 0x092164a0, 0x0a0408a6, 0x030f0911,   // tl.ceb.lt_433 lg.jw.pl_322  uk.ru.mk_521 pl.lv.nl_653
  0x0f002b0d, 0x0600040b, 0x0f000922, 0x12211804,   // vi.lv.un_540 fi.de.un_520  pl.lv.un_870 ar.fa.ur_332
  // [1480]
  0x53091b05, 0x1b006419, 0x04001012, 0x0f0410a4,   // tr.pl.ht_333 lg.tr.un_750  lt.fi.un_640 lt.fi.lv_433
  0x04000e02, 0x05002108, 0x09000f14, 0x10006405,   // is.fi.un_220 jw.fr.un_430  lv.pl.un_660 lg.lt.un_330
  0x09230fa7, 0x110f090b, 0x0d002d07, 0x1800271b,   // lv.ca.pl_532 pl.lv.ro_542  sk.cs.un_420 gd.ga.un_770
  0x20003f04, 0x53090f07, 0x25190b02, 0x18002718,   // af.sq.un_320 lv.pl.ht_432  es.gl.eu_222 gd.ga.un_740
  // [1490]
  0x0f002d1a, 0x18002a04, 0x10003114, 0x11040813,   // sk.lv.un_760 mt.ga.un_320  az.lt.un_660 uk.ru.ro_665
  0x1f00640d, 0x06255307, 0x1328230c, 0x31001904,   // lg.cy.un_540 ht.eu.de_432  ca.sw.et_543 gl.az.un_320
  0x0a00050d, 0x07001704, 0x19310a55, 0x1a006b22,   // fr.pt.un_540 sr.bg.un_320  pt.az.gl_442 ceb.tl.un_870
  0x2118125a, 0x0f000204, 0x0408100d, 0x211e1c0e,   // ur.ar.fa_553 da.lv.un_320  be.uk.ru_554 id.ms.jw_555
  // [14a0]
  0x27001807, 0x08070aa4, 0x04060c0d, 0x2a0519a0,   // ga.gd.un_420 mk.bg.uk_433  sv.de.fi_554 gl.fr.mt_322
  0x232101a0, 0x042a0708, 0x292d0d05, 0x0d0b2da4,   // en.jw.ca_322 it.mt.fi_443  cs.sk.sl_333 sk.es.cs_433
  0x010a0504, 0x08100408, 0x03001a04, 0x0d0913a9,   // fr.pt.en_332 ru.be.uk_443  tl.nl.un_320 bh.hi.ne_544
  0x211218af, 0x211a28af, 0x55006b02, 0x6b1e1a09,   // ar.ur.fa_655 sw.tl.jw_655  ceb.rw.un_220 tl.ms.ceb_444
  // [14b0]
  0x00002437, 0x06003107, 0x6b002809, 0x211b28a4,   // yi.un.un_B00 az.de.un_420  sw.ceb.un_440 sw.tr.jw_433
  0x04100814, 0x1b535504, 0x1e0929ec, 0x232d0d05,   // uk.be.ru_666 rw.ht.tr_332  sl.pl.ms_644 cs.sk.ca_333
  0x55640612, 0x08120c13, 0x1a2d08a0, 0x05200ba0,   // de.lg.rw_654 sv.hu.no_665  no.sk.tl_322 es.sq.fr_322
  0x53000104, 0x6b292855, 0x2800251b, 0x16170d04,   // en.ht.un_320 sw.sl.ceb_442  eu.sw.un_770 cs.sr.hr_332
  // [14c0]
  0x18001107, 0x18002b04, 0x08020ea4, 0x0925120e,   // ro.ga.un_420 vi.ga.un_320  is.da.no_433 hu.eu.pl_555
  0x23002704, 0x0e0201a0, 0x0800102b, 0x1a211cee,   // gd.ca.un_320 en.da.is_322  be.uk.un_980 id.jw.tl_422
  0x645507a9, 0x0c060ea7, 0x06000e08, 0x18002804,   // it.rw.lg_544 is.de.sv_532  is.de.un_430 sw.ga.un_320
  0x28001c04, 0x211b04a4, 0x1b0e28a7, 0x1e1c1014,   // id.sw.un_320 fi.tr.jw_433  sw.is.tr_532 lt.id.ms_666
  // [14d0]
  0x04000802, 0x1b290809, 0x2a0603a0, 0x1f080204,   // uk.ru.un_220 no.sl.tr_444  nl.de.mt_322 da.no.cy_332
  0x08000f08, 0x210464ee, 0x09211aa4, 0x21182707,   // lv.no.un_430 lg.fi.jw_422  tl.jw.pl_433 gd.ga.jw_432
  0x01002704, 0x190a13a9, 0x255323ee, 0x06002519,   // gd.en.un_320 et.pt.gl_544  ca.ht.eu_422 eu.de.un_750
  0x04002808, 0x062a030d, 0x03000b16, 0x1e1c1b09,   // sw.fi.un_430 nl.mt.de_554  bn.ko.un_720 tr.id.ms_444
  // [14e0]
  0x31162904, 0x53000508, 0x1b1e1c09, 0x253f03a7,   // sl.hr.az_332 fr.ht.un_430  id.ms.tr_444 nl.af.eu_532
  0x06640811, 0x06120e0e, 0x0c083fa0, 0x13006404,   // no.lg.de_653 is.hu.de_555  af.no.sv_322 lg.et.un_320
  0x3f0306af, 0x0c09100d, 0x0f000e19, 0x1c130905,   // de.nl.af_655 lt.pl.sv_554  is.lv.un_750 hi.bh.mr_333
  0x20210c04, 0x1b290f08, 0x1b1f0612, 0x211a5309,   // sv.jw.sq_332 lv.sl.tr_443  de.cy.tr_654 ht.tl.jw_444
  // [14f0]
  0x062d0d08, 0x100c02a4, 0x2000211a, 0x2b001c02,   // cs.sk.de_443 da.sv.lt_433  jw.sq.un_760 id.vi.un_220
  0x5300210c, 0x170f0ea0, 0x160953a0, 0x230b010b,   // jw.ht.un_530 is.lv.sr_322  ht.pl.hr_322 en.es.ca_542
  0x170408a9, 0x0e000104, 0x11001904, 0x04110705,   // uk.ru.sr_544 en.is.un_320  gl.ro.un_320 bg.ro.ru_333
  0x06005307, 0x2028550b, 0x0253090b, 0x09006419,   // ht.de.un_420 rw.sw.sq_542  pl.ht.da_542 lg.pl.un_750
  // [1500]
  0x21001102, 0x0a040760, 0x010507a0, 0x11061807,   // ro.jw.un_220 bg.ru.mk_664  it.fr.en_322 ga.de.ro_432
  0x131604ee, 0x00003101, 0x0e00270d, 0x6e285512,   // fi.hr.et_422 az.un.un_200  gd.is.un_540 rw.sw.blu_654
  0x5500060d, 0x020453a4, 0x03083fee, 0x08020e05,   // de.rw.un_540 ht.fi.da_433  af.no.nl_422 is.da.no_333
  0x29001204, 0x17070a12, 0x04171104, 0x1a6b2505,   // hu.sl.un_320 mk.bg.sr_654  ro.sr.ru_332 eu.ceb.tl_333
  // [1510]
  0x02001c04, 0x12001a02, 0x211e1ca9, 0x1a080da0,   // id.da.un_320 tl.hu.un_220  id.ms.jw_544 cs.no.tl_322
  0x130612a0, 0x6b1b5308, 0x03003f19, 0x0a040705,   // hu.de.et_322 ht.tr.ceb_443  af.nl.un_750 bg.ru.mk_333
  0x12000d07, 0x31091ba7, 0x092d0d07, 0x31000d07,   // cs.hu.un_420 tr.pl.az_532  cs.sk.pl_432 cs.az.un_420
  0x17001004, 0x0a0704af, 0x0d101aee, 0x230955a0,   // be.sr.un_320 ru.bg.mk_655  tl.lt.cs_422 rw.pl.ca_322
  // [1520]
  0x052d0d02, 0x29180702, 0x18000c04, 0x1708040c,   // cs.sk.fr_222 it.ga.sl_222  sv.ga.un_320 ru.uk.sr_543
  0x0b2311ee, 0x31002a09, 0x55002822, 0x21001907,   // ro.ca.es_422 mt.az.un_440  sw.rw.un_870 gl.jw.un_420
  0x272a5305, 0x0e001808, 0x04110aaf, 0x03003f14,   // ht.mt.gd_333 ga.is.un_430  mk.ro.ru_655 af.nl.un_660
  0x0c0604ec, 0x180e2d08, 0x08020d0c, 0x2d120daf,   // fi.de.sv_644 sk.is.ga_443  cs.da.no_543 cs.hu.sk_655
  // [1530]
  0x07000d04, 0x20000504, 0x0b050704, 0x27000e0c,   // cs.it.un_320 fr.sq.un_320  it.fr.es_332 is.gd.un_530
  0x122d0d04, 0x04000c13, 0x0d006e04, 0x190a23ee,   // cs.sk.hu_332 sv.fi.un_650  blu.cs.un_320 ca.pt.gl_422
  0x07000812, 0x0a1f230c, 0x6b552308, 0x0d000c02,   // uk.bg.un_640 ca.cy.pt_543  ca.rw.ceb_443 sv.cs.un_220
  0x190b11a0, 0x0a1123ad, 0x09071a0c, 0x0c000405,   // ro.es.gl_322 ca.ro.pt_643  tl.it.pl_543 fi.sv.un_330
  // [1540]
  0x250e1a0c, 0x061f20ee, 0x29551a11, 0x06040cee,   // tl.is.eu_543 sq.cy.de_422  tl.rw.sl_653 sv.fi.de_422
  0x190a23ec, 0x17291060, 0x1e1c550e, 0x201123ee,   // ca.pt.gl_644 lt.sl.sr_664  rw.id.ms_555 ca.ro.sq_422
  0x28645512, 0x0a2823ad, 0x21000e08, 0x080717ee,   // rw.lg.sw_654 ca.sw.pt_643  is.jw.un_430 sr.bg.uk_422
  0x292d0d07, 0x25002702, 0x19230a08, 0x0c001608,   // cs.sk.sl_432 gd.eu.un_220  pt.ca.gl_443 hr.sv.un_430
  // [1550]
  0x2d0d1705, 0x11190a5a, 0x0d060708, 0x16095511,   // sr.cs.sk_333 pt.gl.ro_553  it.de.cs_443 rw.pl.hr_653
  0x2d0d1609, 0x041b13a9, 0x0d000919, 0x170d1305,   // hr.cs.sk_444 et.tr.fi_544  hi.ne.un_750 et.cs.sr_333
  0x080a1104, 0x05532b07, 0x1b040107, 0x0c2d0d09,   // ro.mk.uk_332 vi.ht.fr_432  en.fi.tr_432 cs.sk.sv_444
  0x1b021602, 0x19230a0c, 0x6b0d1aa4, 0x080411a9,   // hr.da.tr_222 pt.ca.gl_543  tl.cs.ceb_433 ro.ru.uk_544
  // [1560]
  0x110703a9, 0x190a23a4, 0x080605a0, 0x1e00130c,   // nl.it.ro_544 ca.pt.gl_433  fr.de.no_322 et.ms.un_530
  0x0d002304, 0x1f11230c, 0x040a07a0, 0x110a2312,   // ca.cs.un_320 ca.ro.cy_543  bg.mk.ru_322 ca.pt.ro_654
  0x642155a7, 0x1f000c08, 0x110a2307, 0x1b001104,   // rw.jw.lg_532 sv.cy.un_430  ca.pt.ro_432 ro.tr.un_320
  0x0a0711ad, 0x310c2b04, 0x2d0d31af, 0x292d0d0d,   // ro.bg.mk_643 vi.sv.az_332  az.cs.sk_655 cs.sk.sl_554
  // [1570]
  0x100c21a0, 0x2d0f0907, 0x1b6420ec, 0x04002309,   // jw.sv.lt_322 pl.lv.sk_432  sq.lg.tr_644 ca.fi.un_440
  0x17000407, 0x16000d02, 0x0f102507, 0x16291708,   // ru.sr.un_420 cs.hr.un_220  eu.lt.lv_432 sr.sl.hr_443
  0x0a0407a4, 0x091c0d0b, 0x21021c07, 0x0f080c04,   // bg.ru.mk_433 ne.mr.hi_542  id.da.jw_432 sv.no.lv_332
  0x21001014, 0x091c0d09, 0x1a116b0c, 0x060c02af,   // lt.jw.un_660 ne.mr.hi_444  ceb.ro.tl_543 da.sv.de_655
  // [1580]
  0x04100712, 0x211e1c09, 0x10161aa0, 0x07000414,   // bg.be.ru_654 id.ms.jw_444  tl.hr.lt_322 ru.bg.un_660
  0x20120da0, 0x0e001e04, 0x2a1a5507, 0x17160d07,   // cs.hu.sq_322 ms.is.un_320  rw.tl.mt_432 cs.hr.sr_432
  0x1a100c07, 0x6e281ea0, 0x13215308, 0x04642807,   // sv.lt.tl_432 ms.sw.blu_322  ht.jw.et_443 sw.lg.fi_432
  0x28001804, 0x026455a4, 0x11002819, 0x07002004,   // ga.sw.un_320 rw.lg.da_433  sw.ro.un_750 sq.it.un_320
  // [1590]
  0x2b00270e, 0x1000200c, 0x0d161712, 0x550a07a0,   // gd.vi.un_550 sq.lt.un_530  sr.hr.cs_654 it.pt.rw_322
  0x53190b02, 0x0710115a, 0x28005512, 0x106455ec,   // es.gl.ht_222 ro.be.bg_553  rw.sw.un_640 rw.lg.lt_644
  0x530306a0, 0x11002304, 0x281901a4, 0x09000d11,   // de.nl.ht_322 ca.ro.un_320  en.gl.sw_433 cs.pl.un_630
  0x64005505, 0x182128a7, 0x0407080d, 0x0a080407,   // rw.lg.un_330 sw.jw.ga_532  uk.bg.ru_554 ru.uk.mk_432
  // [15a0]
  0x06010da0, 0x07002a0e, 0x0b000704, 0x27002a12,   // cs.en.de_322 mt.it.un_550  it.es.un_320 mt.gd.un_640
  0x556b120c, 0x5528120c, 0x55071aa7, 0x191c1e07,   // hu.ceb.rw_543 hu.sw.rw_543  tl.it.rw_532 ms.id.gl_432
  0x17002008, 0x17081612, 0x1a6b5312, 0x645528ad,   // sq.sr.un_430 hr.no.sr_654  ht.ceb.tl_654 sw.rw.lg_643
  0x3f091ea0, 0x17002d14, 0x040a17a0, 0x2a0711a4,   // ms.pl.af_322 sk.sr.un_660  sr.mk.ru_322 ro.it.mt_433
  // [15b0]
  0x171a0da0, 0x53001f07, 0x213f5304, 0x092d0d14,   // cs.tl.sr_322 cy.ht.un_420  ht.af.jw_332 cs.sk.pl_666
  0x27281808, 0x17160dee, 0x102a2ba7, 0x0b000108,   // ga.sw.gd_443 cs.hr.sr_422  vi.mt.lt_532 en.es.un_430
  0x110f0d07, 0x186b06ee, 0x6e2028a6, 0x112a0705,   // cs.lv.ro_432 de.ceb.ga_422  sw.sq.blu_521 it.mt.ro_333
  0x092d0d0c, 0x092d0d55, 0x5564280e, 0x08000f02,   // cs.sk.pl_543 cs.sk.pl_442  sw.lg.rw_555 lv.no.un_220
  // [15c0]
  0x0a101704, 0x09060804, 0x202d0d04, 0x1f556412,   // sr.be.mk_332 no.de.pl_332  cs.sk.sq_332 lg.rw.cy_654
  0x64285513, 0x030c3f07, 0x23555302, 0x1a552309,   // rw.sw.lg_665 af.sv.nl_432  ht.rw.ca_222 ca.rw.tl_444
  0x11001702, 0x2a55075a, 0x122328a0, 0x1707080e,   // sr.ro.un_220 it.rw.mt_553  sw.ca.hu_322 uk.bg.sr_555
  0x3f0612ee, 0x1b001122, 0x29002d04, 0x0c310604,   // hu.de.af_422 ro.tr.un_870  sk.sl.un_320 de.az.sv_332
  // [15d0]
  0x060c0412, 0x6b0601a0, 0x5500010c, 0x1123010c,   // fi.sv.de_654 en.de.ceb_322  en.rw.un_530 en.ca.ro_543
  0x080e1fad, 0x17001111, 0x10000804, 0x2917160e,   // cy.is.no_643 ro.sr.un_630  no.lt.un_320 hr.sr.sl_555
  0x2d000d08, 0x08110a09, 0x0d092d0c, 0x092d0d60,   // cs.sk.un_430 mk.ro.uk_444  sk.pl.cs_543 cs.sk.pl_664
  0x18122109, 0x17040812, 0x07000422, 0x080a1704,   // fa.ur.ar_444 uk.ru.sr_654  ru.bg.un_870 sr.mk.uk_332
  // [15e0]
  0x0b003107, 0x040a075a, 0x2d0d10ee, 0x11040712,   // az.es.un_420 bg.mk.ru_553  lt.cs.sk_422 bg.ru.ro_654
  0x0c00080c, 0x06000c14, 0x3f030805, 0x16083fa0,   // no.sv.un_530 sv.de.un_660  no.nl.af_333 af.no.hr_322
  0x0c000613, 0x0c00060b, 0x070105af, 0x0400101a,   // de.sv.un_650 de.sv.un_520  fr.en.it_655 be.ru.un_760
  0x0a1e0307, 0x08000c0e, 0x06001212, 0x64003f0c,   // nl.ms.pt_432 sv.no.un_550  hu.de.un_640 af.lg.un_530
  // [15f0]
  0x1f1318ee, 0x080a0702, 0x0c00200c, 0x1304120d,   // ga.et.cy_422 bg.mk.uk_222  sq.sv.un_530 hu.fi.et_554
  0x21181211, 0x2d162955, 0x0f17290c, 0x03002704,   // ur.ar.fa_653 sl.hr.sk_442  sl.sr.lv_543 gd.nl.un_320
  0x1221180d, 0x23000508, 0x090d0614, 0x0b001705,   // ar.fa.ur_554 fr.ca.un_430  de.cs.pl_666 sr.es.un_330
  0x0d00110c, 0x20100904, 0x0800100b, 0x27001a07,   // ro.cs.un_530 pl.lt.sq_332  be.uk.un_520 tl.gd.un_420
  // [1600]
  0x1800270b, 0x101b0fa0, 0x181123ee, 0x1c012702,   // gd.ga.un_520 lv.tr.lt_322  ca.ro.ga_422 gd.en.id_222
  0x091c1355, 0x1b002519, 0x171623a0, 0x071004a4,   // bh.mr.hi_442 eu.tr.un_750  ca.hr.sr_322 ru.be.bg_433
  0x25230b05, 0x270825a0, 0x201b0ca7, 0x161017a0,   // es.ca.eu_333 eu.no.gd_322  sv.tr.sq_532 sr.lt.hr_322
  0x1802080c, 0x0900070c, 0x08001905, 0x0d0e0aaf,   // no.da.ga_543 it.pl.un_530  gl.no.un_330 pt.is.cs_655
  // [1610]
  0x210c1c07, 0x2b0a18af, 0x06271813, 0x3f0e18ad,   // id.sv.jw_432 ga.pt.vi_655  ga.gd.de_665 ga.is.af_643
  0x07080aa0, 0x102d0d08, 0x1b001109, 0x18002b12,   // mk.uk.bg_322 cs.sk.lt_443  ro.tr.un_440 vi.ga.un_640
  0x040b20a7, 0x13030607, 0x110a1709, 0x18002b21,   // sq.es.fi_532 de.nl.et_432  sr.mk.ro_444 vi.ga.un_860
  0x190a18a9, 0x070208ec, 0x18000e21, 0x05000119,   // ga.pt.gl_544 no.da.it_644  is.ga.un_860 en.fr.un_750
  // [1620]
  0x1b002513, 0x1b0c100c, 0x07000405, 0x100f2d02,   // eu.tr.un_650 lt.sv.tr_543  ru.bg.un_330 sk.lv.lt_222
  0x11002519, 0x25080e09, 0x16002002, 0x0900100c,   // eu.ro.un_750 is.no.eu_444  sq.hr.un_220 lt.pl.un_530
  0x0b002302, 0x1200181b, 0x03020707, 0x1c0d090c,   // ca.es.un_220 ga.hu.un_770  it.da.nl_432 hi.ne.mr_543
  0x0a180d0b, 0x00002324, 0x0d2d090d, 0x120a0ea4,   // cs.ga.pt_542 ca.un.un_900  pl.sk.cs_554 is.pt.hu_433
  // [1630]
  0x06100808, 0x27002d02, 0x03000214, 0x03001102,   // no.lt.de_443 sk.gd.un_220  da.nl.un_660 ro.nl.un_220
  0x20000305, 0x17291608, 0x03002007, 0x0a171109,   // nl.sq.un_330 hr.sl.sr_443  sq.nl.un_420 ro.sr.mk_444
  0x0f00101b, 0x28030c05, 0x28105507, 0x0300200e,   // lt.lv.un_770 sv.nl.sw_333  rw.lt.sw_432 sq.nl.un_550
  0x022d06ee, 0x0d102d0d, 0x2a00200c, 0x0b2d0d04,   // de.sk.da_422 sk.lt.cs_554  sq.mt.un_530 cs.sk.es_332
  // [1640]
  0x0900100d, 0x070a17a9, 0x5500640d, 0x21556412,   // lt.pl.un_540 sr.mk.bg_544  lg.rw.un_540 lg.rw.jw_654
  0x551028a4, 0x10000812, 0x041007a0, 0x09001021,   // sw.lt.rw_433 uk.be.un_640  bg.be.ru_322 lt.pl.un_860
  0x0900101a, 0x0d001305, 0x2500641b, 0x0f171007,   // lt.pl.un_760 bh.ne.un_330  lg.eu.un_770 lt.sr.lv_432
  0x0d1c1355, 0x0400070b, 0x21552808, 0x09000d0c,   // bh.mr.ne_442 bg.ru.un_520  sw.rw.jw_443 ne.hi.un_530
  // [1650]
  0x120c0214, 0x1f000104, 0x12003f05, 0x01533fa7,   // da.sv.hu_666 en.cy.un_320  af.hu.un_330 af.ht.en_532
  0x080a1705, 0x07000107, 0x09000b14, 0x0e282a14,   // sr.mk.uk_333 en.it.un_420  es.pl.un_660 mt.sw.is_666
  0x1a211c07, 0x0600091b, 0x09002104, 0x096b1a04,   // id.jw.tl_432 pl.de.un_770  jw.pl.un_320 tl.ceb.pl_332
  0x090f0360, 0x0e020c0c, 0x3f030ca4, 0x020c08af,   // nl.lv.pl_664 sv.da.is_543  sv.nl.af_433 no.sv.da_655
  // [1660]
  0x2a641fad, 0x02030ca0, 0x090d1c5a, 0x0400111a,   // cy.lg.mt_643 sv.nl.da_322  mr.ne.hi_553 ro.ru.un_760
  0x020c04ad, 0x10002d08, 0x55093f12, 0x10000412,   // fi.sv.da_643 sk.lt.un_430  af.pl.rw_654 ru.be.un_640
  0x3f1a04a6, 0x2a100fad, 0x1f6428ad, 0x091c0da7,   // fi.tl.af_521 lv.lt.mt_643  sw.lg.cy_643 ne.mr.hi_532
  0x64005308, 0x2a060708, 0x5300101a, 0x12093fee,   // ht.lg.un_430 it.de.mt_443  lt.ht.un_760 af.pl.hu_422
  // [1670]
  0x06102a07, 0x09002019, 0x2d5309a4, 0x0b070fac,   // mt.lt.de_432 sq.pl.un_750  pl.ht.sk_433 lv.it.es_632
  0x16000704, 0x0f002d13, 0x17001112, 0x09000622,   // it.hr.un_320 sk.lv.un_650  ro.sr.un_640 de.pl.un_870
  0x1b002a04, 0x18033fad, 0x2a1f0e04, 0x1a282102,   // mt.tr.un_320 af.nl.ga_643  is.cy.mt_332 jw.sw.tl_222
  0x080c0704, 0x040a0704, 0x090d130c, 0x08020c09,   // it.sv.no_332 bg.mk.ru_332  bh.ne.hi_543 sv.da.no_444
  // [1680]
  0x05640707, 0x2508020b, 0x17070a07, 0x6b1c0904,   // it.lg.fr_432 da.no.eu_542  mk.bg.sr_432 pl.id.ceb_332
  0x31006402, 0x0e001812, 0x0400100b, 0x12532ba0,   // lg.az.un_220 ga.is.un_640  be.ru.un_520 vi.ht.hu_322
  0x0d002102, 0x05211804, 0x2d0d1702, 0x0000052d,   // jw.cs.un_220 ga.jw.fr_332  sr.cs.sk_222 fr.un.un_A00
  0x05070ea4, 0x01002421, 0x23002b23, 0x250455a0,   // is.it.fr_433 yi.iw.un_860  vi.ca.un_880 rw.fi.eu_322
  // [1690]
  0x1e211cec, 0x05000108, 0x07041002, 0x13211c07,   // id.jw.ms_644 en.fr.un_430  be.ru.bg_222 id.jw.et_432
  0x0a000d07, 0x180e0a14, 0x211c13ad, 0x53000502,   // cs.pt.un_420 pt.is.ga_666  et.id.jw_643 fr.ht.un_220
  0x1c1b28ee, 0x2a000a0c, 0x0e181904, 0x11121bee,   // sw.tr.id_422 pt.mt.un_530  gl.ga.is_332 tr.hu.ro_422
  0x04000c08, 0x0a0518ad, 0x0e001835, 0x18190a05,   // sv.fi.un_430 ga.fr.pt_643  ga.is.un_A90 pt.gl.ga_333
  // [16a0]
  0x09130d0c, 0x270f01a0, 0x170216a0, 0x55000104,   // ne.bh.hi_543 en.lv.gd_322  hr.da.sr_322 en.rw.un_320
  0x18211260, 0x180d2312, 0x3f080204, 0x215528a4,   // ur.fa.ar_664 ca.cs.ga_654  da.no.af_332 sw.rw.jw_433
  0x030602a0, 0x0c0306a7, 0x06000d0b, 0x21001c0d,   // da.de.nl_322 de.nl.sv_532  cs.de.un_520 id.jw.un_540
  0x07001108, 0x0c000612, 0x0d1716a7, 0x1f001304,   // ro.it.un_430 de.sv.un_640  hr.sr.cs_532 et.cy.un_320
  // [16b0]
  0x095320a0, 0x06001202, 0x016b11a4, 0x28002022,   // sq.ht.pl_322 hu.de.un_220  ro.ceb.en_433 sq.sw.un_870
  0x13290d11, 0x01000505, 0x08000405, 0x21000d04,   // cs.sl.et_653 fr.en.un_330  ru.uk.un_330 cs.jw.un_320
  0x1700110d, 0x53290d07, 0x3f0802ad, 0x1c0721a6,   // ro.sr.un_540 cs.sl.ht_432  da.no.af_643 jw.it.id_521
  0x170a07ad, 0x2118010c, 0x03060107, 0x21100904,   // bg.mk.sr_643 en.ga.jw_543  en.de.nl_432 pl.lt.jw_332
  // [16c0]
  0x170a0714, 0x0d0913ad, 0x21006419, 0x08001f09,   // bg.mk.sr_666 bh.hi.ne_643  lg.jw.un_750 cy.no.un_440
  0x2a536ea4, 0x230c0107, 0x1c211f02, 0x1c161ea4,   // blu.ht.mt_433 en.sv.ca_432  cy.jw.id_222 ms.hr.id_433
  0x2821640c, 0x0c000404, 0x23012904, 0x170904ee,   // lg.jw.sw_543 fi.sv.un_320  sl.en.ca_332 fi.pl.sr_422
  0x18010da0, 0x1c2107a7, 0x060c1205, 0x10070b08,   // cs.en.ga_322 it.jw.id_532  hu.sv.de_333 es.it.lt_443
  // [16d0]
  0x21076412, 0x060208a0, 0x640b2104, 0x09001c19,   // lg.it.jw_654 no.da.de_322  jw.es.lg_332 mr.hi.un_750
  0x102a6404, 0x0b0a0714, 0x09000712, 0x171625af,   // lg.mt.lt_332 it.pt.es_666  it.pl.un_640 eu.hr.sr_655
  0x11071709, 0x0900291a, 0x08002505, 0x1a5512ee,   // sr.bg.ro_444 sl.pl.un_760  eu.no.un_330 hu.rw.tl_422
  0x29000d1a, 0x2909100e, 0x03001007, 0x01001a02,   // cs.sl.un_760 lt.pl.sl_555  lt.nl.un_420 tl.en.un_220
  // [16e0]
  0x281b5507, 0x191064ad, 0x07041105, 0x130905a0,   // rw.tr.sw_432 lg.lt.gl_643  ro.ru.bg_333 fr.pl.et_322
  0x211907a4, 0x64211c02, 0x18002119, 0x181a6b60,   // it.gl.jw_433 id.jw.lg_222  fa.ar.un_750 ceb.tl.ga_664
  0x12645509, 0x01021fa0, 0x04132808, 0x0810070b,   // rw.lg.hu_444 cy.da.en_322  sw.et.fi_443 bg.be.uk_542
  0x1c002113, 0x07170404, 0x2d0d03a4, 0x040710a7,   // jw.id.un_650 ru.sr.bg_332  nl.cs.sk_433 be.bg.ru_532
  // [16f0]
  0x120c0609, 0x060c1207, 0x23002505, 0x1b2a16a4,   // de.sv.hu_444 hu.sv.de_432  eu.ca.un_330 hr.mt.tr_433
  0x11000804, 0x09130d55, 0x0a00200d, 0x2a0e1008,   // no.ro.un_320 ne.bh.hi_442  sq.pt.un_540 lt.is.mt_443
  0x11272511, 0x21000604, 0x21202508, 0x17070a60,   // eu.gd.ro_653 de.jw.un_320  eu.sq.jw_443 mk.bg.sr_664
  0x08000908, 0x010d230d, 0x28005514, 0x126b1a04,   // pl.no.un_430 ca.cs.en_554  rw.sw.un_660 tl.ceb.hu_332
  // [1700]
  0x1c000405, 0x25230ba9, 0x19002302, 0x2d001004,   // fi.id.un_330 es.ca.eu_544  ca.gl.un_220 lt.sk.un_320
  0x0f002907, 0x3f010704, 0x0a080255, 0x31001b20,   // sl.lv.un_420 it.en.af_332  da.no.pt_442 tr.az.un_850
  0x1b060ca7, 0x01070505, 0x04171155, 0x061f3f04,   // sv.de.tr_532 fr.it.en_333  ro.sr.ru_442 af.cy.de_332
  0x1c000904, 0x19060a04, 0x07040a08, 0x16041755,   // hi.mr.un_320 pt.de.gl_332  mk.ru.bg_443 sr.fi.hr_442
  // [1710]
  0x291016a0, 0x2a1a010c, 0x3f086ea0, 0x0f0420a4,   // hr.lt.sl_322 en.tl.mt_543  blu.no.af_322 sq.fi.lv_433
  0x17070a14, 0x10000f12, 0x1f081ba0, 0x08201b07,   // mk.bg.sr_666 lv.lt.un_640  tr.no.cy_322 tr.sq.no_432
  0x133f6ead, 0x31001c02, 0x110113a4, 0x28000414,   // blu.af.et_643 id.az.un_220  et.en.ro_433 fi.sw.un_660
  0x0b0a1902, 0x0400110e, 0x281c1b04, 0x0c001f0d,   // gl.pt.es_222 ro.ru.un_550  tr.id.sw_332 cy.sv.un_540
  // [1720]
  0x18001104, 0x190a0ba4, 0x6b000804, 0x0f041308,   // ro.ga.un_320 es.pt.gl_433  no.ceb.un_320 et.fi.lv_443
  0x08060aa7, 0x19000b04, 0x190a0805, 0x1f006b08,   // pt.de.no_532 es.gl.un_320  no.pt.gl_333 ceb.cy.un_430
  0x08001022, 0x1c090d60, 0x07040812, 0x033f1fee,   // be.uk.un_870 ne.hi.mr_664  uk.ru.bg_654 cy.af.nl_422
  0x25001222, 0x1800010c, 0x211101a0, 0x112023a4,   // hu.eu.un_870 en.ga.un_530  en.ro.jw_322 ca.sq.ro_433
  // [1730]
  0x3102080b, 0x0b1819a7, 0x2000100d, 0x23002014,   // no.da.az_542 gl.ga.es_532  lt.sq.un_540 sq.ca.un_660
  0x02311105, 0x0d0306ad, 0x0c000207, 0x0b001c04,   // ro.az.da_333 de.nl.cs_643  da.sv.un_420 id.es.un_320
  0x170a040c, 0x18080604, 0x02033f08, 0x0c002a1a,   // ru.mk.sr_543 de.no.ga_332  af.nl.da_443 mt.sv.un_760
  0x16250107, 0x03122a07, 0x29132a08, 0x2d0d02a0,   // en.eu.hr_432 mt.hu.nl_432  mt.et.sl_443 da.cs.sk_322
  // [1740]
  0x2b001704, 0x3f001902, 0x531811a0, 0x0407080c,   // sr.vi.un_320 gl.af.un_220  ro.ga.ht_322 uk.bg.ru_543
  0x311e1c05, 0x020c1ea0, 0x13091c0e, 0x07000814,   // id.ms.az_333 ms.sv.da_322  mr.hi.bh_555 uk.bg.un_660
  0x2a0e1308, 0x100925a4, 0x0e00280e, 0x07041704,   // et.is.mt_443 eu.pl.lt_433  sw.is.un_550 sr.ru.bg_332
  0x0e130f04, 0x211e2807, 0x180527ad, 0x18052713,   // lv.et.is_332 sw.ms.jw_432  gd.fr.ga_643 gd.fr.ga_665
  // [1750]
  0x0f0913ad, 0x07002904, 0x0300050d, 0x1827050c,   // et.pl.lv_643 sl.it.un_320  fr.nl.un_540 fr.gd.ga_543
  0x2a1006ac, 0x07001904, 0x2a640e5a, 0x2900120d,   // de.lt.mt_632 gl.it.un_320  is.lg.mt_553 hu.sl.un_540
  0x2827180c, 0x24000122, 0x1a212504, 0x0f090107,   // ga.gd.sw_543 iw.yi.un_870  eu.jw.tl_332 en.pl.lv_432
  0x123f0304, 0x53000507, 0x1805270c, 0x1c000d05,   // nl.af.hu_332 fr.ht.un_420  gd.fr.ga_543 ne.mr.un_330
  // [1760]
  0x1e001c36, 0x170a07af, 0x0500010d, 0x03000802,   // id.ms.un_AA0 bg.mk.sr_655  en.fr.un_540 no.nl.un_220
  0x0c082b04, 0x0a00110d, 0x55002807, 0x1e1c310c,   // vi.no.sv_332 ro.pt.un_540  sw.rw.un_420 az.id.ms_543
  0x2d160905, 0x0f000804, 0x170216ec, 0x101b1f11,   // pl.hr.sk_333 no.lv.un_320  hr.da.sr_644 cy.tr.lt_653
  0x17080a05, 0x17160fa9, 0x232718af, 0x07001119,   // mk.uk.sr_333 lv.hr.sr_544  ga.gd.ca_655 ro.bg.un_750
  // [1770]
  0x0d532d07, 0x111e1ca4, 0x10000f19, 0x1f00050b,   // sk.ht.cs_432 id.ms.ro_433  lv.lt.un_750 fr.cy.un_520
  0x02090ca4, 0x1e006402, 0x05001823, 0x1e1c05a4,   // sv.pl.da_433 lg.ms.un_220  ga.fr.un_880 fr.id.ms_433
  0x12042705, 0x1a316ea4, 0x171629ac, 0x181a01ee,   // gd.fi.hu_333 blu.az.tl_433  sl.hr.sr_632 en.tl.ga_422
  0x0800021b, 0x310a2b07, 0x12080255, 0x036b0912,   // da.no.un_770 vi.pt.az_432  da.no.hu_442 pl.ceb.nl_654
  // [1780]
  0x120d2004, 0x02000818, 0x091c13ad, 0x0a000702,   // sq.cs.hu_332 no.da.un_740  bh.mr.hi_643 bg.mk.un_220
  0x07080aee, 0x16001e04, 0x0e000502, 0x2a003107,   // mk.uk.bg_422 ms.hr.un_320  fr.is.un_220 az.mt.un_420
  0x0c000609, 0x06000802, 0x0f00200c, 0x09100805,   // de.sv.un_440 no.de.un_220  sq.lv.un_530 no.lt.pl_333
  0x091c0d55, 0x1800050c, 0x04001712, 0x2d001808,   // ne.mr.hi_442 fr.ga.un_530  sr.ru.un_640 ga.sk.un_430
  // [1790]
  0x532028a6, 0x3f000c07, 0x04100702, 0x2d001602,   // sw.sq.ht_521 sv.af.un_420  bg.be.ru_222 hr.sk.un_220
  0x02082307, 0x20642102, 0x1f002a08, 0x10170808,   // ca.no.da_432 jw.lg.sq_222  mt.cy.un_430 uk.sr.be_443
  0x091706a0, 0x030f2902, 0x1a002104, 0x64000607,   // de.sr.pl_322 sl.lv.nl_222  jw.tl.un_320 de.lg.un_420
  0x171007a0, 0x1f6b1a08, 0x11000b21, 0x0600120e,   // bg.be.sr_322 tl.ceb.cy_443  es.ro.un_860 hu.de.un_550
  // [17a0]
  0x2700210b, 0x0f2d0912, 0x12002019, 0x040a1705,   // jw.gd.un_520 pl.sk.lv_654  sq.hu.un_750 sr.mk.ru_333
  0x07002a04, 0x04001207, 0x060318ee, 0x20020cad,   // mt.it.un_320 hu.fi.un_420  ga.nl.de_422 sv.da.sq_643
  0x03000608, 0x09001012, 0x1a080204, 0x2b3f03a0,   // de.nl.un_430 lt.pl.un_640  da.no.tl_332 nl.af.vi_322
  0x27005302, 0x0c080204, 0x120e0107, 0x2a280504,   // ht.gd.un_220 da.no.sv_332  en.is.hu_432 fr.sw.mt_332
  // [17b0]
  0x01003f05, 0x21002307, 0x20080208, 0x08003f04,   // af.en.un_330 ca.jw.un_420  da.no.sq_443 af.no.un_320
  0x07001207, 0x08090213, 0x18000a02, 0x100811ee,   // hu.it.un_420 da.pl.no_665  pt.ga.un_220 ro.uk.be_422
  0x19230bee, 0x21012aee, 0x0b0a18ec, 0x2503060c,   // es.ca.gl_422 mt.en.jw_422  ga.pt.es_644 de.nl.eu_543
  0x03090d12, 0x1800211b, 0x061209ad, 0x18000b07,   // cs.pl.nl_654 fa.ar.un_770  pl.hu.de_643 es.ga.un_420
  // [17c0]
  0x2b2a01ad, 0x120c0807, 0x0a070409, 0x28001105,   // en.mt.vi_643 no.sv.hu_432  ru.bg.mk_444 ro.sw.un_330
  0x0d172d0b, 0x04100f12, 0x12180ba6, 0x0411100c,   // sk.sr.cs_542 lv.lt.fi_654  es.ga.hu_521 be.ro.ru_543
  0x08040755, 0x0900061a, 0x1f190b0e, 0x21101c04,   // bg.ru.uk_442 de.pl.un_760  es.gl.cy_555 id.lt.jw_332
  0x1f00090c, 0x12000c0d, 0x1b5321a4, 0x0f005304,   // pl.cy.un_530 sv.hu.un_540  jw.ht.tr_433 ht.lv.un_320
  // [17d0]
  0x17001107, 0x171016a4, 0x0a171011, 0x18000a1a,   // ro.sr.un_420 hr.lt.sr_433  be.sr.mk_653 pt.ga.un_760
  0x111a2bee, 0x1b002008, 0x0b00180e, 0x20532508,   // vi.tl.ro_422 sq.tr.un_430  ga.es.un_550 eu.ht.sq_443
  0x07002b04, 0x18000b04, 0x2b182811, 0x18000a0d,   // vi.it.un_320 es.ga.un_320  sw.ga.vi_653 pt.ga.un_540
  0x070a11ac, 0x2127180b, 0x18001721, 0x0a071712,   // ro.mk.bg_632 ga.gd.jw_542  sr.ga.un_860 sr.bg.mk_654
  // [17e0]
  0x04081013, 0x10170aad, 0x2a001819, 0x0a000722,   // be.uk.ru_665 mk.sr.be_643  ga.mt.un_750 bg.mk.un_870
  0x28210e12, 0x03000e11, 0x1229160c, 0x27001836,   // is.jw.sw_654 is.nl.un_630  hr.sl.hu_543 ga.gd.un_AA0
  0x06005512, 0x1a2113a0, 0x6b000b07, 0x03043f08,   // rw.de.un_640 et.jw.tl_322  es.ceb.un_420 af.fi.nl_443
  0x276b1fa6, 0x111810a4, 0x17291612, 0x10070aec,   // cy.ceb.gd_521 lt.ga.ro_433  hr.sl.sr_654 mk.bg.be_644
  // [17f0]
  0x06002a04, 0x0d001c18, 0x1f311eec, 0x531e3104,   // mt.de.un_320 mr.ne.un_740  ms.az.cy_644 az.ms.ht_332
  0x1800010d, 0x1b312808, 0x3f001f07, 0x280413ee,   // en.ga.un_540 sw.az.tr_443  cy.af.un_420 et.fi.sw_422
  0x0810040e, 0x0804070d, 0x03133fa4, 0x12002919,   // ru.be.uk_555 bg.ru.uk_554  af.et.nl_433 sl.hu.un_750
  0x2d000e08, 0x3f031313, 0x0c00091a, 0x13033f12,   // is.sk.un_430 et.nl.af_665  pl.sv.un_760 af.nl.et_654

  // [1800]
  0x0a0828a0, 0x040313a0, 0x11003f1a, 0x0e1f2704,   // sw.no.pt_322 et.nl.fi_322  af.ro.un_760 gd.cy.is_332
  0x0100240d, 0x64003f04, 0x081a02a7, 0x1908280d,   // yi.iw.un_540 af.lg.un_320  da.tl.no_532 sw.no.gl_554
  0x1f003f04, 0x070c0ea0, 0x12001820, 0x0c1264ad,   // af.cy.un_320 is.sv.it_322  ar.ur.un_850 lg.hu.sv_643
  0x17160f0e, 0x2a1264ee, 0x050801a4, 0x642a1ba4,   // lv.hr.sr_555 lg.hu.mt_422  en.no.fr_433 tr.mt.lg_433
  // [1810]
  0x6400552b, 0x530d2d11, 0x12002a0d, 0x17001008,   // rw.lg.un_980 sk.cs.ht_653  mt.hu.un_540 be.sr.un_430
  0x08001904, 0x5500640e, 0x04033f0c, 0x11000a14,   // gl.no.un_320 lg.rw.un_550  af.nl.fi_543 mk.ro.un_660
  0x042a0707, 0x0f000b21, 0x3f281307, 0x203f03a4,   // it.mt.fi_432 es.lv.un_860  et.sw.af_432 nl.af.sq_433
  0x20041308, 0x55642d07, 0x190b1eec, 0x0b002305,   // et.fi.sq_443 sk.lg.rw_432  ms.es.gl_644 ca.es.un_330
  // [1820]
  0x25002d04, 0x0b0a19ac, 0x166b64ee, 0x130929ac,   // sk.eu.un_320 gl.pt.es_632  lg.ceb.hr_422 sl.pl.et_632
  0x162d0d13, 0x29212807, 0x3f001f1a, 0x1700550d,   // cs.sk.hr_665 sw.jw.sl_432  cy.af.un_760 rw.sr.un_540
  0x1f0e27ac, 0x1013045a, 0x2a210ea4, 0x16172807,   // gd.is.cy_632 fi.et.lt_553  is.jw.mt_433 sw.sr.hr_432
  0x23000b21, 0x1f005302, 0x12072a04, 0x17040804,   // es.ca.un_860 ht.cy.un_220  mt.it.hu_332 uk.ru.sr_332
  // [1830]
  0x07165504, 0x6b2301ec, 0x13290ba0, 0x23131ba4,   // rw.hr.it_332 en.ca.ceb_644  es.sl.et_322 tr.et.ca_433
  0x2d0d2914, 0x0f001709, 0x55641308, 0x17071107,   // sl.cs.sk_666 sr.lv.un_440  et.lg.rw_443 ro.bg.sr_432
  0x25001219, 0x1c03280b, 0x0e003f04, 0x21001804,   // hu.eu.un_750 sw.nl.id_542  af.is.un_320 ar.fa.un_320
  0x2d6b0c0c, 0x19001807, 0x1c132807, 0x07101707,   // sv.ceb.sk_543 ga.gl.un_420  sw.et.id_432 sr.be.bg_432
  // [1840]
  0x0d002d1a, 0x2d0d1014, 0x12001702, 0x090b0402,   // sk.cs.un_760 lt.cs.sk_666  sr.hu.un_220 fi.es.pl_222
  0x20033f04, 0x28002108, 0x2d001007, 0x0a171112,   // af.nl.sq_332 jw.sw.un_430  lt.sk.un_420 ro.sr.mk_654
  0x29001714, 0x28002105, 0x28002b04, 0x0d002a02,   // sr.sl.un_660 jw.sw.un_330  vi.sw.un_320 mt.cs.un_220
  0x0500110d, 0x18190b08, 0x2d290da4, 0x27001813,   // ro.fr.un_540 es.gl.ga_443  cs.sl.sk_433 ga.gd.un_650
  // [1850]
  0x271e1c05, 0x29171614, 0x17002d04, 0x040810ec,   // id.ms.gd_333 hr.sr.sl_666  sk.sr.un_320 be.uk.ru_644
  0x64551204, 0x64002802, 0x091c0da9, 0x55006402,   // hu.rw.lg_332 sw.lg.un_220  ne.mr.hi_544 lg.rw.un_220
  0x07040807, 0x25006b04, 0x04160202, 0x0e171655,   // uk.ru.bg_432 ceb.eu.un_320  da.hr.fi_222 hr.sr.is_442
  0x02171602, 0x1b2518ec, 0x0f2a040c, 0x0a1011ee,   // hr.sr.da_222 ga.eu.tr_644  fi.mt.lv_543 ro.be.mk_422
  // [1860]
  0x08000c14, 0x18002705, 0x31001e04, 0x19002b04,   // sv.no.un_660 gd.ga.un_330  ms.az.un_320 vi.gl.un_320
  0x3f042a0d, 0x1e003122, 0x07012ba0, 0x27006402,   // mt.fi.af_554 az.ms.un_870  vi.en.it_322 lg.gd.un_220
  0x1c000f08, 0x1800280e, 0x06000c19, 0x6b3f5307,   // lv.id.un_430 sw.ga.un_550  sv.de.un_750 ht.af.ceb_432
  0x080a07ad, 0x122a640c, 0x2118120c, 0x1100070e,   // bg.mk.uk_643 lg.mt.hu_543  ur.ar.fa_543 bg.ro.un_550
  // [1870]
  0x20001b04, 0x0d010c02, 0x1c002107, 0x080711a7,   // tr.sq.un_320 sv.en.cs_222  jw.id.un_420 ro.bg.uk_532
  0x11002307, 0x08000c1b, 0x0f530455, 0x12003f07,   // ca.ro.un_420 sv.no.un_770  fi.ht.lv_442 af.hu.un_420
  0x170a0809, 0x0200082b, 0x53001f02, 0x0800122b,   // uk.mk.sr_444 no.da.un_980  cy.ht.un_220 hu.no.un_980
  0x251b1808, 0x23070107, 0x0408530c, 0x1f126ba0,   // ga.tr.eu_443 en.it.ca_432  ht.no.fi_543 ceb.hu.cy_322
  // [1880]
  0x2a00101b, 0x063f03a7, 0x0c171ea0, 0x0c00040b,   // lt.mt.un_770 nl.af.de_532  ms.sr.sv_322 fi.sv.un_520
  0x0d000c04, 0x201f100c, 0x110a01a4, 0x23021307,   // sv.cs.un_320 lt.cy.sq_543  en.pt.ro_433 et.da.ca_432
  0x170a070e, 0x20001b09, 0x25190bee, 0x18102aad,   // bg.mk.sr_555 tr.sq.un_440  es.gl.eu_422 mt.lt.ga_643
  0x100c3f0d, 0x0400070c, 0x07000102, 0x06001f21,   // af.sv.lt_554 bg.ru.un_530  en.it.un_220 cy.de.un_860
  // [1890]
  0x13000c07, 0x3f0e0813, 0x06033f13, 0x051f6e55,   // sv.et.un_420 no.is.af_665  af.nl.de_665 blu.cy.fr_442
  0x1c1e13a7, 0x23530107, 0x31000a02, 0x08041014,   // et.ms.id_532 en.ht.ca_432  pt.az.un_220 be.ru.uk_666
  0x16001a08, 0x0100241a, 0x092d0d02, 0x205511a4,   // tl.hr.un_430 yi.iw.un_760  cs.sk.pl_222 ro.rw.sq_433
  0x13001005, 0x170a0408, 0x216455af, 0x131264ee,   // lt.et.un_330 ru.mk.sr_443  rw.lg.jw_655 lg.hu.et_422
  // [18a0]
  0x060c135a, 0x0a190b0d, 0x09001608, 0x2d2b06a9,   // et.sv.de_553 es.gl.pt_554  hr.pl.un_430 de.vi.sk_544
  0x10040809, 0x551a6bad, 0x55286413, 0x3f6413a9,   // uk.ru.be_444 ceb.tl.rw_643  lg.sw.rw_665 et.lg.af_544
  0x17162d04, 0x2a033fa0, 0x0c020604, 0x2b003f02,   // sk.hr.sr_332 af.nl.mt_322  de.da.sv_332 af.vi.un_220
  0x20000612, 0x1a006b1a, 0x6b001e05, 0x13000413,   // de.sq.un_640 ceb.tl.un_760  ms.ceb.un_330 fi.et.un_650
  // [18b0]
  0x17162909, 0x12130ca7, 0x25530ca0, 0x1b256b0d,   // sl.hr.sr_444 sv.et.hu_532  sv.ht.eu_322 ceb.eu.tr_554
  0x110a1713, 0x53000a04, 0x070410a4, 0x06255507,   // sr.mk.ro_665 pt.ht.un_320  be.ru.bg_433 rw.eu.de_432
  0x0d000f08, 0x0a1707ee, 0x313f08ee, 0x2100551a,   // lv.cs.un_430 bg.sr.mk_422  no.af.az_422 rw.jw.un_760
  0x07100b08, 0x2d1a5307, 0x0c082909, 0x531f2aa7,   // es.lt.it_443 ht.tl.sk_432  sl.no.sv_444 mt.cy.ht_532
  // [18c0]
  0x050c2aa4, 0x556b1c07, 0x02131ca0, 0x04080a07,   // mt.sv.fr_433 id.ceb.rw_432  id.et.da_322 mk.uk.ru_432
  0x0a1708a0, 0x551e1c0d, 0x2a6b07ee, 0x0f060107,   // uk.sr.mk_322 id.ms.rw_554  it.ceb.mt_422 en.de.lv_432
  0x64105512, 0x641a6b0e, 0x281029a0, 0x1b1a6b07,   // rw.lt.lg_654 ceb.tl.lg_555  sl.lt.sw_322 ceb.tl.tr_432
  0x10171608, 0x17070aa0, 0x0b0710a4, 0x0409130c,   // hr.sr.lt_443 mk.bg.sr_322  lt.it.es_433 et.pl.fi_543
  // [18d0]
  0x0a170713, 0x102829a4, 0x290b07a7, 0x170a1007,   // bg.sr.mk_665 sl.sw.lt_433  it.es.sl_532 be.mk.sr_432
  0x17000808, 0x05002507, 0x040c0607, 0x0d006412,   // uk.sr.un_430 eu.fr.un_420  de.sv.fi_432 lg.cs.un_640
  0x2d2312a0, 0x080410af, 0x1c130904, 0x0d001809,   // hu.ca.sk_322 be.ru.uk_655  hi.bh.mr_332 ga.cs.un_440
  0x0b072907, 0x18122112, 0x2a000d02, 0x040813ad,   // sl.it.es_432 fa.ur.ar_654  cs.mt.un_220 et.no.fi_643
  // [18e0]
  0x0a00070c, 0x01291aa7, 0x100408a0, 0x1a5564a4,   // it.pt.un_530 tl.sl.en_532  uk.ru.be_322 lg.rw.tl_433
  0x28001a07, 0x06002a14, 0x2800060c, 0x1e006404,   // tl.sw.un_420 mt.de.un_660  de.sw.un_530 lg.ms.un_320
  0x080a17a0, 0x27002102, 0x07000412, 0x04001121,   // sr.mk.uk_322 jw.gd.un_220  ru.bg.un_640 ro.ru.un_860
  0x0d272da4, 0x1a3f010b, 0x53000808, 0x0e0304a4,   // sk.gd.cs_433 en.af.tl_542  no.ht.un_430 fi.nl.is_433
  // [18f0]
  0x0410080e, 0x082a07a9, 0x29002d22, 0x0f0c04a4,   // uk.be.ru_555 it.mt.no_544  sk.sl.un_870 fi.sv.lv_433
  0x64001219, 0x070c08a7, 0x2a041208, 0x0e080ca0,   // hu.lg.un_750 no.sv.it_532  hu.fi.mt_443 sv.no.is_322
  0x10080411, 0x55006404, 0x12002d13, 0x13000c09,   // ru.uk.be_653 lg.rw.un_320  sk.hu.un_650 sv.et.un_440
  0x102917a0, 0x07000808, 0x53073f04, 0x11070a12,   // sr.sl.lt_322 no.it.un_430  af.it.ht_332 mk.bg.ro_654
  // [1900]
  0x200c2a05, 0x2a000804, 0x21001811, 0x55281ca4,   // mt.sv.sq_333 no.mt.un_320  ar.fa.un_630 id.sw.rw_433
  0x2b001f04, 0x25000622, 0x040a0709, 0x1b5364a0,   // cy.vi.un_320 de.eu.un_870  bg.mk.ru_444 lg.ht.tr_322
  0x3f002504, 0x28000608, 0x170408af, 0x1a006b14,   // eu.af.un_320 de.sw.un_430  uk.ru.sr_655 ceb.tl.un_660
  0x1b00060e, 0x1b1a6ba4, 0x083f03a4, 0x08000104,   // de.tr.un_550 ceb.tl.tr_433  nl.af.no_433 en.no.un_320
  // [1910]
  0x1f112302, 0x0e3f0ca4, 0x2d002919, 0x250508a0,   // ca.ro.cy_222 sv.af.is_433  sl.sk.un_750 no.fr.eu_322
  0x121b0607, 0x11001304, 0x29002d14, 0x070a11a9,   // de.tr.hu_432 et.ro.un_320  sk.sl.un_660 ro.mk.bg_544
  0x060a2308, 0x2a0c04a4, 0x21310c07, 0x06000c05,   // ca.pt.de_443 fi.sv.mt_433  sv.az.jw_432 sv.de.un_330
  0x11001607, 0x1213045a, 0x210e06af, 0x0a071705,   // hr.ro.un_420 fi.et.hu_553  de.is.jw_655 sr.bg.mk_333
  // [1920]
  0x120625ad, 0x270418af, 0x21002512, 0x02000812,   // eu.de.hu_643 ga.fi.gd_655  eu.jw.un_640 no.da.un_640
  0x2a0f2814, 0x0c0807ad, 0x02100fa9, 0x1a27180c,   // sw.lv.mt_666 it.no.sv_643  lv.lt.da_544 ga.gd.tl_543
  0x023f030c, 0x55020812, 0x162d0607, 0x2d180d07,   // nl.af.da_543 no.da.rw_654  de.sk.hr_432 cs.ga.sk_432
  0x1a6b1007, 0x04031304, 0x12030604, 0x0a00171a,   // lt.ceb.tl_432 et.nl.fi_332  de.nl.hu_332 sr.mk.un_760
  // [1930]
  0x0c071a07, 0x0d063f0c, 0x0d1105a6, 0x03273f5a,   // tl.it.sv_432 af.de.cs_543  fr.ro.cs_521 af.gd.nl_553
  0x0c3f1f0c, 0x29121608, 0x23160708, 0x10120111,   // cy.af.sv_543 hr.hu.sl_443  it.hr.ca_443 en.hu.lt_653
  0x3f000f04, 0x55006413, 0x1b292dee, 0x290d2da0,   // lv.af.un_320 lg.rw.un_650  sk.sl.tr_422 sk.cs.sl_322
  0x1c00130c, 0x12001109, 0x27251108, 0x25310804,   // bh.mr.un_530 ro.hu.un_440  ro.eu.gd_443 no.az.eu_332
  // [1940]
  0x20250a08, 0x12005512, 0x172916a4, 0x23122905,   // pt.eu.sq_443 rw.hu.un_640  hr.sl.sr_433 sl.hu.ca_333
  0x28556404, 0x0a001904, 0x0e13060c, 0x0e002a1a,   // lg.rw.sw_332 gl.pt.un_320  de.et.is_543 mt.is.un_760
  0x55001114, 0x080206a4, 0x642555ad, 0x033f0502,   // ro.rw.un_660 de.da.no_433  rw.eu.lg_643 fr.af.nl_222
  0x060c08a4, 0x3f232a08, 0x0400130c, 0x2100280c,   // no.sv.de_433 mt.ca.af_443  et.fi.un_530 sw.jw.un_530
  // [1950]
  0x17110455, 0x2a55640c, 0x31002009, 0x02000822,   // ru.ro.sr_442 lg.rw.mt_543  sq.az.un_440 no.da.un_870
  0x07001004, 0x251655ee, 0x04170804, 0x551625a4,   // be.bg.un_320 rw.hr.eu_422  uk.sr.ru_332 eu.hr.rw_433
  0x1000081a, 0x07001f13, 0x070417a4, 0x0d092d5a,   // uk.be.un_760 cy.it.un_650  sr.ru.bg_433 sk.pl.cs_553
  0x04000709, 0x16005507, 0x0a0411ad, 0x1e002107,   // bg.ru.un_440 rw.hr.un_420  ro.ru.mk_643 jw.ms.un_420
  // [1960]
  0x11040713, 0x08030202, 0x0807170c, 0x1e001f21,   // bg.ru.ro_665 da.nl.no_222  sr.bg.uk_543 cy.ms.un_860
  0x04001708, 0x1f1e1ca9, 0x020c23ec, 0x2a002813,   // sr.ru.un_430 id.ms.cy_544  ca.sv.da_644 sw.mt.un_650
  0x18002d12, 0x21101fa9, 0x1c002b07, 0x130b01a0,   // sk.ga.un_640 cy.lt.jw_544  vi.id.un_420 en.es.et_322
  0x08041055, 0x1b172905, 0x06281fad, 0x1e1c10af,   // be.ru.uk_442 sl.sr.tr_333  cy.sw.de_643 lt.id.ms_655
  // [1970]
  0x111a01a0, 0x08070a5a, 0x1e1c10ec, 0x00001f2d,   // en.tl.ro_322 mk.bg.uk_553  lt.id.ms_644 cy.un.un_A00
  0x201b3112, 0x201a5505, 0x0c64200b, 0x16291707,   // az.tr.sq_654 rw.tl.sq_333  sq.lg.sv_542 sr.sl.hr_432
  0x27000202, 0x23001108, 0x27160d55, 0x311a280c,   // da.gd.un_220 ro.ca.un_430  cs.hr.gd_442 sw.tl.az_543
  0x2118120e, 0x1a001f1b, 0x033f0208, 0x0c006402,   // ur.ar.fa_555 cy.tl.un_770  da.af.nl_443 lg.sv.un_220
  // [1980]
  0x09162907, 0x31172908, 0x5500280c, 0x25101107,   // sl.hr.pl_432 sl.sr.az_443  sw.rw.un_530 ro.lt.eu_432
  0x190e1212, 0x1a00281a, 0x0f1328a4, 0x101a130c,   // hu.is.gl_654 sw.tl.un_760  sw.et.lv_433 et.tl.lt_543
  0x0a0704a7, 0x211e1f11, 0x231f1008, 0x07171604,   // ru.bg.mk_532 cy.ms.jw_653  lt.cy.ca_443 hr.sr.it_332
  0x29001307, 0x02000c04, 0x551a6b12, 0x1c1309a9,   // et.sl.un_420 sv.da.un_320  ceb.tl.rw_654 hi.bh.mr_544
  // [1990]
  0x25101f0c, 0x0b0a55a0, 0x0d033fa4, 0x10251f07,   // cy.lt.eu_543 rw.pt.es_322  af.nl.cs_433 cy.eu.lt_432
  0x13006413, 0x08003f05, 0x23110a07, 0x3f282104,   // lg.et.un_650 af.no.un_330  pt.ro.ca_432 jw.sw.af_332
  0x25006402, 0x170411ee, 0x07170412, 0x071c1ea0,   // lg.eu.un_220 ro.ru.sr_422  ru.sr.bg_654 ms.id.it_322
  0x10530aa0, 0x04070804, 0x105509a4, 0x18000713,   // pt.ht.lt_322 uk.bg.ru_332  pl.rw.lt_433 it.ga.un_650
  // [19a0]
  0x1f530902, 0x010c1104, 0x07000307, 0x1b1328a4,   // pl.ht.cy_222 ro.sv.en_332  nl.it.un_420 sw.et.tr_433
  0x28000207, 0x6b285504, 0x13000108, 0x55101a0c,   // da.sw.un_420 rw.sw.ceb_332  en.et.un_430 tl.lt.rw_543
  0x640813a4, 0x10000905, 0x01000705, 0x3f062a0b,   // et.no.lg_433 pl.lt.un_330  it.en.un_330 mt.de.af_542
  0x0900100e, 0x2300210c, 0x09000f04, 0x100a0802,   // lt.pl.un_550 jw.ca.un_530  lv.pl.un_320 uk.mk.be_222
  // [19b0]
  0x181221ac, 0x033f1f0e, 0x06080202, 0x0a00110e,   // fa.ur.ar_632 cy.af.nl_555  da.no.de_222 ro.mk.un_550
  0x0e000202, 0x11000304, 0x08170a05, 0x130d09af,   // da.is.un_220 nl.ro.un_320  mk.sr.uk_333 hi.ne.bh_655
  0x1f00030c, 0x2a001307, 0x1e1c64ec, 0x1e062a07,   // nl.cy.un_530 et.mt.un_420  lg.id.ms_644 mt.de.ms_432
  0x190a050c, 0x1c641e12, 0x2d171604, 0x31171604,   // fr.pt.gl_543 ms.lg.id_654  hr.sr.sk_332 hr.sr.az_332
  // [19c0]
  0x1e1c64a9, 0x3f000309, 0x64551c07, 0x0a1107a4,   // lg.id.ms_544 nl.af.un_440  id.rw.lg_432 bg.ro.mk_433
  0x211a5505, 0x0f0c0209, 0x00002824, 0x64005523,   // rw.tl.jw_333 da.sv.lv_444  sw.un.un_900 rw.lg.un_880
  0x2a6e08a0, 0x120206a0, 0x1a556b55, 0x060403ec,   // no.blu.mt_322 de.da.hu_322  ceb.rw.tl_442 nl.fi.de_644
  0x551e1c14, 0x29001607, 0x2000250c, 0x062502ee,   // id.ms.rw_666 hr.sl.un_420  eu.sq.un_530 da.eu.de_422
  // [19d0]
  0x0c092a07, 0x09645512, 0x05003f08, 0x1e1c55a4,   // mt.pl.sv_432 rw.lg.pl_654  af.fr.un_430 rw.id.ms_433
  0x1e1c5509, 0x2d0d01ee, 0x2d556455, 0x070a01a4,   // rw.id.ms_444 en.cs.sk_422  lg.rw.sk_442 en.pt.it_433
  0x020e0c07, 0x170a11ac, 0x2855090c, 0x1c090d13,   // sv.is.da_432 ro.mk.sr_632  pl.rw.sw_543 ne.hi.mr_665
  0x0e130408, 0x55001e08, 0x041b310d, 0x1e1c55af,   // fi.et.is_443 ms.rw.un_430  az.tr.fi_554 rw.id.ms_655
  // [19e0]
  0x531b3112, 0x1e641ca9, 0x07111705, 0x23001e1a,   // az.tr.ht_654 id.lg.ms_544  sr.ro.bg_333 ms.ca.un_760
  0x160413a0, 0x55006b11, 0x31130607, 0x122010a7,   // et.fi.hr_322 ceb.rw.un_630  de.et.az_432 lt.sq.hu_532
  0x1f001221, 0x066b1a07, 0x020608ee, 0x106b0308,   // hu.cy.un_860 tl.ceb.de_432  no.de.da_422 nl.ceb.lt_443
  0x6b0501a4, 0x11211f08, 0x0c00060d, 0x64100405,   // en.fr.ceb_433 cy.jw.ro_443  de.sv.un_540 fi.lt.lg_333
  // [19f0]
  0x0a071105, 0x211c3104, 0x19001602, 0x21000b08,   // ro.bg.mk_333 az.id.jw_332  hr.gl.un_220 es.jw.un_430
  0x20001f02, 0x31001f08, 0x292d0d02, 0x101f3fad,   // cy.sq.un_220 cy.az.un_430  cs.sk.sl_222 af.cy.lt_643
  0x100a0709, 0x0c1b310c, 0x080411ee, 0x130e2702,   // bg.mk.be_444 az.tr.sv_543  ro.ru.uk_422 gd.is.et_222
  0x1c081ea9, 0x1800270c, 0x310153ee, 0x17160f07,   // ms.no.id_544 gd.ga.un_530  ht.en.az_422 lv.hr.sr_432
  // [1a00]
  0x28311bee, 0x25055304, 0x1a126bec, 0x19002704,   // tr.az.sw_422 ht.fr.eu_332  ceb.hu.tl_644 gd.gl.un_320
  0x04130c02, 0x2d122aa4, 0x0c00040e, 0x18002709,   // sv.et.fi_222 mt.hu.sk_433  fi.sv.un_550 gd.ga.un_440
  0x2900130d, 0x07100804, 0x060a1ba4, 0x0a070804,   // et.sl.un_540 uk.be.bg_332  tr.pt.de_433 uk.bg.mk_332
  0x09000d02, 0x29006e07, 0x11001019, 0x16292d55,   // cs.pl.un_220 blu.sl.un_420  be.ro.un_750 sk.sl.hr_442
  // [1a10]
  0x2a001f13, 0x212a180c, 0x07000a07, 0x0b001f02,   // cy.mt.un_650 ga.mt.jw_543  mk.bg.un_420 cy.es.un_220
  0x2704180c, 0x08001009, 0x09061f0d, 0x0c001318,   // ga.fi.gd_543 be.uk.un_440  cy.de.pl_554 et.sv.un_740
  0x11081705, 0x120d09a9, 0x20311b0d, 0x0e1b315a,   // sr.uk.ro_333 pl.cs.hu_544  tr.az.sq_554 az.tr.is_553
  0x0a1707a4, 0x04110712, 0x111e1c09, 0x0c23010c,   // bg.sr.mk_433 bg.ro.ru_654  id.ms.ro_444 en.ca.sv_543
  // [1a20]
  0x0a230607, 0x0900200e, 0x53001a02, 0x29091707,   // de.ca.pt_432 sq.pl.un_550  tl.ht.un_220 sr.pl.sl_432
  0x0000112d, 0x06005304, 0x09290da4, 0x0d201155,   // ro.un.un_A00 ht.de.un_320  cs.sl.pl_433 ro.sq.cs_442
  0x03080607, 0x170105af, 0x192511ad, 0x53050aa0,   // de.no.nl_432 fr.en.sr_655  ro.eu.gl_643 pt.fr.ht_322
  0x0a2308a9, 0x1b6b2805, 0x29001708, 0x2d0d11a4,   // no.ca.pt_544 sw.ceb.tr_333  sr.sl.un_430 ro.cs.sk_433
  // [1a30]
  0x291b0d07, 0x0a001722, 0x022a070c, 0x0a1711af,   // cs.tr.sl_432 sr.mk.un_870  it.mt.da_543 ro.sr.mk_655
  0x6b2707ad, 0x060521a0, 0x092d0dad, 0x3f081c07,   // it.gd.ceb_643 jw.fr.de_322  cs.sk.pl_643 id.no.af_432
  0x03060cee, 0x17040809, 0x171116ec, 0x181927ee,   // sv.de.nl_422 uk.ru.sr_444  hr.ro.sr_644 gd.gl.ga_422
  0x202a2307, 0x0b292d07, 0x023f0c04, 0x10181b04,   // ca.mt.sq_432 sk.sl.es_432  sv.af.da_332 tr.ga.lt_332
  // [1a40]
  0x1f0e18ee, 0x010811a0, 0x02000c0c, 0x17000304,   // ga.is.cy_422 ro.no.en_322  sv.da.un_530 nl.sr.un_320
  0x1e001f2a, 0x030c0255, 0x07060202, 0x06002504,   // cy.ms.un_970 da.sv.nl_442  da.de.it_222 eu.de.un_320
  0x01002d02, 0x17070412, 0x020c0e02, 0x0c023f07,   // sk.en.un_220 ru.bg.sr_654  is.sv.da_222 af.da.sv_432
  0x16172908, 0x080c12a9, 0x251827af, 0x3f0306ec,   // sl.sr.hr_443 hu.sv.no_544  gd.ga.eu_655 de.nl.af_644
  // [1a50]
  0x290d1bad, 0x05012aa4, 0x0d2b1102, 0x230112a0,   // tr.cs.sl_643 mt.en.fr_433  ro.vi.cs_222 hu.en.ca_322
  0x09251113, 0x17000a09, 0x0a071714, 0x11002d08,   // ro.eu.pl_665 mk.sr.un_440  sr.bg.mk_666 sk.ro.un_430
  0x6b0501ad, 0x3f1f0904, 0x07000813, 0x02050602,   // en.fr.ceb_643 pl.cy.af_332  uk.bg.un_650 de.fr.da_222
  0x0d0501a9, 0x640e23a0, 0x07001823, 0x3f030f0c,   // en.fr.cs_544 ca.is.lg_322  ga.it.un_880 lv.nl.af_543
  // [1a60]
  0x29160dad, 0x190b110c, 0x16041107, 0x2d006e0d,   // cs.hr.sl_643 ro.es.gl_543  ro.fi.hr_432 blu.sk.un_540
  0x29002302, 0x060c03a0, 0x1b006421, 0x25002705,   // ca.sl.un_220 nl.sv.de_322  lg.tr.un_860 gd.eu.un_330
  0x31001b21, 0x1600210d, 0x3f040307, 0x551e2108,   // tr.az.un_860 jw.hr.un_540  nl.fi.af_432 jw.ms.rw_443
  0x0b2a19a7, 0x081004af, 0x0a0710af, 0x19001804,   // gl.mt.es_532 ru.be.uk_655  be.bg.mk_655 ga.gl.un_320
  // [1a70]
  0x03006405, 0x0000191c, 0x1100041a, 0x16002802,   // lg.nl.un_330 gl.un.un_800  ru.ro.un_760 sw.hr.un_220
  0x02170655, 0x0d0913ec, 0x1100081a, 0x17110705,   // de.sr.da_442 bh.hi.ne_644  uk.ro.un_760 bg.ro.sr_333
  0x10002d12, 0x211b03a0, 0x091b1a08, 0x16000502,   // sk.lt.un_640 nl.tr.jw_322  tl.tr.pl_443 fr.hr.un_220
  0x121821a9, 0x0a0417af, 0x0f000921, 0x16002004,   // fa.ar.ur_544 sr.ru.mk_655  pl.lv.un_860 sq.hr.un_320
  // [1a80]
  0x0d1716ec, 0x0f0209ee, 0x1007110c, 0x09002d19,   // hr.sr.cs_644 pl.da.lv_422  ro.bg.be_543 sk.pl.un_750
  0x53000b04, 0x041713af, 0x0a0e1255, 0x3f1708a4,   // es.ht.un_320 et.sr.fi_655  hu.is.pt_442 no.sr.af_433
  0x0d102a07, 0x3f001a04, 0x2d001702, 0x1a0d25ee,   // mt.lt.cs_432 tl.af.un_320  sr.sk.un_220 eu.cs.tl_422
  0x2b002d04, 0x040c0e07, 0x041710a0, 0x13280f04,   // sk.vi.un_320 is.sv.fi_432  be.sr.ru_322 lv.sw.et_332
  // [1a90]
  0x0a101707, 0x16002a12, 0x10090f08, 0x28121b04,   // sr.be.mk_432 mt.hr.un_640  lv.pl.lt_443 tr.hu.sw_332
  0x07130411, 0x21001202, 0x291707a4, 0x0e2016ee,   // fi.et.it_653 ur.fa.un_220  it.sr.sl_433 hr.sq.is_422
  0x05005308, 0x1a005304, 0x08040e0c, 0x16292d04,   // ht.fr.un_430 ht.tl.un_320  is.fi.no_543 sk.sl.hr_332
  0x130427a0, 0x53042107, 0x0e000818, 0x0e642a0d,   // gd.fi.et_322 jw.fi.ht_432  no.is.un_740 mt.lg.is_554
  // [1aa0]
  0x6b251ca4, 0x041711a0, 0x1c0e08a0, 0x211304ee,   // id.eu.ceb_433 ro.sr.ru_322  no.is.id_322 fi.et.jw_422
  0x0c063104, 0x171609a0, 0x2100122b, 0x1f27010c,   // az.de.sv_332 pl.hr.sr_322  ur.fa.un_980 en.gd.cy_543
  0x2d0d16ec, 0x3f0801a9, 0x13040ea0, 0x0a0704a0,   // hr.cs.sk_644 en.no.af_544  is.fi.et_322 ru.bg.mk_322
  0x17131604, 0x0c130e5a, 0x552b1a04, 0x100f1e0c,   // hr.et.sr_332 is.et.sv_553  tl.vi.rw_332 ms.lv.lt_543
  // [1ab0]
  0x2d0d2aac, 0x090d2d0b, 0x0d1c0960, 0x120c1bee,   // mt.cs.sk_632 sk.cs.pl_542  hi.mr.ne_664 tr.sv.hu_422
  0x171104a4, 0x07002504, 0x03000507, 0x04000c0d,   // ru.ro.sr_433 eu.it.un_320  fr.nl.un_420 sv.fi.un_540
  0x07002305, 0x0600180c, 0x1f120e14, 0x0c03080c,   // ca.it.un_330 ga.de.un_530  is.hu.cy_666 no.nl.sv_543
  0x171610a4, 0x12211802, 0x01002422, 0x0e101ba4,   // lt.hr.sr_433 ar.fa.ur_222  yi.iw.un_870 tr.lt.is_433
  // [1ac0]
  0x1925040c, 0x0c000e0b, 0x2a0721ad, 0x3f211fa9,   // fi.eu.gl_543 is.sv.un_520  jw.it.mt_643 cy.jw.af_544
  0x17162d05, 0x10000413, 0x2b00271a, 0x31170bee,   // sk.hr.sr_333 ru.be.un_650  gd.vi.un_760 es.sr.az_422
  0x1f002908, 0x12000c13, 0x08011907, 0x23111faf,   // sl.cy.un_430 sv.hu.un_650  gl.en.no_432 cy.ro.ca_655
  0x27002b21, 0x040a11a9, 0x55250e0c, 0x0d1716ad,   // vi.gd.un_860 ro.mk.ru_544  is.eu.rw_543 hr.sr.cs_643
  // [1ad0]
  0x090d1c0b, 0x27002b14, 0x0b0a08a4, 0x03001204,   // mr.ne.hi_542 vi.gd.un_660  no.pt.es_433 hu.nl.un_320
  0x10000402, 0x20230ea6, 0x030655a9, 0x3f0a0805,   // ru.be.un_220 is.ca.sq_521  rw.de.nl_544 no.pt.af_333
  0x64001319, 0x06005508, 0x10171604, 0x0a000104,   // et.lg.un_750 rw.de.un_430  hr.sr.lt_332 en.pt.un_320
  0x1a645508, 0x191b11ee, 0x170a0807, 0x0d190204,   // rw.lg.tl_443 ro.tr.gl_422  uk.mk.sr_432 da.gl.cs_332
  // [1ae0]
  0x6428550d, 0x0b0d1907, 0x2b001104, 0x23001909,   // rw.sw.lg_554 gl.cs.es_432  ro.vi.un_320 gl.ca.un_440
  0x190501ec, 0x080602a0, 0x28251f0d, 0x1f2d19a4,   // en.fr.gl_644 da.de.no_322  cy.eu.sw_554 gl.sk.cy_433
  0x092855ad, 0x09000d1b, 0x28172007, 0x03001212,   // rw.sw.pl_643 ne.hi.un_770  sq.sr.sw_432 hu.nl.un_640
  0x21001108, 0x18071fee, 0x0e000c0d, 0x0c0e1fa7,   // ro.jw.un_430 cy.it.ga_422  sv.is.un_540 cy.is.sv_532
  // [1af0]
  0x12000921, 0x066455a4, 0x1a001b04, 0x0e0f17a0,   // pl.hu.un_860 rw.lg.de_433  tr.tl.un_320 sr.lv.is_322
  0x063f550c, 0x2d002108, 0x0d13095a, 0x016b1107,   // rw.af.de_543 jw.sk.un_430  hi.bh.ne_553 ro.ceb.en_432
  0x21001c07, 0x033f0aac, 0x04005319, 0x533f01a0,   // id.jw.un_420 pt.af.nl_632  ht.fi.un_750 en.af.ht_322
  0x0500531a, 0x093f21a0, 0x050a53ad, 0x2b0603a0,   // ht.fr.un_760 jw.af.pl_322  ht.pt.fr_643 nl.de.vi_322
  // [1b00]
  0x20000108, 0x13060c04, 0x5300052b, 0x53010aa0,   // en.sq.un_430 sv.de.et_332  fr.ht.un_980 pt.en.ht_322
  0x060c08a0, 0x19251fee, 0x53080204, 0x05005321,   // no.sv.de_322 cy.eu.gl_422  da.no.ht_332 ht.fr.un_860
  0x2900210c, 0x17080a08, 0x070804a4, 0x29033f07,   // jw.sl.un_530 mk.uk.sr_443  ru.uk.bg_433 af.nl.sl_432
  0x0f172d14, 0x210c2aec, 0x642d0d04, 0x1e1c2114,   // sk.sr.lv_666 mt.sv.jw_644  cs.sk.lg_332 jw.id.ms_666
  // [1b10]
  0x166b100c, 0x03050407, 0x530d0514, 0x53000523,   // lt.ceb.hr_543 fi.fr.nl_432  fr.cs.ht_666 fr.ht.un_880
  0x0c6b550d, 0x12182113, 0x1c5305a0, 0x170411a0,   // rw.ceb.sv_554 fa.ar.ur_665  fr.ht.id_322 ro.ru.sr_322
  0x1c00210d, 0x20001207, 0x2d170f07, 0x291606ec,   // jw.id.un_540 hu.sq.un_420  lv.sr.sk_432 de.hr.sl_644
  0x3f006b07, 0x1f033f09, 0x3f001c04, 0x2a6e1e04,   // ceb.af.un_420 af.nl.cy_444  id.af.un_320 ms.blu.mt_332
  // [1b20]
  0x2112180d, 0x200e060c, 0x16002107, 0x016b0d02,   // ar.ur.fa_554 de.is.sq_543  jw.hr.un_420 cs.ceb.en_222
  0x091f0e07, 0x0c003f07, 0x2a001621, 0x12001307,   // is.cy.pl_432 af.sv.un_420  hr.mt.un_860 et.hu.un_420
  0x1004050c, 0x10002d13, 0x16000804, 0x0d2108a0,   // fr.fi.lt_543 sk.lt.un_650  no.hr.un_320 no.jw.cs_322
  0x20070412, 0x551a1604, 0x170711ee, 0x020c0812,   // fi.it.sq_654 hr.tl.rw_332  ro.bg.sr_422 no.sv.da_654
  // [1b30]
  0x29001b11, 0x12211814, 0x200d3fee, 0x1b081307,   // tr.sl.un_630 ar.fa.ur_666  af.cs.sq_422 et.no.tr_432
  0x081304a4, 0x04070860, 0x060413a4, 0x13003f04,   // fi.et.no_433 uk.bg.ru_664  et.fi.de_433 af.et.un_320
  0x0f006e04, 0x13000804, 0x08101705, 0x1700112a,   // blu.lv.un_320 no.et.un_320  sr.be.uk_333 ro.sr.un_970
  0x09130813, 0x08190aee, 0x25080ea0, 0x55000607,   // no.et.pl_665 pt.gl.no_422  is.no.eu_322 de.rw.un_420
  // [1b40]
  0x060e080e, 0x080c0260, 0x06002705, 0x04001312,   // no.is.de_555 da.sv.no_664  gd.de.un_330 et.fi.un_640
  0x07040a0e, 0x08050405, 0x18000419, 0x13001c0b,   // mk.ru.bg_555 fi.fr.no_333  fi.ga.un_750 mr.bh.un_520
  0x10070411, 0x05000413, 0x06003f04, 0x0e000c04,   // ru.bg.be_653 fi.fr.un_650  af.de.un_320 sv.is.un_320
  0x290f1bad, 0x1800040d, 0x01311b0c, 0x040811ad,   // tr.lv.sl_643 fi.ga.un_540  tr.az.en_543 ro.uk.ru_643
  // [1b50]
  0x08000704, 0x2b0504ad, 0x17070402, 0x0306130c,   // bg.uk.un_320 fi.fr.vi_643  ru.bg.sr_222 et.de.nl_543
  0x3f0208a0, 0x16051712, 0x1b1306a4, 0x05002704,   // no.da.af_322 sr.fr.hr_654  de.et.tr_433 gd.fr.un_320
  0x170f16a9, 0x08000623, 0x270f0605, 0x01000e07,   // hr.lv.sr_544 de.no.un_880  de.lv.gd_333 is.en.un_420
  0x05000412, 0x07170a12, 0x311b0ead, 0x0c060807,   // fi.fr.un_640 mk.sr.bg_654  is.tr.az_643 no.de.sv_432
  // [1b60]
  0x041008a9, 0x0c020f07, 0x2704170c, 0x170411af,   // uk.be.ru_544 lv.da.sv_432  sr.fi.gd_543 ro.ru.sr_655
  0x6e000912, 0x28041307, 0x092d0d13, 0x2b002109,   // pl.blu.un_640 et.fi.sw_432  cs.sk.pl_665 jw.vi.un_440
  0x55002804, 0x2a000e0d, 0x00000937, 0x235321a0,   // sw.rw.un_320 is.mt.un_540  hi.un.un_B00 jw.ht.ca_322
  0x552d10a0, 0x1f001319, 0x07000823, 0x17002507,   // lt.sk.rw_322 et.cy.un_750  uk.bg.un_880 eu.sr.un_420
  // [1b70]
  0x0800110d, 0x25005304, 0x1f002a0e, 0x23000b09,   // ro.uk.un_540 ht.eu.un_320  mt.cy.un_550 es.ca.un_440
  0x102a0e12, 0x53002b0e, 0x16002d05, 0x01081bee,   // is.mt.lt_654 vi.ht.un_550  sk.hr.un_330 tr.no.en_422
  0x0a001721, 0x040817a0, 0x0600040c, 0x28003f02,   // sr.mk.un_860 sr.uk.ru_322  fi.de.un_530 af.sw.un_220
  0x212718ad, 0x023f0309, 0x182827ec, 0x2d001b05,   // ga.gd.jw_643 nl.af.da_444  gd.sw.ga_644 tr.sk.un_330
  // [1b80]
  0x16291b55, 0x07170aee, 0x1a006b0c, 0x171011ad,   // tr.sl.hr_442 mk.sr.bg_422  ceb.tl.un_530 ro.be.sr_643
  0x09001002, 0x213f03ec, 0x09171604, 0x18006404,   // lt.pl.un_220 nl.af.jw_644  hr.sr.pl_332 lg.ga.un_320
  0x1700290d, 0x2d002909, 0x0f001705, 0x1031110c,   // sl.sr.un_540 sl.sk.un_440  sr.lv.un_330 ro.az.lt_543
  0x110a2da0, 0x2917160b, 0x170a04ee, 0x1c001308,   // sk.pt.ro_322 hr.sr.sl_542  ru.mk.sr_422 bh.mr.un_430
  // [1b90]
  0x1627180d, 0x180e1fa7, 0x2d1b2905, 0x2800080d,   // ga.gd.hr_554 cy.is.ga_532  sl.tr.sk_333 no.sw.un_540
  0x09000507, 0x12000312, 0x080407a0, 0x162d0d02,   // fr.pl.un_420 nl.hu.un_640  bg.ru.uk_322 cs.sk.hr_222
  0x12290312, 0x02000807, 0x2d1129a7, 0x161b2da0,   // nl.sl.hu_654 no.da.un_420  sl.ro.sk_532 sk.tr.hr_322
  0x530a1108, 0x20002a13, 0x0e120ca9, 0x01001f05,   // ro.pt.ht_443 mt.sq.un_650  sv.hu.is_544 cy.en.un_330
  // [1ba0]
  0x03002019, 0x07100805, 0x29000405, 0x04000c04,   // sq.nl.un_750 uk.be.bg_333  fi.sl.un_330 sv.fi.un_320
  0x1300042b, 0x2a051aee, 0x1f001c04, 0x0a002323,   // fi.et.un_980 tl.fr.mt_422  id.cy.un_320 ca.pt.un_880
  0x09011fa4, 0x020c0ea4, 0x23050bee, 0x2b001e08,   // cy.en.pl_433 is.sv.da_433  es.fr.ca_422 ms.vi.un_430
  0x2a000c05, 0x041008ec, 0x01000b04, 0x1e1c0c02,   // sv.mt.un_330 uk.be.ru_644  es.en.un_320 sv.id.ms_222
  // [1bb0]
  0x180c0611, 0x11000414, 0x17160a02, 0x03000607,   // de.sv.ga_653 ru.ro.un_660  pt.hr.sr_222 de.nl.un_420
  0x0c000822, 0x090d1c12, 0x3100530e, 0x6b3f0260,   // no.sv.un_870 mr.ne.hi_654  ht.az.un_550 da.af.ceb_664
  0x29000313, 0x09001007, 0x28002004, 0x210b070d,   // nl.sl.un_650 lt.pl.un_420  sq.sw.un_320 it.es.jw_554
  0x271b2302, 0x21000105, 0x2b00201a, 0x53000713,   // ca.tr.gd_222 en.jw.un_330  sq.vi.un_760 it.ht.un_650
  // [1bc0]
  0x0a071104, 0x11101904, 0x0a0408ec, 0x1e2a2007,   // ro.bg.mk_332 gl.lt.ro_332  uk.ru.mk_644 sq.mt.ms_432
  0x100a08a0, 0x01000204, 0x1c0d0908, 0x19110f0c,   // uk.mk.be_322 da.en.un_320  hi.ne.mr_443 lv.ro.gl_543
  0x19000702, 0x3f000607, 0x07000819, 0x080410a7,   // it.gl.un_220 de.af.un_420  uk.bg.un_750 be.ru.uk_532
  0x06021ea0, 0x03000508, 0x6b5321a4, 0x09125307,   // ms.da.de_322 fr.nl.un_430  jw.ht.ceb_433 ht.hu.pl_432
  // [1bd0]
  0x08021214, 0x03080407, 0x071704ec, 0x0c080207,   // hu.da.no_666 fi.no.nl_432  ru.sr.bg_644 da.no.sv_432
  0x020312a9, 0x0b0a0702, 0x3f0c10a7, 0x18005504,   // hu.nl.da_544 it.pt.es_222  lt.sv.af_532 rw.ga.un_320
  0x17162902, 0x01001f19, 0x10000808, 0x532a0707,   // sl.hr.sr_222 cy.en.un_750  no.lt.un_430 it.mt.ht_432
  0x04001112, 0x090d1c09, 0x111b12ad, 0x04080708,   // ro.fi.un_640 mr.ne.hi_444  hu.tr.ro_643 bg.uk.ru_443
  // [1be0]
  0x080c0207, 0x0e0c0607, 0x10000e04, 0x16001b05,   // da.sv.no_432 de.sv.is_432  is.lt.un_320 tr.hr.un_330
  0x01001107, 0x3f002008, 0x29172daf, 0x042155ad,   // ro.en.un_420 sq.af.un_430  sk.sr.sl_655 rw.jw.fi_643
  0x130411ad, 0x0a00190d, 0x0a190b04, 0x11000404,   // ro.fi.et_643 gl.pt.un_540  es.gl.pt_332 fi.ro.un_320
  0x0a001102, 0x06000d1a, 0x64002318, 0x12132009,   // ro.pt.un_220 cs.de.un_760  ca.lg.un_740 sq.et.hu_444
  // [1bf0]
  0x1004160c, 0x200a2d07, 0x130b0c0d, 0x1a00640e,   // hr.fi.lt_543 sk.pt.sq_432  sv.es.et_554 lg.tl.un_550
  0x12001b0c, 0x0b0c13af, 0x07006409, 0x17641607,   // tr.hu.un_530 et.sv.es_655  lg.it.un_440 hr.lg.sr_432
  0x0a000c04, 0x110919a0, 0x09001604, 0x0c000b04,   // sv.pt.un_320 gl.pl.ro_322  hr.pl.un_320 es.sv.un_320
  0x29171612, 0x04170aa4, 0x12130c07, 0x556416a0,   // hr.sr.sl_654 mk.sr.ru_433  sv.et.hu_432 hr.lg.rw_322

  // [1c00]
  0x55642855, 0x25001b1a, 0x23001904, 0x21645505,   // sw.lg.rw_442 tr.eu.un_760  gl.ca.un_320 rw.lg.jw_333
  0x0000212d, 0x0a17160e, 0x202d0a0c, 0x3f1a2102,   // fa.un.un_A00 hr.sr.pt_555  pt.sk.sq_543 jw.tl.af_222
  0x13171608, 0x3f202905, 0x101a280b, 0x21102904,   // hr.sr.et_443 sl.sq.af_333  sw.tl.lt_542 sl.lt.jw_332
  0x12002123, 0x17002b0e, 0x0c000b19, 0x0a17160c,   // fa.ur.un_880 vi.sr.un_550  es.sv.un_750 hr.sr.pt_543
  // [1c10]
  0x172129ad, 0x190b07a0, 0x171613a4, 0x3f00200c,   // sl.jw.sr_643 it.es.gl_322  et.hr.sr_433 sq.af.un_530
  0x21181202, 0x1e001605, 0x070c2002, 0x2100122a,   // ur.ar.fa_222 hr.ms.un_330  sq.sv.it_222 ur.fa.un_970
  0x0b001c02, 0x0b01110c, 0x0d171605, 0x040a17a4,   // id.es.un_220 ro.en.es_543  hr.sr.cs_333 sr.mk.ru_433
  0x02000302, 0x0a000108, 0x0a0411a7, 0x3f2b17a0,   // nl.da.un_220 en.pt.un_430  ro.ru.mk_532 sr.vi.af_322
  // [1c20]
  0x07080405, 0x1000211a, 0x075310ee, 0x19002119,   // ru.uk.bg_333 jw.lt.un_760  lt.ht.it_422 jw.gl.un_750
  0x080302ad, 0x060e0c60, 0x1e001c07, 0x17041108,   // da.nl.no_643 sv.is.de_664  id.ms.un_420 ro.ru.sr_443
  0x1b000609, 0x0d000412, 0x04002a02, 0x1c002a02,   // de.tr.un_440 fi.cs.un_640  mt.fi.un_220 mt.id.un_220
  0x06001108, 0x18002105, 0x070a1714, 0x010c020c,   // ro.de.un_430 fa.ar.un_330  sr.mk.bg_666 da.sv.en_543
  // [1c30]
  0x3f211ca0, 0x18006e07, 0x0a2b27a0, 0x190a010c,   // id.jw.af_322 blu.ga.un_420  gd.vi.pt_322 en.pt.gl_543
  0x05130702, 0x01001804, 0x17000412, 0x1e001304,   // it.et.fr_222 ga.en.un_320  ru.sr.un_640 et.ms.un_320
  0x080c2508, 0x23081f02, 0x20000304, 0x0c000220,   // eu.sv.no_443 cy.no.ca_222  nl.sq.un_320 da.sv.un_850
  0x0c1e08a0, 0x1e1c3109, 0x0e000c1a, 0x1a006b1b,   // no.ms.sv_322 az.id.ms_444  sv.is.un_760 ceb.tl.un_770
  // [1c40]
  0x07110a14, 0x07000809, 0x23080e11, 0x120306a0,   // mk.ro.bg_666 uk.bg.un_440  is.no.ca_653 de.nl.hu_322
  0x032923ad, 0x133f03af, 0x0a171105, 0x03003f23,   // ca.sl.nl_643 nl.af.et_655  ro.sr.mk_333 af.nl.un_880
  0x2a1c1ea6, 0x3f00130e, 0x12002507, 0x13000a07,   // ms.id.mt_521 et.af.un_550  eu.hu.un_420 pt.et.un_420
  0x0c070107, 0x08041004, 0x0c25050c, 0x12090da0,   // en.it.sv_432 be.ru.uk_332  fr.eu.sv_543 cs.pl.hu_322
  // [1c50]
  0x033f08ad, 0x21121813, 0x04000607, 0x296b2808,   // no.af.nl_643 ar.ur.fa_665  de.fi.un_420 sw.ceb.sl_443
  0x07170409, 0x0400131a, 0x17000a21, 0x20131a02,   // ru.sr.bg_444 et.fi.un_760  mk.sr.un_860 tl.et.sq_222
  0x010b0502, 0x29042002, 0x28003f19, 0x23000b02,   // fr.es.en_222 sq.fi.sl_222  af.sw.un_750 es.ca.un_220
  0x556b1a12, 0x11000302, 0x080a070d, 0x6b552014,   // tl.ceb.rw_654 nl.ro.un_220  bg.mk.uk_554 sq.rw.ceb_666
  // [1c60]
  0x0a1711ac, 0x033f1308, 0x17041007, 0x1000210c,   // ro.sr.mk_632 et.af.nl_443  be.ru.sr_432 jw.lt.un_530
  0x18002102, 0x17161cee, 0x10282d07, 0x120625a4,   // fa.ar.un_220 id.hr.sr_422  sk.sw.lt_432 eu.de.hu_433
  0x29030604, 0x13285504, 0x291712a7, 0x07040aaf,   // de.nl.sl_332 rw.sw.et_332  hu.sr.sl_532 mk.ru.bg_655
  0x64211bee, 0x280418a4, 0x06000f19, 0x20102802,   // tr.jw.lg_422 ga.fi.sw_433  lv.de.un_750 sw.lt.sq_222
  // [1c70]
  0x311255ac, 0x1a1c1eee, 0x3f000e05, 0x18211207,   // rw.hu.az_632 ms.id.tl_422  is.af.un_330 ur.fa.ar_432
  0x1604130c, 0x043f1305, 0x080a170c, 0x3f000e13,   // et.fi.hr_543 et.af.fi_333  sr.mk.uk_543 is.af.un_650
  0x132d02a0, 0x18002b0d, 0x19002504, 0x2d0d0909,   // da.sk.et_322 vi.ga.un_540  eu.gl.un_320 pl.cs.sk_444
  0x5520280c, 0x25033f04, 0x112025a7, 0x01001e02,   // sw.sq.rw_543 af.nl.eu_332  eu.sq.ro_532 ms.en.un_220
  // [1c80]
  0x04081705, 0x0c162aa6, 0x5510210d, 0x0f090608,   // sr.uk.ru_333 mt.hr.sv_521  jw.lt.rw_554 de.pl.lv_443
  0x170804ad, 0x04006408, 0x05080107, 0x0a080404,   // ru.uk.sr_643 lg.fi.un_430  en.no.fr_432 ru.uk.mk_332
  0x07040aad, 0x17070a02, 0x1100101b, 0x18002702,   // mk.ru.bg_643 mk.bg.sr_222  be.ro.un_770 gd.ga.un_220
  0x170411ad, 0x131c09ac, 0x172d0d13, 0x20122a0c,   // ro.ru.sr_643 hi.mr.bh_632  cs.sk.sr_665 mt.hu.sq_543
  // [1c90]
  0x171609a4, 0x1a000504, 0x1a2a01a4, 0x1c1e1907,   // pl.hr.sr_433 fr.tl.un_320  en.mt.tl_433 gl.ms.id_432
  0x536428a7, 0x6400090e, 0x6b3f03ee, 0x11001312,   // sw.lg.ht_532 pl.lg.un_550  nl.af.ceb_422 et.ro.un_640
  0x0b000a09, 0x092a28a4, 0x0400250d, 0x02003f04,   // pt.es.un_440 sw.mt.pl_433  eu.fi.un_540 af.da.un_320
  0x033f060b, 0x3f642a11, 0x01000504, 0x0800120c,   // de.af.nl_542 mt.lg.af_653  fr.en.un_320 hu.no.un_530
  // [1ca0]
  0x0600130c, 0x28645560, 0x12001007, 0x1927060b,   // et.de.un_530 rw.lg.sw_664  lt.hu.un_420 de.gd.gl_542
  0x10001119, 0x0f000d08, 0x6404130e, 0x12000604,   // ro.be.un_750 cs.lv.un_430  et.fi.lg_555 de.hu.un_320
  0x1c0913a7, 0x100a0707, 0x29001807, 0x55005305,   // bh.hi.mr_532 bg.mk.be_432  ga.sl.un_420 ht.rw.un_330
  0x0e2d0d02, 0x211c1eaf, 0x070a04a7, 0x645506ee,   // cs.sk.is_222 ms.id.jw_655  ru.mk.bg_532 de.rw.lg_422
  // [1cb0]
  0x09002908, 0x3f09060c, 0x06533fa0, 0x03000808,   // sl.pl.un_430 de.pl.af_543  af.ht.de_322 no.nl.un_430
  0x010b08a0, 0x04000c0c, 0x0c060fee, 0x10120912,   // no.es.en_322 sv.fi.un_530  lv.de.sv_422 pl.hu.lt_654
  0x0c130411, 0x130c2aa0, 0x10080412, 0x0801055a,   // fi.et.sv_653 mt.sv.et_322  ru.uk.be_654 fr.en.no_553
  0x071116a0, 0x16000807, 0x17160d09, 0x0c093fa0,   // hr.ro.it_322 no.hr.un_420  cs.hr.sr_444 af.pl.sv_322
  // [1cc0]
  0x1e001a02, 0x12080213, 0x190b23ac, 0x0d001c05,   // tl.ms.un_220 da.no.hu_665  ca.es.gl_632 mr.ne.un_330
  0x1716290d, 0x062d0d02, 0x06001307, 0x0c000107,   // sl.hr.sr_554 cs.sk.de_222  et.de.un_420 en.sv.un_420
  0x05000707, 0x3100250c, 0x2d000913, 0x230b0704,   // it.fr.un_420 eu.az.un_530  pl.sk.un_650 it.es.ca_332
  0x2d000907, 0x311b5511, 0x1c000d0c, 0x011827a4,   // pl.sk.un_420 rw.tr.az_653  ne.mr.un_530 gd.ga.en_433
  // [1cd0]
  0x291617a6, 0x64000911, 0x050453a0, 0x052d01a0,   // sr.hr.sl_521 pl.lg.un_630  ht.fi.fr_322 en.sk.fr_322
  0x0c0802a9, 0x3f00032c, 0x030b3f5a, 0x13002905,   // da.no.sv_544 nl.af.un_990  af.es.nl_553 sl.et.un_330
  0x536409ad, 0x29170d07, 0x6b0b19a0, 0x08020ca9,   // pl.lg.ht_643 cs.sr.sl_432  gl.es.ceb_322 sv.da.no_544
  0x10093f02, 0x3f1a01ee, 0x08230708, 0x2d006407,   // af.pl.lt_222 en.tl.af_422  it.ca.no_443 lg.sk.un_420
  // [1ce0]
  0x6b001b0b, 0x130c270b, 0x645528a4, 0x055301a4,   // tr.ceb.un_520 gd.sv.et_542  sw.rw.lg_433 en.ht.fr_433
  0x040810a7, 0x640c28a4, 0x02002714, 0x280c1aa4,   // be.uk.ru_532 sw.sv.lg_433  gd.da.un_660 tl.sv.sw_433
  0x101704a4, 0x2817160d, 0x2d0428a0, 0x1a00552b,   // ru.sr.be_433 hr.sr.sw_554  sw.fi.sk_322 rw.tl.un_980
  0x0b060aa4, 0x6425550c, 0x033f0607, 0x17112904,   // pt.de.es_433 rw.eu.lg_543  de.af.nl_432 sl.ro.sr_332
  // [1cf0]
  0x182a01a4, 0x642809ad, 0x53641211, 0x130e1804,   // en.mt.ga_433 pl.sw.lg_643  hu.lg.ht_653 ga.is.et_332
  0x6e641aad, 0x642855ad, 0x6b2155af, 0x070a04af,   // tl.lg.blu_643 rw.sw.lg_643  rw.jw.ceb_655 ru.mk.bg_655
  0x1e551c07, 0x130408a0, 0x110a1313, 0x02000c1b,   // id.rw.ms_432 no.fi.et_322  et.pt.ro_665 sv.da.un_770
  0x2000040e, 0x0e000814, 0x020c1fee, 0x13552108,   // fi.sq.un_550 no.is.un_660  cy.sv.da_422 jw.rw.et_443
  // [1d00]
  0x0c000523, 0x200b0708, 0x211a1c07, 0x013f6ba4,   // fr.sv.un_880 it.es.sq_443  id.tl.jw_432 ceb.af.en_433
  0x1f055305, 0x18122113, 0x3f080e0b, 0x040a11a7,   // ht.fr.cy_333 fa.ur.ar_665  is.no.af_542 ro.mk.ru_532
  0x160428a4, 0x21001a0b, 0x3f270208, 0x100721a0,   // sw.fi.hr_433 tl.jw.un_520  da.gd.af_443 jw.it.lt_322
  0x1304645a, 0x1b000c12, 0x12000418, 0x20001108,   // lg.fi.et_553 sv.tr.un_640  fi.hu.un_740 ro.sq.un_430
  // [1d10]
  0x0f130407, 0x00001e15, 0x1a0e6407, 0x04000712,   // fi.et.lv_432 ms.un.un_700  lg.is.tl_432 bg.ru.un_640
  0x13286407, 0x190b25a9, 0x070a0402, 0x64211a04,   // lg.sw.et_432 eu.es.gl_544  ru.mk.bg_222 tl.jw.lg_332
  0x640f13a9, 0x10000f21, 0x1713255a, 0x31001b11,   // et.lv.lg_544 lv.lt.un_860  eu.et.sr_553 tr.az.un_630
  0x0d006408, 0x132d0e0c, 0x64131aee, 0x080711ee,   // lg.cs.un_430 is.sk.et_543  tl.et.lg_422 ro.bg.uk_422
  // [1d20]
  0x3f1c080c, 0x1b096ea0, 0x06002704, 0x6b002707,   // no.id.af_543 blu.pl.tr_322  gd.de.un_320 gd.ceb.un_420
  0x53001c04, 0x091c0d11, 0x28640f04, 0x29031209,   // id.ht.un_320 ne.mr.hi_653  lv.lg.sw_332 hu.nl.sl_444
  0x130464a7, 0x07080407, 0x04641313, 0x0b0a19a0,   // lg.fi.et_532 ru.uk.bg_432  et.lg.fi_665 gl.pt.es_322
  0x64041307, 0x110a17af, 0x1f002a09, 0x0c000814,   // et.fi.lg_432 sr.mk.ro_655  mt.cy.un_440 no.sv.un_660
  // [1d30]
  0x0a070404, 0x162910ee, 0x0a0817a0, 0x1b00530e,   // ru.bg.mk_332 lt.sl.hr_422  sr.uk.mk_322 ht.tr.un_550
  0x6b533109, 0x01001902, 0x070a0413, 0x2d001214,   // az.ht.ceb_444 gl.en.un_220  ru.mk.bg_665 hu.sk.un_660
  0x1e1c1aa0, 0x202925ad, 0x051311a0, 0x070a25ec,   // tl.id.ms_322 eu.sl.sq_643  ro.et.fr_322 eu.pt.it_644
  0x0b210707, 0x2700250d, 0x646e250c, 0x6b1a25a4,   // it.jw.es_432 eu.gd.un_540  eu.blu.lg_543 eu.tl.ceb_433
  // [1d40]
  0x07001114, 0x04100809, 0x31002108, 0x11050e07,   // ro.bg.un_660 uk.be.ru_444  jw.az.un_430 is.fr.ro_432
  0x212728a4, 0x04006e09, 0x53002a07, 0x230b130c,   // sw.gd.jw_433 blu.fi.un_440  mt.ht.un_420 et.es.ca_543
  0x0f000808, 0x1b005321, 0x1800110c, 0x16045507,   // no.lv.un_430 ht.tr.un_860  ro.ga.un_530 rw.fi.hr_432
  0x21000b04, 0x17162aa9, 0x190b21a0, 0x211053ec,   // es.jw.un_320 mt.hr.sr_544  jw.es.gl_322 ht.lt.jw_644
  // [1d50]
  0x6400280c, 0x6b1a5312, 0x1e1c1bee, 0x532d0d5a,   // sw.lg.un_530 ht.tl.ceb_654  tr.id.ms_422 cs.sk.ht_553
  0x2d120ea0, 0x16002007, 0x29002704, 0x0a1811ee,   // is.hu.sk_322 sq.hr.un_420  gd.sl.un_320 ro.ga.pt_422
  0x0b23190c, 0x010e0a08, 0x272528ee, 0x04171111,   // gl.ca.es_543 pt.is.en_443  sw.eu.gd_422 ro.sr.ru_653
  0x23180eaf, 0x0e003121, 0x04000519, 0x55280605,   // is.ga.ca_655 az.is.un_860  fr.fi.un_750 de.sw.rw_333
  // [1d60]
  0x0d005508, 0x1e002a07, 0x120a1fa0, 0x0b182308,   // rw.cs.un_430 mt.ms.un_420  cy.pt.hu_322 ca.ga.es_443
  0x212320a0, 0x17080a55, 0x0e162002, 0x08040705,   // sq.ca.jw_322 mk.uk.sr_442  sq.hr.is_222 bg.ru.uk_333
  0x0b0a20a4, 0x05001107, 0x286455af, 0x040a070c,   // sq.pt.es_433 ro.fr.un_420  rw.lg.sw_655 bg.mk.ru_543
  0x1800121a, 0x17162aee, 0x230e19ad, 0x1f001b04,   // hu.ga.un_760 mt.hr.sr_422  gl.is.ca_643 tr.cy.un_320
  // [1d70]
  0x2d0d0509, 0x0c030407, 0x116455ec, 0x190e2302,   // fr.cs.sk_444 fi.nl.sv_432  rw.lg.ro_644 ca.is.gl_222
  0x11200c12, 0x25002304, 0x06002322, 0x0a00170c,   // sv.sq.ro_654 ca.eu.un_320  ca.de.un_870 sr.mk.un_530
  0x13000d0d, 0x1219180c, 0x182d0d1a, 0x3f00080c,   // ne.bh.un_540 ga.gl.hu_543  cs.sk.ga_776 no.af.un_530
  0x09010b0c, 0x16002909, 0x032d2307, 0x122d0d12,   // es.en.pl_543 sl.hr.un_440  ca.sk.nl_432 cs.sk.hu_654
  // [1d80]
  0x110407af, 0x090d13af, 0x31000b05, 0x0b000a08,   // bg.ru.ro_655 bh.ne.hi_655  es.az.un_330 pt.es.un_430
  0x230705a4, 0x122d0d0e, 0x21001c13, 0x03002902,   // fr.it.ca_433 cs.sk.hu_555  id.jw.un_650 sl.nl.un_220
  0x07100aa4, 0x060c3fa0, 0x122d0d0d, 0x0c0203a4,   // mk.be.bg_433 af.sv.de_322  cs.sk.hu_554 nl.da.sv_433
  0x25642aee, 0x02003f07, 0x101806ee, 0x1904110c,   // mt.lg.eu_422 af.da.un_420  de.ga.lt_422 ro.fi.gl_543
  // [1d90]
  0x11190a0c, 0x17070404, 0x060e0c02, 0x05020e04,   // pt.gl.ro_543 ru.bg.sr_332  sv.is.de_222 is.da.fr_332
  0x250b19ee, 0x16551108, 0x0d6b04ee, 0x04080504,   // gl.es.eu_422 ro.rw.hr_443  fi.ceb.cs_422 fr.no.fi_332
  0x0e0c08ee, 0x0a000708, 0x03000514, 0x293f16ee,   // no.sv.is_422 it.pt.un_430  fr.nl.un_660 hr.af.sl_422
  0x0e250c0d, 0x12001319, 0x64000b02, 0x11001705,   // sv.eu.is_554 et.hu.un_750  es.lg.un_220 sr.ro.un_330
  // [1da0]
  0x2500230d, 0x55002112, 0x130710a4, 0x11002322,   // ca.eu.un_540 jw.rw.un_640  lt.it.et_433 ca.ro.un_870
  0x23290509, 0x27002302, 0x07040aee, 0x28041007,   // fr.sl.ca_444 ca.gd.un_220  mk.ru.bg_422 lt.fi.sw_432
  0x25100407, 0x122d0d08, 0x040f100b, 0x2d000d0c,   // fi.lt.eu_432 cs.sk.hu_443  lt.lv.fi_542 cs.sk.un_530
  0x031205a4, 0x190b0a02, 0x04131012, 0x07101faf,   // fr.hu.nl_433 pt.es.gl_222  lt.et.fi_654 cy.lt.it_655
  // [1db0]
  0x0f0604a0, 0x09000d14, 0x0e171604, 0x23000504,   // fi.de.lv_322 ne.hi.un_660  hr.sr.is_332 fr.ca.un_320
  0x1e1c28af, 0x0e002d09, 0x13000921, 0x04001019,   // sw.id.ms_655 sk.is.un_440  hi.bh.un_860 be.ru.un_750
  0x0a000b04, 0x1c1309af, 0x531304a4, 0x27002d0e,   // es.pt.un_320 hi.bh.mr_655  fi.et.ht_433 sk.gd.un_550
  0x53016b0c, 0x1c0428a4, 0x06182d07, 0x12182160,   // ceb.en.ht_543 sw.fi.id_433  sk.ga.de_432 fa.ar.ur_664
  // [1dc0]
  0x13041004, 0x09130d0b, 0x110a0808, 0x2d001f1a,   // lt.fi.et_332 ne.bh.hi_542  uk.mk.ro_443 cy.sk.un_760
  0x231c03a6, 0x0b0a10a4, 0x061f2d0c, 0x030908a9,   // nl.id.ca_521 lt.pt.es_433  sk.cy.de_543 no.pl.nl_544
  0x101a1307, 0x2d00061a, 0x02130cad, 0x535513a7,   // et.tl.lt_432 de.sk.un_760  sv.et.da_643 et.rw.ht_532
  0x131a5512, 0x13285505, 0x2900171b, 0x0e161707,   // rw.tl.et_654 rw.sw.et_333  sr.sl.un_770 sr.hr.is_432
  // [1dd0]
  0x0a0711a0, 0x2a1f2da7, 0x130c6413, 0x291610a0,   // ro.bg.mk_322 sk.cy.mt_532  lg.sv.et_665 lt.hr.sl_322
  0x280f10a4, 0x110812af, 0x04081707, 0x050b0a04,   // lt.lv.sw_433 hu.no.ro_655  sr.uk.ru_432 pt.es.fr_332
  0x0c5513ad, 0x132055ee, 0x19100aaf, 0x210501ec,   // et.rw.sv_643 rw.sq.et_422  pt.lt.gl_655 en.fr.jw_644
  0x19001709, 0x270f10a9, 0x6413160d, 0x050155ad,   // sr.gl.un_440 lt.lv.gd_544  hr.et.lg_554 rw.en.fr_643
  // [1de0]
  0x18080205, 0x041716a4, 0x0b00070c, 0x120c0ead,   // da.no.ga_333 hr.sr.fi_433  it.es.un_530 is.sv.hu_643
  0x08000708, 0x200f55a4, 0x3f0608af, 0x1000251a,   // bg.uk.un_430 rw.lv.sq_433  no.de.af_655 eu.lt.un_760
  0x030501a4, 0x0c060513, 0x27312808, 0x18272dad,   // en.fr.nl_433 fr.de.sv_665  sw.az.gd_443 sk.gd.ga_643
  0x21000212, 0x0e060805, 0x055501ee, 0x131911a7,   // da.jw.un_640 no.de.is_333  en.rw.fr_422 ro.gl.et_532
  // [1df0]
  0x290309a7, 0x2a0713a4, 0x2d0d2a0e, 0x311b640c,   // pl.nl.sl_532 et.it.mt_433  mt.cs.sk_555 lg.tr.az_543
  0x2a130c0c, 0x27001207, 0x0d062507, 0x0f641bac,   // sv.et.mt_543 hu.gd.un_420  eu.de.cs_432 tr.lg.lv_632
  0x55136409, 0x122d0d5a, 0x2d0d1bee, 0x03001f04,   // lg.et.rw_444 cs.sk.hu_553  tr.cs.sk_422 cy.nl.un_320
  0x29165505, 0x05000a08, 0x04130f0c, 0x12000e14,   // rw.hr.sl_333 pt.fr.un_430  lv.et.fi_543 is.hu.un_660
  // [1e00]
  0x19050e5a, 0x1f033fa9, 0x0e05080c, 0x210410a4,   // is.fr.gl_553 af.nl.cy_544  no.fr.is_543 lt.fi.jw_433
  0x0f022da0, 0x060318ec, 0x0a171012, 0x20001c08,   // sk.da.lv_322 ga.nl.de_644  be.sr.mk_654 id.sq.un_430
  0x120608ad, 0x07050111, 0x03001902, 0x17292d0b,   // no.de.hu_643 en.fr.it_653  gl.nl.un_220 sk.sl.sr_542
  0x09101a07, 0x0f041311, 0x07111204, 0x06000321,   // tl.lt.pl_432 et.fi.lv_653  hu.ro.it_332 nl.de.un_860
  // [1e10]
  0x10280f07, 0x07050112, 0x083f020b, 0x190b12a0,   // lv.sw.lt_432 en.fr.it_654  da.af.no_542 hu.es.gl_322
  0x3f021ca0, 0x12001904, 0x04000e12, 0x1b1628ad,   // id.da.af_322 gl.hu.un_320  is.fi.un_640 sw.hr.tr_643
  0x090d1c0c, 0x2b000707, 0x13171604, 0x231f12af,   // mr.ne.hi_543 it.vi.un_420  hr.sr.et_332 hu.cy.ca_655
  0x0d292da6, 0x04110807, 0x1f3f0311, 0x08041307,   // sk.sl.cs_521 uk.ro.ru_432  nl.af.cy_653 et.fi.no_432
  // [1e20]
  0x55002113, 0x161a0455, 0x10190a07, 0x18002123,   // jw.rw.un_650 fi.tl.hr_442  pt.gl.lt_432 fa.ar.un_880
  0x120b1a0c, 0x190a10ee, 0x0704110c, 0x0f311b08,   // tl.es.hu_543 lt.pt.gl_422  ro.ru.bg_543 tr.az.lv_443
  0x2d0d20ee, 0x052d25a4, 0x032a07ee, 0x21001c12,   // sq.cs.sk_422 eu.sk.fr_433  it.mt.nl_422 id.jw.un_640
  0x0f311b07, 0x231627a0, 0x06000c02, 0x31216407,   // tr.az.lv_432 gd.hr.ca_322  sv.de.un_220 lg.jw.az_432
  // [1e30]
  0x1205530c, 0x17040805, 0x3f211ca9, 0x02000f14,   // ht.fr.hu_543 uk.ru.sr_333  id.jw.af_544 lv.da.un_660
  0x213f0309, 0x1609120e, 0x19001208, 0x160c04a0,   // nl.af.jw_444 hu.pl.hr_555  hu.gl.un_430 fi.sv.hr_322
  0x040a0707, 0x160f29a9, 0x12100407, 0x1f033f55,   // bg.mk.ru_432 sl.lv.hr_544  fi.lt.hu_432 af.nl.cy_442
  0x0c00250b, 0x646b09ee, 0x19041a0d, 0x041005a0,   // eu.sv.un_520 pl.ceb.lg_422  tl.fi.gl_554 fr.lt.fi_322
  // [1e40]
  0x2a000404, 0x55002107, 0x130704a4, 0x1c1e21ad,   // fi.mt.un_320 jw.rw.un_420  fi.it.et_433 jw.ms.id_643
  0x2300270d, 0x070c01a0, 0x17070a0d, 0x0a170402,   // gd.ca.un_540 en.sv.it_322  mk.bg.sr_554 ru.sr.mk_222
  0x170704ad, 0x0d001907, 0x1f002502, 0x1e530405,   // ru.bg.sr_643 gl.cs.un_420  eu.cy.un_220 fi.ht.ms_333
  0x08063faf, 0x06030407, 0x0c0f080c, 0x00003f2d,   // af.de.no_655 fi.nl.de_432  no.lv.sv_543 af.un.un_A00
  // [1e50]
  0x1a2113ac, 0x021e08a4, 0x033f270d, 0x123f0208,   // et.jw.tl_632 no.ms.da_433  gd.af.nl_554 da.af.hu_443
  0x0c080208, 0x23181bee, 0x17040a08, 0x2900030e,   // da.no.sv_443 tr.ga.ca_422  mk.ru.sr_443 nl.sl.un_550
  0x05030b09, 0x180227a4, 0x0e002807, 0x080a0707,   // es.nl.fr_444 gd.da.ga_433  sw.is.un_420 bg.mk.uk_432
  0x12002513, 0x313f0ea4, 0x21001834, 0x03043f55,   // eu.hu.un_650 is.af.az_433  ar.fa.un_A80 af.fi.nl_442
  // [1e60]
  0x23000a04, 0x280403a0, 0x3f040313, 0x133f040b,   // pt.ca.un_320 nl.fi.sw_322  nl.fi.af_665 fi.af.et_542
  0x05031c0c, 0x083f03a0, 0x19230a07, 0x0d022a07,   // id.nl.fr_543 nl.af.no_322  pt.ca.gl_432 mt.da.cs_432
  0x3f031a14, 0x09000e07, 0x13182713, 0x2d0d0eee,   // tl.nl.af_666 is.pl.un_420  gd.ga.et_665 is.cs.sk_422
  0x0417165a, 0x0a001105, 0x25190b04, 0x08310aa0,   // hr.sr.fi_553 ro.mk.un_330  es.gl.eu_332 pt.az.no_322
  // [1e70]
  0x06000e05, 0x06030205, 0x12000e1a, 0x04003f08,   // is.de.un_330 da.nl.de_333  is.hu.un_760 af.fi.un_430
  0x020c0807, 0x132d0d11, 0x53282155, 0x1c001e08,   // no.sv.da_432 cs.sk.et_653  jw.sw.ht_442 ms.id.un_430
  0x043f0307, 0x1c000914, 0x111a6bee, 0x04001307,   // nl.af.fi_432 hi.mr.un_660  ceb.tl.ro_422 et.fi.un_420
  0x033f0409, 0x043f13a4, 0x03003f0c, 0x0b0711a4,   // fi.af.nl_444 et.af.fi_433  af.nl.un_530 ro.it.es_433
  // [1e80]
  0x100f17a0, 0x1b000404, 0x0d001c13, 0x06001102,   // sr.lv.lt_322 fi.tr.un_320  mr.ne.un_650 ro.de.un_220
  0x2a002505, 0x2d0d16a0, 0x2500110c, 0x041b310c,   // eu.mt.un_330 hr.cs.sk_322  ro.eu.un_530 az.tr.fi_543
  0x2b1f1107, 0x20002d02, 0x023f1f04, 0x020c080c,   // ro.cy.vi_432 sk.sq.un_220  cy.af.da_332 no.sv.da_543
  0x2000550c, 0x55000d13, 0x292320ad, 0x6b000912,   // rw.sq.un_530 cs.rw.un_650  sq.ca.sl_643 pl.ceb.un_640
  // [1e90]
  0x0b002d08, 0x201206ad, 0x0a070455, 0x170811a7,   // sk.es.un_430 de.hu.sq_643  ru.bg.mk_442 ro.uk.sr_532
  0x19100f09, 0x1c0d1311, 0x071704a0, 0x23190a05,   // lv.lt.gl_444 bh.ne.mr_653  ru.sr.bg_322 pt.gl.ca_333
  0x033f1f08, 0x2b002508, 0x20001002, 0x032153ec,   // cy.af.nl_443 eu.vi.un_430  lt.sq.un_220 ht.jw.nl_644
  0x0a170704, 0x2b002505, 0x033f0ca9, 0x0a17070e,   // bg.sr.mk_332 eu.vi.un_330  sv.af.nl_544 bg.sr.mk_555
  // [1ea0]
  0x55002904, 0x08101104, 0x0000092d, 0x190a0b09,   // sl.rw.un_320 ro.be.uk_332  pl.un.un_A00 es.pt.gl_444
  0x190a05ac, 0x04641355, 0x0f001307, 0x1e001c04,   // fr.pt.gl_632 et.lg.fi_442  et.lv.un_420 id.ms.un_320
  0x13642808, 0x1c0913ac, 0x0c081a05, 0x230a0bad,   // sw.lg.et_443 bh.hi.mr_632  tl.no.sv_333 es.pt.ca_643
  0x04136407, 0x033f08a4, 0x0a002305, 0x1e211007,   // lg.et.fi_432 no.af.nl_433  ca.pt.un_330 lt.jw.ms_432
  // [1eb0]
  0x10002807, 0x1e1c1faf, 0x19050aa0, 0x1c002907,   // sw.lt.un_420 cy.id.ms_655  pt.fr.gl_322 sl.id.un_420
  0x531b13ad, 0x530a2104, 0x2b00641a, 0x171b1612,   // et.tr.ht_643 jw.pt.ht_332  lg.vi.un_760 hr.tr.sr_654
  0x04001304, 0x0800040e, 0x070a110c, 0x3f006402,   // et.fi.un_320 ru.uk.un_550  ro.mk.bg_543 lg.af.un_220
  0x271a6b12, 0x2d1710a0, 0x1f0728ee, 0x64002809,   // ceb.tl.gd_654 lt.sr.sk_322  sw.it.cy_422 sw.lg.un_440
  // [1ec0]
  0x0b0a19af, 0x25556b0c, 0x0a000402, 0x0b001a05,   // gl.pt.es_655 ceb.rw.eu_543  ru.mk.un_220 tl.es.un_330
  0x2d001002, 0x23190a08, 0x530a0504, 0x21001234,   // lt.sk.un_220 pt.gl.ca_443  fr.pt.ht_332 ur.fa.un_A80
  0x04001c04, 0x13002a1b, 0x04001321, 0x04133f14,   // id.fi.un_320 mt.et.un_770  et.fi.un_860 af.et.fi_666
  0x0c001313, 0x232d210c, 0x64001902, 0x21131c0c,   // et.sv.un_650 jw.sk.ca_543  gl.lg.un_220 id.et.jw_543
  // [1ed0]
  0x64003f05, 0x17162d0e, 0x3f022504, 0x1e003108,   // af.lg.un_330 sk.hr.sr_555  eu.da.af_332 az.ms.un_430
  0x0c0f1014, 0x08071008, 0x21001c19, 0x0e020607,   // lt.lv.sv_666 be.bg.uk_443  id.jw.un_750 de.da.is_432
  0x050701af, 0x230716a0, 0x130c0ea7, 0x0e3f1b0c,   // en.it.fr_655 hr.it.ca_322  is.sv.et_532 tr.af.is_543
  0x13001c0e, 0x04071107, 0x0d1c090d, 0x1c000911,   // mr.bh.un_550 ro.bg.ru_432  hi.mr.ne_554 hi.mr.un_630
  // [1ee0]
  0x1300092a, 0x21001809, 0x10002307, 0x0600310d,   // hi.bh.un_970 ar.fa.un_440  ca.lt.un_420 az.de.un_540
  0x1b00180e, 0x0a122da4, 0x16000702, 0x10170a55,   // ga.tr.un_550 sk.hu.pt_433  it.hr.un_220 mk.sr.be_442
  0x1e002708, 0x0308060b, 0x0a070412, 0x1b001902,   // gd.ms.un_430 de.no.nl_542  ru.bg.mk_654 gl.tr.un_220
  0x2800200d, 0x160f29a4, 0x21002819, 0x10000f08,   // sq.sw.un_540 sl.lv.hr_433  sw.jw.un_750 lv.lt.un_430
  // [1ef0]
  0x0b002b02, 0x29162a0b, 0x21002704, 0x23281c04,   // vi.es.un_220 mt.hr.sl_542  gd.jw.un_320 id.sw.ca_332
  0x6b1c21a7, 0x1c00130d, 0x21201ea4, 0x032305ee,   // jw.id.ceb_532 bh.mr.un_540  ms.sq.jw_433 fr.ca.nl_422
  0x6b131a08, 0x122118ac, 0x21002829, 0x18002007,   // tl.et.ceb_443 ar.fa.ur_632  sw.jw.un_960 sq.ga.un_420
  0x292d0d5a, 0x0a001b0e, 0x02002107, 0x2d00250c,   // cs.sk.sl_553 tr.pt.un_550  jw.da.un_420 eu.sk.un_530
  // [1f00]
  0x1a6b28ac, 0x0f000705, 0x110119a0, 0x04081105,   // sw.ceb.tl_632 it.lv.un_330  gl.en.ro_322 ro.uk.ru_333
  0x2164280e, 0x011c21a7, 0x1f00011a, 0x0c102708,   // sw.lg.jw_555 jw.id.en_532  en.cy.un_760 gd.lt.sv_443
  0x04071112, 0x2a00180c, 0x25101fa6, 0x1e1c2d0c,   // ro.bg.ru_654 ga.mt.un_530  cy.lt.eu_521 sk.id.ms_543
  0x281912a7, 0x2d1a10ad, 0x09642812, 0x073f2507,   // hu.gl.sw_532 lt.tl.sk_643  sw.lg.pl_654 eu.af.it_432
  // [1f10]
  0x5300050d, 0x0900121a, 0x131f2a07, 0x0c001312,   // fr.ht.un_540 hu.pl.un_760  mt.cy.et_432 et.sv.un_640
  0x0a1710a7, 0x0413100e, 0x050625ad, 0x1a6428ec,   // be.sr.mk_532 lt.et.fi_555  eu.de.fr_643 sw.lg.tl_644
  0x641a28ad, 0x1b0a04ee, 0x0c1201a7, 0x040708ad,   // sw.tl.lg_643 fi.pt.tr_422  en.hu.sv_532 uk.bg.ru_643
  0x17160709, 0x281e1c04, 0x100804ec, 0x07000b13,   // it.hr.sr_444 id.ms.sw_332  ru.uk.be_644 es.it.un_650
  // [1f20]
  0x2d1629a0, 0x272a21a4, 0x2000110e, 0x0c083f07,   // sl.hr.sk_322 jw.mt.gd_433  ro.sq.un_550 af.no.sv_432
  0x126b27a0, 0x1e1f10ad, 0x2a000704, 0x040711a9,   // gd.ceb.hu_322 lt.cy.ms_643  it.mt.un_320 ro.bg.ru_544
  0x212701a0, 0x0d001c1b, 0x0a2308a4, 0x231a2708,   // en.gd.jw_322 mr.ne.un_770  no.ca.pt_433 gd.tl.ca_443
  0x03000c04, 0x10000b02, 0x0c001607, 0x28002509,   // sv.nl.un_320 es.lt.un_220  hr.sv.un_420 eu.sw.un_440
  // [1f30]
  0x2000251a, 0x0c3f03a0, 0x252a04af, 0x12000305,   // eu.sq.un_760 nl.af.sv_322  fi.mt.eu_655 nl.hu.un_330
  0x090d1311, 0x290d160d, 0x6e00060d, 0x0b001922,   // bh.ne.hi_653 hr.cs.sl_554  de.blu.un_540 gl.es.un_870
  0x16070da4, 0x08000404, 0x020c2a55, 0x10000b04,   // cs.it.hr_433 fi.no.un_320  mt.sv.da_442 es.lt.un_320
  0x5300050c, 0x12171604, 0x1f20275a, 0x06006b05,   // fr.ht.un_530 hr.sr.hu_332  gd.sq.cy_553 ceb.de.un_330
  // [1f40]
  0x55280805, 0x050601ac, 0x0e6e0ba0, 0x210c0405,   // no.sw.rw_333 en.de.fr_632  es.blu.is_322 fi.sv.jw_333
  0x13000c12, 0x0f002904, 0x19210ba4, 0x086e01a0,   // sv.et.un_640 sl.lv.un_320  es.jw.gl_433 en.blu.no_322
  0x0c3f0205, 0x080c0208, 0x0c003f08, 0x13041b0b,   // da.af.sv_333 da.sv.no_443  af.sv.un_430 tr.fi.et_542
  0x1c0d130c, 0x0804530c, 0x1b006b04, 0x250b0a08,   // bh.ne.mr_543 ht.fi.no_543  ceb.tr.un_320 pt.es.eu_443
  // [1f50]
  0x0b000607, 0x23190b02, 0x190b070c, 0x25002807,   // de.es.un_420 es.gl.ca_222  it.es.gl_543 sw.eu.un_420
  0x04002513, 0x05002104, 0x3f0d0e04, 0x13000d14,   // eu.fi.un_650 jw.fr.un_320  is.cs.af_332 ne.bh.un_660
  0x040a170d, 0x0500250c, 0x53071155, 0x3f000320,   // sr.mk.ru_554 eu.fr.un_530  ro.it.ht_442 nl.af.un_850
  0x020725ee, 0x04171009, 0x3f0353a7, 0x0c0408a4,   // eu.it.da_422 be.sr.ru_444  ht.nl.af_532 no.fi.sv_433
  // [1f60]
  0x53000414, 0x53050dee, 0x0a07040e, 0x291e1c04,   // fi.ht.un_660 cs.fr.ht_422  ru.bg.mk_555 id.ms.sl_332
  0x31280802, 0x29005509, 0x3f000413, 0x04081007,   // no.sw.az_222 rw.sl.un_440  fi.af.un_650 be.uk.ru_432
  0x07021fa0, 0x0d055307, 0x04170a08, 0x0d530504,   // cy.da.it_322 ht.fr.cs_432  mk.sr.ru_443 fr.ht.cs_332
  0x64001f07, 0x0a2325a4, 0x533f0307, 0x2d0d29ec,   // cy.lg.un_420 eu.ca.pt_433  nl.af.ht_432 sl.cs.sk_644
  // [1f70]
  0x171664a4, 0x080710a0, 0x0f1716a9, 0x190a01a4,   // lg.hr.sr_433 be.bg.uk_322  hr.sr.lv_544 en.pt.gl_433
  0x1900010c, 0x17010807, 0x10000a04, 0x3f040da0,   // en.gl.un_530 no.en.sr_432  mk.be.un_320 cs.fi.af_322
  0x53050d0c, 0x080c0204, 0x53052912, 0x0d0206a4,   // cs.fr.ht_543 da.sv.no_332  sl.fr.ht_654 de.da.cs_433
  0x0800040d, 0x1f251804, 0x1700081a, 0x55001604,   // ru.uk.un_540 ga.eu.cy_332  uk.sr.un_760 hr.rw.un_320
  // [1f80]
  0x0600290c, 0x1f001021, 0x17070807, 0x01000b07,   // sl.de.un_530 lt.cy.un_860  uk.bg.sr_432 es.en.un_420
  0x12000621, 0x20002a18, 0x0e0406ad, 0x211f25a0,   // de.hu.un_860 mt.sq.un_740  de.fi.is_643 eu.cy.jw_322
  0x06000807, 0x06041313, 0x21001e05, 0x08000208,   // no.de.un_420 et.fi.de_665  ms.jw.un_330 da.no.un_430
  0x3f0601a4, 0x2a001314, 0x25001214, 0x311b1205,   // en.de.af_433 et.mt.un_660  hu.eu.un_660 hu.tr.az_333
  // [1f90]
  0x02052807, 0x0c1312ee, 0x1664170c, 0x6413060c,   // sw.fr.da_432 hu.et.sv_422  sr.lg.hr_543 de.et.lg_543
  0x0e000618, 0x0c1a6b07, 0x2100050c, 0x55642107,   // de.is.un_740 ceb.tl.sv_432  fr.jw.un_530 jw.lg.rw_432
  0x31000a12, 0x2a000e21, 0x641b2aee, 0x0a080709,   // pt.az.un_640 is.mt.un_860  mt.tr.lg_422 bg.uk.mk_444
  0x08202a07, 0x0e080204, 0x0f290d04, 0x0c0e1fee,   // mt.sq.no_432 da.no.is_332  cs.sl.lv_332 cy.is.sv_422
  // [1fa0]
  0x13000420, 0x2a060409, 0x21000218, 0x03000412,   // fi.et.un_850 fi.de.mt_444  da.jw.un_740 fi.nl.un_640
  0x252a0713, 0x28000407, 0x13040609, 0x03001302,   // it.mt.eu_665 fi.sw.un_420  de.fi.et_444 et.nl.un_220
  0x062701ad, 0x0704100b, 0x28006b0b, 0x3f000407,   // en.gd.de_643 be.ru.bg_542  ceb.sw.un_520 fi.af.un_420
  0x0f001a07, 0x05000704, 0x07170aa7, 0x23002004,   // tl.lv.un_420 it.fr.un_320  mk.sr.bg_532 sq.ca.un_320
  // [1fb0]
  0x6b53010c, 0x0a001012, 0x1a000404, 0x1f000619,   // en.ht.ceb_543 lt.pt.un_640  fi.tl.un_320 de.cy.un_750
  0x091c130d, 0x08171608, 0x6b27010b, 0x1100250c,   // bh.mr.hi_554 hr.sr.no_443  en.gd.ceb_542 eu.ro.un_530
  0x3f066405, 0x0b0a1baf, 0x10170809, 0x12000807,   // lg.de.af_333 tr.pt.es_655  uk.sr.be_444 no.hu.un_420
  0x27000112, 0x13002509, 0x130825ec, 0x2500110d,   // en.gd.un_640 eu.et.un_440  eu.no.et_644 ro.eu.un_540
  // [1fc0]
  0x0a051b02, 0x3f030405, 0x07002508, 0x0d091c0e,   // tr.fr.pt_222 fi.nl.af_333  eu.it.un_430 mr.hi.ne_555
  0x133f03ec, 0x2d1720a4, 0x192523a0, 0x53000709,   // nl.af.et_644 sq.sr.sk_433  ca.eu.gl_322 it.ht.un_440
  0x130c2804, 0x2a110107, 0x0b0a1909, 0x02001a07,   // sw.sv.et_332 en.ro.mt_432  gl.pt.es_444 tl.da.un_420
  0x060e1b08, 0x053f03a9, 0x100e040c, 0x081004ee,   // tr.is.de_443 nl.af.fr_544  fi.is.lt_543 ru.be.uk_422
  // [1fd0]
  0x0725010c, 0x0c122107, 0x27000113, 0x530501a0,   // en.eu.it_543 jw.hu.sv_432  en.gd.un_650 en.fr.ht_322
  0x1c2127a0, 0x080231a0, 0x03112dee, 0x100807a4,   // gd.jw.id_322 az.da.no_322  sk.ro.nl_422 bg.uk.be_433
  0x0a170405, 0x1a006b09, 0x04071007, 0x016b16a0,   // ru.sr.mk_333 ceb.tl.un_440  be.bg.ru_432 hr.ceb.en_322
  0x2500190c, 0x533113a7, 0x170a0404, 0x08000e0c,   // gl.eu.un_530 et.az.ht_532  ru.mk.sr_332 is.no.un_530
  // [1fe0]
  0x131c0912, 0x13033f60, 0x12000512, 0x0b00550c,   // hi.mr.bh_654 af.nl.et_664  fr.hu.un_640 rw.es.un_530
  0x0300110d, 0x171602ee, 0x550464ee, 0x03001304,   // ro.nl.un_540 da.hr.sr_422  lg.fi.rw_422 et.nl.un_320
  0x55100a0c, 0x13080408, 0x09000714, 0x1112010b,   // pt.lt.rw_543 fi.no.et_443  it.pl.un_660 en.hu.ro_542
  0x033f1909, 0x27002d04, 0x530413a4, 0x0e1b0202,   // gl.af.nl_444 sk.gd.un_320  et.fi.ht_433 da.tr.is_222
  // [1ff0]
  0x25126bad, 0x53551a05, 0x05122d13, 0x0d032d55,   // ceb.hu.eu_643 tl.rw.ht_333  sk.hu.fr_665 sk.nl.cs_442
  0x052b270c, 0x1e0702a4, 0x0a1208a0, 0x532b270c,   // gd.vi.fr_543 da.it.ms_433  no.hu.pt_322 gd.vi.ht_543
  0x2d110fa0, 0x0b5355a4, 0x11070bee, 0x17002922,   // lv.ro.sk_322 rw.ht.es_433  es.it.ro_422 sl.sr.un_870
  0x0900270e, 0x20000a0c, 0x19006e07, 0x04170705,   // gd.pl.un_550 pt.sq.un_530  blu.gl.un_420 bg.sr.ru_333

  // [2000]
  0x2a001102, 0x31001e08, 0x1c0421ee, 0x3f1a13a0,   // ro.mt.un_220 ms.az.un_430  jw.fi.id_422 et.tl.af_322
  0x55642804, 0x2d001102, 0x6b2821a4, 0x3f210507,   // sw.lg.rw_332 ro.sk.un_220  jw.sw.ceb_433 fr.jw.af_432
  0x071117af, 0x1b641fa7, 0x0b00121a, 0x08000e21,   // sr.ro.bg_655 cy.lg.tr_532  hu.es.un_760 is.no.un_860
  0x23272d07, 0x0f006b04, 0x2700061b, 0x2d001709,   // sk.gd.ca_432 ceb.lv.un_320  de.gd.un_770 sr.sk.un_440
  // [2010]
  0x0b0a16a0, 0x270f0404, 0x17081108, 0x02280fec,   // hr.pt.es_322 fi.lv.gd_332  ro.uk.sr_443 lv.sw.da_644
  0x28002102, 0x0a2d19a4, 0x011b1f07, 0x0e190b60,   // jw.sw.un_220 gl.sk.pt_433  cy.tr.en_432 es.gl.is_664
  0x2d0d2909, 0x11002023, 0x033f0514, 0x0d292daf,   // sl.cs.sk_444 sq.ro.un_880  fr.af.nl_666 sk.sl.cs_655
  0x03063f09, 0x17162d02, 0x3f000323, 0x07001008,   // af.de.nl_444 sk.hr.sr_222  nl.af.un_880 be.bg.un_430
  // [2020]
  0x050a01a4, 0x08000719, 0x1c19070c, 0x0b212304,   // en.pt.fr_433 bg.uk.un_750  it.gl.id_543 ca.jw.es_332
  0x31001b2a, 0x0f001f1a, 0x1200090b, 0x171604a9,   // tr.az.un_970 cy.lv.un_760  pl.hu.un_520 fi.hr.sr_544
  0x0a0711ee, 0x16070612, 0x0f130ead, 0x111e1c02,   // ro.bg.mk_422 de.it.hr_654  is.et.lv_643 id.ms.ro_222
  0x2a3f0355, 0x0c6b080c, 0x011c08a0, 0x122d190d,   // nl.af.mt_442 no.ceb.sv_543  no.id.en_322 gl.sk.hu_554
  // [2030]
  0x0b550a0c, 0x04100704, 0x1100231b, 0x03070508,   // pt.rw.es_543 bg.be.ru_332  ca.ro.un_770 fr.it.nl_443
  0x08272104, 0x1e210307, 0x04110713, 0x2b061fee,   // jw.gd.no_332 nl.jw.ms_432  bg.ro.ru_665 cy.de.vi_422
  0x02001702, 0x08002711, 0x06021255, 0x53210307,   // sr.da.un_220 gd.no.un_630  hu.da.de_442 nl.jw.ht_432
  0x3f060355, 0x55006423, 0x0500070d, 0x1e001c2b,   // nl.de.af_442 lg.rw.un_880  it.fr.un_540 id.ms.un_980
  // [2040]
  0x0627180d, 0x123f0107, 0x17002d0c, 0x03061802,   // ga.gd.de_554 en.af.hu_432  sk.sr.un_530 ga.de.nl_222
  0x530321ee, 0x6b006e12, 0x033f2004, 0x172d0d0d,   // jw.nl.ht_422 blu.ceb.un_640  sq.af.nl_332 cs.sk.sr_554
  0x1f200304, 0x060e0ca0, 0x031a6b0c, 0x170a0808,   // nl.sq.cy_332 sv.is.de_322  ceb.tl.nl_543 uk.mk.sr_443
  0x102311a4, 0x0a04110d, 0x07041712, 0x18003f07,   // ro.ca.lt_433 ro.ru.mk_554  sr.ru.bg_654 af.ga.un_420
  // [2050]
  0x016b0307, 0x23001104, 0x13002722, 0x3f2127a0,   // nl.ceb.en_432 ro.ca.un_320  gd.et.un_870 gd.jw.af_322
  0x6b002014, 0x25123107, 0x021b2312, 0x03001802,   // sq.ceb.un_660 az.hu.eu_432  ca.tr.da_654 ga.nl.un_220
  0x53002819, 0x13271808, 0x02530c09, 0x31002b04,   // sw.ht.un_750 ga.gd.et_443  sv.ht.da_444 vi.az.un_320
  0x0d130904, 0x13080604, 0x530121a0, 0x21002707,   // hi.bh.ne_332 de.no.et_332  jw.en.ht_322 gd.jw.un_420
  // [2060]
  0x18271f07, 0x0e000505, 0x01210307, 0x06002104,   // cy.gd.ga_432 fr.is.un_330  nl.jw.en_432 jw.de.un_320
  0x0d001c21, 0x01532712, 0x1f3f010c, 0x5500282b,   // mr.ne.un_860 gd.ht.en_654  en.af.cy_543 sw.rw.un_980
  0x25000307, 0x03003f08, 0x0800060d, 0x042006ee,   // nl.eu.un_420 af.nl.un_430  de.no.un_540 de.sq.fi_422
  0x0417075a, 0x2700010d, 0x040e08ad, 0x0a17040c,   // bg.sr.ru_553 en.gd.un_540  no.is.fi_643 ru.sr.mk_543
  // [2070]
  0x040a1708, 0x55205307, 0x286455ec, 0x2d170da0,   // sr.mk.ru_443 ht.sq.rw_432  rw.lg.sw_644 cs.sr.sk_322
  0x20001c02, 0x0d000902, 0x100a17ee, 0x2d290f04,   // id.sq.un_220 hi.ne.un_220  sr.mk.be_422 lv.sl.sk_332
  0x0b1918a9, 0x041708ee, 0x20002a09, 0x172a12ad,   // ga.gl.es_544 uk.sr.ru_422  mt.sq.un_440 hu.mt.sr_643
  0x06551305, 0x0613290b, 0x2d0920ec, 0x6b020cec,   // et.rw.de_333 sl.et.de_542  sq.pl.sk_644 sv.da.ceb_644
  // [2080]
  0x17206e04, 0x04006409, 0x041b3107, 0x2a002904,   // blu.sq.sr_332 lg.fi.un_440  az.tr.fi_432 sl.mt.un_320
  0x29162d04, 0x28640407, 0x1800121b, 0x18211213,   // sk.hr.sl_332 fi.lg.sw_432  ur.ar.un_770 ur.fa.ar_665
  0x0d130911, 0x64046ba0, 0x162017a0, 0x0400080c,   // hi.bh.ne_653 ceb.fi.lg_322  sr.sq.hr_322 uk.ru.un_530
  0x29162da7, 0x641a28a0, 0x05001812, 0x0a190707,   // sk.hr.sl_532 sw.tl.lg_322  ga.fr.un_640 it.gl.pt_432
  // [2090]
  0x1e211ca4, 0x2d1707a0, 0x2a001218, 0x17202a0c,   // id.jw.ms_433 it.sr.sk_322  hu.mt.un_740 mt.sq.sr_543
  0x0c121714, 0x0d001c1a, 0x0b00180b, 0x20120ca6,   // sr.hu.sv_666 mr.ne.un_760  ga.es.un_520 sv.hu.sq_521
  0x176e200c, 0x010c0aee, 0x20006e14, 0x0700290e,   // sq.blu.sr_543 pt.sv.en_422  blu.sq.un_660 sl.it.un_550
  0x0d1c09ee, 0x0c002504, 0x0e1208a4, 0x10020f07,   // hi.mr.ne_422 eu.sv.un_320  no.hu.is_433 lv.da.lt_432
  // [20a0]
  0x12010c0b, 0x131629a9, 0x281a6407, 0x0d1c09af,   // sv.en.hu_542 sl.hr.et_544  lg.tl.sw_432 hi.mr.ne_655
  0x20001312, 0x55291602, 0x170a110c, 0x18000709,   // et.sq.un_640 hr.sl.rw_222  ro.mk.sr_543 it.ga.un_440
  0x13640407, 0x06080212, 0x641304ec, 0x090d1caf,   // fi.lg.et_432 da.no.de_654  fi.et.lg_644 mr.ne.hi_655
  0x05000113, 0x2d100f0c, 0x0e021ba4, 0x13000d04,   // en.fr.un_650 lv.lt.sk_543  tr.da.is_433 ne.bh.un_320
  // [20b0]
  0x55001602, 0x0f003f02, 0x16311ba0, 0x20005505,   // hr.rw.un_220 af.lv.un_220  tr.az.hr_322 rw.sq.un_330
  0x0a170407, 0x3f0604a4, 0x07000421, 0x0802040c,   // ru.sr.mk_432 fi.de.af_433  ru.bg.un_860 fi.da.no_543
  0x0700190d, 0x0317020c, 0x191617a0, 0x0c271807,   // gl.it.un_540 da.sr.nl_543  sr.hr.gl_322 ga.gd.sv_432
  0x1f000914, 0x3f001005, 0x0c081304, 0x13640404,   // pl.cy.un_660 lt.af.un_330  et.no.sv_332 fi.lg.et_332
  // [20c0]
  0x5500060c, 0x13090dee, 0x311c23a4, 0x17000404,   // de.rw.un_530 ne.hi.bh_422  ca.id.az_433 ru.sr.un_320
  0x3f021ba0, 0x10060f07, 0x2d0d20a0, 0x060412a0,   // tr.da.af_322 lv.de.lt_432  sq.cs.sk_322 hu.fi.de_322
  0x0300130c, 0x2500231b, 0x01001207, 0x080601a0,   // et.nl.un_530 ca.eu.un_770  hu.en.un_420 en.de.no_322
  0x08041005, 0x06000811, 0x070a040b, 0x1f122713,   // lt.fi.no_333 no.de.un_630  ru.mk.bg_542 gd.hu.cy_665
  // [20d0]
  0x53000513, 0x0a0711ac, 0x10070808, 0x100704ec,   // fr.ht.un_650 ro.bg.mk_632  uk.bg.be_443 ru.bg.be_644
  0x1f00110c, 0x0c0406a7, 0x120613a7, 0x10002905,   // ro.cy.un_530 de.fi.sv_532  et.de.hu_532 sl.lt.un_330
  0x1c130911, 0x0b001907, 0x0a100802, 0x12001102,   // hi.bh.mr_653 gl.es.un_420  uk.be.mk_222 ro.hu.un_220
  0x0d001602, 0x012718a0, 0x10060404, 0x050401a4,   // hr.cs.un_220 ga.gd.en_322  fi.de.lt_332 en.fi.fr_433
  // [20e0]
  0x1c0201a6, 0x0e060fa0, 0x31002004, 0x040a07ec,   // en.da.id_521 lv.de.is_322  sq.az.un_320 bg.mk.ru_644
  0x20000302, 0x13006b08, 0x2800530d, 0x3f280302,   // nl.sq.un_220 ceb.et.un_430  ht.sw.un_540 nl.sw.af_222
  0x10002d0c, 0x0d0929a7, 0x0d092d04, 0x23290d07,   // sk.lt.un_530 sl.pl.cs_532  sk.pl.cs_332 cs.sl.ca_432
  0x0f001607, 0x64060402, 0x0d002905, 0x1f000919,   // hr.lv.un_420 fi.de.lg_222  sl.cs.un_330 pl.cy.un_750
  // [20f0]
  0x060e1304, 0x170d16a4, 0x01130455, 0x1b0121a0,   // et.is.de_332 hr.cs.sr_433  fi.et.en_442 jw.en.tr_322
  0x0e080205, 0x25101faf, 0x1c006412, 0x0e060ca0,   // da.no.is_333 cy.lt.eu_655  lg.id.un_640 sv.de.is_322
  0x01001102, 0x182001a0, 0x0200290e, 0x211e1c05,   // ro.en.un_220 en.sq.ga_322  sl.da.un_550 id.ms.jw_333
  0x100b0955, 0x31000a0d, 0x3f6b1a04, 0x55642811,   // pl.es.lt_442 pt.az.un_540  tl.ceb.af_332 sw.lg.rw_653
  // [2100]
  0x2d096e55, 0x07040aa0, 0x531205a4, 0x0e04130c,   // blu.pl.sk_442 mk.ru.bg_322  fr.hu.ht_433 et.fi.is_543
  0x64005314, 0x2b0f1107, 0x16040e04, 0x5500641a,   // ht.lg.un_660 ro.lv.vi_432  is.fi.hr_332 lg.rw.un_760
  0x1b001108, 0x060f25a4, 0x13090d14, 0x17160aa0,   // ro.tr.un_430 eu.lv.de_433  ne.hi.bh_666 pt.hr.sr_322
  0x0d002902, 0x050e2105, 0x0a07170c, 0x10170702,   // sl.cs.un_220 jw.is.fr_333  sr.bg.mk_543 bg.sr.be_222
  // [2110]
  0x6b020509, 0x21006b14, 0x1f000913, 0x28001009,   // fr.da.ceb_444 ceb.jw.un_660  pl.cy.un_650 lt.sw.un_440
  0x29060da7, 0x171610a9, 0x1104070c, 0x1c1f1e0b,   // cs.de.sl_532 lt.hr.sr_544  bg.ru.ro_543 ms.cy.id_542
  0x25082aa4, 0x13000409, 0x21286b04, 0x122118af,   // mt.no.eu_433 fi.et.un_440  ceb.sw.jw_332 ar.fa.ur_655
  0x02006e19, 0x29200311, 0x2d0f090c, 0x21121811,   // blu.da.un_750 nl.sq.sl_653  pl.lv.sk_543 ar.ur.fa_653
  // [2120]
  0x29082d07, 0x073f08a0, 0x2112110c, 0x17000a12,   // sk.no.sl_432 no.af.it_322  ro.hu.jw_543 mk.sr.un_640
  0x55645312, 0x19000405, 0x28002113, 0x190b0aa0,   // ht.lg.rw_654 fi.gl.un_330  jw.sw.un_650 pt.es.gl_322
  0x21000509, 0x0e000808, 0x23002521, 0x201304a4,   // fr.jw.un_440 no.is.un_430  eu.ca.un_860 fi.et.sq_433
  0x64001908, 0x06000704, 0x13090802, 0x12640713,   // gl.lg.un_430 it.de.un_320  no.pl.et_222 it.lg.hu_665
  // [2130]
  0x12000913, 0x190b0ca4, 0x190a0b0e, 0x040710a4,   // pl.hu.un_650 sv.es.gl_433  es.pt.gl_555 be.bg.ru_433
  0x2d280b02, 0x1c13090c, 0x23062560, 0x046455ee,   // es.sw.sk_222 hi.bh.mr_543  eu.de.ca_664 rw.lg.fi_422
  0x0f050307, 0x3f006e08, 0x170f1607, 0x12000922,   // nl.fr.lv_432 blu.af.un_430  hr.lv.sr_432 pl.hu.un_870
  0x0e001904, 0x3f000307, 0x55000608, 0x1b00210c,   // gl.is.un_320 nl.af.un_420  de.rw.un_430 jw.tr.un_530
  // [2140]
  0x190a0b14, 0x2d0d0b02, 0x0a10170c, 0x0f00100e,   // es.pt.gl_666 es.cs.sk_222  sr.be.mk_543 lt.lv.un_550
  0x28645505, 0x0e55205a, 0x0e006405, 0x040811a9,   // rw.lg.sw_333 sq.rw.is_553  lg.is.un_330 ro.uk.ru_544
  0x0b251955, 0x18002107, 0x64005502, 0x3f0a2504,   // gl.eu.es_442 jw.ga.un_420  rw.lg.un_220 eu.pt.af_332
  0x230b25a0, 0x08000121, 0x071801a4, 0x180e1907,   // eu.es.ca_322 en.no.un_860  en.ga.it_433 gl.is.ga_432
  // [2150]
  0x17100813, 0x070601ee, 0x08001011, 0x13040e10,   // uk.be.sr_665 en.de.it_422  be.uk.un_630 is.fi.et_642
  0x5300050e, 0x063f130c, 0x0a3f0802, 0x01046ea7,   // fr.ht.un_550 et.af.de_543  no.af.pt_222 blu.fi.en_532
  0x0655200d, 0x27060405, 0x21001829, 0x07001705,   // sq.rw.de_554 fi.de.gd_333  ar.fa.un_960 sr.bg.un_330
  0x1e2120a0, 0x046e13ec, 0x08041108, 0x190b2305,   // sq.jw.ms_322 et.blu.fi_644  ro.ru.uk_443 ca.es.gl_333
  // [2160]
  0x09000d18, 0x130c08ec, 0x2d0d1faf, 0x2900160e,   // ne.hi.un_740 no.sv.et_644  cy.cs.sk_655 hr.sl.un_550
  0x55536ba4, 0x0b00020d, 0x1200251b, 0x2d0d11ee,   // ceb.ht.rw_433 da.es.un_540  eu.hu.un_770 ro.cs.sk_422
  0x2d0d03a0, 0x0d122d55, 0x1c002109, 0x20552804,   // nl.cs.sk_322 sk.hu.cs_442  jw.id.un_440 sw.rw.sq_332
  0x0a000304, 0x0b002513, 0x0a000502, 0x07040a14,   // nl.pt.un_320 eu.es.un_650  fr.pt.un_220 mk.ru.bg_666
  // [2170]
  0x0a000b07, 0x04001721, 0x0c0208a4, 0x10000308,   // es.pt.un_420 sr.ru.un_860  no.da.sv_433 nl.lt.un_430
  0x0700111a, 0x20000e07, 0x55002821, 0x091c0d60,   // ro.bg.un_760 is.sq.un_420  sw.rw.un_860 ne.mr.hi_664
  0x17070809, 0x0e00060c, 0x2a190107, 0x043f03ee,   // uk.bg.sr_444 de.is.un_530  en.gl.mt_432 nl.af.fi_422
  0x1a005504, 0x130364a4, 0x3f0e03ee, 0x3f080304,   // rw.tl.un_320 lg.nl.et_433  nl.is.af_422 nl.no.af_332
  // [2180]
  0x031c3fa0, 0x16002104, 0x12080204, 0x04003f0e,   // af.id.nl_322 jw.hr.un_320  da.no.hu_332 af.fi.un_550
  0x0413030e, 0x06000409, 0x070a11af, 0x29000d07,   // nl.et.fi_555 fi.de.un_440  ro.mk.bg_655 cs.sl.un_420
  0x131c09ad, 0x0200120c, 0x12556409, 0x0700040e,   // hi.mr.bh_643 hu.da.un_530  lg.rw.hu_444 ru.bg.un_550
  0x1b000d02, 0x2700120d, 0x0c001f05, 0x3f031aa7,   // cs.tr.un_220 hu.gd.un_540  cy.sv.un_330 tl.nl.af_532
  // [2190]
  0x29001608, 0x0c2d09ad, 0x081711ee, 0x3f00030d,   // hr.sl.un_430 pl.sk.sv_643  ro.sr.uk_422 nl.af.un_540
  0x550106a0, 0x2d1c3f02, 0x3f072307, 0x0600130e,   // de.en.rw_322 af.id.sk_222  ca.it.af_432 et.de.un_550
  0x06130407, 0x6e00010d, 0x170807a6, 0x1f000912,   // fi.et.de_432 en.blu.un_540  bg.uk.sr_521 pl.cy.un_640
  0x16002907, 0x12002d04, 0x172d0d04, 0x17040813,   // sl.hr.un_420 sk.hu.un_320  cs.sk.sr_332 uk.ru.sr_665
  // [21a0]
  0x12211812, 0x076b23a0, 0x2003050c, 0x21003f04,   // ar.fa.ur_654 ca.ceb.it_322  fr.nl.sq_543 af.jw.un_320
  0x190b0a09, 0x2d000912, 0x10190b13, 0x1900100c,   // pt.es.gl_444 pl.sk.un_640  es.gl.lt_665 lt.gl.un_530
  0x13000d1a, 0x1700080c, 0x0b001008, 0x2b311ba0,   // ne.bh.un_760 uk.sr.un_530  lt.es.un_430 tr.az.vi_322
  0x2307125a, 0x0a07010c, 0x0a000e0b, 0x033f0aa0,   // hu.it.ca_553 en.it.pt_543  is.pt.un_520 pt.af.nl_322
  // [21b0]
  0x08092a0c, 0x07042a05, 0x0d001c0d, 0x100b0a08,   // mt.pl.no_543 mt.fi.it_333  mr.ne.un_540 pt.es.lt_443
  0x190b25ee, 0x3f1303a4, 0x1821125a, 0x170a0805,   // eu.es.gl_422 nl.et.af_433  ur.fa.ar_553 uk.mk.sr_333
  0x030c06a0, 0x121b2512, 0x2b002d08, 0x23030512,   // de.sv.nl_322 eu.tr.hu_654  sk.vi.un_430 fr.nl.ca_654
  0x0f04130c, 0x20555307, 0x04170805, 0x21086b04,   // et.fi.lv_543 ht.rw.sq_432  uk.sr.ru_333 ceb.no.jw_332
  // [21c0]
  0x0e2d0d12, 0x0510280b, 0x0c1a02ee, 0x10000a0e,   // cs.sk.is_654 sw.lt.fr_542  da.tl.sv_422 pt.lt.un_550
  0x0c060ea0, 0x0f100807, 0x2b0302a0, 0x10000b05,   // is.de.sv_322 no.lt.lv_432  da.nl.vi_322 es.lt.un_330
  0x061a0807, 0x130406ee, 0x050f100c, 0x0c002a0d,   // no.tl.de_432 de.fi.et_422  lt.lv.fr_543 mt.sv.un_540
  0x02080c07, 0x25000f23, 0x0c026b07, 0x0a101755,   // sv.no.da_432 lv.eu.un_880  ceb.da.sv_432 sr.be.mk_442
  // [21d0]
  0x271118ad, 0x3f002512, 0x10232513, 0x190b0e0e,   // ga.ro.gd_643 eu.af.un_640  eu.ca.lt_665 is.es.gl_555
  0x2a100808, 0x25000f1a, 0x08230507, 0x08171007,   // no.lt.mt_443 lv.eu.un_760  fr.ca.no_432 be.sr.uk_432
  0x2b000b04, 0x271806a4, 0x112916a0, 0x19230b07,   // es.vi.un_320 de.ga.gd_433  hr.sl.ro_322 es.ca.gl_432
  0x03043fa9, 0x2723010c, 0x02080c0c, 0x0a071108,   // af.fi.nl_544 en.ca.gd_543  sv.no.da_543 ro.bg.mk_443
  // [21e0]
  0x183127ee, 0x01116ba0, 0x08070a07, 0x17052907,   // gd.az.ga_422 ceb.ro.en_322  mk.bg.uk_432 sl.fr.sr_432
  0x21531cec, 0x1a2a0107, 0x31080ea0, 0x20002a0d,   // id.ht.jw_644 en.mt.tl_432  is.no.az_322 mt.sq.un_540
  0x02000504, 0x25061f5a, 0x641a6b0c, 0x09062507,   // fr.da.un_320 cy.de.eu_553  ceb.tl.lg_543 eu.de.pl_432
  0x0c1b2a0c, 0x0e06075a, 0x12080e08, 0x1a645307,   // mt.tr.sv_543 it.de.is_553  is.no.hu_443 ht.lg.tl_432
  // [21f0]
  0x08211108, 0x3f171613, 0x1c000d2b, 0x21002522,   // ro.jw.no_443 hr.sr.af_665  ne.mr.un_980 eu.jw.un_870
  0x050f0911, 0x08041011, 0x1e000b13, 0x0a111713,   // pl.lv.fr_653 lt.fi.no_653  es.ms.un_650 sr.ro.mk_665
  0x062109a9, 0x3f200ca0, 0x1b13125a, 0x0e190b0d,   // pl.jw.de_544 sv.sq.af_322  hu.et.tr_553 es.gl.is_554
  0x171116ac, 0x1f030107, 0x09131c60, 0x212825ee,   // hr.ro.sr_632 en.nl.cy_432  mr.bh.hi_664 eu.sw.jw_422
  // [2200]
  0x18000912, 0x040a0808, 0x3f002a04, 0x1c0d1305,   // pl.ga.un_640 uk.mk.ru_443  mt.af.un_320 bh.ne.mr_333
  0x09161aee, 0x1f006405, 0x64002804, 0x13091c11,   // tl.hr.pl_422 lg.cy.un_330  sw.lg.un_320 mr.hi.bh_653
  0x02001e02, 0x172916af, 0x04000a1b, 0x17161204,   // ms.da.un_220 hr.sl.sr_655  mk.ru.un_770 hu.hr.sr_332
  0x06041008, 0x20000a02, 0x230e06ec, 0x0f041007,   // lt.fi.de_443 pt.sq.un_220  de.is.ca_644 lt.fi.lv_432
  // [2210]
  0x022d250c, 0x080710a4, 0x3f03010c, 0x100e0fa0,   // eu.sk.da_543 be.bg.uk_433  en.nl.af_543 lv.is.lt_322
  0x0a1710a0, 0x3f2825ee, 0x203f64a0, 0x0400171a,   // be.sr.mk_322 eu.sw.af_422  lg.af.sq_322 sr.ru.un_760
  0x13091c09, 0x0e060f13, 0x12006419, 0x0e000212,   // mr.hi.bh_444 lv.de.is_665  lg.hu.un_750 da.is.un_640
  0x130d1c13, 0x060f10ad, 0x11002b20, 0x29001012,   // mr.ne.bh_665 lt.lv.de_643  vi.ro.un_850 lt.sl.un_640
  // [2220]
  0x13061004, 0x0f2506a4, 0x121a6409, 0x041710a6,   // lt.de.et_332 de.eu.lv_433  lg.tl.hu_444 be.sr.ru_521
  0x04100604, 0x3f09085a, 0x2300050d, 0x0f0e1007,   // de.lt.fi_332 no.pl.af_553  fr.ca.un_540 lt.is.lv_432
  0x1b1a31ec, 0x0c2308a0, 0x25000d14, 0x1e1c01a0,   // az.tl.tr_644 no.ca.sv_322  cs.eu.un_660 en.id.ms_322
  0x55001e13, 0x010608a4, 0x1e1c12a4, 0x64555313,   // ms.rw.un_650 no.de.en_433  hu.id.ms_433 ht.rw.lg_665
  // [2230]
  0x1a6b530c, 0x2d060f0c, 0x2d1b3112, 0x532855af,   // ht.ceb.tl_543 lv.de.sk_543  az.tr.sk_654 rw.sw.ht_655
  0x2a0655a7, 0x0a170709, 0x3f5364ec, 0x292d17a0,   // rw.de.mt_532 bg.sr.mk_444  lg.ht.af_644 sr.sk.sl_322
  0x0e001314, 0x1b6b53ad, 0x1c000504, 0x53281ca4,   // et.is.un_660 ht.ceb.tr_643  fr.id.un_320 id.sw.ht_433
  0x12006422, 0x05271855, 0x056428a0, 0x3f001702,   // lg.hu.un_870 ga.gd.fr_442  sw.lg.fr_322 sr.af.un_220
  // [2240]
  0x290d2dec, 0x0e072a08, 0x19210504, 0x1e1c04af,   // sk.cs.sl_644 mt.it.is_443  fr.jw.gl_332 fi.id.ms_655
  0x201a6b04, 0x3f0304a4, 0x10040813, 0x641c210b,   // ceb.tl.sq_332 fi.nl.af_433  uk.ru.be_665 jw.id.lg_542
  0x133f040c, 0x20000f12, 0x170a070c, 0x551b530d,   // fi.af.et_543 lv.sq.un_640  bg.mk.sr_543 ht.tr.rw_554
  0x070a110d, 0x53553f0c, 0x28005305, 0x1a64535a,   // ro.mk.bg_554 af.rw.ht_543  ht.sw.un_330 ht.lg.tl_553
  // [2250]
  0x20005322, 0x00002a2d, 0x0408110c, 0x171611a9,   // ht.sq.un_870 mt.un.un_A00  ro.uk.ru_543 ro.hr.sr_544
  0x13010511, 0x0b201104, 0x01080307, 0x2d0d04a4,   // fr.en.et_653 ro.sq.es_332  nl.no.en_432 fi.cs.sk_433
  0x0a0807af, 0x112d0d04, 0x110701a4, 0x0e3f0204,   // bg.uk.mk_655 cs.sk.ro_332  en.it.ro_433 da.af.is_332
  0x11001c13, 0x08040713, 0x0000282d, 0x016413ee,   // id.ro.un_650 bg.ru.uk_665  sw.un.un_A00 et.lg.en_422
  // [2260]
  0x192528ec, 0x10112808, 0x0c051fa0, 0x04080713,   // sw.eu.gl_644 sw.ro.lt_443  cy.fr.sv_322 bg.uk.ru_665
  0x04170a05, 0x536b2012, 0x1f1e1c14, 0x17002012,   // mk.sr.ru_333 sq.ceb.ht_654  id.ms.cy_666 sq.sr.un_640
  0x101a6bee, 0x64051f0c, 0x1f020811, 0x04000b05,   // ceb.tl.lt_422 cy.fr.lg_543  no.da.cy_653 es.fi.un_330
  0x0c0f20a4, 0x0d042aa0, 0x080f02a0, 0x0c1a6b0c,   // sq.lv.sv_433 mt.fi.cs_322  da.lv.no_322 ceb.tl.sv_543
  // [2270]
  0x2a0c20a0, 0x6e6b1f04, 0x3f25280c, 0x06001e04,   // sq.sv.mt_322 cy.ceb.blu_332  sw.eu.af_543 ms.de.un_320
  0x28082004, 0x551b2107, 0x17291660, 0x64001c05,   // sq.no.sw_332 jw.tr.rw_432  hr.sl.sr_664 id.lg.un_330
  0x0b000a05, 0x3120180c, 0x283f2004, 0x0300200d,   // pt.es.un_330 ga.sq.az_543  sq.af.sw_332 sq.nl.un_540
  0x0c000e0c, 0x13001c13, 0x27003f02, 0x20002109,   // is.sv.un_530 mr.bh.un_650  af.gd.un_220 jw.sq.un_440
  // [2280]
  0x0b0a010c, 0x041011a7, 0x1c002121, 0x1e012304,   // en.pt.es_543 ro.lt.fi_532  jw.id.un_860 ca.en.ms_332
  0x3f0601a6, 0x1e3f0604, 0x10000805, 0x09002911,   // en.de.af_521 de.af.ms_332  no.lt.un_330 sl.pl.un_630
  0x1117160c, 0x1b001f0b, 0x10005307, 0x043f1b0c,   // hr.sr.ro_543 cy.tr.un_520  ht.lt.un_420 tr.af.fi_543
  0x06002804, 0x2a1a6b5a, 0x291304ec, 0x2004010c,   // sw.de.un_320 ceb.tl.mt_553  fi.et.sl_644 en.fi.sq_543
  // [2290]
  0x6b2a2007, 0x04001c0d, 0x21001220, 0x030c02a0,   // sq.mt.ceb_432 id.fi.un_540  ur.fa.un_850 da.sv.nl_322
  0x0700041b, 0x0400200d, 0x00001624, 0x3f082007,   // ru.bg.un_770 sq.fi.un_540  hr.un.un_900 sq.no.af_432
  0x100f0808, 0x1f000613, 0x3f001f0c, 0x3f000609,   // no.lv.lt_443 de.cy.un_650  cy.af.un_530 de.af.un_440
  0x080620a0, 0x23002a02, 0x0c0820a0, 0x12001b05,   // sq.de.no_322 mt.ca.un_220  sq.no.sv_322 tr.hu.un_330
  // [22a0]
  0x1b211c02, 0x55002114, 0x641b310c, 0x0d000912,   // id.jw.tr_222 jw.rw.un_660  az.tr.lg_543 hi.ne.un_640
  0x1f006414, 0x1a04130c, 0x1b001f19, 0x0d091309,   // lg.cy.un_660 et.fi.tl_543  cy.tr.un_750 bh.hi.ne_444
  0x13041a0c, 0x040717a0, 0x07100a04, 0x171116a0,   // tl.fi.et_543 sr.bg.ru_322  mk.be.bg_332 hr.ro.sr_322
  0x02000c0e, 0x31201bec, 0x53001609, 0x05270da0,   // sv.da.un_550 tr.sq.az_644  hr.ht.un_440 cs.gd.fr_322
  // [22b0]
  0x19120a12, 0x08021ba4, 0x1700291a, 0x0e002a02,   // pt.hu.gl_654 tr.da.no_433  sl.sr.un_760 mt.is.un_220
  0x27250504, 0x6b1a55ee, 0x0b05190c, 0x1c003108,   // fr.eu.gd_332 rw.tl.ceb_422  gl.fr.es_543 az.id.un_430
  0x6e00180e, 0x3155210c, 0x0a006b07, 0x0a101708,   // ga.blu.un_550 jw.rw.az_543  ceb.pt.un_420 sr.be.mk_443
  0x1a003122, 0x6b000a09, 0x211e1c02, 0x1b281a07,   // az.tl.un_870 pt.ceb.un_440  id.ms.jw_222 tl.sw.tr_432
  // [22c0]
  0x1f000204, 0x3f1f6407, 0x3f001908, 0x641c31a4,   // da.cy.un_320 lg.cy.af_432  gl.af.un_430 az.id.lg_433
  0x2100181b, 0x272128ee, 0x280804a4, 0x131c090d,   // ar.fa.un_770 sw.jw.gd_422  fi.no.sw_433 hi.mr.bh_554
  0x53181304, 0x282b04ec, 0x1b003107, 0x21003119,   // et.ga.ht_332 fi.vi.sw_644  az.tr.un_420 az.jw.un_750
  0x07001113, 0x1702080b, 0x2b0428ee, 0x1a6b1ba4,   // ro.it.un_650 no.da.sr_542  sw.fi.vi_422 tr.ceb.tl_433
  // [22d0]
  0x111f070c, 0x2b001a0c, 0x08130e05, 0x230a0bee,   // it.cy.ro_543 tl.vi.un_530  is.et.no_333 es.pt.ca_422
  0x1c000913, 0x07001a22, 0x530e1ca4, 0x535531ec,   // hi.mr.un_650 tl.it.un_870  id.is.ht_433 az.rw.ht_644
  0x20001004, 0x10002b14, 0x08070a0d, 0x21005502,   // lt.sq.un_320 vi.lt.un_660  mk.bg.uk_554 rw.jw.un_220
  0x0b6b070c, 0x2500061a, 0x0e091f07, 0x531b31a4,   // it.ceb.es_543 de.eu.un_760  cy.pl.is_432 az.tr.ht_433
  // [22e0]
  0x16092905, 0x09075508, 0x531b31a9, 0x040a1712,   // sl.pl.hr_333 rw.it.pl_443  az.tr.ht_544 sr.mk.ru_654
  0x3f2011a0, 0x2864550c, 0x531a31ad, 0x0b2d0d08,   // ro.sq.af_322 rw.lg.sw_543  az.tl.ht_643 cs.sk.es_443
  0x1f290909, 0x080453a4, 0x6b011fa0, 0x07132107,   // pl.sl.cy_444 ht.fi.no_433  cy.en.ceb_322 jw.et.it_432
  0x6b280708, 0x060f04ee, 0x0c081fee, 0x2b0407ad,   // it.sw.ceb_443 fi.lv.de_422  cy.no.sv_422 it.fi.vi_643
  // [22f0]
  0x0a005508, 0x17070409, 0x1c001304, 0x102d0f08,   // rw.pt.un_430 ru.bg.sr_444  et.id.un_320 lv.sk.lt_443
  0x2b2804af, 0x101f180c, 0x0f00060b, 0x06003f13,   // fi.sw.vi_655 ga.cy.lt_543  de.lv.un_520 af.de.un_650
  0x13180e04, 0x64310a02, 0x020e3108, 0x551a6b08,   // is.ga.et_332 pt.az.lg_222  az.is.da_443 ceb.tl.rw_443
  0x0d006b04, 0x1617070c, 0x1c101fee, 0x0a07280c,   // ceb.cs.un_320 it.sr.hr_543  cy.lt.id_422 sw.it.pt_543
  // [2300]
  0x20230a08, 0x07005509, 0x00000a37, 0x190a0bec,   // pt.ca.sq_443 rw.it.un_440  pt.un.un_B00 es.pt.gl_644
  0x17290908, 0x1a075505, 0x1800100b, 0x12000619,   // pl.sl.sr_443 rw.it.tl_333  lt.ga.un_520 de.hu.un_750
  0x09003f04, 0x1a001f07, 0x01000808, 0x0d1716a9,   // af.pl.un_320 cy.tl.un_420  no.en.un_430 hr.sr.cs_544
  0x19060807, 0x18001f1a, 0x100f0aee, 0x1f211c55,   // no.de.gl_432 cy.ga.un_760  pt.lv.lt_422 id.jw.cy_442
  // [2310]
  0x19252104, 0x1e1c04a4, 0x0e066ba0, 0x10081713,   // jw.eu.gl_332 fi.id.ms_433  ceb.de.is_322 sr.uk.be_665
  0x19000a09, 0x040708ec, 0x04001f23, 0x27060155,   // pt.gl.un_440 uk.bg.ru_644  cy.fi.un_880 en.de.gd_442
  0x2a002004, 0x17290aad, 0x021304a4, 0x3f1e6b07,   // sq.mt.un_320 pt.sl.sr_643  fi.et.da_433 ceb.ms.af_432
  0x0a11100c, 0x17002921, 0x04002304, 0x0a0811a7,   // be.ro.mk_543 sl.sr.un_860  ca.fi.un_320 ro.uk.mk_532
  // [2320]
  0x04311ea4, 0x1b2b010c, 0x07210aa0, 0x230b20ad,   // ms.az.fi_433 en.vi.tr_543  pt.jw.it_322 sq.es.ca_643
  0x100a17a4, 0x10000a1a, 0x6b001a0e, 0x08001019,   // sr.mk.be_433 mk.be.un_760  tl.ceb.un_550 be.uk.un_750
  0x01002307, 0x07000d0d, 0x066e0408, 0x0e000509,   // ca.en.un_420 cs.it.un_540  fi.blu.de_443 fr.is.un_440
  0x0a0613a0, 0x2d1105a9, 0x19171613, 0x292d0d09,   // et.de.pt_322 fr.ro.sk_544  hr.sr.gl_665 cs.sk.sl_444
  // [2330]
  0x1b12200c, 0x0500010c, 0x07050fa0, 0x0d001c22,   // sq.hu.tr_543 en.fr.un_530  lv.fr.it_322 mr.ne.un_870
  0x0300041a, 0x3104200c, 0x19000c04, 0x170708a0,   // fi.nl.un_760 sq.fi.az_543  sv.gl.un_320 uk.bg.sr_322
  0x04002022, 0x13000e12, 0x040a0714, 0x1306040c,   // sq.fi.un_870 is.et.un_640  bg.mk.ru_666 fi.de.et_543
  0x01001f04, 0x311b11a4, 0x180427af, 0x5525160c,   // cy.en.un_320 ro.tr.az_433  gd.fi.ga_655 hr.eu.rw_543
  // [2340]
  0x250412af, 0x181f2308, 0x18271fee, 0x06001f09,   // hu.fi.eu_655 ca.cy.ga_443  cy.gd.ga_422 cy.de.un_440
  0x081704a4, 0x0300252a, 0x091716ec, 0x27181f04,   // ru.sr.uk_433 eu.nl.un_970  hr.sr.pl_644 cy.ga.gd_332
  0x04000604, 0x04080705, 0x18211214, 0x011a09ee,   // de.fi.un_320 bg.uk.ru_333  ur.fa.ar_666 pl.tl.en_422
  0x09061004, 0x31000521, 0x08040e04, 0x131004ad,   // lt.de.pl_332 fr.az.un_860  is.fi.no_332 fi.lt.et_643
  // [2350]
  0x0900641a, 0x07000a19, 0x03040c07, 0x2d291704,   // lg.pl.un_760 mk.bg.un_750  sv.fi.nl_432 sr.sl.sk_332
  0x28106402, 0x040c08ad, 0x0a170712, 0x060c0302,   // lg.lt.sw_222 no.sv.fi_643  bg.sr.mk_654 nl.sv.de_222
  0x0f6b1a08, 0x29000913, 0x06171660, 0x171655ee,   // tl.ceb.lv_443 pl.sl.un_650  hr.sr.de_664 rw.hr.sr_422
  0x033f04a0, 0x071711a0, 0x1a136e04, 0x20061ea4,   // fi.af.nl_322 ro.sr.bg_322  blu.et.tl_332 ms.de.sq_433
  // [2360]
  0x170710a0, 0x080211ec, 0x281a0302, 0x0e042aaf,   // be.bg.sr_322 ro.da.no_644  nl.tl.sw_222 mt.fi.is_655
  0x211e28ee, 0x17080412, 0x2d000614, 0x1a0e6ba4,   // sw.ms.jw_422 ru.uk.sr_654  de.sk.un_660 ceb.is.tl_433
  0x07000a0c, 0x0e0413ad, 0x04080c04, 0x03006b05,   // mk.bg.un_530 et.fi.is_643  sv.no.fi_332 ceb.nl.un_330
  0x6400132a, 0x55642114, 0x3f002a12, 0x1a000702,   // et.lg.un_970 jw.lg.rw_666  mt.af.un_640 it.tl.un_220
  // [2370]
  0x0500230d, 0x6427130c, 0x641c21a0, 0x25001013,   // ca.fr.un_540 et.gd.lg_543  jw.id.lg_322 lt.eu.un_650
  0x08000414, 0x04110a04, 0x061f1055, 0x080e1005,   // ru.uk.un_660 mk.ro.ru_332  lt.cy.de_442 lt.is.no_333
  0x271801ee, 0x55001a04, 0x0e080c14, 0x6b001f0d,   // en.ga.gd_422 tl.rw.un_320  sv.no.is_666 cy.ceb.un_540
  0x1a002804, 0x29190a60, 0x06033f0c, 0x0f290d02,   // sw.tl.un_320 pt.gl.sl_664  af.nl.de_543 cs.sl.lv_222
  // [2380]
  0x0664035a, 0x29002d02, 0x04033faf, 0x311e1cee,   // nl.lg.de_553 sk.sl.un_220  af.nl.fi_655 id.ms.az_422
  0x6b310209, 0x3f0f28a0, 0x3f000504, 0x1b006404,   // da.az.ceb_444 sw.lv.af_322  fr.af.un_320 lg.tr.un_320
  0x10001804, 0x311b2a0c, 0x091c13ec, 0x2d0d6eee,   // ga.lt.un_320 mt.tr.az_543  bh.mr.hi_644 blu.cs.sk_422
  0x11190a0d, 0x0400180c, 0x1a0c1f04, 0x271118ec,   // pt.gl.ro_554 ga.fi.un_530  cy.sv.tl_332 ga.ro.gd_644
  // [2390]
  0x196b07a0, 0x2300251a, 0x02003107, 0x2d02060c,   // it.ceb.gl_322 eu.ca.un_760  az.da.un_420 de.da.sk_543
  0x23000a12, 0x3f0e0807, 0x0c0210a4, 0x1c211a07,   // pt.ca.un_640 no.is.af_432  lt.da.sv_433 tl.jw.id_432
  0x23000a1b, 0x0a000709, 0x18002708, 0x6b162da7,   // pt.ca.un_770 bg.mk.un_440  gd.ga.un_430 sk.hr.ceb_532
  0x0a1710af, 0x11002719, 0x04102511, 0x12181955,   // be.sr.mk_655 gd.ro.un_750  eu.lt.fi_653 gl.ga.hu_442
  // [23a0]
  0x536b01a0, 0x02000835, 0x0d291602, 0x29000713,   // en.ceb.ht_322 no.da.un_A90  hr.sl.cs_222 it.sl.un_650
  0x17100a09, 0x100904ec, 0x13271104, 0x6b181108,   // mk.be.sr_444 fi.pl.lt_644  ro.gd.et_332 ro.ga.ceb_443
  0x1000120e, 0x16000202, 0x13000b07, 0x08026b0c,   // hu.lt.un_550 da.hr.un_220  es.et.un_420 ceb.da.no_543
  0x0f3f10ac, 0x0c212502, 0x10002008, 0x0c120402,   // lt.af.lv_632 eu.jw.sv_222  sq.lt.un_430 fi.hu.sv_222
  // [23b0]
  0x0b1e1aa0, 0x13003f12, 0x132116a9, 0x0e000613,   // tl.ms.es_322 af.et.un_640  hr.jw.et_544 de.is.un_650
  0x1b230aee, 0x12000302, 0x07110a12, 0x0f00170c,   // pt.ca.tr_422 nl.hu.un_220  mk.ro.bg_654 sr.lv.un_530
  0x0a07080c, 0x01101a02, 0x01532704, 0x21000504,   // uk.bg.mk_543 tl.lt.en_222  gd.ht.en_332 fr.jw.un_320
  0x0c2308a4, 0x1f001007, 0x121f0409, 0x19001f1a,   // no.ca.sv_433 lt.cy.un_420  fi.cy.hu_444 cy.gl.un_760
  // [23c0]
  0x0a0411a4, 0x041f1207, 0x3f000807, 0x25171055,   // ro.ru.mk_433 hu.cy.fi_432  no.af.un_420 lt.sr.eu_442
  0x033f16a4, 0x0a170711, 0x10000f14, 0x102729ad,   // hr.af.nl_433 bg.sr.mk_653  lv.lt.un_660 sl.gd.lt_643
  0x1f001204, 0x55051107, 0x05005302, 0x090627a7,   // hu.cy.un_320 ro.fr.rw_432  ht.fr.un_220 gd.de.pl_532
  0x20001704, 0x27181104, 0x11270108, 0x6b190b0d,   // sr.sq.un_320 ro.ga.gd_332  en.gd.ro_443 es.gl.ceb_554
  // [23d0]
  0x191811a7, 0x016b1807, 0x18001b07, 0x0500111a,   // ro.ga.gl_532 ga.ceb.en_432  tr.ga.un_420 ro.fr.un_760
  0x23190b09, 0x011827a0, 0x20051a04, 0x17070aad,   // es.gl.ca_444 gd.ga.en_322  tl.fr.sq_332 mk.bg.sr_643
  0x17002913, 0x100f16a0, 0x64001107, 0x1c000d04,   // sl.sr.un_650 hr.lv.lt_322  ro.lg.un_420 cs.id.un_320
  0x05006b04, 0x072710ad, 0x05042005, 0x10002908,   // ceb.fr.un_320 lt.gd.it_643  sq.fi.fr_333 sl.lt.un_430
  // [23e0]
  0x20001213, 0x170507a4, 0x21005305, 0x1c13095a,   // hu.sq.un_650 it.fr.sr_433  ht.jw.un_330 hi.bh.mr_553
  0x0a001a04, 0x11002907, 0x01251107, 0x0c061313,   // tl.pt.un_320 sl.ro.un_420  ro.eu.en_432 et.de.sv_665
  0x27000104, 0x041101ad, 0x131804a4, 0x0d00290c,   // en.gd.un_320 en.ro.fi_643  fi.ga.et_433 sl.cs.un_530
  0x0f002509, 0x20000f0d, 0x11001b13, 0x290f100b,   // eu.lv.un_440 lv.sq.un_540  tr.ro.un_650 lt.lv.sl_542
  // [23f0]
  0x13090d09, 0x2829130b, 0x0f1009a7, 0x0e000108,   // ne.hi.bh_444 et.sl.sw_542  pl.lt.lv_532 en.is.un_430
  0x0200080c, 0x08020e07, 0x5355280c, 0x03021807,   // no.da.un_530 is.da.no_432  sw.rw.ht_543 ga.da.nl_432
  0x29191311, 0x2a1629a9, 0x5500291b, 0x181221a7,   // et.gl.sl_653 sl.hr.mt_544  sl.rw.un_770 fa.ur.ar_532
  0x0a0523ec, 0x132964ad, 0x0a171155, 0x11070a05,   // ca.fr.pt_644 lg.sl.et_643  ro.sr.mk_442 mk.bg.ro_333

  // [2400]
  0x011e1c04, 0x0810170c, 0x1200180e, 0x29090f07,   // id.ms.en_332 sr.be.uk_543  ar.ur.un_550 lv.pl.sl_432
  0x212502a0, 0x0e002922, 0x2d2916a0, 0x18000304,   // da.eu.jw_322 sl.is.un_870  hr.sl.sk_322 nl.ga.un_320
  0x11001013, 0x5529130c, 0x0b2510a4, 0x13552908,   // be.ro.un_650 et.sl.rw_543  lt.eu.es_433 sl.rw.et_443
  0x0b6e040d, 0x03041304, 0x0a2325a9, 0x13002908,   // fi.blu.es_554 et.fi.nl_332  eu.ca.pt_544 sl.et.un_430
  // [2410]
  0x0364040c, 0x6e1a1fa4, 0x0c12060c, 0x1f000808,   // fi.lg.nl_543 cy.tl.blu_433  de.hu.sv_543 no.cy.un_430
  0x64000421, 0x53040755, 0x03083f0b, 0x080253ee,   // fi.lg.un_860 it.fi.ht_442  af.no.nl_542 ht.da.no_422
  0x06022d04, 0x1708045a, 0x1b0a05ee, 0x0a050708,   // sk.da.de_332 ru.uk.sr_553  fr.pt.tr_422 it.fr.pt_443
  0x3f1a6b0c, 0x16000304, 0x6e6b06a0, 0x0f003f04,   // ceb.tl.af_543 nl.hr.un_320  de.ceb.blu_322 af.lv.un_320
  // [2420]
  0x130506a4, 0x18000807, 0x3f0608ee, 0x0f001104,   // de.fr.et_433 no.ga.un_420  no.de.af_422 ro.lv.un_320
  0x2d1b0905, 0x09180d02, 0x0c0e0804, 0x1b000a05,   // pl.tr.sk_333 cs.ga.pl_222  no.is.sv_332 pt.tr.un_330
  0x23003104, 0x04190ba0, 0x0e0c3f04, 0x1f270807,   // az.ca.un_320 es.gl.fi_322  af.sv.is_332 no.gd.cy_432
  0x080229a4, 0x1b003104, 0x23130707, 0x0e0802ee,   // sl.da.no_433 az.tr.un_320  it.et.ca_432 da.no.is_422
  // [2430]
  0x082a05a4, 0x3f1304a4, 0x17160302, 0x08000c05,   // fr.mt.no_433 fi.et.af_433  nl.hr.sr_222 sv.no.un_330
  0x0c3f080c, 0x033f25ac, 0x032a060c, 0x05072a55,   // no.af.sv_543 eu.af.nl_632  de.mt.nl_543 mt.it.fr_442
  0x231b0a04, 0x13000308, 0x130c11a6, 0x6b181ea0,   // pt.tr.ca_332 nl.et.un_430  ro.sv.et_521 ms.ga.ceb_322
  0x032a2d04, 0x3f062aa0, 0x1b0131ee, 0x08171014,   // sk.mt.nl_332 mt.de.af_322  az.en.tr_422 be.sr.uk_666
  // [2440]
  0x01000e0c, 0x11163fa0, 0x02000402, 0x12001602,   // is.en.un_530 af.hr.ro_322  fi.da.un_220 hr.hu.un_220
  0x040c3fee, 0x2825130c, 0x0e0c6ba0, 0x17070405,   // af.sv.fi_422 et.eu.sw_543  ceb.sv.is_322 ru.bg.sr_333
  0x04071109, 0x081710a9, 0x060c3f04, 0x23190b0e,   // ro.bg.ru_444 be.sr.uk_544  af.sv.de_332 es.gl.ca_555
  0x030c08a0, 0x070a17ad, 0x171004a0, 0x20102907,   // no.sv.nl_322 sr.mk.bg_643  ru.be.sr_322 sl.lt.sq_432
  // [2450]
  0x1c0d09ad, 0x07001011, 0x0c0208ac, 0x05002314,   // hi.ne.mr_643 lt.it.un_630  no.da.sv_632 ca.fr.un_660
  0x21002d02, 0x2d291004, 0x041353a0, 0x2b1c07ee,   // sk.jw.un_220 lt.sl.sk_332  ht.et.fi_322 it.id.vi_422
  0x2d1029ad, 0x05002708, 0x0b2d0d55, 0x03000804,   // sl.lt.sk_643 gd.fr.un_430  cs.sk.es_442 no.nl.un_320
  0x20000b07, 0x10002907, 0x1600070b, 0x17131612,   // es.sq.un_420 sl.lt.un_420  it.hr.un_520 hr.et.sr_654
  // [2460]
  0x1600090d, 0x04002a04, 0x0a041708, 0x10002913,   // pl.hr.un_540 mt.fi.un_320  sr.ru.mk_443 sl.lt.un_650
  0x0b000505, 0x1c002005, 0x171613ad, 0x160710ee,   // fr.es.un_330 sq.id.un_330  et.hr.sr_643 lt.it.hr_422
  0x55006b0c, 0x531905ad, 0x1b000e12, 0x16001c02,   // ceb.rw.un_530 fr.gl.ht_643  is.tr.un_640 id.hr.un_220
  0x172910af, 0x0f1325a4, 0x02100f04, 0x011b0e0c,   // lt.sl.sr_655 eu.et.lv_433  lv.lt.da_332 is.tr.en_543
  // [2470]
  0x0400251b, 0x531029a0, 0x6b2110a4, 0x64171609,   // eu.fi.un_770 sl.lt.ht_322  lt.jw.ceb_433 hr.sr.lg_444
  0x1e005307, 0x03003f11, 0x040f0955, 0x100f1eee,   // ht.ms.un_420 af.nl.un_630  pl.lv.fi_442 ms.lv.lt_422
  0x1c0d090b, 0x25640e04, 0x3f250c04, 0x081602af,   // hi.ne.mr_542 is.lg.eu_332  sv.eu.af_332 da.hr.no_655
  0x0c171604, 0x04001323, 0x041e1c0d, 0x10000422,   // hr.sr.sv_332 et.fi.un_880  id.ms.fi_554 ru.be.un_870
  // [2480]
  0x10066e04, 0x28641fa4, 0x290f1ca4, 0x09001c0b,   // blu.de.lt_332 cy.lg.sw_433  id.lv.sl_433 mr.hi.un_520
  0x181e2aee, 0x1b00121b, 0x3f0e1b0c, 0x1a006b19,   // mt.ms.ga_422 hu.tr.un_770  tr.is.af_543 ceb.tl.un_750
  0x201b2da0, 0x211218a9, 0x19000804, 0x2a001f19,   // sk.tr.sq_322 ar.ur.fa_544  no.gl.un_320 cy.mt.un_750
  0x0a00041a, 0x0a00230c, 0x28000119, 0x0800070e,   // ru.mk.un_760 ca.pt.un_530  en.sw.un_750 bg.uk.un_550
  // [2490]
  0x1007040c, 0x08001112, 0x062104ee, 0x091c130b,   // ru.bg.be_543 ro.uk.un_640  fi.jw.de_422 bh.mr.hi_542
  0x1f002807, 0x08041105, 0x1a0d01ec, 0x0800171b,   // sw.cy.un_420 ro.ru.uk_333  en.cs.tl_644 sr.uk.un_770
  0x04130e0b, 0x182112ad, 0x23190b13, 0x060b0ca0,   // is.et.fi_542 ur.fa.ar_643  es.gl.ca_665 sv.es.de_322
  0x21021ca0, 0x2b1827a6, 0x08100aa7, 0x550a01a4,   // id.da.jw_322 gd.ga.vi_521  mk.be.uk_532 en.pt.rw_433
  // [24a0]
  0x050108a4, 0x19001c02, 0x0b001004, 0x172d2911,   // no.en.fr_433 id.gl.un_220  lt.es.un_320 sl.sk.sr_653
  0x1a001b07, 0x10006b08, 0x13081ba9, 0x29190a05,   // tr.tl.un_420 ceb.lt.un_430  tr.no.et_544 pt.gl.sl_333
  0x64001a08, 0x6b1b040d, 0x21100a04, 0x07001902,   // tl.lg.un_430 fi.tr.ceb_554  pt.lt.jw_332 gl.it.un_220
  0x0c0e080c, 0x1f002304, 0x04310814, 0x1a0e6ba0,   // no.is.sv_543 ca.cy.un_320  no.az.fi_666 ceb.is.tl_322
  // [24b0]
  0x040e130d, 0x2b172911, 0x312005a4, 0x1c311e07,   // et.is.fi_554 sl.sr.vi_653  fr.sq.az_433 ms.az.id_432
  0x0c040609, 0x286412a9, 0x0a0417a9, 0x0d1617a0,   // de.fi.sv_444 hu.lg.sw_544  sr.ru.mk_544 sr.hr.cs_322
  0x551220a0, 0x130108a0, 0x203f12a0, 0x130d1ba0,   // sq.hu.rw_322 no.en.et_322  hu.af.sq_322 tr.cs.et_322
  0x071308ee, 0x292d12a7, 0x3f0103a7, 0x0c0e0107,   // no.et.it_422 hu.sk.sl_532  nl.en.af_532 en.is.sv_432
  // [24c0]
  0x10070802, 0x07080404, 0x0d000a07, 0x1b2a12a0,   // uk.bg.be_222 ru.uk.bg_332  pt.cs.un_420 hu.mt.tr_322
  0x12000c05, 0x0a002313, 0x063f1b07, 0x0200310d,   // sv.hu.un_330 ca.pt.un_650  tr.af.de_432 az.da.un_540
  0x17070aec, 0x200a2304, 0x0c0810a7, 0x0f000a04,   // mk.bg.sr_644 ca.pt.sq_332  lt.no.sv_532 pt.lv.un_320
  0x070c6b09, 0x3f1a6b04, 0x16003104, 0x21002019,   // ceb.sv.it_444 ceb.tl.af_332  az.hr.un_320 sq.jw.un_750
  // [24d0]
  0x532129ad, 0x23110712, 0x062916ee, 0x080211ee,   // sl.jw.ht_643 it.ro.ca_654  hr.sl.de_422 ro.da.no_422
  0x17002912, 0x2000121b, 0x0c001309, 0x082105ec,   // sl.sr.un_640 hu.sq.un_770  et.sv.un_440 fr.jw.no_644
  0x0a07040b, 0x06003f0d, 0x0a07100c, 0x1800050e,   // ru.bg.mk_542 af.de.un_540  be.bg.mk_543 fr.ga.un_550
  0x53000304, 0x64000c09, 0x2d122911, 0x04071104,   // nl.ht.un_320 sv.lg.un_440  sl.hu.sk_653 ro.bg.ru_332
  // [24e0]
  0x5300051b, 0x281e1c14, 0x211c53a0, 0x1600201a,   // fr.ht.un_770 id.ms.sw_666  ht.id.jw_322 sq.hr.un_760
  0x2d0d16ee, 0x0d6b1ba0, 0x213f1ca0, 0x211218a4,   // hr.cs.sk_422 tr.ceb.cs_322  id.af.jw_322 ar.ur.fa_433
  0x1c282104, 0x120208a4, 0x230b01ee, 0x041e1c55,   // jw.sw.id_332 no.da.hu_433  en.es.ca_422 id.ms.fi_442
  0x02000c09, 0x64002812, 0x10040812, 0x1c002119,   // sv.da.un_440 sw.lg.un_640  uk.ru.be_654 jw.id.un_750
  // [24f0]
  0x100f2155, 0x21162aa6, 0x0a0817ad, 0x21002912,   // jw.lv.lt_442 mt.hr.jw_521  sr.uk.mk_643 sl.jw.un_640
  0x1f000121, 0x1b001609, 0x051109ad, 0x06070502,   // en.cy.un_860 hr.tr.un_440  pl.ro.fr_643 fr.it.de_222
  0x0a110407, 0x10170a05, 0x1f0301ee, 0x11093fee,   // ru.ro.mk_432 mk.sr.be_333  en.nl.cy_422 af.pl.ro_422
  0x55005308, 0x041921ad, 0x6428090d, 0x21002508,   // ht.rw.un_430 jw.gl.fi_643  pl.sw.lg_554 eu.jw.un_430
  // [2500]
  0x17110412, 0x13000d0c, 0x1b001604, 0x0a00070e,   // ru.ro.sr_654 ne.bh.un_530  hr.tr.un_320 bg.mk.un_550
  0x070905af, 0x53001a04, 0x55006414, 0x05001208,   // fr.pl.it_655 tl.ht.un_320  lg.rw.un_660 hu.fr.un_430
  0x550164a0, 0x10122a02, 0x00003f24, 0x6b091aee,   // lg.en.rw_322 mt.hu.lt_222  af.un.un_900 tl.pl.ceb_422
  0x21001b19, 0x190b03a0, 0x0a000302, 0x211812ec,   // tr.jw.un_750 nl.es.gl_322  nl.pt.un_220 ur.ar.fa_644
  // [2510]
  0x12000919, 0x190b2ba0, 0x2d3f09ac, 0x09001607,   // pl.hu.un_750 vi.es.gl_322  pl.af.sk_632 hr.pl.un_420
  0x12000e05, 0x17080409, 0x131c09a9, 0x12050907,   // is.hu.un_330 ru.uk.sr_444  hi.mr.bh_544 pl.fr.hu_432
  0x1600290d, 0x04170802, 0x0c005302, 0x210220a4,   // sl.hr.un_540 uk.sr.ru_222  ht.sv.un_220 sq.da.jw_433
  0x1a286b0c, 0x0e031bec, 0x6400550d, 0x642106ee,   // ceb.sw.tl_543 tr.nl.is_644  rw.lg.un_540 de.jw.lg_422
  // [2520]
  0x212331ad, 0x100804ee, 0x23002705, 0x09171613,   // az.ca.jw_643 ru.uk.be_422  gd.ca.un_330 hr.sr.pl_665
  0x09171614, 0x1a070e04, 0x07081104, 0x17160914,   // hr.sr.pl_666 is.it.tl_332  ro.uk.bg_332 pl.hr.sr_666
  0x04136455, 0x181209a7, 0x13060ca4, 0x1c090d08,   // lg.et.fi_442 pl.hu.ga_532  sv.de.et_433 ne.hi.mr_443
  0x1c091307, 0x6e6b01ee, 0x1716095a, 0x0d002702,   // bh.hi.mr_432 en.ceb.blu_422  pl.hr.sr_553 gd.cs.un_220
  // [2530]
  0x04003f11, 0x171609ec, 0x080253a0, 0x061a2808,   // af.fi.un_630 pl.hr.sr_644  ht.da.no_322 sw.tl.de_443
  0x21061c07, 0x0a0411ec, 0x64211c07, 0x28000613,   // id.de.jw_432 ro.ru.mk_644  id.jw.lg_432 de.sw.un_650
  0x27000912, 0x100408ad, 0x64280da0, 0x1e1c6ba4,   // pl.gd.un_640 uk.ru.be_643  cs.sw.lg_322 ceb.id.ms_433
  0x1364040c, 0x556420a9, 0x211e1c0c, 0x0a0710a0,   // fi.lg.et_543 sq.lg.rw_544  id.ms.jw_543 be.bg.mk_322
  // [2540]
  0x64005520, 0x3f0313ee, 0x64003f08, 0x0600250c,   // rw.lg.un_850 et.nl.af_422  af.lg.un_430 eu.de.un_530
  0x2a001702, 0x08000723, 0x21005318, 0x210409a4,   // sr.mt.un_220 bg.uk.un_880  ht.jw.un_740 pl.fi.jw_433
  0x04122aad, 0x212855a4, 0x25002804, 0x04002904,   // mt.hu.fi_643 rw.sw.jw_433  sw.eu.un_320 sl.fi.un_320
  0x0807110c, 0x2104105a, 0x041e1c11, 0x122021a0,   // ro.bg.uk_543 lt.fi.jw_553  id.ms.fi_653 jw.sq.hu_322
  // [2550]
  0x21126404, 0x16211aa0, 0x3f1210ee, 0x0c0d2a05,   // lg.hu.jw_332 tl.jw.hr_322  lt.hu.af_422 mt.cs.sv_333
  0x28640f08, 0x12000904, 0x0e001819, 0x550c200d,   // lv.lg.sw_443 pl.hu.un_320  ga.is.un_750 sq.sv.rw_554
  0x20172a04, 0x29066407, 0x16041ba0, 0x13001c21,   // mt.sr.sq_332 lg.de.sl_432  tr.fi.hr_322 mr.bh.un_860
  0x64205305, 0x1c001808, 0x125528a4, 0x2a0b2507,   // ht.sq.lg_333 ga.id.un_430  sw.rw.hu_433 eu.es.mt_432
  // [2560]
  0x070c2807, 0x0d001c0b, 0x1653280b, 0x53001208,   // sw.sv.it_432 mr.ne.un_520  sw.ht.hr_542 hu.ht.un_430
  0x28135309, 0x0b0a050c, 0x12002509, 0x0127050c,   // ht.et.sw_444 fr.pt.es_543  eu.hu.un_440 fr.gd.en_543
  0x29002a07, 0x206455ad, 0x0800100d, 0x286429a0,   // mt.sl.un_420 rw.lg.sq_643  be.uk.un_540 sl.lg.sw_322
  0x12000914, 0x021a6ba4, 0x012d20a6, 0x1e1c09af,   // pl.hu.un_660 ceb.tl.da_433  sq.sk.en_521 pl.id.ms_655
  // [2570]
  0x2a171608, 0x121009a4, 0x23002d08, 0x20285511,   // hr.sr.mt_443 pl.lt.hu_433  sk.ca.un_430 rw.sw.sq_653
  0x55006405, 0x2d0d0fa4, 0x3f031312, 0x0d000f05,   // lg.rw.un_330 lv.cs.sk_433  et.nl.af_654 lv.cs.un_330
  0x07080205, 0x29001b04, 0x0a041305, 0x040a07ad,   // da.no.it_333 tr.sl.un_320  et.fi.pt_333 bg.mk.ru_643
  0x0802010c, 0x070301a7, 0x131611a0, 0x170704a4,   // en.da.no_543 en.nl.it_532  ro.hr.et_322 ru.bg.sr_433
  // [2580]
  0x27006e07, 0x1708040d, 0x1f006e2a, 0x03133fa9,   // blu.gd.un_420 ru.uk.sr_554  blu.cy.un_970 af.et.nl_544
  0x09130107, 0x081011ee, 0x0f001309, 0x0b0a190c,   // en.et.pl_432 ro.be.uk_422  et.lv.un_440 gl.pt.es_543
  0x1200212a, 0x12180ea9, 0x13000c19, 0x29062ba0,   // fa.ur.un_970 is.ga.hu_544  sv.et.un_750 vi.de.sl_322
  0x1e002802, 0x08001713, 0x2a000b02, 0x1c0d09a9,   // sw.ms.un_220 sr.uk.un_650  es.mt.un_220 hi.ne.mr_544
  // [2590]
  0x170a07ec, 0x55000804, 0x28120602, 0x01086b09,   // bg.mk.sr_644 no.rw.un_320  de.hu.sw_222 ceb.no.en_444
  0x07081713, 0x0d2d2904, 0x06001f05, 0x21060304,   // sr.uk.bg_665 sl.sk.cs_332  cy.de.un_330 nl.de.jw_332
  0x53311b0c, 0x532564ec, 0x070a11ec, 0x08130e13,   // tr.az.ht_543 lg.eu.ht_644  ro.mk.bg_644 is.et.no_665
  0x2a005507, 0x1e0e1ca4, 0x19000507, 0x1f061a07,   // rw.mt.un_420 id.is.ms_433  fr.gl.un_420 tl.de.cy_432
  // [25a0]
  0x07041708, 0x1f0d06a6, 0x0000552d, 0x1f2a550c,   // sr.ru.bg_443 de.cs.cy_521  rw.un.un_A00 rw.mt.cy_543
  0x282964a0, 0x64003f1b, 0x1f00010d, 0x1a086b07,   // lg.sl.sw_322 af.lg.un_770  en.cy.un_540 ceb.no.tl_432
  0x12001907, 0x1e1c2a0c, 0x1f645511, 0x23051104,   // gl.hu.un_420 mt.id.ms_543  rw.lg.cy_653 ro.fr.ca_332
  0x190b2309, 0x64182707, 0x28643fee, 0x21535511,   // ca.es.gl_444 gd.ga.lg_432  af.lg.sw_422 rw.ht.jw_653
  // [25b0]
  0x28645513, 0x3f0803a4, 0x0700130e, 0x0900280e,   // rw.lg.sw_665 nl.no.af_433  et.it.un_550 sw.pl.un_550
  0x2800640d, 0x09000309, 0x285564ad, 0x55216455,   // lg.sw.un_540 nl.pl.un_440  lg.rw.sw_643 lg.jw.rw_442
  0x16096413, 0x050e1004, 0x55000108, 0x0c001e07,   // lg.pl.hr_665 lt.is.fr_332  en.rw.un_430 ms.sv.un_420
  0x060205ee, 0x2a000d0c, 0x0d001f1a, 0x28005521,   // fr.da.de_422 cs.mt.un_530  cy.cs.un_760 rw.sw.un_860
  // [25c0]
  0x6b2319a7, 0x0f171613, 0x18002b2b, 0x2a000d08,   // gl.ca.ceb_532 hr.sr.lv_665  vi.ga.un_980 cs.mt.un_430
  0x10000d07, 0x64553f07, 0x17052dac, 0x6e251355,   // cs.lt.un_420 af.rw.lg_432  sk.fr.sr_632 et.eu.blu_442
  0x551a2508, 0x0f2017a0, 0x05121907, 0x00000324,   // eu.tl.rw_443 sr.sq.lv_322  gl.hu.fr_432 nl.un.un_900
  0x2d1716ec, 0x2d25060b, 0x643f5513, 0x160711a0,   // hr.sr.sk_644 de.eu.sk_542  rw.af.lg_665 ro.it.hr_322
  // [25d0]
  0x16281707, 0x53002808, 0x0f17160d, 0x0f001004,   // sr.sw.hr_432 sw.ht.un_430  hr.sr.lv_554 lt.lv.un_320
  0x02000d0d, 0x0a110f0b, 0x17160f14, 0x2b003f07,   // cs.da.un_540 lv.ro.pt_542  lv.hr.sr_666 af.vi.un_420
  0x0d091ca9, 0x1200210b, 0x08030c13, 0x55642802,   // mr.hi.ne_544 fa.ur.un_520  sv.nl.no_665 sw.lg.rw_222
  0x3f000d0c, 0x122b0da7, 0x0d001c0c, 0x530128a0,   // cs.af.un_530 cs.vi.hu_532  mr.ne.un_530 sw.en.ht_322
  // [25e0]
  0x11000d04, 0x1f090d07, 0x0f171655, 0x2b1628ee,   // cs.ro.un_320 cs.pl.cy_432  hr.sr.lv_442 sw.hr.vi_422
  0x0b001104, 0x17160faf, 0x16212a09, 0x1c532802,   // ro.es.un_320 lv.hr.sr_655  mt.jw.hr_444 sw.ht.id_222
  0x28006402, 0x2d16090e, 0x171620a0, 0x190b0a5a,   // lg.sw.un_220 pl.hr.sk_555  sq.hr.sr_322 pt.es.gl_553
  0x0b000a0e, 0x192d0d0d, 0x1b006411, 0x040a0702,   // pt.es.un_550 cs.sk.gl_554  lg.tr.un_630 bg.mk.ru_222
  // [25f0]
  0x6b55210c, 0x3f216ba4, 0x2700051b, 0x1e641c0c,   // jw.rw.ceb_543 ceb.jw.af_433  fr.gd.un_770 id.lg.ms_543
  0x1b052aa0, 0x21002004, 0x17230faf, 0x05001914,   // mt.fr.tr_322 sq.jw.un_320  lv.ca.sr_655 gl.fr.un_660
  0x0c171655, 0x2a0e0faf, 0x18000b1b, 0x0a55280c,   // hr.sr.sv_442 lv.is.mt_655  es.ga.un_770 sw.rw.pt_543
  0x11170a0c, 0x11160d0c, 0x13001c14, 0x2d002905,   // mk.sr.ro_543 cs.hr.ro_543  mr.bh.un_660 sl.sk.un_330
  // [2600]
  0x0d1209ec, 0x033f1305, 0x175320ee, 0x18000e0e,   // pl.hu.cs_644 et.af.nl_333  sq.ht.sr_422 is.ga.un_550
  0x1218210d, 0x182705af, 0x1a002813, 0x3f1864a0,   // fa.ar.ur_554 fr.gd.ga_655  sw.tl.un_650 lg.ga.af_322
  0x07110409, 0x53202907, 0x1e00550e, 0x020308a6,   // ru.ro.bg_444 sl.sq.ht_432  rw.ms.un_550 no.nl.da_521
  0x0f2a0d07, 0x08022d05, 0x10041312, 0x040a08a0,   // cs.mt.lv_432 sk.da.no_333  et.fi.lt_654 uk.mk.ru_322
  // [2610]
  0x0112130c, 0x08040a05, 0x2300052a, 0x23005313,   // et.hu.en_543 mk.ru.uk_333  fr.ca.un_970 ht.ca.un_650
  0x53001921, 0x130420ad, 0x0a1a0c05, 0x23161b02,   // gl.ht.un_860 sq.fi.et_643  sv.tl.pt_333 tr.hr.ca_222
  0x5364550c, 0x6b532504, 0x53000522, 0x18000e08,   // rw.lg.ht_543 eu.ht.ceb_332  fr.ht.un_870 is.ga.un_430
  0x3f2353a9, 0x17080aa0, 0x07110107, 0x04080aa0,   // ht.ca.af_544 mk.uk.sr_322  en.ro.it_432 mk.uk.ru_322
  // [2620]
  0x291311a0, 0x17551bee, 0x310f0d07, 0x060a25a6,   // ro.et.sl_322 tr.rw.sr_422  cs.lv.az_432 eu.pt.de_521
  0x11000a0d, 0x16112007, 0x040708a4, 0x310a1b02,   // pt.ro.un_540 sq.ro.hr_432  uk.bg.ru_433 tr.pt.az_222
  0x1f001008, 0x1c002308, 0x28556413, 0x645528a0,   // lt.cy.un_430 ca.id.un_430  lg.rw.sw_665 sw.rw.lg_322
  0x1c2d0d55, 0x18002a02, 0x0804070c, 0x0a0408af,   // cs.sk.id_442 mt.ga.un_220  bg.ru.uk_543 uk.ru.mk_655
  // [2630]
  0x552d0dee, 0x25645507, 0x0a071709, 0x1c1a2102,   // cs.sk.rw_422 rw.lg.eu_432  sr.bg.mk_444 jw.tl.id_222
  0x100407a9, 0x55001f12, 0x0a002104, 0x21001a02,   // bg.ru.be_544 cy.rw.un_640  jw.pt.un_320 tl.jw.un_220
  0x28001308, 0x033f2507, 0x2a645508, 0x0807040c,   // et.sw.un_430 eu.af.nl_432  rw.lg.mt_443 ru.bg.uk_543
  0x0a0708a0, 0x040708af, 0x0807040b, 0x1716090c,   // uk.bg.mk_322 uk.bg.ru_655  ru.bg.uk_542 pl.hr.sr_543
  // [2640]
  0x230a1211, 0x040a17ad, 0x09002a04, 0x6400210b,   // hu.pt.ca_653 sr.mk.ru_643  mt.pl.un_320 jw.lg.un_520
  0x11000f12, 0x113f25ad, 0x1f001e04, 0x1b2b3f04,   // lv.ro.un_640 eu.af.ro_643  ms.cy.un_320 af.vi.tr_332
  0x162917a9, 0x160729a9, 0x01002902, 0x016b1207,   // sr.sl.hr_544 sl.it.hr_544  sl.en.un_220 hu.ceb.en_432
  0x27000402, 0x291b1e09, 0x3f126bee, 0x291716ee,   // fi.gd.un_220 ms.tr.sl_444  ceb.hu.af_422 hr.sr.sl_422
  // [2650]
  0x290706ee, 0x19002305, 0x2b000304, 0x191e1ca7,   // de.it.sl_422 ca.gl.un_330  nl.vi.un_320 id.ms.gl_532
  0x27081807, 0x081104a4, 0x03006b08, 0x1e1c2104,   // ga.no.gd_432 ru.ro.uk_433  ceb.nl.un_430 jw.id.ms_332
  0x19001102, 0x10000819, 0x18032307, 0x0b010509,   // ro.gl.un_220 uk.be.un_750  ca.nl.ga_432 fr.en.es_444
  0x190b0ea0, 0x1f210604, 0x070a0412, 0x0f0e08a4,   // is.es.gl_322 de.jw.cy_332  ru.mk.bg_654 no.is.lv_433
  // [2660]
  0x2a1b64a4, 0x1700041b, 0x0f0e08a0, 0x060308a0,   // lg.tr.mt_433 ru.sr.un_770  no.is.lv_322 no.nl.de_322
  0x1116170c, 0x23001f04, 0x131b0fa0, 0x1f000b0e,   // sr.hr.ro_543 cy.ca.un_320  lv.tr.et_322 es.cy.un_550
  0x06000308, 0x2d001213, 0x2d2112ad, 0x1221040c,   // nl.de.un_430 hu.sk.un_650  hu.jw.sk_643 fi.jw.hu_543
  0x310603ee, 0x13285512, 0x0b0f1007, 0x162511ee,   // nl.de.az_422 rw.sw.et_654  lt.lv.es_432 ro.eu.hr_422
  // [2670]
  0x10000c04, 0x131155af, 0x100b01a0, 0x10000b14,   // sv.lt.un_320 rw.ro.et_655  en.es.lt_322 es.lt.un_660
  0x170804a4, 0x0b001912, 0x1729160c, 0x0c101f0c,   // ru.uk.sr_433 gl.es.un_640  hr.sl.sr_543 cy.lt.sv_543
  0x18000309, 0x1e1c2514, 0x03550509, 0x0f28130c,   // nl.ga.un_440 eu.id.ms_666  fr.rw.nl_444 et.sw.lv_543
  0x13211ca4, 0x1b023f05, 0x050311a4, 0x01002007,   // id.jw.et_433 af.da.tr_333  ro.nl.fr_433 sq.en.un_420
  // [2680]
  0x1806250c, 0x07001007, 0x0a0417a0, 0x1b002814,   // eu.de.ga_543 be.bg.un_420  sr.ru.mk_322 sw.tr.un_660
  0x1c100fa4, 0x06002514, 0x10000f1a, 0x21201ca4,   // lv.lt.id_433 eu.de.un_660  lv.lt.un_760 id.sq.jw_433
  0x06002513, 0x1b2a07a9, 0x0805230c, 0x27000c02,   // eu.de.un_650 it.mt.tr_544  ca.fr.no_543 sv.gd.un_220
  0x1b001a05, 0x0e100f14, 0x281c0e02, 0x1028210c,   // tl.tr.un_330 lv.lt.is_666  is.id.sw_222 jw.sw.lt_543
  // [2690]
  0x285525a4, 0x08041008, 0x081c1e11, 0x0f1c2108,   // eu.rw.sw_433 be.ru.uk_443  ms.id.no_653 jw.id.lv_443
  0x251e1c0d, 0x17040a05, 0x0964550c, 0x31001c05,   // id.ms.eu_554 mk.ru.sr_333  rw.lg.pl_543 id.az.un_330
  0x08000419, 0x06001f1b, 0x1b551309, 0x53551b08,   // ru.uk.un_750 cy.de.un_770  et.rw.tr_444 tr.rw.ht_443
  0x16211aaf, 0x21281c0c, 0x1b00551a, 0x195525a7,   // tl.jw.hr_655 id.sw.jw_543  rw.tr.un_760 eu.rw.gl_532
  // [26a0]
  0x6b1a53af, 0x13100f13, 0x21000308, 0x6b001a35,   // ht.tl.ceb_655 lv.lt.et_665  nl.jw.un_430 tl.ceb.un_A90
  0x1100130c, 0x55281e0b, 0x21551e04, 0x6455210d,   // et.ro.un_530 ms.sw.rw_542  ms.rw.jw_332 jw.rw.lg_554
  0x286b3111, 0x1c1a1e07, 0x1c2d1ea0, 0x21162507,   // az.ceb.sw_653 ms.tl.id_432  ms.sk.id_322 eu.hr.jw_432
  0x0c2164a0, 0x12001b19, 0x0f11285a, 0x21006e08,   // lg.jw.sv_322 tr.hu.un_750  sw.ro.lv_553 blu.jw.un_430
  // [26b0]
  0x1e09290c, 0x55281ba4, 0x070b01af, 0x551b5304,   // sl.pl.ms_543 tr.sw.rw_433  en.es.it_655 ht.tr.rw_332
  0x1b002502, 0x060e3f02, 0x1b041e0c, 0x190a0802,   // eu.tr.un_220 af.is.de_222  ms.fi.tr_543 no.pt.gl_222
  0x06122aa9, 0x03100fa9, 0x18272aa0, 0x09642811,   // mt.hu.de_544 lv.lt.nl_544  mt.gd.ga_322 sw.lg.pl_653
  0x111e2a04, 0x1b005519, 0x1200040c, 0x0600051a,   // mt.ms.ro_332 rw.tr.un_750  fi.hu.un_530 fr.de.un_760
  // [26c0]
  0x05000a12, 0x28552aa0, 0x1318040c, 0x0f2704ad,   // pt.fr.un_640 mt.rw.sw_322  fi.ga.et_543 fi.gd.lv_643
  0x2500031a, 0x182702a4, 0x091c13a4, 0x0518040c,   // nl.eu.un_760 da.gd.ga_433  bh.mr.hi_433 fi.ga.fr_543
  0x180427a7, 0x2700180e, 0x281304a7, 0x1000042b,   // gd.fi.ga_532 ga.gd.un_550  fi.et.sw_532 ru.be.un_980
  0x1c182808, 0x0f1827ad, 0x0a002b1a, 0x17100a07,   // sw.ga.id_443 gd.ga.lv_643  vi.pt.un_760 mk.be.sr_432
  // [26d0]
  0x0600130d, 0x27000e1f, 0x290c0207, 0x232705a0,   // et.de.un_540 is.gd.un_840  da.sv.sl_432 fr.gd.ca_322
  0x1c090d55, 0x03170608, 0x12002804, 0x10050412,   // ne.hi.mr_442 de.sr.nl_443  sw.hu.un_320 fi.fr.lt_654
  0x1f002804, 0x100f0409, 0x050f27a4, 0x080717ad,   // sw.cy.un_320 fi.lv.lt_444  gd.lv.fr_433 sr.bg.uk_643
  0x06040f11, 0x10130405, 0x09006404, 0x556428a7,   // lv.fi.de_653 fi.et.lt_333  lg.pl.un_320 sw.lg.rw_532
  // [26e0]
  0x55286455, 0x2d090d0d, 0x1b3101a4, 0x10000f1b,   // lg.sw.rw_442 cs.pl.sk_554  en.az.tr_433 lv.lt.un_770
  0x3f1a03a9, 0x07252804, 0x160d17a9, 0x0a250ead,   // nl.tl.af_544 sw.eu.it_332  sr.cs.hr_544 is.eu.pt_643
  0x2d0d05a0, 0x1b00201a, 0x0800160c, 0x1f53080b,   // fr.cs.sk_322 sq.tr.un_760  hr.no.un_530 no.ht.cy_542
  0x0f033f04, 0x040711a6, 0x071125a9, 0x0f1307a7,   // af.nl.lv_332 ro.bg.ru_521  eu.ro.it_544 it.et.lv_532
  // [26f0]
  0x23002102, 0x28171613, 0x1a2012a4, 0x080a0412,   // jw.ca.un_220 hr.sr.sw_665  hu.sq.tl_433 ru.mk.uk_654
  0x31001f04, 0x190c64a4, 0x3f031e02, 0x0917160c,   // cy.az.un_320 lg.sv.gl_433  ms.nl.af_222 hr.sr.pl_543
  0x532720ad, 0x0f171607, 0x121311ee, 0x211e1c55,   // sq.gd.ht_643 hr.sr.lv_432  ro.et.hu_422 id.ms.jw_442
  0x3f6e0112, 0x0b2711a4, 0x0a133fa4, 0x17002519,   // en.blu.af_654 ro.gd.es_433  af.et.pt_433 eu.sr.un_750
  // [2700]
  0x1a006b21, 0x170a0707, 0x06023fa9, 0x28641608,   // ceb.tl.un_860 bg.mk.sr_432  af.da.de_544 hr.lg.sw_443
  0x1107010c, 0x080411a7, 0x06022312, 0x0c0831a7,   // en.it.ro_543 ro.ru.uk_532  ca.da.de_654 az.no.sv_532
  0x2016280b, 0x286420a7, 0x05112311, 0x0c2a31ee,   // sw.hr.sq_542 sq.lg.sw_532  ca.ro.fr_653 az.mt.sv_422
  0x16000e04, 0x0c0708a0, 0x2d170e12, 0x3f006e04,   // is.hr.un_320 no.it.sv_322  is.sr.sk_654 blu.af.un_320
  // [2710]
  0x256455a4, 0x061225ad, 0x21251e07, 0x06110508,   // rw.lg.eu_433 eu.hu.de_643  ms.eu.jw_432 fr.ro.de_443
  0x1b311104, 0x1a6b0107, 0x10006407, 0x2d001a04,   // ro.az.tr_332 en.ceb.tl_432  lg.lt.un_420 tl.sk.un_320
  0x2564550e, 0x06055312, 0x0e001a07, 0x16291755,   // rw.lg.eu_555 ht.fr.de_654  tl.is.un_420 sr.sl.hr_442
  0x080411a4, 0x086e6b04, 0x01003f02, 0x19000404,   // ro.ru.uk_433 ceb.blu.no_332  af.en.un_220 fi.gl.un_320
  // [2720]
  0x55022aa0, 0x1b2a2812, 0x2b1301a4, 0x20002809,   // mt.da.rw_322 sw.mt.tr_654  en.et.vi_433 sw.sq.un_440
  0x6455090b, 0x040807a0, 0x08023f05, 0x16530408,   // pl.rw.lg_542 bg.uk.ru_322  af.da.no_333 fi.ht.hr_443
  0x21001708, 0x10081107, 0x21000a0d, 0x121821ac,   // sr.jw.un_430 ro.uk.be_432  pt.jw.un_540 fa.ar.ur_632
  0x0a080405, 0x1e211c12, 0x3f0b0aee, 0x0810045a,   // ru.uk.mk_333 id.jw.ms_654  pt.es.af_422 ru.be.uk_553
  // [2730]
  0x1c000e19, 0x0c211355, 0x116e21a7, 0x2300270b,   // is.id.un_750 et.jw.sv_442  jw.blu.ro_532 gd.ca.un_520
  0x2a216ea0, 0x232811ee, 0x0b2d0d0e, 0x3f000919,   // blu.jw.mt_322 ro.sw.ca_422  cs.sk.es_555 pl.af.un_750
  0x0a1108ee, 0x041710ad, 0x171611a0, 0x1b005502,   // no.ro.pt_422 be.sr.ru_643  ro.hr.sr_322 rw.tr.un_220
  0x25001f09, 0x182021a0, 0x25000a08, 0x112305ad,   // cy.eu.un_440 jw.sq.ga_322  pt.eu.un_430 fr.ca.ro_643
  // [2740]
  0x0a21110b, 0x0a002504, 0x0e001c13, 0x070408ad,   // ro.jw.pt_542 eu.pt.un_320  id.is.un_650 uk.ru.bg_643
  0x0d292d07, 0x281c2107, 0x0a000712, 0x1e1c0ea9,   // sk.sl.cs_432 jw.id.sw_432  bg.mk.un_640 is.id.ms_544
  0x273f09a7, 0x17110707, 0x17070455, 0x17000e21,   // pl.af.gd_532 it.ro.sr_432  ru.bg.sr_442 is.sr.un_860
  0x641304af, 0x311b0e0c, 0x0413640c, 0x07040aec,   // fi.et.lg_655 is.tr.az_543  lg.et.fi_543 mk.ru.bg_644
  // [2750]
  0x1f3f0309, 0x1a136407, 0x0a000e2a, 0x17070a11,   // nl.af.cy_444 lg.et.tl_432  is.pt.un_970 mk.bg.sr_653
  0x06000913, 0x09002512, 0x046413af, 0x310811a9,   // pl.de.un_650 eu.pl.un_640  et.lg.fi_655 ro.no.az_544
  0x1f000611, 0x64001305, 0x1a13640d, 0x5503280c,   // de.cy.un_630 et.lg.un_330  lg.et.tl_554 sw.nl.rw_543
  0x10071155, 0x070a04a4, 0x0f00091b, 0x11000713,   // ro.it.lt_442 ru.mk.bg_433  pl.lv.un_770 it.ro.un_650
  // [2760]
  0x2917120c, 0x1300641a, 0x0c000e13, 0x316b1bee,   // hu.sr.sl_543 lg.et.un_760  is.sv.un_650 tr.ceb.az_422
  0x03003102, 0x030e1207, 0x6b000919, 0x03000705,   // az.nl.un_220 hu.is.nl_432  pl.ceb.un_750 it.nl.un_330
  0x1b190a04, 0x080a170d, 0x6e230ea4, 0x25190b05,   // pt.gl.tr_332 sr.mk.uk_554  is.ca.blu_433 es.gl.eu_333
  0x641304ee, 0x28006412, 0x6b04640c, 0x251304a0,   // fi.et.lg_422 lg.sw.un_640  lg.fi.ceb_543 fi.et.eu_322
  // [2770]
  0x040717a4, 0x12290fad, 0x6b010607, 0x0a0b1907,   // sr.bg.ru_433 lv.sl.hu_643  de.en.ceb_432 gl.es.pt_432
  0x29091309, 0x20120305, 0x0e641aad, 0x6b1f06ad,   // et.pl.sl_444 nl.hu.sq_333  tl.lg.is_643 de.cy.ceb_643
  0x03000612, 0x17080a60, 0x041b55ee, 0x3f21530c,   // de.nl.un_640 mk.uk.sr_664  rw.tr.fi_422 ht.jw.af_543
  0x28551307, 0x070a1105, 0x64135512, 0x09281fa9,   // et.rw.sw_432 ro.mk.bg_333  rw.et.lg_654 cy.sw.pl_544
  // [2780]
  0x041008ad, 0x642113a4, 0x080e130e, 0x0717045a,   // uk.be.ru_643 et.jw.lg_433  et.is.no_555 ru.sr.bg_553
  0x0a070414, 0x2a180912, 0x280a09a9, 0x1a64530c,   // ru.bg.mk_666 pl.ga.mt_654  pl.pt.sw_544 ht.lg.tl_543
  0x04000a08, 0x2100281a, 0x0f092907, 0x09001213,   // mk.ru.un_430 sw.jw.un_760  sl.pl.lv_432 hu.pl.un_650
  0x0f002912, 0x17110a0e, 0x1b00040e, 0x1b2855ee,   // sl.lv.un_640 mk.ro.sr_555  fi.tr.un_550 rw.sw.tr_422
  // [2790]
  0x55001313, 0x0f001014, 0x1a005508, 0x641a55a4,   // et.rw.un_650 lt.lv.un_660  rw.tl.un_430 rw.tl.lg_433
  0x6421555a, 0x130e55a4, 0x10000709, 0x07001302,   // rw.jw.lg_553 rw.is.et_433  bg.be.un_440 et.it.un_220
  0x1c090da6, 0x111304ad, 0x29002a08, 0x20001104,   // ne.hi.mr_521 fi.et.ro_643  mt.sl.un_430 ro.sq.un_320
  0x2a002912, 0x04001108, 0x640508a0, 0x0c08020c,   // sl.mt.un_640 ro.ru.un_430  no.fr.lg_322 da.no.sv_543
  // [27a0]
  0x202864ec, 0x0e001019, 0x013f2804, 0x2a002919,   // lg.sw.sq_644 lt.is.un_750  sw.af.en_332 sl.mt.un_750
  0x071828a0, 0x27000502, 0x091e1c08, 0x1716200c,   // sw.ga.it_322 fr.gd.un_220  id.ms.pl_443 sq.hr.sr_543
  0x2d290d0c, 0x1e291c04, 0x25002309, 0x05190707,   // cs.sl.sk_543 id.sl.ms_332  ca.eu.un_440 it.gl.fr_432
  0x10000809, 0x182112a7, 0x643107a0, 0x2b001922,   // uk.be.un_440 ur.fa.ar_532  it.az.lg_322 gl.vi.un_870
  // [27b0]
  0x1f002a13, 0x112a2904, 0x08000902, 0x29100f08,   // mt.cy.un_650 sl.mt.ro_332  pl.no.un_220 lv.lt.sl_443
  0x162905a7, 0x0500020c, 0x1f001212, 0x6b05010b,   // fr.sl.hr_532 da.fr.un_530  hu.cy.un_640 en.fr.ceb_542
  0x201a6b12, 0x0417080c, 0x171613a0, 0x162d07ee,   // ceb.tl.sq_654 uk.sr.ru_543  et.hr.sr_322 it.sk.hr_422
  0x1f0918ee, 0x13000923, 0x23002904, 0x010605a4,   // ga.pl.cy_422 hi.bh.un_880  sl.ca.un_320 fr.de.en_433
  // [27c0]
  0x3f055304, 0x28182a0d, 0x0b00190c, 0x12002007,   // ht.fr.af_332 mt.ga.sw_554  gl.es.un_530 sq.hu.un_420
  0x272a28a0, 0x12001f04, 0x0d1309ad, 0x20002505,   // sw.mt.gd_322 cy.hu.un_320  hi.bh.ne_643 eu.sq.un_330
  0x111c1e0c, 0x051f01a0, 0x1b0329a0, 0x200e0607,   // ms.id.ro_543 en.cy.fr_322  sl.nl.tr_322 de.is.sq_432
  0x3f002704, 0x2018130c, 0x2500201a, 0x180711a4,   // gd.af.un_320 et.ga.sq_543  sq.eu.un_760 ro.it.ga_433
  // [27d0]
  0x2d000e12, 0x19072507, 0x05002804, 0x050401ad,   // is.sk.un_640 eu.it.gl_432  sw.fr.un_320 en.fi.fr_643
  0x051f23a9, 0x0b0a07a6, 0x0b002504, 0x02252804,   // ca.cy.fr_544 it.pt.es_521  eu.es.un_320 sw.eu.da_332
  0x08002004, 0x1a001804, 0x211c1eac, 0x01073f0d,   // sq.no.un_320 ga.tl.un_320  ms.id.jw_632 af.it.en_554
  0x6b1a1f0c, 0x3f5305ee, 0x070a1755, 0x28000804,   // cy.tl.ceb_543 fr.ht.af_422  sr.mk.bg_442 no.sw.un_320
  // [27e0]
  0x0a0501a4, 0x1b5304ee, 0x25002013, 0x3f0c0704,   // en.fr.pt_433 fi.ht.tr_422  sq.eu.un_650 it.sv.af_332
  0x070305a0, 0x2500200d, 0x04002007, 0x1b002912,   // fr.nl.it_322 sq.eu.un_540  sq.fi.un_420 sl.tr.un_640
  0x641b0ca7, 0x070a04a0, 0x2025010c, 0x0a17070d,   // sv.tr.lg_532 ru.mk.bg_322  en.eu.sq_543 bg.sr.mk_554
  0x200825a4, 0x060a0704, 0x25002004, 0x2d0d05a4,   // eu.no.sq_433 it.pt.de_332  sq.eu.un_320 fr.cs.sk_433
  // [27f0]
  0x20250507, 0x20050205, 0x0e00230e, 0x0a000519,   // fr.eu.sq_432 da.fr.sq_333  ca.is.un_550 fr.pt.un_750
  0x0c071155, 0x0a050112, 0x1821120d, 0x081104ad,   // ro.it.sv_442 en.fr.pt_654  ur.fa.ar_554 ru.ro.uk_643
  0x2a00071a, 0x6b001a19, 0x170408ee, 0x04000a09,   // it.mt.un_760 tl.ceb.un_750  uk.ru.sr_422 mk.ru.un_440
  0x2d291602, 0x06002005, 0x020c08ec, 0x2d000e21,   // hr.sl.sk_222 sq.de.un_330  no.sv.da_644 is.sk.un_860

  // [2800]
  0x1219100c, 0x1700290c, 0x291716ad, 0x29001904,   // lt.gl.hu_543 sl.sr.un_530  hr.sr.sl_643 gl.sl.un_320
  0x28001219, 0x122809ee, 0x05281ba4, 0x122a0707,   // hu.sw.un_750 pl.sw.hu_422  tr.sw.fr_433 it.mt.hu_432
  0x27181005, 0x216b1a60, 0x04081708, 0x1e1c25a4,   // lt.ga.gd_333 tl.ceb.jw_664  sr.uk.ru_443 eu.id.ms_433
  0x1a001e0d, 0x2821550d, 0x11251ea0, 0x09182513,   // ms.tl.un_540 rw.jw.sw_554  ms.eu.ro_322 eu.ga.pl_665
  // [2810]
  0x1800090d, 0x646b1a0c, 0x0e001912, 0x042013ee,   // pl.ga.un_540 tl.ceb.lg_543  gl.is.un_640 et.sq.fi_422
  0x136b1a0c, 0x2a0f2108, 0x55002a04, 0x272d0d05,   // tl.ceb.et_543 jw.lv.mt_443  mt.rw.un_320 cs.sk.gd_333
  0x2b6b07ad, 0x110804a4, 0x191c1e0c, 0x040f250c,   // it.ceb.vi_643 ru.uk.ro_433  ms.id.gl_543 eu.lv.fi_543
  0x1325640c, 0x13002022, 0x256455a7, 0x17002a14,   // lg.eu.et_543 sq.et.un_870  rw.lg.eu_532 mt.sr.un_660
  // [2820]
  0x0d000e02, 0x1c0d13ad, 0x64551ba9, 0x1c006b05,   // is.cs.un_220 bh.ne.mr_643  tr.rw.lg_544 ceb.id.un_330
  0x1c2a1fee, 0x0c002902, 0x136425a7, 0x1e1c0c05,   // cy.mt.id_422 sl.sv.un_220  eu.lg.et_532 sv.id.ms_333
  0x2b2a13a0, 0x0c53210c, 0x0900121b, 0x0b0407ee,   // et.mt.vi_322 jw.ht.sv_543  hu.pl.un_770 it.fi.es_422
  0x211a1e07, 0x17000a2b, 0x13071f07, 0x29201702,   // ms.tl.jw_432 mk.sr.un_980  cy.it.et_432 sr.sq.sl_222
  // [2830]
  0x08000422, 0x130f100d, 0x11040708, 0x2a281f09,   // ru.uk.un_870 lt.lv.et_554  bg.ru.ro_443 cy.sw.mt_444
  0x0d182711, 0x0c133f07, 0x13041ba9, 0x1b080204,   // gd.ga.cs_653 af.et.sv_432  tr.fi.et_544 da.no.tr_332
  0x130e04ec, 0x170a04a4, 0x036b07ad, 0x100f2504,   // fi.is.et_644 ru.mk.sr_433  it.ceb.nl_643 eu.lv.lt_332
  0x06006e22, 0x13250d0c, 0x23000b07, 0x1c0e6ea6,   // blu.de.un_870 cs.eu.et_543  es.ca.un_420 blu.is.id_521
  // [2840]
  0x080a10af, 0x251716a4, 0x0c311baf, 0x0a00060d,   // be.mk.uk_655 hr.sr.eu_433  tr.az.sv_655 de.pt.un_540
  0x0a1704a6, 0x12000804, 0x0a170808, 0x180127a4,   // ru.sr.mk_521 no.hu.un_320  uk.sr.mk_443 gd.en.ga_433
  0x021a6b11, 0x23006e18, 0x011205a4, 0x11190b05,   // ceb.tl.da_653 blu.ca.un_740  fr.hu.en_433 es.gl.ro_333
  0x1f001208, 0x18050807, 0x2b1b25a7, 0x18000621,   // hu.cy.un_430 no.fr.ga_432  eu.tr.vi_532 de.ga.un_860
  // [2850]
  0x07080c07, 0x23006e0c, 0x1f1a010c, 0x0b00250c,   // sv.no.it_432 blu.ca.un_530  en.tl.cy_543 eu.es.un_530
  0x10000912, 0x071b05a9, 0x271218a6, 0x0a071004,   // pl.lt.un_640 fr.tr.it_544  ga.hu.gd_521 be.bg.mk_332
  0x27001308, 0x071209a7, 0x0b232da4, 0x060302a0,   // et.gd.un_430 pl.hu.it_532  sk.ca.es_433 da.nl.de_322
  0x11011f07, 0x0a001114, 0x0f1729ee, 0x0c000f02,   // cy.en.ro_432 ro.pt.un_660  sl.sr.lv_422 lv.sv.un_220
  // [2860]
  0x1700040e, 0x081710ee, 0x3f201c07, 0x6e000613,   // ru.sr.un_550 be.sr.uk_422  id.sq.af_432 de.blu.un_650
  0x07231109, 0x0b191107, 0x036e1c07, 0x1a0208a0,   // ro.ca.it_444 ro.gl.es_432  id.blu.nl_432 no.da.tl_322
  0x1e1c6eaf, 0x090d13ad, 0x1220080c, 0x191110a0,   // blu.id.ms_655 bh.ne.hi_643  no.sq.hu_543 lt.ro.gl_322
  0x530a05a9, 0x051b29a0, 0x3f0523ad, 0x171607a0,   // fr.pt.ht_544 sl.tr.fr_322  ca.fr.af_643 it.hr.sr_322
  // [2870]
  0x0500530d, 0x1a002123, 0x04171107, 0x00001e24,   // ht.fr.un_540 jw.tl.un_880  ro.sr.ru_432 ms.un.un_900
  0x091c1304, 0x09002808, 0x08170409, 0x03071107,   // bh.mr.hi_332 sw.pl.un_430  ru.sr.uk_444 ro.it.nl_432
  0x1c2128a9, 0x0b000908, 0x09212812, 0x25092aa0,   // sw.jw.id_544 pl.es.un_430  sw.jw.pl_654 mt.pl.eu_322
  0x28211aaf, 0x2d17160d, 0x10001904, 0x53212805,   // tl.jw.sw_655 hr.sr.sk_554  gl.lt.un_320 sw.jw.ht_333
  // [2880]
  0x285331ad, 0x1e1c6409, 0x2a000908, 0x1e001c13,   // az.ht.sw_643 lg.id.ms_444  pl.mt.un_430 id.ms.un_650
  0x64002104, 0x0209050c, 0x162d2904, 0x1e006407,   // jw.lg.un_320 fr.pl.da_543  sl.sk.hr_332 lg.ms.un_420
  0x286421ee, 0x13002a04, 0x211a28a4, 0x09190604,   // jw.lg.sw_422 mt.et.un_320  sw.tl.jw_433 de.gl.pl_332
  0x096b1a0c, 0x1b006408, 0x1c210913, 0x2d0306ad,   // tl.ceb.pl_543 lg.tr.un_430  pl.jw.id_665 de.nl.sk_643
  // [2890]
  0x64281aa4, 0x096428a6, 0x1a0205ad, 0x1c0d13a9,   // tl.sw.lg_433 sw.lg.pl_521  fr.da.tl_643 bh.ne.mr_544
  0x090c2d07, 0x0c080260, 0x07170808, 0x553f2d07,   // sk.sv.pl_432 da.no.sv_664  uk.sr.bg_443 sk.af.rw_432
  0x171612a0, 0x532864a7, 0x2d0906a6, 0x1f001e02,   // hu.hr.sr_322 lg.sw.ht_532  de.pl.sk_521 ms.cy.un_220
  0x01005304, 0x21006414, 0x5300640d, 0x64552812,   // ht.en.un_320 lg.jw.un_660  lg.ht.un_540 sw.rw.lg_654
  // [28a0]
  0x31536408, 0x040a07a4, 0x162d17a0, 0x1e00530c,   // lg.ht.az_443 bg.mk.ru_433  sr.sk.hr_322 ht.ms.un_530
  0x170a11ec, 0x0b2153a7, 0x02000c08, 0x18011ba0,   // ro.mk.sr_644 ht.jw.es_532  sv.da.un_430 tr.en.ga_322
  0x07001b0d, 0x08060207, 0x07010ba7, 0x18001902,   // tr.it.un_540 da.de.no_432  es.en.it_532 gl.ga.un_220
  0x17071007, 0x05641313, 0x31001b05, 0x10110713,   // be.bg.sr_432 et.lg.fr_665  tr.az.un_330 it.ro.lt_665
  // [28b0]
  0x172d0d55, 0x0d091c11, 0x080216a0, 0x1e1c280c,   // cs.sk.sr_442 mr.hi.ne_653  hr.da.no_322 sw.id.ms_543
  0x0603550c, 0x1e000f04, 0x23001f02, 0x10170fee,   // rw.nl.de_543 lv.ms.un_320  cy.ca.un_220 lv.sr.lt_422
  0x190206ee, 0x081f2807, 0x0b0e19a4, 0x172808a0,   // de.da.gl_422 sw.cy.no_432  gl.is.es_433 no.sw.sr_322
  0x130d0955, 0x190e0ba4, 0x050701a9, 0x11002b04,   // hi.ne.bh_442 es.is.gl_433  en.it.fr_544 vi.ro.un_320
  // [28c0]
  0x2112180e, 0x19000b11, 0x2917160c, 0x01002104,   // ar.ur.fa_555 es.gl.un_630  hr.sr.sl_543 jw.en.un_320
  0x03002107, 0x21003f02, 0x106b55a0, 0x050c08a9,   // jw.nl.un_420 af.jw.un_220  rw.ceb.lt_322 no.sv.fr_544
  0x1b5501ee, 0x2b000502, 0x2100640c, 0x08132aa4,   // en.rw.tr_422 fr.vi.un_220  lg.jw.un_530 mt.et.no_433
  0x07040a05, 0x211120a0, 0x102d0d05, 0x10001719,   // mk.ru.bg_333 sq.ro.jw_322  cs.sk.lt_333 sr.be.un_750
  // [28d0]
  0x270b010c, 0x080205a4, 0x291716af, 0x1a212755,   // en.es.gd_543 fr.da.no_433  hr.sr.sl_655 gd.jw.tl_442
  0x072301a4, 0x13000a29, 0x181127a7, 0x071011ee,   // en.ca.it_433 pt.et.un_960  gd.ro.ga_532 ro.be.bg_422
  0x1c213f09, 0x122a0708, 0x2900160c, 0x21033f0c,   // af.jw.id_444 it.mt.hu_443  hr.sl.un_530 af.nl.jw_543
  0x13001c02, 0x1a0501a4, 0x050907a0, 0x010819a0,   // mr.bh.un_220 en.fr.tl_433  it.pl.fr_322 gl.no.en_322
  // [28e0]
  0x04080aa7, 0x1e1629a4, 0x06022004, 0x190a04a4,   // mk.uk.ru_532 sl.hr.ms_433  sq.da.de_332 fi.pt.gl_433
  0x0b190a13, 0x13000419, 0x06130c0c, 0x190b20a0,   // pt.gl.es_665 fi.et.un_750  sv.et.de_543 sq.es.gl_322
  0x162d0d5a, 0x3f000312, 0x0a1711a7, 0x08060e07,   // cs.sk.hr_553 nl.af.un_640  ro.sr.mk_532 is.de.no_432
  0x0e006402, 0x29171611, 0x060f0ead, 0x13000402,   // lg.is.un_220 hr.sr.sl_653  is.lv.de_643 fi.et.un_220
  // [28f0]
  0x0800060c, 0x11182307, 0x29005319, 0x110a0712,   // de.no.un_530 ca.ga.ro_432  ht.sl.un_750 it.pt.ro_654
  0x1e005304, 0x060f2507, 0x122d0d60, 0x55642812,   // ht.ms.un_320 eu.lv.de_432  cs.sk.hu_664 sw.lg.rw_654
  0x130604a9, 0x162d0d05, 0x04000811, 0x0a040807,   // fi.de.et_544 cs.sk.hr_333  uk.ru.un_630 uk.ru.mk_432
  0x0f3f08a0, 0x13000e05, 0x0c2813ee, 0x3f011f04,   // no.af.lv_322 is.et.un_330  et.sw.sv_422 cy.en.af_332
  // [2900]
  0x210904a7, 0x04081055, 0x190b0504, 0x106b3fa0,   // fi.pl.jw_532 be.uk.ru_442  fr.es.gl_332 af.ceb.lt_322
  0x0e002904, 0x122d0d11, 0x2017290d, 0x1c001311,   // sl.is.un_320 cs.sk.hu_653  sl.sr.sq_554 bh.mr.un_630
  0x0e21100c, 0x16001107, 0x04000707, 0x0d002d19,   // lt.jw.is_543 ro.hr.un_420  bg.ru.un_420 sk.cs.un_750
  0x10002d19, 0x1e1c03a4, 0x08001705, 0x08000604,   // sk.lt.un_750 nl.id.ms_433  sr.uk.un_330 de.no.un_320
  // [2910]
  0x0f161707, 0x04003f1a, 0x0d1629ad, 0x04100fec,   // sr.hr.lv_432 af.fi.un_760  sl.hr.cs_643 lv.lt.fi_644
  0x0e291608, 0x0700080e, 0x080e1211, 0x04000f14,   // hr.sl.is_443 uk.bg.un_550  hu.is.no_653 lv.fi.un_660
  0x04081014, 0x12000e0c, 0x6b1a1ea0, 0x04001105,   // be.uk.ru_666 is.hu.un_530  ms.tl.ceb_322 ro.fi.un_330
  0x101708a4, 0x28000423, 0x04001111, 0x08001008,   // uk.sr.be_433 fi.sw.un_880  ro.ru.un_630 lt.no.un_430
  // [2920]
  0x1f1a1008, 0x08002302, 0x00006b2d, 0x13091c0d,   // lt.tl.cy_443 ca.no.un_220  ceb.un.un_A00 mr.hi.bh_554
  0x13000d18, 0x64130f08, 0x06002a07, 0x0407640c,   // ne.bh.un_740 lv.et.lg_443  mt.de.un_420 lg.it.fi_543
  0x0f131113, 0x1b002807, 0x28130f08, 0x08041111,   // ro.et.lv_665 sw.tr.un_420  lv.et.sw_443 ro.ru.uk_653
  0x2d000d20, 0x13002814, 0x07170a09, 0x0f136408,   // cs.sk.un_850 sw.et.un_660  mk.sr.bg_444 lg.et.lv_443
  // [2930]
  0x13042104, 0x03000404, 0x6b2a2713, 0x0400130e,   // jw.fi.et_332 fi.nl.un_320  gd.mt.ceb_665 et.fi.un_550
  0x041e130c, 0x10083104, 0x25270107, 0x3f1b180c,   // et.ms.fi_543 az.no.lt_332  en.gd.eu_432 ga.tr.af_543
  0x080c0255, 0x07000504, 0x080201a4, 0x1000011a,   // da.sv.no_442 fr.it.un_320  en.da.no_433 en.lt.un_760
  0x3f000108, 0x180506a9, 0x0c00030d, 0x16000909,   // en.af.un_430 de.fr.ga_544  nl.sv.un_540 pl.hr.un_440
  // [2940]
  0x18062704, 0x083f13ec, 0x06020fa4, 0x2000021a,   // gd.de.ga_332 et.af.no_644  lv.da.de_433 da.sq.un_760
  0x3f250309, 0x023f130c, 0x0f642805, 0x07171107,   // nl.eu.af_444 et.af.da_543  sw.lg.lv_333 ro.sr.bg_432
  0x05001907, 0x041328ec, 0x0400082a, 0x3f1327a4,   // gl.fr.un_420 sw.et.fi_644  uk.ru.un_970 gd.et.af_433
  0x200413a9, 0x17041107, 0x1900100e, 0x070810a0,   // et.fi.sq_544 ro.ru.sr_432  lt.gl.un_550 be.uk.bg_322
  // [2950]
  0x10001f23, 0x1a130407, 0x1200200d, 0x0d170f05,   // cy.lt.un_880 fi.et.tl_432  sq.hu.un_540 lv.sr.cs_333
  0x1f000107, 0x06006b04, 0x05110704, 0x1a2a1b07,   // en.cy.un_420 ceb.de.un_320  it.ro.fr_332 tr.mt.tl_432
  0x09182711, 0x070e08a0, 0x281c1ea4, 0x12001004,   // gd.ga.pl_653 no.is.it_322  ms.id.sw_433 lt.hu.un_320
  0x09271812, 0x083f1b08, 0x2d00091a, 0x1a6b0112,   // ga.gd.pl_654 tr.af.no_443  pl.sk.un_760 en.ceb.tl_654
  // [2960]
  0x041355ec, 0x091827af, 0x05190107, 0x18272a14,   // rw.et.fi_644 gd.ga.pl_655  en.gl.fr_432 mt.gd.ga_666
  0x1f180607, 0x3f1320ad, 0x18092714, 0x55006409,   // de.ga.cy_432 sq.et.af_643  gd.pl.ga_666 lg.rw.un_440
  0x052701a4, 0x182721a4, 0x05110108, 0x092706a4,   // en.gd.fr_433 jw.gd.ga_433  en.ro.fr_443 de.gd.pl_433
  0x1a1e6bee, 0x27010904, 0x18272a0c, 0x0800111a,   // ceb.ms.tl_422 pl.en.gd_332  mt.gd.ga_543 ro.uk.un_760
  // [2970]
  0x1e1c12a0, 0x28001e02, 0x641e1c55, 0x55006408,   // hu.id.ms_322 ms.sw.un_220  id.ms.lg_442 lg.rw.un_430
  0x18532d04, 0x1c2001a4, 0x2709180d, 0x1c2d0d04,   // sk.ht.ga_332 en.sq.id_433  ga.pl.gd_554 cs.sk.id_332
  0x18000802, 0x231e1c55, 0x10000913, 0x091827a9,   // no.ga.un_220 id.ms.ca_442  pl.lt.un_650 gd.ga.pl_544
  0x09271813, 0x16002a1a, 0x1f18270c, 0x182709a7,   // ga.gd.pl_665 mt.hr.un_760  gd.ga.cy_543 pl.gd.ga_532
  // [2980]
  0x02000c23, 0x08000c02, 0x64285560, 0x011f1a02,   // sv.da.un_880 sv.no.un_220  rw.sw.lg_664 tl.cy.en_222
  0x20001902, 0x551e1c55, 0x06000912, 0x07170402,   // gl.sq.un_220 id.ms.rw_442  pl.de.un_640 ru.sr.bg_222
  0x1a1e1c55, 0x2d161208, 0x2a001f34, 0x021a09a7,   // id.ms.tl_442 hu.hr.sk_443  cy.mt.un_A80 pl.tl.da_532
  0x020c3f04, 0x23000707, 0x111b25a0, 0x64250e09,   // af.sv.da_332 it.ca.un_420  eu.tr.ro_322 is.eu.lg_444
  // [2990]
  0x1c2a1e07, 0x1a3f0ba0, 0x16000204, 0x23190b08,   // ms.mt.id_432 es.af.tl_322  da.hr.un_320 es.gl.ca_443
  0x0f642a04, 0x1f1b11a4, 0x13170904, 0x17162aa4,   // mt.lg.lv_332 ro.tr.cy_433  pl.sr.et_332 mt.hr.sr_433
  0x2b000504, 0x2800090e, 0x16000912, 0x04000302,   // fr.vi.un_320 pl.sw.un_550  pl.hr.un_640 nl.fi.un_220
  0x1c171004, 0x1a00090e, 0x0328090b, 0x0e000b04,   // lt.sr.id_332 pl.tl.un_550  pl.sw.nl_542 es.is.un_320
  // [29a0]
  0x09006405, 0x101f2507, 0x18002a07, 0x06640907,   // lg.pl.un_330 eu.cy.lt_432  mt.ga.un_420 pl.lg.de_432
  0x063f03a4, 0x2a0f11a9, 0x06000121, 0x0f051004,   // nl.af.de_433 ro.lv.mt_544  en.de.un_860 lt.fr.lv_332
  0x251f2aaf, 0x092153a7, 0x11132a07, 0x100704a0,   // mt.cy.eu_655 ht.jw.pl_532  mt.et.ro_432 ru.bg.be_322
  0x6400532a, 0x091c13ee, 0x21065305, 0x040817a9,   // ht.lg.un_970 bh.mr.hi_422  ht.de.jw_333 sr.uk.ru_544
  // [29b0]
  0x1200100d, 0x1e1c1b05, 0x060c08ee, 0x272021a7,   // lt.hu.un_540 tr.id.ms_333  no.sv.de_422 jw.sq.gd_532
  0x116b1aa4, 0x07100a05, 0x131c0da9, 0x010d1002,   // tl.ceb.ro_433 mk.be.bg_333  ne.mr.bh_544 lt.cs.en_222
  0x062b55ad, 0x3f021304, 0x131755a4, 0x033f6408,   // rw.vi.de_643 et.da.af_332  rw.sr.et_433 lg.af.nl_443
  0x25010b11, 0x160601ad, 0x1a001b0c, 0x3f0428ad,   // es.en.eu_653 en.de.hr_643  tr.tl.un_530 sw.fi.af_643
  // [29c0]
  0x31641ca0, 0x03000209, 0x0e000604, 0x180627a7,   // id.lg.az_322 da.nl.un_440  de.is.un_320 gd.de.ga_532
  0x02033f0c, 0x3f006404, 0x181920ba, 0x0f000518,   // af.nl.da_543 lg.af.un_320  sq.gl.ga_843 fr.lv.un_740
  0x1c641ead, 0x216e1a04, 0x03063fa0, 0x53001913,   // ms.lg.id_643 tl.blu.jw_332  af.de.nl_322 gl.ht.un_650
  0x2d0d0902, 0x0f002d04, 0x13001c12, 0x190a23af,   // pl.cs.sk_222 sk.lv.un_320  mr.bh.un_640 ca.pt.gl_655
  // [29d0]
  0x091e1c04, 0x2800250d, 0x0a1f2507, 0x31002d04,   // id.ms.pl_332 eu.sw.un_540  eu.cy.pt_432 sk.az.un_320
  0x133f0355, 0x08021f55, 0x10000405, 0x03001c09,   // nl.af.et_442 cy.da.no_442  ru.be.un_330 id.nl.un_440
  0x033f02ee, 0x19101604, 0x3f002502, 0x3f2106a0,   // da.af.nl_422 hr.lt.gl_332  eu.af.un_220 de.jw.af_322
  0x0a001002, 0x121821ee, 0x0a171008, 0x3f530307,   // be.mk.un_220 fa.ar.ur_422  be.sr.mk_443 nl.ht.af_432
  // [29e0]
  0x0a000504, 0x23190aaf, 0x03533fa4, 0x12001809,   // fr.pt.un_320 pt.gl.ca_655  af.ht.nl_433 ga.hu.un_440
  0x1b002805, 0x17040a02, 0x533f03ac, 0x16000d04,   // sw.tr.un_330 mk.ru.sr_222  nl.af.ht_632 cs.hr.un_320
  0x12192da9, 0x1f3f2504, 0x2a27110c, 0x55046ba4,   // sk.gl.hu_544 eu.af.cy_332  ro.gd.mt_543 ceb.fi.rw_433
  0x2a060107, 0x13080c07, 0x10091f0b, 0x641b53a0,   // en.de.mt_432 sv.no.et_432  cy.pl.lt_542 ht.tr.lg_322
  // [29f0]
  0x030408a0, 0x08020ea9, 0x132a0707, 0x08192da0,   // no.fi.nl_322 is.da.no_544  it.mt.et_432 sk.gl.no_322
  0x12000e04, 0x0212010b, 0x050364ad, 0x55006b08,   // is.hu.un_320 en.hu.da_542  lg.nl.fr_643 ceb.rw.un_430
  0x28006b20, 0x09000321, 0x05000b0d, 0x31131b11,   // ceb.sw.un_850 nl.pl.un_860  es.fr.un_540 tr.et.az_653
  0x0c080ea9, 0x04080a05, 0x21181208, 0x190b010c,   // is.no.sv_544 mk.uk.ru_333  ur.ar.fa_443 en.es.gl_543
  // [2a00]
  0x2100531a, 0x042711ad, 0x0c001f02, 0x1a066ba0,   // ht.jw.un_760 ro.gd.fi_643  cy.sv.un_220 ceb.de.tl_322
  0x12000b04, 0x250713ee, 0x09000d0b, 0x2a006b07,   // es.hu.un_320 et.it.eu_422  ne.hi.un_520 ceb.mt.un_420
  0x29170dee, 0x181304ad, 0x1b2031ee, 0x081704a0,   // cs.sr.sl_422 fi.et.ga_643  az.sq.tr_422 ru.sr.uk_322
  0x2a080c05, 0x190b2307, 0x07040860, 0x19040709,   // sv.no.mt_333 ca.es.gl_432  uk.ru.bg_664 it.fi.gl_444
  // [2a10]
  0x08131f07, 0x3f036ba0, 0x27000412, 0x28005508,   // cy.et.no_432 ceb.nl.af_322  fi.gd.un_640 rw.sw.un_430
  0x0d00290b, 0x232b250c, 0x121a6b0c, 0x2d001008,   // sl.cs.un_520 eu.vi.ca_543  ceb.tl.hu_543 lt.sk.un_430
  0x0b002307, 0x25002313, 0x012a2802, 0x2b002502,   // ca.es.un_420 ca.eu.un_650  sw.mt.en_222 eu.vi.un_220
  0x23005302, 0x2300250d, 0x1a286b02, 0x25041108,   // ht.ca.un_220 eu.ca.un_540  ceb.sw.tl_222 ro.fi.eu_443
  // [2a20]
  0x281e64ec, 0x0a040804, 0x17041111, 0x08060faf,   // lg.ms.sw_644 uk.ru.mk_332  ro.ru.sr_653 lv.de.no_655
  0x170408a4, 0x0a041108, 0x030f0655, 0x130427ec,   // uk.ru.sr_433 ro.ru.mk_443  de.lv.nl_442 gd.fi.et_644
  0x10000f07, 0x18000622, 0x10000614, 0x28005304,   // lv.lt.un_420 de.ga.un_870  de.lt.un_660 ht.sw.un_320
  0x0e061faf, 0x081004a0, 0x08060e0c, 0x21181205,   // cy.de.is_655 ru.be.uk_322  is.de.no_543 ur.ar.fa_333
  // [2a30]
  0x19080309, 0x230b0a04, 0x0810070c, 0x050a2ba9,   // nl.no.gl_444 pt.es.ca_332  bg.be.uk_543 vi.pt.fr_544
  0x080411ad, 0x200201a0, 0x0a130fa9, 0x00001e1c,   // ro.ru.uk_643 en.da.sq_322  lv.et.pt_544 ms.un.un_800
  0x2b112702, 0x06190a09, 0x0300060d, 0x080e0607,   // gd.ro.vi_222 pt.gl.de_444  de.nl.un_540 de.is.no_432
  0x093f16a0, 0x06033f5a, 0x133f12a9, 0x130c06a9,   // hr.af.pl_322 af.nl.de_553  hu.af.et_544 de.sv.et_544
  // [2a40]
  0x0c001605, 0x6b001a29, 0x533f05a6, 0x312120a0,   // hr.sv.un_330 tl.ceb.un_960  fr.af.ht_521 sq.jw.az_322
  0x2b182755, 0x0c0601a0, 0x016b20ad, 0x0f002007,   // gd.ga.vi_442 en.de.sv_322  sq.ceb.en_643 sq.lv.un_420
  0x31201bee, 0x1b0c02a9, 0x0e062704, 0x0d000f04,   // tr.sq.az_422 da.sv.tr_544  gd.de.is_332 lv.cs.un_320
  0x06020ca9, 0x02001304, 0x18005312, 0x1f03060c,   // sv.da.de_544 et.da.un_320  ht.ga.un_640 de.nl.cy_543
  // [2a50]
  0x10070a07, 0x55000611, 0x11100f04, 0x210e0fa4,   // mk.bg.be_432 de.rw.un_630  lv.lt.ro_332 lv.is.jw_433
  0x12051fa4, 0x2a0653ec, 0x130853a4, 0x0f13040b,   // cy.fr.hu_433 ht.de.mt_644  ht.no.et_433 fi.et.lv_542
  0x130c0407, 0x061827ec, 0x53000505, 0x040f1309,   // fi.sv.et_432 gd.ga.de_644  fr.ht.un_330 et.lv.fi_444
  0x07081107, 0x6400060c, 0x0c000809, 0x020e0707,   // ro.uk.bg_432 de.lg.un_530  no.sv.un_440 it.is.da_432
  // [2a60]
  0x640655ec, 0x100f2a07, 0x21002a08, 0x170704a0,   // rw.de.lg_644 mt.lv.lt_432  mt.jw.un_430 ru.bg.sr_322
  0x05640107, 0x0a000907, 0x04080712, 0x070a0407,   // en.lg.fr_432 pl.pt.un_420  bg.uk.ru_654 ru.mk.bg_432
  0x2a0164ad, 0x00001a2d, 0x03556405, 0x28550507,   // lg.en.mt_643 tl.un.un_A00  lg.rw.nl_333 fr.rw.sw_432
  0x20092d11, 0x03006421, 0x286b1aa7, 0x030c08ad,   // sk.pl.sq_653 lg.nl.un_860  tl.ceb.sw_532 no.sv.nl_643
  // [2a70]
  0x55003f1a, 0x2b0a2812, 0x5502060c, 0x1b001c04,   // af.rw.un_760 sw.pt.vi_654  de.da.rw_543 id.tr.un_320
  0x090e1f08, 0x0f101355, 0x55006e19, 0x02000f04,   // cy.is.pl_443 et.lt.lv_442  blu.rw.un_750 lv.da.un_320
  0x1f0a20ac, 0x04050112, 0x280602a7, 0x053f060c,   // sq.pt.cy_632 en.fr.fi_654  da.de.sw_532 de.af.fr_543
  0x0a170707, 0x0e000205, 0x13040c55, 0x090e0f08,   // bg.sr.mk_432 da.is.un_330  sv.fi.et_442 lv.is.pl_443
  // [2a80]
  0x1a00641b, 0x0b001a04, 0x08100411, 0x042a0ead,   // lg.tl.un_770 tl.es.un_320  ru.be.uk_653 is.mt.fi_643
  0x03123f04, 0x041321a4, 0x06000208, 0x0b0a19ec,   // af.hu.nl_332 jw.et.fi_433  da.de.un_430 gl.pt.es_644
  0x210464a0, 0x1803060c, 0x170a075a, 0x31006404,   // lg.fi.jw_322 de.nl.ga_543  bg.mk.sr_553 lg.az.un_320
  0x642813ad, 0x31000404, 0x21001b07, 0x18001a02,   // et.sw.lg_643 fi.az.un_320  tr.jw.un_420 tl.ga.un_220
  // [2a90]
  0x3f0429ee, 0x170f16a4, 0x1c6428a0, 0x0f04100c,   // sl.fi.af_422 hr.lv.sr_433  sw.lg.id_322 lt.fi.lv_543
  0x100c0807, 0x2b0908af, 0x0c0e02a0, 0x07002b07,   // no.sv.lt_432 no.pl.vi_655  da.is.sv_322 vi.it.un_420
  0x171a2da9, 0x170416a0, 0x10040802, 0x2b001313,   // sk.tl.sr_544 hr.fi.sr_322  uk.ru.be_222 et.vi.un_650
  0x1c001608, 0x161b28a0, 0x25002d02, 0x172916a9,   // hr.id.un_430 sw.tr.hr_322  sk.eu.un_220 hr.sl.sr_544
  // [2aa0]
  0x0600010c, 0x21080207, 0x16201004, 0x1a2825ad,   // en.de.un_530 da.no.jw_432  lt.sq.hr_332 eu.sw.tl_643
  0x060501ec, 0x070411a7, 0x0653250c, 0x10080a14,   // en.fr.de_644 ro.ru.bg_532  eu.ht.de_543 mk.uk.be_666
  0x03000f04, 0x10170aa0, 0x01103f0b, 0x0c0802a0,   // lv.nl.un_320 mk.sr.be_322  af.lt.en_542 da.no.sv_322
  0x0a070413, 0x1900080c, 0x2a002012, 0x6b001a08,   // ru.bg.mk_665 no.gl.un_530  sq.mt.un_640 tl.ceb.un_430
  // [2ab0]
  0x180a0513, 0x032923a9, 0x16093105, 0x27100f05,   // fr.pt.ga_665 ca.sl.nl_544  az.pl.hr_333 lv.lt.gd_333
  0x04070aa4, 0x0d002d22, 0x1b000420, 0x1a016b08,   // mk.bg.ru_433 sk.cs.un_870  fi.tr.un_850 ceb.en.tl_443
  0x0a11270c, 0x2b080202, 0x170a04ec, 0x20211c07,   // gd.ro.pt_543 da.no.vi_222  ru.mk.sr_644 id.jw.sq_432
  0x120d2dad, 0x19110a04, 0x01111aa0, 0x182112ee,   // sk.cs.hu_643 pt.ro.gl_332  tl.ro.en_322 ur.fa.ar_422
  // [2ac0]
  0x530c0205, 0x5328050c, 0x230b010c, 0x0600120d,   // da.sv.ht_333 fr.sw.ht_543  en.es.ca_543 hu.de.un_540
  0x12001813, 0x023f080c, 0x04130205, 0x040708ee,   // ar.ur.un_650 no.af.da_543  da.et.fi_333 uk.bg.ru_422
  0x13121b0c, 0x083f1b11, 0x071708ad, 0x110a080d,   // tr.hu.et_543 tr.af.no_653  uk.sr.bg_643 uk.mk.ro_554
  0x17160fa0, 0x13001b13, 0x25070c07, 0x11000c08,   // lv.hr.sr_322 tr.et.un_650  sv.it.eu_432 sv.ro.un_430
  // [2ad0]
  0x132820a7, 0x100411a0, 0x1e11550b, 0x02060ca4,   // sq.sw.et_532 ro.ru.be_322  rw.ro.ms_542 sv.de.da_433
  0x11230107, 0x2d000a0e, 0x0b05190d, 0x100804a4,   // en.ca.ro_432 pt.sk.un_550  gl.fr.es_554 ru.uk.be_433
  0x212d01a0, 0x1000040c, 0x2100641a, 0x27180c0b,   // en.sk.jw_322 ru.be.un_530  lg.jw.un_760 sv.ga.gd_542
  0x3f1b13af, 0x18283fa9, 0x05000a02, 0x3f1b1260,   // et.tr.af_655 af.sw.ga_544  pt.fr.un_220 hu.tr.af_664
  // [2ae0]
  0x21070ba4, 0x08110a07, 0x16001013, 0x2b000b02,   // es.it.jw_433 mk.ro.uk_432  lt.hr.un_650 es.vi.un_220
  0x13230aa0, 0x02000a07, 0x110a23a0, 0x0c1b64a0,   // pt.ca.et_322 pt.da.un_420  ca.pt.ro_322 lg.tr.sv_322
  0x04101713, 0x251e1c0e, 0x2a001f04, 0x041007a9,   // sr.be.ru_665 id.ms.eu_555  cy.mt.un_320 bg.be.ru_544
  0x28122507, 0x190a03a0, 0x0a1e25ec, 0x29000202,   // eu.hu.sw_432 nl.pt.gl_322  eu.ms.pt_644 da.sl.un_220
  // [2af0]
  0x1e002514, 0x31000c04, 0x0a002507, 0x03023fa0,   // eu.ms.un_660 sv.az.un_320  eu.pt.un_420 af.da.nl_322
  0x09001702, 0x1f280a05, 0x64001a04, 0x0d1c09ad,   // sr.pl.un_220 pt.sw.cy_333  tl.lg.un_320 hi.mr.ne_643
  0x100717ee, 0x02060c02, 0x052d0d13, 0x12000707,   // sr.bg.be_422 sv.de.da_222  cs.sk.fr_665 it.hu.un_420
  0x0a040709, 0x06001309, 0x0d091c14, 0x07000a05,   // bg.ru.mk_444 et.de.un_440  mr.hi.ne_666 mk.bg.un_330
  // [2b00]
  0x06000521, 0x190b2302, 0x1e1c25af, 0x130627ee,   // fr.de.un_860 ca.es.gl_222  eu.id.ms_655 gd.de.et_422
  0x18005313, 0x0a081105, 0x13002004, 0x1f033f5a,   // ht.ga.un_650 ro.uk.mk_333  sq.et.un_320 af.nl.cy_553
  0x11092bee, 0x013f0304, 0x132a040c, 0x27001e02,   // vi.pl.ro_422 nl.af.en_332  fi.mt.et_543 ms.gd.un_220
  0x2b001a02, 0x23070e0c, 0x080e0c07, 0x081107a9,   // tl.vi.un_220 is.it.ca_543  sv.is.no_432 bg.ro.uk_544
  // [2b10]
  0x12002d08, 0x0806130b, 0x010416ee, 0x08020e08,   // sk.hu.un_430 et.de.no_542  hr.fi.en_422 is.da.no_443
  0x13060513, 0x0f0b19af, 0x53002b14, 0x1c022bee,   // fr.de.et_665 gl.es.lv_655  vi.ht.un_660 vi.da.id_422
  0x0c2a0804, 0x0f002813, 0x1c0e21a0, 0x071b2aaf,   // no.mt.sv_332 sw.lv.un_650  jw.is.id_322 mt.tr.it_655
  0x2d0d11a0, 0x05110111, 0x191a210d, 0x2b001105,   // ro.cs.sk_322 en.ro.fr_653  jw.tl.gl_554 ro.vi.un_330
  // [2b20]
  0x170a10a7, 0x17100a13, 0x0d000913, 0x162d2909,   // be.mk.sr_532 mk.be.sr_665  hi.ne.un_650 sl.sk.hr_444
  0x11002104, 0x050201ee, 0x10000f04, 0x01000712,   // jw.ro.un_320 en.da.fr_422  lv.lt.un_320 it.en.un_640
  0x01002a02, 0x0e122308, 0x641a6b07, 0x29071102,   // mt.en.un_220 ca.hu.is_443  ceb.tl.lg_432 ro.it.sl_222
  0x29101604, 0x21001235, 0x01002304, 0x041801a0,   // hr.lt.sl_332 ur.fa.un_A90  ca.en.un_320 en.ga.fi_322
  // [2b30]
  0x160d2da0, 0x096428a4, 0x08070aa0, 0x0a0710a4,   // sk.cs.hr_322 sw.lg.pl_433  mk.bg.uk_322 be.bg.mk_433
  0x040810a4, 0x28001f05, 0x55642813, 0x3f000311,   // be.uk.ru_433 cy.sw.un_330  sw.lg.rw_665 nl.af.un_630
  0x556428ad, 0x12000b09, 0x100617a0, 0x06000819,   // sw.lg.rw_643 es.hu.un_440  sr.de.lt_322 no.de.un_750
  0x0327180d, 0x31000f04, 0x0d101702, 0x10000e12,   // ga.gd.nl_554 lv.az.un_320  sr.lt.cs_222 is.lt.un_640
  // [2b40]
  0x31002814, 0x033f2704, 0x170704a9, 0x030a07a0,   // sw.az.un_660 gd.af.nl_332  ru.bg.sr_544 it.pt.nl_322
  0x10170fa0, 0x6b1a0109, 0x1e5564a7, 0x0f00290d,   // lv.sr.lt_322 en.tl.ceb_444  lg.rw.ms_532 sl.lv.un_540
  0x11001021, 0x01001814, 0x17040802, 0x040a0804,   // be.ro.un_860 ga.en.un_660  uk.ru.sr_222 uk.mk.ru_332
  0x6409280d, 0x17001019, 0x082d0d0e, 0x1e1621af,   // sw.pl.lg_554 lt.sr.un_750  cs.sk.no_555 jw.hr.ms_655
  // [2b50]
  0x02002a12, 0x20006404, 0x21000412, 0x532155a0,   // mt.da.un_640 lg.sq.un_320  fi.jw.un_640 rw.jw.ht_322
  0x643f06a4, 0x3f6455ec, 0x070a0802, 0x31006409,   // de.af.lg_433 rw.lg.af_644  uk.mk.bg_222 lg.az.un_440
  0x012b1607, 0x3f0327a4, 0x290f10a0, 0x08001704,   // hr.vi.en_432 gd.nl.af_433  lt.lv.sl_322 sr.uk.un_320
  0x190a2314, 0x0c1e1c08, 0x2d211004, 0x29112104,   // ca.pt.gl_666 id.ms.sv_443  lt.jw.sk_332 jw.ro.sl_332
  // [2b60]
  0x0a1704ee, 0x041b0807, 0x64002112, 0x1e1c21a9,   // ru.sr.mk_422 no.tr.fi_432  jw.lg.un_640 jw.id.ms_544
  0x1716100b, 0x0a000412, 0x1e002102, 0x12002a13,   // lt.hr.sr_542 ru.mk.un_640  jw.ms.un_220 mt.hu.un_650
  0x10040714, 0x17160fee, 0x6e006b12, 0x29000f02,   // it.fi.lt_666 lv.hr.sr_422  ceb.blu.un_640 lv.sl.un_220
  0x0f001702, 0x0d000907, 0x08100702, 0x0800021a,   // sr.lv.un_220 hi.ne.un_420  bg.be.uk_222 da.no.un_760
  // [2b70]
  0x18000d02, 0x17002a0d, 0x31002a0c, 0x0e060cee,   // cs.ga.un_220 mt.sr.un_540  mt.az.un_530 sv.de.is_422
  0x033f0605, 0x1c1e2155, 0x3f00060e, 0x1f00061a,   // de.af.nl_333 jw.ms.id_442  de.af.un_550 de.cy.un_760
  0x063f0304, 0x08100707, 0x0410070c, 0x04032504,   // nl.af.de_332 bg.be.uk_432  bg.be.ru_543 eu.nl.fi_332
  0x252321ee, 0x1812210b, 0x31202a0c, 0x02000e05,   // jw.ca.eu_422 fa.ur.ar_542  mt.sq.az_543 is.da.un_330
  // [2b80]
  0x013f060c, 0x19000502, 0x18190b04, 0x0b00190d,   // de.af.en_543 fr.gl.un_220  es.gl.ga_332 gl.es.un_540
  0x280e200b, 0x170416a4, 0x13040b0c, 0x033f060d,   // sq.is.sw_542 hr.fi.sr_433  es.fi.et_543 de.af.nl_554
  0x642921ac, 0x253f0607, 0x04281312, 0x10110812,   // jw.sl.lg_632 de.af.eu_432  et.sw.fi_654 uk.ro.be_654
  0x0e001705, 0x2a2120ec, 0x070a0409, 0x2d0d25ec,   // sr.is.un_330 sq.jw.mt_644  ru.mk.bg_444 eu.cs.sk_644
  // [2b90]
  0x0e00202a, 0x20000e1b, 0x070a0414, 0x170711af,   // sq.is.un_970 is.sq.un_770  ru.mk.bg_666 ro.bg.sr_655
  0x131a21a7, 0x020e0c05, 0x28000b0b, 0x031164a7,   // jw.tl.et_532 sv.is.da_333  es.sw.un_520 lg.ro.nl_532
  0x0413210c, 0x04002121, 0x25033f07, 0x02253f07,   // jw.et.fi_543 jw.fi.un_860  af.nl.eu_432 af.eu.da_432
  0x0f012a04, 0x0c080e55, 0x0a00172b, 0x05190b04,   // mt.en.lv_332 is.no.sv_442  sr.mk.un_980 es.gl.fr_332
  // [2ba0]
  0x033f6ead, 0x06000f0e, 0x2d0d170e, 0x2d17160e,   // blu.af.nl_643 lv.de.un_550  sr.cs.sk_555 hr.sr.sk_555
  0x031f3fa0, 0x3f6e030c, 0x1620170c, 0x17001618,   // af.cy.nl_322 nl.blu.af_543  sr.sq.hr_543 hr.sr.un_740
  0x3f00131a, 0x08111004, 0x6e033faf, 0x211c1e12,   // et.af.un_760 be.ro.uk_332  af.nl.blu_655 ms.id.jw_654
  0x0e0f1fad, 0x131c0908, 0x53072a55, 0x0f130aa0,   // cy.lv.is_643 hi.mr.bh_443  mt.it.ht_442 pt.et.lv_322
  // [2bb0]
  0x21036e08, 0x1c130da9, 0x64002119, 0x0f2a1107,   // blu.nl.jw_443 ne.bh.mr_544  jw.lg.un_750 ro.mt.lv_432
  0x110a08a4, 0x641f280b, 0x12291707, 0x02003f05,   // uk.mk.ro_433 sw.cy.lg_542  sr.sl.hu_432 af.da.un_330
  0x10041105, 0x31001602, 0x2d00290c, 0x1716100e,   // ro.ru.be_333 hr.az.un_220  sl.sk.un_530 lt.hr.sr_555
  0x25006b07, 0x27001f07, 0x12000713, 0x03136eee,   // ceb.eu.un_420 cy.gd.un_420  it.hu.un_650 blu.et.nl_422
  // [2bc0]
  0x040c06a9, 0x13006e13, 0x552d6408, 0x31002904,   // de.sv.fi_544 blu.et.un_650  lg.sk.rw_443 sl.az.un_320
  0x040811ee, 0x04000a21, 0x2a171607, 0x050f6ea0,   // ro.uk.ru_422 mk.ru.un_860  hr.sr.mt_432 blu.lv.fr_322
  0x0e0f10a4, 0x0e130413, 0x311b1107, 0x090d1fa4,   // lt.lv.is_433 fi.et.is_665  ro.tr.az_432 cy.cs.pl_433
  0x08001b13, 0x04641302, 0x12041004, 0x103f0e07,   // tr.no.un_650 et.lg.fi_222  lt.fi.hu_332 is.af.lt_432
  // [2bd0]
  0x02000502, 0x0b1101ad, 0x23180eee, 0x1e081fad,   // fr.da.un_220 en.ro.es_643  is.ga.ca_422 cy.no.ms_643
  0x2a0e0613, 0x55211e55, 0x09001e02, 0x192510a7,   // de.is.mt_665 ms.jw.rw_442  ms.pl.un_220 lt.eu.gl_532
  0x29172008, 0x3f076eec, 0x3f00090c, 0x55000302,   // sq.sr.sl_443 blu.it.af_644  pl.af.un_530 nl.rw.un_220
  0x19311baf, 0x102928ee, 0x07050104, 0x2b006e04,   // tr.az.gl_655 sw.sl.lt_422  en.fr.it_332 blu.vi.un_320
  // [2be0]
  0x2a000202, 0x2a0811af, 0x211b0304, 0x1f060812,   // da.mt.un_220 ro.no.mt_655  nl.tr.jw_332 no.de.cy_654
  0x2d003f02, 0x18000202, 0x1a2753a7, 0x0f2b0308,   // af.sk.un_220 da.ga.un_220  ht.gd.tl_532 nl.vi.lv_443
  0x025331a0, 0x20000f14, 0x31002b21, 0x16291bee,   // az.ht.da_322 lv.sq.un_660  vi.az.un_860 tr.sl.hr_422
  0x28551f05, 0x170a04a7, 0x193f06a0, 0x1a00531a,   // cy.rw.sw_333 ru.mk.sr_532  de.af.gl_322 ht.tl.un_760
  // [2bf0]
  0x1e0c3f07, 0x271808a9, 0x080c020d, 0x1b250c0b,   // af.sv.ms_432 no.ga.gd_544  da.sv.no_554 sv.eu.tr_542
  0x191e1c04, 0x29081b07, 0x021153ad, 0x063f11a0,   // id.ms.gl_332 tr.no.sl_432  ht.ro.da_643 ro.af.de_322
  0x29061604, 0x2b000108, 0x040811a0, 0x270f1ca4,   // hr.de.sl_332 en.vi.un_430  ro.uk.ru_322 id.lv.gd_433
  0x08040707, 0x0719010c, 0x021619a0, 0x21001114,   // bg.ru.uk_432 en.gl.it_543  gl.hr.da_322 ro.jw.un_660

  // [2c00]
  0x1b2d0d12, 0x6b101a07, 0x17061604, 0x160f1205,   // cs.sk.tr_654 tl.lt.ceb_432  hr.de.sr_332 hu.lv.hr_333
  0x1a1e1c0d, 0x21310107, 0x172d0d5a, 0x1a001e13,   // id.ms.tl_554 en.az.jw_432  cs.sk.sr_553 ms.tl.un_650
  0x10311b13, 0x310c1b04, 0x216b1ca4, 0x2000170b,   // tr.az.lt_665 tr.sv.az_332  id.ceb.jw_433 sr.sq.un_520
  0x1b000702, 0x07033f12, 0x12002d12, 0x041708a4,   // it.tr.un_220 af.nl.it_654  sk.hu.un_640 uk.sr.ru_433
  // [2c10]
  0x2100530c, 0x08101704, 0x53311baf, 0x0f251b55,   // ht.jw.un_530 sr.be.uk_332  tr.az.ht_655 tr.eu.lv_442
  0x17160f0c, 0x162d0dee, 0x642010a7, 0x09000402,   // lv.hr.sr_543 cs.sk.hr_422  lt.sq.lg_532 fi.pl.un_220
  0x28000307, 0x13270eec, 0x2a1b1014, 0x6b171602,   // nl.sw.un_420 is.gd.et_644  lt.tr.mt_666 hr.sr.ceb_222
  0x280603a0, 0x21281aa4, 0x1a000312, 0x185553a9,   // nl.de.sw_322 tl.sw.jw_433  nl.tl.un_640 ht.rw.ga_544
  // [2c20]
  0x281a1b0c, 0x0a040812, 0x06002119, 0x6b1a1e13,   // tr.tl.sw_543 uk.ru.mk_654  jw.de.un_750 ms.tl.ceb_665
  0x0e002713, 0x27060eac, 0x04171608, 0x18000513,   // gd.is.un_650 is.de.gd_632  hr.sr.fi_443 fr.ga.un_650
  0x1f1e1ca7, 0x09001c1b, 0x1a251b0c, 0x1c000d11,   // id.ms.cy_532 mr.hi.un_770  tr.eu.tl_543 ne.mr.un_630
  0x060a01a4, 0x180e01a0, 0x0520010c, 0x101729a4,   // en.pt.de_433 en.is.ga_322  en.sq.fr_543 sl.sr.lt_433
  // [2c30]
  0x0a21190c, 0x282029a4, 0x10061f0b, 0x18270eaf,   // gl.jw.pt_543 sl.sq.sw_433  cy.de.lt_542 is.gd.ga_655
  0x27180ead, 0x0b002308, 0x25001907, 0x0e2a27a9,   // is.ga.gd_643 ca.es.un_430  gl.eu.un_420 gd.mt.is_544
  0x1f0a2508, 0x0f1607a0, 0x270501a0, 0x033f2ba7,   // eu.pt.cy_443 it.hr.lv_322  en.fr.gd_322 vi.af.nl_532
  0x0a00040e, 0x28000507, 0x0a1017ad, 0x16001719,   // fi.pt.un_550 fr.sw.un_420  sr.be.mk_643 sr.hr.un_750
  // [2c40]
  0x10000f05, 0x111013ee, 0x31002a04, 0x17292d12,   // lv.lt.un_330 et.lt.ro_422  mt.az.un_320 sk.sl.sr_654
  0x0b1219a9, 0x1b005522, 0x1118270c, 0x1b005521,   // gl.hu.es_544 rw.tr.un_870  gd.ga.ro_543 rw.tr.un_860
  0x080a11ee, 0x0407170c, 0x281b2a05, 0x1e1c2aa0,   // ro.mk.uk_422 sr.bg.ru_543  mt.tr.sw_333 mt.id.ms_322
  0x1004080d, 0x0c001b04, 0x071711ec, 0x02530c04,   // uk.ru.be_554 tr.sv.un_320  ro.sr.bg_644 sv.ht.da_332
  // [2c50]
  0x1e001a07, 0x081117a4, 0x1f21200d, 0x1b005508,   // tl.ms.un_420 sr.ro.uk_433  sq.jw.cy_554 rw.tr.un_430
  0x1e1c3fee, 0x0f003f08, 0x1b005513, 0x28551ba9,   // af.id.ms_422 af.lv.un_430  rw.tr.un_650 tr.rw.sw_544
  0x1600081a, 0x023f0307, 0x53000205, 0x20005308,   // no.hr.un_760 nl.af.da_432  da.ht.un_330 ht.sq.un_430
  0x551b53ad, 0x1f006408, 0x0500231a, 0x11170705,   // ht.tr.rw_643 lg.cy.un_430  ca.fr.un_760 bg.sr.ro_333
  // [2c60]
  0x05005304, 0x071708a0, 0x11170504, 0x0e1f0707,   // ht.fr.un_320 uk.sr.bg_322  fr.sr.ro_332 it.cy.is_432
  0x171129a0, 0x113f0e04, 0x0a170811, 0x53002102,   // sl.ro.sr_322 is.af.ro_332  uk.sr.mk_653 jw.ht.un_220
  0x02000c13, 0x1b3f03ec, 0x0a100804, 0x0a000507,   // sv.da.un_650 nl.af.tr_644  uk.be.mk_332 fr.pt.un_420
  0x0a080714, 0x20070ca4, 0x1a016e07, 0x19060a12,   // bg.uk.mk_666 sv.it.sq_433  blu.en.tl_432 pt.de.gl_654
  // [2c70]
  0x090d2d11, 0x04130805, 0x0400170d, 0x64033f0c,   // sk.cs.pl_653 no.et.fi_333  sr.ru.un_540 af.nl.lg_543
  0x033f25ad, 0x1b0f20ad, 0x04060c5a, 0x131617a0,   // eu.af.nl_643 sq.lv.tr_643  sv.de.fi_553 sr.hr.et_322
  0x19001808, 0x1b020c02, 0x0c000e12, 0x11000702,   // ga.gl.un_430 sv.da.tr_222  is.sv.un_640 it.ro.un_220
  0x31001b18, 0x6b230111, 0x0e132107, 0x2d0d0aec,   // tr.az.un_740 en.ca.ceb_653  jw.et.is_432 pt.cs.sk_644
  // [2c80]
  0x25213fec, 0x0e00130c, 0x23002804, 0x08170a0e,   // af.jw.eu_644 et.is.un_530  sw.ca.un_320 mk.sr.uk_555
  0x07000821, 0x05002a1a, 0x0a080704, 0x0e1f070c,   // uk.bg.un_860 mt.fr.un_760  bg.uk.mk_332 it.cy.is_543
  0x551a6bec, 0x0e001219, 0x060e04a9, 0x0e2d0d0d,   // ceb.tl.rw_644 hu.is.un_750  fi.is.de_544 cs.sk.is_554
  0x3f080e0c, 0x0f00290c, 0x31641c02, 0x27531c07,   // is.no.af_543 sl.lv.un_530  id.lg.az_222 id.ht.gd_432
  // [2c90]
  0x230b19a0, 0x162a0f04, 0x181007ee, 0x04070aa0,   // gl.es.ca_322 lv.mt.hr_332  it.lt.ga_422 mk.bg.ru_322
  0x231810a0, 0x6b0e640c, 0x0b001013, 0x0e0d0f02,   // lt.ga.ca_322 lg.is.ceb_543  lt.es.un_650 lv.cs.is_222
  0x170f2910, 0x070501a4, 0x0c0208ee, 0x08070209,   // sl.lv.sr_642 en.fr.it_433  no.da.sv_422 da.it.no_444
  0x17160f04, 0x1c000407, 0x0c070e14, 0x1f002a07,   // lv.hr.sr_332 fi.id.un_420  is.it.sv_666 mt.cy.un_420
  // [2ca0]
  0x3f0e0204, 0x0d0f16a0, 0x282d2a08, 0x2b056407,   // da.is.af_332 hr.lv.cs_322  mt.sk.sw_443 lg.fr.vi_432
  0x02001216, 0x11091602, 0x19120ba4, 0x18276bee,   // hu.da.un_720 hr.pl.ro_222  es.hu.gl_433 ceb.gd.ga_422
  0x2a2864a6, 0x281b3112, 0x180e27a9, 0x201e1c0c,   // lg.sw.mt_521 az.tr.sw_654  gd.is.ga_544 id.ms.sq_543
  0x641304a4, 0x0b0a19a4, 0x173f1607, 0x20111b12,   // fi.et.lg_433 gl.pt.es_433  hr.af.sr_432 tr.ro.sq_654
  // [2cb0]
  0x1c130912, 0x64001e13, 0x250e0804, 0x23002a07,   // hi.bh.mr_654 ms.lg.un_650  no.is.eu_332 mt.ca.un_420
  0x080712a4, 0x28033f60, 0x530f1f09, 0x64000804,   // hu.it.no_433 af.nl.sw_664  cy.lv.ht_444 no.lg.un_320
  0x1f0b2355, 0x136431af, 0x1e001c2a, 0x10000613,   // ca.es.cy_442 az.lg.et_655  id.ms.un_970 de.lt.un_650
  0x6b001f12, 0x0b531ca4, 0x0b002a07, 0x1000071a,   // cy.ceb.un_640 id.ht.es_433  mt.es.un_420 it.lt.un_760
  // [2cc0]
  0x2d005507, 0x3f210613, 0x64002507, 0x010208a7,   // rw.sk.un_420 de.jw.af_665  eu.lg.un_420 no.da.en_532
  0x1c6455a0, 0x27180e0c, 0x18000c1a, 0x08100409,   // rw.lg.id_322 is.ga.gd_543  sv.ga.un_760 ru.be.uk_444
  0x1a2a1ea0, 0x0a00231b, 0x1b0408ee, 0x0f000b08,   // ms.mt.tl_322 ca.pt.un_770  no.fi.tr_422 es.lv.un_430
  0x100a07a0, 0x06020c04, 0x08000e19, 0x17110755,   // bg.mk.be_322 sv.da.de_332  is.no.un_750 bg.ro.sr_442
  // [2cd0]
  0x1f0921a0, 0x120d28ee, 0x12000e13, 0x23000308,   // jw.pl.cy_322 sw.cs.hu_422  is.hu.un_650 nl.ca.un_430
  0x19230a60, 0x0c000820, 0x23000a07, 0x1f002702,   // pt.ca.gl_664 no.sv.un_850  pt.ca.un_420 gd.cy.un_220
  0x23033f0d, 0x27000a04, 0x1b001819, 0x03000d04,   // af.nl.ca_554 pt.gd.un_320  ga.tr.un_750 cs.nl.un_320
  0x03000204, 0x0a04080c, 0x060b0702, 0x0e000413,   // da.nl.un_320 uk.ru.mk_543  it.es.de_222 fi.is.un_650
  // [2ce0]
  0x080c0202, 0x020c0855, 0x040a08a4, 0x1a013fa4,   // da.sv.no_222 no.sv.da_442  uk.mk.ru_433 af.en.tl_433
  0x23190a14, 0x29002d1a, 0x64161204, 0x1716280c,   // pt.gl.ca_666 sk.sl.un_760  hu.hr.lg_332 sw.hr.sr_543
  0x64291602, 0x01050c04, 0x0e001b04, 0x1b003118,   // hr.sl.lg_222 sv.fr.en_332  tr.is.un_320 az.tr.un_740
  0x202855a0, 0x06000f12, 0x28006405, 0x3f552a04,   // rw.sw.sq_322 lv.de.un_640  lg.sw.un_330 mt.rw.af_332
  // [2cf0]
  0x0f060204, 0x28550711, 0x081304af, 0x1c216411,   // da.de.lv_332 it.rw.sw_653  fi.et.no_655 lg.jw.id_653
  0x1b1e1c13, 0x022a6b07, 0x29000f04, 0x0c080ea4,   // id.ms.tr_665 ceb.mt.da_432  lv.sl.un_320 is.no.sv_433
  0x556b64a0, 0x0e3f080d, 0x64000304, 0x29000c04,   // lg.ceb.rw_322 no.af.is_554  nl.lg.un_320 sv.sl.un_320
  0x01000605, 0x2a1a6b07, 0x31003f0e, 0x133f11ad,   // de.en.un_330 ceb.tl.mt_432  af.az.un_550 ro.af.et_643
  // [2d00]
  0x12001604, 0x1c556b04, 0x0900211a, 0x0b001208,   // hr.hu.un_320 ceb.rw.id_332  jw.pl.un_760 hu.es.un_430
  0x641c2da4, 0x2a000e1b, 0x5500641b, 0x182d0d67,   // sk.id.lg_433 is.mt.un_770  lg.rw.un_770 cs.sk.ga_775
  0x11002807, 0x0e002d07, 0x2d0d6e05, 0x12101aa4,   // sw.ro.un_420 sk.is.un_420  blu.cs.sk_333 tl.lt.hu_433
  0x07110405, 0x28000302, 0x0f2d64a9, 0x2b002105,   // ru.ro.bg_333 nl.sw.un_220  lg.sk.lv_544 jw.vi.un_330
  // [2d10]
  0x0c160805, 0x0e0208ec, 0x21022d04, 0x0a07170e,   // no.hr.sv_333 no.da.is_644  sk.da.jw_332 sr.bg.mk_555
  0x1e1c27a0, 0x1b2312ee, 0x091112a9, 0x162917a4,   // gd.id.ms_322 hu.ca.tr_422  hu.ro.pl_544 sr.sl.hr_433
  0x06230a02, 0x2105310c, 0x01006407, 0x64001012,   // pt.ca.de_222 az.fr.jw_543  lg.en.un_420 lt.lg.un_640
  0x12002914, 0x25001f0c, 0x0a000707, 0x6e056b04,   // sl.hu.un_660 cy.eu.un_530  bg.mk.un_420 ceb.fr.blu_332
  // [2d20]
  0x06001208, 0x0f2d2911, 0x292d1708, 0x1a2001ee,   // hu.de.un_430 sl.sk.lv_653  sr.sk.sl_443 en.sq.tl_422
  0x27002a13, 0x1b002704, 0x2b0801ee, 0x31006e14,   // mt.gd.un_650 gd.tr.un_320  en.no.vi_422 blu.az.un_660
  0x25072a07, 0x01000807, 0x3f006e13, 0x04080a04,   // mt.it.eu_432 no.en.un_420  blu.af.un_650 mk.uk.ru_332
  0x0c000e04, 0x05316ea0, 0x03023f08, 0x0d091204,   // is.sv.un_320 blu.az.fr_322  af.da.nl_443 hu.pl.cs_332
  // [2d30]
  0x2a020a07, 0x08020cec, 0x1c1e31a7, 0x230912a0,   // pt.da.mt_432 sv.da.no_644  az.ms.id_532 hu.pl.ca_322
  0x11056ea0, 0x11170aa4, 0x190b23ee, 0x17161205,   // blu.fr.ro_322 mk.sr.ro_433  ca.es.gl_422 hu.hr.sr_333
  0x04171105, 0x180e3107, 0x25200e07, 0x0b000404,   // ro.sr.ru_333 az.is.ga_432  is.sq.eu_432 fi.es.un_320
  0x08002105, 0x132d0d04, 0x0c000411, 0x03061207,   // jw.no.un_330 cs.sk.et_332  fi.sv.un_630 hu.de.nl_432
  // [2d40]
  0x6b641aa4, 0x12171655, 0x0c2d0d0c, 0x041b0cac,   // tl.lg.ceb_433 hr.sr.hu_442  cs.sk.sv_543 sv.tr.fi_632
  0x3f190b08, 0x10071107, 0x1a3128a7, 0x120613a0,   // es.gl.af_443 ro.bg.be_432  sw.az.tl_532 et.de.hu_322
  0x6e005321, 0x0c001b19, 0x0a1707ec, 0x100708a0,   // ht.blu.un_860 tr.sv.un_750  bg.sr.mk_644 uk.bg.be_322
  0x080229a0, 0x0a171107, 0x191a64a4, 0x08040cac,   // sl.da.no_322 ro.sr.mk_432  lg.tl.gl_433 sv.fi.no_632
  // [2d50]
  0x11190b5a, 0x0c000f13, 0x0806025a, 0x0d1209af,   // es.gl.ro_553 lv.sv.un_650  da.de.no_553 pl.hu.cs_655
  0x31290804, 0x096425a0, 0x190b53a0, 0x6b041a0c,   // no.sl.az_332 eu.lg.pl_322  ht.es.gl_322 tl.fi.ceb_543
  0x16002102, 0x071711a7, 0x08071702, 0x2d0d29a4,   // jw.hr.un_220 ro.sr.bg_532  sr.bg.uk_222 sl.cs.sk_433
  0x2d0f0d08, 0x646b1a55, 0x206b1a07, 0x1a002805,   // cs.lv.sk_443 tl.ceb.lg_442  tl.ceb.sq_432 sw.tl.un_330
  // [2d60]
  0x1b120c55, 0x1b00120d, 0x20110708, 0x110710a4,   // sv.hu.tr_442 hu.tr.un_540  it.ro.sq_443 lt.it.ro_433
  0x08040aad, 0x01280605, 0x255512a4, 0x07200805,   // mk.ru.uk_643 de.sw.en_333  hu.rw.eu_433 no.sq.it_333
  0x20071fa0, 0x64002807, 0x1b0e3105, 0x0b2105a7,   // cy.it.sq_322 sw.lg.un_420  az.is.tr_333 fr.jw.es_532
  0x291a0ea0, 0x20531755, 0x2d120aac, 0x1c00530d,   // is.tl.sl_322 sr.ht.sq_442  pt.hu.sk_632 ht.id.un_540
  // [2d70]
  0x12092da0, 0x050b01a0, 0x1629175a, 0x02002304,   // sk.pl.hu_322 en.es.fr_322  sr.sl.hr_553 ca.da.un_320
  0x110a0107, 0x1300100e, 0x2311070d, 0x02005307,   // en.pt.ro_432 lt.et.un_550  it.ro.ca_554 ht.da.un_420
  0x200755a4, 0x09006421, 0x04170a04, 0x072011a4,   // rw.it.sq_433 lg.pl.un_860  mk.sr.ru_332 ro.sq.it_433
  0x2100182a, 0x1b002507, 0x17000f02, 0x53000916,   // ar.fa.un_970 eu.tr.un_420  lv.sr.un_220 pl.ht.un_720
  // [2d80]
  0x200c0f0c, 0x0d001219, 0x211218a0, 0x28641aee,   // lv.sv.sq_543 hu.cs.un_750  ar.ur.fa_322 tl.lg.sw_422
  0x0a170814, 0x21001a09, 0x31101b12, 0x2d0d12ec,   // uk.sr.mk_666 tl.jw.un_440  tr.lt.az_654 hu.cs.sk_644
  0x2d090daf, 0x08002905, 0x1700070b, 0x091a6bec,   // cs.pl.sk_655 sl.no.un_330  bg.sr.un_520 ceb.tl.pl_644
  0x1b310655, 0x0b002309, 0x12230b55, 0x0d002a04,   // de.az.tr_442 ca.es.un_440  es.ca.hu_442 mt.cs.un_320
  // [2d90]
  0x2d120d14, 0x030508a0, 0x0b121814, 0x0800110c,   // cs.hu.sk_666 no.fr.nl_322  ga.hu.es_666 ro.uk.un_530
  0x0b1223af, 0x2d0d12a9, 0x08001308, 0x530d0407,   // ca.hu.es_655 hu.cs.sk_544  et.no.un_430 fi.cs.ht_432
  0x00002337, 0x6b0e1aad, 0x2500551b, 0x18271f12,   // ca.un.un_B00 tl.is.ceb_643  rw.eu.un_770 cy.gd.ga_654
  0x08040a04, 0x6400200d, 0x0d000413, 0x11002a02,   // mk.ru.uk_332 sq.lg.un_540  fi.cs.un_650 mt.ro.un_220
  // [2da0]
  0x55101ca0, 0x271a09ee, 0x0c082308, 0x16110707,   // id.lt.rw_322 pl.tl.gd_422  ca.no.sv_443 it.ro.hr_432
  0x1e1811a0, 0x1f000d04, 0x0e17165a, 0x3f0d530c,   // ro.ga.ms_322 cs.cy.un_320  hr.sr.is_553 ht.cs.af_543
  0x11230a0e, 0x27180107, 0x0b3f0308, 0x181a6b07,   // pt.ca.ro_555 en.ga.gd_432  nl.af.es_443 ceb.tl.ga_432
  0x1a3f2960, 0x0c000d08, 0x1b162dec, 0x200f1004,   // sl.af.tl_664 cs.sv.un_430  sk.hr.tr_644 lt.lv.sq_332
  // [2db0]
  0x55002702, 0x28091a08, 0x20001f19, 0x3f11210c,   // gd.rw.un_220 tl.pl.sw_443  cy.sq.un_750 jw.ro.af_543
  0x1b171604, 0x111055a4, 0x6b1a210c, 0x551120a4,   // hr.sr.tr_332 rw.lt.ro_433  jw.tl.ceb_543 sq.ro.rw_433
  0x03001108, 0x2a033f09, 0x040d10a0, 0x17040707,   // ro.nl.un_430 af.nl.mt_444  lt.cs.fi_322 bg.ru.sr_432
  0x64135508, 0x08210907, 0x0810040c, 0x1a00211b,   // rw.et.lg_443 pl.jw.no_432  ru.be.uk_543 jw.tl.un_770
  // [2dc0]
  0x10002911, 0x08170a0c, 0x061304ee, 0x0804100e,   // sl.lt.un_630 mk.sr.uk_543  fi.et.de_422 be.ru.uk_555
  0x07002309, 0x07100409, 0x29002d09, 0x0a1f19af,   // ca.it.un_440 ru.be.bg_444  sk.sl.un_440 gl.cy.pt_655
  0x0c292d0c, 0x0700230b, 0x29170da9, 0x121b64a9,   // sk.sl.sv_543 ca.it.un_520  cs.sr.sl_544 lg.tr.hu_544
  0x64002d02, 0x0b1819a0, 0x286b1a12, 0x0700230c,   // sk.lg.un_220 gl.ga.es_322  tl.ceb.sw_654 ca.it.un_530
  // [2dd0]
  0x1b006b05, 0x17162102, 0x16291713, 0x190b0a05,   // ceb.tr.un_330 jw.hr.sr_222  sr.sl.hr_665 pt.es.gl_333
  0x1a002807, 0x29002a0d, 0x1a3f030c, 0x0e190bee,   // sw.tl.un_420 mt.sl.un_540  nl.af.tl_543 es.gl.is_422
  0x0755280b, 0x0f291708, 0x121f2aa7, 0x28003f07,   // sw.rw.it_542 sr.sl.lv_443  mt.cy.hu_532 af.sw.un_420
  0x05002308, 0x0b07230d, 0x170804a7, 0x03643f0d,   // ca.fr.un_430 ca.it.es_554  ru.uk.sr_532 af.lg.nl_554
  // [2de0]
  0x122a21a0, 0x0a190b08, 0x0a006405, 0x05003f05,   // jw.mt.hu_322 es.gl.pt_443  lg.pt.un_330 af.fr.un_330
  0x6b1c2104, 0x11002b0e, 0x05003f07, 0x1b001c08,   // jw.id.ceb_332 vi.ro.un_550  af.fr.un_420 id.tr.un_430
  0x1f000a04, 0x091f18a4, 0x190a0b05, 0x190b0a55,   // pt.cy.un_320 ga.cy.pl_433  es.pt.gl_333 pt.es.gl_442
  0x0f0804a7, 0x11001908, 0x023f0308, 0x055308a0,   // fi.no.lv_532 gl.ro.un_430  nl.af.da_443 no.ht.fr_322
  // [2df0]
  0x0a002302, 0x311b1fa4, 0x2d002308, 0x0a211ea4,   // ca.pt.un_220 cy.tr.az_433  ca.sk.un_430 ms.jw.pt_433
  0x2d171607, 0x07001e02, 0x0d001313, 0x18001302,   // hr.sr.sk_432 ms.it.un_220  bh.ne.un_650 et.ga.un_220
  0x31001b29, 0x200a2355, 0x17040aa0, 0x20001c04,   // tr.az.un_960 ca.pt.sq_442  mk.ru.sr_322 id.sq.un_320
  0x1b1309a4, 0x2d002105, 0x082902ec, 0x64040ca0,   // pl.et.tr_433 jw.sk.un_330  da.sl.no_644 sv.fi.lg_322
  // [2e00]
  0x23000a14, 0x08255507, 0x040711ad, 0x2a1c0e04,   // pt.ca.un_660 rw.eu.no_432  ro.bg.ru_643 is.id.mt_332
  0x13000807, 0x03170502, 0x0e000621, 0x131b64ee,   // no.et.un_420 fr.sr.nl_222  de.is.un_860 lg.tr.et_422
  0x050c0204, 0x020d04a0, 0x530c0e12, 0x12002814,   // da.sv.fr_332 fi.cs.da_322  is.sv.ht_654 sw.hu.un_660
  0x3f000202, 0x2b030eee, 0x55282aa0, 0x05070107,   // da.af.un_220 is.nl.vi_422  mt.sw.rw_322 en.it.fr_432
  // [2e10]
  0x2a3f13a7, 0x12000d08, 0x3f0301af, 0x09000b04,   // et.af.mt_532 cs.hu.un_430  en.nl.af_655 es.pl.un_320
  0x100407a0, 0x1a0e25a9, 0x29000e07, 0x0a0623af,   // bg.ru.be_322 eu.is.tl_544  is.sl.un_420 ca.de.pt_655
  0x02201611, 0x0c0802ec, 0x23000b05, 0x0810040d,   // hr.sq.da_653 da.no.sv_644  es.ca.un_330 ru.be.uk_554
  0x6b1a0f13, 0x06032507, 0x55002005, 0x6400110e,   // lv.tl.ceb_665 eu.nl.de_432  sq.rw.un_330 ro.lg.un_550
  // [2e20]
  0x1700041a, 0x07081760, 0x12001807, 0x27070502,   // ru.sr.un_760 sr.uk.bg_664  ar.ur.un_420 fr.it.gd_222
  0x080c0e11, 0x31020807, 0x091601ee, 0x20550707,   // is.sv.no_653 no.da.az_432  en.hr.pl_422 it.rw.sq_432
  0x0c000309, 0x64001a18, 0x531b1f07, 0x210c1c0c,   // nl.sv.un_440 tl.lg.un_740  cy.tr.ht_432 id.sv.jw_543
  0x55001a02, 0x07041702, 0x25000c09, 0x12000912,   // tl.rw.un_220 sr.ru.bg_222  sv.eu.un_440 pl.hu.un_640
  // [2e30]
  0x6e290fa4, 0x07002a1b, 0x23000713, 0x1c130d04,   // lv.sl.blu_433 mt.it.un_770  it.ca.un_650 ne.bh.mr_332
  0x07110aa4, 0x020603a4, 0x1200181a, 0x0d001704,   // mk.ro.bg_433 nl.de.da_433  ga.hu.un_760 sr.cs.un_320
  0x05000a07, 0x3f0f100c, 0x032d1fee, 0x016b2aee,   // pt.fr.un_420 lt.lv.af_543  cy.sk.nl_422 mt.ceb.en_422
  0x122111ad, 0x10000e0b, 0x0a001112, 0x1f002d1a,   // ro.jw.hu_643 is.lt.un_520  ro.mk.un_640 sk.cy.un_760
  // [2e40]
  0x0c0e0807, 0x536b1aec, 0x29000607, 0x216b23ee,   // no.is.sv_432 tl.ceb.ht_644  de.sl.un_420 ca.ceb.jw_422
  0x08000c22, 0x311b1c07, 0x10061707, 0x17110704,   // sv.no.un_870 id.tr.az_432  sr.de.lt_432 bg.ro.sr_332
  0x12090f07, 0x0a1f2da4, 0x6b01110c, 0x07002a1a,   // lv.pl.hu_432 sk.cy.pt_433  ro.en.ceb_543 mt.it.un_760
  0x2a230709, 0x312855ee, 0x09250307, 0x091c1360,   // it.ca.mt_444 rw.sw.az_422  nl.eu.pl_432 bh.mr.hi_664
  // [2e50]
  0x04170a07, 0x0d2d1207, 0x21002305, 0x1f1b53af,   // mk.sr.ru_432 hu.sk.cs_432  ca.jw.un_330 ht.tr.cy_655
  0x103f0fa4, 0x23002d13, 0x1b000e1a, 0x2a1f53ee,   // lv.af.lt_433 sk.ca.un_650  is.tr.un_760 ht.cy.mt_422
  0x2d1a230c, 0x1200111a, 0x3f00101b, 0x64171604,   // ca.tl.sk_543 ro.hu.un_760  lt.af.un_770 hr.sr.lg_332
  0x12190d0c, 0x061b0e0c, 0x062118a0, 0x0c00160c,   // cs.gl.hu_543 is.tr.de_543  ga.jw.de_322 hr.sv.un_530
  // [2e60]
  0x01003107, 0x6423280c, 0x2100200d, 0x18002122,   // az.en.un_420 sw.ca.lg_543  sq.jw.un_540 fa.ar.un_870
  0x0d001c04, 0x19000104, 0x530213a4, 0x120a05ee,   // id.cs.un_320 en.gl.un_320  et.da.ht_433 fr.pt.hu_422
  0x250418ac, 0x23530b55, 0x23000d08, 0x1b0a0207,   // ga.fi.eu_632 es.ht.ca_442  cs.ca.un_430 da.pt.tr_432
  0x18041155, 0x25002b04, 0x3f0803af, 0x172d0d08,   // ro.fi.ga_442 vi.eu.un_320  nl.no.af_655 cs.sk.sr_443
  // [2e70]
  0x090a2308, 0x0a292302, 0x253f0307, 0x28001104,   // ca.pt.pl_443 ca.sl.pt_222  nl.af.eu_432 ro.sw.un_320
  0x05010702, 0x1827110c, 0x07000a23, 0x062901a4,   // it.en.fr_222 ro.gd.ga_543  mk.bg.un_880 en.sl.de_433
  0x16201707, 0x2d120d0e, 0x190d2dee, 0x071101a4,   // sr.sq.hr_432 cs.hu.sk_555  sk.cs.gl_422 en.ro.it_433
  0x0a041755, 0x19000b13, 0x01200507, 0x0d001213,   // sr.ru.mk_442 es.gl.un_650  fr.sq.en_432 hu.cs.un_650
  // [2e80]
  0x06110d07, 0x212b010c, 0x032d0d02, 0x25182713,   // cs.ro.de_432 en.vi.jw_543  cs.sk.nl_222 gd.ga.eu_665
  0x1b200a0d, 0x0510270c, 0x232119ee, 0x0a04170c,   // pt.sq.tr_554 gd.lt.fr_543  gl.jw.ca_422 sr.ru.mk_543
  0x23111ba0, 0x6b001f09, 0x05270107, 0x211a28a0,   // tr.ro.ca_322 cy.ceb.un_440  en.gd.fr_432 sw.tl.jw_322
  0x1c00090b, 0x0d1c1eee, 0x011a280c, 0x21033f55,   // hi.mr.un_520 ms.id.cs_422  sw.tl.en_543 af.nl.jw_442
  // [2e90]
  0x080a1005, 0x031b1909, 0x2d0d08ee, 0x0d202d12,   // be.mk.uk_333 gl.tr.nl_444  no.cs.sk_422 sk.sq.cs_654
  0x160817a0, 0x1f2d3f04, 0x1f002113, 0x1e00530d,   // sr.no.hr_322 af.sk.cy_332  jw.cy.un_650 ht.ms.un_540
  0x6400121a, 0x09130d12, 0x211c2d07, 0x020c21a7,   // hu.lg.un_760 ne.bh.hi_654  sk.id.jw_432 jw.sv.da_532
  0x13002505, 0x042d0d12, 0x0d2d28a0, 0x16125507,   // eu.et.un_330 cs.sk.fi_654  sw.sk.cs_322 rw.hu.hr_432
  // [2ea0]
  0x00000e2d, 0x1b100707, 0x01002a04, 0x55001b22,   // is.un.un_A00 it.lt.tr_432  mt.en.un_320 tr.rw.un_870
  0x210d09a4, 0x21001a19, 0x1f001813, 0x060c0807,   // pl.cs.jw_433 tl.jw.un_750  ga.cy.un_650 no.sv.de_432
  0x641325ad, 0x21002b0d, 0x0c080e13, 0x06036bee,   // eu.et.lg_643 vi.jw.un_540  is.no.sv_665 ceb.nl.de_422
  0x120d2d0b, 0x08001712, 0x0e190b08, 0x17291613,   // sk.cs.hu_542 sr.uk.un_640  es.gl.is_443 hr.sl.sr_665
  // [2eb0]
  0x1c001318, 0x1c21100c, 0x126b1fa9, 0x0400081b,   // bh.mr.un_740 lt.jw.id_543  cy.ceb.hu_544 uk.ru.un_770
  0x55002814, 0x6b1f1a13, 0x311b28af, 0x291f0d07,   // sw.rw.un_660 tl.cy.ceb_665  sw.tr.az_655 cs.cy.sl_432
  0x6400281b, 0x6b1a1e12, 0x55311b11, 0x0f2a1209,   // sw.lg.un_770 ms.tl.ceb_654  tr.az.rw_653 hu.mt.lv_444
  0x11552812, 0x2800070e, 0x3f081fac, 0x0a0b2da0,   // sw.rw.ro_654 it.sw.un_550  cy.no.af_632 sk.es.pt_322
  // [2ec0]
  0x0a000b08, 0x0b2d1912, 0x130511a0, 0x072105a7,   // es.pt.un_430 gl.sk.es_654  ro.fr.et_322 fr.jw.it_532
  0x3f000402, 0x31125304, 0x11000a0c, 0x04110804,   // fi.af.un_220 ht.hu.az_332  pt.ro.un_530 uk.ro.ru_332
  0x1108045a, 0x131f6b0d, 0x6453280c, 0x31110dee,   // ru.uk.ro_553 ceb.cy.et_554  sw.ht.lg_543 cs.ro.az_422
  0x1f6b1e07, 0x17166b14, 0x0725550c, 0x170a1112,   // ms.ceb.cy_432 ceb.hr.sr_666  rw.eu.it_543 ro.mk.sr_654
  // [2ed0]
  0x28556407, 0x551a0d05, 0x04091aa4, 0x161e1c04,   // lg.rw.sw_432 cs.tl.rw_333  tl.pl.fi_433 id.ms.hr_332
  0x290d17a0, 0x20282da4, 0x12000b13, 0x16111205,   // sr.cs.sl_322 sk.sw.sq_433  es.hu.un_650 hu.ro.hr_333
  0x1328040d, 0x6b1a0b05, 0x3f556407, 0x1b000704,   // fi.sw.et_554 es.tl.ceb_333  lg.rw.af_432 it.tr.un_320
  0x12000b07, 0x28001e08, 0x121a6b05, 0x121a0cad,   // es.hu.un_420 ms.sw.un_430  ceb.tl.hu_333 sv.tl.hu_643
  // [2ee0]
  0x0900530e, 0x13100413, 0x17070a0e, 0x081007a0,   // ht.pl.un_550 fi.lt.et_665  mk.bg.sr_555 bg.be.uk_322
  0x2d171611, 0x55216404, 0x120c1aa7, 0x170a16af,   // hr.sr.sk_653 lg.jw.rw_332  tl.sv.hu_532 hr.pt.sr_655
  0x64001b0b, 0x06201107, 0x180e1211, 0x17161214,   // tr.lg.un_520 ro.sq.de_432  hu.is.ga_653 hu.hr.sr_666
  0x1700030d, 0x190b1208, 0x02063fa4, 0x122d0d13,   // nl.sr.un_540 hu.es.gl_443  af.de.da_433 cs.sk.hu_665
  // [2ef0]
  0x0700640c, 0x1b000405, 0x12002908, 0x552864a4,   // lg.it.un_530 fi.tr.un_330  sl.hu.un_430 lg.sw.rw_433
  0x05190a02, 0x08000a04, 0x0d122da9, 0x092d120c,   // pt.gl.fr_222 mk.uk.un_320  sk.hu.cs_544 hu.sk.pl_543
  0x55000c07, 0x041a6ba4, 0x04001322, 0x12130caf,   // sv.rw.un_420 ceb.tl.fi_433  et.fi.un_870 sv.et.hu_655
  0x21200fa0, 0x53006407, 0x120413a4, 0x04131055,   // lv.sq.jw_322 lg.ht.un_420  et.fi.hu_433 lt.et.fi_442
  // [2f00]
  0x190c0b07, 0x130c085a, 0x060c3f07, 0x110108a0,   // es.sv.gl_432 no.sv.et_553  af.sv.de_432 no.en.ro_322
  0x29160d04, 0x13041e12, 0x0c000412, 0x2d001904,   // cs.hr.sl_332 ms.fi.et_654  fi.sv.un_640 gl.sk.un_320
  0x0708020d, 0x18000e09, 0x0800230e, 0x202d1709,   // da.no.it_554 is.ga.un_440  ca.no.un_550 sr.sk.sq_444
  0x230e1905, 0x0c000112, 0x06160f0e, 0x1a216e0c,   // gl.is.ca_333 en.sv.un_640  lv.hr.de_555 blu.jw.tl_543
  // [2f10]
  0x55002812, 0x08111012, 0x3f1103a4, 0x04002b04,   // sw.rw.un_640 be.ro.uk_654  nl.ro.af_433 vi.fi.un_320
  0x1b0853a4, 0x05002316, 0x53001604, 0x20171605,   // ht.no.tr_433 ca.fr.un_720  hr.ht.un_320 hr.sr.sq_333
  0x21001e13, 0x0a170805, 0x081b20ee, 0x1629170b,   // ms.jw.un_650 uk.sr.mk_333  sq.tr.no_422 sr.sl.hr_542
  0x17063f04, 0x16001105, 0x170b1b02, 0x0a000512,   // af.de.sr_332 ro.hr.un_330  tr.es.sr_222 fr.pt.un_640
  // [2f20]
  0x120e18a4, 0x0e001204, 0x12212004, 0x082917a7,   // ga.is.hu_433 hu.is.un_320  sq.jw.hu_332 sr.sl.no_532
  0x3f165307, 0x6b1a28ad, 0x0a17070c, 0x13040cac,   // ht.hr.af_432 sw.tl.ceb_643  bg.sr.mk_543 sv.fi.et_632
  0x31641aee, 0x0c080904, 0x17111604, 0x0f002913,   // tl.lg.az_422 pl.no.sv_332  hr.ro.sr_332 sl.lv.un_650
  0x04001714, 0x23060c04, 0x55212807, 0x55281309,   // sr.ru.un_660 sv.de.ca_332  sw.jw.rw_432 et.sw.rw_444
  // [2f30]
  0x2700130d, 0x11002707, 0x2031280b, 0x28041a04,   // et.gd.un_540 gd.ro.un_420  sw.az.sq_542 tl.fi.sw_332
  0x2a010502, 0x25215505, 0x3f080255, 0x1f0c06a9,   // fr.en.mt_222 rw.jw.eu_333  da.no.af_442 de.sv.cy_544
  0x28556412, 0x1f000c0e, 0x3f000b02, 0x11001707,   // lg.rw.sw_654 sv.cy.un_550  es.af.un_220 sr.ro.un_420
  0x06182713, 0x3f001002, 0x03133fa0, 0x2d090da0,   // gd.ga.de_665 lt.af.un_220  af.et.nl_322 cs.pl.sk_322
  // [2f40]
  0x100a1708, 0x1c090d5a, 0x25001c04, 0x31002822,   // sr.mk.be_443 ne.hi.mr_553  id.eu.un_320 sw.az.un_870
  0x08000402, 0x04000b12, 0x2a200ead, 0x55311b07,   // ru.uk.un_220 es.fi.un_640  is.sq.mt_643 tr.az.rw_432
  0x03001312, 0x17165513, 0x1a1e1c5a, 0x1c000302,   // et.nl.un_640 rw.hr.sr_665  id.ms.tl_553 nl.id.un_220
  0x040a07a9, 0x2a64280c, 0x3128640c, 0x01060c07,   // bg.mk.ru_544 sw.lg.mt_543  lg.sw.az_543 sv.de.en_432
  // [2f50]
  0x0a0923a0, 0x281e64af, 0x093f130d, 0x0c080e12,   // ca.pl.pt_322 lg.ms.sw_655  et.af.pl_554 is.no.sv_654
  0x170811ee, 0x19005304, 0x0e030fa0, 0x0e1310a6,   // ro.uk.sr_422 ht.gl.un_320  lv.nl.is_322 lt.et.is_521
  0x1a1e5507, 0x55002819, 0x0a1812ac, 0x1c052107,   // rw.ms.tl_432 sw.rw.un_750  hu.ga.pt_632 jw.fr.id_432
  0x216b1a0d, 0x0f2a250c, 0x132910a0, 0x19001802,   // tl.ceb.jw_554 eu.mt.lv_543  lt.sl.et_322 ga.gl.un_220
  // [2f60]
  0x646b1a08, 0x2d1729a4, 0x042d0d09, 0x250208ad,   // tl.ceb.lg_443 sl.sr.sk_433  cs.sk.fi_444 no.da.eu_643
  0x192d0d04, 0x070a1155, 0x2b005504, 0x1b122004,   // cs.sk.gl_332 ro.mk.bg_442  rw.vi.un_320 sq.hu.tr_332
  0x55092da4, 0x09131bee, 0x2a230a07, 0x07000807,   // sk.pl.rw_433 tr.et.pl_422  pt.ca.mt_432 uk.bg.un_420
  0x10001714, 0x0f2a28ad, 0x20171608, 0x165528a7,   // sr.be.un_660 sw.mt.lv_643  hr.sr.sq_443 sw.rw.hr_532
  // [2f70]
  0x0d171602, 0x6b101aa4, 0x07110a07, 0x20001f0c,   // hr.sr.cs_222 tl.lt.ceb_433  mk.ro.bg_432 cy.sq.un_530
  0x182705a4, 0x1000280d, 0x55286411, 0x040a17a7,   // fr.gd.ga_433 sw.lt.un_540  lg.sw.rw_653 sr.mk.ru_532
  0x090d13a9, 0x1b000c0e, 0x18122104, 0x0a001734,   // bh.ne.hi_544 sv.tr.un_550  fa.ur.ar_332 sr.mk.un_A80
  0x041707ee, 0x132004ee, 0x285564a9, 0x13551aaf,   // bg.sr.ru_422 fi.sq.et_422  lg.rw.sw_544 tl.rw.et_655
  // [2f80]
  0x1b00310c, 0x1f0e04a4, 0x07110a08, 0x1a28640c,   // az.tr.un_530 fi.is.cy_433  mk.ro.bg_443 lg.sw.tl_543
  0x210306a4, 0x55280404, 0x110a07a9, 0x08021e02,   // de.nl.jw_433 fi.sw.rw_332  bg.mk.ro_544 ms.da.no_222
  0x07002313, 0x282055a4, 0x55200b04, 0x23002005,   // ca.it.un_650 rw.sq.sw_433  es.sq.rw_332 sq.ca.un_330
  0x043f08ad, 0x0c0e02ee, 0x25100708, 0x3f0c02a0,   // no.af.fi_643 da.is.sv_422  it.lt.eu_443 da.sv.af_322
  // [2f90]
  0x1b00130c, 0x1e1c1aaf, 0x02060cee, 0x060302ad,   // et.tr.un_530 tl.id.ms_655  sv.de.da_422 da.nl.de_643
  0x0d00180b, 0x180b28a4, 0x160c1b55, 0x01000f02,   // ga.cs.un_520 sw.es.ga_433  tr.sv.hr_442 lv.en.un_220
  0x0d001212, 0x0c100ea0, 0x110b5305, 0x181327ec,   // hu.cs.un_640 is.lt.sv_322  ht.es.ro_333 gd.et.ga_644
  0x64000308, 0x53311bee, 0x2a6408a0, 0x23000714,   // nl.lg.un_430 tr.az.ht_422  no.lg.mt_322 it.ca.un_660
  // [2fa0]
  0x13002b04, 0x1f000804, 0x1e1c18ee, 0x172816a4,   // vi.et.un_320 no.cy.un_320  ga.id.ms_422 hr.sw.sr_433
  0x13063f04, 0x070410af, 0x20080202, 0x02005508,   // af.de.et_332 be.ru.bg_655  da.no.sq_222 rw.da.un_430
  0x1b000c09, 0x1c001314, 0x531b1a07, 0x022a0eee,   // sv.tr.un_440 bh.mr.un_660  tl.tr.ht_432 is.mt.da_422
  0x0c080ea7, 0x12001802, 0x17311611, 0x17001013,   // is.no.sv_532 ga.hu.un_220  hr.az.sr_653 be.sr.un_650
  // [2fb0]
  0x19003107, 0x19001604, 0x1a001302, 0x080a04a4,   // az.gl.un_420 hr.gl.un_320  et.tl.un_220 ru.mk.uk_433
  0x2d120d09, 0x0900640d, 0x1a2b01a7, 0x290911ac,   // cs.hu.sk_444 lg.pl.un_540  en.vi.tl_532 ro.pl.sl_632
  0x100408a9, 0x071716a7, 0x12001902, 0x29000704,   // uk.ru.be_544 hr.sr.it_532  gl.hu.un_220 it.sl.un_320
  0x0f2d0d08, 0x172d0d09, 0x090b19a0, 0x212504a0,   // cs.sk.lv_443 cs.sk.sr_444  gl.es.pl_322 fi.eu.jw_322
  // [2fc0]
  0x0d162d0c, 0x04110704, 0x55001212, 0x0d122d0d,   // sk.hr.cs_543 bg.ro.ru_332  hu.rw.un_640 sk.hu.cs_554
  0x0d2d10ad, 0x090f28af, 0x55642005, 0x042106ee,   // lt.sk.cs_643 sw.lv.pl_655  sq.lg.rw_333 de.jw.fi_422
  0x555328a7, 0x120a1805, 0x3f2002ee, 0x085364ee,   // sw.ht.rw_532 ga.pt.hu_333  da.sq.af_422 lg.ht.no_422
  0x21030607, 0x072a010c, 0x3f001219, 0x64283112,   // de.nl.jw_432 en.mt.it_543  hu.af.un_750 az.sw.lg_654
  // [2fd0]
  0x552864ec, 0x170a0407, 0x2d170d07, 0x28551baf,   // lg.sw.rw_644 ru.mk.sr_432  cs.sr.sk_432 tr.rw.sw_655
  0x556410ad, 0x25000d07, 0x6b041a08, 0x090f0d07,   // lt.lg.rw_643 cs.eu.un_420  tl.fi.ceb_443 cs.lv.pl_432
  0x10040f0c, 0x0e002714, 0x6b285513, 0x03110e04,   // lv.fi.lt_543 gd.is.un_660  rw.sw.ceb_665 is.ro.nl_332
  0x23005304, 0x120f1aa9, 0x031907ee, 0x120f0412,   // ht.ca.un_320 tl.lv.hu_544  it.gl.nl_422 fi.lv.hu_654
  // [2fe0]
  0x01190b04, 0x0e05640c, 0x552812a0, 0x121a0ca9,   // es.gl.en_332 lg.fr.is_543  hu.sw.rw_322 sv.tl.hu_544
  0x3f0608a0, 0x083f0304, 0x05120f04, 0x5500531a,   // no.de.af_322 nl.af.no_332  lv.hu.fr_332 ht.rw.un_760
  0x53005513, 0x03005504, 0x07190eee, 0x2d0e1bad,   // rw.ht.un_650 rw.nl.un_320  is.gl.it_422 tr.is.sk_643
  0x102953a7, 0x215305a9, 0x0e531ba7, 0x03000609,   // ht.sl.lt_532 fr.ht.jw_544  tr.ht.is_532 de.nl.un_440
  // [2ff0]
  0x20000f08, 0x102d0d02, 0x12531a04, 0x13286404,   // lv.sq.un_430 cs.sk.lt_222  tl.ht.hu_332 lg.sw.et_332
  0x172d0da4, 0x06035505, 0x1f002a14, 0x04120f08,   // cs.sk.sr_433 rw.nl.de_333  mt.cy.un_660 lv.hu.fi_443
  0x06000120, 0x25001704, 0x21040f0c, 0x06000e14,   // en.de.un_850 sr.eu.un_320  lv.fi.jw_543 is.de.un_660
  0x1e1a0fa4, 0x64000f05, 0x031b120e, 0x6412550c,   // lv.tl.ms_433 lv.lg.un_330  hu.tr.nl_555 rw.hu.lg_543

  // [3000]
  0x016b1a02, 0x12000814, 0x060364af, 0x170c6ea0,   // tl.ceb.en_222 no.hu.un_660  lg.nl.de_655 blu.sv.sr_322
  0x28556460, 0x55641012, 0x2a3f0305, 0x531b0e08,   // lg.rw.sw_664 lt.lg.rw_654  nl.af.mt_333 is.tr.ht_443
  0x0c0802ee, 0x0e001b14, 0x1b000e13, 0x0d002d11,   // da.no.sv_422 tr.is.un_660  is.tr.un_650 sk.cs.un_630
  0x6b001a14, 0x0c0520a0, 0x01001104, 0x641328a0,   // tl.ceb.un_660 sq.fr.sv_322  ro.en.un_320 sw.et.lg_322
  // [3010]
  0x0d001c14, 0x13292da4, 0x130f64ec, 0x1e232113,   // mr.ne.un_660 sk.sl.et_433  lg.lv.et_644 jw.ca.ms_665
  0x10001f08, 0x17160da9, 0x211c1ea0, 0x0f291604,   // cy.lt.un_430 cs.hr.sr_544  ms.id.jw_322 hr.sl.lv_332
  0x0b0a1f14, 0x04000d07, 0x05271809, 0x131e1a08,   // cy.pt.es_666 cs.fi.un_420  ga.gd.fr_444 tl.ms.et_443
  0x23001905, 0x050901a0, 0x0c122507, 0x31002807,   // gl.ca.un_330 en.pl.fr_322  eu.hu.sv_432 sw.az.un_420
  // [3020]
  0x29005302, 0x0a1e1c0c, 0x0a1107a0, 0x0c030f0c,   // ht.sl.un_220 id.ms.pt_543  it.ro.pt_322 lv.nl.sv_543
  0x281a11a4, 0x06001313, 0x080602ee, 0x2d001e02,   // ro.tl.sw_433 et.de.un_650  da.de.no_422 ms.sk.un_220
  0x09105304, 0x17000408, 0x53003121, 0x2800530e,   // ht.lt.pl_332 fi.sr.un_430  az.ht.un_860 ht.sw.un_550
  0x29530107, 0x092a1f0c, 0x091f5308, 0x021001a0,   // en.ht.sl_432 cy.mt.pl_543  ht.cy.pl_443 en.lt.da_322
  // [3030]
  0x1e0a1c0c, 0x13210c05, 0x291153ac, 0x06001704,   // id.pt.ms_543 sv.jw.et_333  ht.ro.sl_632 sr.de.un_320
  0x0c002d08, 0x1000172a, 0x53002704, 0x0d190b04,   // sk.sv.un_430 sr.be.un_970  gd.ht.un_320 es.gl.cs_332
  0x16090da4, 0x111617ec, 0x01040907, 0x13001c1b,   // cs.pl.hr_433 sr.hr.ro_644  pl.fi.en_432 mr.bh.un_770
  0x2a003f04, 0x281e1c0c, 0x0a04175a, 0x1c1e1f07,   // af.mt.un_320 id.ms.sw_543  sr.ru.mk_553 cy.ms.id_432
  // [3040]
  0x09001f19, 0x1c016ba0, 0x3f030605, 0x1e1c160e,   // cy.pl.un_750 ceb.en.id_322  de.nl.af_333 hr.id.ms_555
  0x55281a08, 0x0d100407, 0x25001a09, 0x0a0711a7,   // tl.sw.rw_443 fi.lt.cs_432  tl.eu.un_440 ro.bg.mk_532
  0x2d0d250e, 0x0e00080c, 0x55281f08, 0x190b1205,   // eu.cs.sk_555 no.is.un_530  cy.sw.rw_443 hu.es.gl_333
  0x170a08af, 0x2a1f0c04, 0x2a021a04, 0x1200280e,   // uk.mk.sr_655 sv.cy.mt_332  tl.da.mt_332 sw.hu.un_550
  // [3050]
  0x201617a7, 0x0a2a11ee, 0x13080607, 0x170f25a0,   // sr.hr.sq_532 ro.mt.pt_422  de.no.et_432 eu.lv.sr_322
  0x0d00091b, 0x021b1105, 0x550f1c07, 0x11071005,   // hi.ne.un_770 ro.tr.da_333  id.lv.rw_432 be.bg.ro_333
  0x642855ec, 0x0f002d09, 0x290f100c, 0x2d0d095a,   // rw.sw.lg_644 sk.lv.un_440  lt.lv.sl_543 pl.cs.sk_553
  0x285511ee, 0x11210f0c, 0x6e0f6b04, 0x16000f05,   // ro.rw.sw_422 lv.jw.ro_543  ceb.lv.blu_332 lv.hr.un_330
  // [3060]
  0x55050fee, 0x190b1802, 0x06210914, 0x1a1c2107,   // lv.fr.rw_422 ga.es.gl_222  pl.jw.de_666 jw.id.tl_432
  0x1f023fa4, 0x3f640305, 0x0804110c, 0x3153200c,   // af.da.cy_433 nl.lg.af_333  ro.ru.uk_543 sq.ht.az_543
  0x17161bee, 0x2800551a, 0x0c000614, 0x2b00010c,   // tr.hr.sr_422 rw.sw.un_760  de.sv.un_660 en.vi.un_530
  0x6b0c0107, 0x122d0907, 0x2800550e, 0x0e1e1ca0,   // en.sv.ceb_432 pl.sk.hu_432  rw.sw.un_550 id.ms.is_322
  // [3070]
  0x10006404, 0x06080e0b, 0x101708a0, 0x17000c02,   // lg.lt.un_320 is.no.de_542  uk.sr.be_322 sv.sr.un_220
  0x2a112308, 0x13000418, 0x13000936, 0x0113640b,   // ca.ro.mt_443 fi.et.un_740  hi.bh.un_AA0 lg.et.en_542
  0x3f25125a, 0x040810a0, 0x0a2d0d07, 0x0a171113,   // hu.eu.af_553 be.uk.ru_322  cs.sk.pt_432 ro.sr.mk_665
  0x0f291fa4, 0x0e002b12, 0x1e000a02, 0x09002d1a,   // cy.sl.lv_433 vi.is.un_640  pt.ms.un_220 sk.pl.un_760
  // [3080]
  0x1a000107, 0x1a006b0b, 0x0700230e, 0x1318010c,   // en.tl.un_420 ceb.tl.un_520  ca.it.un_550 en.ga.et_543
  0x27001f02, 0x1a1f1309, 0x29002108, 0x1e032704,   // cy.gd.un_220 et.cy.tl_444  jw.sl.un_430 gd.nl.ms_332
  0x136b2da9, 0x2100250c, 0x29002d0e, 0x292d0d14,   // sk.ceb.et_544 eu.jw.un_530  sk.sl.un_550 cs.sk.sl_666
  0x2a133108, 0x531a13a4, 0x12001f08, 0x01002521,   // az.et.mt_443 et.tl.ht_433  cy.hu.un_430 eu.en.un_860
  // [3090]
  0x3f1729af, 0x0a041107, 0x2a1f13af, 0x1b3153a4,   // sl.sr.af_655 ro.ru.mk_432  et.cy.mt_655 ht.az.tr_433
  0x23001812, 0x093f21a9, 0x01050804, 0x28311b0c,   // ga.ca.un_640 jw.af.pl_544  no.fr.en_332 tr.az.sw_543
  0x1211070c, 0x131f1807, 0x0c0603a0, 0x13006e08,   // it.ro.hu_543 ga.cy.et_432  nl.de.sv_322 blu.et.un_430
  0x065308a7, 0x06000e22, 0x1b005507, 0x0d192011,   // no.ht.de_532 is.de.un_870  rw.tr.un_420 sq.gl.cs_653
  // [30a0]
  0x03131fec, 0x3f2a13a4, 0x06210a02, 0x17160105,   // cy.et.nl_644 et.mt.af_433  pt.jw.de_222 en.hr.sr_333
  0x070801a0, 0x20005312, 0x052d0912, 0x136b0a08,   // en.no.it_322 ht.sq.un_640  pl.sk.fr_654 pt.ceb.et_443
  0x190b1105, 0x061b1ea0, 0x100804ac, 0x31111ba4,   // ro.es.gl_333 ms.tr.de_322  ru.uk.be_632 tr.ro.az_433
  0x3f1a1fec, 0x041011a0, 0x531a0209, 0x25000702,   // cy.tl.af_644 ro.be.ru_322  da.tl.ht_444 it.eu.un_220
  // [30b0]
  0x16172d07, 0x0a19530c, 0x080729ee, 0x11130107,   // sk.sr.hr_432 ht.gl.pt_543  sl.it.no_422 en.et.ro_432
  0x531b10a0, 0x17100aaf, 0x20190b0e, 0x12005307,   // lt.tr.ht_322 mk.be.sr_655  es.gl.sq_555 ht.hu.un_420
  0x205319a0, 0x0b080107, 0x0a08170c, 0x2b000208,   // gl.ht.sq_322 en.no.es_432  sr.uk.mk_543 da.vi.un_430
  0x00006e03, 0x3f005521, 0x1b005305, 0x1b005314,   // blu.un.un_300 rw.af.un_860  ht.tr.un_330 ht.tr.un_660
  // [30c0]
  0x07190a55, 0x182a03a4, 0x0804175a, 0x080417a7,   // pt.gl.it_442 nl.mt.ga_433  sr.ru.uk_553 sr.ru.uk_532
  0x17110708, 0x2011255a, 0x5500281a, 0x10001f0e,   // bg.ro.sr_443 eu.ro.sq_553  sw.rw.un_760 cy.lt.un_550
  0x0c00040d, 0x0c040613, 0x0a171108, 0x10001e07,   // fi.sv.un_540 de.fi.sv_665  ro.sr.mk_443 ms.lt.un_420
  0x040708a0, 0x3f0302a0, 0x02002102, 0x020408a0,   // uk.bg.ru_322 da.nl.af_322  jw.da.un_220 no.fi.da_322
  // [30d0]
  0x031b0607, 0x0b162a04, 0x1800272c, 0x0527180b,   // de.tr.nl_432 mt.hr.es_332  gd.ga.un_990 ga.gd.fr_542
  0x281001a7, 0x170806a7, 0x1b2a0307, 0x0f1001a4,   // en.lt.sw_532 de.no.sr_532  nl.mt.tr_432 en.lt.lv_433
  0x2710180c, 0x02060c08, 0x081c1ea9, 0x05001e05,   // ga.lt.gd_543 sv.de.da_443  ms.id.no_544 ms.fr.un_330
  0x03201baf, 0x170a0702, 0x012b2a07, 0x1b121ea9,   // tr.sq.nl_655 bg.mk.sr_222  mt.vi.en_432 ms.hu.tr_544
  // [30e0]
  0x070410a9, 0x3f002814, 0x272801ee, 0x1e283f55,   // be.ru.bg_544 sw.af.un_660  en.sw.gd_422 af.sw.ms_442
  0x180504a0, 0x0c083f04, 0x0900170c, 0x0125050c,   // fi.fr.ga_322 af.no.sv_332  sr.pl.un_530 fr.eu.en_543
  0x212b08a0, 0x05005309, 0x0917290d, 0x0411100e,   // no.vi.jw_322 ht.fr.un_440  sl.sr.pl_554 be.ro.ru_555
  0x2d002907, 0x100708a4, 0x04080605, 0x100711a7,   // sl.sk.un_420 uk.bg.be_433  de.no.fi_333 ro.it.lt_532
  // [30f0]
  0x092917a0, 0x281b1eee, 0x04000c1b, 0x230507a4,   // sr.sl.pl_322 ms.tr.sw_422  sv.fi.un_770 it.fr.ca_433
  0x29091104, 0x1b2812ee, 0x0c000819, 0x5527280c,   // ro.pl.sl_332 hu.sw.tr_422  no.sv.un_750 sw.gd.rw_543
  0x282164ee, 0x172d0d02, 0x0e2d0a0c, 0x09172905,   // lg.jw.sw_422 cs.sk.sr_222  pt.sk.is_543 sl.sr.pl_333
  0x050a01ee, 0x08060302, 0x08170413, 0x29091709,   // en.pt.fr_422 nl.de.no_222  ru.sr.uk_665 sr.pl.sl_444
  // [3100]
  0x1c090d11, 0x1e001c19, 0x133f03a4, 0x2a0608a0,   // ne.hi.mr_653 id.ms.un_750  nl.af.et_433 no.de.mt_322
  0x0705010c, 0x11100805, 0x1e092955, 0x21111360,   // en.fr.it_543 uk.be.ro_333  sl.pl.ms_442 et.ro.jw_664
  0x07081155, 0x27000607, 0x0c041304, 0x071704af,   // ro.uk.bg_442 de.gd.un_420  et.fi.sv_332 ru.sr.bg_655
  0x02000304, 0x132708a0, 0x28020302, 0x230b0a02,   // nl.da.un_320 no.gd.et_322  nl.da.sw_222 pt.es.ca_222
  // [3110]
  0x050c0807, 0x0e06180d, 0x271f18a9, 0x05001905,   // no.sv.fr_432 ga.de.is_554  ga.cy.gd_544 gl.fr.un_330
  0x04080cee, 0x04001319, 0x28000107, 0x0123050c,   // sv.no.fi_422 et.fi.un_750  en.sw.un_420 fr.ca.en_543
  0x3f001304, 0x131b11ee, 0x23101f0c, 0x2a0e53ad,   // et.af.un_320 ro.tr.et_422  cy.lt.ca_543 ht.is.mt_643
  0x04100812, 0x17112a12, 0x0704080d, 0x0e081f12,   // uk.be.ru_654 mt.ro.sr_654  uk.ru.bg_554 cy.no.is_654
  // [3120]
  0x12006b07, 0x04000821, 0x10000419, 0x130d0912,   // ceb.hu.un_420 uk.ru.un_860  ru.be.un_750 hi.ne.bh_654
  0x1a001f0d, 0x210501a4, 0x1f032507, 0x281306a6,   // cy.tl.un_540 en.fr.jw_433  eu.nl.cy_432 de.et.sw_521
  0x2b000402, 0x27126ba9, 0x0c00130d, 0x21000204,   // fi.vi.un_220 ceb.hu.gd_544  et.sv.un_540 da.jw.un_320
  0x060821a0, 0x1c1b0cac, 0x1e1c27ee, 0x04060c13,   // jw.no.de_322 sv.tr.id_632  gd.id.ms_422 sv.de.fi_665
  // [3130]
  0x0c00041a, 0x27002819, 0x080c0ea9, 0x25046404,   // fi.sv.un_760 sw.gd.un_750  is.sv.no_544 lg.fi.eu_332
  0x19126bac, 0x060e0107, 0x28645507, 0x0c0608ec,   // ceb.hu.gl_632 en.is.de_432  rw.lg.sw_432 no.de.sv_644
  0x1c1309a4, 0x0413125a, 0x55006412, 0x0f3f03a7,   // hi.bh.mr_433 hu.et.fi_553  lg.rw.un_640 nl.af.lv_532
  0x0800200d, 0x64060e12, 0x1a000a02, 0x6b3f0355,   // sq.no.un_540 is.de.lg_654  pt.tl.un_220 nl.af.ceb_442
  // [3140]
  0x641f120c, 0x1b092d08, 0x181a55a0, 0x536412a7,   // hu.cy.lg_543 sk.pl.tr_443  rw.tl.ga_322 hu.lg.ht_532
  0x071f0213, 0x06000d09, 0x312d0d04, 0x08040307,   // da.cy.it_665 cs.de.un_440  cs.sk.az_332 nl.fi.no_432
  0x10001707, 0x1a001309, 0x04006402, 0x122d0d55,   // sr.lt.un_420 et.tl.un_440  lg.fi.un_220 cs.sk.hu_442
  0x060e08a0, 0x3f641a07, 0x010804ee, 0x133f53a0,   // no.is.de_322 tl.lg.af_432  fi.no.en_422 ht.af.et_322
  // [3150]
  0x0e041ea0, 0x6b002009, 0x1e1c6b09, 0x0f091255,   // ms.fi.is_322 sq.ceb.un_440  ceb.id.ms_444 hu.pl.lv_442
  0x120208a9, 0x03063f07, 0x1b002a12, 0x17162002,   // no.da.hu_544 af.de.nl_432  mt.tr.un_640 sq.hr.sr_222
  0x6b120107, 0x641a6b60, 0x020a1907, 0x06000c13,   // en.hu.ceb_432 ceb.tl.lg_664  gl.pt.da_432 sv.de.un_650
  0x04006412, 0x04070a07, 0x11191f55, 0x23000202,   // lg.fi.un_640 mk.bg.ru_432  cy.gl.ro_442 da.ca.un_220
  // [3160]
  0x0f0d2911, 0x2b000104, 0x06040c0c, 0x28136405,   // sl.cs.lv_653 en.vi.un_320  sv.fi.de_543 lg.et.sw_333
  0x1609170c, 0x043f1aee, 0x09160d07, 0x041710a7,   // sr.pl.hr_543 tl.af.fi_422  cs.hr.pl_432 be.sr.ru_532
  0x2a00072a, 0x3f00041a, 0x0a0710ad, 0x03286407,   // it.mt.un_970 fi.af.un_760  be.bg.mk_643 lg.sw.nl_432
  0x03283fa4, 0x11170a05, 0x091c0da6, 0x0d311f02,   // af.sw.nl_433 mk.sr.ro_333  ne.mr.hi_521 cy.az.cs_222
  // [3170]
  0x3f001e02, 0x2b001f09, 0x06290d0c, 0x03006e08,   // ms.af.un_220 cy.vi.un_440  cs.sl.de_543 blu.nl.un_430
  0x07040855, 0x0a081707, 0x12002502, 0x040c0604,   // uk.ru.bg_442 sr.uk.mk_432  eu.hu.un_220 de.sv.fi_332
  0x27010507, 0x056e0d0c, 0x1f000209, 0x21001821,   // fr.en.gd_432 cs.blu.fr_543  da.cy.un_440 ar.fa.un_860
  0x1c090da7, 0x03080209, 0x21006405, 0x64001002,   // ne.hi.mr_532 da.no.nl_444  lg.jw.un_330 lt.lg.un_220
  // [3180]
  0x08006404, 0x1812215a, 0x64552814, 0x081017a4,   // lg.no.un_320 fa.ur.ar_553  sw.rw.lg_666 sr.be.uk_433
  0x2a000302, 0x1b000f21, 0x13001b08, 0x1e211ca0,   // nl.mt.un_220 lv.tr.un_860  tr.et.un_430 id.jw.ms_322
  0x09311013, 0x04020cee, 0x642128ee, 0x060c0205,   // lt.az.pl_665 sv.da.fi_422  sw.jw.lg_422 da.sv.de_333
  0x041301a0, 0x04001904, 0x08171655, 0x17160960,   // en.et.fi_322 gl.fi.un_320  hr.sr.no_442 pl.hr.sr_664
  // [3190]
  0x021312a4, 0x171004ad, 0x212018a4, 0x13000c08,   // hu.et.da_433 ru.be.sr_643  ga.sq.jw_433 sv.et.un_430
  0x06000708, 0x210f1b12, 0x111a200d, 0x07530fa4,   // it.de.un_430 tr.lv.jw_654  sq.tl.ro_554 lv.ht.it_433
  0x0e00530e, 0x1f3f250c, 0x1a001c13, 0x23181155,   // ht.is.un_550 eu.af.cy_543  id.tl.un_650 ro.ga.ca_442
  0x0d1c13ee, 0x6b1a1ea9, 0x04200d08, 0x25100f13,   // bh.mr.ne_422 ms.tl.ceb_544  cs.sq.fi_443 lv.lt.eu_665
  // [31a0]
  0x1b062a07, 0x033f13a4, 0x1f000e1a, 0x1628550b,   // mt.de.tr_432 et.af.nl_433  is.cy.un_760 rw.sw.hr_542
  0x0c231aa9, 0x53080e12, 0x3f000704, 0x3f050307,   // tl.ca.sv_544 is.no.ht_654  it.af.un_320 nl.fr.af_432
  0x04000823, 0x25171b0c, 0x2753280b, 0x00002737,   // uk.ru.un_880 tr.sr.eu_543  sw.ht.gd_542 gd.un.un_B00
  0x116b0fa4, 0x18005302, 0x0e001f19, 0x6b071aaf,   // lv.ceb.ro_433 ht.ga.un_220  cy.is.un_750 tl.it.ceb_655
  // [31b0]
  0x16001b07, 0x2d000c02, 0x18005307, 0x1a6b180e,   // tr.hr.un_420 sv.sk.un_220  ht.ga.un_420 ga.ceb.tl_555
  0x061e1c02, 0x5300080c, 0x11200d09, 0x05060ba0,   // id.ms.de_222 no.ht.un_530  cs.sq.ro_444 es.de.fr_322
  0x020c0ea7, 0x28531b05, 0x531b12a4, 0x0d080204,   // is.sv.da_532 tr.ht.sw_333  hu.tr.ht_433 da.no.cs_332
  0x27000804, 0x0d002502, 0x110c0d09, 0x64210bee,   // no.gd.un_320 eu.cs.un_220  cs.sv.ro_444 es.jw.lg_422
  // [31c0]
  0x1a53210c, 0x05532012, 0x19170fa4, 0x6b010655,   // jw.ht.tl_543 sq.ht.fr_654  lv.sr.gl_433 de.en.ceb_442
  0x0a05230c, 0x290b0707, 0x1120010c, 0x201a6ba9,   // ca.fr.pt_543 it.es.sl_432  en.sq.ro_543 ceb.tl.sq_544
  0x28291605, 0x17160fec, 0x28061807, 0x0c080212,   // hr.sl.sw_333 lv.hr.sr_644  ga.de.sw_432 da.no.sv_654
  0x13061bec, 0x081710ec, 0x1a000b0c, 0x31000402,   // tr.de.et_644 be.sr.uk_644  es.tl.un_530 fi.az.un_220
  // [31d0]
  0x1b311007, 0x13530c04, 0x180853a7, 0x08170aaf,   // lt.az.tr_432 sv.ht.et_332  ht.no.ga_532 mk.sr.uk_655
  0x2a005313, 0x0e6b01a0, 0x23130b02, 0x090d1c08,   // ht.mt.un_650 en.ceb.is_322  es.et.ca_222 mr.ne.hi_443
  0x1e281cec, 0x25003108, 0x011f1b07, 0x0e022507,   // id.sw.ms_644 az.eu.un_430  tr.cy.en_432 eu.da.is_432
  0x01001a04, 0x6b131aa4, 0x1b31280c, 0x085321a4,   // tl.en.un_320 tl.et.ceb_433  sw.az.tr_543 jw.ht.no_433
  // [31e0]
  0x2b311aa0, 0x2900170e, 0x131a28ac, 0x21131b08,   // tl.az.vi_322 sr.sl.un_550  sw.tl.et_632 tr.et.jw_443
  0x05000105, 0x2d000b09, 0x0408100e, 0x0d1c1311,   // en.fr.un_330 es.sk.un_440  be.uk.ru_555 bh.mr.ne_653
  0x0e190b02, 0x1a1b31a9, 0x04000c0e, 0x07101705,   // es.gl.is_222 az.tr.tl_544  sv.fi.un_550 sr.be.bg_333
  0x276b010d, 0x1e1c20a4, 0x08001005, 0x1c023f04,   // en.ceb.gd_554 sq.id.ms_433  be.uk.un_330 af.da.id_332
  // [31f0]
  0x6b3f1a09, 0x171610af, 0x31000908, 0x29161712,   // tl.af.ceb_444 lt.hr.sr_655  pl.az.un_430 sr.hr.sl_654
  0x0a0b19a7, 0x21002308, 0x05230b08, 0x0a00110b,   // gl.es.pt_532 ca.jw.un_430  es.ca.fr_443 ro.mk.un_520
  0x0a00080d, 0x1e1c210b, 0x0d1c1308, 0x110a1708,   // uk.mk.un_540 jw.id.ms_542  bh.mr.ne_443 sr.mk.ro_443
  0x0a000f04, 0x2d005308, 0x0708100b, 0x25006404,   // lv.pt.un_320 ht.sk.un_430  be.uk.bg_542 lg.eu.un_320
  // [3200]
  0x122d0da9, 0x05002313, 0x2d1716ee, 0x23000a0e,   // cs.sk.hu_544 ca.fr.un_650  hr.sr.sk_422 pt.ca.un_550
  0x03000a04, 0x12000f19, 0x18011207, 0x0b0a19a9,   // pt.nl.un_320 lv.hu.un_750  hu.en.ga_432 gl.pt.es_544
  0x160604ee, 0x6b0106a0, 0x03063f08, 0x6e6b3107,   // fi.de.hr_422 de.en.ceb_322  af.de.nl_443 az.ceb.blu_432
  0x07040a13, 0x20081bac, 0x0f0c080e, 0x0c0f120b,   // mk.ru.bg_665 tr.no.sq_632  no.sv.lv_555 hu.lv.sv_542
  // [3210]
  0x10160fa6, 0x090d130b, 0x1e311b09, 0x1b1a3104,   // lv.hr.lt_521 bh.ne.hi_542  tr.az.ms_444 az.tl.tr_332
  0x090607ec, 0x041a120c, 0x1c283104, 0x0b001219,   // it.de.pl_644 hu.tl.fi_543  az.sw.id_332 hu.es.un_750
  0x08002812, 0x282a1c02, 0x281a1007, 0x10005504,   // sw.no.un_640 id.mt.sw_222  lt.tl.sw_432 rw.lt.un_320
  0x1f283104, 0x071f1ba7, 0x040e1bad, 0x231807a0,   // az.sw.cy_332 tr.cy.it_532  tr.is.fi_643 it.ga.ca_322
  // [3220]
  0x1b1827a4, 0x12001304, 0x27002b07, 0x126428af,   // gd.ga.tr_433 et.hu.un_320  vi.gd.un_420 sw.lg.hu_655
  0x0600550d, 0x55001e02, 0x28002d09, 0x0e00550c,   // rw.de.un_540 ms.rw.un_220  sk.sw.un_440 rw.is.un_530
  0x02190107, 0x532a1104, 0x13080412, 0x19311b08,   // en.gl.da_432 ro.mt.ht_332  fi.no.et_654 tr.az.gl_443
  0x0b006e08, 0x17160255, 0x120b230d, 0x080e12a0,   // blu.es.un_430 da.hr.sr_442  ca.es.hu_554 hu.is.no_322
  // [3230]
  0x0c000619, 0x0c0e02a6, 0x1a1e0fa4, 0x040802a9,   // de.sv.un_750 da.is.sv_521  lv.ms.tl_433 da.no.fi_544
  0x1e1c12af, 0x2d00092a, 0x01000607, 0x012a0c02,   // hu.id.ms_655 pl.sk.un_970  de.en.un_420 sv.mt.en_222
  0x0c033f04, 0x0e1e1c55, 0x2d091fec, 0x0f001208,   // af.nl.sv_332 id.ms.is_442  cy.pl.sk_644 hu.lv.un_430
  0x27000c07, 0x04001005, 0x29211305, 0x07002a14,   // sv.gd.un_420 be.ru.un_330  et.jw.sl_333 mt.it.un_660
  // [3240]
  0x100711ee, 0x0c120f07, 0x040810ad, 0x202a110d,   // ro.bg.be_422 lv.hu.sv_432  be.uk.ru_643 ro.mt.sq_554
  0x311364a9, 0x0a1017a9, 0x080c12ad, 0x0d002914,   // lg.et.az_544 sr.be.mk_544  hu.sv.no_643 sl.cs.un_660
  0x2a040ca0, 0x0d063f04, 0x04070802, 0x191e1c55,   // sv.fi.mt_322 af.de.cs_332  uk.bg.ru_222 id.ms.gl_442
  0x1c0d2d0b, 0x3f2a0305, 0x18016ba0, 0x2d000919,   // sk.cs.id_542 nl.mt.af_333  ceb.en.ga_322 pl.sk.un_750
  // [3250]
  0x1e1c1605, 0x01282a0c, 0x09001f21, 0x05002309,   // hr.id.ms_333 mt.sw.en_543  cy.pl.un_860 ca.fr.un_440
  0x172d29a4, 0x2d000d2c, 0x2300070c, 0x2d17160c,   // sl.sk.sr_433 cs.sk.un_990  it.ca.un_530 hr.sr.sk_543
  0x13062904, 0x0c000d05, 0x28006b08, 0x21001e08,   // sl.de.et_332 cs.sv.un_330  ceb.sw.un_430 ms.jw.un_430
  0x230b01a4, 0x06040c12, 0x1000041a, 0x2a000702,   // en.es.ca_433 sv.fi.de_654  ru.be.un_760 it.mt.un_220
  // [3260]
  0x1100170c, 0x29025305, 0x171610ec, 0x17100408,   // sr.ro.un_530 ht.da.sl_333  lt.hr.sr_644 ru.be.sr_443
  0x09080c0e, 0x17070804, 0x55002a0d, 0x21001608,   // sv.no.pl_555 uk.bg.sr_332  mt.rw.un_540 hr.jw.un_430
  0x1a041e04, 0x2d162907, 0x55002704, 0x642128a9,   // ms.fi.tl_332 sl.hr.sk_432  gd.rw.un_320 sw.jw.lg_544
  0x03000605, 0x07080408, 0x070411ec, 0x1700161a,   // de.nl.un_330 ru.uk.bg_443  ro.ru.bg_644 hr.sr.un_760
  // [3270]
  0x2d000202, 0x13642511, 0x0d001302, 0x1f1101ee,   // da.sk.un_220 eu.lg.et_653  bh.ne.un_220 en.ro.cy_422
  0x0c001f23, 0x04081108, 0x20250807, 0x2a002d13,   // cy.sv.un_880 ro.uk.ru_443  no.eu.sq_432 sk.mt.un_650
  0x1c07010c, 0x531f2bee, 0x04000611, 0x53190713,   // en.it.id_543 vi.cy.ht_422  de.fi.un_630 it.gl.ht_665
  0x1e002105, 0x23055312, 0x07190b0e, 0x050b01ec,   // jw.ms.un_330 ht.fr.ca_654  es.gl.it_555 en.es.fr_644
  // [3280]
  0x1727530c, 0x212b5304, 0x10041104, 0x2b031e05,   // ht.gd.sr_543 ht.vi.jw_332  ro.ru.be_332 ms.nl.vi_333
  0x210228ee, 0x00005337, 0x0f5304a0, 0x0e18270c,   // sw.da.jw_422 ht.un.un_B00  fi.ht.lv_322 gd.ga.is_543
  0x2b002a02, 0x081110a4, 0x110b0104, 0x0000062d,   // mt.vi.un_220 be.ro.uk_433  en.es.ro_332 de.un.un_A00
  0x070410ee, 0x311c050c, 0x03180613, 0x0c000413,   // lt.fi.it_422 fr.id.az_543  de.ga.nl_665 fi.sv.un_650
  // [3290]
  0x0f1716a0, 0x1f00041a, 0x1b215507, 0x070a110b,   // hr.sr.lv_322 fi.cy.un_760  rw.jw.tr_432 ro.mk.bg_542
  0x011a1f02, 0x1a005513, 0x08070a04, 0x6b531b08,   // cy.tl.en_222 rw.tl.un_650  mk.bg.uk_332 tr.ht.ceb_443
  0x0718270c, 0x6b1b1a0d, 0x10000921, 0x53006b04,   // gd.ga.it_543 tl.tr.ceb_554  pl.lt.un_860 ceb.ht.un_320
  0x160f17ee, 0x1b00550d, 0x10002912, 0x3f006e07,   // sr.lv.hr_422 rw.tr.un_540  sl.lt.un_640 blu.af.un_420
  // [32a0]
  0x130f12af, 0x0308040c, 0x021c04ee, 0x21005504,   // hu.lv.et_655 fi.no.nl_543  fi.id.da_422 rw.jw.un_320
  0x1b215307, 0x08182711, 0x040a1704, 0x196407a6,   // ht.jw.tr_432 gd.ga.no_653  sr.mk.ru_332 it.lg.gl_521
  0x021208ee, 0x08001b11, 0x130825ac, 0x170a08ec,   // no.hu.da_422 tr.no.un_630  eu.no.et_632 uk.mk.sr_644
  0x2321200c, 0x27180e0d, 0x64552111, 0x12000e08,   // sq.jw.ca_543 is.ga.gd_554  jw.rw.lg_653 is.hu.un_430
  // [32b0]
  0x11000708, 0x0d1c09a9, 0x27001c02, 0x04170aa9,   // it.ro.un_430 hi.mr.ne_544  id.gd.un_220 mk.sr.ru_544
  0x1a086ba4, 0x3f1b25ec, 0x2a060104, 0x08191ba0,   // ceb.no.tl_433 eu.tr.af_644  en.de.mt_332 tr.gl.no_322
  0x10190b0d, 0x052112ad, 0x030e2daf, 0x17120daf,   // es.gl.lt_554 hu.jw.fr_643  sk.is.nl_655 cs.hu.sr_655
  0x1206550c, 0x0c0d2911, 0x2a000407, 0x2320110c,   // rw.de.hu_543 sl.cs.sv_653  fi.mt.un_420 ro.sq.ca_543
  // [32c0]
  0x6b131aad, 0x6b132055, 0x3f181f5a, 0x10200f0c,   // tl.et.ceb_643 sq.et.ceb_442  cy.ga.af_553 lv.sq.lt_543
  0x55001b23, 0x3f000305, 0x28001304, 0x64001b19,   // tr.rw.un_880 nl.af.un_330  et.sw.un_320 tr.lg.un_750
  0x030c25a0, 0x17080aa9, 0x21000108, 0x28556b55,   // eu.sv.nl_322 mk.uk.sr_544  en.jw.un_430 ceb.rw.sw_442
  0x6b031ea0, 0x1a6b5508, 0x10000b12, 0x0f190b55,   // ms.nl.ceb_322 rw.ceb.tl_443  es.lt.un_640 es.gl.lv_442
  // [32d0]
  0x05190b05, 0x2700020c, 0x1a2125ee, 0x161b0804,   // es.gl.fr_333 da.gd.un_530  eu.jw.tl_422 no.tr.hr_332
  0x1c0d1e04, 0x02033f0e, 0x18000514, 0x0f190a13,   // ms.cs.id_332 af.nl.da_555  fr.ga.un_660 pt.gl.lv_665
  0x0e0b2304, 0x2013550c, 0x13000902, 0x030e3fa0,   // ca.es.is_332 rw.et.sq_543  hi.bh.un_220 af.is.nl_322
  0x17000804, 0x10080402, 0x032b0504, 0x080e02ad,   // no.sr.un_320 ru.uk.be_222  fr.vi.nl_332 da.is.no_643
  // [32e0]
  0x0c002302, 0x6b001a2b, 0x0a041702, 0x24000111,   // ca.sv.un_220 tl.ceb.un_980  sr.ru.mk_222 iw.yi.un_630
  0x0e000214, 0x27000f05, 0x06006408, 0x02001a0d,   // da.is.un_660 lv.gd.un_330  lg.de.un_430 tl.da.un_540
  0x0e003f07, 0x290c53ee, 0x1c000d1a, 0x1a036ba0,   // af.is.un_420 ht.sv.sl_422  ne.mr.un_760 ceb.nl.tl_322
  0x0e020c5a, 0x55000609, 0x552a28a4, 0x05000304,   // sv.da.is_553 de.rw.un_440  sw.mt.rw_433 nl.fr.un_320
  // [32f0]
  0x04002302, 0x28121e0c, 0x07000411, 0x27011f07,   // ca.fi.un_220 ms.hu.sw_543  ru.bg.un_630 cy.en.gd_432
  0x1c285507, 0x08023f02, 0x07040a0d, 0x06000914,   // rw.sw.id_432 af.da.no_222  mk.ru.bg_554 pl.de.un_660
  0x126e6b04, 0x0e0b1911, 0x071704a4, 0x23190a09,   // ceb.blu.hu_332 gl.es.is_653  ru.sr.bg_433 pt.gl.ca_444
  0x01231baf, 0x553f03ee, 0x19002d07, 0x0a170708,   // tr.ca.en_655 nl.af.rw_422  sk.gl.un_420 bg.sr.mk_443
  // [3300]
  0x060109ad, 0x08040714, 0x0a1219ad, 0x2b006e08,   // pl.en.de_643 bg.ru.uk_666  gl.hu.pt_643 blu.vi.un_430
  0x07002308, 0x23002504, 0x2d00290e, 0x080e13a6,   // ca.it.un_430 eu.ca.un_320  sl.sk.un_550 et.is.no_521
  0x0c00060e, 0x08000304, 0x0a001a0c, 0x13000c0d,   // de.sv.un_550 nl.no.un_320  tl.pt.un_530 sv.et.un_540
  0x16000c0c, 0x03060fa9, 0x05011a09, 0x02060309,   // sv.hr.un_530 lv.de.nl_544  tl.en.fr_444 nl.de.da_444
  // [3310]
  0x0e000321, 0x315528a4, 0x07170408, 0x551b0d07,   // nl.is.un_860 sw.rw.az_433  ru.sr.bg_443 cs.tr.rw_432
  0x536428a4, 0x08000e11, 0x2a060c04, 0x282053a9,   // sw.lg.ht_433 is.no.un_630  sv.de.mt_332 ht.sq.sw_544
  0x19000b19, 0x0205010c, 0x1c00641b, 0x0900030e,   // es.gl.un_750 en.fr.da_543  lg.id.un_770 nl.pl.un_550
  0x160655ad, 0x6400030e, 0x27182a12, 0x0a002107,   // rw.de.hr_643 nl.lg.un_550  mt.ga.gd_654 jw.pt.un_420
  // [3320]
  0x102d0dad, 0x3f18270c, 0x050a010c, 0x20000f1a,   // cs.sk.lt_643 gd.ga.af_543  en.pt.fr_543 lv.sq.un_760
  0x550128a4, 0x0b190aad, 0x080255a4, 0x2300070d,   // sw.en.rw_433 pt.gl.es_643  rw.da.no_433 it.ca.un_540
  0x0f00030c, 0x080255af, 0x0a0b07a7, 0x03020ca4,   // nl.lv.un_530 rw.da.no_655  it.es.pt_532 sv.da.nl_433
  0x19002d04, 0x5320110c, 0x0b001812, 0x012b190c,   // sk.gl.un_320 ro.sq.ht_543  ga.es.un_640 gl.vi.en_543
  // [3330]
  0x2164550b, 0x13160108, 0x03050aa4, 0x29170fa9,   // rw.lg.jw_542 en.hr.et_443  pt.fr.nl_433 lv.sr.sl_544
  0x1a530112, 0x0a001009, 0x0f0603a9, 0x0555010c,   // en.ht.tl_654 lt.pt.un_440  nl.de.lv_544 en.rw.fr_543
  0x020d31a0, 0x0a005519, 0x5500051a, 0x072305ad,   // az.cs.da_322 rw.pt.un_750  fr.rw.un_760 fr.ca.it_643
  0x07002307, 0x2b030607, 0x550c025a, 0x0b001919,   // ca.it.un_420 de.nl.vi_432  da.sv.rw_553 gl.es.un_750
  // [3340]
  0x0e002702, 0x1a6b01ee, 0x1300030c, 0x25230bad,   // gd.is.un_220 en.ceb.tl_422  nl.et.un_530 es.ca.eu_643
  0x211c1e07, 0x12001814, 0x2d001902, 0x1c006b07,   // ms.id.jw_432 ar.ur.un_660  gl.sk.un_220 ceb.id.un_420
  0x060c0305, 0x25000b0b, 0x1c0a10ee, 0x05006e04,   // nl.sv.de_333 es.eu.un_520  lt.pt.id_422 blu.fr.un_320
  0x1a003f04, 0x13082aec, 0x07002304, 0x2a000723,   // af.tl.un_320 mt.no.et_644  ca.it.un_320 it.mt.un_880
  // [3350]
  0x07002322, 0x2707010b, 0x1000030c, 0x3f060c0c,   // ca.it.un_870 en.it.gd_542  nl.lt.un_530 sv.de.af_543
  0x31041b21, 0x17080704, 0x0c000812, 0x01002002,   // tr.fi.az_876 bg.uk.sr_332  no.sv.un_640 sq.en.un_220
  0x6400190b, 0x070a0107, 0x06280404, 0x0a001919,   // gl.lg.un_520 en.pt.it_432  fi.sw.de_332 gl.pt.un_750
  0x04131013, 0x251e2aa0, 0x02080e60, 0x023f0cee,   // lt.et.fi_665 mt.ms.eu_322  is.no.da_664 sv.af.da_422
  // [3360]
  0x126b1a60, 0x3f060c14, 0x0e002102, 0x060c13a7,   // tl.ceb.hu_664 sv.de.af_666  jw.is.un_220 et.sv.de_532
  0x0c251e07, 0x0e060caf, 0x170a080d, 0x0700040d,   // ms.eu.sv_432 sv.de.is_655  uk.mk.sr_554 ru.bg.un_540
  0x1f033f0c, 0x20531b07, 0x070a10ad, 0x03163fa4,   // af.nl.cy_543 tr.ht.sq_432  be.mk.bg_643 af.hr.nl_433
  0x1b0c10ad, 0x1c001a04, 0x10001f14, 0x17160d02,   // lt.sv.tr_643 tl.id.un_320  cy.lt.un_660 cs.hr.sr_222
  // [3370]
  0x6428550c, 0x10110413, 0x6b033f14, 0x0306210c,   // rw.sw.lg_543 ru.ro.be_665  af.nl.ceb_666 jw.de.nl_543
  0x55061c07, 0x130425a0, 0x23002702, 0x256404a4,   // id.de.rw_432 eu.fi.et_322  gd.ca.un_220 fi.lg.eu_433
  0x0e0801a9, 0x041707a0, 0x08640407, 0x03000409,   // en.no.is_544 bg.sr.ru_322  fi.lg.no_432 fi.nl.un_440
  0x033f1bee, 0x13000e11, 0x1f181ea0, 0x08001f04,   // tr.af.nl_422 is.et.un_630  ms.ga.cy_322 cy.no.un_320
  // [3380]
  0x531827ad, 0x2a032b04, 0x21001e12, 0x2d0d1009,   // gd.ga.ht_643 vi.nl.mt_332  ms.jw.un_640 lt.cs.sk_444
  0x17162960, 0x03001a07, 0x206421a0, 0x02230507,   // sl.hr.sr_664 tl.nl.un_420  jw.lg.sq_322 fr.ca.da_432
  0x033f06ad, 0x033f64a4, 0x1200131a, 0x2d00291a,   // de.af.nl_643 lg.af.nl_433  et.hu.un_760 sl.sk.un_760
  0x18000813, 0x040e0607, 0x100a1707, 0x033f0855,   // no.ga.un_650 de.is.fi_432  sr.mk.be_432 no.af.nl_442
  // [3390]
  0x0c295355, 0x23161e07, 0x0704080b, 0x01030b07,   // ht.sl.sv_442 ms.hr.ca_432  uk.ru.bg_542 es.nl.en_432
  0x0400280c, 0x08026407, 0x211e64ee, 0x2013080c,   // sw.fi.un_530 lg.da.no_432  lg.ms.jw_422 no.et.sq_543
  0x20190a08, 0x1a3f0507, 0x1b31110d, 0x13121a04,   // pt.gl.sq_443 fr.af.tl_432  ro.az.tr_554 tl.hu.et_332
  0x20026e07, 0x10006e08, 0x0e121c05, 0x0b2301a4,   // blu.da.sq_432 blu.lt.un_430  id.hu.is_333 en.ca.es_433
  // [33a0]
  0x01006e05, 0x27251f55, 0x08026e14, 0x29250ba0,   // blu.en.un_330 cy.eu.gd_442  blu.da.no_666 es.eu.sl_322
  0x12080209, 0x0d001702, 0x190b25a7, 0x64552813,   // da.no.hu_444 sr.cs.un_220  eu.es.gl_532 sw.rw.lg_665
  0x6400250d, 0x10000f22, 0x25000808, 0x080220a0,   // eu.lg.un_540 lv.lt.un_870  no.eu.un_430 sq.da.no_322
  0x17100412, 0x100f1704, 0x2a2523a0, 0x28006421,   // ru.be.sr_654 sr.lv.lt_332  ca.eu.mt_322 lg.sw.un_860
  // [33b0]
  0x6e000709, 0x31111baf, 0x29000f0d, 0x03063f12,   // it.blu.un_440 tr.ro.az_655  lv.sl.un_540 af.de.nl_654
  0x1a092a07, 0x100a11ee, 0x1c2555a9, 0x08020c11,   // mt.pl.tl_432 ro.mk.be_422  rw.eu.id_544 sv.da.no_653
  0x2a002008, 0x0600071a, 0x190c1e02, 0x201716ac,   // sq.mt.un_430 it.de.un_760  ms.sv.gl_222 hr.sr.sq_632
  0x02290c05, 0x06002509, 0x020c6eec, 0x013f09a7,   // sv.sl.da_333 eu.de.un_440  blu.sv.da_644 pl.af.en_532
  // [33c0]
  0x082b6e07, 0x162d0d0d, 0x08020cee, 0x3f036eee,   // blu.vi.no_432 cs.sk.hr_554  sv.da.no_422 blu.nl.af_422
  0x0b000707, 0x01000a02, 0x101716a7, 0x171629ad,   // it.es.un_420 pt.en.un_220  hr.sr.lt_532 sl.hr.sr_643
  0x53645555, 0x170a1109, 0x0f1029ee, 0x291c2102,   // rw.lg.ht_442 ro.mk.sr_444  sl.lt.lv_422 jw.id.sl_222
  0x211812a7, 0x28001b09, 0x08070a05, 0x04001b05,   // ur.ar.fa_532 tr.sw.un_440  mk.bg.uk_333 tr.fi.un_330
  // [33d0]
  0x10251b04, 0x11001014, 0x08000712, 0x0700530c,   // tr.eu.lt_332 be.ro.un_660  bg.uk.un_640 ht.it.un_530
  0x0c08020e, 0x2d190b08, 0x13001604, 0x0b2d1907,   // da.no.sv_555 es.gl.sk_443  hr.et.un_320 gl.sk.es_432
  0x10000708, 0x19000b21, 0x120c0107, 0x1204200c,   // bg.be.un_430 es.gl.un_860  en.sv.hu_432 sq.fi.hu_543
  0x291617ad, 0x3f0c030e, 0x2d000b19, 0x190e0a07,   // sr.hr.sl_643 nl.sv.af_555  es.sk.un_750 pt.is.gl_432
  // [33e0]
  0x0a071002, 0x3f080305, 0x19000b36, 0x0a0b06ac,   // be.bg.mk_222 nl.no.af_333  es.gl.un_AA0 de.es.pt_632
  0x530602a9, 0x55005302, 0x53000108, 0x531128a0,   // da.de.ht_544 ht.rw.un_220  en.ht.un_430 sw.ro.ht_322
  0x2d112807, 0x0f002902, 0x31002921, 0x0b001921,   // sw.ro.sk_432 sl.lv.un_220  sl.az.un_860 gl.es.un_860
  0x53281104, 0x10001705, 0x2d171605, 0x11311b12,   // ro.sw.ht_332 sr.be.un_330  hr.sr.sk_333 tr.az.ro_654
  // [33f0]
  0x09131c11, 0x090320a4, 0x1e231c07, 0x1b00251b,   // mr.bh.hi_653 sq.nl.pl_433  id.ca.ms_432 eu.tr.un_770
  0x55006421, 0x55003f05, 0x03000a02, 0x642809a9,   // lg.rw.un_860 af.rw.un_330  pt.nl.un_220 pl.sw.lg_544
  0x092821a7, 0x29163105, 0x17160605, 0x6b121007,   // jw.sw.pl_532 az.hr.sl_333  de.hr.sr_333 lt.hu.ceb_432
  0x11102504, 0x02000c22, 0x3f5521ad, 0x2d060d04,   // eu.lt.ro_332 sv.da.un_870  jw.rw.af_643 cs.de.sk_332

  // [3400]
  0x20002513, 0x552804a4, 0x09006413, 0x5528215a,   // eu.sq.un_650 fi.sw.rw_433  lg.pl.un_650 jw.sw.rw_553
  0x17160aa4, 0x040f25a0, 0x2000110b, 0x11070405,   // pt.hr.sr_433 eu.lv.fi_322  ro.sq.un_520 ru.bg.ro_333
  0x29001302, 0x10216ba4, 0x17080a0c, 0x12001105,   // et.sl.un_220 ceb.jw.lt_433  mk.uk.sr_543 ro.hu.un_330
  0x13001207, 0x556428af, 0x12092507, 0x551128ec,   // hu.et.un_420 sw.lg.rw_655  eu.pl.hu_432 sw.ro.rw_644
  // [3410]
  0x1b00312b, 0x642555a9, 0x64551155, 0x29001104,   // az.tr.un_980 rw.eu.lg_544  ro.rw.lg_442 ro.sl.un_320
  0x3f020311, 0x64002818, 0x20161707, 0x070804a0,   // nl.da.af_653 sw.lg.un_740  sr.hr.sq_432 ru.uk.bg_322
  0x07005305, 0x08002109, 0x17251204, 0x110408af,   // ht.it.un_330 jw.no.un_440  hu.eu.sr_332 uk.ru.ro_655
  0x12285507, 0x171621a4, 0x2900101a, 0x53096404,   // rw.sw.hu_432 jw.hr.sr_433  lt.sl.un_760 lg.pl.ht_332
  // [3420]
  0x13080409, 0x130d0905, 0x0a111708, 0x05231114,   // fi.no.et_444 hi.ne.bh_333  sr.ro.mk_443 ro.ca.fr_666
  0x0d092dee, 0x080a07a4, 0x17161007, 0x0d061f07,   // sk.pl.cs_422 bg.mk.uk_433  lt.hr.sr_432 cy.de.cs_432
  0x093f2da4, 0x200810a4, 0x04000108, 0x291853ee,   // sk.af.pl_433 lt.no.sq_433  en.fi.un_430 ht.ga.sl_422
  0x29001013, 0x0400101b, 0x08170a0b, 0x2d001813,   // lt.sl.un_650 be.ru.un_770  mk.sr.uk_542 ga.sk.un_650
  // [3430]
  0x230701a0, 0x252016a4, 0x09111fee, 0x0700230d,   // en.it.ca_322 hr.sq.eu_433  cy.ro.pl_422 ca.it.un_540
  0x19002a04, 0x2900101b, 0x53002804, 0x122164ee,   // mt.gl.un_320 lt.sl.un_770  sw.ht.un_320 lg.jw.hu_422
  0x1f160ba4, 0x1e1c64af, 0x10171602, 0x23001112,   // es.hr.cy_433 lg.id.ms_655  hr.sr.lt_222 ro.ca.un_640
  0x5364280c, 0x6b2a01a6, 0x1c0e10a7, 0x01002434,   // sw.lg.ht_543 en.mt.ceb_521  lt.is.id_532 yi.iw.un_A80
  // [3440]
  0x3f000319, 0x2d0d120e, 0x072a01ee, 0x03061ca4,   // nl.af.un_750 hu.cs.sk_555  en.mt.it_422 id.de.nl_433
  0x2b003f08, 0x13041002, 0x64006b0d, 0x08022a05,   // af.vi.un_430 lt.fi.et_222  ceb.lg.un_540 mt.da.no_333
  0x0f002508, 0x08110705, 0x072364a4, 0x230721a4,   // eu.lv.un_430 bg.ro.uk_333  lg.ca.it_433 jw.it.ca_433
  0x282718ad, 0x06041355, 0x1f1e1c55, 0x04001f18,   // ga.gd.sw_643 et.fi.de_442  id.ms.cy_442 cy.fi.un_740
  // [3450]
  0x2a00640c, 0x1a216b02, 0x041e25a0, 0x290d2d11,   // lg.mt.un_530 ceb.jw.tl_222  eu.ms.fi_322 sk.cs.sl_653
  0x01040ea0, 0x2000120e, 0x1f000302, 0x041c1ead,   // is.fi.en_322 hu.sq.un_550  nl.cy.un_220 ms.id.fi_643
  0x1c6b21a0, 0x0c060805, 0x030511a4, 0x2d000a08,   // jw.ceb.id_322 no.de.sv_333  ro.fr.nl_433 pt.sk.un_430
  0x0e000619, 0x01000604, 0x55113fa0, 0x07000434,   // de.is.un_750 de.en.un_320  af.ro.rw_322 ru.bg.un_A80
  // [3460]
  0x071112a9, 0x641a2807, 0x1a166baf, 0x13080407,   // hu.ro.it_544 sw.tl.lg_432  ceb.hr.tl_655 fi.no.et_432
  0x04080707, 0x0b0713a0, 0x0a07040d, 0x06233f04,   // bg.uk.ru_432 et.it.es_322  ru.bg.mk_554 af.ca.de_332
  0x07002902, 0x1f002307, 0x1c645508, 0x2d0f11a9,   // sl.it.un_220 ca.cy.un_420  rw.lg.id_443 ro.lv.sk_544
  0x3f001f08, 0x0f112709, 0x2806025a, 0x641c1e0b,   // cy.af.un_430 gd.ro.lv_444  da.de.sw_553 ms.id.lg_542
  // [3470]
  0x20171655, 0x0a1711a0, 0x31551ea0, 0x11270ca0,   // hr.sr.sq_442 ro.sr.mk_322  ms.rw.az_322 sv.gd.ro_322
  0x25000412, 0x641c1eec, 0x0113110c, 0x061c1e12,   // fi.eu.un_640 ms.id.lg_644  ro.et.en_543 ms.id.de_654
  0x1c291ea4, 0x0d171613, 0x1b5511a7, 0x2d1211a6,   // ms.sl.id_433 hr.sr.cs_665  ro.rw.tr_532 ro.hu.sk_521
  0x11000214, 0x12291607, 0x0300060e, 0x1e002a04,   // da.ro.un_660 hr.sl.hu_432  de.nl.un_550 mt.ms.un_320
  // [3480]
  0x1200040d, 0x3f000611, 0x31126404, 0x64002513,   // fi.hu.un_540 de.af.un_630  lg.hu.az_332 eu.lg.un_650
  0x1c2864ad, 0x1700160b, 0x1b645514, 0x2b001807,   // lg.sw.id_643 hr.sr.un_520  rw.lg.tr_666 ga.vi.un_420
  0x28000612, 0x2900550d, 0x55001108, 0x1e1c040e,   // de.sw.un_640 rw.sl.un_540  ro.rw.un_430 fi.id.ms_555
  0x2311200c, 0x0c0501a7, 0x06170e08, 0x5500211a,   // sq.ro.ca_543 en.fr.sv_532  is.sr.de_443 jw.rw.un_760
  // [3490]
  0x3f031ea9, 0x28000408, 0x0c1e1c02, 0x25000413,   // ms.nl.af_544 fi.sw.un_430  id.ms.sv_222 fi.eu.un_650
  0x110a17a4, 0x113120a7, 0x1a00120d, 0x09002004,   // sr.mk.ro_433 sq.az.ro_532  hu.tl.un_540 sq.pl.un_320
  0x0e020c08, 0x25005504, 0x1a0c0802, 0x113f08a0,   // sv.da.is_443 rw.eu.un_320  no.sv.tl_222 no.af.ro_322
  0x031a2108, 0x1f190a04, 0x271f180b, 0x03000621,   // jw.tl.nl_443 pt.gl.cy_332  ga.cy.gd_542 de.nl.un_860
  // [34a0]
  0x180e12a7, 0x210f1fad, 0x070408a9, 0x12001b07,   // hu.is.ga_532 cy.lv.jw_643  uk.ru.bg_544 tr.hu.un_420
  0x6421200c, 0x046425ad, 0x230e09a7, 0x1f006422,   // sq.jw.lg_543 eu.lg.fi_643  pl.is.ca_532 lg.cy.un_870
  0x0a005308, 0x1f001219, 0x18006b07, 0x31002502,   // ht.pt.un_430 hu.cy.un_750  ceb.ga.un_420 eu.az.un_220
  0x272111a4, 0x1b3f64a0, 0x020c08a9, 0x25000308,   // ro.jw.gd_433 lg.af.tr_322  no.sv.da_544 nl.eu.un_430
  // [34b0]
  0x171620ec, 0x0c00130e, 0x020c01a0, 0x23001219,   // sq.hr.sr_644 et.sv.un_550  en.sv.da_322 hu.ca.un_750
  0x25532111, 0x07041709, 0x27005334, 0x0e000805,   // jw.ht.eu_653 sr.ru.bg_444  ht.gd.un_A80 no.is.un_330
  0x0b001802, 0x3f000336, 0x12532baf, 0x0a001912,   // ga.es.un_220 nl.af.un_AA0  vi.ht.hu_655 gl.pt.un_640
  0x2a1e1c11, 0x062a07a9, 0x2b230107, 0x230b1207,   // id.ms.mt_653 it.mt.de_544  en.ca.vi_432 hu.es.ca_432
  // [34c0]
  0x0d001307, 0x180f1faf, 0x21001c1a, 0x31001b0b,   // bh.ne.un_420 cy.lv.ga_655  id.jw.un_760 tr.az.un_520
  0x25002d08, 0x5300251a, 0x1b311a0c, 0x211c1ea9,   // sk.eu.un_430 eu.ht.un_760  tl.az.tr_543 ms.id.jw_544
  0x25193107, 0x022d17a4, 0x17282aee, 0x27001f0c,   // az.gl.eu_432 sr.sk.da_433  mt.sw.sr_422 cy.gd.un_530
  0x032755ee, 0x1827530e, 0x172d0d0b, 0x0e060304,   // rw.gd.nl_422 ht.gd.ga_555  cs.sk.sr_542 nl.de.is_332
  // [34d0]
  0x2927010c, 0x20003112, 0x3f002d02, 0x123f0360,   // en.gd.sl_543 az.sq.un_640  sk.af.un_220 nl.af.hu_664
  0x0a071708, 0x2a531e07, 0x161f2908, 0x3f001f02,   // sr.bg.mk_443 ms.ht.mt_432  sl.cy.hr_443 cy.af.un_220
  0x1e1b3f08, 0x18001211, 0x1b001a14, 0x0a000813,   // af.tr.ms_443 ur.ar.un_630  tl.tr.un_660 uk.mk.un_650
  0x1e1c1b14, 0x13101b55, 0x04002807, 0x1b00640d,   // tr.id.ms_666 tr.lt.et_442  sw.fi.un_420 lg.tr.un_540
  // [34e0]
  0x1b000805, 0x101711a4, 0x55000a12, 0x0d6b20ec,   // no.tr.un_330 ro.sr.be_433  pt.rw.un_640 sq.ceb.cs_644
  0x17003104, 0x130208a4, 0x020c0609, 0x1c172a02,   // az.sr.un_320 no.da.et_433  de.sv.da_444 mt.sr.id_222
  0x28002007, 0x2a006b1a, 0x1f1210a0, 0x0e002004,   // sq.sw.un_420 ceb.mt.un_760  lt.hu.cy_322 sq.is.un_320
  0x530425a4, 0x2b0c25a7, 0x11032b02, 0x171b0e0b,   // eu.fi.ht_433 eu.sv.vi_532  vi.nl.ro_222 is.tr.sr_542
  // [34f0]
  0x1b2813a4, 0x0e27185a, 0x08201ba4, 0x0b010507,   // et.sw.tr_433 ga.gd.is_553  tr.sq.no_433 fr.en.es_432
  0x09081ba4, 0x0e000307, 0x280617a0, 0x3f060e05,   // tr.no.pl_433 nl.is.un_420  sr.de.sw_322 is.de.af_333
  0x160d17a4, 0x2d011e02, 0x086b1aec, 0x0e005312,   // sr.cs.hr_433 ms.en.sk_222  tl.ceb.no_644 ht.is.un_640
  0x0500230e, 0x040e1304, 0x11040aa4, 0x0a0c1fa4,   // ca.fr.un_550 et.is.fi_332  mk.ru.ro_433 cy.sv.pt_433
  // [3500]
  0x6e011105, 0x10040509, 0x6b0119a0, 0x0e00180c,   // ro.en.blu_333 fr.fi.lt_444  gl.en.ceb_322 ga.is.un_530
  0x0c080a07, 0x27182808, 0x0f1f1355, 0x271853af,   // pt.no.sv_432 sw.ga.gd_443  et.cy.lv_442 ht.ga.gd_655
  0x282b1e02, 0x12002519, 0x09080ea4, 0x11000a05,   // ms.vi.sw_222 eu.hu.un_750  is.no.pl_433 pt.ro.un_330
  0x271f0e0c, 0x2b000d02, 0x0708110b, 0x182708ad,   // is.cy.gd_543 cs.vi.un_220  ro.uk.bg_542 no.gd.ga_643
  // [3510]
  0x180306a4, 0x27000b07, 0x1a230a07, 0x13250e07,   // de.nl.ga_433 es.gd.un_420  pt.ca.tl_432 is.eu.et_432
  0x1c27250c, 0x550120a6, 0x11030655, 0x3f04130c,   // eu.gd.id_543 sq.en.rw_521  de.nl.ro_442 et.fi.af_543
  0x0c0853af, 0x53000612, 0x180e5307, 0x1f000c02,   // ht.no.sv_655 de.ht.un_640  ht.is.ga_432 sv.cy.un_220
  0x182753ec, 0x1800531a, 0x2d291605, 0x0e1853ad,   // ht.gd.ga_644 ht.ga.un_760  hr.sl.sk_333 ht.ga.is_643
  // [3520]
  0x27000808, 0x10001818, 0x083f0308, 0x080306ee,   // no.gd.un_430 ga.lt.un_740  nl.af.no_443 de.nl.no_422
  0x1318060c, 0x0704110b, 0x07002107, 0x043f1304,   // de.ga.et_543 ro.ru.bg_542  jw.it.un_420 et.af.fi_332
  0x0420080c, 0x07000b0e, 0x1b0f5307, 0x6e1a6b02,   // no.sq.fi_543 es.it.un_550  ht.lv.tr_432 ceb.tl.blu_222
  0x1b2013a4, 0x21001a12, 0x0d6b0ea0, 0x136b1a60,   // et.sq.tr_433 tl.jw.un_640  is.ceb.cs_322 tl.ceb.et_664
  // [3530]
  0x53112aec, 0x0d2004a9, 0x17000202, 0x13000509,   // mt.ro.ht_644 fi.sq.cs_544  da.sr.un_220 fr.et.un_440
  0x07170405, 0x196b2107, 0x12002d02, 0x0a0407a0,   // ru.sr.bg_333 jw.ceb.gl_432  sk.hu.un_220 bg.ru.mk_322
  0x1f030e12, 0x07170804, 0x11131a07, 0x10211ca4,   // is.nl.cy_654 uk.sr.bg_332  tl.et.ro_432 id.jw.lt_433
  0x06130c07, 0x1b002b04, 0x0704085a, 0x13082a04,   // sv.et.de_432 vi.tr.un_320  uk.ru.bg_553 mt.no.et_332
  // [3540]
  0x1c002108, 0x2a1228a7, 0x130428ec, 0x033f04ec,   // jw.id.un_430 sw.hu.mt_532  sw.fi.et_644 fi.af.nl_644
  0x180705a0, 0x2d003f13, 0x28043fee, 0x1c1304a7,   // fr.it.ga_322 af.sk.un_650  af.fi.sw_422 fi.et.id_532
  0x1f002a1a, 0x170403ad, 0x3f0405ee, 0x06001602,   // mt.cy.un_760 nl.fi.sr_643  fr.fi.af_422 hr.de.un_220
  0x0a111704, 0x10051907, 0x0d2d0611, 0x12002805,   // sr.ro.mk_332 gl.fr.lt_432  de.sk.cs_653 sw.hu.un_330
  // [3550]
  0x2128640d, 0x212a1ea0, 0x0e2a18a4, 0x3f281ea4,   // lg.sw.jw_554 ms.mt.jw_322  ga.mt.is_433 ms.sw.af_433
  0x270f06a6, 0x1f051b0c, 0x09131c12, 0x211f135a,   // de.lv.gd_521 tr.fr.cy_543  mr.bh.hi_654 et.cy.jw_553
  0x5305040c, 0x032108a4, 0x18122d0b, 0x2a1f0107,   // fi.fr.ht_543 no.jw.nl_433  sk.hu.ga_542 en.cy.mt_432
  0x03023fee, 0x3f1f2a0c, 0x17040a07, 0x2a000104,   // af.da.nl_422 mt.cy.af_543  mk.ru.sr_432 en.mt.un_320
  // [3560]
  0x53002707, 0x12001b23, 0x11002704, 0x532112a4,   // gd.ht.un_420 tr.hu.un_880  gd.ro.un_320 hu.jw.ht_433
  0x13120a08, 0x0a1201a9, 0x033f2aa9, 0x13083fee,   // pt.hu.et_443 en.hu.pt_544  mt.af.nl_544 af.no.et_422
  0x03002805, 0x03063f0c, 0x133101a0, 0x061b13ec,   // sw.nl.un_330 af.de.nl_543  en.az.et_322 et.tr.de_644
  0x17071008, 0x04000e20, 0x0a00120e, 0x2800031b,   // be.bg.sr_443 is.fi.un_850  hu.pt.un_550 nl.sw.un_770
  // [3570]
  0x0e0c1fad, 0x011f3fa0, 0x122104a0, 0x040c02a0,   // cy.sv.is_643 af.cy.en_322  fi.jw.hu_322 da.sv.fi_322
  0x1f006b04, 0x1f091007, 0x05002307, 0x1f002911,   // ceb.cy.un_320 lt.pl.cy_432  ca.fr.un_420 sl.cy.un_630
  0x051801a0, 0x181a21a0, 0x0a081008, 0x20000407,   // en.ga.fr_322 jw.tl.ga_322  be.uk.mk_443 fi.sq.un_420
  0x03051607, 0x1729040c, 0x20000113, 0x101617ee,   // hr.fr.nl_432 fi.sl.sr_543  en.sq.un_650 sr.hr.lt_422
  // [3580]
  0x186b01ec, 0x6b2028ee, 0x0b200704, 0x206e2804,   // en.ceb.ga_644 sw.sq.ceb_422  it.sq.es_332 sw.blu.sq_332
  0x53202908, 0x2a000107, 0x28000b02, 0x29000104,   // sl.sq.ht_443 en.mt.un_420  es.sw.un_220 en.sl.un_320
  0x1c006407, 0x09001605, 0x6e001805, 0x21290ba0,   // lg.id.un_420 hr.pl.un_330  ga.blu.un_330 es.sl.jw_322
  0x01201ba7, 0x08190b04, 0x0c1f0412, 0x27001820,   // tr.sq.en_532 es.gl.no_332  fi.cy.sv_654 ga.gd.un_850
  // [3590]
  0x2d161004, 0x20006407, 0x12552807, 0x271118af,   // lt.hr.sk_332 lg.sq.un_420  sw.rw.hu_432 ga.ro.gd_655
  0x2700011a, 0x2d001e04, 0x08001f19, 0x210119a0,   // en.gd.un_760 ms.sk.un_320  cy.no.un_750 gl.en.jw_322
  0x31182711, 0x1a006404, 0x1a001e04, 0x1e0e1c0c,   // gd.ga.az_653 lg.tl.un_320  ms.tl.un_320 id.is.ms_543
  0x6b0801a0, 0x01001f07, 0x080704ad, 0x0c00280d,   // en.no.ceb_322 cy.en.un_420  ru.bg.uk_643 sw.sv.un_540
  // [35a0]
  0x64002a07, 0x01000404, 0x2d0d1614, 0x0429120d,   // mt.lg.un_420 fi.en.un_320  hr.cs.sk_666 hu.sl.fi_554
  0x1327010c, 0x17000423, 0x18001f05, 0x552864a9,   // en.gd.et_543 ru.sr.un_880  cy.ga.un_330 lg.sw.rw_544
  0x31000f19, 0x042164ee, 0x13000611, 0x04071304,   // lv.az.un_750 lg.jw.fi_422  de.et.un_630 et.it.fi_332
  0x0c0206ee, 0x186e2805, 0x07041307, 0x64280107,   // de.da.sv_422 sw.blu.ga_333  et.fi.it_432 en.sw.lg_432
  // [35b0]
  0x13120ca7, 0x232a20a4, 0x0a0717ec, 0x16002514,   // sv.hu.et_532 sq.mt.ca_433  sr.bg.mk_644 eu.hr.un_660
  0x040e0c12, 0x1a1c1ea9, 0x17006e09, 0x0c6b1a07,   // sv.is.fi_654 ms.id.tl_544  blu.sr.un_440 tl.ceb.sv_432
  0x08001105, 0x09171608, 0x08000722, 0x04530504,   // ro.no.un_330 hr.sr.pl_443  bg.uk.un_870 fr.ht.fi_332
  0x3f000212, 0x291301a4, 0x2916010c, 0x1b231207,   // da.af.un_640 en.et.sl_433  en.hr.sl_543 hu.ca.tr_432
  // [35c0]
  0x12170d0c, 0x0c001104, 0x02001309, 0x13120108,   // cs.sr.hu_543 ro.sv.un_320  et.da.un_440 en.hu.et_443
  0x082a16af, 0x281e1c5a, 0x1c271e08, 0x27190b02,   // hr.mt.no_655 id.ms.sw_553  ms.gd.id_443 es.gl.gd_222
  0x28181fa6, 0x190a18ee, 0x2100011a, 0x0a5305af,   // cy.ga.sw_521 ga.pt.gl_422  en.jw.un_760 fr.ht.pt_655
  0x1f013fa9, 0x0105115a, 0x17166405, 0x0910250c,   // af.en.cy_544 ro.fr.en_553  lg.hr.sr_333 eu.lt.pl_543
  // [35d0]
  0x201c21ee, 0x13090dac, 0x10252da4, 0x09000122,   // jw.id.sq_422 ne.hi.bh_632  sk.eu.lt_433 en.pl.un_870
  0x19002508, 0x13002514, 0x0425640c, 0x2a1f01ec,   // eu.gl.un_430 eu.et.un_660  lg.eu.fi_543 en.cy.mt_644
  0x171628a0, 0x0000012d, 0x1b202507, 0x1f006404,   // sw.hr.sr_322 en.un.un_A00  eu.sq.tr_432 lg.cy.un_320
  0x1f000112, 0x13000122, 0x5513250d, 0x2a001a02,   // en.cy.un_640 en.et.un_870  eu.et.rw_554 tl.mt.un_220
  // [35e0]
  0x041117a9, 0x08003f09, 0x09002d04, 0x23022007,   // sr.ro.ru_544 af.no.un_440  sk.pl.un_320 sq.da.ca_432
  0x0b271807, 0x13190b04, 0x292010a4, 0x0c062508,   // ga.gd.es_432 es.gl.et_332  lt.sq.sl_433 eu.de.sv_443
  0x130804a9, 0x2d000f12, 0x0400171b, 0x25135512,   // fi.no.et_544 lv.sk.un_640  sr.ru.un_770 rw.et.eu_654
  0x0a0417ad, 0x102a25a4, 0x55130e07, 0x092a07ad,   // sr.ru.mk_643 eu.mt.lt_433  is.et.rw_432 it.mt.pl_643
  // [35f0]
  0x551613a0, 0x21131c08, 0x0504530c, 0x0d006b07,   // et.hr.rw_322 id.et.jw_443  ht.fi.fr_543 ceb.cs.un_420
  0x20250107, 0x0c030804, 0x022a250c, 0x0700100c,   // en.eu.sq_432 no.nl.sv_332  eu.mt.da_543 be.bg.un_530
  0x10080c08, 0x25000104, 0x1b00010d, 0x0308020d,   // sv.no.lt_443 en.eu.un_320  en.tr.un_540 da.no.nl_554
  0x01006e02, 0x2a2501a0, 0x030802af, 0x0a2301a4,   // blu.en.un_220 en.eu.mt_322  da.no.nl_655 en.ca.pt_433
  // [3600]
  0x25061b08, 0x0608030c, 0x08026e0c, 0x2164200d,   // tr.de.eu_443 nl.no.de_543  blu.da.no_543 sq.lg.jw_554
  0x232a18a4, 0x05003f04, 0x1f23250c, 0x64171608,   // ga.mt.ca_433 af.fr.un_320  eu.ca.cy_543 hr.sr.lg_443
  0x12250408, 0x53000914, 0x64001312, 0x090d1ca0,   // fi.eu.hu_443 pl.ht.un_660  et.lg.un_640 mr.ne.hi_322
  0x1e1a2102, 0x161827a0, 0x2a000d05, 0x020c08ee,   // jw.tl.ms_222 gd.ga.hr_322  cs.mt.un_330 no.sv.da_422
  // [3610]
  0x1b6b1a02, 0x121a6ba9, 0x00001924, 0x120420a4,   // tl.ceb.tr_222 ceb.tl.hu_544  gl.un.un_900 sq.fi.hu_433
  0x1a3f01ec, 0x18272313, 0x041023a0, 0x2d6e100c,   // en.af.tl_644 ca.gd.ga_665  ca.lt.fi_322 lt.blu.sk_543
  0x170a1013, 0x0a12190b, 0x536e1004, 0x0f00130c,   // be.mk.sr_665 gl.hu.pt_542  lt.blu.ht_332 et.lv.un_530
  0x1b002504, 0x23256ea7, 0x04006e07, 0x09001309,   // eu.tr.un_320 blu.eu.ca_532  blu.fi.un_420 bh.hi.un_440
  // [3620]
  0x120f0455, 0x0c1c080c, 0x070804ec, 0x20002805,   // fi.lv.hu_442 no.id.sv_543  ru.uk.bg_644 sw.sq.un_330
  0x20001804, 0x13000e13, 0x08001108, 0x071004ec,   // ga.sq.un_320 is.et.un_650  ro.uk.un_430 ru.be.bg_644
  0x0a202108, 0x090f0804, 0x08531c07, 0x0c080209,   // jw.sq.pt_443 no.lv.pl_332  id.ht.no_432 da.no.sv_444
  0x1a0a29a0, 0x04182755, 0x131e08ee, 0x0b000a21,   // sl.pt.tl_322 gd.ga.fi_442  no.ms.et_422 pt.es.un_860
  // [3630]
  0x310527a0, 0x0f000e1a, 0x08000418, 0x1a6455ad,   // gd.fr.az_322 is.lv.un_760  ru.uk.un_740 rw.lg.tl_643
  0x08000423, 0x1e001c22, 0x122321a0, 0x0b0a23a0,   // ru.uk.un_880 id.ms.un_870  jw.ca.hu_322 ca.pt.es_322
  0x0a002702, 0x07002008, 0x1b002009, 0x0b000a0c,   // gd.pt.un_220 sq.it.un_430  sq.tr.un_440 pt.es.un_530
  0x130431a0, 0x1c130d55, 0x310413a0, 0x090f1013,   // az.fi.et_322 ne.bh.mr_442  et.fi.az_322 lt.lv.pl_665
  // [3640]
  0x11170708, 0x190a0b0c, 0x210b2309, 0x101f28a7,   // bg.sr.ro_443 es.pt.gl_543  ca.es.jw_444 sw.cy.lt_532
  0x23002105, 0x0b000507, 0x23190b60, 0x25000b0d,   // jw.ca.un_330 fr.es.un_420  es.gl.ca_664 es.eu.un_540
  0x10080705, 0x0a081708, 0x100a0413, 0x19180b04,   // bg.uk.be_333 sr.uk.mk_443  ru.mk.be_665 es.ga.gl_332
  0x1c0d090d, 0x230b0e07, 0x12190b55, 0x070a0807,   // hi.ne.mr_554 is.es.ca_432  es.gl.hu_442 uk.mk.bg_432
  // [3650]
  0x0a08040c, 0x18002d0d, 0x13091cac, 0x28072d12,   // ru.uk.mk_543 sk.ga.un_540  mr.hi.bh_632 sk.it.sw_654
  0x081b12ad, 0x18001222, 0x1b000f04, 0x0f2531a7,   // hu.tr.no_643 ur.ar.un_870  lv.tr.un_320 az.eu.lv_532
  0x0b002508, 0x12190b02, 0x12190b04, 0x07171104,   // eu.es.un_430 es.gl.hu_222  es.gl.hu_332 ro.sr.bg_332
  0x12190b08, 0x20000708, 0x0b000a14, 0x040810a9,   // es.gl.hu_443 it.sq.un_430  pt.es.un_660 be.uk.ru_544
  // [3660]
  0x12001308, 0x13552808, 0x05232004, 0x021125a0,   // et.hu.un_430 sw.rw.et_443  sq.ca.fr_332 eu.ro.da_322
  0x281a6b60, 0x10000823, 0x11002d0c, 0x01050ba0,   // ceb.tl.sw_664 uk.be.un_880  sk.ro.un_530 es.fr.en_322
  0x04001719, 0x0a000413, 0x291619a0, 0x2d161aa7,   // sr.ru.un_750 ru.mk.un_650  gl.hr.sl_322 tl.hr.sk_532
  0x1c130daf, 0x20000b18, 0x281a6402, 0x2055110c,   // ne.bh.mr_655 es.sq.un_740  lg.tl.sw_222 ro.rw.sq_543
  // [3670]
  0x23111fa7, 0x05000414, 0x071101a0, 0x201b06a0,   // cy.ro.ca_532 fi.fr.un_660  en.ro.it_322 de.tr.sq_322
  0x1308040c, 0x0500120e, 0x05110708, 0x3f110405,   // fi.no.et_543 hu.fr.un_550  it.ro.fr_443 fi.ro.af_333
  0x1f001a1a, 0x1c281ea0, 0x27002b12, 0x07200fee,   // tl.cy.un_760 ms.sw.id_322  vi.gd.un_640 lv.sq.it_422
  0x01060712, 0x272b53af, 0x2b00531a, 0x281e1c60,   // it.de.en_654 ht.vi.gd_655  ht.vi.un_760 id.ms.sw_664
  // [3680]
  0x03020811, 0x25000705, 0x1117165a, 0x2b005321,   // no.da.nl_653 it.eu.un_330  hr.sr.ro_553 ht.vi.un_860
  0x051a6b0d, 0x2b002719, 0x05001912, 0x20003108,   // ceb.tl.fr_554 gd.vi.un_750  gl.fr.un_640 az.sq.un_430
  0x1b030aa0, 0x27532b07, 0x0717100c, 0x060e0408,   // pt.nl.tr_322 vi.ht.gd_432  be.sr.bg_543 fi.is.de_443
  0x201b09a4, 0x0d1617ec, 0x101304a4, 0x10000807,   // pl.tr.sq_433 sr.hr.cs_644  fi.et.lt_433 uk.be.un_420
  // [3690]
  0x07110a0b, 0x106b1c07, 0x08130404, 0x2b0753a9,   // mk.ro.bg_542 id.ceb.lt_432  fi.et.no_332 ht.it.vi_544
  0x29160d0d, 0x06000e0e, 0x53002b0d, 0x28001605,   // cs.hr.sl_554 is.de.un_550  vi.ht.un_540 hr.sw.un_330
  0x28001a05, 0x08070107, 0x2700030d, 0x29002819,   // tl.sw.un_330 en.it.no_432  nl.gd.un_540 sw.sl.un_750
  0x18080204, 0x0d280404, 0x64101a08, 0x2d002812,   // da.no.ga_332 fi.sw.cs_332  tl.lt.lg_443 sw.sk.un_640
  // [36a0]
  0x0c0801ee, 0x04033fa0, 0x06080204, 0x1c1e2812,   // en.no.sv_422 af.nl.fi_322  da.no.de_332 sw.ms.id_654
  0x21292811, 0x2d002908, 0x0a001f04, 0x2d0a0b07,   // sw.sl.jw_653 sl.sk.un_430  cy.pt.un_320 es.pt.sk_432
  0x2d640da0, 0x16120fa0, 0x0b0a23af, 0x0e551b12,   // cs.lg.sk_322 lv.hu.hr_322  ca.pt.es_655 tr.rw.is_654
  0x1b1711ee, 0x02002702, 0x0408170e, 0x64000408,   // ro.sr.tr_422 gd.da.un_220  sr.uk.ru_555 fi.lg.un_430
  // [36b0]
  0x190b0a0d, 0x29285507, 0x2916120c, 0x170f1604,   // pt.es.gl_554 rw.sw.sl_432  hu.hr.sl_543 hr.lv.sr_332
  0x12002704, 0x2800530c, 0x0c021f0c, 0x0d0829a0,   // gd.hu.un_320 ht.sw.un_530  cy.da.sv_543 sl.no.cs_322
  0x1b282a5a, 0x1e00110c, 0x100820ee, 0x1e006e0b,   // mt.sw.tr_553 ro.ms.un_530  sq.no.lt_422 blu.ms.un_520
  0x13043f08, 0x133f0304, 0x133f04ee, 0x03003f2a,   // af.fi.et_443 nl.af.et_332  fi.af.et_422 af.nl.un_970
  // [36c0]
  0x01286e07, 0x2a00070d, 0x0e001b0c, 0x07040811,   // blu.sw.en_432 it.mt.un_540  tr.is.un_530 uk.ru.bg_653
  0x03001a02, 0x1a00641a, 0x2a111eee, 0x050413a7,   // tl.nl.un_220 lg.tl.un_760  ms.ro.mt_422 et.fi.fr_532
  0x0c1f0907, 0x170a10a9, 0x0b0501a4, 0x28646b0c,   // pl.cy.sv_432 be.mk.sr_544  en.fr.es_433 ceb.lg.sw_543
  0x20000404, 0x2a00290c, 0x0d00110e, 0x17160902,   // fi.sq.un_320 sl.mt.un_530  ro.cs.un_550 pl.hr.sr_222
  // [36d0]
  0x04000c14, 0x046b1aa9, 0x291120a0, 0x2a0121ee,   // sv.fi.un_660 tl.ceb.fi_544  sq.ro.sl_322 jw.en.mt_422
  0x21136ba4, 0x090c13a4, 0x13002102, 0x2b002507,   // ceb.et.jw_433 et.sv.pl_433  jw.et.un_220 eu.vi.un_420
  0x281e2514, 0x29111aa0, 0x2a310c0c, 0x04002008,   // eu.ms.sw_666 tl.ro.sl_322  sv.az.mt_543 sq.fi.un_430
  0x080f1fa0, 0x12200812, 0x25005307, 0x211a6460,   // cy.lv.no_322 no.sq.hu_654  ht.eu.un_420 lg.tl.jw_664
  // [36e0]
  0x53002812, 0x02001002, 0x20051ea0, 0x13001c0c,   // sw.ht.un_640 lt.da.un_220  ms.fr.sq_322 mr.bh.un_530
  0x21645512, 0x550964ad, 0x201b05a4, 0x10292504,   // rw.lg.jw_654 lg.pl.rw_643  fr.tr.sq_433 eu.sl.lt_332
  0x29160da0, 0x1f002505, 0x20001f05, 0x17070a5a,   // cs.hr.sl_322 eu.cy.un_330  cy.sq.un_330 mk.bg.sr_553
  0x2021020c, 0x04071704, 0x21002005, 0x202d0d07,   // da.jw.sq_543 sr.bg.ru_332  sq.jw.un_330 cs.sk.sq_432
  // [36f0]
  0x080207ee, 0x05110d05, 0x160d0207, 0x080225a4,   // it.da.no_422 cs.ro.fr_333  da.cs.hr_432 eu.da.no_433
  0x0300120d, 0x06130804, 0x12081bec, 0x080204ee,   // hu.nl.un_540 no.et.de_332  tr.no.hu_644 fi.da.no_422
  0x2a020ca0, 0x2a0418a0, 0x31281e07, 0x64211aee,   // sv.da.mt_322 ga.fi.mt_322  ms.sw.az_432 tl.jw.lg_422
  0x3f21090c, 0x211a640c, 0x0b002312, 0x64312008,   // pl.jw.af_543 lg.tl.jw_543  ca.es.un_640 sq.az.lg_443
  // [3700]
  0x200802af, 0x080204a9, 0x0d000802, 0x0c2108a9,   // da.no.sq_655 fi.da.no_544  no.cs.un_220 no.jw.sv_544
  0x530e2804, 0x2b000207, 0x04002502, 0x2a0764ad,   // sw.is.ht_332 da.vi.un_420  eu.fi.un_220 lg.it.mt_643
  0x0d09060e, 0x16000207, 0x6b1a1f09, 0x6b1a1012,   // de.pl.cs_555 da.hr.un_420  cy.tl.ceb_444 lt.tl.ceb_654
  0x3f0e13a0, 0x0c00081b, 0x18001f13, 0x1e041ca4,   // et.is.af_322 no.sv.un_770  cy.ga.un_650 id.fi.ms_433
  // [3710]
  0x0b052107, 0x0e122ba0, 0x08101ba4, 0x18002813,   // jw.fr.es_432 vi.hu.is_322  tr.lt.no_433 sw.ga.un_650
  0x171f0da9, 0x281364a0, 0x16172907, 0x1300092b,   // cs.cy.sr_544 lg.et.sw_322  sl.sr.hr_432 hi.bh.un_980
  0x2104135a, 0x1a646ba7, 0x16001c13, 0x0e002b08,   // et.fi.jw_553 ceb.lg.tl_532  id.hr.un_650 vi.is.un_430
  0x111316a0, 0x03000a08, 0x0a182bec, 0x130203a9,   // hr.et.ro_322 pt.nl.un_430  vi.ga.pt_644 nl.da.et_544
  // [3720]
  0x0f000702, 0x0e04080d, 0x310f1ba6, 0x29000d19,   // it.lv.un_220 no.fi.is_554  tr.lv.az_521 cs.sl.un_750
  0x08001307, 0x64001a13, 0x01182707, 0x291617ee,   // et.no.un_420 tl.lg.un_650  gd.ga.en_432 sr.hr.sl_422
  0x251304af, 0x64005507, 0x211b1212, 0x3f281ba7,   // fi.et.eu_655 rw.lg.un_420  hu.tr.jw_654 tr.sw.af_532
  0x0e002d2a, 0x5300090d, 0x033f1f14, 0x0a0704ec,   // sk.is.un_970 pl.ht.un_540  cy.af.nl_666 ru.bg.mk_644
  // [3730]
  0x1b3129ee, 0x2a001607, 0x03080408, 0x551a6408,   // sl.az.tr_422 hr.mt.un_420  fi.no.nl_443 lg.tl.rw_443
  0x211329af, 0x136b1a08, 0x2800640c, 0x18001905,   // sl.et.jw_655 tl.ceb.et_443  lg.sw.un_530 gl.ga.un_330
  0x030701af, 0x2b002804, 0x09000114, 0x02002804,   // en.it.nl_655 sw.vi.un_320  en.pl.un_660 sw.da.un_320
  0x132511a4, 0x2a000e05, 0x27001f1b, 0x1e1a6bee,   // ro.eu.et_433 is.mt.un_330  cy.gd.un_770 ceb.tl.ms_422
  // [3740]
  0x21556404, 0x17080a07, 0x6b645555, 0x0f002909,   // lg.rw.jw_332 mk.uk.sr_432  rw.lg.ceb_442 sl.lv.un_440
  0x0f6b11af, 0x01060d05, 0x0a00210d, 0x292304ee,   // ro.ceb.lv_655 cs.de.en_333  jw.pt.un_540 fi.ca.sl_422
  0x01041105, 0x0e12230c, 0x08200304, 0x25050b07,   // ro.fi.en_333 ca.hu.is_543  nl.sq.no_332 es.fr.eu_432
  0x25112004, 0x100f1304, 0x23190b14, 0x100f13ad,   // sq.ro.eu_332 et.lv.lt_332  es.gl.ca_666 et.lv.lt_643
  // [3750]
  0x0c231113, 0x0c020e0c, 0x11002314, 0x2a0c040c,   // ro.ca.sv_665 is.da.sv_543  ca.ro.un_660 fi.sv.mt_543
  0x3f030107, 0x042d0da9, 0x111008a4, 0x211a0cee,   // en.nl.af_432 cs.sk.fi_544  uk.be.ro_433 sv.tl.jw_422
  0x0b0a180c, 0x0e1f0ca4, 0x181b0a04, 0x0c6b2307,   // ga.pt.es_543 sv.cy.is_433  pt.tr.ga_332 ca.ceb.sv_432
  0x3f001218, 0x1b0c06ee, 0x231901ee, 0x0b0a0514,   // hu.af.un_740 de.sv.tr_422  en.gl.ca_422 fr.pt.es_666
  // [3760]
  0x041a13a0, 0x13001a1a, 0x05001904, 0x1a0f04a0,   // et.tl.fi_322 tl.et.un_760  gl.fr.un_320 fi.lv.tl_322
  0x23130f07, 0x031f1b0c, 0x0e0803ad, 0x112a23a4,   // lv.et.ca_432 tr.cy.nl_543  nl.no.is_643 ca.mt.ro_433
  0x1b001705, 0x1b531f0c, 0x3f000c0c, 0x1600172b,   // sr.tr.un_330 cy.ht.tr_543  sv.af.un_530 sr.hr.un_980
  0x12050a07, 0x1f001105, 0x0b001112, 0x211b12a0,   // pt.fr.hu_432 ro.cy.un_330  ro.es.un_640 hu.tr.jw_322
  // [3770]
  0x112706ee, 0x281809a4, 0x28645504, 0x3f2a1f07,   // de.gd.ro_422 pl.ga.sw_433  rw.lg.sw_332 cy.mt.af_432
  0x033f640e, 0x250655a9, 0x5500280e, 0x063f0307,   // lg.af.nl_555 rw.de.eu_544  sw.rw.un_550 nl.af.de_432
  0x201b1f07, 0x0d091c12, 0x282064a4, 0x281e6405,   // cy.tr.sq_432 mr.hi.ne_654  lg.sq.sw_433 lg.ms.sw_333
  0x6b091a04, 0x1f170608, 0x0b0a23a4, 0x1a3f640d,   // tl.pl.ceb_332 de.sr.cy_443  ca.pt.es_433 lg.af.tl_554
  // [3780]
  0x13000f08, 0x060d2ba0, 0x64255512, 0x53130f55,   // lv.et.un_430 vi.cs.de_322  rw.eu.lg_654 lv.et.ht_442
  0x0f001312, 0x033f04a7, 0x1b005313, 0x081727a0,   // et.lv.un_640 fi.af.nl_532  ht.tr.un_650 gd.sr.no_322
  0x292d0d0e, 0x0c00080d, 0x0f171612, 0x53000512,   // cs.sk.sl_555 no.sv.un_540  hr.sr.lv_654 fr.ht.un_640
  0x03080604, 0x291f01a0, 0x642853ec, 0x191e01a4,   // de.no.nl_332 en.cy.sl_322  ht.sw.lg_644 en.ms.gl_433
  // [3790]
  0x5500111a, 0x205525a9, 0x3f036412, 0x1e061c0c,   // ro.rw.un_760 eu.rw.sq_544  lg.nl.af_654 id.de.ms_543
  0x64001602, 0x0f000614, 0x1c033f07, 0x090106a0,   // hr.lg.un_220 de.lv.un_660  af.nl.id_432 de.en.pl_322
  0x1c211eee, 0x130504a6, 0x08002904, 0x1b005308,   // ms.jw.id_422 fi.fr.et_521  sl.no.un_320 ht.tr.un_430
  0x640804ee, 0x0a110705, 0x022706a0, 0x1008045a,   // fi.no.lg_422 bg.ro.mk_333  de.gd.da_322 ru.uk.be_553
  // [37a0]
  0x180727a0, 0x6b006e09, 0x2b001107, 0x07041707,   // gd.it.ga_322 blu.ceb.un_440  ro.vi.un_420 sr.ru.bg_432
  0x182112a4, 0x1c002702, 0x010e6407, 0x0d000612,   // ur.fa.ar_433 gd.id.un_220  lg.is.en_432 de.cs.un_640
  0x0a23010c, 0x0e030613, 0x162d10a4, 0x2b1a1307,   // en.ca.pt_543 de.nl.is_665  lt.sk.hr_433 et.tl.vi_432
  0x170b16a4, 0x051b3f04, 0x03040804, 0x6b002708,   // hr.es.sr_433 af.tr.fr_332  no.fi.nl_332 gd.ceb.un_430
  // [37b0]
  0x646b215a, 0x0c061f11, 0x01193104, 0x27186408,   // jw.ceb.lg_553 cy.de.sv_653  az.gl.en_332 lg.ga.gd_443
  0x022a64a0, 0x0d0153af, 0x21000f12, 0x6400310e,   // lg.mt.da_322 ht.en.cs_655  lv.jw.un_640 az.lg.un_550
  0x0f102daf, 0x05531107, 0x3f09030c, 0x18000511,   // sk.lt.lv_655 ro.ht.fr_432  nl.pl.af_543 fr.ga.un_630
  0x2a0925a0, 0x0a052307, 0x06003f22, 0x092901a0,   // eu.pl.mt_322 ca.fr.pt_432  af.de.un_870 en.sl.pl_322
  // [37c0]
  0x5313040c, 0x0f0407a0, 0x101716ee, 0x130d090b,   // fi.et.ht_543 it.fi.lv_322  hr.sr.lt_422 hi.ne.bh_542
  0x291617a0, 0x06030e0c, 0x640128a0, 0x290c080c,   // sr.hr.sl_322 is.nl.de_543  sw.en.lg_322 no.sv.sl_543
  0x13251a08, 0x07100f07, 0x0b072d0c, 0x17002908,   // tl.eu.et_443 lv.lt.it_432  sk.it.es_543 sl.sr.un_430
  0x07000f0c, 0x2b100f13, 0x0603090c, 0x04002d1a,   // lv.it.un_530 lv.lt.vi_665  pl.nl.de_543 sk.fi.un_760
  // [37d0]
  0x12000a09, 0x09002912, 0x02060402, 0x11041012,   // pt.hu.un_440 sl.pl.un_640  fi.de.da_222 be.ru.ro_654
  0x1c641ea4, 0x081711a7, 0x0500210d, 0x10070a08,   // ms.lg.id_433 ro.sr.uk_532  jw.fr.un_540 mk.bg.be_443
  0x08110a08, 0x17162505, 0x0c130404, 0x1c281ea4,   // mk.ro.uk_443 eu.hr.sr_333  fi.et.sv_332 ms.sw.id_433
  0x21066ba0, 0x0d1c0913, 0x31112dee, 0x55002102,   // ceb.de.jw_322 hi.mr.ne_665  sk.ro.az_422 jw.rw.un_220
  // [37e0]
  0x282155a4, 0x17110aa4, 0x55286407, 0x041323a0,   // rw.jw.sw_433 mk.ro.sr_433  lg.sw.rw_432 ca.et.fi_322
  0x55280912, 0x1c231104, 0x11005308, 0x0411070d,   // pl.sw.rw_654 ro.ca.id_332  ht.ro.un_430 bg.ro.ru_554
  0x09001c0e, 0x02000607, 0x0a07170b, 0x0f25110b,   // mr.hi.un_550 de.da.un_420  sr.bg.mk_542 ro.eu.lv_542
  0x11072912, 0x13001104, 0x55281aaf, 0x072025ad,   // sl.it.ro_654 ro.et.un_320  tl.sw.rw_655 eu.sq.it_643
  // [37f0]
  0x042531a7, 0x01063f04, 0x28215504, 0x23201108,   // az.eu.fi_532 af.de.en_332  rw.jw.sw_332 ro.sq.ca_443
  0x6455530d, 0x11232509, 0x132311a0, 0x04081205,   // ht.rw.lg_554 eu.ca.ro_444  ro.ca.et_322 hu.no.fi_333
  0x070a0809, 0x1c1b1e0c, 0x23001114, 0x21101ca0,   // uk.mk.bg_444 ms.tr.id_543  ro.ca.un_660 id.lt.jw_322
  0x012a04a0, 0x0a0512a0, 0x092d0d0d, 0x03080cee,   // fi.mt.en_322 hu.fr.pt_322  cs.sk.pl_554 sv.no.nl_422

  // [3800]
  0x0b00230c, 0x132311a9, 0x17201604, 0x1a1c1ba0,   // ca.es.un_530 ro.ca.et_544  hr.sq.sr_332 tr.id.tl_322
  0x0a0407af, 0x04000b02, 0x091604ee, 0x290806ee,   // bg.ru.mk_655 es.fi.un_220  fi.hr.pl_422 de.no.sl_422
  0x1006040c, 0x3f002b22, 0x1a2804ee, 0x10040f12,   // fi.de.lt_543 vi.af.un_870  fi.sw.tl_422 lv.fi.lt_654
  0x0400250c, 0x2b003f09, 0x3f0c0607, 0x2b000a13,   // eu.fi.un_530 af.vi.un_440  de.sv.af_432 pt.vi.un_650
  // [3810]
  0x08170a07, 0x07001102, 0x19230ba7, 0x230b180c,   // mk.sr.uk_432 ro.it.un_220  es.ca.gl_532 ga.es.ca_543
  0x2d002012, 0x25000a04, 0x10000411, 0x0a002b07,   // sq.sk.un_640 pt.eu.un_320  fi.lt.un_630 vi.pt.un_420
  0x0500180d, 0x04100f13, 0x2b000a12, 0x0a002b0d,   // ga.fr.un_540 lv.lt.fi_665  pt.vi.un_640 vi.pt.un_540
  0x076405a0, 0x251617a7, 0x0d0521a0, 0x21001818,   // fr.lg.it_322 sr.hr.eu_532  jw.fr.cs_322 ar.fa.un_740
  // [3820]
  0x0a230107, 0x04100807, 0x0a05645a, 0x041f6b0c,   // en.ca.pt_432 uk.be.ru_432  lg.fr.pt_553 ceb.cy.fi_543
  0x110b1907, 0x1f011ea4, 0x0500180c, 0x25001808,   // gl.es.ro_432 ms.en.cy_433  ga.fr.un_530 ga.eu.un_430
  0x04001c08, 0x1e001c0d, 0x04003f02, 0x1a006e0c,   // id.fi.un_430 id.ms.un_540  af.fi.un_220 blu.tl.un_530
  0x281301a0, 0x04532107, 0x070417ad, 0x28000f02,   // en.et.sw_322 jw.ht.fi_432  sr.ru.bg_643 lv.sw.un_220
  // [3830]
  0x3f0c0307, 0x17111612, 0x08170402, 0x1b003111,   // nl.sv.af_432 hr.ro.sr_654  ru.sr.uk_222 az.tr.un_630
  0x281304ec, 0x071004a0, 0x3f2d03a0, 0x04130fa0,   // fi.et.sw_644 ru.be.bg_322  nl.sk.af_322 lv.et.fi_322
  0x0c0704af, 0x0600080d, 0x6b001a1b, 0x041f20a0,   // fi.it.sv_655 no.de.un_540  tl.ceb.un_770 sq.cy.fi_322
  0x180a055e, 0x10170a12, 0x17160f0b, 0x070411a0,   // fr.pt.ga_652 mk.sr.be_654  lv.hr.sr_542 ro.ru.bg_322
  // [3840]
  0x25101b0c, 0x12250e04, 0x02002104, 0x1b0109a0,   // tr.lt.eu_543 is.eu.hu_332  jw.da.un_320 pl.en.tr_322
  0x110e0fa4, 0x0e040c04, 0x28532004, 0x0a1101a7,   // lv.is.ro_433 sv.fi.is_332  sq.ht.sw_332 en.ro.pt_532
  0x200625a0, 0x190b08a4, 0x091c0d05, 0x071708a4,   // eu.de.sq_322 no.es.gl_433  ne.mr.hi_333 uk.sr.bg_433
  0x551a20a0, 0x232105af, 0x101a0407, 0x3f04030c,   // sq.tl.rw_322 fr.jw.ca_655  fi.tl.lt_432 nl.fi.af_543
  // [3850]
  0x53002107, 0x070a1760, 0x01045507, 0x0e210c02,   // jw.ht.un_420 sr.mk.bg_664  rw.fi.en_432 sv.jw.is_222
  0x0602080c, 0x1a001105, 0x1a0321a7, 0x20251b0c,   // no.da.de_543 ro.tl.un_330  jw.nl.tl_532 tr.eu.sq_543
  0x060e08a4, 0x0f030607, 0x20011205, 0x53041ba4,   // no.is.de_433 de.nl.lv_432  hu.en.sq_333 tr.fi.ht_433
  0x0b0a16a9, 0x201225a4, 0x0e000508, 0x03060f12,   // hr.pt.es_544 eu.hu.sq_433  fr.is.un_430 lv.de.nl_654
  // [3860]
  0x3f200107, 0x060c0eaf, 0x0a110d04, 0x21000813,   // en.sq.af_432 is.sv.de_655  cs.ro.pt_332 no.jw.un_650
  0x1a212007, 0x1c001a0c, 0x28253108, 0x28001b18,   // sq.jw.tl_432 tl.id.un_530  az.eu.sw_443 tr.sw.un_740
  0x196b25ee, 0x040a0805, 0x0a070405, 0x18282707,   // eu.ceb.gl_422 uk.mk.ru_333  ru.bg.mk_333 gd.sw.ga_432
  0x5321640c, 0x312520ad, 0x030f06ee, 0x060e0308,   // lg.jw.ht_543 sq.eu.az_643  de.lv.nl_422 nl.is.de_443
  // [3870]
  0x0c1306ad, 0x2500270e, 0x1200212c, 0x0e1e0504,   // de.et.sv_643 gd.eu.un_550  fa.ur.un_990 fr.ms.is_332
  0x09000d20, 0x180b270c, 0x081104af, 0x13000d21,   // ne.hi.un_850 gd.es.ga_543  ru.ro.uk_655 ne.bh.un_860
  0x0b5328ac, 0x062d0d04, 0x532305a0, 0x18122707,   // sw.ht.es_632 cs.sk.de_332  fr.ca.ht_322 gd.hu.ga_432
  0x06193f07, 0x210212a6, 0x3f00070c, 0x060c6b08,   // af.gl.de_432 hu.da.jw_521  it.af.un_530 ceb.sv.de_443
  // [3880]
  0x28271204, 0x11072a0c, 0x121a6bee, 0x031f3f02,   // hu.gd.sw_332 mt.it.ro_543  ceb.tl.hu_422 af.cy.nl_222
  0x6b131a0c, 0x6b211e0c, 0x2a003108, 0x063f5507,   // tl.et.ceb_543 ms.jw.ceb_543  az.mt.un_430 rw.af.de_432
  0x01552504, 0x01002702, 0x02121f0c, 0x1a010c04,   // eu.rw.en_332 gd.en.un_220  cy.hu.da_543 sv.en.tl_332
  0x162920a0, 0x13033f13, 0x03073f0c, 0x1e2d0d55,   // sq.sl.hr_322 af.nl.et_665  af.it.nl_543 cs.sk.ms_442
  // [3890]
  0x186b010b, 0x271801ad, 0x53001b0d, 0x1c000919,   // en.ceb.ga_542 en.ga.gd_643  tr.ht.un_540 hi.mr.un_750
  0x29121ea0, 0x080c0612, 0x6b5301a4, 0x112b31a0,   // ms.hu.sl_322 de.sv.no_654  en.ht.ceb_433 az.vi.ro_322
  0x11003107, 0x0400031b, 0x531a1e08, 0x043f1312,   // az.ro.un_420 nl.fi.un_770  ms.tl.ht_443 et.af.fi_654
  0x09002d09, 0x0a1117a4, 0x0600100c, 0x13043f04,   // sk.pl.un_440 sr.ro.mk_433  lt.de.un_530 af.fi.et_332
  // [38a0]
  0x31002a0e, 0x0c3106ec, 0x04070812, 0x07271004,   // mt.az.un_550 de.az.sv_644  uk.bg.ru_654 lt.gd.it_332
  0x08005312, 0x0f006402, 0x0a04100c, 0x130e0c11,   // ht.no.un_640 lg.lv.un_220  be.ru.mk_543 sv.is.et_653
  0x1e092807, 0x09000704, 0x27006b0e, 0x10080704,   // sw.pl.ms_432 it.pl.un_320  ceb.gd.un_550 bg.uk.be_332
  0x1000082b, 0x13285508, 0x11642807, 0x210c0607,   // uk.be.un_980 rw.sw.et_443  sw.lg.ro_432 de.sv.jw_432
  // [38b0]
  0x1b001309, 0x6b251aa0, 0x1c001e2a, 0x53110aad,   // et.tr.un_440 tl.eu.ceb_322  ms.id.un_970 pt.ro.ht_643
  0x10002704, 0x200828a4, 0x3f0304af, 0x21001822,   // gd.lt.un_320 sw.no.sq_433  fi.nl.af_655 ar.fa.un_870
  0x212707ad, 0x03080204, 0x181b1e09, 0x17000a07,   // it.gd.jw_643 da.no.nl_332  ms.tr.ga_444 mk.sr.un_420
  0x19002304, 0x122d29a0, 0x1c130da0, 0x1e211c08,   // ca.gl.un_320 sl.sk.hu_322  ne.bh.mr_322 id.jw.ms_443
  // [38c0]
  0x03000704, 0x1e281c0c, 0x121b3104, 0x10080a07,   // it.nl.un_320 id.sw.ms_543  az.tr.hu_332 mk.uk.be_432
  0x10171614, 0x11000a2a, 0x53000a02, 0x07040a07,   // hr.sr.lt_666 mk.ro.un_970  pt.ht.un_220 mk.ru.bg_432
  0x08003109, 0x2a000108, 0x043f080b, 0x29001705,   // az.no.un_440 en.mt.un_430  no.af.fi_542 sr.sl.un_330
  0x080f100c, 0x08021aec, 0x21002011, 0x1b000613,   // lt.lv.no_543 tl.da.no_644  sq.jw.un_630 de.tr.un_650
  // [38d0]
  0x080417a4, 0x0b000107, 0x04100707, 0x53006408,   // sr.ru.uk_433 en.es.un_420  bg.be.ru_432 lg.ht.un_430
  0x2b1204ec, 0x072127ad, 0x25072a55, 0x16021707,   // fi.hu.vi_644 gd.jw.it_643  mt.it.eu_442 sr.da.hr_432
  0x21201255, 0x2d162804, 0x0f001022, 0x02031faf,   // hu.sq.jw_442 sw.hr.sk_332  lt.lv.un_870 cy.nl.da_655
  0x122a1e5a, 0x6e033f0c, 0x53000d21, 0x08041012,   // ms.mt.hu_553 af.nl.blu_543  cs.ht.un_860 be.ru.uk_654
  // [38e0]
  0x12182705, 0x2d050da6, 0x1200020c, 0x1c081fee,   // gd.ga.hu_333 cs.fr.sk_521  da.hu.un_530 cy.no.id_422
  0x530620a4, 0x0400250e, 0x10120412, 0x0a100704,   // sq.de.ht_433 eu.fi.un_550  fi.hu.lt_654 bg.be.mk_332
  0x04231208, 0x29090d09, 0x04070805, 0x3f000334,   // hu.ca.fi_443 cs.pl.sl_444  uk.bg.ru_333 nl.af.un_A80
  0x201b5312, 0x13001e1a, 0x1b2012ee, 0x0f172904,   // ht.tr.sq_654 ms.et.un_760  hu.sq.tr_422 sl.sr.lv_332
  // [38f0]
  0x02002a0e, 0x04121ba0, 0x3f001205, 0x180c08a0,   // mt.da.un_550 tr.hu.fi_322  hu.af.un_330 no.sv.ga_322
  0x1a030e04, 0x12002012, 0x642b1204, 0x0d080c02,   // is.nl.tl_332 sq.hu.un_640  hu.vi.lg_332 sv.no.cs_222
  0x64006b09, 0x1a6b0b12, 0x0c1904a9, 0x2a001f02,   // ceb.lg.un_440 es.ceb.tl_654  fi.gl.sv_544 cy.mt.un_220
  0x01210607, 0x1f001819, 0x6b210fa9, 0x282a64a7,   // de.jw.en_432 ga.cy.un_750  lv.jw.ceb_544 lg.mt.sw_532
  // [3900]
  0x1c00250c, 0x0705020c, 0x061f3fa4, 0x10171660,   // eu.id.un_530 da.fr.it_543  af.cy.de_433 hr.sr.lt_664
  0x1300640c, 0x05002002, 0x161f0402, 0x64001a09,   // lg.et.un_530 sq.fr.un_220  fi.cy.hr_222 tl.lg.un_440
  0x0e005519, 0x1f001807, 0x0b006b04, 0x042a1304,   // rw.is.un_750 ga.cy.un_420  ceb.es.un_320 et.mt.fi_332
  0x03001002, 0x08000218, 0x1100210d, 0x01211c02,   // lt.nl.un_220 da.no.un_740  jw.ro.un_540 id.jw.en_222
  // [3910]
  0x12171605, 0x1b1a6b11, 0x083f03ad, 0x05000c04,   // hr.sr.hu_333 ceb.tl.tr_653  nl.af.no_643 sv.fr.un_320
  0x0000132d, 0x2b6e0104, 0x05006404, 0x01000907,   // et.un.un_A00 en.blu.vi_332  lg.fr.un_320 pl.en.un_420
  0x13001f08, 0x1f000c12, 0x172d16a7, 0x13002d04,   // cy.et.un_430 sv.cy.un_640  hr.sk.sr_532 sk.et.un_320
  0x160d170c, 0x190b10a9, 0x31002a19, 0x281364ad,   // sr.cs.hr_543 lt.es.gl_544  mt.az.un_750 lg.et.sw_643
  // [3920]
  0x19100b0c, 0x010c06a0, 0x6406550c, 0x1b3125a9,   // es.lt.gl_543 de.sv.en_322  rw.de.lg_543 eu.az.tr_544
  0x040a170c, 0x12006409, 0x081f01a4, 0x0f000d0e,   // sr.mk.ru_543 lg.hu.un_440  en.cy.no_433 cs.lv.un_550
  0x060c04ee, 0x13000c1a, 0x05001f13, 0x1a001005,   // fi.sv.de_422 sv.et.un_760  cy.fr.un_650 lt.tl.un_330
  0x0400071a, 0x3f002807, 0x162d290d, 0x09001214,   // bg.ru.un_760 sw.af.un_420  sl.sk.hr_554 hu.pl.un_660
  // [3930]
  0x0a070504, 0x08000e05, 0x160928a4, 0x0d1c0908,   // fr.it.pt_332 is.no.un_330  sw.pl.hr_433 hi.mr.ne_443
  0x2a000612, 0x04060c09, 0x0800071b, 0x11030e0c,   // de.mt.un_640 sv.de.fi_444  bg.uk.un_770 is.nl.ro_543
  0x1316170b, 0x3f1303af, 0x212528a0, 0x25001e04,   // sr.hr.et_542 nl.et.af_655  sw.eu.jw_322 ms.eu.un_320
  0x04000512, 0x01001211, 0x04001a04, 0x06001312,   // fr.fi.un_640 hu.en.un_630  tl.fi.un_320 et.de.un_640
  // [3940]
  0x29281714, 0x282a0107, 0x0c0208a0, 0x040807af,   // sr.sw.sl_666 en.mt.sw_432  no.da.sv_322 bg.uk.ru_655
  0x200801a0, 0x07000804, 0x06311b08, 0x1f001014,   // en.no.sq_322 no.it.un_320  tr.az.de_443 lt.cy.un_660
  0x1f2d1807, 0x530f2107, 0x100b08a0, 0x0f2d21a4,   // ga.sk.cy_432 jw.lv.ht_432  no.es.lt_322 jw.sk.lv_433
  0x0a121004, 0x13003f05, 0x12000808, 0x2d0113ee,   // lt.hu.pt_332 af.et.un_330  no.hu.un_430 et.en.sk_422
  // [3950]
  0x1e6b1a0d, 0x0a0725a0, 0x1f000304, 0x063f0312,   // tl.ceb.ms_554 eu.it.pt_322  nl.cy.un_320 nl.af.de_654
  0x530e1fa9, 0x3100050e, 0x100f09a4, 0x1629170c,   // cy.is.ht_544 fr.az.un_550  pl.lv.lt_433 sr.sl.hr_543
  0x0f000304, 0x1b000619, 0x2d00230d, 0x0a17080c,   // nl.lv.un_320 de.tr.un_750  ca.sk.un_540 uk.sr.mk_543
  0x1f001704, 0x17000a20, 0x210d0aa0, 0x2813100e,   // sr.cy.un_320 mk.sr.un_850  pt.cs.jw_322 lt.et.sw_555
  // [3960]
  0x236b1a0e, 0x070411ad, 0x0c060202, 0x25000113,   // tl.ceb.ca_555 ro.ru.bg_643  da.de.sv_222 en.eu.un_650
  0x102d01a4, 0x0b000702, 0x19311b07, 0x100811ec,   // en.sk.lt_433 it.es.un_220  tr.az.gl_432 ro.uk.be_644
  0x0e111fad, 0x0f000e13, 0x09001008, 0x061b3111,   // cy.ro.is_643 is.lv.un_650  lt.pl.un_430 az.tr.de_653
  0x20032904, 0x6b001023, 0x061210ee, 0x29101609,   // sl.nl.sq_332 lt.ceb.un_880  lt.hu.de_422 hr.lt.sl_444
  // [3970]
  0x170a0802, 0x0c2012a7, 0x6b001012, 0x1e190b05,   // uk.mk.sr_222 hu.sq.sv_532  lt.ceb.un_640 es.gl.ms_333
  0x04170a0e, 0x0f00102a, 0x2a001b1a, 0x101629a7,   // mk.sr.ru_555 lt.lv.un_970  tr.mt.un_760 sl.hr.lt_532
  0x191729a4, 0x1c1309ac, 0x2100130d, 0x1e1c1a0c,   // sl.sr.gl_433 hi.bh.mr_632  et.jw.un_540 tl.id.ms_543
  0x17100707, 0x03000402, 0x1a280a07, 0x20000c12,   // bg.be.sr_432 fi.nl.un_220  pt.sw.tl_432 sv.sq.un_640
  // [3980]
  0x2900100c, 0x2d000804, 0x04171112, 0x291055ad,   // lt.sl.un_530 no.sk.un_320  ro.sr.ru_654 rw.lt.sl_643
  0x110553a0, 0x07002908, 0x10552805, 0x0d002002,   // ht.fr.ro_322 sl.it.un_430  sw.rw.lt_333 sq.cs.un_220
  0x04033fa9, 0x0d001322, 0x530d04ad, 0x3f006407,   // af.nl.fi_544 bh.ne.un_870  fi.cs.ht_643 lg.af.un_420
  0x0c001c05, 0x17160305, 0x040c0dee, 0x1629170d,   // id.sv.un_330 nl.hr.sr_333  cs.sv.fi_422 sr.sl.hr_554
  // [3990]
  0x016b1aec, 0x2718280c, 0x311b11ad, 0x12000104,   // tl.ceb.en_644 sw.ga.gd_543  ro.tr.az_643 en.hu.un_320
  0x06000e02, 0x0a100714, 0x3f0328ee, 0x0804110d,   // is.de.un_220 bg.be.mk_666  sw.nl.af_422 ro.ru.uk_554
  0x28006404, 0x3f035507, 0x1b1c1eec, 0x18000507,   // lg.sw.un_320 rw.nl.af_432  ms.id.tr_644 fr.ga.un_420
  0x033f13a7, 0x0800040c, 0x13050708, 0x3f036407,   // et.af.nl_532 ru.uk.un_530  it.fr.et_443 lg.nl.af_432
  // [39a0]
  0x12536408, 0x10070855, 0x1600290c, 0x23001321,   // lg.ht.hu_443 uk.bg.be_442  sl.hr.un_530 et.ca.un_860
  0x1b643104, 0x1b2a10a0, 0x070301a4, 0x0000642d,   // az.lg.tr_332 lt.mt.tr_322  en.nl.it_433 lg.un.un_A00
  0x286b1aa4, 0x0a006404, 0x06003f23, 0x09005307,   // tl.ceb.sw_433 lg.pt.un_320  af.de.un_880 ht.pl.un_420
  0x641e2804, 0x2d3f29a4, 0x55282707, 0x040c0e04,   // sw.ms.lg_332 sl.af.sk_433  gd.sw.rw_432 is.sv.fi_332
  // [39b0]
  0x640413ad, 0x12006413, 0x06130c11, 0x28002502,   // et.fi.lg_643 lg.hu.un_650  sv.et.de_653 eu.sw.un_220
  0x100c1304, 0x0c5508a4, 0x2d16090d, 0x2100270c,   // et.sv.lt_332 no.rw.sv_433  pl.hr.sk_554 gd.jw.un_530
  0x191e0ba4, 0x1b080e07, 0x09291605, 0x162917ad,   // es.ms.gl_433 is.no.tr_432  hr.sl.pl_333 sr.sl.hr_643
  0x17161114, 0x02002902, 0x1c0d09a7, 0x1100171a,   // ro.hr.sr_666 sl.da.un_220  hi.ne.mr_532 sr.ro.un_760
  // [39c0]
  0x102d0d04, 0x1e1c2107, 0x01130813, 0x280855a4,   // cs.sk.lt_332 jw.id.ms_432  no.et.en_665 rw.no.sw_433
  0x0b07040e, 0x21006b04, 0x01003104, 0x0c190b0d,   // fi.it.es_555 ceb.jw.un_320  az.en.un_320 es.gl.sv_554
  0x21002b05, 0x03043f0d, 0x080c1204, 0x2a072707,   // vi.jw.un_330 af.fi.nl_554  hu.sv.no_332 gd.it.mt_432
  0x04033f08, 0x11190a12, 0x03640402, 0x6b001a21,   // af.nl.fi_443 pt.gl.ro_654  fi.lg.nl_222 tl.ceb.un_860
  // [39d0]
  0x190b2308, 0x033f13af, 0x271304a0, 0x0e3f64a0,   // ca.es.gl_443 et.af.nl_655  fi.et.gd_322 lg.af.is_322
  0x04033f07, 0x0b0a18ac, 0x27011fa0, 0x06006b07,   // af.nl.fi_432 ga.pt.es_632  cy.en.gd_322 ceb.de.un_420
  0x08070a14, 0x070a1013, 0x04081109, 0x08000721,   // mk.bg.uk_666 be.mk.bg_665  ro.uk.ru_444 it.no.un_860
  0x043f0305, 0x061e6ea4, 0x04133f05, 0x133f0308,   // nl.af.fi_333 blu.ms.de_433  af.et.fi_333 nl.af.et_443
  // [39e0]
  0x18192aa0, 0x033f1307, 0x1f002107, 0x1306040d,   // mt.gl.ga_322 et.af.nl_432  jw.cy.un_420 fi.de.et_554
  0x2a2506a0, 0x1800210b, 0x1221185a, 0x11001704,   // de.eu.mt_322 fa.ar.un_520  ar.fa.ur_553 sr.ro.un_320
  0x04080702, 0x17002907, 0x00002924, 0x0e130807,   // bg.uk.ru_222 sl.sr.un_420  sl.un.un_900 no.et.is_432
  0x18002d08, 0x6e000512, 0x6b002513, 0x1000310e,   // sk.ga.un_430 fr.blu.un_640  eu.ceb.un_650 az.lt.un_550
  // [39f0]
  0x6b641a12, 0x131c21a0, 0x13001c05, 0x041011a9,   // tl.lg.ceb_654 jw.id.et_322  id.et.un_330 ro.be.ru_544
  0x2b001a07, 0x0c6b10a4, 0x1e1c1a0e, 0x211a6407,   // tl.vi.un_420 lt.ceb.sv_433  tl.id.ms_555 lg.tl.jw_432
  0x121c1eaf, 0x2013040c, 0x04081709, 0x033f0daf,   // ms.id.hu_655 fi.et.sq_543  sr.uk.ru_444 cs.af.nl_655
  0x0f00030d, 0x311e1c08, 0x126e21a0, 0x231c1e0c,   // nl.lv.un_540 id.ms.az_443  jw.blu.hu_322 ms.id.ca_543
  // [3a00]
  0x2300112b, 0x16292da0, 0x13002008, 0x2b645513,   // ro.ca.un_980 sk.sl.hr_322  sq.et.un_430 rw.lg.vi_665
  0x6b551a0c, 0x1b3111af, 0x28001112, 0x0c0213a7,   // tl.rw.ceb_543 ro.az.tr_655  ro.sw.un_640 et.da.sv_532
  0x25120da4, 0x0203060c, 0x0a000f07, 0x05001a09,   // cs.hu.eu_433 de.nl.da_543  lv.pt.un_420 tl.fr.un_440
  0x311b1ea4, 0x211610ee, 0x0c112307, 0x130d0412,   // ms.tr.az_433 lt.hr.jw_422  ca.ro.sv_432 fi.cs.et_654
  // [3a10]
  0x060b25ad, 0x07001009, 0x2a1123ec, 0x641a01ad,   // eu.es.de_643 be.bg.un_440  ca.ro.mt_644 en.tl.lg_643
  0x1f18010b, 0x2a1925a6, 0x100817ee, 0x201c1e0c,   // en.ga.cy_542 eu.gl.mt_521  sr.uk.be_422 ms.id.sq_543
  0x1a1e1c12, 0x21642307, 0x091310a0, 0x0e645504,   // id.ms.tl_654 ca.lg.jw_432  lt.et.pl_322 rw.lg.is_332
  0x026e0807, 0x0800252c, 0x01006e0c, 0x1f1b0b0c,   // no.blu.da_432 eu.no.un_990  blu.en.un_530 es.tr.cy_543
  // [3a20]
  0x01006b08, 0x6e003f13, 0x033f250c, 0x18001f08,   // ceb.en.un_430 af.blu.un_650  eu.af.nl_543 cy.ga.un_430
  0x231204ee, 0x286406a7, 0x12092da7, 0x05070104,   // fi.hu.ca_422 de.lg.sw_532  sk.pl.hu_532 en.it.fr_332
  0x1e001f19, 0x0c000205, 0x6e0a3112, 0x28136ba9,   // cy.ms.un_750 da.sv.un_330  az.pt.blu_654 ceb.et.sw_544
  0x06000523, 0x1b1a1e04, 0x040c13a4, 0x281a1308,   // fr.de.un_880 ms.tl.tr_332  et.sv.fi_433 et.tl.sw_443
  // [3a30]
  0x130310ac, 0x0a00250c, 0x31006e08, 0x3f070107,   // lt.nl.et_632 eu.pt.un_530  blu.az.un_430 en.it.af_432
  0x6400550e, 0x1b002107, 0x1a136b09, 0x171316a9,   // rw.lg.un_550 jw.tr.un_420  ceb.et.tl_444 hr.et.sr_544
  0x1b0e6404, 0x1b6e0fa7, 0x08640205, 0x101a6ba9,   // lg.is.tr_332 lv.blu.tr_532  da.lg.no_333 ceb.tl.lt_544
  0x55006407, 0x6b1a1ea4, 0x6e000f21, 0x012a08a4,   // lg.rw.un_420 ms.tl.ceb_433  lv.blu.un_860 no.mt.en_433
  // [3a40]
  0x6e2319a4, 0x080225ee, 0x0c001804, 0x1f1806a0,   // gl.ca.blu_433 eu.da.no_422  ga.sv.un_320 de.ga.cy_322
  0x03000623, 0x6416280c, 0x1b645312, 0x0410130c,   // de.nl.un_880 sw.hr.lg_543  ht.lg.tr_654 et.lt.fi_543
  0x111b2bee, 0x040a17ee, 0x2809640c, 0x010a18a0,   // vi.tr.ro_422 sr.mk.ru_422  lg.pl.sw_543 ga.pt.en_322
  0x1a646b09, 0x110410af, 0x23000c0b, 0x120b19a0,   // ceb.lg.tl_444 be.ru.ro_655  sv.ca.un_520 gl.es.hu_322
  // [3a50]
  0x04030fee, 0x23000a23, 0x17001108, 0x11070412,   // lv.nl.fi_422 pt.ca.un_880  ro.sr.un_430 ru.bg.ro_654
  0x2500121a, 0x3100060d, 0x3f001013, 0x080f2508,   // hu.eu.un_760 de.az.un_540  lt.af.un_650 eu.lv.no_443
  0x041306a4, 0x120903ec, 0x04002a1b, 0x1b000607,   // de.et.fi_433 nl.pl.hu_644  mt.fi.un_770 de.tr.un_420
  0x17161307, 0x10002004, 0x190b21a9, 0x09001219,   // et.hr.sr_432 sq.lt.un_320  jw.es.gl_544 hu.pl.un_750
  // [3a60]
  0x12002005, 0x27091fa7, 0x0e000a04, 0x09060304,   // sq.hu.un_330 cy.pl.gd_532  pt.is.un_320 nl.de.pl_332
  0x0c171605, 0x16000412, 0x29162a07, 0x04160204,   // hr.sr.sv_333 fi.hr.un_640  mt.hr.sl_432 da.hr.fi_332
  0x0700100e, 0x071011a0, 0x08041060, 0x13002a07,   // be.bg.un_550 ro.be.bg_322  be.ru.uk_664 mt.et.un_420
  0x11000f04, 0x03251b0c, 0x0b092955, 0x200f21a7,   // lv.ro.un_320 tr.eu.nl_543  sl.pl.es_442 jw.lv.sq_532
  // [3a70]
  0x1b210112, 0x013f2a08, 0x55530507, 0x17162009,   // en.jw.tr_654 mt.af.en_443  fr.ht.rw_432 sq.hr.sr_444
  0x13000304, 0x3f3101a0, 0x21001609, 0x132a23af,   // nl.et.un_320 en.az.af_322  hr.jw.un_440 ca.mt.et_655
  0x2a3f19a0, 0x05160107, 0x2d0d0c04, 0x031e1c13,   // gl.af.mt_322 en.hr.fr_432  sv.cs.sk_332 id.ms.nl_665
  0x081a2807, 0x1e1c2814, 0x17081055, 0x071c1e0c,   // sw.tl.no_432 sw.id.ms_666  be.uk.sr_442 ms.id.it_543
  // [3a80]
  0x643f040c, 0x06110107, 0x281019a4, 0x27160704,   // fi.af.lg_543 en.ro.de_432  gl.lt.sw_433 it.hr.gd_332
  0x3f6413a0, 0x0507110c, 0x21000621, 0x041e1c08,   // et.lg.af_322 ro.it.fr_543  de.jw.un_860 id.ms.fi_443
  0x1c060ca0, 0x0b00230d, 0x3112280c, 0x2b0d21ee,   // sv.de.id_322 ca.es.un_540  sw.hu.az_543 jw.cs.vi_422
  0x1c000f07, 0x08020aee, 0x0806180c, 0x07532102,   // lv.id.un_420 pt.da.no_422  ga.de.no_543 jw.ht.it_222
  // [3a90]
  0x04100f0b, 0x0e0108ee, 0x08000219, 0x080f0e07,   // lv.lt.fi_542 no.en.is_422  da.no.un_750 is.lv.no_432
  0x25000a02, 0x130f100c, 0x28001f0c, 0x190b10a4,   // pt.eu.un_220 lt.lv.et_543  cy.sw.un_530 lt.es.gl_433
  0x2b001102, 0x120e0ca0, 0x100817a7, 0x082d01a0,   // ro.vi.un_220 sv.is.hu_322  sr.uk.be_532 en.sk.no_322
  0x020f2b07, 0x2d0d310c, 0x0e001a14, 0x1a211c0c,   // vi.lv.da_432 az.cs.sk_543  tl.is.un_660 id.jw.tl_543
  // [3aa0]
  0x171655a4, 0x0c1b28ec, 0x116428a9, 0x133f0405,   // rw.hr.sr_433 sw.tr.sv_644  sw.lg.ro_544 fi.af.et_333
  0x0c086407, 0x27002b0d, 0x04133f0c, 0x07190b04,   // lg.no.sv_432 vi.gd.un_540  af.et.fi_543 es.gl.it_332
  0x13640413, 0x270d06ee, 0x13002513, 0x04170809,   // fi.lg.et_665 de.cs.gd_422  eu.et.un_650 uk.sr.ru_444
  0x2100550b, 0x0f1920a4, 0x13000a05, 0x0e230aa0,   // rw.jw.un_520 sq.gl.lv_433  pt.et.un_330 pt.ca.is_322
  // [3ab0]
  0x1e1c2509, 0x5500640c, 0x20000413, 0x10040a04,   // eu.id.ms_444 lg.rw.un_530  fi.sq.un_650 mk.ru.be_332
  0x212d2808, 0x071b1aa0, 0x280e0714, 0x1308060c,   // sw.sk.jw_443 tl.tr.it_322  it.is.sw_666 de.no.et_543
  0x53171a07, 0x17000a18, 0x0c6b0105, 0x0c092da0,   // tl.sr.ht_432 mk.sr.un_740  en.ceb.sv_333 sk.pl.sv_322
  0x2a051308, 0x20160e04, 0x1b190b02, 0x16311707,   // et.fr.mt_443 is.hr.sq_332  es.gl.tr_222 sr.az.hr_432
  // [3ac0]
  0x2a16200c, 0x0800102a, 0x161c04ee, 0x100a0705,   // sq.hr.mt_543 be.uk.un_970  fi.id.hr_422 bg.mk.be_333
  0x170d290b, 0x21000607, 0x0e002a04, 0x0e1b3160,   // sl.cs.sr_542 de.jw.un_420  mt.is.un_320 az.tr.is_664
  0x27182a07, 0x64235502, 0x1b310ea6, 0x0a110804,   // mt.ga.gd_432 rw.ca.lg_222  is.az.tr_521 uk.ro.mk_332
  0x110407a4, 0x1b001302, 0x081a6b07, 0x3f1328a0,   // bg.ru.ro_433 et.tr.un_220  ceb.tl.no_432 sw.et.af_322
  // [3ad0]
  0x21003f08, 0x6e000619, 0x255313ec, 0x1c002102,   // af.jw.un_430 de.blu.un_750  et.ht.eu_644 jw.id.un_220
  0x04200804, 0x04001705, 0x0600270d, 0x08022505,   // no.sq.fi_332 sr.ru.un_330  gd.de.un_540 eu.da.no_333
  0x0600291a, 0x1000060d, 0x6b0801ee, 0x2d0d06ec,   // sl.de.un_760 de.lt.un_540  en.no.ceb_422 de.cs.sk_644
  0x1a00010c, 0x0c1906a7, 0x3f0625ee, 0x1600060d,   // en.tl.un_530 de.gl.sv_532  eu.de.af_422 de.hr.un_540
  // [3ae0]
  0x1c001e12, 0x102d0d55, 0x0d0f17a0, 0x1a002a08,   // ms.id.un_640 cs.sk.lt_442  sr.lv.cs_322 mt.tl.un_430
  0x2128550e, 0x25000914, 0x64001a12, 0x64282002,   // rw.sw.jw_555 pl.eu.un_660  tl.lg.un_640 sq.sw.lg_222
  0x535564ad, 0x29021708, 0x06000905, 0x031b2507,   // lg.rw.ht_643 sr.da.sl_443  pl.de.un_330 eu.tr.nl_432
  0x1304250c, 0x0c201055, 0x17070aa7, 0x01103f0c,   // eu.fi.et_543 lt.sq.sv_442  mk.bg.sr_532 af.lt.en_543
  // [3af0]
  0x0c132509, 0x080a070c, 0x1603060c, 0x28002a04,   // eu.et.sv_444 bg.mk.uk_543  de.nl.hr_543 mt.sw.un_320
  0x08020605, 0x28022a07, 0x060764a0, 0x1f1012af,   // de.da.no_333 mt.da.sw_432  lg.it.de_322 hu.lt.cy_655
  0x08000b07, 0x31000c07, 0x2702250d, 0x311b11a0,   // es.no.un_420 sv.az.un_420  eu.da.gd_554 ro.tr.az_322
  0x07190a0d, 0x1a033f08, 0x06020c0d, 0x031e1c07,   // pt.gl.it_554 af.nl.tl_443  sv.da.de_554 id.ms.nl_432
  // [3b00]
  0x27281904, 0x2a00072b, 0x2a000705, 0x18000804,   // gl.sw.gd_332 it.mt.un_980  it.mt.un_330 no.ga.un_320
  0x2a2318a0, 0x271101a0, 0x0b000113, 0x0d6b0107,   // ga.ca.mt_322 en.ro.gd_322  en.es.un_650 en.ceb.cs_432
  0x1b000307, 0x3f001604, 0x2a002804, 0x53050607,   // nl.tr.un_420 hr.af.un_320  sw.mt.un_320 de.fr.ht_432
  0x0a111714, 0x1c21030c, 0x0c002a19, 0x6b210604,   // sr.ro.mk_666 nl.jw.id_543  mt.sv.un_750 de.jw.ceb_332
  // [3b10]
  0x3f0e06a9, 0x11202a07, 0x1600171a, 0x25001f1b,   // de.is.af_544 mt.sq.ro_432  sr.hr.un_760 cy.eu.un_770
  0x230801a4, 0x2a00112a, 0x64551a12, 0x1f2a2913,   // en.no.ca_433 ro.mt.un_970  tl.rw.lg_654 sl.mt.cy_665
  0x1c0b010c, 0x6b1a01ee, 0x16001004, 0x12182b07,   // en.es.id_543 en.tl.ceb_422  lt.hr.un_320 vi.ga.hu_432
  0x551a6407, 0x1a6b5314, 0x08090407, 0x2510280c,   // lg.tl.rw_432 ht.ceb.tl_666  fi.pl.no_432 sw.lt.eu_543
  // [3b20]
  0x536455a7, 0x171008ec, 0x0c0611ee, 0x1c090d0d,   // rw.lg.ht_532 uk.be.sr_644  ro.de.sv_422 ne.hi.mr_554
  0x07000121, 0x05001c02, 0x3f0c08af, 0x1e6b1aac,   // en.it.un_860 id.fr.un_220  no.sv.af_655 tl.ceb.ms_632
  0x131c25a0, 0x0d1c090c, 0x1a001e07, 0x2d2b0e08,   // eu.id.et_322 hi.mr.ne_543  ms.tl.un_420 is.vi.sk_443
  0x27100704, 0x550531ad, 0x211a6b55, 0x12002b12,   // it.lt.gd_332 az.fr.rw_643  ceb.tl.jw_442 vi.hu.un_640
  // [3b30]
  0x53645512, 0x64001a19, 0x1b2855a9, 0x0b000407,   // rw.lg.ht_654 tl.lg.un_750  rw.sw.tr_544 fi.es.un_420
  0x1c1a6ba4, 0x55190a05, 0x251304ee, 0x0d000502,   // ceb.tl.id_433 pt.gl.rw_333  fi.et.eu_422 fr.cs.un_220
  0x02063112, 0x132025a4, 0x25001e19, 0x64000204,   // az.de.da_654 eu.sq.et_433  ms.eu.un_750 da.lg.un_320
  0x04001707, 0x55311ba4, 0x311b1908, 0x285531a9,   // sr.ru.un_420 tr.az.rw_433  gl.tr.az_443 az.rw.sw_544
  // [3b40]
  0x1b64310c, 0x070a10a4, 0x21193111, 0x05000904,   // az.lg.tr_543 be.mk.bg_433  az.gl.jw_653 pl.fr.un_320
  0x283f0608, 0x55311b0e, 0x0500530c, 0x0e1b310d,   // de.af.sw_443 tr.az.rw_555  ht.fr.un_530 az.tr.is_554
  0x0f001007, 0x06001a05, 0x1e1c1a14, 0x53002109,   // lt.lv.un_420 tl.de.un_330  tl.id.ms_666 jw.ht.un_440
  0x0f101ba6, 0x080410ad, 0x18002808, 0x1a002304,   // tr.lt.lv_521 be.ru.uk_643  sw.ga.un_430 ca.tl.un_320
  // [3b50]
  0x07001202, 0x1200250d, 0x0a0119ee, 0x12006b08,   // hu.it.un_220 eu.hu.un_540  gl.en.pt_422 ceb.hu.un_430
  0x08022713, 0x1f0318a0, 0x181f27af, 0x232153ec,   // gd.da.no_665 ga.nl.cy_322  gd.cy.ga_655 ht.jw.ca_644
  0x190b18a0, 0x061827af, 0x066b1a08, 0x1b0d03a0,   // ga.es.gl_322 gd.ga.de_655  tl.ceb.de_443 nl.cs.tr_322
  0x0306555a, 0x64551ba0, 0x16000904, 0x0900180b,   // rw.de.nl_553 tr.rw.lg_322  pl.hr.un_320 ga.pl.un_520
  // [3b60]
  0x2a2320a6, 0x0b272308, 0x070408a7, 0x2d0206a7,   // sq.ca.mt_521 ca.gd.es_443  uk.ru.bg_532 de.da.sk_532
  0x17162955, 0x01000f04, 0x6b121aaf, 0x29162d02,   // sl.hr.sr_442 lv.en.un_320  tl.hu.ceb_655 sk.hr.sl_222
  0x1b090da4, 0x011f09ee, 0x01112704, 0x0c010807,   // cs.pl.tr_433 pl.cy.en_422  gd.ro.en_332 no.en.sv_432
  0x170410a4, 0x18002d04, 0x04071707, 0x06182704,   // be.ru.sr_433 sk.ga.un_320  sr.bg.ru_432 gd.ga.de_332
  // [3b70]
  0x0e002b0d, 0x0d05010c, 0x0300060c, 0x21002b09,   // vi.is.un_540 en.fr.cs_543  de.nl.un_530 vi.jw.un_440
  0x02002504, 0x2d0d18a7, 0x0a0807a6, 0x2d002020,   // eu.da.un_320 ga.cs.sk_532  bg.uk.mk_521 sq.sk.un_850
  0x04100a08, 0x17292da0, 0x05640704, 0x05001f08,   // mk.be.ru_443 sk.sl.sr_322  it.lg.fr_332 cy.fr.un_430
  0x1a001904, 0x111320ec, 0x2b1219ec, 0x051103ad,   // gl.tl.un_320 sq.et.ro_644  gl.hu.vi_644 nl.ro.fr_643
  // [3b80]
  0x2b001904, 0x04001b0d, 0x1e001f04, 0x0c030f07,   // gl.vi.un_320 tr.fi.un_540  cy.ms.un_320 lv.nl.sv_432
  0x130e10a7, 0x3f0111a7, 0x05110304, 0x55201a08,   // lt.is.et_532 ro.en.af_532  nl.ro.fr_332 tl.sq.rw_443
  0x1100032a, 0x21002d0d, 0x031701a4, 0x080a17a4,   // nl.ro.un_970 sk.jw.un_540  en.sr.nl_433 sr.mk.uk_433
  0x10000421, 0x021a3f0c, 0x0325010c, 0x2d160da0,   // ru.be.un_860 af.tl.da_543  en.eu.nl_543 cs.hr.sk_322
  // [3b90]
  0x16110705, 0x0c001f08, 0x090b23ad, 0x03063f5a,   // it.ro.hr_333 cy.sv.un_430  ca.es.pl_643 af.de.nl_553
  0x1812210e, 0x030501ec, 0x195564a0, 0x0d041e04,   // fa.ur.ar_555 en.fr.nl_644  lg.rw.gl_322 ms.fi.cs_332
  0x20051305, 0x10081755, 0x11052da4, 0x2a290fa4,   // et.fr.sq_333 sr.uk.be_442  sk.fr.ro_433 lv.sl.mt_433
  0x03112da4, 0x2511010c, 0x03001113, 0x030105a4,   // sk.ro.nl_433 en.ro.eu_543  ro.nl.un_650 fr.en.nl_433
  // [3ba0]
  0x0f001e05, 0x64211ca0, 0x23090704, 0x3f1f0c02,   // ms.lv.un_330 id.jw.lg_322  it.pl.ca_332 sv.cy.af_222
  0x17280e07, 0x1105010d, 0x010311a4, 0x0c03050c,   // is.sw.sr_432 en.fr.ro_554  ro.nl.en_433 fr.nl.sv_543
  0x1a2801a4, 0x5504640c, 0x04000305, 0x1b555307,   // en.sw.tl_433 lg.fi.rw_543  nl.fi.un_330 ht.rw.tr_432
  0x170d2a07, 0x0f04160c, 0x02003f18, 0x0d0f2d0c,   // mt.cs.sr_432 hr.fi.lv_543  af.da.un_740 sk.lv.cs_543
  // [3bb0]
  0x02003f1a, 0x09002323, 0x1c1625a7, 0x04292808,   // af.da.un_760 ca.pl.un_880  eu.hr.id_532 sw.sl.fi_443
  0x531711ee, 0x0a17100c, 0x08023fa7, 0x171613ee,   // ro.sr.ht_422 be.sr.mk_543  af.da.no_532 et.hr.sr_422
  0x20170cad, 0x252813a9, 0x132311ec, 0x020e0812,   // sv.sr.sq_643 et.sw.eu_544  ro.ca.et_644 no.is.da_654
  0x0d0c0807, 0x200723a4, 0x0a00010c, 0x3f0109ac,   // no.sv.cs_432 ca.it.sq_433  en.pt.un_530 pl.en.af_632
  // [3bc0]
  0x0b311b0c, 0x0c000818, 0x10000f23, 0x0f002a0e,   // tr.az.es_543 no.sv.un_740  lv.lt.un_880 mt.lv.un_550
  0x1600030c, 0x6b001e04, 0x0d291608, 0x17160cee,   // nl.hr.un_530 ms.ceb.un_320  hr.sl.cs_443 sv.hr.sr_422
  0x2d0d20a4, 0x011304a4, 0x133f0407, 0x2829170c,   // sq.cs.sk_433 fi.et.en_433  fi.af.et_432 sr.sl.sw_543
  0x0a130409, 0x01310f02, 0x2a1823a0, 0x0f000c11,   // fi.et.pt_444 lv.az.en_222  ca.ga.mt_322 sv.lv.un_630
  // [3bd0]
  0x08000305, 0x0c0e08a0, 0x07001121, 0x07170812,   // nl.no.un_330 no.is.sv_322  ro.bg.un_860 uk.sr.bg_654
  0x12000d02, 0x0a040707, 0x19001e02, 0x311b0e07,   // cs.hu.un_220 bg.ru.mk_432  ms.gl.un_220 is.tr.az_432
  0x0c6b0104, 0x06130404, 0x1200090e, 0x282d0d0d,   // en.ceb.sv_332 fi.et.de_332  pl.hu.un_550 cs.sk.sw_554
  0x10000d04, 0x11072002, 0x181e090b, 0x12060e04,   // cs.lt.un_320 sq.it.ro_222  pl.ms.ga_542 is.de.hu_332
  // [3be0]
  0x07100a09, 0x12000c04, 0x0e130cee, 0x11000c05,   // mk.be.bg_444 sv.hu.un_320  sv.et.is_422 sv.ro.un_330
  0x170a1008, 0x17080aee, 0x6e002013, 0x0b002808,   // be.mk.sr_443 mk.uk.sr_422  sq.blu.un_650 sw.es.un_430
  0x1b120c12, 0x0d1629a7, 0x28001904, 0x0b6b19a0,   // sv.hu.tr_654 sl.hr.cs_532  gl.sw.un_320 gl.ceb.es_322
  0x170d16a0, 0x06000c1a, 0x53180d07, 0x04172904,   // hr.cs.sr_322 sv.de.un_760  cs.ga.ht_432 sl.sr.fi_332
  // [3bf0]
  0x1b0c1208, 0x64090e07, 0x2b0f10a7, 0x3f00050d,   // hu.sv.tr_443 is.pl.lg_432  lt.lv.vi_532 fr.af.un_540
  0x02000b02, 0x1e28180c, 0x0a000d13, 0x0c121b1f,   // es.da.un_220 ga.sw.ms_543  cs.pt.un_650 tr.hu.sv_864
  0x10110404, 0x23002b04, 0x13282304, 0x113f0308,   // ru.ro.be_332 vi.ca.un_320  ca.sw.et_332 nl.af.ro_443
  0x190b08a7, 0x06000b02, 0x0508010c, 0x64210ca0,   // no.es.gl_532 es.de.un_220  en.no.fr_543 sv.jw.lg_322

  // [3c00]
  0x0d002004, 0x0c08200c, 0x04080208, 0x2a070508,   // sq.cs.un_320 sq.no.sv_543  da.no.fi_443 fr.it.mt_443
  0x2d0d280c, 0x06002b04, 0x01130204, 0x1b001214,   // sw.cs.sk_543 vi.de.un_320  da.et.en_332 hu.tr.un_660
  0x0e182304, 0x060c030c, 0x233f0207, 0x0b231804,   // ca.ga.is_332 nl.sv.de_543  da.af.ca_432 ga.ca.es_332
  0x04171004, 0x20003f07, 0x12000e12, 0x190b2dee,   // be.sr.ru_332 af.sq.un_420  is.hu.un_640 sk.es.gl_422
  // [3c10]
  0x041017ad, 0x25001021, 0x066b1a05, 0x010c21ee,   // sr.be.ru_643 lt.eu.un_860  tl.ceb.de_333 jw.sv.en_422
  0x23006b08, 0x06042807, 0x170711a7, 0x0c5528a7,   // ceb.ca.un_430 sw.fi.de_432  ro.bg.sr_532 sw.rw.sv_532
  0x29012ba0, 0x18002305, 0x291617a4, 0x0f1029af,   // vi.en.sl_322 ca.ga.un_330  sr.hr.sl_433 sl.lt.lv_655
  0x3f2320ee, 0x07002a23, 0x1a190b02, 0x53000d04,   // sq.ca.af_422 mt.it.un_880  es.gl.tl_222 cs.ht.un_320
  // [3c20]
  0x060c0e08, 0x06040e0c, 0x13005513, 0x3f00130b,   // is.sv.de_443 is.fi.de_543  rw.et.un_650 et.af.un_520
  0x080e020c, 0x21002907, 0x27120e04, 0x231227ee,   // da.is.no_543 sl.jw.un_420  is.hu.gd_332 gd.hu.ca_422
  0x29002811, 0x080a0709, 0x055325ee, 0x0e001902,   // sw.sl.un_630 bg.mk.uk_444  eu.ht.fr_422 gl.is.un_220
  0x2d0d1602, 0x07002104, 0x6e086ba0, 0x0c001219,   // hr.cs.sk_222 jw.it.un_320  ceb.no.blu_322 hu.sv.un_750
  // [3c30]
  0x3f001f05, 0x12080e0d, 0x271206a4, 0x04061207,   // cy.af.un_330 is.no.hu_554  de.hu.gd_433 hu.de.fi_432
  0x27101207, 0x07003f04, 0x3f110504, 0x21001a0e,   // hu.lt.gd_432 af.it.un_320  fr.ro.af_332 tl.jw.un_550
  0x09290d0b, 0x07171655, 0x132804a0, 0x0a00040d,   // cs.sl.pl_542 hr.sr.it_442  fi.sw.et_322 ru.mk.un_540
  0x0709270c, 0x6404280c, 0x07041007, 0x27001105,   // gd.pl.it_543 sw.fi.lg_543  be.ru.bg_432 ro.gd.un_330
  // [3c40]
  0x55046412, 0x2700110d, 0x1f001804, 0x6b100404,   // lg.fi.rw_654 ro.gd.un_540  ga.cy.un_320 fi.lt.ceb_332
  0x111e07a0, 0x08040aee, 0x251c1e0c, 0x182709ee,   // it.ms.ro_322 mk.ru.uk_422  ms.id.eu_543 pl.gd.ga_422
  0x250853ee, 0x040811af, 0x0d17160e, 0x0c1b0e04,   // ht.no.eu_422 ro.uk.ru_655  hr.sr.cs_555 is.tr.sv_332
  0x64005518, 0x06002502, 0x2d161707, 0x063f03ee,   // rw.lg.un_740 eu.de.un_220  sr.hr.sk_432 nl.af.de_422
  // [3c50]
  0x1c000608, 0x13000309, 0x17165509, 0x03060408,   // de.id.un_430 nl.et.un_440  rw.hr.sr_444 fi.de.nl_443
  0x28171604, 0x0f2d0da0, 0x29000d04, 0x06030404,   // hr.sr.sw_332 cs.sk.lv_322  cs.sl.un_320 fi.nl.de_332
  0x21552908, 0x1f00030d, 0x0e003119, 0x08060304,   // sl.rw.jw_443 nl.cy.un_540  az.is.un_750 nl.de.no_332
  0x100f0907, 0x211c1ea4, 0x0f120304, 0x0c030604,   // pl.lv.lt_432 ms.id.jw_433  nl.hu.lv_332 de.nl.sv_332
  // [3c60]
  0x041017a4, 0x060403a9, 0x10171607, 0x28000405,   // sr.be.ru_433 nl.fi.de_544  hr.sr.lt_432 fi.sw.un_330
  0x06030ca0, 0x172d10ad, 0x1a046baf, 0x10111704,   // sv.nl.de_322 lt.sk.sr_643  ceb.fi.tl_655 sr.ro.be_332
  0x0d161707, 0x0427180c, 0x270e04a7, 0x2a64090c,   // sr.hr.cs_432 ga.gd.fi_543  fi.is.gd_532 pl.lg.mt_543
  0x0c00120e, 0x6b0105ee, 0x55251004, 0x291e1c13,   // hu.sv.un_550 fr.en.ceb_422  lt.eu.rw_332 id.ms.sl_665
  // [3c70]
  0x3f030fa0, 0x1c080404, 0x09000e18, 0x171610ee,   // lv.nl.af_322 fi.no.id_332  is.pl.un_740 lt.hr.sr_422
  0x073f1112, 0x6b001e07, 0x29003f08, 0x10000811,   // ro.af.it_654 ms.ceb.un_420  af.sl.un_430 uk.be.un_630
  0x1f002314, 0x29002507, 0x03000504, 0x01033f0c,   // ca.cy.un_660 eu.sl.un_420  fr.nl.un_320 af.nl.en_543
  0x19001b05, 0x1f200e04, 0x171604a0, 0x0a072a14,   // tr.gl.un_330 is.sq.cy_332  fi.hr.sr_322 mt.it.pt_666
  // [3c80]
  0x10216407, 0x02200e55, 0x0f291660, 0x09002102,   // lg.jw.lt_432 is.sq.da_442  hr.sl.lv_664 jw.pl.un_220
  0x0600090d, 0x07171608, 0x0100090c, 0x17163109,   // pl.de.un_540 hr.sr.it_443  pl.en.un_530 az.hr.sr_444
  0x201617a4, 0x042a27a4, 0x21002a12, 0x20001604,   // sr.hr.sq_433 gd.mt.fi_433  mt.jw.un_640 hr.sq.un_320
  0x23001102, 0x09130d60, 0x31171655, 0x00000101,   // ro.ca.un_220 ne.bh.hi_664  hr.sr.az_442 en.un.un_200
  // [3c90]
  0x17000205, 0x161029a4, 0x1e1c0505, 0x2a031e04,   // da.sr.un_330 sl.lt.hr_433  fr.id.ms_333 ms.nl.mt_332
  0x0d112a04, 0x16090fec, 0x12002109, 0x171620af,   // mt.ro.cs_332 lv.pl.hr_644  fa.ur.un_440 sq.hr.sr_655
  0x3f000c11, 0x532305ad, 0x0f000302, 0x16002805,   // sv.af.un_630 fr.ca.ht_643  nl.lv.un_220 sw.hr.un_330
  0x01021c0b, 0x01002707, 0x1a0401ee, 0x03212b04,   // id.da.en_542 gd.en.un_420  en.fi.tl_422 vi.jw.nl_332
  // [3ca0]
  0x13006e22, 0x31031b07, 0x6b1e1c08, 0x1e1b1604,   // blu.et.un_870 tr.nl.az_432  id.ms.ceb_443 hr.tr.ms_332
  0x5300281b, 0x18270660, 0x070b0a05, 0x2d091602,   // sw.ht.un_770 de.gd.ga_664  pt.es.it_333 hr.pl.sk_222
  0x04132512, 0x2a040b05, 0x0f001023, 0x04100705,   // eu.et.fi_654 es.fi.mt_333  lt.lv.un_880 bg.be.ru_333
  0x23091808, 0x64001108, 0x55001b04, 0x111f2a09,   // ga.pl.ca_443 ro.lg.un_430  tr.rw.un_320 mt.cy.ro_444
  // [3cb0]
  0x23272da0, 0x55000e07, 0x091827ad, 0x213f1f04,   // sk.gd.ca_322 is.rw.un_420  gd.ga.pl_643 cy.af.jw_332
  0x17160bec, 0x021a3fee, 0x13020d0b, 0x1f002108,   // es.hr.sr_644 af.tl.da_422  cs.da.et_542 jw.cy.un_430
  0x0d001318, 0x033f010c, 0x23000704, 0x1f3f0211,   // bh.ne.un_740 en.af.nl_543  it.ca.un_320 da.af.cy_653
  0x0f165507, 0x230a2da0, 0x04031fee, 0x2928040c,   // rw.hr.lv_432 sk.pt.ca_322  cy.nl.fi_422 fi.sw.sl_543
  // [3cc0]
  0x07000a0e, 0x1f002722, 0x6b000108, 0x032928ad,   // mk.bg.un_550 gd.cy.un_870  en.ceb.un_430 sw.sl.nl_643
  0x06130c13, 0x1e211c5a, 0x16000f12, 0x11002a04,   // sv.et.de_665 id.jw.ms_553  lv.hr.un_640 mt.ro.un_320
  0x11080504, 0x3f550302, 0x06000c29, 0x311b12bc,   // fr.no.ro_332 nl.rw.af_222  sv.de.un_960 hu.tr.az_865
  0x200f020c, 0x1300020b, 0x1f003f14, 0x0a2b21ee,   // da.lv.sq_543 da.et.un_520  af.cy.un_660 jw.vi.pt_422
  // [3cd0]
  0x206b01ee, 0x646b01a6, 0x3f100e0b, 0x03000614,   // en.ceb.sq_422 en.ceb.lg_521  is.lt.af_542 de.nl.un_660
  0x0a002a04, 0x23052aaf, 0x2d0d17a0, 0x040a1007,   // mt.pt.un_320 mt.fr.ca_655  sr.cs.sk_322 be.mk.ru_432
  0x312920a4, 0x04000513, 0x0c080e08, 0x0f000108,   // sq.sl.az_433 fr.fi.un_650  is.no.sv_443 en.lv.un_430
  0x020e0807, 0x03000107, 0x1a1f0304, 0x23080208,   // no.is.da_432 en.nl.un_420  nl.cy.tl_332 da.no.ca_443
  // [3ce0]
  0x0900060e, 0x3100061a, 0x3f0f10ec, 0x2d100d12,   // de.pl.un_550 de.az.un_760  lt.lv.af_644 cs.lt.sk_654
  0x112d64ec, 0x2d171613, 0x18190b5a, 0x290e06ad,   // lg.sk.ro_644 hr.sr.sk_665  es.gl.ga_553 de.is.sl_643
  0x08001020, 0x02000e07, 0x20071a11, 0x06030204,   // lt.no.un_850 is.da.un_420  tl.it.sq_653 da.nl.de_332
  0x13551ea7, 0x200d12a7, 0x08001714, 0x0a040802,   // ms.rw.et_532 hu.cs.sq_532  sr.uk.un_660 uk.ru.mk_222
  // [3cf0]
  0x08002308, 0x0f001019, 0x18001207, 0x2300030d,   // ca.no.un_430 lt.lv.un_750  ur.ar.un_420 nl.ca.un_540
  0x0a101155, 0x042a08a0, 0x08041708, 0x29001e0c,   // ro.be.mk_442 no.mt.fi_322  sr.ru.uk_443 ms.sl.un_530
  0x06002904, 0x031801a6, 0x0f005508, 0x31060e0c,   // sl.de.un_320 en.ga.nl_521  rw.lv.un_430 is.de.az_543
  0x23000514, 0x1a091f0d, 0x172d16a0, 0x1e061ca4,   // fr.ca.un_660 cy.pl.tl_554  hr.sk.sr_322 id.de.ms_433
  // [3d00]
  0x131e1c05, 0x1b002a0d, 0x132a04a4, 0x0108020d,   // id.ms.et_333 mt.tr.un_540  fi.mt.et_433 da.no.en_554
  0x31002512, 0x0c25020c, 0x066b550d, 0x3100280d,   // eu.az.un_640 da.eu.sv_543  rw.ceb.de_554 sw.az.un_540
  0x3125110c, 0x120811a7, 0x090d1c60, 0x0f02120b,   // ro.eu.az_543 ro.no.hu_532  mr.ne.hi_664 hu.da.lv_542
  0x55212504, 0x0c311b0c, 0x12006b1a, 0x27281802,   // eu.jw.rw_332 tr.az.sv_543  ceb.hu.un_760 ga.sw.gd_222
  // [3d10]
  0x642855af, 0x281e2aa7, 0x08200ba0, 0x285355ee,   // rw.sw.lg_655 mt.ms.sw_532  es.sq.no_322 rw.ht.sw_422
  0x12000304, 0x21001823, 0x29645511, 0x110a07a4,   // nl.hu.un_320 ar.fa.un_880  rw.lg.sl_653 bg.mk.ro_433
  0x1c001605, 0x311a19ee, 0x17000705, 0x642855a7,   // hr.id.un_330 gl.tl.az_422  bg.sr.un_330 rw.sw.lg_532
  0x131e1c04, 0x03291ca0, 0x0e003f14, 0x29006b21,   // id.ms.et_332 id.sl.nl_322  af.is.un_660 ceb.sl.un_860
  // [3d20]
  0x3f020308, 0x11041712, 0x0a0411ee, 0x0f64550b,   // nl.da.af_443 sr.ru.ro_654  ro.ru.mk_422 rw.lg.lv_542
  0x13000314, 0x550802a4, 0x0b005519, 0x23250404,   // nl.et.un_660 da.no.rw_433  rw.es.un_750 fi.eu.ca_332
  0x04171005, 0x033f01a4, 0x211c550c, 0x281a2107,   // be.sr.ru_333 en.af.nl_433  rw.id.jw_543 jw.tl.sw_432
  0x2d000921, 0x3f032102, 0x3f002d05, 0x2d091f11,   // pl.sk.un_860 jw.nl.af_222  sk.af.un_330 cy.pl.sk_653
  // [3d30]
  0x0d6b01a4, 0x11033f0c, 0x6b27010c, 0x3f00050e,   // en.ceb.cs_433 af.nl.ro_543  en.gd.ceb_543 fr.af.un_550
  0x2b000e0d, 0x17040708, 0x090d2dad, 0x0f00090d,   // is.vi.un_540 bg.ru.sr_443  sk.cs.pl_643 pl.lv.un_540
  0x2d000911, 0x133f0a08, 0x0d2d090b, 0x0e00021a,   // pl.sk.un_630 pt.af.et_443  pl.sk.cs_542 da.is.un_760
  0x12000b12, 0x532d090c, 0x0e000208, 0x09002d13,   // es.hu.un_640 pl.sk.ht_543  da.is.un_430 sk.pl.un_650
  // [3d40]
  0x27000707, 0x07092302, 0x25043fee, 0x093f030c,   // it.gd.un_420 ca.pl.it_222  af.fi.eu_422 nl.af.pl_543
  0x05033f5a, 0x53182d04, 0x190b23a4, 0x112d3f55,   // af.nl.fr_553 sk.ga.ht_332  ca.es.gl_433 af.sk.ro_442
  0x09001005, 0x11052308, 0x07170807, 0x28092d09,   // lt.pl.un_330 ca.fr.ro_443  uk.sr.bg_432 sk.pl.sw_444
  0x19286404, 0x0a101104, 0x180627ad, 0x3f001819,   // lg.sw.gl_332 ro.be.mk_332  gd.de.ga_643 ga.af.un_750
  // [3d50]
  0x2d001205, 0x170a08ad, 0x170411a7, 0x04100a04,   // hu.sk.un_330 uk.mk.sr_643  ro.ru.sr_532 mk.be.ru_332
  0x0e000d0b, 0x310c0455, 0x0a001119, 0x1b0f2808,   // cs.is.un_520 fi.sv.az_442  ro.mk.un_750 sw.lv.tr_443
  0x04070a55, 0x28231b07, 0x0e002822, 0x2817640c,   // mk.bg.ru_442 tr.ca.sw_432  sw.is.un_870 lg.sr.sw_543
  0x21552807, 0x2800552a, 0x12211ea0, 0x173155ee,   // sw.rw.jw_432 rw.sw.un_970  ms.jw.hu_322 rw.az.sr_422
  // [3d60]
  0x3f000e04, 0x2d170daf, 0x550e28a9, 0x25005522,   // is.af.un_320 cs.sr.sk_655  sw.is.rw_544 rw.eu.un_870
  0x0e080208, 0x05000a05, 0x6e001022, 0x0c1f08a4,   // da.no.is_443 pt.fr.un_330  lt.blu.un_870 no.cy.sv_433
  0x0b1b2307, 0x1a281e07, 0x1b311e08, 0x1364285a,   // ca.tr.es_432 ms.sw.tl_432  ms.az.tr_443 sw.lg.et_553
  0x0c022a13, 0x2800551b, 0x16552805, 0x315564ad,   // mt.da.sv_665 rw.sw.un_770  sw.rw.hr_333 lg.rw.az_643
  // [3d70]
  0x55642755, 0x28531ba4, 0x3f0c21a0, 0x2a190a07,   // gd.lg.rw_442 tr.ht.sw_433  jw.sv.af_322 pt.gl.mt_432
  0x04006419, 0x09130d5a, 0x1b285511, 0x1912550c,   // lg.fi.un_750 ne.bh.hi_553  rw.sw.tr_653 rw.hu.gl_543
  0x171b2807, 0x2d2755ad, 0x130a25ee, 0x030c1fa6,   // sw.tr.sr_432 rw.gd.sk_643  eu.pt.et_422 cy.sv.nl_521
  0x1f033faf, 0x03063f13, 0x231f3fad, 0x2100050d,   // af.nl.cy_655 af.de.nl_665  af.cy.ca_643 fr.jw.un_540
  // [3d80]
  0x641a55ec, 0x01121355, 0x11200e0c, 0x020e08ad,   // rw.tl.lg_644 et.hu.en_442  is.sq.ro_543 no.is.da_643
  0x063f0807, 0x27005312, 0x2d172908, 0x1b1e0608,   // no.af.de_432 ht.gd.un_640  sl.sr.sk_443 de.ms.tr_443
  0x0a1011a0, 0x21551c0c, 0x53002002, 0x311e55ee,   // ro.be.mk_322 id.rw.jw_543  sq.ht.un_220 rw.ms.az_422
  0x016453a7, 0x2b0723a4, 0x2d000f16, 0x020c0813,   // ht.lg.en_532 ca.it.vi_433  lv.sk.un_720 no.sv.da_665
  // [3d90]
  0x1c3f1308, 0x11201705, 0x110805a4, 0x2a001b13,   // et.af.id_443 sr.sq.ro_333  fr.no.ro_433 tr.mt.un_650
  0x0c2864ac, 0x0109280c, 0x13001a12, 0x033f1312,   // lg.sw.sv_632 sw.pl.en_543  tl.et.un_640 et.af.nl_654
  0x020e0804, 0x10000a0c, 0x020f1307, 0x081011a0,   // no.is.da_332 mk.be.un_530  et.lv.da_432 ro.be.uk_322
  0x20001e04, 0x0e08020d, 0x13000d13, 0x041011a4,   // ms.sq.un_320 da.no.is_554  ne.bh.un_650 ro.be.ru_433
  // [3da0]
  0x21001a0c, 0x0e000204, 0x03001308, 0x0b000519,   // tl.jw.un_530 da.is.un_320  et.nl.un_430 fr.es.un_750
  0x01050bee, 0x0700101a, 0x1b001608, 0x13002a12,   // es.fr.en_422 be.bg.un_760  hr.tr.un_430 mt.et.un_640
  0x04641305, 0x25211eaf, 0x0b001105, 0x131255a4,   // et.lg.fi_333 ms.jw.eu_655  ro.es.un_330 rw.hu.et_433
  0x641f28a9, 0x0d001807, 0x12556408, 0x0e001212,   // sw.cy.lg_544 ga.cs.un_420  lg.rw.hu_443 hu.is.un_640
  // [3db0]
  0x070411a9, 0x0b0706ec, 0x1220550c, 0x1264550c,   // ro.ru.bg_544 de.it.es_644  rw.sq.hu_543 rw.lg.hu_543
  0x04291304, 0x0d1729ee, 0x1a2125a9, 0x1355250c,   // et.sl.fi_332 sl.sr.cs_422  eu.jw.tl_544 eu.rw.et_543
  0x1213100c, 0x55090a02, 0x3127180b, 0x28251304,   // lt.et.hu_543 pt.pl.rw_222  ga.gd.az_542 et.eu.sw_332
  0x6b1801ee, 0x23000d11, 0x0e0802af, 0x27001a05,   // en.ga.ceb_422 cs.ca.un_630  da.no.is_655 tl.gd.un_330
  // [3dc0]
  0x1c1f1a0c, 0x131c0911, 0x28001e0d, 0x641b2505,   // tl.cy.id_543 hi.mr.bh_653  ms.sw.un_540 eu.tr.lg_333
  0x190125ee, 0x6e6b1ea0, 0x641b550c, 0x1c050a02,   // eu.en.gl_422 ms.ceb.blu_322  rw.tr.lg_543 pt.fr.id_222
  0x05001702, 0x0419130b, 0x1b000c04, 0x030b0a04,   // sr.fr.un_220 et.gl.fi_542  sv.tr.un_320 pt.es.nl_332
  0x23000705, 0x08120608, 0x642555a4, 0x250b1907,   // it.ca.un_330 de.hu.no_443  rw.eu.lg_433 gl.es.eu_432
  // [3dd0]
  0x06033f11, 0x3f000808, 0x09000319, 0x03133f0d,   // af.nl.de_653 no.af.un_430  nl.pl.un_750 af.et.nl_554
  0x130d1caf, 0x1a2a6bee, 0x1a002108, 0x1900050b,   // mr.ne.bh_655 ceb.mt.tl_422  jw.tl.un_430 fr.gl.un_520
  0x120e2d12, 0x041711a4, 0x1e31200b, 0x190a040c,   // sk.is.hu_654 ro.sr.ru_433  sq.az.ms_542 fi.pt.gl_543
  0x230a200c, 0x6b2a12a0, 0x0b060104, 0x0b050104,   // sq.pt.ca_543 hu.mt.ceb_322  en.de.es_332 en.fr.es_332
  // [3de0]
  0x21000209, 0x1323050c, 0x070408ee, 0x2d003f04,   // da.jw.un_440 fr.ca.et_543  uk.ru.bg_422 af.sk.un_320
  0x131b2902, 0x0a1708a9, 0x016b28a0, 0x2d130da4,   // sl.tr.et_222 uk.sr.mk_544  sw.ceb.en_322 cs.et.sk_433
  0x230e190c, 0x1f1908a4, 0x131c2107, 0x0e070c0d,   // gl.is.ca_543 no.gl.cy_433  jw.id.et_432 sv.it.is_554
  0x09642507, 0x13000935, 0x0000042d, 0x1e230b0c,   // eu.lg.pl_432 hi.bh.un_A90  ru.un.un_A00 es.ca.ms_543
  // [3df0]
  0x012a3fa0, 0x040807ee, 0x1a1801a0, 0x0d290408,   // af.mt.en_322 bg.uk.ru_422  en.ga.tl_322 fi.sl.cs_443
  0x64002908, 0x64001a07, 0x27005304, 0x17160705,   // sl.lg.un_430 tl.lg.un_420  ht.gd.un_320 it.hr.sr_333
  0x29001107, 0x640820a4, 0x092d0d12, 0x13123fa0,   // ro.sl.un_420 sq.no.lg_433  cs.sk.pl_654 af.hu.et_322
  0x1b001904, 0x2916130c, 0x07000b04, 0x55001605,   // gl.tr.un_320 et.hr.sl_543  es.it.un_320 hr.rw.un_330
  // [3e00]
  0x0a170812, 0x161855a4, 0x552916a0, 0x3120055a,   // uk.sr.mk_654 rw.ga.hr_433  hr.sl.rw_322 fr.sq.az_553
  0x1f080209, 0x07190b02, 0x55072908, 0x060b20a4,   // da.no.cy_444 es.gl.it_222  sl.it.rw_443 sq.es.de_433
  0x162904ee, 0x162855ee, 0x2319050c, 0x1b1a6ba0,   // fi.sl.hr_422 rw.sw.hr_422  fr.gl.ca_543 ceb.tl.tr_322
  0x04100860, 0x0a002508, 0x3f002304, 0x120819a0,   // uk.be.ru_664 eu.pt.un_430  ca.af.un_320 gl.no.hu_322
  // [3e10]
  0x0a1707a9, 0x23000509, 0x2d1221a0, 0x06120c04,   // bg.sr.mk_544 fr.ca.un_440  jw.hu.sk_322 sv.hu.de_332
  0x170410af, 0x086b28a0, 0x16041304, 0x12001704,   // be.ru.sr_655 sw.ceb.no_322  et.fi.hr_332 sr.hu.un_320
  0x28011fee, 0x1004080b, 0x04060c02, 0x2b061a02,   // cy.en.sw_422 uk.ru.be_542  sv.de.fi_222 tl.de.vi_222
  0x2a042da9, 0x2b006b13, 0x2b002007, 0x170a11ee,   // sk.fi.mt_544 ceb.vi.un_650  sq.vi.un_420 ro.mk.sr_422
  // [3e20]
  0x53171604, 0x08020e09, 0x2a2b0aac, 0x1f2153a4,   // hr.sr.ht_332 is.da.no_444  pt.vi.mt_632 ht.jw.cy_433
  0x3f272812, 0x04001722, 0x2b000a19, 0x0b0928a4,   // sw.gd.af_654 sr.ru.un_870  pt.vi.un_750 sw.pl.es_433
  0x2a292d05, 0x09001105, 0x2a2b0aa4, 0x092916ee,   // sk.sl.mt_333 ro.pl.un_330  pt.vi.mt_433 hr.sl.pl_422
  0x286b1a04, 0x0b2325ee, 0x200d09a7, 0x6b1a2b04,   // tl.ceb.sw_332 eu.ca.es_422  pl.cs.sq_532 vi.tl.ceb_332
  // [3e30]
  0x130d0908, 0x1a276bee, 0x1a0a6b11, 0x06000e29,   // hi.ne.bh_443 ceb.gd.tl_422  ceb.pt.tl_653 is.de.un_960
  0x0e2d0d13, 0x160a07a4, 0x2a002b05, 0x09001621,   // cs.sk.is_665 it.pt.hr_433  vi.mt.un_330 hr.pl.un_860
  0x29000f12, 0x2d0d29af, 0x27640702, 0x1c291ea0,   // lv.sl.un_640 sl.cs.sk_655  it.lg.gd_222 ms.sl.id_322
  0x110523a7, 0x041008af, 0x23002b02, 0x0e201f11,   // ca.fr.ro_532 uk.be.ru_655  vi.ca.un_220 cy.sq.is_653
  // [3e40]
  0x022b0aad, 0x282127ad, 0x2a2b0aad, 0x29002d19,   // pt.vi.da_643 gd.jw.sw_643  pt.vi.mt_643 sk.sl.un_750
  0x091716ee, 0x0a0817af, 0x100c0955, 0x07001708,   // hr.sr.pl_422 sr.uk.mk_655  pl.sv.lt_442 sr.bg.un_430
  0x0c0802a4, 0x07093fa4, 0x16002804, 0x11080aa4,   // da.no.sv_433 af.pl.it_433  sw.hr.un_320 mk.uk.ro_433
  0x1a001207, 0x17166baf, 0x53002504, 0x0e002d1a,   // hu.tl.un_420 ceb.hr.sr_655  eu.ht.un_320 sk.is.un_760
  // [3e50]
  0x0f250e04, 0x230c0ea0, 0x100f13a0, 0x033f0602,   // is.eu.lv_332 is.sv.ca_322  et.lv.lt_322 de.af.nl_222
  0x53000113, 0x3f030d04, 0x3f0925ad, 0x04101707,   // en.ht.un_650 cs.nl.af_332  eu.pl.af_643 sr.be.ru_432
  0x04080aac, 0x0411190c, 0x18006b04, 0x09022007,   // mk.uk.ru_632 gl.ro.fi_543  ceb.ga.un_320 sq.da.pl_432
  0x09003f0d, 0x070a040e, 0x190a05a4, 0x0a0519af,   // af.pl.un_540 ru.mk.bg_555  fr.pt.gl_433 gl.fr.pt_655
  // [3e60]
  0x08641fa0, 0x533f0309, 0x070a11a7, 0x290c270c,   // cy.lg.no_322 nl.af.ht_444  ro.mk.bg_532 gd.sv.sl_543
  0x11033faf, 0x180b01a4, 0x06002008, 0x0c003107,   // af.nl.ro_655 en.es.ga_433  sq.de.un_430 az.sv.un_420
  0x05010d08, 0x29000c08, 0x050d53ad, 0x05000404,   // cs.en.fr_443 sv.sl.un_430  ht.cs.fr_643 fi.fr.un_320
  0x0f101705, 0x09130d0d, 0x3f53030c, 0x5300052a,   // sr.lt.lv_333 ne.bh.hi_554  nl.ht.af_543 fr.ht.un_970
  // [3e70]
  0x17132504, 0x07001005, 0x09001321, 0x3f552804,   // eu.et.sr_332 be.bg.un_330  bh.hi.un_860 sw.rw.af_332
  0x12100f08, 0x050a19a0, 0x0200050d, 0x53006e07,   // lv.lt.hu_443 gl.pt.fr_322  fr.da.un_540 blu.ht.un_420
  0x0200060d, 0x0d002d2b, 0x071804a7, 0x0200050c,   // de.da.un_540 sk.cs.un_980  fi.ga.it_532 fr.da.un_530
  0x21181207, 0x3f000e0d, 0x08000c11, 0x02000513,   // ur.ar.fa_432 is.af.un_540  sv.no.un_630 fr.da.un_650
  // [3e80]
  0x02000507, 0x1f00200d, 0x1905230c, 0x3f0203af,   // fr.da.un_420 sq.cy.un_540  ca.fr.gl_543 nl.da.af_655
  0x06001705, 0x160a1ca0, 0x04070a02, 0x17000822,   // sr.de.un_330 id.pt.hr_322  mk.bg.ru_222 uk.sr.un_870
  0x0e00020d, 0x0a040809, 0x130d1c11, 0x171011ec,   // da.is.un_540 uk.ru.mk_444  mr.ne.bh_653 ro.be.sr_644
  0x171110af, 0x20080eac, 0x09003102, 0x033f01af,   // be.ro.sr_655 is.no.sq_632  az.pl.un_220 en.af.nl_655
  // [3e90]
  0x0a002d04, 0x1b000907, 0x121a6ba0, 0x1b2d0908,   // sk.pt.un_320 pl.tr.un_420  ceb.tl.hu_322 pl.sk.tr_443
  0x1c130402, 0x046b1308, 0x09001013, 0x0c001e11,   // fi.et.id_222 et.ceb.fi_443  lt.pl.un_650 ms.sv.un_630
  0x645553a4, 0x1e1c21ac, 0x10000919, 0x28551ea4,   // ht.rw.lg_433 jw.id.ms_632  pl.lt.un_750 ms.rw.sw_433
  0x1707110c, 0x090d2da0, 0x0d130955, 0x1a211ea0,   // ro.bg.sr_543 sk.cs.pl_322  hi.bh.ne_442 ms.jw.tl_322
  // [3ea0]
  0x02001005, 0x21001e09, 0x55005309, 0x641e1b07,   // lt.da.un_330 ms.jw.un_440  ht.rw.un_440 tr.ms.lg_432
  0x6400530e, 0x10310fa6, 0x1b000108, 0x55316455,   // ht.lg.un_550 lv.az.lt_521  en.tr.un_430 lg.az.rw_442
  0x2a002908, 0x0e0b0a02, 0x23005502, 0x2d092107,   // sl.mt.un_430 pt.es.is_222  rw.ca.un_220 jw.pl.sk_432
  0x1c001a0b, 0x046b1a0c, 0x2d1609ee, 0x12042104,   // tl.id.un_520 tl.ceb.fi_543  pl.hr.sk_422 jw.fi.hu_332
  // [3eb0]
  0x64002819, 0x20182708, 0x6b0b10ee, 0x021c2102,   // sw.lg.un_750 gd.ga.sq_443  lt.es.ceb_422 jw.id.da_222
  0x0c03100b, 0x0c0210ee, 0x211b530c, 0x06001c02,   // lt.nl.sv_542 lt.da.sv_422  ht.tr.jw_543 id.de.un_220
  0x230f0508, 0x0f050cad, 0x17100713, 0x182729ec,   // fr.lv.ca_443 sv.fr.lv_643  bg.be.sr_665 sl.gd.ga_644
  0x01002807, 0x13003113, 0x05180107, 0x18271faf,   // sw.en.un_420 az.et.un_650  en.ga.fr_432 cy.gd.ga_655
  // [3ec0]
  0x2a0f230c, 0x042d0d0d, 0x07170407, 0x23000108,   // ca.lv.mt_543 cs.sk.fi_554  ru.sr.bg_432 en.ca.un_430
  0x01002302, 0x0f122507, 0x2b5328a7, 0x13033f09,   // ca.en.un_220 eu.hu.lv_432  sw.ht.vi_532 af.nl.et_444
  0x28000807, 0x25120709, 0x2b2a200d, 0x250f1007,   // no.sw.un_420 it.hu.eu_444  sq.mt.vi_554 lt.lv.eu_432
  0x2b6e2809, 0x03253fa4, 0x64131a55, 0x05231902,   // sw.blu.vi_444 af.eu.nl_433  tl.et.lg_442 gl.ca.fr_222
  // [3ed0]
  0x190111a6, 0x1100080c, 0x230f05af, 0x20121fec,   // ro.en.gl_521 uk.ro.un_530  fr.lv.ca_655 cy.hu.sq_644
  0x0f010507, 0x0c050112, 0x016b05a0, 0x25005514,   // fr.en.lv_432 en.fr.sv_654  fr.ceb.en_322 rw.eu.un_660
  0x13000505, 0x2a001e02, 0x3f12010b, 0x11532004,   // fr.et.un_330 ms.mt.un_220  en.hu.af_542 sq.ht.ro_332
  0x25230b11, 0x6b0e5504, 0x1b000d04, 0x64170da4,   // es.ca.eu_653 rw.is.ceb_332  cs.tr.un_320 cs.sr.lg_433
  // [3ee0]
  0x28000e14, 0x31556414, 0x21001a07, 0x0c6b08a4,   // is.sw.un_660 lg.rw.az_666  tl.jw.un_420 no.ceb.sv_433
  0x08000c0c, 0x2a002104, 0x27002b0c, 0x0e102513,   // sv.no.un_530 jw.mt.un_320  vi.gd.un_530 eu.lt.is_665
  0x1e1c2da9, 0x2800531b, 0x13033f05, 0x285564ee,   // sk.id.ms_544 ht.sw.un_770  af.nl.et_333 lg.rw.sw_422
  0x212b0904, 0x03013fee, 0x190b12a6, 0x190b23a9,   // pl.vi.jw_332 af.en.nl_422  hu.es.gl_521 ca.es.gl_544
  // [3ef0]
  0x0e0f2511, 0x64000414, 0x215525a4, 0x040a110c,   // eu.lv.is_653 fi.lg.un_660  eu.rw.jw_433 ro.mk.ru_543
  0x2d091a0c, 0x1b002a0c, 0x192325a0, 0x0b080705,   // tl.pl.sk_543 mt.tr.un_530  eu.ca.gl_322 it.no.es_333
  0x1a130f0c, 0x0f1008a0, 0x2d0d07a0, 0x09063f08,   // lv.et.tl_543 no.lt.lv_322  it.cs.sk_322 af.de.pl_443
  0x04000807, 0x19005302, 0x130d1c12, 0x251b1f0c,   // uk.ru.un_420 ht.gl.un_220  mr.ne.bh_654 cy.tr.eu_543
  // [3f00]
  0x3f2b2107, 0x2d0d29ee, 0x062b18a7, 0x0c1729ee,   // jw.vi.af_432 sl.cs.sk_422  ga.vi.de_532 sl.sr.sv_422
  0x25001319, 0x0c000a04, 0x02080e0c, 0x2b000204,   // et.eu.un_750 pt.sv.un_320  is.no.da_543 da.vi.un_320
  0x1a120508, 0x121a05ec, 0x0a1708ec, 0x11270555,   // fr.hu.tl_443 fr.tl.hu_644  uk.sr.mk_644 fr.gd.ro_442
  0x0d00530b, 0x6b000508, 0x295310a4, 0x05006b05,   // ht.cs.un_520 fr.ceb.un_430  lt.ht.sl_433 ceb.fr.un_330
  // [3f10]
  0x071f19a6, 0x04081255, 0x0c2b0e05, 0x20251aaf,   // gl.cy.it_521 hu.no.fi_442  is.vi.sv_333 tl.eu.sq_655
  0x2b001f0c, 0x06181f07, 0x100807a9, 0x0d001707,   // cy.vi.un_530 cy.ga.de_432  bg.uk.be_544 sr.cs.un_420
  0x1200050e, 0x05001213, 0x04001311, 0x080a0413,   // fr.hu.un_550 hu.fr.un_650  et.fi.un_630 ru.mk.uk_665
  0x12310513, 0x6b1a21a4, 0x08170411, 0x64002821,   // fr.az.hu_665 jw.tl.ceb_433  ru.sr.uk_653 sw.lg.un_860
  // [3f20]
  0x0a070407, 0x2d0f09ad, 0x21001602, 0x29162d07,   // ru.bg.mk_432 pl.lv.sk_643  hr.jw.un_220 sk.hr.sl_432
  0x16172960, 0x211218a7, 0x11040811, 0x0a0407ad,   // sl.sr.hr_664 ar.ur.fa_532  uk.ru.ro_653 bg.ru.mk_643
  0x200804a0, 0x230c04a4, 0x2a001f14, 0x6b1e1cee,   // fi.no.sq_322 fi.sv.ca_433  cy.mt.un_660 id.ms.ceb_422
  0x02000404, 0x090d1c55, 0x64001702, 0x1a0425ee,   // fi.da.un_320 mr.ne.hi_442  sr.lg.un_220 eu.fi.tl_422
  // [3f30]
  0x020b07ee, 0x17001902, 0x0107030c, 0x641c1eac,   // it.es.da_422 gl.sr.un_220  nl.it.en_543 ms.id.lg_632
  0x0c002304, 0x072128ad, 0x060c01a0, 0x03000829,   // ca.sv.un_320 sw.jw.it_643  en.sv.de_322 no.nl.un_960
  0x07190b09, 0x08060205, 0x1b002a02, 0x06000c11,   // es.gl.it_444 da.de.no_333  mt.tr.un_220 sv.de.un_630
  0x0d091c08, 0x181c1fa0, 0x1e1c0ba0, 0x2a006419,   // mr.hi.ne_443 cy.id.ga_322  es.id.ms_322 lg.mt.un_750
  // [3f40]
  0x292d0da0, 0x1f2a0911, 0x17160b07, 0x1a062ba0,   // cs.sk.sl_322 pl.mt.cy_653  es.hr.sr_432 vi.de.tl_322
  0x29000905, 0x11050705, 0x100f0c07, 0x28640804,   // pl.sl.un_330 it.fr.ro_333  sv.lv.lt_432 no.lg.sw_332
  0x03181ca0, 0x3100641a, 0x0600030b, 0x0a0811a4,   // id.ga.nl_322 lg.az.un_760  nl.de.un_520 ro.uk.mk_433
  0x2900170d, 0x06072009, 0x070e1fec, 0x20005313,   // sr.sl.un_540 sq.it.de_444  cy.is.it_644 ht.sq.un_650
  // [3f50]
  0x1f000a0e, 0x170712ee, 0x0d091c0d, 0x08071f07,   // pt.cy.un_550 hu.it.sr_422  mr.hi.ne_554 cy.it.no_432
  0x2a0764a0, 0x01060207, 0x17005512, 0x101107a4,   // lg.it.mt_322 da.de.en_432  rw.sr.un_640 bg.ro.be_433
  0x0802060c, 0x0a006b08, 0x02002305, 0x13000811,   // de.da.no_543 ceb.pt.un_430  ca.da.un_330 no.et.un_630
  0x20005508, 0x2d002902, 0x0e131fee, 0x2000010d,   // rw.sq.un_430 sl.sk.un_220  cy.et.is_422 en.sq.un_540
  // [3f60]
  0x04001302, 0x530a13ac, 0x040208af, 0x0d020407,   // et.fi.un_220 et.pt.ht_632  no.da.fi_655 fi.da.cs_432
  0x1b030613, 0x0b0e19a0, 0x25002307, 0x1300060d,   // de.nl.tr_665 gl.is.es_322  ca.eu.un_420 de.et.un_540
  0x2d171612, 0x08170a13, 0x0c090aa0, 0x17041004,   // hr.sr.sk_654 mk.sr.uk_665  pt.pl.sv_322 be.ru.sr_332
  0x0a040805, 0x17110a12, 0x08040aa9, 0x01076b05,   // uk.ru.mk_333 mk.ro.sr_654  mk.ru.uk_544 ceb.it.en_333
  // [3f70]
  0x03041ea0, 0x03043f0c, 0x0a290ba4, 0x0e00190c,   // ms.fi.nl_322 af.fi.nl_543  es.sl.pt_433 gl.is.un_530
  0x041117a4, 0x17000b08, 0x0f000407, 0x3f130305,   // sr.ro.ru_433 es.sr.un_430  fi.lv.un_420 nl.et.af_333
  0x10000a23, 0x3f001c08, 0x120e2d05, 0x1b000313,   // mk.be.un_880 id.af.un_430  sk.is.hu_333 nl.tr.un_650
  0x203f1ba4, 0x033f0205, 0x10006e05, 0x1700081b,   // tr.af.sq_433 da.af.nl_333  blu.lt.un_330 uk.sr.un_770
  // [3f80]
  0x081331a4, 0x2a00050c, 0x21020c04, 0x25002802,   // az.et.no_433 fr.mt.un_530  sv.da.jw_332 sw.eu.un_220
  0x29005304, 0x04003f07, 0x3f0203a0, 0x133f0313,   // ht.sl.un_320 af.fi.un_420  nl.da.af_322 nl.af.et_665
  0x25002314, 0x1b3f030c, 0x0f0b6b04, 0x041e1c04,   // ca.eu.un_660 nl.af.tr_543  ceb.es.lv_332 id.ms.fi_332
  0x031304ee, 0x1b002d14, 0x0c1b02a0, 0x171655ec,   // fi.et.nl_422 sk.tr.un_660  da.tr.sv_322 rw.hr.sr_644
  // [3f90]
  0x0d000602, 0x08021ca0, 0x202b0804, 0x060812a4,   // de.cs.un_220 id.da.no_322  no.vi.sq_332 hu.no.de_433
  0x13000805, 0x28070605, 0x04100805, 0x0a1011a4,   // no.et.un_330 de.it.sw_333  uk.be.ru_333 ro.be.mk_433
  0x2006130c, 0x13080208, 0x1302080c, 0x13002512,   // et.de.sq_543 da.no.et_443  no.da.et_543 eu.et.un_640
  0x1900250d, 0x1c000d22, 0x556401a0, 0x070a04ee,   // eu.gl.un_540 ne.mr.un_870  en.lg.rw_322 ru.mk.bg_422
  // [3fa0]
  0x13002305, 0x040a10a6, 0x06232511, 0x642a0707,   // ca.et.un_330 be.mk.ru_521  eu.ca.de_653 it.mt.lg_432
  0x25000613, 0x030a2560, 0x1c1b0ea4, 0x2506230c,   // de.eu.un_650 eu.pt.nl_664  is.tr.id_433 ca.de.eu_543
  0x64550b08, 0x132a1aee, 0x190a2a02, 0x200208a4,   // es.rw.lg_443 tl.mt.et_422  mt.pt.gl_222 no.da.sq_433
  0x0c061f0b, 0x063f6413, 0x040a070b, 0x07100405,   // cy.de.sv_542 lg.af.de_665  bg.mk.ru_542 ru.be.bg_333
  // [3fb0]
  0x551a6b0c, 0x2328010c, 0x2d0d0baf, 0x181364a0,   // ceb.tl.rw_543 en.sw.ca_543  es.cs.sk_655 lg.et.ga_322
  0x6b211a04, 0x2d291712, 0x28001a14, 0x6e011fee,   // tl.jw.ceb_332 sr.sl.sk_654  tl.sw.un_660 cy.en.blu_422
  0x6407250c, 0x0b2d0d14, 0x641e1c02, 0x29201e07,   // eu.it.lg_543 cs.sk.es_666  id.ms.lg_222 ms.sq.sl_432
  0x11001e08, 0x31000104, 0x2a1f1aa4, 0x1f002a19,   // ms.ro.un_430 en.az.un_320  tl.cy.mt_433 mt.cy.un_750
  // [3fc0]
  0x282a64a4, 0x0f0821ad, 0x3f21110b, 0x0b2712a0,   // lg.mt.sw_433 jw.no.lv_643  ro.jw.af_542 hu.gd.es_322
  0x1300281a, 0x1221010c, 0x0c552812, 0x1f003f11,   // sw.et.un_760 en.jw.hu_543  sw.rw.sv_654 af.cy.un_630
  0x1c285555, 0x161304a0, 0x3f6403a0, 0x1700040d,   // rw.sw.id_442 fi.et.hr_322  nl.lg.af_322 ru.sr.un_540
  0x0f17160c, 0x29000d12, 0x53001702, 0x1c130404,   // hr.sr.lv_543 cs.sl.un_640  sr.ht.un_220 fi.et.id_332
  // [3fd0]
  0x08001a08, 0x1219055a, 0x1b133113, 0x55001113,   // tl.no.un_430 fr.gl.hu_553  az.et.tr_665 ro.rw.un_650
  0x0b002013, 0x02000c07, 0x10170407, 0x08000a22,   // sq.es.un_650 sv.da.un_420  ru.sr.be_432 mk.uk.un_870
  0x036b3f08, 0x01110a04, 0x1f000307, 0x1600050c,   // af.ceb.nl_443 pt.ro.en_332  nl.cy.un_420 fr.hr.un_530
  0x291653ac, 0x530f05a6, 0x08000f0c, 0x05002707,   // ht.hr.sl_632 fr.lv.ht_521  lv.no.un_530 gd.fr.un_420
  // [3fe0]
  0x02033f0d, 0x0a1008ee, 0x17001012, 0x10001a08,   // af.nl.da_554 uk.be.mk_422  be.sr.un_640 tl.lt.un_430
  0x3f252305, 0x0a101709, 0x041a6b02, 0x101716a0,   // ca.eu.af_333 sr.be.mk_444  ceb.tl.fi_222 hr.sr.lt_322
  0x0c130408, 0x200a0ba7, 0x062a0302, 0x192d0e55,   // fi.et.sv_443 es.pt.sq_532  nl.mt.de_222 is.sk.gl_442
  0x211812a0, 0x030e3fee, 0x0e0208af, 0x02136407,   // ur.ar.fa_322 af.is.nl_422  no.da.is_655 lg.et.da_432
  // [3ff0]
  0x162a2807, 0x3f032a0e, 0x20060c02, 0x0a1704a7,   // sw.mt.hr_432 mt.nl.af_555  sv.de.sq_222 fi.sr.pt_532
  0x21645504, 0x25130407, 0x16282104, 0x31250fa9,   // rw.lg.jw_332 fi.et.eu_432  jw.sw.hr_332 lv.eu.az_544
  0x06002a13, 0x10040aaf, 0x040b28ee, 0x0b181908,   // mt.de.un_650 mk.ru.be_655  sw.es.fi_422 gl.ga.es_443
  0x12001c04, 0x0e0b1208, 0x121b060c, 0x13645507,   // id.hu.un_320 hu.es.is_443  de.tr.hu_543 rw.lg.et_432

  // [4000]
  0x12003f19, 0x02285514, 0x29091fa4, 0x06080304,   // af.hu.un_750 rw.sw.da_666  cy.pl.sl_433 nl.no.de_332
  0x2d0b0d04, 0x210210a0, 0x6b0f0107, 0x07186e02,   // cs.es.sk_332 lt.da.jw_322  en.lv.ceb_432 blu.ga.it_222
  0x1a6b0e07, 0x120b190b, 0x28131e04, 0x0f102a60,   // is.ceb.tl_432 gl.es.hu_542  ms.et.sw_332 mt.lt.lv_664
  0x55041aee, 0x190b1209, 0x0f000621, 0x081707af,   // tl.fi.rw_422 hu.es.gl_444  de.lv.un_860 bg.sr.uk_655
  // [4010]
  0x0b000919, 0x100a17a9, 0x190b1214, 0x1b3113a4,   // pl.es.un_750 sr.mk.be_544  hu.es.gl_666 et.az.tr_433
  0x180723a0, 0x062a09ec, 0x19530ba7, 0x04020c09,   // ca.it.ga_322 pl.mt.de_644  es.ht.gl_532 sv.da.fi_444
  0x55001a08, 0x0d012004, 0x011320a0, 0x02001f02,   // tl.rw.un_430 sq.en.cs_332  sq.et.en_322 cy.da.un_220
  0x55250607, 0x19005513, 0x1e28550c, 0x11000c04,   // de.eu.rw_432 rw.gl.un_650  rw.sw.ms_543 sv.ro.un_320
  // [4020]
  0x25000419, 0x0a002518, 0x25001707, 0x21005519,   // fi.eu.un_750 eu.pt.un_740  sr.eu.un_420 rw.jw.un_750
  0x0d190b08, 0x10001107, 0x19311708, 0x311e1ca4,   // es.gl.cs_443 ro.lt.un_420  sr.az.gl_443 id.ms.az_433
  0x0d060b04, 0x192d0d08, 0x062a0807, 0x55001a0c,   // es.de.cs_332 cs.sk.gl_443  no.mt.de_432 tl.rw.un_530
  0x021807a7, 0x131c1ead, 0x1c211ea9, 0x180908a0,   // it.ga.da_532 ms.id.et_643  ms.jw.id_544 no.pl.ga_322
  // [4030]
  0x1c041a07, 0x19001104, 0x08000a05, 0x2a000605,   // tl.fi.id_432 ro.gl.un_320  mk.uk.un_330 de.mt.un_330
  0x2d002912, 0x64130e09, 0x53002521, 0x101e1c0d,   // sl.sk.un_640 is.et.lg_444  eu.ht.un_860 id.ms.lt_554
  0x0405255a, 0x09013fee, 0x210f040c, 0x0a2512a7,   // eu.fr.fi_553 af.en.pl_422  fi.lv.jw_543 hu.eu.pt_532
  0x06286b07, 0x061b13ee, 0x1a012aad, 0x29021605,   // ceb.sw.de_432 et.tr.de_422  mt.en.tl_643 hr.da.sl_333
  // [4040]
  0x1b311313, 0x01002a05, 0x02000b05, 0x0e002b13,   // et.az.tr_665 mt.en.un_330  es.da.un_330 vi.is.un_650
  0x2a003f08, 0x0000232d, 0x2a120c04, 0x04002319,   // af.mt.un_430 ca.un.un_A00  sv.hu.mt_332 ca.fi.un_750
  0x1100010d, 0x0a000e08, 0x1e2a21ee, 0x0f2a01ee,   // en.ro.un_540 is.pt.un_430  jw.mt.ms_422 en.mt.lv_422
  0x01050702, 0x0e3f100b, 0x0f001e04, 0x5300050b,   // it.fr.en_222 lt.af.is_542  ms.lv.un_320 fr.ht.un_520
  // [4050]
  0x0d131c0c, 0x11000507, 0x28000d04, 0x11130f04,   // mr.bh.ne_543 fr.ro.un_420  cs.sw.un_320 lv.et.ro_332
  0x17001002, 0x1e160f02, 0x0e1104a6, 0x1b0811a4,   // be.sr.un_220 lv.hr.ms_222  fi.ro.is_521 ro.no.tr_433
  0x6e016ba0, 0x0805280b, 0x1a6b1ead, 0x05110804,   // ceb.en.blu_322 sw.fr.no_542  ms.ceb.tl_643 no.ro.fr_332
  0x0e12180e, 0x2a00090d, 0x110a23a4, 0x04000504,   // ga.hu.is_555 pl.mt.un_540  ca.pt.ro_433 fr.fi.un_320
  // [4060]
  0x05110e0c, 0x05000e29, 0x11050804, 0x0e001a02,   // is.ro.fr_543 is.fr.un_960  no.fr.ro_332 tl.is.un_220
  0x270d1855, 0x25000b0c, 0x2300530d, 0x230553ad,   // ga.cs.gd_442 es.eu.un_530  ht.ca.un_540 ht.fr.ca_643
  0x0d1c0955, 0x1c00091a, 0x031202a0, 0x100804ad,   // hi.mr.ne_442 hi.mr.un_760  da.hu.nl_322 ru.uk.be_643
  0x08000302, 0x0c1303a0, 0x053f0307, 0x07001b07,   // nl.no.un_220 nl.et.sv_322  nl.af.fr_432 tr.it.un_420
  // [4070]
  0x1c1719a4, 0x13040c0c, 0x05033f09, 0x07080412,   // gl.sr.id_433 sv.fi.et_543  af.nl.fr_444 ru.uk.bg_654
  0x0d091605, 0x21002022, 0x10070409, 0x0c292d07,   // hr.pl.cs_333 sq.jw.un_870  ru.bg.be_444 sk.sl.sv_432
  0x0d122d0c, 0x072064a0, 0x19000707, 0x212903a7,   // sk.hu.cs_543 lg.sq.it_322  it.gl.un_420 nl.sl.jw_532
  0x21000304, 0x20111e0c, 0x1109100c, 0x0e182dec,   // nl.jw.un_320 ms.ro.sq_543  lt.pl.ro_543 sk.ga.is_644
  // [4080]
  0x2a190b05, 0x0e0a12ee, 0x2000210e, 0x0c121fa0,   // es.gl.mt_333 hu.pt.is_422  jw.sq.un_550 cy.hu.sv_322
  0x17181608, 0x192112ec, 0x06001214, 0x08001f11,   // hr.ga.sr_443 hu.jw.gl_644  hu.de.un_660 cy.no.un_630
  0x0e080212, 0x08130609, 0x1a2d0d02, 0x12285508,   // da.no.is_654 de.et.no_444  cs.sk.tl_222 rw.sw.hu_443
  0x0c0208a9, 0x0a0807a0, 0x2900530e, 0x3f000d05,   // no.da.sv_544 bg.uk.mk_322  ht.sl.un_550 cs.af.un_330
  // [4090]
  0x55000504, 0x030e010c, 0x13090d60, 0x55001b19,   // fr.rw.un_320 en.is.nl_543  ne.hi.bh_664 tr.rw.un_750
  0x05233f0e, 0x052023a0, 0x11001608, 0x0c020605,   // af.ca.fr_555 ca.sq.fr_322  hr.ro.un_430 de.da.sv_333
  0x130823af, 0x063f03ad, 0x6b190b04, 0x08021605,   // ca.no.et_655 nl.af.de_643  es.gl.ceb_332 hr.da.no_333
  0x23000104, 0x08071704, 0x0c00132a, 0x12002807,   // en.ca.un_320 sr.bg.uk_332  et.sv.un_970 sw.hu.un_420
  // [40a0]
  0x0c3f1f5a, 0x051107a0, 0x09001222, 0x11002008,   // cy.af.sv_553 it.ro.fr_322  hu.pl.un_870 sq.ro.un_430
  0x0d002107, 0x2b1b010c, 0x11100f05, 0x53643112,   // jw.cs.un_420 en.tr.vi_543  lv.lt.ro_333 az.lg.ht_654
  0x05005502, 0x1102080c, 0x10002102, 0x100e020c,   // rw.fr.un_220 no.da.ro_543  jw.lt.un_220 da.is.lt_543
  0x1b6455ee, 0x070601a4, 0x130211ee, 0x171b160b,   // rw.lg.tr_422 en.de.it_433  ro.da.et_422 hr.tr.sr_542
  // [40b0]
  0x311b06ec, 0x2d0d1e02, 0x311b2055, 0x29001614,   // de.tr.az_644 ms.cs.sk_222  sq.tr.az_442 hr.sl.un_660
  0x080410a9, 0x31002804, 0x12000d0e, 0x3f0c080c,   // be.ru.uk_544 sw.az.un_320  cs.hu.un_550 no.sv.af_543
  0x0f042102, 0x130f080c, 0x0600050d, 0x03000104,   // jw.fi.lv_222 no.lv.et_543  fr.de.un_540 en.nl.un_320
  0x20002d08, 0x060f0ca7, 0x20131b04, 0x10000a1b,   // sk.sq.un_430 sv.lv.de_532  tr.et.sq_332 mk.be.un_770
  // [40c0]
  0x033f10ec, 0x0f2025a4, 0x27002504, 0x3f1706a4,   // lt.af.nl_644 eu.sq.lv_433  eu.gd.un_320 de.sr.af_433
  0x531901a0, 0x10000407, 0x0e0c2a02, 0x1a2864ad,   // en.gl.ht_322 ru.be.un_420  mt.sv.is_222 lg.sw.tl_643
  0x120d2d0c, 0x1a212a0d, 0x1a1b250c, 0x2d0d06a4,   // sk.cs.hu_543 mt.jw.tl_554  eu.tr.tl_543 de.cs.sk_433
  0x3f00210e, 0x031a3fa9, 0x0c0e2aad, 0x0c033fa0,   // jw.af.un_550 af.tl.nl_544  mt.is.sv_643 af.nl.sv_322
  // [40d0]
  0x6b172da7, 0x0c000605, 0x552103a0, 0x641a280c,   // sk.sr.ceb_532 de.sv.un_330  nl.jw.rw_322 sw.tl.lg_543
  0x0b0a01a4, 0x01001304, 0x03213f5a, 0x180e2d0c,   // en.pt.es_433 et.en.un_320  af.jw.nl_553 sk.is.ga_543
  0x211a1f05, 0x1b1018a4, 0x230927a0, 0x072a555a,   // cy.tl.jw_333 ga.lt.tr_433  gd.pl.ca_322 rw.mt.it_553
  0x230e19a0, 0x0708045a, 0x27190a08, 0x09001c20,   // gl.is.ca_322 ru.uk.bg_553  pt.gl.gd_443 mr.hi.un_850
  // [40e0]
  0x08100414, 0x25001205, 0x04101704, 0x641e1ca0,   // ru.be.uk_666 hu.eu.un_330  sr.be.ru_332 id.ms.lg_322
  0x04005518, 0x55002833, 0x052d0d55, 0x2d0d19a4,   // rw.fi.un_740 sw.rw.un_A70  cs.sk.fr_442 gl.cs.sk_433
  0x0b6401a0, 0x55642807, 0x2d0d0eaf, 0x2a003112,   // en.lg.es_322 sw.lg.rw_432  is.cs.sk_655 az.mt.un_640
  0x292a0804, 0x281c2004, 0x281a6b12, 0x206e0c04,   // no.mt.sl_332 sq.id.sw_332  ceb.tl.sw_654 sv.blu.sq_332
  // [40f0]
  0x17162dec, 0x16001204, 0x17080708, 0x0400170e,   // sk.hr.sr_644 hu.hr.un_320  bg.uk.sr_443 sr.ru.un_550
  0x1c002112, 0x16000c04, 0x55280604, 0x53006404,   // jw.id.un_640 sv.hr.un_320  de.sw.rw_332 lg.ht.un_320
  0x12002021, 0x18122d11, 0x072005ad, 0x291628a4,   // sq.hu.un_860 sk.hu.ga_653  fr.sq.it_643 sw.hr.sl_433
  0x070f29a0, 0x110f5508, 0x2d002a04, 0x16552908,   // sl.lv.it_322 rw.lv.ro_443  mt.sk.un_320 sl.rw.hr_443
  // [4100]
  0x53070560, 0x290f55a4, 0x0c130412, 0x25001804,   // fr.it.ht_664 rw.lv.sl_433  fi.et.sv_654 ga.eu.un_320
  0x6b291608, 0x18190b55, 0x190b1805, 0x1223110b,   // hr.sl.ceb_443 es.gl.ga_442  ga.es.gl_333 ro.ca.hu_542
  0x160e28a0, 0x11202313, 0x29005513, 0x28165555,   // sw.is.hr_322 ca.sq.ro_665  rw.sl.un_650 rw.hr.sw_442
  0x051a6ba0, 0x29200507, 0x17110407, 0x23002a04,   // ceb.tl.fr_322 fr.sq.sl_432  ru.ro.sr_432 mt.ca.un_320
  // [4110]
  0x13042107, 0x16552905, 0x026b1aee, 0x6428250d,   // jw.fi.et_432 sl.rw.hr_333  tl.ceb.da_422 eu.sw.lg_554
  0x2855645a, 0x2d0d04af, 0x06556408, 0x64092a55,   // lg.rw.sw_553 fi.cs.sk_655  lg.rw.de_443 mt.pl.lg_442
  0x20112313, 0x112a2313, 0x01091fa0, 0x21001e0d,   // ca.ro.sq_665 ca.mt.ro_665  cy.pl.en_322 ms.jw.un_540
  0x125320ad, 0x09005513, 0x080407a7, 0x07041109,   // sq.ht.hu_643 rw.pl.un_650  bg.ru.uk_532 ro.ru.bg_444
  // [4120]
  0x12002d11, 0x18000308, 0x063f27a0, 0x29005312,   // sk.hu.un_630 nl.ga.un_430  gd.af.de_322 ht.sl.un_640
  0x0c202907, 0x31002504, 0x1c201ead, 0x0a111707,   // sl.sq.sv_432 eu.az.un_320  ms.sq.id_643 sr.ro.mk_432
  0x080203a9, 0x1c2d0d0e, 0x18002711, 0x1a2a53af,   // nl.da.no_544 cs.sk.id_555  gd.ga.un_630 ht.mt.tl_655
  0x64000808, 0x0b002a04, 0x0b001114, 0x08063f04,   // no.lg.un_430 mt.es.un_320  ro.es.un_660 af.de.no_332
  // [4130]
  0x08642711, 0x1e1c1aee, 0x07002708, 0x10170aa7,   // gd.lg.no_653 tl.id.ms_422  gd.it.un_430 mk.sr.be_532
  0x0e0c13ee, 0x19000504, 0x0c000f05, 0x09162dee,   // et.sv.is_422 fr.gl.un_320  lv.sv.un_330 sk.hr.pl_422
  0x0c0108a4, 0x131625ad, 0x0c180ea4, 0x1017280c,   // no.en.sv_433 eu.hr.et_643  is.ga.sv_433 sw.sr.lt_543
  0x291653ee, 0x0900270c, 0x2500310c, 0x1104080e,   // ht.hr.sl_422 gd.pl.un_530  az.eu.un_530 uk.ru.ro_555
  // [4140]
  0x030e06a4, 0x2a0123a0, 0x0b0a05ec, 0x27033fa0,   // de.is.nl_433 ca.en.mt_322  fr.pt.es_644 af.nl.gd_322
  0x31201b0c, 0x190a28a4, 0x2a0e01a4, 0x13201ea4,   // tr.sq.az_543 sw.pt.gl_433  en.is.mt_433 ms.sq.et_433
  0x13002007, 0x271304a9, 0x640c0807, 0x12182104,   // sq.et.un_420 fi.et.gd_544  no.sv.lg_432 fa.ar.ur_332
  0x130401a9, 0x1b202a07, 0x016b09ee, 0x0a051255,   // en.fi.et_544 mt.sq.tr_432  pl.ceb.en_422 hu.fr.pt_442
  // [4150]
  0x1e001c35, 0x20002308, 0x311c1ea0, 0x070f110e,   // id.ms.un_A90 ca.sq.un_430  ms.id.az_322 ro.lv.it_555
  0x10001722, 0x31002805, 0x0d000f09, 0x02001a02,   // sr.lt.un_870 sw.az.un_330  lv.cs.un_440 tl.da.un_220
  0x232d1004, 0x16290fa7, 0x64002a0c, 0x03002a02,   // lt.sk.ca_332 lv.sl.hr_532  mt.lg.un_530 mt.nl.un_220
  0x2700071b, 0x07080402, 0x1000171a, 0x04171160,   // it.gd.un_770 ru.uk.bg_222  sr.be.un_760 ro.sr.ru_664
  // [4160]
  0x01000e02, 0x18001223, 0x1f2812ee, 0x17070aac,   // is.en.un_220 ur.ar.un_880  hu.sw.cy_422 mk.bg.sr_632
  0x06001a02, 0x230507a0, 0x0a000419, 0x2a201204,   // tl.de.un_220 it.fr.ca_322  ru.mk.un_750 hu.sq.mt_332
  0x1708110c, 0x05000721, 0x27001802, 0x01280707,   // ro.uk.sr_543 it.fr.un_860  ga.gd.un_220 it.sw.en_432
  0x100807ee, 0x0a00180c, 0x1a000302, 0x0f006b05,   // bg.uk.be_422 ga.pt.un_530  nl.tl.un_220 ceb.lv.un_330
  // [4170]
  0x0a2a07a7, 0x64000302, 0x0a001111, 0x131620a0,   // it.mt.pt_532 nl.lg.un_220  ro.mk.un_630 sq.hr.et_322
  0x1f000305, 0x29000b08, 0x09162904, 0x07000f0d,   // nl.cy.un_330 es.sl.un_430  sl.hr.pl_332 lv.it.un_540
  0x17160d55, 0x6400280e, 0x19000f19, 0x2900642a,   // cs.hr.sr_442 sw.lg.un_550  lv.gl.un_750 lg.sl.un_970
  0x0b1921ad, 0x64311aa0, 0x03102907, 0x131a1b07,   // jw.gl.es_643 tl.az.lg_322  sl.lt.nl_432 tr.tl.et_432
  // [4180]
  0x033f64ec, 0x1b6b0fa4, 0x06000f04, 0x060f08ee,   // lg.af.nl_644 lv.ceb.tr_433  lv.de.un_320 no.lv.de_422
  0x281a6b0c, 0x281a1304, 0x0f131bad, 0x070417ee,   // ceb.tl.sw_543 et.tl.sw_332  tr.et.lv_643 sr.ru.bg_422
  0x136b11a7, 0x6b281a0c, 0x1e002813, 0x131c210d,   // ro.ceb.et_532 tl.sw.ceb_543  sw.ms.un_650 jw.id.et_554
  0x286b0107, 0x1a1b1007, 0x04001214, 0x02120412,   // en.ceb.sw_432 lt.tr.tl_432  hu.fi.un_660 fi.hu.da_654
  // [4190]
  0x12003f04, 0x25135504, 0x0200040c, 0x0b00190b,   // af.hu.un_320 rw.et.eu_332  fi.da.un_530 gl.es.un_520
  0x04001011, 0x0410090b, 0x070a04a9, 0x0618030c,   // lt.fi.un_630 pl.lt.fi_542  ru.mk.bg_544 nl.ga.de_543
  0x1b171660, 0x2517160d, 0x1b001a09, 0x0c282507,   // hr.sr.tr_664 hr.sr.eu_554  tl.tr.un_440 eu.sw.sv_432
  0x1f000502, 0x110a1760, 0x1a001e19, 0x131c2507,   // fr.cy.un_220 sr.mk.ro_664  ms.tl.un_750 eu.id.et_432
  // [41a0]
  0x16091b04, 0x042125ee, 0x28000422, 0x53001e04,   // tr.pl.hr_332 eu.jw.fi_422  fi.sw.un_870 ms.ht.un_320
  0x1a0413a4, 0x19230ba9, 0x21005508, 0x12080504,   // et.fi.tl_433 es.ca.gl_544  rw.jw.un_430 fr.no.hu_332
  0x1900121e, 0x04000735, 0x1f083f02, 0x1f0910a6,   // hu.gl.un_830 bg.ru.un_A90  af.no.cy_222 lt.pl.cy_521
  0x050103a4, 0x281a53a7, 0x04080aee, 0x25000d0d,   // nl.en.fr_433 ht.tl.sw_532  mk.uk.ru_422 cs.eu.un_540
  // [41b0]
  0x3f643104, 0x2a2519a7, 0x20001e08, 0x0900210b,   // az.lg.af_332 gl.eu.mt_532  ms.sq.un_430 jw.pl.un_520
  0x060e0811, 0x17072512, 0x20041307, 0x13000421,   // no.is.de_653 eu.it.sr_654  et.fi.sq_432 fi.et.un_860
  0x3f062ba0, 0x080920a4, 0x21195304, 0x110413ad,   // vi.de.af_322 sq.pl.no_433  ht.gl.jw_332 et.fi.ro_643
  0x03643f0e, 0x18001218, 0x0a002a18, 0x17081007,   // af.lg.nl_555 ur.ar.un_740  mt.pt.un_740 be.uk.sr_432
  // [41c0]
  0x2d100904, 0x032a3f02, 0x2d090d04, 0x05006405,   // pl.lt.sk_332 af.mt.nl_222  cs.pl.sk_332 lg.fr.un_330
  0x06000902, 0x3f006b04, 0x2a000a0d, 0x01000802,   // pl.de.un_220 ceb.af.un_320  pt.mt.un_540 no.en.un_220
  0x172d2907, 0x12040655, 0x09006b05, 0x1a3f0107,   // sl.sk.sr_432 de.fi.hu_442  ceb.pl.un_330 en.af.tl_432
  0x13001e08, 0x061009ee, 0x2a080a0e, 0x173111ee,   // ms.et.un_430 pl.lt.de_422  pt.no.mt_555 ro.az.sr_422
  // [41d0]
  0x1c0a2a07, 0x06010c02, 0x1700162a, 0x1617295a,   // mt.pt.id_432 sv.en.de_222  hr.sr.un_970 sl.sr.hr_553
  0x09190a55, 0x0a100404, 0x1c003f04, 0x020e08a9,   // pt.gl.pl_442 ru.be.mk_332  af.id.un_320 no.is.da_544
  0x09001602, 0x07080a11, 0x162d1707, 0x202701a0,   // hr.pl.un_220 mk.uk.bg_653  sr.sk.hr_432 en.gd.sq_322
  0x11001f02, 0x2300110d, 0x25002008, 0x252119a0,   // cy.ro.un_220 ro.ca.un_540  sq.eu.un_430 gl.jw.eu_322
  // [41e0]
  0x272818af, 0x190b0a04, 0x0804170b, 0x1800272b,   // ga.sw.gd_655 pt.es.gl_332  sr.ru.uk_542 gd.ga.un_980
  0x10000418, 0x1a3f06a4, 0x03182711, 0x0b000513,   // ru.be.un_740 de.af.tl_433  gd.ga.nl_653 fr.es.un_650
  0x31001113, 0x6b3f06a9, 0x08002008, 0x08033f07,   // ro.az.un_650 de.af.ceb_544  sq.no.un_430 af.nl.no_432
  0x0e002011, 0x13121108, 0x041364ac, 0x0d1f3f07,   // sq.is.un_630 ro.hu.et_443  lg.et.fi_632 af.cy.cs_432
  // [41f0]
  0x2700182c, 0x060f1007, 0x3f550604, 0x06641307,   // ga.gd.un_990 lt.lv.de_432  de.rw.af_332 et.lg.de_432
  0x03081307, 0x0a00270d, 0x012a06a0, 0x0c2b0202,   // et.no.nl_432 gd.pt.un_540  de.mt.en_322 da.vi.sv_222
  0x04170a02, 0x2d0d05ec, 0x1e001a04, 0x0c0e0604,   // mk.sr.ru_222 fr.cs.sk_644  tl.ms.un_320 de.is.sv_332
  0x0800200c, 0x17092d04, 0x07080a08, 0x29640307,   // sq.no.un_530 sk.pl.sr_332  mk.uk.bg_443 nl.lg.sl_432
  // [4200]
  0x190a09af, 0x23000d04, 0x0a111712, 0x04210fa4,   // pl.pt.gl_655 cs.ca.un_320  sr.ro.mk_654 lv.jw.fi_433
  0x1f005507, 0x170f16a0, 0x09000404, 0x1a100404,   // rw.cy.un_420 hr.lv.sr_322  fi.pl.un_320 fi.lt.tl_332
  0x0e0302a0, 0x2d290d08, 0x27282008, 0x17162709,   // da.nl.is_322 cs.sl.sk_443  sq.sw.gd_443 gd.hr.sr_444
  0x080a175a, 0x0b001213, 0x1c272155, 0x070e2708,   // sr.mk.uk_553 hu.es.un_650  jw.gd.id_442 gd.is.it_443
  // [4210]
  0x09271805, 0x23120bec, 0x2a000604, 0x091a6ba6,   // ga.gd.pl_333 es.hu.ca_644  de.mt.un_320 ceb.tl.pl_521
  0x1800071a, 0x1811070c, 0x180a0709, 0x27001c04,   // it.ga.un_760 it.ro.ga_543  it.pt.ga_444 id.gd.un_320
  0x07182708, 0x17040709, 0x072b0107, 0x081e10a4,   // gd.ga.it_443 bg.ru.sr_444  en.vi.it_432 lt.ms.no_433
  0x25281eee, 0x160701a0, 0x21000921, 0x1b102755,   // ms.sw.eu_422 en.it.hr_322  pl.jw.un_860 gd.lt.tr_442
  // [4220]
  0x2d0d2902, 0x01160aee, 0x3f182707, 0x6b0c19ee,   // sl.cs.sk_222 pt.hr.en_422  gd.ga.af_432 gl.sv.ceb_422
  0x3f001f19, 0x2a001c04, 0x2800271b, 0x2b1e1c02,   // cy.af.un_750 id.mt.un_320  gd.sw.un_770 id.ms.vi_222
  0x1b002829, 0x281e1c12, 0x0a052da4, 0x180b12ad,   // sw.tr.un_960 id.ms.sw_654  sk.fr.pt_433 hu.es.ga_643
  0x25001e02, 0x1c1a1ea4, 0x20072112, 0x072306a4,   // ms.eu.un_220 ms.tl.id_433  jw.it.sq_654 de.ca.it_433
  // [4230]
  0x01002802, 0x1a6b1ca4, 0x08000705, 0x07000122,   // sw.en.un_220 id.ceb.tl_433  bg.uk.un_330 en.it.un_870
  0x170a08a4, 0x2d0d53a0, 0x080c1107, 0x07081008,   // uk.mk.sr_433 ht.cs.sk_322  ro.sv.no_432 be.uk.bg_443
  0x0a171004, 0x190b070e, 0x0a100805, 0x050b0708,   // be.sr.mk_332 it.es.gl_555  uk.be.mk_333 it.es.fr_443
  0x020306a0, 0x07110105, 0x2a1c1709, 0x192a07a4,   // de.nl.da_322 en.ro.it_333  sr.id.mt_444 it.mt.gl_433
  // [4240]
  0x02080ea7, 0x1b080ea7, 0x201110a0, 0x11211c12,   // is.no.da_532 is.no.tr_532  lt.ro.sq_322 id.jw.ro_654
  0x25091ba4, 0x0b000e09, 0x081704ee, 0x210e2d0c,   // tr.pl.eu_433 is.es.un_440  ru.sr.uk_422 sk.is.jw_543
  0x21002518, 0x07310b04, 0x311221a0, 0x0a002d0c,   // eu.jw.un_740 es.az.it_332  jw.hu.az_322 sk.pt.un_530
  0x080402a4, 0x5500050c, 0x1e031ca0, 0x2a171604,   // da.fi.no_433 fr.rw.un_530  id.nl.ms_322 hr.sr.mt_332
  // [4250]
  0x06001b08, 0x2a291708, 0x012a1ba0, 0x172353a0,   // tr.de.un_430 sr.sl.mt_443  tr.mt.en_322 ht.ca.sr_322
  0x100b5307, 0x23001705, 0x3f0f23a0, 0x0c000b0d,   // ht.es.lt_432 sr.ca.un_330  ca.lv.af_322 es.sv.un_540
  0x16102005, 0x080c0314, 0x1716070c, 0x292d2805,   // sq.lt.hr_333 nl.sv.no_666  it.hr.sr_543 sw.sk.sl_333
  0x3f080aa7, 0x0a000422, 0x130f04a4, 0x55062a07,   // pt.no.af_532 ru.mk.un_870  fi.lv.et_433 mt.de.rw_432
  // [4260]
  0x09001614, 0x2a0564a7, 0x28000313, 0x02000e14,   // hr.pl.un_660 lg.fr.mt_532  nl.sw.un_650 is.da.un_660
  0x53645504, 0x290c08a0, 0x190b07af, 0x64002820,   // rw.lg.ht_332 no.sv.sl_322  it.es.gl_655 sw.lg.un_850
  0x08170407, 0x1f052308, 0x17000807, 0x17000104,   // ru.sr.uk_432 ca.fr.cy_443  no.sr.un_420 en.sr.un_320
  0x0d2b06ee, 0x25530707, 0x3f002b09, 0x050e1fa0,   // de.vi.cs_422 it.ht.eu_432  vi.af.un_440 cy.is.fr_322
  // [4270]
  0x02000c0b, 0x160311ec, 0x642855a0, 0x5500282a,   // sv.da.un_520 ro.nl.hr_644  rw.sw.lg_322 sw.rw.un_970
  0x032a3f07, 0x10080707, 0x251a55ad, 0x1e002b07,   // af.mt.nl_432 bg.uk.be_432  rw.tl.eu_643 vi.ms.un_420
  0x18203fa0, 0x281827ec, 0x023f0c07, 0x1c2a06a7,   // af.sq.ga_322 gd.ga.sw_644  sv.af.da_432 de.mt.id_532
  0x216b55ad, 0x0d210aa0, 0x1c18275a, 0x06001802,   // rw.ceb.jw_643 pt.jw.cs_322  gd.ga.id_553 ga.de.un_220
  // [4280]
  0x13002104, 0x1828010c, 0x18272107, 0x3f000c02,   // jw.et.un_320 en.sw.ga_543  jw.gd.ga_432 sv.af.un_220
  0x2b1318a0, 0x08281304, 0x112718af, 0x0e002804,   // ga.et.vi_322 et.sw.no_332  ga.gd.ro_655 sw.is.un_320
  0x21002008, 0x031f0607, 0x11000505, 0x55280107,   // sq.jw.un_430 de.cy.nl_432  fr.ro.un_330 en.sw.rw_432
  0x23000502, 0x3f2718ee, 0x0e0c01a0, 0x023f0804,   // fr.ca.un_220 ga.gd.af_422  en.sv.is_322 no.af.da_332
  // [4290]
  0x12080ea4, 0x1f002a05, 0x28552504, 0x3f03080c,   // is.no.hu_433 mt.cy.un_330  eu.rw.sw_332 no.nl.af_543
  0x0b0813a9, 0x12250807, 0x64005508, 0x19080ca4,   // et.no.es_544 no.eu.hu_432  rw.lg.un_430 sv.no.gl_433
  0x1225060c, 0x0200290c, 0x0c1f0e0c, 0x551a6412,   // de.eu.hu_543 sl.da.un_530  is.cy.sv_543 lg.tl.rw_654
  0x0a110709, 0x030f1304, 0x2d0d10a0, 0x1c105509,   // bg.ro.mk_444 et.lv.nl_332  lt.cs.sk_322 rw.lt.id_444
  // [42a0]
  0x061b0cac, 0x29231707, 0x0b052d05, 0x120a0504,   // sv.tr.de_632 sr.ca.sl_432  sk.fr.es_333 fr.pt.hu_332
  0x070413af, 0x2a052107, 0x0713110c, 0x21282aa4,   // et.fi.it_655 jw.fr.mt_432  ro.et.it_543 mt.sw.jw_433
  0x2013110c, 0x060b0102, 0x11122112, 0x3f00530e,   // ro.et.sq_543 en.es.de_222  jw.hu.ro_654 ht.af.un_550
  0x13082004, 0x6431550c, 0x19000b08, 0x31041305,   // sq.no.et_332 rw.az.lg_543  es.gl.un_430 et.fi.az_333
  // [42b0]
  0x0f1129a4, 0x1b645507, 0x55641ca0, 0x11192104,   // sl.ro.lv_433 rw.lg.tr_432  id.lg.rw_322 jw.gl.ro_332
  0x531a21a0, 0x19000805, 0x1105070e, 0x171621ee,   // jw.tl.ht_322 no.gl.un_330  it.fr.ro_555 jw.hr.sr_422
  0x030e250c, 0x111607ad, 0x170f13a7, 0x1b1325a9,   // eu.is.nl_543 it.hr.ro_643  et.lv.sr_532 eu.et.tr_544
  0x250e08a0, 0x120e0807, 0x050e2da4, 0x3f0313a0,   // no.is.eu_322 no.is.hu_432  sk.is.fr_433 et.nl.af_322
  // [42c0]
  0x29001613, 0x0306080c, 0x04000722, 0x0f003f05,   // hr.sl.un_650 no.de.nl_543  bg.ru.un_870 af.lv.un_330
  0x0d281ba0, 0x12001811, 0x1c1121a4, 0x031b250b,   // tr.sw.cs_322 ar.ur.un_630  jw.ro.id_433 eu.tr.nl_542
  0x03000b07, 0x0a002808, 0x1f002111, 0x5521280c,   // es.nl.un_420 sw.pt.un_430  jw.cy.un_630 sw.jw.rw_543
  0x01251804, 0x1e061213, 0x290717a0, 0x251b0309,   // ga.eu.en_332 hu.de.ms_665  sr.it.sl_322 nl.tr.eu_444
  // [42d0]
  0x53060204, 0x211a6bee, 0x0a2117a0, 0x3f0103ee,   // da.de.ht_332 ceb.tl.jw_422  sr.jw.pt_322 nl.en.af_422
  0x1e210fee, 0x3f00160b, 0x11000d14, 0x13311b5a,   // lv.jw.ms_422 hr.af.un_520  cs.ro.un_660 tr.az.et_553
  0x2d1629ad, 0x3f080e05, 0x131f0fee, 0x16271fee,   // sl.hr.sk_643 is.no.af_333  lv.cy.et_422 cy.gd.hr_422
  0x3f0e080c, 0x033f01a0, 0x0e001b08, 0x270b2305,   // no.is.af_543 en.af.nl_322  tr.is.un_430 ca.es.gd_333
  // [42e0]
  0x05001108, 0x642906ee, 0x0a08070e, 0x08215307,   // ro.fr.un_430 de.sl.lg_422  bg.uk.mk_555 ht.jw.no_432
  0x271801a0, 0x27291602, 0x0b230aaf, 0x0f000c04,   // en.ga.gd_322 hr.sl.gd_222  pt.ca.es_655 sv.lv.un_320
  0x0f003102, 0x0d001320, 0x08001f13, 0x6b1e1c04,   // az.lv.un_220 bh.ne.un_850  cy.no.un_650 id.ms.ceb_332
  0x06001904, 0x05190b02, 0x040a07af, 0x08001605,   // gl.de.un_320 es.gl.fr_222  bg.mk.ru_655 hr.no.un_330
  // [42f0]
  0x23110d04, 0x17000713, 0x03210c04, 0x0e002908,   // cs.ro.ca_332 bg.sr.un_650  sv.jw.nl_332 sl.is.un_430
  0x250603a0, 0x1a0218ee, 0x0e2d0d08, 0x1f2818a7,   // nl.de.eu_322 ga.da.tl_422  cs.sk.is_443 ga.sw.cy_532
  0x1b550408, 0x13033f04, 0x2b000808, 0x18282712,   // fi.rw.tr_443 af.nl.et_332  no.vi.un_430 gd.sw.ga_654
  0x28000d0d, 0x5300180d, 0x31646bee, 0x1820280b,   // cs.sw.un_540 ga.ht.un_540  ceb.lg.az_422 sw.sq.ga_542
  // [4300]
  0x040c100c, 0x28001e13, 0x12003f0c, 0x2800131b,   // lt.sv.fi_543 ms.sw.un_650  af.hu.un_530 et.sw.un_770
  0x6b182711, 0x0553010c, 0x286421a4, 0x3f001a12,   // gd.ga.ceb_653 en.ht.fr_543  jw.lg.sw_433 tl.af.un_640
  0x2b18270b, 0x202821a4, 0x64040b05, 0x0e0c21a4,   // gd.ga.vi_542 jw.sw.sq_433  es.fi.lg_333 jw.sv.is_433
  0x03001f19, 0x100708ad, 0x282a1e0b, 0x3f00020d,   // cy.nl.un_750 uk.bg.be_643  ms.mt.sw_542 da.af.un_540
  // [4310]
  0x08215505, 0x170711a4, 0x3f0313ec, 0x0a000b0b,   // rw.jw.no_333 ro.bg.sr_433  et.nl.af_644 es.pt.un_520
  0x033f31a0, 0x06001b19, 0x01531fa0, 0x291653a0,   // az.af.nl_322 tr.de.un_750  cy.ht.en_322 ht.hr.sl_322
  0x125564a4, 0x02001f21, 0x080110a0, 0x170704ee,   // lg.rw.hu_433 cy.da.un_860  lt.en.no_322 ru.bg.sr_422
  0x020c1f11, 0x2b000122, 0x0c2d0d04, 0x1c001e21,   // cy.sv.da_653 en.vi.un_870  cs.sk.sv_332 ms.id.un_860
  // [4320]
  0x28000d05, 0x080c0e0e, 0x1e001c1a, 0x1c1e2160,   // cs.sw.un_330 is.sv.no_555  id.ms.un_760 jw.ms.id_664
  0x06023f0b, 0x0a022aa0, 0x100811a7, 0x1a1b2560,   // af.da.de_542 mt.da.pt_322  ro.uk.be_532 eu.tr.tl_664
  0x13280304, 0x131228a4, 0x12000b08, 0x03130111,   // nl.sw.et_332 sw.hu.et_433  es.hu.un_430 en.et.nl_653
  0x2d1b0da4, 0x03055304, 0x08170a12, 0x1b002a13,   // cs.tr.sk_433 ht.fr.nl_332  mk.sr.uk_654 mt.tr.un_650
  // [4330]
  0x2a5507a0, 0x11003f02, 0x25271b0c, 0x0c1f0855,   // it.rw.mt_322 af.ro.un_220  tr.gd.eu_543 no.cy.sv_442
  0x2b002802, 0x1c2720a7, 0x190c08a4, 0x01053f0b,   // sw.vi.un_220 sq.gd.id_532  no.sv.gl_433 af.fr.en_542
  0x1a1f01a7, 0x011e08a9, 0x10310502, 0x0b231204,   // en.cy.tl_532 no.ms.en_544  fr.az.lt_222 hu.ca.es_332
  0x21002d04, 0x2d000f07, 0x0b0a12a0, 0x056b0c08,   // sk.jw.un_320 lv.sk.un_420  hu.pt.es_322 sv.ceb.fr_443
  // [4340]
  0x17002d0d, 0x6b2a070c, 0x6400131b, 0x25001308,   // sk.sr.un_540 it.mt.ceb_543  et.lg.un_770 et.eu.un_430
  0x040313ec, 0x3f0364ad, 0x23132807, 0x13040107,   // et.nl.fi_644 lg.nl.af_643  sw.et.ca_432 en.fi.et_432
  0x05001214, 0x1700071a, 0x0318275a, 0x2d0d0fa0,   // hu.fr.un_660 bg.sr.un_760  gd.ga.nl_553 lv.cs.sk_322
  0x17100812, 0x20050107, 0x0400111b, 0x0a11080d,   // uk.be.sr_654 en.fr.sq_432  ro.ru.un_770 uk.ro.mk_554
  // [4350]
  0x6e1b53a9, 0x0f000907, 0x13001f07, 0x090d1307,   // ht.tr.blu_544 pl.lv.un_420  cy.et.un_420 bh.ne.hi_432
  0x55002805, 0x1e552aad, 0x1f181c07, 0x060e0c12,   // sw.rw.un_330 mt.rw.ms_643  id.ga.cy_432 sv.is.de_654
  0x171621a9, 0x0a17040e, 0x17101155, 0x171011ee,   // jw.hr.sr_544 ru.sr.mk_555  ro.be.sr_442 ro.be.sr_422
  0x02042555, 0x64002107, 0x09001902, 0x171655a0,   // eu.fi.da_442 jw.lg.un_420  gl.pl.un_220 rw.hr.sr_322
  // [4360]
  0x0f006e07, 0x060c0fa4, 0x292a0704, 0x172916a6,   // blu.lv.un_420 lv.sv.de_433  it.mt.sl_332 hr.sl.sr_521
  0x06000b09, 0x2b071c07, 0x111b230c, 0x211c1e11,   // es.de.un_440 id.it.vi_432  ca.tr.ro_543 ms.id.jw_653
  0x2164550c, 0x1f282507, 0x255564a0, 0x20001307,   // rw.lg.jw_543 eu.sw.cy_432  lg.rw.eu_322 et.sq.un_420
  0x1a096408, 0x101c55ad, 0x20003f05, 0x180927a9,   // lg.pl.tl_443 rw.id.lt_643  af.sq.un_330 gd.pl.ga_544
  // [4370]
  0x130c0202, 0x060802ad, 0x101e0f07, 0x1f000507,   // da.sv.et_222 da.no.de_643  lv.ms.lt_432 fr.cy.un_420
  0x2a002107, 0x64211c04, 0x171120a4, 0x64000f0c,   // jw.mt.un_420 id.jw.lg_332  sq.ro.sr_433 lv.lg.un_530
  0x0700550c, 0x02002507, 0x020e0302, 0x0e002a19,   // rw.it.un_530 eu.da.un_420  nl.is.da_222 mt.is.un_750
  0x07002507, 0x0a0810ec, 0x2100550c, 0x1b3155a9,   // eu.it.un_420 be.uk.mk_644  rw.jw.un_530 rw.az.tr_544
  // [4380]
  0x64000b04, 0x641e1c08, 0x16292da4, 0x09000c08,   // es.lg.un_320 id.ms.lg_443  sk.sl.hr_433 sv.pl.un_430
  0x17000821, 0x29531ea0, 0x10532507, 0x281225af,   // uk.sr.un_860 ms.ht.sl_322  eu.ht.lt_432 eu.hu.sw_655
  0x25006422, 0x100f2508, 0x31000d08, 0x1b006e09,   // lg.eu.un_870 eu.lv.lt_443  cs.az.un_430 blu.tr.un_440
  0x17161ea4, 0x17183105, 0x31001b02, 0x3f032aa9,   // ms.hr.sr_433 az.ga.sr_333  tr.az.un_220 mt.nl.af_544
  // [4390]
  0x27050107, 0x08020a0c, 0x25001f0d, 0x0c2321a0,   // en.fr.gd_432 pt.da.no_543  cy.eu.un_540 jw.ca.sv_322
  0x062527ad, 0x1f310555, 0x23121f08, 0x6b1f05ee,   // gd.eu.de_643 fr.az.cy_442  cy.hu.ca_443 fr.cy.ceb_422
  0x1b000802, 0x3f021bec, 0x25003107, 0x170a10af,   // no.tr.un_220 tr.da.af_644  az.eu.un_420 be.mk.sr_655
  0x01550507, 0x2800100e, 0x64033fa7, 0x0a000808,   // fr.rw.en_432 lt.sw.un_550  af.nl.lg_532 no.pt.un_430
  // [43a0]
  0x12251b07, 0x0d092da9, 0x251e1c5a, 0x2500041a,   // tr.eu.hu_432 sk.pl.cs_544  id.ms.eu_553 fi.eu.un_760
  0x04281307, 0x0800022c, 0x17000835, 0x271816af,   // et.sw.fi_432 da.no.un_990  uk.sr.un_A90 hr.ga.gd_655
  0x0b130412, 0x2b550504, 0x2b000c02, 0x6b0b1ca4,   // fi.et.es_654 fr.rw.vi_332  sv.vi.un_220 id.es.ceb_433
  0x06090112, 0x0d100fa0, 0x0a111ca0, 0x0a0817a9,   // en.pl.de_654 lv.lt.cs_322  id.ro.pt_322 sr.uk.mk_544
  // [43b0]
  0x23000519, 0x555364a7, 0x230501ad, 0x19056ea4,   // fr.ca.un_750 lg.ht.rw_532  en.fr.ca_643 blu.fr.gl_433
  0x05002b0c, 0x2a000f02, 0x0f000507, 0x0e046404,   // vi.fr.un_530 lv.mt.un_220  fr.lv.un_420 lg.fi.is_332
  0x0e190b05, 0x055501a4, 0x130c04ec, 0x1c1e2512,   // es.gl.is_333 en.rw.fr_433  fi.sv.et_644 eu.ms.id_654
  0x1c00530c, 0x1325040c, 0x170a08a9, 0x2500290d,   // ht.id.un_530 fi.eu.et_543  uk.mk.sr_544 sl.eu.un_540
  // [43c0]
  0x2d120aad, 0x0c000302, 0x2d033fa7, 0x13002308,   // pt.hu.sk_643 nl.sv.un_220  af.nl.sk_532 ca.et.un_430
  0x080c0602, 0x130e08a0, 0x2a002508, 0x04170a0b,   // de.sv.no_222 no.is.et_322  eu.mt.un_430 mk.sr.ru_542
  0x0e00080b, 0x121a6b04, 0x07041004, 0x06315312,   // no.is.un_520 ceb.tl.hu_332  be.ru.bg_332 ht.az.de_654
  0x12002002, 0x2b250cad, 0x171664a0, 0x1f101ead,   // sq.hu.un_220 sv.eu.vi_643  lg.hr.sr_322 ms.lt.cy_643
  // [43d0]
  0x0b1906b9, 0x645528af, 0x0c1304ec, 0x3f080309,   // de.gl.es_842 sw.rw.lg_655  fi.et.sv_644 nl.no.af_444
  0x10001f21, 0x12002d22, 0x28001b13, 0x25000822,   // cy.lt.un_860 sk.hu.un_870  tr.sw.un_650 no.eu.un_870
  0x28001e09, 0x2a00280c, 0x64095504, 0x100408a7,   // ms.sw.un_440 sw.mt.un_530  rw.pl.lg_332 uk.ru.be_532
  0x25006407, 0x556428ec, 0x11002509, 0x20551107,   // lg.eu.un_420 sw.lg.rw_644  eu.ro.un_440 ro.rw.sq_432
  // [43e0]
  0x1f00101a, 0x012818a0, 0x11130ca0, 0x2d550607,   // lt.cy.un_760 ga.sw.en_322  sv.et.ro_322 de.rw.sk_432
  0x015308ee, 0x2a1f23a0, 0x20311ba0, 0x27200ca6,   // no.ht.en_422 ca.cy.mt_322  tr.az.sq_322 sv.sq.gd_521
  0x1000090c, 0x64552808, 0x0b001905, 0x2a55280c,   // pl.lt.un_530 sw.rw.lg_443  gl.es.un_330 sw.rw.mt_543
  0x1f00101b, 0x10001f12, 0x17530207, 0x28556402,   // lt.cy.un_770 cy.lt.un_640  da.ht.sr_432 lg.rw.sw_222
  // [43f0]
  0x0a040855, 0x08000613, 0x041007a4, 0x1b002105,   // uk.ru.mk_442 de.no.un_650  bg.be.ru_433 jw.tr.un_330
  0x64080208, 0x0c082a08, 0x080201a9, 0x040a080c,   // da.no.lg_443 mt.no.sv_443  en.da.no_544 uk.mk.ru_543
  0x17000919, 0x1e001602, 0x12000d04, 0x1a28230b,   // pl.sr.un_750 hr.ms.un_220  cs.hu.un_320 ca.sw.tl_542
  0x19005502, 0x1c0d1309, 0x27002108, 0x18001221,   // rw.gl.un_220 bh.ne.mr_444  jw.gd.un_430 ur.ar.un_860

  // [4400]
  0x1f000512, 0x023f030d, 0x120e2307, 0x021a6b05,   // fr.cy.un_640 nl.af.da_554  ca.is.hu_432 ceb.tl.da_333
  0x16000604, 0x6b1a5507, 0x0800070d, 0x0d001319,   // de.hr.un_320 rw.tl.ceb_432  bg.uk.un_540 bh.ne.un_750
  0x27640707, 0x080c0213, 0x64003f07, 0x082053a4,   // it.lg.gd_432 da.sv.no_665  af.lg.un_420 ht.sq.no_433
  0x2a0118a0, 0x07171007, 0x0d00180d, 0x180603a4,   // ga.en.mt_322 be.sr.bg_432  ga.cs.un_540 nl.de.ga_433
  // [4410]
  0x23002d04, 0x13005504, 0x6b0d2da7, 0x061b0c07,   // sk.ca.un_320 rw.et.un_320  sk.cs.ceb_532 sv.tr.de_432
  0x160d2907, 0x1c001802, 0x53000307, 0x2d2b25a0,   // sl.cs.hr_432 ga.id.un_220  nl.ht.un_420 eu.vi.sk_322
  0x1a6b2513, 0x040711ee, 0x2a180605, 0x1c001b02,   // eu.ceb.tl_665 ro.bg.ru_422  de.ga.mt_333 tr.id.un_220
  0x0b000105, 0x0d131cad, 0x03005519, 0x1c00180b,   // en.es.un_330 mr.bh.ne_643  rw.nl.un_750 ga.id.un_520
  // [4420]
  0x182827a7, 0x28001312, 0x06051c02, 0x042b2d07,   // gd.sw.ga_532 et.sw.un_640  id.fr.de_222 sk.vi.fi_432
  0x29041fee, 0x53010502, 0x642506ad, 0x2a0764ec,   // cy.fi.sl_422 fr.en.ht_222  de.eu.lg_643 lg.it.mt_644
  0x011c31a0, 0x1e120607, 0x10170408, 0x212a1112,   // az.id.en_322 de.hu.ms_432  ru.sr.be_443 ro.mt.jw_654
  0x1a2a11ad, 0x17002107, 0x202855a4, 0x281e1ca4,   // ro.mt.tl_643 jw.sr.un_420  rw.sw.sq_433 id.ms.sw_433
  // [4430]
  0x28551b0d, 0x6b205507, 0x111c1ea4, 0x11045502,   // tr.rw.sw_554 rw.sq.ceb_432  ms.id.ro_433 rw.fi.ro_222
  0x252155a4, 0x01081fee, 0x55281107, 0x55282155,   // rw.jw.eu_433 cy.no.en_422  ro.sw.rw_432 jw.sw.rw_442
  0x01212b07, 0x0e111304, 0x5500250d, 0x55281108,   // vi.jw.en_432 et.ro.is_332  eu.rw.un_540 ro.sw.rw_443
  0x196b050b, 0x0a001c04, 0x273f0307, 0x31211b60,   // fr.ceb.gl_542 id.pt.un_320  nl.af.gd_432 tr.jw.az_664
  // [4440]
  0x01181f07, 0x0d073fa0, 0x160620a0, 0x55112811,   // cy.ga.en_432 af.it.cs_322  sq.de.hr_322 sw.ro.rw_653
  0x1712090d, 0x25001108, 0x04112a0c, 0x061f0d04,   // pl.hu.sr_554 ro.eu.un_430  mt.ro.fi_543 cs.cy.de_332
  0x11552107, 0x10112a0d, 0x31001114, 0x1a215555,   // jw.rw.ro_432 mt.ro.lt_554  ro.az.un_660 rw.jw.tl_442
  0x201a1108, 0x2a1a110c, 0x19121860, 0x0a17070b,   // ro.tl.sq_443 ro.tl.mt_543  ga.hu.gl_664 bg.sr.mk_542
  // [4450]
  0x1b2831af, 0x170710ee, 0x191812a0, 0x551c21ad,   // az.sw.tr_655 be.bg.sr_422  hu.ga.gl_322 jw.id.rw_643
  0x3f02290c, 0x020c1202, 0x0d092d08, 0x112506ad,   // sl.da.af_543 hu.sv.da_222  sk.pl.cs_443 de.eu.ro_643
  0x172007a9, 0x023f6ba0, 0x12000b02, 0x53000904,   // it.sq.sr_544 ceb.af.da_322  es.hu.un_220 pl.ht.un_320
  0x1a0123a0, 0x0e006419, 0x640c08a0, 0x13211e07,   // ca.en.tl_322 lg.is.un_750  no.sv.lg_322 ms.jw.et_432
  // [4460]
  0x23000c04, 0x550864ee, 0x1e0b1c07, 0x2800130d,   // sv.ca.un_320 lg.no.rw_422  id.es.ms_432 et.sw.un_540
  0x0f64250c, 0x53640307, 0x6400040d, 0x04110760,   // eu.lg.lv_543 nl.lg.ht_432  fi.lg.un_540 bg.ro.ru_664
  0x08001e0d, 0x190a0bee, 0x1b000a12, 0x2d120da7,   // ms.no.un_540 es.pt.gl_422  pt.tr.un_640 cs.hu.sk_532
  0x212029ee, 0x0e000d08, 0x170408ad, 0x0400640e,   // sl.sq.jw_422 cs.is.un_430  uk.ru.sr_643 lg.fi.un_550
  // [4470]
  0x010827a7, 0x07041013, 0x1f006402, 0x09002d07,   // gd.no.en_532 be.ru.bg_665  lg.cy.un_220 sk.pl.un_420
  0x09002d18, 0x0d162dee, 0x28001007, 0x12052d02,   // sk.pl.un_740 sk.hr.cs_422  lt.sw.un_420 sk.fr.hu_222
  0x05001202, 0x21041308, 0x0f13210c, 0x0f1c1008,   // hu.fr.un_220 et.fi.jw_443  jw.et.lv_543 lt.id.lv_443
  0x02122808, 0x13000f23, 0x19002513, 0x07192707,   // sw.hu.da_443 lv.et.un_880  eu.gl.un_650 gd.gl.it_432
  // [4480]
  0x17040aa7, 0x290d2d0c, 0x0d122daf, 0x180f1055,   // mk.ru.sr_532 sk.cs.sl_543  sk.hu.cs_655 lt.lv.ga_442
  0x09060fa0, 0x0c001f07, 0x02001f08, 0x13041ba4,   // lv.de.pl_322 cy.sv.un_420  cy.da.un_430 tr.fi.et_433
  0x0916020c, 0x2a0c11a4, 0x1707080c, 0x0c003f02,   // da.hr.pl_543 ro.sv.mt_433  uk.bg.sr_543 af.sv.un_220
  0x0a1017a0, 0x2b29120c, 0x12286408, 0x281b2aa0,   // sr.be.mk_322 hu.sl.vi_543  lg.sw.hu_443 mt.tr.sw_322
  // [4490]
  0x6406040c, 0x21185307, 0x182b01a0, 0x0a2719a9,   // fi.de.lg_543 ht.ga.jw_432  en.vi.ga_322 gl.gd.pt_544
  0x13001e09, 0x1f000c0d, 0x55000d08, 0x0c0111a9,   // ms.et.un_440 sv.cy.un_540  cs.rw.un_430 ro.en.sv_544
  0x31002a13, 0x64001f19, 0x190b01a4, 0x1c1e3f5a,   // mt.az.un_650 cy.lg.un_750  en.es.gl_433 af.ms.id_553
  0x0e051904, 0x0c3f0e07, 0x056455ad, 0x07000a09,   // gl.fr.is_332 is.af.sv_432  rw.lg.fr_643 mk.bg.un_440
  // [44a0]
  0x08071107, 0x27642312, 0x170a1009, 0x0a080414,   // ro.bg.uk_432 ca.lg.gd_654  be.mk.sr_444 ru.uk.mk_666
  0x0c0228a0, 0x1100280d, 0x04270807, 0x64000104,   // sw.da.sv_322 sw.ro.un_540  no.gd.fi_432 en.lg.un_320
  0x29120c04, 0x256b3f04, 0x0455280d, 0x08040a0b,   // sv.hu.sl_332 af.ceb.eu_332  sw.rw.fi_554 mk.ru.uk_542
  0x0428295a, 0x0c231ca4, 0x550f0708, 0x18030507,   // sl.sw.fi_553 id.ca.sv_433  it.lv.rw_443 fr.nl.ga_432
  // [44b0]
  0x05031ba9, 0x17552da0, 0x0c211105, 0x0e55645a,   // tr.nl.fr_544 sk.rw.sr_322  ro.jw.sv_333 lg.rw.is_553
  0x10270408, 0x280820a4, 0x2a095507, 0x646b5512,   // fi.gd.lt_443 sq.no.sw_433  rw.pl.mt_432 rw.ceb.lg_654
  0x0d00120c, 0x1827010c, 0x051827af, 0x2a0712a4,   // hu.cs.un_530 en.gd.ga_543  gd.ga.fr_655 hu.it.mt_433
  0x2855210c, 0x016b06a0, 0x3100110e, 0x0c173fa0,   // jw.rw.sw_543 de.ceb.en_322  ro.az.un_550 af.sr.sv_322
  // [44c0]
  0x6b050107, 0x16041708, 0x1c000307, 0x095564a9,   // en.fr.ceb_432 sr.fi.hr_443  nl.id.un_420 lg.rw.pl_544
  0x28006b09, 0x55001e0e, 0x553f1f07, 0x64042114,   // ceb.sw.un_440 ms.rw.un_550  cy.af.rw_432 jw.fi.lg_666
  0x05000e04, 0x29002808, 0x2900081a, 0x17162812,   // is.fr.un_320 sw.sl.un_430  no.sl.un_760 sw.hr.sr_654
  0x2b3f0307, 0x07292aa4, 0x2a001e04, 0x0a0807ad,   // nl.af.vi_432 mt.sl.it_433  ms.mt.un_320 bg.uk.mk_643
  // [44d0]
  0x160a1907, 0x2a006b04, 0x09001c11, 0x1110040c,   // gl.pt.hr_432 ceb.mt.un_320  mr.hi.un_630 ru.be.ro_543
  0x032a01a0, 0x291705a7, 0x130f0308, 0x172925a9,   // en.mt.nl_322 fr.sr.sl_532  nl.lv.et_443 eu.sl.sr_544
  0x551a2812, 0x041711ad, 0x64001c04, 0x0f000908,   // sw.tl.rw_654 ro.sr.ru_643  id.lg.un_320 pl.lv.un_430
  0x6b1a2814, 0x3f080c0d, 0x6b1a10a9, 0x0c000212,   // sw.tl.ceb_666 sv.no.af_554  lt.tl.ceb_544 da.sv.un_640
  // [44e0]
  0x0a000814, 0x64551aee, 0x08002a11, 0x551a21a9,   // uk.mk.un_660 tl.rw.lg_422  mt.no.un_630 jw.tl.rw_544
  0x1b002902, 0x111e1c04, 0x1f6e6b08, 0x19531fa0,   // sl.tr.un_220 id.ms.ro_332  ceb.blu.cy_443 cy.ht.gl_322
  0x6b0f1aad, 0x172016ec, 0x01096404, 0x2916250d,   // tl.lv.ceb_643 hr.sq.sr_644  lg.pl.en_332 eu.hr.sl_554
  0x3f530505, 0x0c00020e, 0x1b645513, 0x0a172da0,   // fr.ht.af_333 da.sv.un_550  rw.lg.tr_665 sk.sr.pt_322
  // [44f0]
  0x0c0f04af, 0x130425a7, 0x081011a7, 0x16002d09,   // fi.lv.sv_655 eu.fi.et_532  ro.be.uk_532 sk.hr.un_440
  0x111008af, 0x6b1a1009, 0x3f211c04, 0x2a00311a,   // uk.be.ro_655 lt.tl.ceb_444  id.jw.af_332 az.mt.un_760
  0x27080c04, 0x6b0818ee, 0x28645508, 0x1f00060c,   // sv.no.gd_332 ga.no.ceb_422  rw.lg.sw_443 de.cy.un_530
  0x1b136b09, 0x09000204, 0x55005307, 0x11050ba0,   // ceb.et.tr_444 da.pl.un_320  ht.rw.un_420 es.fr.ro_322
  // [4500]
  0x040b2902, 0x0d000221, 0x022a0d07, 0x0d2002a4,   // sl.es.fi_222 da.cs.un_860  cs.mt.da_432 da.sq.cs_433
  0x0b110704, 0x11000a04, 0x050d11a7, 0x1c211ea4,   // it.ro.es_332 pt.ro.un_320  ro.cs.fr_532 ms.jw.id_433
  0x270f2855, 0x19001212, 0x011a0da4, 0x0f002807,   // sw.lv.gd_442 hu.gl.un_640  cs.tl.en_433 sw.lv.un_420
  0x13002107, 0x062001a0, 0x130821ec, 0x53006409,   // jw.et.un_420 en.sq.de_322  jw.no.et_644 lg.ht.un_440
  // [4510]
  0x070a10a9, 0x0e2a11ac, 0x28000704, 0x11000502,   // be.mk.bg_544 ro.mt.is_632  it.sw.un_320 fr.ro.un_220
  0x121311ec, 0x0300090b, 0x112113ad, 0x25080209,   // ro.et.hu_644 pl.nl.un_520  et.jw.ro_643 da.no.eu_444
  0x0b0a2309, 0x21131ca4, 0x130811a9, 0x2900090e,   // ca.pt.es_444 id.et.jw_433  ro.no.et_544 pl.sl.un_550
  0x11000120, 0x21286b02, 0x211b310d, 0x18000e0c,   // en.ro.un_850 ceb.sw.jw_222  az.tr.jw_554 is.ga.un_530
  // [4520]
  0x040813a0, 0x1e256bad, 0x251211ad, 0x08006b04,   // et.no.fi_322 ceb.eu.ms_643  ro.hu.eu_643 ceb.no.un_320
  0x123f11a7, 0x111c2107, 0x100f1307, 0x1e2a11ad,   // ro.af.hu_532 jw.id.ro_432  et.lv.lt_432 ro.mt.ms_643
  0x531b0409, 0x3f00030b, 0x1c000804, 0x1221110c,   // fi.tr.ht_444 nl.af.un_520  no.id.un_320 ro.jw.hu_543
  0x2a215304, 0x0b002323, 0x080c0214, 0x1327110c,   // ht.jw.mt_332 ca.es.un_880  da.sv.no_666 ro.gd.et_543
  // [4530]
  0x311e1c02, 0x232053ac, 0x13091c60, 0x250a1109,   // id.ms.az_222 ht.sq.ca_632  mr.hi.bh_664 ro.pt.eu_444
  0x080c02a0, 0x21200209, 0x1f002102, 0x3f002a09,   // da.sv.no_322 da.sq.jw_444  jw.cy.un_220 mt.af.un_440
  0x0e0b64a0, 0x0c0a080b, 0x0e002104, 0x020c2305,   // lg.es.is_322 no.pt.sv_542  jw.is.un_320 ca.sv.da_333
  0x53083fa0, 0x0d170c07, 0x0a001113, 0x1e00280c,   // af.no.ht_322 sv.sr.cs_432  ro.mk.un_650 sw.ms.un_530
  // [4540]
  0x023f05ad, 0x020c080d, 0x0e003f20, 0x212d1607,   // fr.af.da_643 no.sv.da_554  af.is.un_850 hr.sk.jw_432
  0x0a53030c, 0x0b252307, 0x17060807, 0x2a211caf,   // nl.ht.pt_543 ca.eu.es_432  no.de.sr_432 id.jw.mt_655
  0x5500121b, 0x29001b0d, 0x1a6b010c, 0x16641707,   // hu.rw.un_770 tr.sl.un_540  en.ceb.tl_543 sr.lg.hr_432
  0x27190bad, 0x2500290c, 0x1b18270c, 0x1000110b,   // es.gl.gd_643 sl.eu.un_530  gd.ga.tr_543 ro.be.un_520
  // [4550]
  0x0d31550d, 0x08291205, 0x190b11af, 0x17160ca4,   // rw.az.cs_554 hu.sl.no_333  ro.es.gl_655 sv.hr.sr_433
  0x31000a05, 0x100704a4, 0x0a1e1c07, 0x0a08030b,   // pt.az.un_330 ru.bg.be_433  id.ms.pt_432 nl.no.pt_542
  0x12000205, 0x04000835, 0x101b2dad, 0x641b55a0,   // da.hu.un_330 uk.ru.un_A90  sk.tr.lt_643 rw.tr.lg_322
  0x31003f04, 0x55311b0c, 0x0d132d11, 0x21100f0c,   // af.az.un_320 tr.az.rw_543  sk.et.cs_653 lv.lt.jw_543
  // [4560]
  0x3100281b, 0x172528ee, 0x2307010c, 0x0912270c,   // sw.az.un_770 sw.eu.sr_422  en.it.ca_543 gd.hu.pl_543
  0x2b002702, 0x12002904, 0x13100f05, 0x07110812,   // gd.vi.un_220 sl.hu.un_320  lv.lt.et_333 uk.ro.bg_654
  0x0f201b0c, 0x0d2909a9, 0x01190b14, 0x530b28ad,   // tr.sq.lv_543 pl.sl.cs_544  es.gl.en_666 sw.es.ht_643
  0x1c006e07, 0x0c0e3f12, 0x081218af, 0x12000714,   // blu.id.un_420 af.is.sv_654  ga.hu.no_655 it.hu.un_660
  // [4570]
  0x0e020812, 0x080701a4, 0x291e1c05, 0x0d070a04,   // no.da.is_654 en.it.no_433  id.ms.sl_333 pt.it.cs_332
  0x2100120b, 0x05110104, 0x182a2ba0, 0x31000712,   // ur.fa.un_520 en.ro.fr_332  vi.mt.ga_322 it.az.un_640
  0x13001f1a, 0x130b6b12, 0x0c3f08a4, 0x6b001334,   // cy.et.un_760 ceb.es.et_654  no.af.sv_433 et.ceb.un_A80
  0x1a086ba6, 0x6b130d11, 0x052b2807, 0x1c1e210c,   // ceb.no.tl_521 cs.et.ceb_653  sw.vi.fr_432 jw.ms.id_543
  // [4580]
  0x06200202, 0x023f1304, 0x1b003102, 0x28005504,   // da.sq.de_222 et.af.da_332  az.tr.un_220 rw.sw.un_320
  0x31020ca4, 0x180c1307, 0x081e1c08, 0x23181f11,   // sv.da.az_433 et.sv.ga_432  id.ms.no_443 cy.ga.ca_653
  0x06000809, 0x1e6b1a04, 0x13000e02, 0x27010ea0,   // no.de.un_440 tl.ceb.ms_332  is.et.un_220 is.en.gd_322
  0x09002d0e, 0x120c1e04, 0x081302a4, 0x6b000d13,   // sk.pl.un_550 ms.sv.hu_332  da.et.no_433 cs.ceb.un_650
  // [4590]
  0x09000602, 0x13006b13, 0x190b18a4, 0x0b191307,   // de.pl.un_220 ceb.et.un_650  ga.es.gl_433 et.gl.es_432
  0x0600100d, 0x1b001e07, 0x0d092dec, 0x1a002a04,   // lt.de.un_540 ms.tr.un_420  sk.pl.cs_644 mt.tl.un_320
  0x0e17160c, 0x040711a4, 0x1b1a21a0, 0x0e13080d,   // hr.sr.is_543 ro.bg.ru_433  jw.tl.tr_322 no.et.is_554
  0x02121ca0, 0x1a5355ad, 0x53040d0b, 0x09001a04,   // id.hu.da_322 rw.ht.tl_643  cs.fi.ht_542 tl.pl.un_320
  // [45a0]
  0x1c000104, 0x6b080204, 0x070904ac, 0x551a2808,   // en.id.un_320 da.no.ceb_332  fi.pl.it_632 sw.tl.rw_443
  0x08030204, 0x1b1a1ca0, 0x12111a0c, 0x1100230d,   // da.nl.no_332 id.tl.tr_322  tl.ro.hu_543 ca.ro.un_540
  0x1a2101a0, 0x211a6b0d, 0x111b6408, 0x090b2508,   // en.jw.tl_322 ceb.tl.jw_554  lg.tr.ro_443 eu.es.pl_443
  0x07001013, 0x061e1ca4, 0x07000407, 0x29161ca4,   // be.bg.un_650 id.ms.de_433  fi.it.un_420 id.hr.sl_433
  // [45b0]
  0x093f0355, 0x2d00160e, 0x10002809, 0x02250107,   // nl.af.pl_442 hr.sk.un_550  sw.lt.un_440 en.eu.da_432
  0x1b553113, 0x012305ac, 0x2a0c5302, 0x6b2a31ad,   // az.rw.tr_665 fr.ca.en_632  ht.sv.mt_222 az.mt.ceb_643
  0x160c1204, 0x086404a0, 0x17292d0c, 0x093f11a0,   // hu.sv.hr_332 fi.lg.no_322  sk.sl.sr_543 ro.af.pl_322
  0x16002a05, 0x0c002704, 0x2a6b1aad, 0x1e1c2a05,   // mt.hr.un_330 gd.sv.un_320  tl.ceb.mt_643 mt.id.ms_333
  // [45c0]
  0x21000507, 0x0f091705, 0x2d001219, 0x1f0564a7,   // fr.jw.un_420 sr.pl.lv_333  hu.sk.un_750 lg.fr.cy_532
  0x0e0c0804, 0x081007ee, 0x08070aaf, 0x28552108,   // no.sv.is_332 bg.be.uk_422  mk.bg.uk_655 jw.rw.sw_443
  0x07081712, 0x1b000808, 0x03023f02, 0x28002709,   // sr.uk.bg_654 no.tr.un_430  af.da.nl_222 gd.sw.un_440
  0x1b000f0d, 0x08020c04, 0x31000a04, 0x0e290fee,   // lv.tr.un_540 sv.da.no_332  pt.az.un_320 lv.sl.is_422
  // [45d0]
  0x23072013, 0x2d0d0905, 0x28230f07, 0x0b0a0502,   // sq.it.ca_665 pl.cs.sk_333  lv.ca.sw_432 fr.pt.es_222
  0x06001b05, 0x180c06a0, 0x3f000614, 0x04001021,   // tr.de.un_330 de.sv.ga_322  de.af.un_660 be.ru.un_860
  0x0800230d, 0x64186ba0, 0x1c0e12a0, 0x5300200c,   // ca.no.un_540 ceb.ga.lg_322  hu.is.id_322 sq.ht.un_530
  0x02030107, 0x6b1c21a0, 0x09190fee, 0x1b182a08,   // en.nl.da_432 jw.id.ceb_322  lv.gl.pl_422 mt.ga.tr_443
  // [45e0]
  0x08070411, 0x090d17a4, 0x6b002512, 0x5300020d,   // ru.bg.uk_653 sr.cs.pl_433  eu.ceb.un_640 da.ht.un_540
  0x3f0608a4, 0x04111007, 0x100f0607, 0x06200c07,   // no.de.af_433 be.ro.ru_432  de.lv.lt_432 sv.sq.de_432
  0x0c270807, 0x1b3106a9, 0x0800042b, 0x3f00090d,   // no.gd.sv_432 de.az.tr_544  ru.uk.un_980 pl.af.un_540
  0x0f2329a4, 0x071105a0, 0x0a552104, 0x03060c07,   // sl.ca.lv_433 fr.ro.it_322  jw.rw.pt_332 sv.de.nl_432
  // [45f0]
  0x270e2507, 0x1c2321ee, 0x16000d05, 0x2a1a01a7,   // eu.is.gd_432 jw.ca.id_422  cs.hr.un_330 en.tl.mt_532
  0x310306ee, 0x070a2305, 0x251a6b55, 0x060801a0,   // de.nl.az_422 ca.pt.it_333  ceb.tl.eu_442 en.no.de_322
  0x13000608, 0x133f06a4, 0x125529a7, 0x13060404,   // de.et.un_430 de.af.et_433  sl.rw.hu_532 fi.de.et_332
  0x0a00230d, 0x18002118, 0x20113107, 0x0d081204,   // ca.pt.un_540 fa.ar.un_740  az.ro.sq_432 hu.no.cs_332
  // [4600]
  0x53000509, 0x0e000813, 0x176b06ee, 0x18120507,   // fr.ht.un_440 no.is.un_650  de.ceb.sr_422 fr.hu.ga_432
  0x0c005504, 0x2a002b04, 0x110a19a0, 0x23171613,   // rw.sv.un_320 vi.mt.un_320  gl.pt.ro_322 hr.sr.ca_665
  0x1105090c, 0x1b1a6b08, 0x0c06045a, 0x296b1655,   // pl.fr.ro_543 ceb.tl.tr_443  fi.de.sv_553 hr.ceb.sl_442
  0x0c0604ee, 0x02042ba0, 0x1a086ba0, 0x0f290802,   // fi.de.sv_422 vi.fi.da_322  ceb.no.tl_322 no.sl.lv_222
  // [4610]
  0x081a20a0, 0x0e001119, 0x252b1fee, 0x0f286e07,   // sq.tl.no_322 ro.is.un_750  cy.vi.eu_422 blu.sw.lv_432
  0x0a17080b, 0x0e2d18ac, 0x1a033f11, 0x0c080604,   // uk.sr.mk_542 ga.sk.is_632  af.nl.tl_653 de.no.sv_332
  0x033f210c, 0x170a0813, 0x0c000414, 0x1f0a2b09,   // jw.af.nl_543 uk.mk.sr_665  fi.sv.un_660 vi.pt.cy_444
  0x2700640b, 0x04111ba4, 0x04000614, 0x21080208,   // lg.gd.un_520 tr.ro.fi_433  de.fi.un_660 da.no.jw_443
  // [4620]
  0x551264a0, 0x29003f02, 0x0c000409, 0x31120709,   // lg.hu.rw_322 af.sl.un_220  fi.sv.un_440 it.hu.az_444
  0x6b1c1e11, 0x19000c02, 0x030c19ad, 0x030c19ac,   // ms.id.ceb_653 sv.gl.un_220  gl.sv.nl_643 gl.sv.nl_632
  0x0e001f08, 0x2a006412, 0x0a060eee, 0x04641312,   // cy.is.un_430 lg.mt.un_640  is.de.pt_422 et.lg.fi_654
  0x06002702, 0x011a6ba7, 0x552864af, 0x23052902,   // gd.de.un_220 ceb.tl.en_532  lg.sw.rw_655 sl.fr.ca_222
  // [4630]
  0x28001f07, 0x1c033fa7, 0x17081104, 0x21063f02,   // cy.sw.un_420 af.nl.id_532  ro.uk.sr_332 af.de.jw_222
  0x25001c08, 0x0b001214, 0x06000323, 0x010825a0,   // id.eu.un_430 hu.es.un_660  nl.de.un_880 eu.no.en_322
  0x171c1ba0, 0x131055a7, 0x01006404, 0x061207a0,   // tr.id.sr_322 rw.lt.et_532  lg.en.un_320 it.hu.de_322
  0x0300062b, 0x06000e0d, 0x04000609, 0x1c000921,   // de.nl.un_980 is.de.un_540  de.fi.un_440 hi.mr.un_860
  // [4640]
  0x10070a0c, 0x0e060c0c, 0x29535513, 0x2d0d1ba4,   // mk.bg.be_543 sv.de.is_543  rw.ht.sl_665 tr.cs.sk_433
  0x29002d12, 0x08270107, 0x063f0302, 0x030c06a7,   // sk.sl.un_640 en.gd.no_432  nl.af.de_222 de.sv.nl_532
  0x08000f19, 0x0c0b0804, 0x0e0c23ee, 0x27005504,   // lv.no.un_750 no.es.sv_332  ca.sv.is_422 rw.gd.un_320
  0x120b0ca0, 0x100a11a4, 0x552021a0, 0x23556404,   // sv.es.hu_322 ro.mk.be_433  jw.sq.rw_322 lg.rw.ca_332
  // [4650]
  0x10535507, 0x070810a7, 0x21072aee, 0x0d111302,   // rw.ht.lt_432 be.uk.bg_532  mt.it.jw_422 et.ro.cs_222
  0x20000c1a, 0x1f003f02, 0x292016a0, 0x313f0fa7,   // sv.sq.un_760 af.cy.un_220  hr.sq.sl_322 lv.af.az_532
  0x08000912, 0x12000c07, 0x0c130407, 0x1a046ba4,   // pl.no.un_640 sv.hu.un_420  fi.et.sv_432 ceb.fi.tl_433
  0x29001312, 0x18272b07, 0x0a1711ad, 0x020608a9,   // et.sl.un_640 vi.gd.ga_432  ro.sr.mk_643 no.de.da_544
  // [4660]
  0x25030407, 0x211e1ba9, 0x020c3f05, 0x16000c02,   // fi.nl.eu_432 tr.ms.jw_544  af.sv.da_333 sv.hr.un_220
  0x06040307, 0x3f1f0e60, 0x1f00271a, 0x21041ea0,   // nl.fi.de_432 is.cy.af_664  gd.cy.un_760 ms.fi.jw_322
  0x052b2004, 0x21001304, 0x2a1b31a4, 0x081716ad,   // sq.vi.fr_332 et.jw.un_320  az.tr.mt_433 hr.sr.no_643
  0x0e132aad, 0x1b216b08, 0x100428ad, 0x052304ad,   // mt.et.is_643 ceb.jw.tr_443  sw.fi.lt_643 fi.ca.fr_643
  // [4670]
  0x080a17ee, 0x2a040d07, 0x1b0c20a0, 0x0421200c,   // sr.mk.uk_422 cs.fi.mt_432  sq.sv.tr_322 sq.jw.fi_543
  0x041108a4, 0x201e1c0d, 0x11001c09, 0x08001b08,   // uk.ro.ru_433 id.ms.sq_554  id.ro.un_440 tr.no.un_430
  0x641220a0, 0x6b20230c, 0x010c09ee, 0x2000280d,   // sq.hu.lg_322 ca.sq.ceb_543  pl.sv.en_422 sw.sq.un_540
  0x1b2111ad, 0x17101107, 0x0c0220ee, 0x0410070e,   // ro.jw.tr_643 ro.be.sr_432  sq.da.sv_422 bg.be.ru_555
  // [4680]
  0x21131c07, 0x12002d19, 0x2a0e0a04, 0x2a2521a4,   // id.et.jw_432 sk.hu.un_750  pt.is.mt_332 jw.eu.mt_433
  0x08041714, 0x19070302, 0x1b2a04ac, 0x1b002a19,   // sr.ru.uk_666 nl.it.gl_222  fi.mt.tr_632 mt.tr.un_750
  0x530504a0, 0x13041ea4, 0x100708af, 0x07005504,   // fi.fr.ht_322 ms.fi.et_433  uk.bg.be_655 rw.it.un_320
  0x086b0907, 0x53000d13, 0x23002523, 0x0f31090b,   // pl.ceb.no_432 cs.ht.un_650  eu.ca.un_880 pl.az.lv_542
  // [4690]
  0x075528af, 0x28272a02, 0x231107a9, 0x1729160d,   // sw.rw.it_655 mt.gd.sw_222  it.ro.ca_544 hr.sl.sr_554
  0x31162905, 0x251306ee, 0x172d0912, 0x04070a08,   // sl.hr.az_333 de.et.eu_422  pl.sk.sr_654 mk.bg.ru_443
  0x17162d14, 0x31000f0d, 0x10170402, 0x2d0316a0,   // sk.hr.sr_666 lv.az.un_540  ru.sr.be_222 hr.nl.sk_322
  0x31230507, 0x091a6b07, 0x1200030c, 0x09000513,   // fr.ca.az_432 ceb.tl.pl_432  nl.hu.un_530 fr.pl.un_650
  // [46a0]
  0x551a1355, 0x080212a0, 0x1a6428a9, 0x23001f19,   // et.tl.rw_442 hu.da.no_322  sw.lg.tl_544 cy.ca.un_750
  0x2800641b, 0x0a2564ad, 0x21002b04, 0x042d0fee,   // lg.sw.un_770 lg.eu.pt_643  vi.jw.un_320 lv.sk.fi_422
  0x111a640c, 0x063f0c07, 0x25002a19, 0x132d0911,   // lg.tl.ro_543 sv.af.de_432  mt.eu.un_750 pl.sk.et_653
  0x2d160d04, 0x23006b04, 0x10645513, 0x2103050c,   // cs.hr.sk_332 ceb.ca.un_320  rw.lg.lt_665 fr.nl.jw_543
  // [46b0]
  0x20030f04, 0x1c066ba0, 0x231827a4, 0x1100531b,   // lv.nl.sq_332 ceb.de.id_322  gd.ga.ca_433 ht.ro.un_770
  0x190b18ee, 0x2a00231b, 0x042810ee, 0x0c001b08,   // ga.es.gl_422 ca.mt.un_770  lt.sw.fi_422 tr.sv.un_430
  0x3f0a12a0, 0x162911a4, 0x1b006b02, 0x12000a13,   // hu.pt.af_322 ro.sl.hr_433  ceb.tr.un_220 pt.hu.un_650
  0x100a07af, 0x641013ee, 0x3f06120c, 0x08005305,   // bg.mk.be_655 et.lt.lg_422  hu.de.af_543 ht.no.un_330
  // [46c0]
  0x03120a07, 0x6404100c, 0x1a002818, 0x2a201c07,   // pt.hu.nl_432 lt.fi.lg_543  sw.tl.un_740 id.sq.mt_432
  0x18001214, 0x21181204, 0x17001119, 0x6400250c,   // ur.ar.un_660 ur.ar.fa_332  ro.sr.un_750 eu.lg.un_530
  0x190a01ee, 0x2d0d13a0, 0x0a2d1707, 0x08022d07,   // en.pt.gl_422 et.cs.sk_322  sr.sk.pt_432 sk.da.no_432
  0x011f0407, 0x0e1e1cee, 0x20172907, 0x08030611,   // fi.cy.en_432 id.ms.is_422  sl.sr.sq_432 de.nl.no_653
  // [46d0]
  0x29032da0, 0x201716ee, 0x11070107, 0x0e1c1aa4,   // sk.nl.sl_322 hr.sr.sq_422  en.it.ro_432 tl.id.is_433
  0x1c211e55, 0x11041c09, 0x1f2953a0, 0x032d2007,   // ms.jw.id_442 id.fi.ro_444  ht.sl.cy_322 sq.sk.nl_432
  0x11070413, 0x17292d0d, 0x29000808, 0x31002908,   // ru.bg.ro_665 sk.sl.sr_554  no.sl.un_430 sl.az.un_430
  0x08030555, 0x182120af, 0x12552107, 0x0e0c06a4,   // fr.nl.no_442 sq.jw.ga_655  jw.rw.hu_432 de.sv.is_433
  // [46e0]
  0x2b001109, 0x0a00081a, 0x100811af, 0x1c001005,   // ro.vi.un_440 uk.mk.un_760  ro.uk.be_655 lt.id.un_330
  0x53000a08, 0x10001208, 0x2d2a1855, 0x11072a07,   // pt.ht.un_430 hu.lt.un_430  ga.mt.sk_442 mt.it.ro_432
  0x292d0da4, 0x0e001708, 0x160f1302, 0x0a0804a7,   // cs.sk.sl_433 sr.is.un_430  et.lv.hr_222 ru.uk.mk_532
  0x1b282104, 0x2b000704, 0x20001222, 0x131217ee,   // jw.sw.tr_332 it.vi.un_320  hu.sq.un_870 sr.hu.et_422
  // [46f0]
  0x640413a4, 0x122a0408, 0x532510a0, 0x172a5504,   // et.fi.lg_433 fi.mt.hu_443  lt.eu.ht_322 rw.mt.sr_332
  0x0800210c, 0x171b53a7, 0x03063f0d, 0x28001f02,   // jw.no.un_530 ht.tr.sr_532  af.de.nl_554 cy.sw.un_220
  0x531801ad, 0x0d001f07, 0x172d16ee, 0x120818a0,   // en.ga.ht_643 cy.cs.un_420  hr.sk.sr_422 ga.no.hu_322
  0x202821a9, 0x061f1804, 0x6b2b0107, 0x20005521,   // jw.sw.sq_544 ga.cy.de_332  en.vi.ceb_432 rw.sq.un_860
  // [4700]
  0x08002022, 0x292d1fee, 0x312917a4, 0x080417ad,   // sq.no.un_870 cy.sk.sl_422  sr.sl.az_433 sr.ru.uk_643
  0x13001002, 0x160e0408, 0x1a002b07, 0x160d2904,   // lt.et.un_220 fi.is.hr_443  vi.tl.un_420 sl.cs.hr_332
  0x2a001021, 0x2b002511, 0x090c21a0, 0x1a000108,   // lt.mt.un_860 eu.vi.un_630  jw.sv.pl_322 en.tl.un_430
  0x0e00120c, 0x06081307, 0x12000f09, 0x200c0804,   // hu.is.un_530 et.no.de_432  lv.hu.un_440 no.sv.sq_332
  // [4710]
  0x122021a7, 0x1f230b09, 0x0519280c, 0x0d252812,   // jw.sq.hu_532 es.ca.cy_444  sw.gl.fr_543 sw.eu.cs_654
  0x17162855, 0x080a0760, 0x19001004, 0x17070aa9,   // sw.hr.sr_442 bg.mk.uk_664  lt.gl.un_320 mk.bg.sr_544
  0x1b1a6b0d, 0x01131104, 0x3f031e0c, 0x2b006b08,   // ceb.tl.tr_554 ro.et.en_332  ms.nl.af_543 ceb.vi.un_430
  0x3f531f5a, 0x0b231fec, 0x2a311b09, 0x2b006b07,   // cy.ht.af_553 cy.ca.es_644  tr.az.mt_444 ceb.vi.un_420
  // [4720]
  0x01002509, 0x53111b07, 0x1b006b34, 0x17163fa0,   // eu.en.un_440 tr.ro.ht_432  ceb.tr.un_A80 af.hr.sr_322
  0x18272d07, 0x3f31130b, 0x23100405, 0x01530807,   // sk.gd.ga_432 et.az.af_542  fi.lt.ca_333 no.ht.en_432
  0x132506a4, 0x180e1955, 0x04251ba4, 0x53050111,   // de.eu.et_433 gl.is.ga_442  tr.eu.fi_433 en.fr.ht_653
  0x0d000402, 0x056401a0, 0x1a2801ad, 0x02080107,   // fi.cs.un_220 en.lg.fr_322  en.sw.tl_643 en.no.da_432
  // [4730]
  0x28002a07, 0x082301a4, 0x13270405, 0x04001a07,   // mt.sw.un_420 en.ca.no_433  fi.gd.et_333 tl.fi.un_420
  0x1a006402, 0x111064a4, 0x5505010c, 0x02172905,   // lg.tl.un_220 lg.lt.ro_433  en.fr.rw_543 sl.sr.da_333
  0x10001114, 0x05100405, 0x1c0d130e, 0x1b181ca0,   // ro.be.un_660 fi.lt.fr_333  bh.ne.mr_555 id.ga.tr_322
  0x072a0455, 0x080a1711, 0x08282112, 0x2b001e02,   // fi.mt.it_442 sr.mk.uk_653  jw.sw.no_654 ms.vi.un_220
  // [4740]
  0x25002709, 0x64001b0c, 0x08021faf, 0x2d0d0aa4,   // gd.eu.un_440 tr.lg.un_530  cy.da.no_655 pt.cs.sk_433
  0x080e0413, 0x040a1107, 0x0a000d0d, 0x0800100e,   // fi.is.no_665 ro.mk.ru_432  cs.pt.un_540 be.uk.un_550
  0x081b040c, 0x18271f0c, 0x0a18270c, 0x271f18a0,   // fi.tr.no_543 cy.gd.ga_543  gd.ga.pt_543 ga.cy.gd_322
  0x13201f0c, 0x1000270e, 0x0d0603ee, 0x31532812,   // cy.sq.et_543 gd.lt.un_550  nl.de.cs_422 sw.ht.az_654
  // [4750]
  0x29001118, 0x1f2701a4, 0x05000c1a, 0x0b033f0b,   // ro.sl.un_740 en.gd.cy_433  sv.fr.un_760 af.nl.es_542
  0x20286404, 0x0c060312, 0x18001121, 0x23170705,   // lg.sw.sq_332 nl.de.sv_654  ro.ga.un_860 it.sr.ca_333
  0x182327a4, 0x29001f04, 0x111b3102, 0x04030607,   // gd.ca.ga_433 cy.sl.un_320  az.tr.ro_222 de.nl.fi_432
  0x1b0c02ad, 0x311f0e07, 0x101707a6, 0x0c02035a,   // da.sv.tr_643 is.cy.az_432  bg.sr.be_521 nl.da.sv_553
  // [4760]
  0x17201607, 0x04030611, 0x02001f12, 0x08021fad,   // hr.sq.sr_432 de.nl.fi_653  cy.da.un_640 cy.da.no_643
  0x53000e02, 0x290625a0, 0x02200605, 0x2a2329ee,   // is.ht.un_220 eu.de.sl_322  de.sq.da_333 sl.ca.mt_422
  0x060c1fa0, 0x1f000309, 0x0a001004, 0x021312ad,   // cy.sv.de_322 nl.cy.un_440  be.mk.un_320 hu.et.da_643
  0x063f03a0, 0x1c0e1b04, 0x2a0e08a9, 0x06231f07,   // nl.af.de_322 tr.is.id_332  no.is.mt_544 cy.ca.de_432
  // [4770]
  0x211223ad, 0x29021fa4, 0x230c04a0, 0x1b531a08,   // ca.hu.jw_643 cy.da.sl_433  fi.sv.ca_322 tl.ht.tr_443
  0x08170708, 0x12001a09, 0x09001104, 0x0e000207,   // bg.sr.uk_443 tl.hu.un_440  ro.pl.un_320 da.is.un_420
  0x02080c55, 0x20191104, 0x3f0c0805, 0x11000405,   // sv.no.da_442 ro.gl.sq_332  no.sv.af_333 ru.ro.un_330
  0x0a08070d, 0x0603080c, 0x11002905, 0x11000604,   // bg.uk.mk_554 no.nl.de_543  sl.ro.un_330 de.ro.un_320
  // [4780]
  0x1c0c08a0, 0x040811ac, 0x0c030e09, 0x31000704,   // no.sv.id_322 ro.uk.ru_632  is.nl.sv_444 it.az.un_320
  0x0e0801a0, 0x02031304, 0x200c11a4, 0x0c023f05,   // en.no.is_322 et.nl.da_332  ro.sv.sq_433 af.da.sv_333
  0x062718a9, 0x06002512, 0x190b0a0c, 0x0f00080c,   // ga.gd.de_544 eu.de.un_640  pt.es.gl_543 no.lv.un_530
  0x290203ad, 0x01002414, 0x0a11040c, 0x16232902,   // nl.da.sl_643 yi.iw.un_660  ru.ro.mk_543 sl.ca.hr_222
  // [4790]
  0x23000113, 0x6b1e1ca4, 0x2a2b6e04, 0x06080208,   // en.ca.un_650 id.ms.ceb_433  blu.vi.mt_332 da.no.de_443
  0x06106baf, 0x0520235a, 0x13030107, 0x2300531a,   // ceb.lt.de_655 ca.sq.fr_553  en.nl.et_432 ht.ca.un_760
  0x25043f04, 0x64552504, 0x080410a4, 0x13001611,   // af.fi.eu_332 eu.rw.lg_332  be.ru.uk_433 hr.et.un_630
  0x110a070c, 0x033f06a4, 0x20252aad, 0x06033f14,   // bg.mk.ro_543 de.af.nl_433  mt.eu.sq_643 af.nl.de_666
  // [47a0]
  0x1805010c, 0x2d001f19, 0x0c080605, 0x17002d09,   // en.fr.ga_543 cy.sk.un_750  de.no.sv_333 sk.sr.un_440
  0x05271807, 0x0e080c04, 0x1117080c, 0x161e1c5a,   // ga.gd.fr_432 sv.no.is_332  uk.sr.ro_543 id.ms.hr_553
  0x13080209, 0x130c0612, 0x5300231d, 0x10080e55,   // da.no.et_444 de.sv.et_654  ca.ht.un_820 is.no.lt_442
  0x172718a4, 0x0718275a, 0x0600251b, 0x080c060c,   // ga.gd.sr_433 gd.ga.it_553  eu.de.un_770 de.sv.no_543
  // [47b0]
  0x112501ad, 0x19050a11, 0x130e0604, 0x0a2d0d08,   // en.eu.ro_643 pt.fr.gl_653  de.is.et_332 cs.sk.pt_443
  0x2a1827ee, 0x122d05a6, 0x13100f02, 0x0b2301a0,   // gd.ga.mt_422 fr.sk.hu_521  lv.lt.et_222 en.ca.es_322
  0x11000514, 0x0b0a2505, 0x021b6b07, 0x166b2a08,   // fr.ro.un_660 eu.pt.es_333  ceb.tr.da_432 mt.ceb.hr_443
  0x1b2d0d04, 0x10232111, 0x0e100f60, 0x04052508,   // cs.sk.tr_332 jw.ca.lt_653  lv.lt.is_664 eu.fr.fi_443
  // [47c0]
  0x082d0d13, 0x1e1f3fa7, 0x09002907, 0x64093f04,   // cs.sk.no_665 af.cy.ms_532  sl.pl.un_420 af.pl.lg_332
  0x0a120104, 0x07040a12, 0x6b000e13, 0x0500280d,   // en.hu.pt_332 mk.ru.bg_654  is.ceb.un_650 sw.fr.un_540
  0x2d3128a0, 0x100c3f08, 0x64315505, 0x2d006402,   // sw.az.sk_322 af.sv.lt_443  rw.az.lg_333 lg.sk.un_220
  0x080f10a9, 0x19001105, 0x0f251704, 0x166b0702,   // lt.lv.no_544 ro.gl.un_330  sr.eu.lv_332 it.ceb.hr_222
  // [47d0]
  0x0f3104a0, 0x03040ca0, 0x0300640c, 0x08000e07,   // fi.az.lv_322 sv.fi.nl_322  lg.nl.un_530 is.no.un_420
  0x05005313, 0x1b000c0c, 0x213f1fee, 0x18280107,   // ht.fr.un_650 sv.tr.un_530  cy.af.jw_422 en.sw.ga_432
  0x180e19a7, 0x1a5507ee, 0x2d0d04a0, 0x102325a0,   // gl.is.ga_532 it.rw.tl_422  fi.cs.sk_322 eu.ca.lt_322
  0x1f001104, 0x06020c07, 0x110417af, 0x252718ec,   // ro.cy.un_320 sv.da.de_432  sr.ru.ro_655 ga.gd.eu_644
  // [47e0]
  0x29002004, 0x20160a04, 0x080c0607, 0x0f002a02,   // sq.sl.un_320 pt.hr.sq_332  de.sv.no_432 mt.lv.un_220
  0x5500530e, 0x29005307, 0x0b295512, 0x28002107,   // ht.rw.un_550 ht.sl.un_420  rw.sl.es_654 jw.sw.un_420
  0x10080fa4, 0x200f2da0, 0x0a070460, 0x08060ea0,   // lv.no.lt_433 sk.lv.sq_322  ru.bg.mk_664 is.de.no_322
  0x10000423, 0x09005504, 0x2a001808, 0x53002912,   // ru.be.un_880 rw.pl.un_320  ga.mt.un_430 sl.ht.un_640
  // [47f0]
  0x20001e13, 0x17005504, 0x1000290c, 0x0e070f0c,   // ms.sq.un_650 rw.sr.un_320  sl.lt.un_530 lv.it.is_543
  0x120f10a6, 0x172d2902, 0x3f250807, 0x02082504,   // lt.lv.hu_521 sl.sk.sr_222  no.eu.af_432 eu.no.da_332
  0x0204255a, 0x06032104, 0x080225ec, 0x1900230c,   // eu.fi.da_553 jw.nl.de_332  eu.da.no_644 ca.gl.un_530
  0x25033fad, 0x070105ee, 0x08002521, 0x171608ee,   // af.nl.eu_643 fr.en.it_422  eu.no.un_860 no.hr.sr_422

  // [4800]
  0x1a216ba4, 0x080229ee, 0x05002b0d, 0x212001ad,   // ceb.jw.tl_433 sl.da.no_422  vi.fr.un_540 en.sq.jw_643
  0x081f1205, 0x1105010c, 0x25000313, 0x13002d09,   // hu.cy.no_333 en.fr.ro_543  nl.eu.un_650 sk.et.un_440
  0x0c002104, 0x13005519, 0x20002108, 0x020610a0,   // jw.sv.un_320 rw.et.un_750  jw.sq.un_430 lt.de.da_322
  0x022508a7, 0x190a10a4, 0x170610a0, 0x3f002514,   // no.eu.da_532 lt.pt.gl_433  lt.de.sr_322 eu.af.un_660
  // [4810]
  0x121f01a7, 0x17101aa4, 0x06011fa0, 0x0d122d12,   // en.cy.hu_532 tl.lt.sr_433  cy.en.de_322 sk.hu.cs_654
  0x2d190b02, 0x0a08100d, 0x03203fa0, 0x3f031a02,   // es.gl.sk_222 be.uk.mk_554  af.sq.nl_322 tl.nl.af_222
  0x1716080b, 0x550525a4, 0x1c001004, 0x162d0da0,   // no.hr.sr_542 eu.fr.rw_433  lt.id.un_320 cs.sk.hr_322
  0x09211c0c, 0x111a1604, 0x0c3f03a7, 0x2a001112,   // id.jw.pl_543 hr.tl.ro_332  nl.af.sv_532 ro.mt.un_640
  // [4820]
  0x03013f02, 0x0d2d12a4, 0x3f030614, 0x23092507,   // af.en.nl_222 hu.sk.cs_433  de.nl.af_666 eu.pl.ca_432
  0x1e3f6ba0, 0x12190ea9, 0x55001a0d, 0x01000d04,   // ceb.af.ms_322 is.gl.hu_544  tl.rw.un_540 cs.en.un_320
  0x0e1b2a04, 0x1e1a1ca4, 0x53000621, 0x28055307,   // mt.tr.is_332 id.tl.ms_433  de.ht.un_860 ht.fr.sw_432
  0x0e1a6bad, 0x11006402, 0x160d0fee, 0x216e1a0c,   // ceb.tl.is_643 lg.ro.un_220  lv.cs.hr_422 tl.blu.jw_543
  // [4830]
  0x172029af, 0x01000704, 0x02002808, 0x04000d02,   // sl.sq.sr_655 it.en.un_320  sw.da.un_430 cs.fi.un_220
  0x551e1c07, 0x64001104, 0x1c1e2811, 0x551b5312,   // id.ms.rw_432 ro.lg.un_320  sw.ms.id_653 ht.tr.rw_654
  0x53552007, 0x216b1aa4, 0x03000121, 0x281c2009,   // sq.rw.ht_432 tl.ceb.jw_433  en.nl.un_860 sq.id.sw_444
  0x2b001909, 0x1a1e1c0c, 0x01271812, 0x0a07110d,   // gl.vi.un_440 id.ms.tl_543  ga.gd.en_654 ro.bg.mk_554
  // [4840]
  0x29000802, 0x0c000a0d, 0x010508a0, 0x1f00060d,   // no.sl.un_220 pt.sv.un_540  no.fr.en_322 de.cy.un_540
  0x13001902, 0x170711ac, 0x291116a0, 0x122555ad,   // gl.et.un_220 ro.bg.sr_632  hr.ro.sl_322 rw.eu.hu_643
  0x20250da0, 0x1b6b1a0c, 0x190a53a0, 0x20215309,   // cs.eu.sq_322 tl.ceb.tr_543  ht.pt.gl_322 ht.jw.sq_444
  0x1e1c28ec, 0x06010b09, 0x2d1604a0, 0x190b1a04,   // sw.id.ms_644 es.en.de_444  fi.hr.sk_322 tl.es.gl_332
  // [4850]
  0x09005505, 0x1a1c55a9, 0x28211c08, 0x6b1a1ca9,   // rw.pl.un_330 rw.id.tl_544  id.jw.sw_443 id.tl.ceb_544
  0x19120b04, 0x180955ee, 0x1e1c04ee, 0x23001604,   // es.hu.gl_332 rw.pl.ga_422  fi.id.ms_422 hr.ca.un_320
  0x01001b08, 0x23006e08, 0x2a23120c, 0x0e230107,   // tr.en.un_430 blu.ca.un_430  hu.ca.mt_543 en.ca.is_432
  0x0c53230c, 0x1a000802, 0x081629a0, 0x283f53a4,   // ca.ht.sv_543 no.tl.un_220  sl.hr.no_322 ht.af.sw_433
  // [4860]
  0x121a6b12, 0x5300161b, 0x530c23a4, 0x1c000304,   // ceb.tl.hu_654 hr.ht.un_770  ca.sv.ht_433 nl.id.un_320
  0x0c531f55, 0x532301a0, 0x04071108, 0x050823ee,   // cy.ht.sv_442 en.ca.ht_322  ro.bg.ru_443 ca.no.fr_422
  0x01002314, 0x02050107, 0x1e211c0b, 0x311b53ad,   // ca.en.un_660 en.fr.da_432  id.jw.ms_542 ht.tr.az_643
  0x03001104, 0x0e1304a0, 0x1c211ea0, 0x0c085305,   // ro.nl.un_320 fi.et.is_322  ms.jw.id_322 ht.no.sv_333
  // [4870]
  0x0e0c5308, 0x0c3153ad, 0x28001314, 0x051b53ad,   // ht.sv.is_443 ht.az.sv_643  et.sw.un_660 ht.tr.fr_643
  0x282113ad, 0x0e2353ee, 0x13001608, 0x2d0d10af,   // et.jw.sw_643 ht.ca.is_422  hr.et.un_430 lt.cs.sk_655
  0x551c2005, 0x041f2aec, 0x1004080e, 0x27002304,   // sq.id.rw_333 mt.cy.fi_644  uk.ru.be_555 ca.gd.un_320
  0x080411a6, 0x07040814, 0x0508010b, 0x170a04a0,   // ro.ru.uk_521 uk.ru.bg_666  en.no.fr_542 ru.mk.sr_322
  // [4880]
  0x010510a4, 0x041011ec, 0x011805ee, 0x2127180c,   // lt.fr.en_433 ro.be.ru_644  fr.ga.en_422 ga.gd.jw_543
  0x0c006b07, 0x02001804, 0x10000f0d, 0x010a07ee,   // ceb.sv.un_420 ga.da.un_320  lv.lt.un_540 it.pt.en_422
  0x55291755, 0x29001008, 0x3f001704, 0x070a1004,   // sr.sl.rw_442 lt.sl.un_430  sr.af.un_320 be.mk.bg_332
  0x23000507, 0x13000920, 0x550603ad, 0x29211e04,   // fr.ca.un_420 hi.bh.un_850  nl.de.rw_643 ms.jw.sl_332
  // [4890]
  0x0b0f53a4, 0x0f0d2d0c, 0x2a1a6ba0, 0x030208a4,   // ht.lv.es_433 sk.cs.lv_543  ceb.tl.mt_322 no.da.nl_433
  0x03213f04, 0x0204080c, 0x0b002922, 0x04002105,   // af.jw.nl_332 no.fi.da_543  sl.es.un_870 jw.fi.un_330
  0x040e2712, 0x5328270c, 0x0600310c, 0x03061f08,   // gd.is.fi_654 gd.sw.ht_543  az.de.un_530 cy.de.nl_443
  0x550603af, 0x061901a0, 0x271a0bad, 0x18271113,   // nl.de.rw_655 en.gl.de_322  es.tl.gd_643 ro.gd.ga_665
  // [48a0]
  0x1a191e0c, 0x041007ee, 0x28171602, 0x1a2b2707,   // ms.gl.tl_543 bg.be.ru_422  hr.sr.sw_222 gd.vi.tl_432
  0x1f00210d, 0x02006b0c, 0x21002502, 0x02100a05,   // jw.cy.un_540 ceb.da.un_530  eu.jw.un_220 pt.lt.da_333
  0x11191c04, 0x290d1ba0, 0x0f171660, 0x0803060c,   // id.gl.ro_332 tr.cs.sl_322  hr.sr.lv_664 de.nl.no_543
  0x21040107, 0x21201102, 0x28076ba0, 0x111e1c0c,   // en.fi.jw_432 ro.sq.jw_222  ceb.it.sw_322 id.ms.ro_543
  // [48b0]
  0x1c000607, 0x040f1c04, 0x192d1105, 0x06001e1a,   // de.id.un_420 id.lv.fi_332  ro.sk.gl_333 ms.de.un_760
  0x0a100712, 0x1c04110c, 0x100a07ad, 0x642053a4,   // bg.be.mk_654 ro.fi.id_543  bg.mk.be_643 ht.sq.lg_433
  0x190a1aa0, 0x0a0717a9, 0x190b23ec, 0x1f00180e,   // tl.pt.gl_322 sr.bg.mk_544  ca.es.gl_644 ga.cy.un_550
  0x256b3fa0, 0x0f000c07, 0x01001a0c, 0x16000f0c,   // af.ceb.eu_322 sv.lv.un_420  tl.en.un_530 lv.hr.un_530
  // [48c0]
  0x04111755, 0x6b1a0c07, 0x10002909, 0x01045304,   // sr.ro.ru_442 sv.tl.ceb_432  sl.lt.un_440 ht.fi.en_332
  0x17292aad, 0x162d0dad, 0x311b04ee, 0x53001108,   // mt.sl.sr_643 cs.sk.hr_643  fi.tr.az_422 ro.ht.un_430
  0x29165307, 0x02250807, 0x06022855, 0x1b312d08,   // ht.hr.sl_432 no.eu.da_432  sw.da.de_442 sk.az.tr_443
  0x086b04a7, 0x090d1c0d, 0x102a2d0c, 0x171629a6,   // fi.ceb.no_532 mr.ne.hi_554  sk.mt.lt_543 sl.hr.sr_521
  // [48d0]
  0x04071702, 0x11012107, 0x0800170e, 0x192108ee,   // sr.bg.ru_222 jw.en.ro_432  sr.uk.un_550 no.jw.gl_422
  0x13002808, 0x186b01a0, 0x13310cad, 0x533f0455,   // sw.et.un_430 en.ceb.ga_322  sv.az.et_643 fi.af.ht_442
  0x533f05a7, 0x0c0208ad, 0x1000170c, 0x033f27ee,   // fr.af.ht_532 no.da.sv_643  sr.be.un_530 gd.af.nl_422
  0x6b021fa0, 0x0a08070c, 0x1b120d02, 0x20033fa7,   // cy.da.ceb_322 bg.uk.mk_543  cs.hu.tr_222 af.nl.sq_532
  // [48e0]
  0x13040c07, 0x53080207, 0x12000c08, 0x18002120,   // sv.fi.et_432 da.no.ht_432  sv.hu.un_430 fa.ar.un_850
  0x030208ee, 0x050b0602, 0x06030107, 0x08000312,   // no.da.nl_422 de.es.fr_222  en.nl.de_432 nl.no.un_640
  0x02216b02, 0x131905ee, 0x0e100304, 0x1153050d,   // ceb.jw.da_222 fr.gl.et_422  nl.lt.is_332 fr.ht.ro_554
  0x013f03a4, 0x27110507, 0x0f000308, 0x11030512,   // nl.af.en_433 fr.ro.gd_432  nl.lv.un_430 fr.nl.ro_654
  // [48f0]
  0x1a0c10ad, 0x0e003113, 0x04000620, 0x23071ba7,   // lt.sv.tl_643 az.is.un_650  de.fi.un_850 tr.it.ca_532
  0x04000619, 0x0500110c, 0x55000a05, 0x2a071ba4,   // de.fi.un_750 ro.fr.un_530  pt.rw.un_330 tr.it.mt_433
  0x1e1c16ee, 0x1c002504, 0x641c1e07, 0x020305a9,   // hr.id.ms_422 eu.id.un_320  ms.id.lg_432 fr.nl.da_544
  0x0f1064a4, 0x0e0c0613, 0x18073108, 0x6b1105a7,   // lg.lt.lv_433 de.sv.is_665  az.it.ga_443 fr.ro.ceb_532
  // [4900]
  0x02030508, 0x2b00160e, 0x2117160d, 0x16190b04,   // fr.nl.da_443 hr.vi.un_550  hr.sr.jw_554 es.gl.hr_332
  0x031105a7, 0x2b01230c, 0x11000711, 0x0d292da9,   // fr.ro.nl_532 ca.en.vi_543  it.ro.un_630 sk.sl.cs_544
  0x532564a0, 0x09001322, 0x082a0713, 0x23102ba4,   // lg.eu.ht_322 bh.hi.un_870  it.mt.no_665 vi.lt.ca_433
  0x06002708, 0x00001742, 0x1e6b07ee, 0x04001735,   // gd.de.un_430 sr.un.un_C00  it.ceb.ms_422 sr.ru.un_A90
  // [4910]
  0x1c001602, 0x530308a9, 0x072a01a4, 0x130825ee,   // hr.id.un_220 no.nl.ht_544  en.mt.it_433 eu.no.et_422
  0x080604ad, 0x071c11ee, 0x0e252aa0, 0x25005314,   // fi.de.no_643 ro.id.it_422  mt.eu.is_322 ht.eu.un_660
  0x201e1c02, 0x0f1016a7, 0x060b03a4, 0x08216e02,   // id.ms.sq_222 hr.lt.lv_532  nl.es.de_433 blu.jw.no_222
  0x06001c08, 0x1b555308, 0x032a0807, 0x21003f1b,   // id.de.un_430 ht.rw.tr_443  no.mt.nl_432 af.jw.un_770
  // [4920]
  0x5307110c, 0x10002b12, 0x172d1608, 0x10033fa0,   // ro.it.ht_543 vi.lt.un_640  hr.sk.sr_443 af.nl.lt_322
  0x53001e02, 0x641207ac, 0x2820070c, 0x64000713,   // ms.ht.un_220 it.hu.lg_632  it.sq.sw_543 it.lg.un_650
  0x20070107, 0x110a6e09, 0x550507a4, 0x1300251a,   // en.it.sq_432 blu.pt.ro_444  it.fr.rw_433 eu.et.un_760
  0x0e000702, 0x04001c02, 0x25060304, 0x1a6e2808,   // it.is.un_220 id.fi.un_220  nl.de.eu_332 sw.blu.tl_443
  // [4930]
  0x02006e08, 0x29100f55, 0x13170f0d, 0x020c0608,   // blu.da.un_430 lv.lt.sl_442  lv.sr.et_554 de.sv.da_443
  0x55050d04, 0x251311ec, 0x04000922, 0x282b1812,   // cs.fr.rw_332 ro.et.eu_644  pl.fi.un_870 ga.vi.sw_654
  0x10006e2b, 0x1e0a1ca9, 0x0f112d0c, 0x10170802,   // blu.lt.un_980 id.pt.ms_544  sk.ro.lv_543 uk.sr.be_222
  0x29160fee, 0x0c2a01a4, 0x0c0608a0, 0x211125a4,   // lv.hr.sl_422 en.mt.sv_433  no.de.sv_322 eu.ro.jw_433
  // [4940]
  0x060309ac, 0x07006e05, 0x062a09a4, 0x2d090b12,   // pl.nl.de_632 blu.it.un_330  pl.mt.de_433 es.pl.sk_654
  0x3f032da9, 0x6e0f0714, 0x12001c02, 0x252006a0,   // sk.nl.af_544 it.lv.blu_666  id.hu.un_220 de.sq.eu_322
  0x01000722, 0x172a0f11, 0x206e2b05, 0x0d291ea0,   // it.en.un_870 lv.mt.sr_653  vi.blu.sq_333 ms.sl.cs_322
  0x1b0225ee, 0x17160f55, 0x3f000a07, 0x1a311b08,   // eu.da.tr_422 lv.hr.sr_442  pt.af.un_420 tr.az.tl_443
  // [4950]
  0x030b09a4, 0x110816a0, 0x0b042d07, 0x13040f0c,   // pl.es.nl_433 hr.no.ro_322  sk.fi.es_432 lv.fi.et_543
  0x050b0660, 0x031729ee, 0x1708020c, 0x642821ec,   // de.es.fr_664 sl.sr.nl_422  da.no.sr_543 jw.sw.lg_644
  0x270306a0, 0x131a6b12, 0x2d0b19ec, 0x02002913,   // de.nl.gd_322 ceb.tl.et_654  gl.es.sk_644 sl.da.un_650
  0x060c0208, 0x056b1ea0, 0x6b190b02, 0x250e0111,   // da.sv.de_443 ms.ceb.fr_322  es.gl.ceb_222 en.is.eu_653
  // [4960]
  0x0a190107, 0x10011a07, 0x0900290c, 0x05112304,   // en.gl.pt_432 tl.en.lt_432  sl.pl.un_530 ca.ro.fr_332
  0x10060e55, 0x0e0f0407, 0x31002508, 0x080e040c,   // is.de.lt_442 fi.lv.is_432  eu.az.un_430 fi.is.no_543
  0x022d0c05, 0x2d001807, 0x02061f07, 0x641f2aad,   // sv.sk.da_333 ga.sk.un_420  cy.de.da_432 mt.cy.lg_643
  0x07170a14, 0x20002508, 0x07001712, 0x1a002b04,   // mk.sr.bg_666 eu.sq.un_430  sr.bg.un_640 vi.tl.un_320
  // [4970]
  0x1900310c, 0x136b2112, 0x071b0f55, 0x0f002507,   // az.gl.un_530 jw.ceb.et_654  lv.tr.it_442 eu.lv.un_420
  0x281b530c, 0x161225a0, 0x08002504, 0x06002521,   // ht.tr.sw_543 eu.hu.hr_322  eu.no.un_320 eu.de.un_860
  0x29000804, 0x09111b07, 0x210f0708, 0x531125a9,   // no.sl.un_320 tr.ro.pl_432  it.lv.jw_443 eu.ro.ht_544
  0x0d1629ee, 0x29001e0d, 0x06640307, 0x10291fa4,   // sl.hr.cs_422 ms.sl.un_540  nl.lg.de_432 cy.sl.lt_433
  // [4980]
  0x642d0d13, 0x040a070e, 0x20251608, 0x1f040c04,   // cs.sk.lg_665 bg.mk.ru_555  hr.eu.sq_443 sv.fi.cy_332
  0x3f1c64a0, 0x191f210c, 0x0e002a12, 0x121053ee,   // lg.id.af_322 jw.cy.gl_543  mt.is.un_640 ht.lt.hu_422
  0x20171ca4, 0x0d171660, 0x11070a08, 0x0e072a07,   // id.sr.sq_433 hr.sr.cs_664  mk.bg.ro_443 mt.it.is_432
  0x6b080107, 0x0c2305a4, 0x1329090d, 0x18011fa0,   // en.no.ceb_432 fr.ca.sv_433  pl.sl.et_554 cy.en.ga_322
  // [4990]
  0x53006b19, 0x070a10a7, 0x07230da4, 0x06110504,   // ceb.ht.un_750 be.mk.bg_532  cs.ca.it_433 fr.ro.de_332
  0x045325ac, 0x23110507, 0x0c000304, 0x06080e13,   // eu.ht.fi_632 fr.ro.ca_432  nl.sv.un_320 is.no.de_665
  0x0c101aa0, 0x6455280b, 0x08001111, 0x1a011f07,   // tl.lt.sv_322 sw.rw.lg_542  ro.uk.un_630 cy.en.tl_432
  0x6b050108, 0x080a11a0, 0x01250202, 0x2a003113,   // en.fr.ceb_443 ro.mk.uk_322  da.eu.en_222 az.mt.un_650
  // [49a0]
  0x05531fa4, 0x07212a08, 0x5300290d, 0x13252a0c,   // cy.ht.fr_433 mt.jw.it_443  sl.ht.un_540 mt.eu.et_543
  0x0500190d, 0x202111a0, 0x03061f0c, 0x08002921,   // gl.fr.un_540 ro.jw.sq_322  cy.de.nl_543 sl.no.un_860
  0x17000a11, 0x08020609, 0x29000f0c, 0x070a080c,   // mk.sr.un_630 de.da.no_444  lv.sl.un_530 uk.mk.bg_543
  0x216b1aa0, 0x101117a4, 0x2b0625a7, 0x2a042513,   // tl.ceb.jw_322 sr.ro.be_433  eu.de.vi_532 eu.fi.mt_665
  // [49b0]
  0x132331ad, 0x033f0fa9, 0x0b230514, 0x041e1a07,   // az.ca.et_643 lv.af.nl_544  fr.ca.es_666 tl.ms.fi_432
  0x0400251a, 0x06020807, 0x6b1a1ca4, 0x02082508,   // eu.fi.un_760 no.da.de_432  id.tl.ceb_433 eu.no.da_443
  0x17080702, 0x21281aa9, 0x530b6ea0, 0x072b1faf,   // bg.uk.sr_222 tl.sw.jw_544  blu.es.ht_322 cy.vi.it_655
  0x230b05a7, 0x6b211ca0, 0x081a6b0d, 0x01001c08,   // fr.es.ca_532 id.jw.ceb_322  ceb.tl.no_554 id.en.un_430
  // [49c0]
  0x216e27a4, 0x23012504, 0x1c001e22, 0x2900100e,   // gd.blu.jw_433 eu.en.ca_332  ms.id.un_870 lt.sl.un_550
  0x190b31a0, 0x25232a04, 0x0f23040c, 0x55641e02,   // az.es.gl_322 mt.ca.eu_332  fi.ca.lv_543 ms.lg.rw_222
  0x060809ee, 0x53050408, 0x230411a9, 0x2d2b0d04,   // pl.no.de_422 fi.fr.ht_443  ro.fi.ca_544 cs.vi.sk_332
  0x062508a4, 0x043f1ca4, 0x06000405, 0x1b095312,   // no.eu.de_433 id.af.fi_433  fi.de.un_330 ht.pl.tr_654
  // [49d0]
  0x04171609, 0x101617a7, 0x28001a08, 0x0d092d12,   // hr.sr.fi_444 sr.hr.lt_532  tl.sw.un_430 sk.pl.cs_654
  0x190b31ee, 0x130f04ec, 0x1128250c, 0x06001008,   // az.es.gl_422 fi.lv.et_644  eu.sw.ro_543 lt.de.un_430
  0x6400310c, 0x1a6b10ad, 0x1e1a1c0b, 0x0f0812a0,   // az.lg.un_530 lt.ceb.tl_643  id.tl.ms_542 hu.no.lv_322
  0x060c1b0c, 0x6b001a20, 0x171611ac, 0x6b041caf,   // tr.sv.de_543 tl.ceb.un_850  ro.hr.sr_632 id.fi.ceb_655
  // [49e0]
  0x31085309, 0x252a200b, 0x04131a05, 0x1800252b,   // ht.no.az_444 sq.mt.eu_542  tl.et.fi_333 eu.ga.un_980
  0x1b1e1c0d, 0x12000e21, 0x16000d09, 0x12033f0e,   // id.ms.tr_554 is.hu.un_860  cs.hr.un_440 af.nl.hu_555
  0x2718100c, 0x230b0304, 0x23000302, 0x271f01a0,   // lt.ga.gd_543 nl.es.ca_332  nl.ca.un_220 en.cy.gd_322
  0x251e1c13, 0x6b121aad, 0x011f0f0c, 0x2500200c,   // id.ms.eu_665 tl.hu.ceb_643  lv.cy.en_543 sq.eu.un_530
  // [49f0]
  0x25091ea9, 0x080601a4, 0x6b006e0d, 0x0c0306a4,   // ms.pl.eu_544 en.de.no_433  blu.ceb.un_540 de.nl.sv_433
  0x010820a0, 0x03050107, 0x032917a4, 0x0c000108,   // sq.no.en_322 en.fr.nl_432  sr.sl.nl_433 en.sv.un_430
  0x12000614, 0x190a230e, 0x0c1f02a4, 0x281827ad,   // de.hu.un_660 ca.pt.gl_555  da.cy.sv_433 gd.ga.sw_643
  0x270b18a4, 0x1804010b, 0x2b1827ac, 0x212d0d07,   // ga.es.gd_433 en.fi.ga_542  gd.ga.vi_632 cs.sk.jw_432
  // [4a00]
  0x1b092904, 0x04050fa4, 0x0153280c, 0x111a27a4,   // sl.pl.tr_332 lv.fr.fi_433  sw.ht.en_543 gd.tl.ro_433
  0x0e120cad, 0x2d001812, 0x100413ee, 0x0000192d,   // sv.hu.is_643 ga.sk.un_640  et.fi.lt_422 gl.un.un_A00
  0x131c20a0, 0x53133fa4, 0x64002a08, 0x6b2018a0,   // sq.id.et_322 af.et.ht_433  mt.lg.un_430 ga.sq.ceb_322
  0x0a001a20, 0x17291307, 0x16033fa0, 0x061004ad,   // tl.pt.un_850 et.sl.sr_432  af.nl.hr_322 fi.lt.de_643
  // [4a10]
  0x1100071a, 0x0c000805, 0x12000e07, 0x6b000a2a,   // it.ro.un_760 no.sv.un_330  is.hu.un_420 pt.ceb.un_970
  0x05091f07, 0x28180aa0, 0x6b051355, 0x3f2801ee,   // cy.pl.fr_432 pt.ga.sw_322  et.fr.ceb_442 en.sw.af_422
  0x011f0ca0, 0x530d2705, 0x0f1a1307, 0x0306010c,   // sv.cy.en_322 gd.cs.ht_333  et.tl.lv_432 en.de.nl_543
  0x13001a04, 0x021308a9, 0x28001a0e, 0x2a1a01ad,   // tl.et.un_320 no.et.da_544  tl.sw.un_550 en.tl.mt_643
  // [4a20]
  0x06000a07, 0x0b2319a0, 0x12000a04, 0x210a1bee,   // pt.de.un_420 gl.ca.es_322  pt.hu.un_320 tr.pt.jw_422
  0x2912210c, 0x21000704, 0x3f0313a7, 0x110a10a9,   // jw.hu.sl_543 it.jw.un_320  et.nl.af_532 lt.pt.ro_544
  0x0810090e, 0x0a000819, 0x3f061007, 0x01002b09,   // pl.lt.no_555 uk.mk.un_750  lt.de.af_432 vi.en.un_440
  0x1f003f0b, 0x2b000708, 0x190d0ba0, 0x08040712,   // af.cy.un_520 it.vi.un_430  es.cs.gl_322 bg.ru.uk_654
  // [4a30]
  0x04000e19, 0x01532a07, 0x01001002, 0x0a2d11af,   // is.fi.un_750 mt.ht.en_432  lt.en.un_220 ro.sk.pt_655
  0x02000e23, 0x17040807, 0x1711080c, 0x23000404,   // is.da.un_880 uk.ru.sr_432  uk.ro.sr_543 fi.ca.un_320
  0x2a000e0c, 0x10080eec, 0x161b31a0, 0x0d001819,   // is.mt.un_530 is.no.lt_644  az.tr.hr_322 ga.cs.un_750
  0x271807a0, 0x216e2b07, 0x31002011, 0x1a1b6ba0,   // it.ga.gd_322 vi.blu.jw_432  sq.az.un_630 ceb.tr.tl_322
  // [4a40]
  0x2700282c, 0x212027ad, 0x022713a0, 0x55001f21,   // sw.gd.un_990 gd.sq.jw_643  et.gd.da_322 cy.rw.un_860
  0x2d0b1204, 0x1000091a, 0x290b0107, 0x1f53050c,   // hu.es.sk_332 pl.lt.un_760  en.es.sl_432 fr.ht.cy_543
  0x0a2301a0, 0x11002305, 0x29111f08, 0x290f10a7,   // en.ca.pt_322 ca.ro.un_330  cy.ro.sl_443 lt.lv.sl_532
  0x10000304, 0x072a1107, 0x081711a4, 0x02002502,   // nl.lt.un_320 ro.mt.it_432  ro.sr.uk_433 eu.da.un_220
  // [4a50]
  0x1a2855a4, 0x552d11ee, 0x20002304, 0x6e1f2ba4,   // rw.sw.tl_433 ro.sk.rw_422  ca.sq.un_320 vi.cy.blu_433
  0x281e1caf, 0x1f000a02, 0x1c002a07, 0x21121807,   // id.ms.sw_655 pt.cy.un_220  mt.id.un_420 ar.ur.fa_432
  0x281a0c04, 0x271221a6, 0x6b0216a0, 0x04000a0e,   // sv.tl.sw_332 jw.hu.gd_521  hr.da.ceb_322 mk.ru.un_550
  0x01000402, 0x01202811, 0x641a6ba4, 0x131a21a4,   // fi.en.un_220 sw.sq.en_653  ceb.tl.lg_433 jw.tl.et_433
  // [4a60]
  0x18002812, 0x3f03280d, 0x1a2813a4, 0x201c2802,   // sw.ga.un_640 sw.nl.af_554  et.sw.tl_433 sw.id.sq_222
  0x55000d0d, 0x090f1007, 0x04071307, 0x2b1f0aa7,   // cs.rw.un_540 lt.lv.pl_432  et.it.fi_432 pt.cy.vi_532
  0x2100010d, 0x022d0d04, 0x0c282104, 0x033f1aad,   // en.jw.un_540 cs.sk.da_332  jw.sw.sv_332 tl.af.nl_643
  0x1e1b1ca4, 0x13001102, 0x081017af, 0x11190b12,   // id.tr.ms_433 ro.et.un_220  sr.be.uk_655 es.gl.ro_654
  // [4a70]
  0x04001a02, 0x27122804, 0x04033f02, 0x64041312,   // tl.fi.un_220 sw.hu.gd_332  af.nl.fi_222 et.fi.lg_654
  0x190b0aaf, 0x1a3f13ee, 0x2a070405, 0x5300231a,   // pt.es.gl_655 et.af.tl_422  fi.it.mt_333 ca.ht.un_760
  0x2d291707, 0x07110aaf, 0x0c000d04, 0x0a002312,   // sr.sl.sk_432 mk.ro.bg_655  cs.sv.un_320 ca.pt.un_640
  0x041107a4, 0x07311b55, 0x202d09a6, 0x11001719,   // bg.ro.ru_433 tr.az.it_442  pl.sk.sq_521 sr.ro.un_750
  // [4a80]
  0x191b05ad, 0x1e1c1ba6, 0x040a0809, 0x201923a9,   // fr.tr.gl_643 tr.id.ms_521  uk.mk.ru_444 ca.gl.sq_544
  0x2d090d0c, 0x1b0e3112, 0x0f1304ee, 0x5300011a,   // cs.pl.sk_543 az.is.tr_654  fi.et.lv_422 en.ht.un_760
  0x09081e04, 0x050301a4, 0x2a001704, 0x090d2d12,   // ms.no.pl_332 en.nl.fr_433  sr.mt.un_320 sk.cs.pl_654
  0x0b311b12, 0x1b310b07, 0x03000807, 0x19230b60,   // tr.az.es_654 es.az.tr_432  no.nl.un_420 es.ca.gl_664
  // [4a90]
  0x0f061ba7, 0x1a002113, 0x1e1c1fa4, 0x0b311b04,   // tr.de.lv_532 jw.tl.un_650  cy.id.ms_433 tr.az.es_332
  0x2a001e08, 0x1801090c, 0x311b0ea6, 0x1b310e08,   // ms.mt.un_430 pl.en.ga_543  is.tr.az_521 is.az.tr_443
  0x0c121fad, 0x2d0d2709, 0x3f1f23a7, 0x2a1b31ad,   // cy.hu.sv_643 gd.cs.sk_444  ca.cy.af_532 az.tr.mt_643
  0x092d0d5a, 0x0c081f08, 0x1a55640c, 0x121e1c09,   // cs.sk.pl_553 cy.no.sv_443  lg.rw.tl_543 id.ms.hu_444
  // [4aa0]
  0x060c3f08, 0x12130e04, 0x062a23a4, 0x136b1aa9,   // af.sv.de_443 is.et.hu_332  ca.mt.de_433 tl.ceb.et_544
  0x0900530c, 0x0e231fad, 0x06191f0c, 0x1f002319,   // ht.pl.un_530 cy.ca.is_643  cy.gl.de_543 ca.cy.un_750
  0x282d0d55, 0x033f1207, 0x0c081fa4, 0x6413550e,   // cs.sk.sw_442 hu.af.nl_432  cy.no.sv_433 rw.et.lg_555
  0x31551b07, 0x1c645504, 0x2a033f0c, 0x10000609,   // tr.rw.az_432 rw.lg.id_332  af.nl.mt_543 de.lt.un_440
  // [4ab0]
  0x05120aa0, 0x20002822, 0x1b005304, 0x286455a9,   // pt.hu.fr_322 sw.sq.un_870  ht.tr.un_320 rw.lg.sw_544
  0x13000405, 0x2d0c23a7, 0x0f1210ad, 0x0a080411,   // fi.et.un_330 ca.sv.sk_532  lt.hu.lv_643 ru.uk.mk_653
  0x23002a1b, 0x55001008, 0x1e311aa0, 0x13080c12,   // mt.ca.un_770 lt.rw.un_430  tl.az.ms_322 sv.no.et_654
  0x0f100e12, 0x091716a7, 0x080623a4, 0x6b1a13a4,   // is.lt.lv_654 hr.sr.pl_532  ca.de.no_433 et.tl.ceb_433
  // [4ac0]
  0x27182aee, 0x12000809, 0x20001c0b, 0x1107040c,   // mt.ga.gd_422 no.hu.un_440  id.sq.un_520 ru.bg.ro_543
  0x046b130c, 0x551021ec, 0x1228550c, 0x1e000d04,   // et.ceb.fi_543 jw.lt.rw_644  rw.sw.hu_543 cs.ms.un_320
  0x55216407, 0x641a6b0b, 0x2100201a, 0x6b211c04,   // lg.jw.rw_432 ceb.tl.lg_542  sq.jw.un_760 id.jw.ceb_332
  0x0400060e, 0x271c2107, 0x252855ad, 0x2a556e04,   // de.fi.un_550 jw.id.gd_432  rw.sw.eu_643 blu.rw.mt_332
  // [4ad0]
  0x2d1716a4, 0x09290404, 0x251f28ee, 0x531b6455,   // hr.sr.sk_433 fi.sl.pl_332  sw.cy.eu_422 lg.tr.ht_442
  0x64532311, 0x1f1c1007, 0x010e0604, 0x1c005507,   // ca.ht.lg_653 lt.id.cy_432  de.is.en_332 rw.id.un_420
  0x0c0501a4, 0x03011007, 0x55006b0d, 0x10006b12,   // en.fr.sv_433 lt.en.nl_432  ceb.rw.un_540 ceb.lt.un_640
  0x192d12a9, 0x1b1c6ba4, 0x202a1707, 0x1a0217a9,   // hu.sk.gl_544 ceb.id.tr_433  sr.mt.sq_432 sr.da.tl_544
  // [4ae0]
  0x0f1e1c0c, 0x12006407, 0x101f01a4, 0x08070a0b,   // id.ms.lv_543 lg.hu.un_420  en.cy.lt_433 mk.bg.uk_542
  0x09211ca0, 0x021b2b07, 0x04071105, 0x09130d08,   // id.jw.pl_322 vi.tr.da_432  ro.bg.ru_333 ne.bh.hi_443
  0x17070a08, 0x09003105, 0x0e000b02, 0x3f0f0111,   // mk.bg.sr_443 az.pl.un_330  es.is.un_220 en.lv.af_653
  0x2b001a04, 0x252d0d05, 0x13010fec, 0x0d1e1c55,   // tl.vi.un_320 cs.sk.eu_333  lv.en.et_644 id.ms.cs_442
  // [4af0]
  0x05100107, 0x0b050112, 0x0f00011a, 0x12190a0c,   // en.lt.fr_432 en.fr.es_654  en.lv.un_760 pt.gl.hu_543
  0x252021ad, 0x6b001212, 0x08051104, 0x17041112,   // jw.sq.eu_643 hu.ceb.un_640  ro.fr.no_332 ro.ru.sr_654
  0x29000e0e, 0x020c0e0c, 0x6e6b01a0, 0x08001721,   // is.sl.un_550 is.sv.da_543  en.ceb.blu_322 sr.uk.un_860
  0x20231905, 0x010853ec, 0x110501af, 0x286421a0,   // gl.ca.sq_333 ht.no.en_644  en.fr.ro_655 jw.lg.sw_322
  // [4b00]
  0x04002322, 0x1729160b, 0x0a0708a9, 0x3f030904,   // ca.fi.un_870 hr.sl.sr_542  uk.bg.mk_544 pl.nl.af_332
  0x2d0d0b09, 0x0d091c60, 0x080c0e05, 0x1c090d04,   // es.cs.sk_444 mr.hi.ne_664  is.sv.no_333 ne.hi.mr_332
  0x0a1008a0, 0x2d6b12af, 0x1a00552a, 0x1a211209,   // uk.be.mk_322 hu.ceb.sk_655  rw.tl.un_970 hu.jw.tl_444
  0x25122d0c, 0x2021280c, 0x211a6b11, 0x2d211207,   // sk.hu.eu_543 sw.jw.sq_543  ceb.tl.jw_653 hu.jw.sk_432
  // [4b10]
  0x2d211214, 0x13033f07, 0x13645504, 0x64031304,   // hu.jw.sk_666 af.nl.et_432  rw.lg.et_332 et.nl.lg_332
  0x2125120c, 0x08070455, 0x3f130355, 0x12211ca4,   // hu.eu.jw_543 ru.bg.uk_442  nl.et.af_442 id.jw.hu_433
  0x01000305, 0x0e00080d, 0x03041308, 0x0e005307,   // nl.en.un_330 no.is.un_540  et.fi.nl_443 ht.is.un_420
  0x3f2512a7, 0x12002d1a, 0x64033f60, 0x6b211208,   // hu.eu.af_532 sk.hu.un_760  af.nl.lg_664 hu.jw.ceb_443
  // [4b20]
  0x17126eee, 0x1a122d11, 0x08001f0c, 0x2d291213,   // blu.hu.sr_422 sk.hu.tl_653  cy.no.un_530 hu.sl.sk_665
  0x211a1212, 0x21121c0b, 0x6403130c, 0x13033f0c,   // hu.tl.jw_654 id.hu.jw_542  et.nl.lg_543 af.nl.et_543
  0x08033f0c, 0x64125513, 0x0710040c, 0x130831a0,   // af.nl.no_543 rw.hu.lg_665  ru.be.bg_543 az.no.et_322
  0x0a000107, 0x17005302, 0x12001019, 0x01000507,   // en.pt.un_420 ht.sr.un_220  lt.hu.un_750 fr.en.un_420
  // [4b30]
  0x17091207, 0x05002702, 0x2b061aa7, 0x182305a6,   // hu.pl.sr_432 gd.fr.un_220  tl.de.vi_532 fr.ca.ga_521
  0x0a171104, 0x2818270c, 0x1e1c180c, 0x21046407,   // ro.sr.mk_332 gd.ga.sw_543  ga.id.ms_543 lg.fi.jw_432
  0x07121855, 0x0c030609, 0x08000321, 0x2d001909,   // ga.hu.it_442 de.nl.sv_444  nl.no.un_860 gl.sk.un_440
  0x535508ee, 0x25085555, 0x02030812, 0x6e2701a4,   // no.rw.ht_422 rw.no.eu_442  no.nl.da_654 en.gd.blu_433
  // [4b40]
  0x071210ad, 0x10080414, 0x2016110b, 0x11200404,   // lt.hu.it_643 ru.uk.be_666  ro.hr.sq_542 fi.sq.ro_332
  0x0a000735, 0x3f120809, 0x230420a9, 0x00000c24,   // bg.mk.un_A90 no.hu.af_444  sq.fi.ca_544 sv.un.un_900
  0x1300210d, 0x0c060111, 0x04002019, 0x031f3f13,   // jw.et.un_540 en.de.sv_653  sq.fi.un_750 af.cy.nl_665
  0x181a2104, 0x25086ba0, 0x08001813, 0x04081104,   // jw.tl.ga_332 ceb.no.eu_322  ga.no.un_650 ro.uk.ru_332
  // [4b50]
  0x28205507, 0x100e3f13, 0x2000040b, 0x18271e07,   // rw.sq.sw_432 af.is.lt_665  fi.sq.un_520 ms.gd.ga_432
  0x20210807, 0x1b3f0455, 0x553f28ec, 0x551728a0,   // no.jw.sq_432 fi.af.tr_442  sw.af.rw_644 sw.sr.rw_322
  0x061b030d, 0x01001f12, 0x02040c08, 0x083f1f0d,   // nl.tr.de_554 cy.en.un_640  sv.fi.da_443 cy.af.no_554
  0x08100705, 0x056e2104, 0x08000a0d, 0x040d05a0,   // bg.be.uk_333 jw.blu.fr_332  mk.uk.un_540 fr.cs.fi_322
  // [4b60]
  0x023f0808, 0x2a2023a9, 0x04000d1a, 0x11200455,   // no.af.da_443 ca.sq.mt_544  cs.fi.un_760 fi.sq.ro_442
  0x28001b02, 0x06021204, 0x17040a09, 0x1c212804,   // tr.sw.un_220 hu.da.de_332  mk.ru.sr_444 sw.jw.id_332
  0x06281205, 0x180e27a7, 0x6b091a07, 0x2a021107,   // hu.sw.de_333 gd.is.ga_532  tl.pl.ceb_432 ro.da.mt_432
  0x1a112107, 0x2800041a, 0x1a2523a4, 0x0804105a,   // jw.ro.tl_432 fi.sw.un_760  ca.eu.tl_433 be.ru.uk_553
  // [4b70]
  0x25552907, 0x1f1b03a4, 0x08290604, 0x0c062108,   // sl.rw.eu_432 nl.tr.cy_433  de.sl.no_332 jw.de.sv_443
  0x28165314, 0x1b0921ee, 0x20111004, 0x21131caf,   // ht.hr.sw_666 jw.pl.tr_422  lt.ro.sq_332 id.et.jw_655
  0x290d090d, 0x206b1aa4, 0x10095312, 0x080602a4,   // pl.cs.sl_554 tl.ceb.sq_433  ht.pl.lt_654 da.de.no_433
  0x05190109, 0x06110213, 0x06000e09, 0x21090d07,   // en.gl.fr_444 da.ro.de_665  is.de.un_440 cs.pl.jw_432
  // [4b80]
  0x10216404, 0x190a20af, 0x0f190d07, 0x1105170c,   // lg.jw.lt_332 sq.pt.gl_655  cs.gl.lv_432 sr.fr.ro_543
  0x0d000604, 0x210f0b08, 0x2a002308, 0x1e000408,   // de.cs.un_320 es.lv.jw_443  ca.mt.un_430 fi.ms.un_430
  0x2b001309, 0x55001a22, 0x25551107, 0x6b0105a0,   // et.vi.un_440 tl.rw.un_870  ro.rw.eu_432 fr.en.ceb_322
  0x072101a4, 0x552021a9, 0x2d2731a0, 0x12101aa0,   // en.jw.it_433 jw.sq.rw_544  az.gd.sk_322 tl.lt.hu_322
  // [4b90]
  0x08020614, 0x27006412, 0x0800171a, 0x531917ac,   // de.da.no_666 lg.gd.un_640  sr.uk.un_760 sr.gl.ht_632
  0x64005535, 0x21001833, 0x29000504, 0x011a2b07,   // rw.lg.un_A90 ar.fa.un_A70  fr.sl.un_320 vi.tl.en_432
  0x205528ec, 0x23171604, 0x211f0705, 0x0b050a04,   // sw.rw.sq_644 hr.sr.ca_332  it.cy.jw_333 pt.fr.es_332
  0x03002502, 0x1a001e09, 0x18112aee, 0x1f000707,   // eu.nl.un_220 ms.tl.un_440  mt.ro.ga_422 it.cy.un_420
  // [4ba0]
  0x133f0311, 0x530b05a7, 0x6b1b5313, 0x1a556bad,   // nl.af.et_653 fr.es.ht_532  ht.tr.ceb_665 ceb.rw.tl_643
  0x040c0fee, 0x09002a05, 0x55002105, 0x06216b05,   // lv.sv.fi_422 mt.pl.un_330  jw.rw.un_330 ceb.jw.de_333
  0x03042904, 0x21001007, 0x291720a0, 0x171608af,   // sl.fi.nl_332 lt.jw.un_420  sq.sr.sl_322 no.hr.sr_655
  0x1c532160, 0x0d642dee, 0x3f161007, 0x170a10a4,   // jw.ht.id_664 sk.lg.cs_422  lt.hr.af_432 be.mk.sr_433
  // [4bb0]
  0x17163faf, 0x530527a0, 0x2a182855, 0x083f0c0c,   // af.hr.sr_655 gd.fr.ht_322  sw.ga.mt_442 sv.af.no_543
  0x2d001309, 0x1a256b07, 0x1a215507, 0x0623010c,   // et.sk.un_440 ceb.eu.tl_432  rw.jw.tl_432 en.ca.de_543
  0x012303ee, 0x0301050c, 0x10001708, 0x120c23a0,   // nl.ca.en_422 fr.en.nl_543  sr.lt.un_430 ca.sv.hu_322
  0x0c3f0804, 0x03023fa9, 0x04083f05, 0x2a23110c,   // no.af.sv_332 af.da.nl_544  af.no.fi_333 ro.ca.mt_543
  // [4bc0]
  0x02001f04, 0x5300640e, 0x3f050107, 0x231104a9,   // cy.da.un_320 lg.ht.un_550  en.fr.af_432 fi.ro.ca_544
  0x551f1ea0, 0x16292004, 0x08040711, 0x3f00170d,   // ms.cy.rw_322 sq.sl.hr_332  bg.ru.uk_653 sr.af.un_540
  0x03230112, 0x020c0fa4, 0x64005302, 0x110603ad,   // en.ca.nl_654 lv.sv.da_433  ht.lg.un_220 nl.de.ro_643
  0x2300111a, 0x1f645512, 0x1f6b28a0, 0x19050b07,   // ro.ca.un_760 rw.lg.cy_654  sw.ceb.cy_322 es.fr.gl_432
  // [4bd0]
  0x55001f0d, 0x1c1f0207, 0x160917a9, 0x170a08a6,   // cy.rw.un_540 da.cy.id_432  sr.pl.hr_544 uk.mk.sr_521
  0x2a0d53ad, 0x0e0206ee, 0x3f080302, 0x122a0c60,   // ht.cs.mt_643 de.da.is_422  nl.no.af_222 sv.mt.hu_664
  0x02033f09, 0x033f0a07, 0x12171011, 0x09033f55,   // af.nl.da_444 pt.af.nl_432  lt.sr.hu_653 af.nl.pl_442
  0x04112308, 0x13001c22, 0x04556407, 0x110c0da4,   // ca.ro.fi_443 mr.bh.un_870  lg.rw.fi_432 cs.sv.ro_433
  // [4be0]
  0x646b1a07, 0x23110d12, 0x08020608, 0x0664550c,   // tl.ceb.lg_432 cs.ro.ca_654  de.da.no_443 rw.lg.de_543
  0x033f2311, 0x171016ad, 0x646b2da0, 0x27021f08,   // ca.af.nl_653 hr.lt.sr_643  sk.ceb.lg_322 cy.da.gd_443
  0x1300550e, 0x0a170404, 0x252d0da7, 0x29000d13,   // rw.et.un_550 ru.sr.mk_332  cs.sk.eu_532 cs.sl.un_650
  0x3f1210a4, 0x1f551207, 0x12000c0c, 0x172d16a4,   // lt.hu.af_433 hu.rw.cy_432  sv.hu.un_530 hr.sk.sr_433
  // [4bf0]
  0x1f0727a9, 0x0408170c, 0x0f211b0c, 0x1a101e07,   // gd.it.cy_544 sr.uk.ru_543  tr.jw.lv_543 ms.lt.tl_432
  0x1b171655, 0x1b033f0c, 0x080c3f0c, 0x2d291705,   // hr.sr.tr_442 af.nl.tr_543  af.sv.no_543 sr.sl.sk_333
  0x0a2909a4, 0x170704af, 0x09002519, 0x13046408,   // pl.sl.pt_433 ru.bg.sr_655  eu.pl.un_750 lg.fi.et_443
  0x291210a4, 0x1e1c1004, 0x10040aa0, 0x172d0da0,   // lt.hu.sl_433 lt.id.ms_332  mk.ru.be_322 cs.sk.sr_322

  // [4c00]
  0x1a6b1204, 0x1b18270b, 0x3f001f12, 0x2a09290e,   // hu.ceb.tl_332 gd.ga.tr_542  cy.af.un_640 sl.pl.mt_555
  0x25230b0c, 0x29002013, 0x20000214, 0x0f291707,   // es.ca.eu_543 sq.sl.un_650  da.sq.un_660 sr.sl.lv_432
  0x2d1612a0, 0x18001604, 0x53002902, 0x20002b04,   // hu.hr.sk_322 hr.ga.un_320  sl.ht.un_220 vi.sq.un_320
  0x20001014, 0x17002d13, 0x530d10a7, 0x0b002d0d,   // lt.sq.un_660 sk.sr.un_650  lt.cs.ht_532 sk.es.un_540
  // [4c10]
  0x04001718, 0x11033f12, 0x113f030c, 0x12080c07,   // sr.ru.un_740 af.nl.ro_654  nl.af.ro_543 sv.no.hu_432
  0x070a0812, 0x202902ee, 0x08000713, 0x3f001112,   // uk.mk.bg_654 da.sl.sq_422  it.no.un_650 ro.af.un_640
  0x1a002502, 0x18000107, 0x20000a08, 0x18006e08,   // eu.tl.un_220 en.ga.un_420  pt.sq.un_430 blu.ga.un_430
  0x07081005, 0x27062304, 0x2d001f07, 0x1100051b,   // be.uk.bg_333 ca.de.gd_332  cy.sk.un_420 fr.ro.un_770
  // [4c20]
  0x11033f60, 0x111c5304, 0x031112a4, 0x250e0c07,   // af.nl.ro_664 ht.id.ro_332  hu.ro.nl_433 sv.is.eu_432
  0x1e160d04, 0x110113ee, 0x0f2a21a0, 0x0e002909,   // cs.hr.ms_332 et.en.ro_422  jw.mt.lv_322 sl.is.un_440
  0x6e001e08, 0x16006404, 0x231918a4, 0x03002804,   // ms.blu.un_430 lg.hr.un_320  ga.gl.ca_433 sw.nl.un_320
  0x0e020604, 0x640313ee, 0x01006b02, 0x0c206408,   // de.da.is_332 et.nl.lg_422  ceb.en.un_220 lg.sq.sv_443
  // [4c30]
  0x55161104, 0x640807a0, 0x190b2304, 0x1a6407ad,   // ro.hr.rw_332 it.no.lg_322  ca.es.gl_332 it.lg.tl_643
  0x18270112, 0x17201612, 0x040825a0, 0x0a002004,   // en.gd.ga_654 hr.sq.sr_654  eu.no.fi_322 sq.pt.un_320
  0x201e1c05, 0x2100202a, 0x061325a9, 0x1716080c,   // id.ms.sq_333 sq.jw.un_970  eu.et.de_544 no.hr.sr_543
  0x03255508, 0x09550e08, 0x53290808, 0x08200207,   // rw.eu.nl_443 is.rw.pl_443  no.sl.ht_443 da.sq.no_432
  // [4c40]
  0x1c002012, 0x281c3fa0, 0x290d2daf, 0x11061fa4,   // sq.id.un_640 af.id.sw_322  sk.cs.sl_655 cy.de.ro_433
  0x21121604, 0x0b00021a, 0x20000808, 0x1c002013,   // hr.hu.jw_332 da.es.un_760  no.sq.un_430 sq.id.un_650
  0x0408070b, 0x29210609, 0x28271807, 0x18276e13,   // bg.uk.ru_542 de.jw.sl_444  ga.gd.sw_432 blu.gd.ga_665
  0x02210cee, 0x20006e0d, 0x16290405, 0x3f0503a0,   // sv.jw.da_422 blu.sq.un_540  fi.sl.hr_333 nl.fr.af_322
  // [4c50]
  0x06280908, 0x18276eaf, 0x0f12250c, 0x55016ba0,   // pl.sw.de_443 blu.gd.ga_655  eu.hu.lv_543 ceb.en.rw_322
  0x1b001208, 0x2a000707, 0x251119ac, 0x0708640c,   // hu.tr.un_430 it.mt.un_420  gl.ro.eu_632 lg.no.it_543
  0x1c000413, 0x0b102da0, 0x06000713, 0x08190aad,   // fi.id.un_650 sk.lt.es_322  it.de.un_650 pt.gl.no_643
  0x6e0a1f0c, 0x120f10ec, 0x13232508, 0x0f0b10ec,   // cy.pt.blu_543 lt.lv.hu_644  eu.ca.et_443 lt.es.lv_644
  // [4c60]
  0x230825a4, 0x25120404, 0x1f033f0d, 0x1906050c,   // eu.no.ca_433 fi.hu.eu_332  af.nl.cy_554 fr.de.gl_543
  0x07000f04, 0x043f03a7, 0x133f0305, 0x10136e04,   // lv.it.un_320 nl.af.fi_532  nl.af.et_333 blu.et.lt_332
  0x100b190c, 0x0e00200c, 0x0a001123, 0x130820a0,   // gl.es.lt_543 sq.is.un_530  ro.mk.un_880 sq.no.et_322
  0x23200404, 0x17081013, 0x0e00020e, 0x0d20530b,   // fi.sq.ca_332 be.uk.sr_665  da.is.un_550 ht.sq.cs_542
  // [4c70]
  0x05002319, 0x3f03640d, 0x13000502, 0x1300201a,   // ca.fr.un_750 lg.nl.af_554  fr.et.un_220 sq.et.un_760
  0x3f0e2007, 0x13002005, 0x53210507, 0x0f1716ec,   // sq.is.af_432 sq.et.un_330  fr.jw.ht_432 hr.sr.lv_644
  0x120e06a0, 0x536b250b, 0x05001104, 0x10070404,   // de.is.hu_322 eu.ceb.ht_542  ro.fr.un_320 ru.bg.be_332
  0x06001f07, 0x091729a9, 0x211812ee, 0x05160fa7,   // cy.de.un_420 sl.sr.pl_544  ur.ar.fa_422 lv.hr.fr_532
  // [4c80]
  0x18001f0e, 0x0807040d, 0x2023110c, 0x11000735,   // cy.ga.un_550 ru.bg.uk_554  ro.ca.sq_543 bg.ro.un_A90
  0x083f0e55, 0x535528ad, 0x18001f04, 0x211218ac,   // is.af.no_442 sw.rw.ht_643  cy.ga.un_320 ar.ur.fa_632
  0x19030607, 0x06132107, 0x53001b1b, 0x1b25120c,   // de.nl.gl_432 jw.et.de_432  tr.ht.un_770 hu.eu.tr_543
  0x10080aa4, 0x53171c07, 0x286b1b04, 0x25021e05,   // mk.uk.be_433 id.sr.ht_432  tr.ceb.sw_332 ms.da.eu_333
  // [4c90]
  0x210425a4, 0x13003f02, 0x1e1b210c, 0x20112355,   // eu.fi.jw_433 af.et.un_220  jw.tr.ms_543 ca.ro.sq_442
  0x12640804, 0x0c0823a7, 0x101107a0, 0x1b121e0c,   // no.lg.hu_332 ca.no.sv_532  it.ro.lt_322 ms.hu.tr_543
  0x1f001902, 0x0e020609, 0x5331120c, 0x0709110c,   // gl.cy.un_220 de.da.is_444  hu.az.ht_543 ro.pl.it_543
  0x252d0d02, 0x07000502, 0x021206a7, 0x25190e0c,   // cs.sk.eu_222 fr.it.un_220  de.hu.da_532 is.gl.eu_543
  // [4ca0]
  0x09002105, 0x16076eee, 0x04111705, 0x25002319,   // jw.pl.un_330 blu.it.hr_422  sr.ro.ru_333 ca.eu.un_750
  0x315325a9, 0x12211c0c, 0x12092512, 0x1000111a,   // eu.ht.az_544 id.jw.hu_543  eu.pl.hu_654 ro.be.un_760
  0x201655ee, 0x201f11ad, 0x292d0daf, 0x23250fa0,   // rw.hr.sq_422 ro.cy.sq_643  cs.sk.sl_655 lv.eu.ca_322
  0x6b531c04, 0x10001a0d, 0x12083f07, 0x09112504,   // id.ht.ceb_332 tl.lt.un_540  af.no.hu_432 eu.ro.pl_332
  // [4cb0]
  0x552a2508, 0x02081208, 0x05001222, 0x55000a04,   // eu.mt.rw_443 hu.no.da_443  hu.fr.un_870 pt.rw.un_320
  0x021855a9, 0x10080409, 0x211e13a0, 0x0a531107,   // rw.ga.da_544 ru.uk.be_444  et.ms.jw_322 ro.ht.pt_432
  0x230a0e0d, 0x192d0d0e, 0x55640611, 0x03000502,   // is.pt.ca_554 cs.sk.gl_555  de.lg.rw_653 fr.nl.un_220
  0x1821120b, 0x25551e07, 0x0a1108a9, 0x0d002d18,   // ur.fa.ar_542 ms.rw.eu_432  uk.ro.mk_544 sk.cs.un_740
  // [4cc0]
  0x0a0723a4, 0x08041713, 0x1b550d04, 0x16290da0,   // ca.it.pt_433 sr.ru.uk_665  cs.rw.tr_332 cs.sl.hr_322
  0x0400102c, 0x16102908, 0x1200100e, 0x011e12ac,   // be.ru.un_990 sl.lt.hr_443  lt.hu.un_550 hu.ms.en_632
  0x1e000d02, 0x1b0112ee, 0x0000032d, 0x1b002907,   // cs.ms.un_220 hu.en.tr_422  nl.un.un_A00 sl.tr.un_420
  0x0c001f0c, 0x5528200c, 0x12001f13, 0x28550107,   // cy.sv.un_530 sq.sw.rw_543  cy.hu.un_650 en.rw.sw_432
  // [4cd0]
  0x0c0e1302, 0x0d2125ee, 0x2d181207, 0x041711a7,   // et.is.sv_222 eu.jw.cs_422  hu.ga.sk_432 ro.sr.ru_532
  0x060c1fac, 0x3f030112, 0x0f00101a, 0x1a1e210c,   // cy.sv.de_632 en.nl.af_654  lt.lv.un_760 jw.ms.tl_543
  0x645525ec, 0x0c002018, 0x25000604, 0x11060111,   // eu.rw.lg_644 sq.sv.un_740  de.eu.un_320 en.de.ro_653
  0x040523a7, 0x23000604, 0x08550107, 0x06000408,   // ca.fr.fi_532 de.ca.un_320  en.rw.no_432 fi.de.un_430
  // [4ce0]
  0x0a100708, 0x2d080b04, 0x2a2d0d09, 0x64000702,   // bg.be.mk_443 es.no.sk_332  cs.sk.mt_444 it.lg.un_220
  0x0c202d07, 0x0e000213, 0x08205304, 0x29311b0c,   // sk.sq.sv_432 da.is.un_650  ht.sq.no_332 tr.az.sl_543
  0x2a1123a0, 0x2a00121b, 0x20001e12, 0x2a1301a7,   // ca.ro.mt_322 hu.mt.un_770  ms.sq.un_640 en.et.mt_532
  0x23200dad, 0x010f100c, 0x270111ad, 0x12001002,   // cs.sq.ca_643 lt.lv.en_543  ro.en.gd_643 lt.hu.un_220
  // [4cf0]
  0x12000608, 0x11066404, 0x27033f02, 0x070a0805,   // de.hu.un_430 lg.de.ro_332  af.nl.gd_222 uk.mk.bg_333
  0x0f041012, 0x11000607, 0x0c1002a0, 0x0a00081b,   // lt.fi.lv_654 de.ro.un_420  da.lt.sv_322 uk.mk.un_770
  0x041123a0, 0x04202308, 0x0e000c08, 0x2a0e0c0c,   // ca.ro.fi_322 ca.sq.fi_443  sv.is.un_430 sv.is.mt_543
  0x1c061e12, 0x0c2320ee, 0x0e000c1b, 0x05000408,   // ms.de.id_654 sq.ca.sv_422  sv.is.un_770 fi.fr.un_430
  // [4d00]
  0x040e0c0b, 0x3f000904, 0x0b251907, 0x09000805,   // sv.is.fi_542 pl.af.un_320  gl.eu.es_432 no.pl.un_330
  0x0e0c080e, 0x19002502, 0x0e000c09, 0x55001a14,   // no.sv.is_555 eu.gl.un_220  sv.is.un_440 tl.rw.un_660
  0x2a0110a0, 0x04202112, 0x130106a0, 0x05005504,   // lt.en.mt_322 jw.sq.fi_654  de.en.et_322 rw.fr.un_320
  0x21136ba0, 0x100e0407, 0x17100702, 0x25041004,   // ceb.et.jw_322 fi.is.lt_432  bg.be.sr_222 lt.fi.eu_332
  // [4d10]
  0x040f1007, 0x04070aec, 0x552128a4, 0x08102507,   // lt.lv.fi_432 mk.bg.ru_644  sw.jw.rw_433 eu.lt.no_432
  0x21112507, 0x190b25a4, 0x2a080c0c, 0x080e0ca4,   // eu.ro.jw_432 eu.es.gl_433  sv.no.mt_543 sv.is.no_433
  0x21085307, 0x1b2901a4, 0x23110112, 0x1a131207,   // ht.no.jw_432 en.sl.tr_433  en.ro.ca_654 hu.et.tl_432
  0x6e01270c, 0x120c09a0, 0x18001204, 0x022916a0,   // gd.en.blu_543 pl.sv.hu_322  ur.ar.un_320 hr.sl.da_322
  // [4d20]
  0x1b2864a0, 0x16082904, 0x012311a4, 0x042010a4,   // lg.sw.tr_322 sl.no.hr_332  ro.ca.en_433 lt.sq.fi_433
  0x2a230107, 0x1a0b6b0c, 0x04251008, 0x23110108,   // en.ca.mt_432 ceb.es.tl_543  lt.eu.fi_443 en.ro.ca_443
  0x04271809, 0x112301a4, 0x0e002907, 0x10000908,   // ga.gd.fi_444 en.ca.ro_433  sl.is.un_420 pl.lt.un_430
  0x20002107, 0x28001209, 0x110408a4, 0x01160907,   // jw.sq.un_420 hu.sw.un_440  uk.ru.ro_433 pl.hr.en_432
  // [4d30]
  0x31280707, 0x53162507, 0x29532508, 0x10042508,   // it.sw.az_432 eu.hr.ht_432  eu.ht.sl_443 eu.fi.lt_443
  0x0e0508a0, 0x1f002321, 0x16091104, 0x11250704,   // no.fr.is_322 ca.cy.un_860  ro.pl.hr_332 it.eu.ro_332
  0x11012304, 0x0e070a0c, 0x211b3f5a, 0x16290107,   // ca.en.ro_332 pt.it.is_543  af.tr.jw_553 en.sl.hr_432
  0x042153ac, 0x0500040d, 0x00000224, 0x112301a9,   // ht.jw.fi_632 fi.fr.un_540  da.un.un_900 en.ca.ro_544
  // [4d40]
  0x20041b13, 0x1b00200e, 0x1b00531a, 0x232b01ad,   // tr.fi.sq_665 sq.tr.un_550  ht.tr.un_760 en.vi.ca_643
  0x070c2512, 0x64000f07, 0x2b1801a4, 0x09011fa0,   // eu.sv.it_654 lv.lg.un_420  en.ga.vi_433 cy.en.pl_322
  0x53001102, 0x29001723, 0x2000252a, 0x132916a0,   // ro.ht.un_220 sr.sl.un_880  eu.sq.un_970 hr.sl.et_322
  0x16081704, 0x0c291107, 0x0400132a, 0x29531f08,   // sr.no.hr_332 ro.sl.sv_432  et.fi.un_970 cy.ht.sl_443
  // [4d50]
  0x0700061b, 0x02201704, 0x25005519, 0x211b5507,   // de.it.un_770 sr.sq.da_332  rw.eu.un_750 rw.tr.jw_432
  0x1a281ba9, 0x06070509, 0x5300280d, 0x06182712,   // tr.sw.tl_544 fr.it.de_444  sw.ht.un_540 gd.ga.de_654
  0x3f002d12, 0x2d000e0c, 0x0600030e, 0x29001318,   // sk.af.un_640 is.sk.un_530  nl.de.un_550 et.sl.un_740
  0x55202307, 0x2d182702, 0x072053ad, 0x0c1304ee,   // ca.sq.rw_432 gd.ga.sk_222  ht.sq.it_643 fi.et.sv_422
  // [4d60]
  0x0c00210e, 0x1300231a, 0x11550904, 0x3f201113,   // jw.sv.un_550 ca.et.un_760  pl.rw.ro_332 ro.sq.af_665
  0x251004a0, 0x0c0504ee, 0x200411ee, 0x07002a08,   // fi.lt.eu_322 fi.fr.sv_422  ro.fi.sq_422 mt.it.un_430
  0x16020cad, 0x20001314, 0x55286412, 0x0f00102c,   // sv.da.hr_643 et.sq.un_660  lg.sw.rw_654 lt.lv.un_990
  0x18012b04, 0x2b005307, 0x1f005307, 0x53252807,   // vi.en.ga_332 ht.vi.un_420  ht.cy.un_420 sw.eu.ht_432
  // [4d70]
  0x03010c05, 0x1e291ba0, 0x0c000f19, 0x29022da4,   // sv.en.nl_333 tr.sl.ms_322  lv.sv.un_750 sk.da.sl_433
  0x036b01a4, 0x5306050e, 0x23010514, 0x0e000c2a,   // en.ceb.nl_433 fr.de.ht_555  fr.en.ca_666 sv.is.un_970
  0x050e0112, 0x55111704, 0x1e1c0e14, 0x020e01ac,   // en.is.fr_654 sr.ro.rw_332  is.id.ms_666 en.is.da_632
  0x29061607, 0x27001902, 0x0708040e, 0x290d2da4,   // hr.de.sl_432 gl.gd.un_220  ru.uk.bg_555 sk.cs.sl_433
  // [4d80]
  0x01005305, 0x06120304, 0x2a011fa4, 0x0803020c,   // ht.en.un_330 nl.hu.de_332  cy.en.mt_433 da.nl.no_543
  0x170f3f04, 0x0f2301a4, 0x08120107, 0x17000a35,   // af.lv.sr_332 en.ca.lv_433  en.hu.no_432 mk.sr.un_A90
  0x05030807, 0x01002504, 0x290d1605, 0x032923a7,   // no.nl.fr_432 eu.en.un_320  hr.cs.sl_333 ca.sl.nl_532
  0x27006b04, 0x062904a0, 0x3f0203ad, 0x1c130605,   // ceb.gd.un_320 fi.sl.de_322  nl.da.af_643 de.et.id_333
  // [4d90]
  0x27000302, 0x080203a0, 0x1105070c, 0x0c210809,   // nl.gd.un_220 nl.da.no_322  it.fr.ro_543 no.jw.sv_444
  0x20001a02, 0x53002502, 0x16001012, 0x25070607,   // tl.sq.un_220 eu.ht.un_220  lt.hr.un_640 de.it.eu_432
  0x25000f13, 0x0d1c095a, 0x0a080707, 0x050a23ec,   // lv.eu.un_650 hi.mr.ne_553  bg.uk.mk_432 ca.pt.fr_644
  0x200401ee, 0x0a0523a7, 0x6b030507, 0x236b1904,   // en.fi.sq_422 ca.fr.pt_532  fr.nl.ceb_432 gl.ceb.ca_332
  // [4da0]
  0x04130cee, 0x073f2708, 0x1a1021a0, 0x0d001b0e,   // sv.et.fi_422 gd.af.it_443  jw.lt.tl_322 tr.cs.un_550
  0x1a0a28a6, 0x1a000502, 0x28550b0c, 0x1b17160d,   // sw.pt.tl_521 fr.tl.un_220  es.rw.sw_543 hr.sr.tr_554
  0x12001a0c, 0x552128ec, 0x2d160daf, 0x190b09a0,   // tl.hu.un_530 sw.jw.rw_644  cs.hr.sk_655 pl.es.gl_322
  0x1e1b1c0c, 0x531b28a6, 0x2d001210, 0x1b212507,   // id.tr.ms_543 sw.tr.ht_521  hu.sk.un_620 eu.jw.tr_432
  // [4db0]
  0x0a00230e, 0x17121607, 0x0a002307, 0x09001808,   // ca.pt.un_550 hr.hu.sr_432  ca.pt.un_420 ga.pl.un_430
  0x1b310a04, 0x040a0760, 0x06120ead, 0x09001202,   // pt.az.tr_332 bg.mk.ru_664  is.hu.de_643 hu.pl.un_220
  0x05006b07, 0x060208a4, 0x271f1860, 0x27001809,   // ceb.fr.un_420 no.da.de_433  ga.cy.gd_664 ga.gd.un_440
  0x063f0aee, 0x161c2102, 0x2d1107ad, 0x21002012,   // pt.af.de_422 jw.id.hr_222  it.ro.sk_643 sq.jw.un_640
  // [4dc0]
  0x21121808, 0x02181fa0, 0x06182760, 0x1c211102,   // ar.ur.fa_443 cy.ga.da_322  gd.ga.de_664 ro.jw.id_222
  0x02231108, 0x1b042004, 0x6b0c08a4, 0x13000212,   // ro.ca.da_443 sq.fi.tr_332  no.sv.ceb_433 da.et.un_640
  0x270e1812, 0x1f000f05, 0x2800172c, 0x29161ca0,   // ga.is.gd_654 lv.cy.un_330  sr.sw.un_990 id.hr.sl_322
  0x0417110c, 0x2100182c, 0x2a001b04, 0x1e1c0eee,   // ro.sr.ru_543 ar.fa.un_990  tr.mt.un_320 is.id.ms_422
  // [4dd0]
  0x06001f02, 0x232055af, 0x06202da7, 0x64130413,   // cy.de.un_220 rw.sq.ca_655  sk.sq.de_532 fi.et.lg_665
  0x291e1c09, 0x06080c09, 0x641729af, 0x182a23a4,   // id.ms.sl_444 sv.no.de_444  sl.sr.lg_655 ca.mt.ga_433
  0x0601230c, 0x1b000a13, 0x1353040c, 0x21000208,   // ca.en.de_543 pt.tr.un_650  fi.ht.et_543 da.jw.un_430
  0x13040ca0, 0x07101714, 0x0d001908, 0x08272007,   // sv.fi.et_322 sr.be.bg_666  gl.cs.un_430 sq.gd.no_432
  // [4de0]
  0x12292d0c, 0x0c2a230c, 0x0c002313, 0x18122105,   // sk.sl.hu_543 ca.mt.sv_543  ca.sv.un_650 fa.ur.ar_333
  0x0f1e1c04, 0x170a0711, 0x020508a4, 0x23060108,   // id.ms.lv_332 bg.mk.sr_653  no.fr.da_433 en.de.ca_443
  0x27001307, 0x121e1c05, 0x0c061ba7, 0x201813af,   // et.gd.un_420 id.ms.hu_333  tr.de.sv_532 et.ga.sq_655
  0x060301a4, 0x06000514, 0x21002a05, 0x0800070c,   // en.nl.de_433 fr.de.un_660  mt.jw.un_330 bg.uk.un_530
  // [4df0]
  0x556b1aa4, 0x0306040c, 0x10000f11, 0x1f0604a4,   // tl.ceb.rw_433 fi.de.nl_543  lv.lt.un_630 fi.de.cy_433
  0x190b2314, 0x28006b07, 0x0c0325ee, 0x011f0308,   // ca.es.gl_666 ceb.sw.un_420  eu.nl.sv_422 nl.cy.en_443
  0x130627a4, 0x02060c04, 0x2a030614, 0x0f110e08,   // gd.de.et_433 sv.de.da_332  de.nl.mt_666 is.ro.lv_443
  0x020c0307, 0x31041007, 0x20080c08, 0x05005312,   // nl.sv.da_432 lt.fi.az_432  sv.no.sq_443 ht.fr.un_640
  // [4e00]
  0x270e010c, 0x181f050d, 0x1f000621, 0x1f06230b,   // en.is.gd_543 fr.cy.ga_554  de.cy.un_860 ca.de.cy_542
  0x1f3f0307, 0x53002514, 0x131110ec, 0x230b19a4,   // nl.af.cy_432 eu.ht.un_660  lt.ro.et_644 gl.es.ca_433
  0x1a1b040c, 0x27051804, 0x10001c0d, 0x0e1f0c07,   // fi.tr.tl_543 ga.fr.gd_332  id.lt.un_540 sv.cy.is_432
  0x116b6e08, 0x012a0302, 0x18001314, 0x0f001e0d,   // blu.ceb.ro_443 nl.mt.en_222  et.ga.un_660 ms.lv.un_540
  // [4e10]
  0x0300041b, 0x1b060312, 0x081901ee, 0x1b030607,   // fi.nl.un_770 nl.de.tr_654  en.gl.no_422 de.nl.tr_432
  0x0b1f05a6, 0x050a12ad, 0x23000e07, 0x0b1301a0,   // fr.cy.es_521 hu.pt.fr_643  is.ca.un_420 en.et.es_322
  0x06031f13, 0x10190a14, 0x0427130c, 0x0c230f09,   // cy.nl.de_665 pt.gl.lt_666  et.gd.fi_543 lv.ca.sv_444
  0x12001905, 0x281801a0, 0x081017a7, 0x2513040c,   // gl.hu.un_330 en.ga.sw_322  sr.be.uk_532 fi.et.eu_543
  // [4e20]
  0x2d0d10ec, 0x16120f08, 0x1b1253a4, 0x1a1f2111,   // lt.cs.sk_644 lv.hu.hr_443  ht.hu.tr_433 jw.cy.tl_653
  0x06052702, 0x081017ee, 0x21001229, 0x04006b05,   // gd.fr.de_222 sr.be.uk_422  ur.fa.un_960 ceb.fi.un_330
  0x063f0408, 0x131c09af, 0x281e21a0, 0x2b180102,   // fi.af.de_443 hi.mr.bh_655  jw.ms.sw_322 en.ga.vi_222
  0x200111a0, 0x646b10ee, 0x18000e0b, 0x1c1028a9,   // ro.en.sq_322 lt.ceb.lg_422  is.ga.un_520 sw.lt.id_544
  // [4e30]
  0x20003107, 0x64072811, 0x531a6bad, 0x55002513,   // az.sq.un_420 sw.it.lg_653  ceb.tl.ht_643 eu.rw.un_650
  0x2700130c, 0x040a1008, 0x040811a6, 0x16001007,   // et.gd.un_530 be.mk.ru_443  ro.uk.ru_521 lt.hr.un_420
  0x09180107, 0x192d0d55, 0x2a000f10, 0x551f13a7,   // en.ga.pl_432 cs.sk.gl_442  lv.mt.un_620 et.cy.rw_532
  0x55001009, 0x0b0a07a4, 0x645510ac, 0x1f000608,   // lt.rw.un_440 it.pt.es_433  lt.rw.lg_632 de.cy.un_430
  // [4e40]
  0x17110a0d, 0x250a190c, 0x0c033f07, 0x08021205,   // mk.ro.sr_554 gl.pt.eu_543  af.nl.sv_432 hu.da.no_333
  0x641009a0, 0x16170904, 0x6b00281b, 0x0c0229a4,   // pl.lt.lg_322 pl.sr.hr_332  sw.ceb.un_770 sl.da.sv_433
  0x6b160107, 0x281716a7, 0x12002120, 0x0d1c130d,   // en.hr.ceb_432 hr.sr.sw_532  fa.ur.un_850 bh.mr.ne_554
  0x190b04ee, 0x1931080c, 0x04001122, 0x10040707,   // fi.es.gl_422 no.az.gl_543  ro.ru.un_870 bg.ru.be_432
  // [4e50]
  0x1c215513, 0x0400550e, 0x53252113, 0x09000c04,   // rw.jw.id_665 rw.fi.un_550  jw.eu.ht_665 sv.pl.un_320
  0x29002a0c, 0x21533f08, 0x1300250d, 0x1b00640e,   // mt.sl.un_530 af.ht.jw_443  eu.et.un_540 lg.tr.un_550
  0x040812ec, 0x19255504, 0x033f2011, 0x1f0501a0,   // hu.no.fi_644 rw.eu.gl_332  sq.af.nl_653 en.fr.cy_322
  0x19000b12, 0x0a071713, 0x171008a0, 0x29000304,   // es.gl.un_640 sr.bg.mk_665  uk.be.sr_322 nl.sl.un_320
  // [4e60]
  0x1a3f230c, 0x2d0d64a4, 0x200921ee, 0x1b2031a9,   // ca.af.tl_543 lg.cs.sk_433  jw.pl.sq_422 az.sq.tr_544
  0x1e1c10a4, 0x020f110c, 0x2a0e10ee, 0x07100807,   // lt.id.ms_433 ro.lv.da_543  lt.is.mt_422 uk.be.bg_432
  0x181e1c07, 0x3f001904, 0x1655170d, 0x100407ad,   // id.ms.ga_432 gl.af.un_320  sr.rw.hr_554 bg.ru.be_643
  0x17122807, 0x10080407, 0x191107ee, 0x0e1c28ee,   // sw.hu.sr_432 fi.no.lt_432  it.ro.gl_422 sw.id.is_422
  // [4e70]
  0x25166b02, 0x020c1f04, 0x53211c04, 0x55112508,   // ceb.hr.eu_222 cy.sv.da_332  id.jw.ht_332 eu.ro.rw_443
  0x0d131c11, 0x126b1a0d, 0x11183f05, 0x2d0d07ec,   // mr.bh.ne_653 tl.ceb.hu_554  af.ga.ro_333 it.cs.sk_644
  0x252307a4, 0x6b0e5307, 0x2d0d2102, 0x0c6b1a55,   // it.ca.eu_433 ht.is.ceb_432  jw.cs.sk_222 tl.ceb.sv_442
  0x1f001a04, 0x16006e08, 0x0f041004, 0x2018275a,   // tl.cy.un_320 blu.hr.un_430  lt.fi.lv_332 gd.ga.sq_553
  // [4e80]
  0x3f001a07, 0x0d00092a, 0x10531b07, 0x64551102,   // tl.af.un_420 hi.ne.un_970  tr.ht.lt_432 ro.rw.lg_222
  0x171604ee, 0x0200080e, 0x641b5312, 0x18211209,   // fi.hr.sr_422 no.da.un_550  ht.tr.lg_654 ur.fa.ar_444
  0x2000310c, 0x12200409, 0x170a0409, 0x01001802,   // az.sq.un_530 fi.sq.hu_444  ru.mk.sr_444 ga.en.un_220
  0x6e311b04, 0x211b1e07, 0x53006e12, 0x13000c02,   // tr.az.blu_332 ms.tr.jw_432  blu.ht.un_640 sv.et.un_220
  // [4e90]
  0x0d000922, 0x17000413, 0x3f040308, 0x0f6e1c07,   // hi.ne.un_870 ru.sr.un_650  nl.fi.af_443 id.blu.lv_432
  0x250403a9, 0x07102d04, 0x13090dad, 0x060304ad,   // nl.fi.eu_544 sk.lt.it_332  ne.hi.bh_643 fi.nl.de_643
  0x04253f14, 0x09080204, 0x201a280c, 0x6428130d,   // af.eu.fi_666 da.no.pl_332  sw.tl.sq_543 et.sw.lg_554
  0x55281a12, 0x083f28ee, 0x101e1c09, 0x53202812,   // tl.sw.rw_654 sw.af.no_422  id.ms.lt_444 sw.sq.ht_654
  // [4ea0]
  0x083f2504, 0x02000a02, 0x02210607, 0x1b315555,   // eu.af.no_332 pt.da.un_220  de.jw.da_432 rw.az.tr_442
  0x0a0411a0, 0x04000308, 0x1e100fee, 0x10006421,   // ro.ru.mk_322 nl.fi.un_430  lv.lt.ms_422 lg.lt.un_860
  0x2503040c, 0x645355ad, 0x0403010b, 0x2053100c,   // fi.nl.eu_543 rw.ht.lg_643  en.nl.fi_542 lt.ht.sq_543
  0x046428a9, 0x31000e0d, 0x281a2104, 0x17006b04,   // sw.lg.fi_544 is.az.un_540  jw.tl.sw_332 ceb.sr.un_320
  // [4eb0]
  0x282b0313, 0x08021baf, 0x03170207, 0x2b051960,   // nl.vi.sw_665 tr.da.no_655  da.sr.nl_432 gl.fr.vi_664
  0x172b050c, 0x06021b55, 0x1e3f0302, 0x2b071112,   // fr.vi.sr_543 tr.da.de_442  nl.af.ms_222 ro.it.vi_654
  0x0d1c130c, 0x530602a0, 0x07002b19, 0x100817ad,   // bh.mr.ne_543 da.de.ht_322  vi.it.un_750 sr.uk.be_643
  0x1b000504, 0x6b251aec, 0x051101ac, 0x1e2a2307,   // fr.tr.un_320 tl.eu.ceb_644  en.ro.fr_632 ca.mt.ms_432
  // [4ec0]
  0x0a001935, 0x112b2511, 0x2a130708, 0x06001319,   // gl.pt.un_A90 eu.vi.ro_653  it.et.mt_443 et.de.un_750
  0x3f030804, 0x03012a07, 0x1b000813, 0x0a04080e,   // no.nl.af_332 mt.en.nl_432  no.tr.un_650 uk.ru.mk_555
  0x31051bad, 0x2b051f0c, 0x0708100c, 0x042b0508,   // tr.fr.az_643 cy.fr.vi_543  be.uk.bg_543 fr.vi.fi_443
  0x063f1ba6, 0x071104ec, 0x07041008, 0x2b0405af,   // tr.af.de_521 fi.ro.it_644  be.ru.bg_443 fr.fi.vi_655
  // [4ed0]
  0x1a310e05, 0x1e55280c, 0x1c063fa0, 0x08001a04,   // is.az.tl_333 sw.rw.ms_543  af.de.id_322 tl.no.un_320
  0x1a6455a7, 0x08040709, 0x1b002d04, 0x116b09ee,   // rw.lg.tl_532 bg.ru.uk_444  sk.tr.un_320 pl.ceb.ro_422
  0x01005308, 0x21055307, 0x08071060, 0x07100aee,   // ht.en.un_430 ht.fr.jw_432  be.bg.uk_664 mk.be.bg_422
  0x1c1f21a0, 0x1f000519, 0x01002b04, 0x28001302,   // jw.cy.id_322 fr.cy.un_750  vi.en.un_320 et.sw.un_220
  // [4ee0]
  0x0f531360, 0x0a0710a9, 0x1a1b0fa4, 0x07001014,   // et.ht.lv_664 be.bg.mk_544  lv.tr.tl_433 be.bg.un_660
  0x020106a6, 0x050b01a9, 0x1017080c, 0x531b0507,   // de.en.da_521 en.es.fr_544  uk.sr.be_543 fr.tr.ht_432
  0x2a000304, 0x28103f04, 0x271f01ee, 0x040f12ec,   // nl.mt.un_320 af.lt.sw_332  en.cy.gd_422 hu.lv.fi_644
  0x04120f09, 0x53190b04, 0x090d1c0e, 0x6b270155,   // lv.hu.fi_444 es.gl.ht_332  mr.ne.hi_555 en.gd.ceb_442
  // [4ef0]
  0x1a002a02, 0x12000a14, 0x1c001604, 0x0d046b07,   // mt.tl.un_220 pt.hu.un_660  hr.id.un_320 ceb.fi.cs_432
  0x2a000c13, 0x1e1c16a0, 0x1b290d07, 0x6b1a1f04,   // sv.mt.un_650 hr.id.ms_322  cs.sl.tr_432 cy.tl.ceb_332
  0x1e171613, 0x0d182da0, 0x120e19a0, 0x19000b1a,   // hr.sr.ms_665 sk.ga.cs_322  gl.is.hu_322 es.gl.un_760
  0x1e1c16a4, 0x100a1104, 0x0400080b, 0x0f002505,   // hr.id.ms_433 ro.mk.be_332  uk.ru.un_520 eu.lv.un_330
  // [4f00]
  0x2a0704a4, 0x18211255, 0x0d00091a, 0x0f121012,   // fi.it.mt_433 ur.fa.ar_442  hi.ne.un_760 lt.hu.lv_654
  0x08020305, 0x0e531aa0, 0x17040a12, 0x041a1c0c,   // nl.da.no_333 tl.ht.is_322  mk.ru.sr_654 id.tl.fi_543
  0x1c1a6ba9, 0x1e6b1cad, 0x2b006e21, 0x64201aa4,   // ceb.tl.id_544 id.ceb.ms_643  blu.vi.un_860 tl.sq.lg_433
  0x02161e07, 0x1e0e31af, 0x1f2d2908, 0x25001b13,   // ms.hr.da_432 az.is.ms_655  sl.sk.cy_443 tr.eu.un_650
  // [4f10]
  0x1b310807, 0x31181bee, 0x55182807, 0x13001c0d,   // no.az.tr_432 tr.ga.az_422  sw.ga.rw_432 mr.bh.un_540
  0x29160da4, 0x080911a6, 0x31000a07, 0x6e002b2a,   // cs.hr.sl_433 ro.pl.no_521  pt.az.un_420 vi.blu.un_970
  0x172916a7, 0x171110a4, 0x1e0f5307, 0x251304ec,   // hr.sl.sr_532 be.ro.sr_433  ht.lv.ms_432 fi.et.eu_644
  0x2d0d2912, 0x10292dee, 0x1c002807, 0x290e090c,   // sl.cs.sk_654 sk.sl.lt_422  sw.id.un_420 pl.is.sl_543
  // [4f20]
  0x3f25100c, 0x1b005514, 0x11100755, 0x551b2904,   // lt.eu.af_543 rw.tr.un_660  it.lt.ro_442 sl.tr.rw_332
  0x03063f60, 0x230b0107, 0x2d005502, 0x102a5505,   // af.de.nl_664 en.es.ca_432  rw.sk.un_220 rw.mt.lt_333
  0x2d1905ee, 0x020c210b, 0x06070e0c, 0x3f1f04ad,   // fr.gl.sk_422 jw.sv.da_542  is.it.de_543 fi.cy.af_643
  0x0c2008a4, 0x061013a0, 0x19080ca0, 0x1c132bad,   // no.sq.sv_433 et.lt.de_322  sv.no.gl_322 vi.et.id_643
  // [4f30]
  0x105301a4, 0x032025a0, 0x31001c04, 0x04136b14,   // en.ht.lt_433 eu.sq.nl_322  id.az.un_320 ceb.et.fi_666
  0x282702a0, 0x03133f60, 0x0f2d0404, 0x25003f14,   // da.gd.sw_322 af.et.nl_664  fi.sk.lv_332 af.eu.un_660
  0x3f006408, 0x080253a9, 0x2a0801a0, 0x18271f13,   // lg.af.un_430 ht.da.no_544  en.no.mt_322 cy.gd.ga_665
  0x02000602, 0x2b011607, 0x1c216b07, 0x2500130e,   // de.da.un_220 hr.en.vi_432  ceb.jw.id_432 et.eu.un_550
  // [4f40]
  0x19000808, 0x10130f07, 0x033f0207, 0x160a2804,   // no.gl.un_430 lv.et.lt_432  da.af.nl_432 sw.pt.hr_332
  0x2055530b, 0x132b2807, 0x271e18a0, 0x023f0304,   // ht.rw.sq_542 sw.vi.et_432  ga.ms.gd_322 nl.af.da_332
  0x03211ca0, 0x231921af, 0x1c002111, 0x53270e05,   // id.jw.nl_322 jw.gl.ca_655  jw.id.un_630 is.gd.ht_333
  0x210305a0, 0x21201c02, 0x2a0305a6, 0x55006b07,   // fr.nl.jw_322 id.sq.jw_222  fr.nl.mt_521 ceb.rw.un_420
  // [4f50]
  0x6e6b0da0, 0x251108a4, 0x130d09a4, 0x1b1321a4,   // cs.ceb.blu_322 no.ro.eu_433  hi.ne.bh_433 jw.et.tr_433
  0x190a23a9, 0x02203f0c, 0x29060eee, 0x04006429,   // ca.pt.gl_544 af.sq.da_543  is.de.sl_422 lg.fi.un_960
  0x532105a7, 0x291c1e0b, 0x3f031b0c, 0x2d0a1207,   // fr.jw.ht_532 ms.id.sl_542  tr.nl.af_543 hu.pt.sk_432
  0x0d001013, 0x0c0602a0, 0x212008a0, 0x04132107,   // lt.cs.un_650 da.de.sv_322  no.sq.jw_322 jw.et.fi_432
  // [4f60]
  0x040621a0, 0x13080205, 0x3f1b2da4, 0x04002104,   // jw.de.fi_322 da.no.et_333  sk.tr.af_433 jw.fi.un_320
  0x18011fad, 0x0e1e1c13, 0x640d21ee, 0x1b310e0d,   // cy.en.ga_643 id.ms.is_665  jw.cs.lg_422 is.az.tr_554
  0x1b1e1c11, 0x06080ead, 0x061b0e04, 0x190155a0,   // id.ms.tr_653 is.no.de_643  is.tr.de_332 rw.en.gl_322
  0x112d0d07, 0x6e1b1207, 0x121f1012, 0x31190bad,   // cs.sk.ro_432 hu.tr.blu_432  lt.cy.hu_654 es.gl.az_643
  // [4f70]
  0x0f0e0107, 0x21132d09, 0x080e0ca0, 0x2b00010d,   // en.is.lv_432 sk.et.jw_444  sv.is.no_322 en.vi.un_540
  0x211f09a7, 0x29000414, 0x11550b0e, 0x04130fee,   // pl.cy.jw_532 fi.sl.un_660  es.rw.ro_555 lv.et.fi_422
  0x03000618, 0x033f0f0c, 0x28000f0d, 0x0c13030c,   // de.nl.un_740 lv.af.nl_543  lv.sw.un_540 nl.et.sv_543
  0x251a0ba4, 0x27001f12, 0x0c000104, 0x0a2d0d02,   // es.tl.eu_433 cy.gd.un_640  en.sv.un_320 cs.sk.pt_222
  // [4f80]
  0x133f01a4, 0x121e1c5a, 0x1b060202, 0x182a01a9,   // en.af.et_433 id.ms.hu_553  da.de.tr_222 en.mt.ga_544
  0x07061f07, 0x19000b0d, 0x0f101b0c, 0x08001002,   // cy.de.it_432 es.gl.un_540  tr.lt.lv_543 be.uk.un_220
  0x17080a09, 0x64001c13, 0x13001004, 0x080e0204,   // mk.uk.sr_444 id.lg.un_650  lt.et.un_320 da.is.no_332
  0x031b3fa9, 0x120c08af, 0x020c2aa4, 0x100f130d,   // af.tr.nl_544 no.sv.hu_655  mt.sv.da_433 et.lv.lt_554
  // [4f90]
  0x0f02010c, 0x066b0107, 0x01000f1a, 0x2a000c04,   // en.da.lv_543 en.ceb.de_432  lv.en.un_760 sv.mt.un_320
  0x11080405, 0x07080208, 0x6e2b2109, 0x08000c09,   // ru.uk.ro_333 da.no.it_443  jw.vi.blu_444 sv.no.un_440
  0x281e1c55, 0x53170e12, 0x0d1c1307, 0x03211fa4,   // id.ms.sw_442 is.sr.ht_654  bh.mr.ne_432 cy.jw.nl_433
  0x0a001604, 0x23552804, 0x171b16ee, 0x171107a9,   // hr.pt.un_320 sw.rw.ca_332  hr.tr.sr_422 bg.ro.sr_544
  // [4fa0]
  0x21002708, 0x04001023, 0x040a11a0, 0x0f112004,   // gd.jw.un_430 be.ru.un_880  ro.mk.ru_322 sq.ro.lv_332
  0x0c002a04, 0x27000305, 0x6e1f2b12, 0x1c130dec,   // mt.sv.un_320 nl.gd.un_330  vi.cy.blu_654 ne.bh.mr_644
  0x120a11a0, 0x1c010902, 0x6e002b2c, 0x6b2a2d04,   // ro.pt.hu_322 pl.en.id_222  vi.blu.un_990 sk.mt.ceb_332
  0x1000090e, 0x25002007, 0x0900101b, 0x06005509,   // pl.lt.un_550 sq.eu.un_420  lt.pl.un_770 rw.de.un_440
  // [4fb0]
  0x6b3f03a9, 0x12000607, 0x0700042c, 0x1c00060c,   // nl.af.ceb_544 de.hu.un_420  ru.bg.un_990 de.id.un_530
  0x25002704, 0x13200e0b, 0x2d121811, 0x3f081207,   // gd.eu.un_320 is.sq.et_542  ga.hu.sk_653 hu.no.af_432
  0x06180302, 0x1a000b21, 0x211b1a0c, 0x1c006b04,   // nl.ga.de_222 es.tl.un_860  tl.tr.jw_543 ceb.id.un_320
  0x05001a04, 0x04532507, 0x091f17a4, 0x1a003113,   // tl.fr.un_320 eu.ht.fi_432  sr.cy.pl_433 az.tl.un_650
  // [4fc0]
  0x060917a0, 0x2d110d0c, 0x1604100d, 0x0e001e07,   // sr.pl.de_322 cs.ro.sk_543  lt.fi.hr_554 ms.is.un_420
  0x1a2b0107, 0x2d290913, 0x311f2907, 0x100817a0,   // en.vi.tl_432 pl.sl.sk_665  sl.cy.az_432 sr.uk.be_322
  0x0e0831ee, 0x13002704, 0x53000408, 0x2d040911,   // az.no.is_422 gd.et.un_320  fi.ht.un_430 pl.fi.sk_653
  0x281706a0, 0x130c6407, 0x55026ba0, 0x02000c18,   // de.sr.sw_322 lg.sv.et_432  ceb.da.rw_322 sv.da.un_740
  // [4fd0]
  0x1f002007, 0x0f000404, 0x13171660, 0x643f5505,   // sq.cy.un_420 fi.lv.un_320  hr.sr.et_664 rw.af.lg_333
  0x6b000b19, 0x2364250c, 0x23280709, 0x6b551a55,   // es.ceb.un_750 eu.lg.ca_543  it.sw.ca_444 tl.rw.ceb_442
  0x0455530b, 0x060412ee, 0x31641b5a, 0x1a1b315a,   // ht.rw.fi_542 hu.fi.de_422  tr.lg.az_553 az.tr.tl_553
  0x05061ca4, 0x19050a5a, 0x25100e12, 0x55000813,   // id.de.fr_433 pt.fr.gl_553  is.lt.eu_654 no.rw.un_650
  // [4fe0]
  0x276b1a0b, 0x282555a9, 0x2b000721, 0x31022507,   // tl.ceb.gd_542 rw.eu.sw_544  it.vi.un_860 eu.da.az_432
  0x033f1fa6, 0x280e0609, 0x5500211b, 0x080a04ad,   // cy.af.nl_521 de.is.sw_444  jw.rw.un_770 ru.mk.uk_643
  0x530c0404, 0x105304a4, 0x04021ba4, 0x1e021c07,   // fi.sv.ht_332 fi.ht.lt_433  tr.da.fi_433 id.da.ms_432
  0x2d0d06a9, 0x55002514, 0x216455a9, 0x08170da0,   // de.cs.sk_544 eu.rw.un_660  rw.lg.jw_544 cs.sr.no_322
  // [4ff0]
  0x04061ca4, 0x13551aa4, 0x3100250d, 0x1a645512,   // id.de.fi_433 tl.rw.et_433  eu.az.un_540 rw.lg.tl_654
  0x1b0264a7, 0x1e1c0a02, 0x251b0608, 0x550664af,   // lg.da.tr_532 pt.id.ms_222  de.tr.eu_443 lg.de.rw_655
  0x01271f07, 0x6b551a04, 0x0721280d, 0x551b2807,   // cy.gd.en_432 tl.rw.ceb_332  sw.jw.it_554 sw.tr.rw_432
  0x063f035a, 0x315521a4, 0x1c530808, 0x64081aa4,   // nl.af.de_553 jw.rw.az_433  no.ht.id_443 tl.no.lg_433

  // [5000]
  0x3f031ba0, 0x1b011fa9, 0x21181214, 0x180d19af,   // tr.nl.af_322 cy.en.tr_544  ur.ar.fa_666 gl.cs.ga_655
  0x190b0da0, 0x11021ca0, 0x022a0c04, 0x07112d0c,   // cs.es.gl_322 id.da.ro_322  sv.mt.da_332 sk.ro.it_543
  0x04645508, 0x13072912, 0x043f53af, 0x12001821,   // rw.lg.fi_443 sl.it.et_654  ht.af.fi_655 ar.ur.un_860
  0x1e003f13, 0x1b1e05ec, 0x0c1f0ea9, 0x1e1c03a0,   // af.ms.un_650 fr.ms.tr_644  is.cy.sv_544 nl.id.ms_322
  // [5010]
  0x17002902, 0x0e020807, 0x180d2d0c, 0x0a2d0d09,   // sl.sr.un_220 no.da.is_432  sk.cs.ga_543 cs.sk.pt_444
  0x120b0a04, 0x1200050b, 0x20000308, 0x10040a05,   // pt.es.hu_332 fr.hu.un_520  nl.sq.un_430 mk.ru.be_333
  0x1600290b, 0x2400012b, 0x030805a7, 0x53081002,   // sl.hr.un_520 iw.yi.un_980  fr.no.nl_532 lt.no.ht_222
  0x212d0d02, 0x2b530304, 0x28180907, 0x2d00290d,   // cs.sk.jw_222 nl.ht.vi_332  pl.ga.sw_432 sl.sk.un_540
  // [5020]
  0x20112160, 0x21033f04, 0x23171608, 0x173f1e0c,   // jw.ro.sq_664 af.nl.jw_332  hr.sr.ca_443 ms.af.sr_543
  0x0700040c, 0x0c060313, 0x0c06030e, 0x10070a12,   // ru.bg.un_530 nl.de.sv_665  nl.de.sv_555 mk.bg.be_654
  0x23055307, 0x6b3f05ee, 0x060418a7, 0x080c05ec,   // ht.fr.ca_432 fr.af.ceb_422  ga.fi.de_532 fr.sv.no_644
  0x17162908, 0x06001302, 0x07002007, 0x0d292dad,   // sl.hr.sr_443 et.de.un_220  sq.it.un_420 sk.sl.cs_643
  // [5030]
  0x03020c04, 0x3f022aa0, 0x0d2d1304, 0x1a281812,   // sv.da.nl_332 mt.da.af_322  et.sk.cs_332 ga.sw.tl_654
  0x23530511, 0x060903af, 0x06180107, 0x316b01a0,   // fr.ht.ca_653 nl.pl.de_655  en.ga.de_432 en.ceb.az_322
  0x19171604, 0x09282d07, 0x12180e5a, 0x2d0d1214,   // hr.sr.gl_332 sk.sw.pl_432  is.ga.hu_553 hu.cs.sk_666
  0x25173109, 0x0c1b23ee, 0x08040eec, 0x64280802,   // az.sr.eu_444 ca.tr.sv_422  is.fi.no_644 no.sw.lg_222
  // [5040]
  0x311b21ec, 0x04250505, 0x1a0801a7, 0x0c00291a,   // jw.tr.az_644 fr.eu.fi_333  en.no.tl_532 sl.sv.un_760
  0x133f06ee, 0x0a250704, 0x10182705, 0x6b530555,   // de.af.et_422 it.eu.pt_332  gd.ga.lt_333 fr.ht.ceb_442
  0x3f000c05, 0x04071709, 0x06080213, 0x0b080612,   // sv.af.un_330 sr.bg.ru_444  da.no.de_665 de.no.es_654
  0x080207a4, 0x530501a4, 0x05000122, 0x0c040807,   // it.da.no_433 en.fr.ht_433  en.fr.un_870 no.fi.sv_432
  // [5050]
  0x02000613, 0x0a00072c, 0x050208a4, 0x01001e04,   // de.da.un_650 bg.mk.un_990  no.da.fr_433 ms.en.un_320
  0x271c0107, 0x130f27a4, 0x06000204, 0x1f0501a4,   // en.id.gd_432 gd.lv.et_433  da.de.un_320 en.fr.cy_433
  0x182101ad, 0x06293f0c, 0x05000d05, 0x0612250c,   // en.jw.ga_643 af.sl.de_543  cs.fr.un_330 eu.hu.de_543
  0x17100704, 0x070b2314, 0x0d210513, 0x17001622,   // bg.be.sr_332 ca.es.it_666  fr.jw.cs_665 hr.sr.un_870
  // [5060]
  0x05210da4, 0x290d1702, 0x2805010c, 0x06120cad,   // cs.jw.fr_433 sr.cs.sl_222  en.fr.sw_543 sv.hu.de_643
  0x3f000e07, 0x2d210d12, 0x3f1a6b11, 0x212d0d14,   // is.af.un_420 cs.jw.sk_654  ceb.tl.af_653 cs.sk.jw_666
  0x55002522, 0x21000d08, 0x021a3fa0, 0x28001a2a,   // eu.rw.un_870 cs.jw.un_430  af.tl.da_322 tl.sw.un_970
  0x2700530b, 0x2b6b21ad, 0x052d0d07, 0x25000612,   // ht.gd.un_520 jw.ceb.vi_643  cs.sk.fr_432 de.eu.un_640
  // [5070]
  0x13110f05, 0x20001109, 0x21000512, 0x530105a0,   // lv.ro.et_333 ro.sq.un_440  fr.jw.un_640 fr.en.ht_322
  0x16172004, 0x07000b1a, 0x06001122, 0x28000707,   // sq.sr.hr_332 es.it.un_760  ro.de.un_870 it.sw.un_420
  0x05002113, 0x052d0d60, 0x29002d0c, 0x2d0d05a9,   // jw.fr.un_650 cs.sk.fr_664  sk.sl.un_530 fr.cs.sk_544
  0x27071f0c, 0x0c13045a, 0x212d0d0d, 0x21000519,   // cy.it.gd_543 fi.et.sv_553  cs.sk.jw_554 fr.jw.un_750
  // [5080]
  0x28101c04, 0x2520210c, 0x07002907, 0x270928a6,   // id.lt.sw_332 jw.sq.eu_543  sl.it.un_420 sw.pl.gd_521
  0x08070407, 0x211a6baf, 0x0a0708ee, 0x04001018,   // ru.bg.uk_432 ceb.tl.jw_655  uk.bg.mk_422 be.ru.un_740
  0x09000504, 0x1f003f05, 0x060c2d05, 0x02290e0c,   // fr.pl.un_320 af.cy.un_330  sk.sv.de_333 is.sl.da_543
  0x03080255, 0x080e0404, 0x1c2a2307, 0x0e002302,   // da.no.nl_442 fi.is.no_332  ca.mt.id_432 ca.is.un_220
  // [5090]
  0x216b6409, 0x6b00210d, 0x3f0106ee, 0x080417ee,   // lg.ceb.jw_444 jw.ceb.un_540  de.en.af_422 sr.ru.uk_422
  0x10122904, 0x100a1705, 0x07290a07, 0x64001c02,   // sl.hu.lt_332 sr.mk.be_333  pt.sl.it_432 id.lg.un_220
  0x2d0d08a4, 0x53311b12, 0x230417a0, 0x08022005,   // no.cs.sk_433 tr.az.ht_654  sr.fi.ca_322 sq.da.no_333
  0x06002a0c, 0x05001f07, 0x2a000513, 0x29172da4,   // mt.de.un_530 cy.fr.un_420  fr.mt.un_650 sk.sr.sl_433
  // [50a0]
  0x0a250f02, 0x230b0a08, 0x641e1c09, 0x21100f07,   // lv.eu.pt_222 pt.es.ca_443  id.ms.lg_444 lv.lt.jw_432
  0x0811170d, 0x0d090fa4, 0x0a081113, 0x0c530402,   // sr.ro.uk_554 lv.pl.cs_433  ro.uk.mk_665 fi.ht.sv_222
  0x0b0a07a0, 0x062818a6, 0x1f005508, 0x0d002d0b,   // it.pt.es_322 ga.sw.de_521  rw.cy.un_430 sk.cs.un_520
  0x531b1208, 0x1e1c10a0, 0x07192b13, 0x04001029,   // hu.tr.ht_443 lt.id.ms_322  vi.gl.it_665 lt.fi.un_960
  // [50b0]
  0x05251012, 0x3f030e05, 0x11000808, 0x2b000f2a,   // lt.eu.fr_654 is.nl.af_333  no.ro.un_430 lv.vi.un_970
  0x01002b0b, 0x2b1a1909, 0x27002105, 0x551228af,   // vi.en.un_520 gl.tl.vi_444  jw.gd.un_330 sw.hu.rw_655
  0x176b0607, 0x530b23a0, 0x2b1f25ad, 0x310c2aa7,   // de.ceb.sr_432 ca.es.ht_322  eu.cy.vi_643 mt.sv.az_532
  0x2d0d0f05, 0x6e000708, 0x2a271ea0, 0x1f07190c,   // lv.cs.sk_333 it.blu.un_430  ms.gd.mt_322 gl.it.cy_543
  // [50c0]
  0x0d0f2dad, 0x232b25ad, 0x64555308, 0x0f2d0d04,   // sk.lv.cs_643 eu.vi.ca_643  ht.rw.lg_443 cs.sk.lv_332
  0x25002b0d, 0x28006e0e, 0x64281e07, 0x232b6e07,   // vi.eu.un_540 blu.sw.un_550  ms.sw.lg_432 blu.vi.ca_432
  0x016b2ba0, 0x031e1c02, 0x0c0313ec, 0x28071fa4,   // vi.ceb.en_322 id.ms.nl_222  et.nl.sv_644 cy.it.sw_433
  0x120253ee, 0x2b6e13a9, 0x1300011a, 0x2d0d3fee,   // ht.da.hu_422 et.blu.vi_544  en.et.un_760 af.cs.sk_422
  // [50d0]
  0x11190a13, 0x53005507, 0x040a0fec, 0x0129050c,   // pt.gl.ro_665 rw.ht.un_420  lv.pt.fi_644 fr.sl.en_543
  0x053f0314, 0x08020ea6, 0x030105a0, 0x01063fa0,   // nl.af.fr_666 is.da.no_521  fr.en.nl_322 af.de.en_322
  0x09112307, 0x10000721, 0x173f0604, 0x0802050c,   // ca.ro.pl_432 bg.be.un_860  de.af.sr_332 fr.da.no_543
  0x19070107, 0x061925ee, 0x010d050c, 0x120c08a4,   // en.it.gl_432 eu.gl.de_422  fr.cs.en_543 no.sv.hu_433
  // [50e0]
  0x1e211caf, 0x25000405, 0x02162902, 0x232110a4,   // id.jw.ms_655 fi.eu.un_330  sl.hr.da_222 lt.jw.ca_433
  0x2b002713, 0x0c002702, 0x0c052da0, 0x21030504,   // gd.vi.un_650 gd.sv.un_220  sk.fr.sv_322 fr.nl.jw_332
  0x080c0209, 0x06033f05, 0x053f0107, 0x31001b35,   // da.sv.no_444 af.nl.de_333  en.af.fr_432 tr.az.un_A90
  0x09080304, 0x01060707, 0x2a0806ee, 0x105302ac,   // nl.no.pl_332 it.de.en_432  de.no.mt_422 da.ht.lt_632
  // [50f0]
  0x01002107, 0x08001107, 0x5305110c, 0x090d2daf,   // jw.en.un_420 ro.uk.un_420  ro.fr.ht_543 sk.cs.pl_655
  0x231e1cec, 0x092b3f07, 0x27001f14, 0x06050107,   // id.ms.ca_644 af.vi.pl_432  cy.gd.un_660 en.fr.de_432
  0x05042aee, 0x213f030c, 0x2812215a, 0x0d093fa0,   // mt.fi.fr_422 nl.af.jw_543  jw.hu.sw_553 af.pl.cs_322
  0x2000100b, 0x0d3f0108, 0x022b2da0, 0x0f2d1002,   // lt.sq.un_520 en.af.cs_443  sk.vi.da_322 lt.sk.lv_222
  // [5100]
  0x0a000219, 0x6b00010b, 0x0400020d, 0x013f0907,   // da.pt.un_750 en.ceb.un_520  da.fi.un_540 pl.af.en_432
  0x29002a04, 0x04002004, 0x2d0d3f02, 0x0f2a090b,   // mt.sl.un_320 sq.fi.un_320  af.cs.sk_222 pl.mt.lv_542
  0x01132004, 0x29166407, 0x05001805, 0x09120da0,   // sq.et.en_332 lg.hr.sl_432  ga.fr.un_330 cs.hu.pl_322
  0x033f0209, 0x2d0d16af, 0x2a0c29a4, 0x170d290d,   // da.af.nl_444 hr.cs.sk_655  sl.sv.mt_433 sl.cs.sr_554
  // [5110]
  0x08212d0e, 0x2800250c, 0x1e211c0c, 0x19070c02,   // sk.jw.no_555 eu.sw.un_530  id.jw.ms_543 sv.it.gl_222
  0x292819ee, 0x17091205, 0x1b001205, 0x0e1e1c0d,   // gl.sw.sl_422 hu.pl.sr_333  hu.tr.un_330 id.ms.is_554
  0x1700100d, 0x0200200c, 0x190b05ee, 0x04070a0b,   // be.sr.un_540 sq.da.un_530  fr.es.gl_422 mk.bg.ru_542
  0x29002102, 0x0c1617a0, 0x28000f07, 0x1c285302,   // jw.sl.un_220 sr.hr.sv_322  lv.sw.un_420 ht.sw.id_222
  // [5120]
  0x25081aa0, 0x081f18a0, 0x060e0c04, 0x3f0221ee,   // tl.no.eu_322 ga.cy.no_322  sv.is.de_332 jw.da.af_422
  0x0c000402, 0x280102a4, 0x11090d0c, 0x28211b0c,   // fi.sv.un_220 da.en.sw_433  cs.pl.ro_543 tr.jw.sw_543
  0x08170404, 0x2813040d, 0x19000505, 0x08021a14,   // ru.sr.uk_332 fi.et.sw_554  fr.gl.un_330 tl.da.no_666
  0x285564a0, 0x080a11ac, 0x06001b04, 0x28080407,   // lg.rw.sw_322 ro.mk.uk_632  tr.de.un_320 fi.no.sw_432
  // [5130]
  0x04280f11, 0x06002a19, 0x3f0828a0, 0x1f000604,   // lv.sw.fi_653 mt.de.un_750  sw.no.af_322 de.cy.un_320
  0x1018270d, 0x16121704, 0x0e211cec, 0x1b10090c,   // gd.ga.lt_554 sr.hu.hr_332  id.jw.is_644 pl.lt.tr_543
  0x2100020c, 0x20112807, 0x6400550b, 0x052301a0,   // da.jw.un_530 sw.ro.sq_432  rw.lg.un_520 en.ca.fr_322
  0x0a000909, 0x050c07ac, 0x230f270c, 0x313f2008,   // pl.pt.un_440 it.sv.fr_632  gd.lv.ca_543 sq.af.az_443
  // [5140]
  0x6b1a0b55, 0x20311b04, 0x0c060107, 0x121b0d0b,   // es.tl.ceb_442 tr.az.sq_332  en.de.sv_432 cs.tr.hu_542
  0x08071014, 0x0d2512a9, 0x21290605, 0x121b1ca9,   // be.bg.uk_666 hu.eu.cs_544  de.sl.jw_333 id.tr.hu_544
  0x16001e1a, 0x0f1b0804, 0x04642aee, 0x090d2aa0,   // ms.hr.un_760 no.tr.lv_332  mt.lg.fi_422 mt.cs.pl_322
  0x2a1b3f07, 0x07640ea4, 0x20100807, 0x03061804,   // af.tr.mt_432 is.lg.it_433  no.lt.sq_432 ga.de.nl_332
  // [5150]
  0x0804070e, 0x0d211ba4, 0x090812ee, 0x04006b07,   // bg.ru.uk_555 tr.jw.cs_433  hu.no.pl_422 ceb.fi.un_420
  0x64002002, 0x070364a0, 0x0200181a, 0x12002008,   // sq.lg.un_220 lg.nl.it_322  ga.da.un_760 sq.hu.un_430
  0x01000b08, 0x04100802, 0x64000e04, 0x06000214,   // es.en.un_430 uk.be.ru_222  is.lg.un_320 da.de.un_660
  0x1f002713, 0x25120d08, 0x21121c12, 0x12290d09,   // gd.cy.un_650 cs.hu.eu_443  id.hu.jw_654 cs.sl.hu_444
  // [5160]
  0x3f210960, 0x21001002, 0x29120da9, 0x17100a02,   // pl.jw.af_664 lt.jw.un_220  cs.hu.sl_544 mk.be.sr_222
  0x1b121ca0, 0x250d12a9, 0x2d002502, 0x2900120c,   // id.hu.tr_322 hu.cs.eu_544  eu.sk.un_220 hu.sl.un_530
  0x64073fa4, 0x2a642107, 0x642a03a0, 0x11251807,   // af.it.lg_433 jw.lg.mt_432  nl.mt.lg_322 ga.eu.ro_432
  0x05001811, 0x08070404, 0x0c080ba0, 0x192307a0,   // ga.fr.un_630 ru.bg.uk_332  es.no.sv_322 it.ca.gl_322
  // [5170]
  0x032311a0, 0x19230b04, 0x1c251eaf, 0x05001804,   // ro.ca.nl_322 es.ca.gl_332  ms.eu.id_655 ga.fr.un_320
  0x1f112107, 0x021a1f0c, 0x08001f1a, 0x53003f08,   // jw.ro.cy_432 cy.tl.da_543  cy.no.un_760 af.ht.un_430
  0x0b002b2b, 0x531a1ea0, 0x550105a0, 0x18122114,   // vi.es.un_980 ms.tl.ht_322  fr.en.rw_322 fa.ur.ar_666
  0x0b0105a4, 0x2b012805, 0x0a0407a7, 0x20000402,   // fr.en.es_433 sw.en.vi_333  bg.ru.mk_532 fi.sq.un_220
  // [5180]
  0x03130c04, 0x2b530111, 0x1200642a, 0x086b2bee,   // sv.et.nl_332 en.ht.vi_653  lg.hu.un_970 vi.ceb.no_422
  0x1b2753a0, 0x2017160d, 0x20001609, 0x07110808,   // ht.gd.tr_322 hr.sr.sq_554  hr.sq.un_440 uk.ro.bg_443
  0x2b006b02, 0x040807a9, 0x6e002b0d, 0x1f080407,   // ceb.vi.un_220 bg.uk.ru_544  vi.blu.un_540 fi.no.cy_432
  0x01002907, 0x53001b05, 0x08021fa4, 0x01001908,   // sl.en.un_420 tr.ht.un_330  cy.da.no_433 gl.en.un_430
  // [5190]
  0x1a2b01ad, 0x1b082702, 0x290131a4, 0x28315504,   // en.vi.tl_643 gd.no.tr_222  az.en.sl_433 rw.az.sw_332
  0x20115505, 0x17071104, 0x0a310e05, 0x04171013,   // rw.ro.sq_333 ro.bg.sr_332  is.az.pt_333 be.sr.ru_665
  0x050129a9, 0x0e1b310c, 0x2100640d, 0x07111704,   // sl.en.fr_544 az.tr.is_543  lg.jw.un_540 sr.ro.bg_332
  0x04070aaf, 0x0a000723, 0x0e55280c, 0x09050804,   // mk.bg.ru_655 bg.mk.un_880  sw.rw.is_543 no.fr.pl_332
  // [51a0]
  0x1b0e2507, 0x076404a6, 0x09000c09, 0x0b251e0c,   // eu.is.tr_432 fi.lg.it_521  sv.pl.un_440 ms.eu.es_543
  0x2d001f05, 0x086b01a6, 0x21552812, 0x281255a4,   // cy.sk.un_330 en.ceb.no_521  sw.rw.jw_654 rw.hu.sw_433
  0x02121fa4, 0x0b2307ee, 0x05060112, 0x0b551f07,   // cy.hu.da_433 it.ca.es_422  en.de.fr_654 cy.rw.es_432
  0x0d000a04, 0x55192d07, 0x31551ba4, 0x64311ba9,   // pt.cs.un_320 sk.gl.rw_432  tr.rw.az_433 tr.az.lg_544
  // [51b0]
  0x0a003104, 0x120d2da4, 0x311b25ad, 0x1806010c,   // az.pt.un_320 sk.cs.hu_433  eu.tr.az_643 en.de.ga_543
  0x161729a4, 0x286b01ee, 0x03642813, 0x09005519,   // sl.sr.hr_433 en.ceb.sw_422  sw.lg.nl_665 rw.pl.un_750
  0x0d122d08, 0x2a286412, 0x0d1c09ec, 0x552112a4,   // sk.hu.cs_443 lg.sw.mt_654  hi.mr.ne_644 hu.jw.rw_433
  0x2812290c, 0x55002021, 0x17070407, 0x291906a0,   // sl.hu.sw_543 sq.rw.un_860  ru.bg.sr_432 de.gl.sl_322
  // [51c0]
  0x12001a04, 0x531b2104, 0x2d0306ec, 0x1b53130c,   // tl.hu.un_320 jw.tr.ht_332  de.nl.sk_644 et.ht.tr_543
  0x27006404, 0x271f06a0, 0x06162904, 0x01001f02,   // lg.gd.un_320 de.cy.gd_322  sl.hr.de_332 cy.en.un_220
  0x25190b08, 0x033107a0, 0x1b0e1ca0, 0x2d1627a0,   // es.gl.eu_443 it.az.nl_322  id.is.tr_322 gd.hr.sk_322
  0x09292d07, 0x3f0953a7, 0x030e01a9, 0x2d290d12,   // sk.sl.pl_432 ht.pl.af_532  en.is.nl_544 cs.sl.sk_654
  // [51d0]
  0x29000508, 0x09291604, 0x2a0203ad, 0x20290d08,   // fr.sl.un_430 hr.sl.pl_332  nl.da.mt_643 cs.sl.sq_443
  0x021a1ca0, 0x090e010c, 0x121903ee, 0x100f64ad,   // id.tl.da_322 en.is.pl_543  nl.gl.hu_422 lg.lv.lt_643
  0x21160b04, 0x010308ee, 0x25060107, 0x310f2a05,   // es.hr.jw_332 no.nl.en_422  en.de.eu_432 mt.lv.az_333
  0x076e64a7, 0x0d021304, 0x0c000e0d, 0x1a0731a0,   // lg.blu.it_532 et.da.cs_332  is.sv.un_540 az.it.tl_322
  // [51e0]
  0x08000e04, 0x1a023fa7, 0x10002d1b, 0x02120807,   // is.no.un_320 af.da.tl_532  sk.lt.un_770 no.hu.da_432
  0x2d0d29a9, 0x01002a08, 0x171a6b14, 0x16002108,   // sl.cs.sk_544 mt.en.un_430  ceb.tl.sr_666 jw.hr.un_430
  0x6b031907, 0x080f04ad, 0x0528010c, 0x0f0801a9,   // gl.nl.ceb_432 fi.lv.no_643  en.sw.fr_543 en.no.lv_544
  0x04532555, 0x210764ad, 0x0d1610a7, 0x10006419,   // eu.ht.fi_442 lg.it.jw_643  lt.hr.cs_532 lg.lt.un_750
  // [51f0]
  0x02010812, 0x12000202, 0x13000802, 0x076b1a0c,   // no.en.da_654 da.hu.un_220  no.et.un_220 tl.ceb.it_543
  0x0c0313ee, 0x0c00022c, 0x070b1a11, 0x0e001304,   // et.nl.sv_422 da.sv.un_990  tl.es.it_653 et.is.un_320
  0x080212a4, 0x04080304, 0x0b160705, 0x02080c60,   // hu.da.no_433 nl.no.fi_332  it.hr.es_333 sv.no.da_664
  0x64001604, 0x09172804, 0x1008040d, 0x5528090c,   // hr.lg.un_320 sw.sr.pl_332  ru.uk.be_554 pl.sw.rw_543
  // [5200]
  0x0c000e07, 0x1b3125ad, 0x551107ad, 0x1c070ca0,   // is.sv.un_420 eu.az.tr_643  it.ro.rw_643 sv.it.id_322
  0x12182102, 0x04071aa0, 0x10040aac, 0x1828110c,   // fa.ar.ur_222 tl.it.fi_322  mk.ru.be_632 ro.sw.ga_543
  0x1e1c3102, 0x1b000e07, 0x04291009, 0x070123ee,   // az.id.ms_222 is.tr.un_420  lt.sl.fi_444 ca.en.it_422
  0x2500270d, 0x25002322, 0x252818a4, 0x1a04210e,   // gd.eu.un_540 ca.eu.un_870  ga.sw.eu_433 jw.fi.tl_555
  // [5210]
  0x171610a6, 0x0f2104a6, 0x070a1005, 0x171610ac,   // lt.hr.sr_521 fi.jw.lv_521  be.mk.bg_333 lt.hr.sr_632
  0x21060a07, 0x23000f1a, 0x25002312, 0x640b0a02,   // pt.de.jw_432 lv.ca.un_760  ca.eu.un_640 pt.es.lg_222
  0x11001813, 0x110e25ec, 0x181027a0, 0x09002507,   // ga.ro.un_650 eu.is.ro_644  gd.lt.ga_322 eu.pl.un_420
  0x0b002004, 0x080201a0, 0x05002502, 0x03210804,   // sq.es.un_320 en.da.no_322  eu.fr.un_220 no.jw.nl_332
  // [5220]
  0x250828ee, 0x551a6b11, 0x07030209, 0x2a100f60,   // sw.no.eu_422 ceb.tl.rw_653  da.nl.it_444 lv.lt.mt_664
  0x072a1fad, 0x531a07ad, 0x081202a4, 0x09062d11,   // cy.mt.it_643 it.tl.ht_643  da.hu.no_433 sk.de.pl_653
  0x03002904, 0x07001707, 0x081855a4, 0x10250107,   // sl.nl.un_320 sr.bg.un_420  rw.ga.no_433 en.eu.lt_432
  0x21030b04, 0x555364ec, 0x6400310d, 0x21551e07,   // es.nl.jw_332 lg.ht.rw_644  az.lg.un_540 ms.rw.jw_432
  // [5230]
  0x645505af, 0x64550807, 0x1b001204, 0x21006412,   // fr.rw.lg_655 no.rw.lg_432  hu.tr.un_320 lg.jw.un_640
  0x6b251113, 0x201b53a0, 0x08126408, 0x13001702,   // ro.eu.ceb_665 ht.tr.sq_322  lg.hu.no_443 sr.et.un_220
  0x181221a6, 0x0c130fec, 0x0717110b, 0x3f010802,   // fa.ur.ar_521 lv.et.sv_644  ro.sr.bg_542 no.en.af_222
  0x2a001321, 0x1b02010c, 0x083f03ee, 0x120208ee,   // et.mt.un_860 en.da.tr_543  nl.af.no_422 no.da.hu_422
  // [5240]
  0x0c0255ee, 0x3f001a19, 0x060c0112, 0x1a005308,   // rw.da.sv_422 tl.af.un_750  en.sv.de_654 ht.tl.un_430
  0x28533f13, 0x5313010c, 0x28006422, 0x1a002d22,   // af.ht.sw_665 en.et.ht_543  lg.sw.un_870 sk.tl.un_870
  0x185564a4, 0x162910a0, 0x23552504, 0x282764ad,   // lg.rw.ga_433 lt.sl.hr_322  eu.rw.ca_332 lg.gd.sw_643
  0x290920a4, 0x202912a7, 0x01006b07, 0x11061208,   // sq.pl.sl_433 hu.sl.sq_532  ceb.en.un_420 hu.de.ro_443
  // [5250]
  0x231a64ee, 0x2300061b, 0x18092dee, 0x17070812,   // lg.tl.ca_422 de.ca.un_770  sk.pl.ga_422 uk.bg.sr_654
  0x230511ee, 0x53001213, 0x183f01ee, 0x0e311ba4,   // ro.fr.ca_422 hu.ht.un_650  en.af.ga_422 tr.az.is_433
  0x01311b13, 0x060301a0, 0x64001304, 0x0b310ea4,   // tr.az.en_665 en.nl.de_322  et.lg.un_320 is.az.es_433
  0x042013ec, 0x0b1b1804, 0x1b253108, 0x210e0ba9,   // et.sq.fi_644 ga.tr.es_332  az.eu.tr_443 es.is.jw_544
  // [5260]
  0x20292dec, 0x12030811, 0x0b0e3108, 0x01201aa0,   // sk.sl.sq_644 no.nl.hu_653  az.is.es_443 tl.sq.en_322
  0x310c0207, 0x0c023f04, 0x200c07a0, 0x010506a0,   // da.sv.az_432 af.da.sv_332  it.sv.sq_322 de.fr.en_322
  0x06000911, 0x1f1801a4, 0x216b5511, 0x1b0b3107,   // pl.de.un_630 en.ga.cy_433  rw.ceb.jw_653 az.es.tr_432
  0x23090da4, 0x19070b07, 0x1827010b, 0x0c00120c,   // cs.pl.ca_433 es.it.gl_432  en.gd.ga_542 hu.sv.un_530
  // [5270]
  0x6b000612, 0x0212060c, 0x1e311b11, 0x062112ad,   // de.ceb.un_640 de.hu.da_543  tr.az.ms_653 hu.jw.de_643
  0x1b0e0808, 0x310b1b07, 0x1300200c, 0x23000a0c,   // no.is.tr_443 tr.es.az_432  sq.et.un_530 pt.ca.un_530
  0x536b1a08, 0x17200d08, 0x1a555307, 0x100411ad,   // tl.ceb.ht_443 cs.sq.sr_443  ht.rw.tl_432 ro.ru.be_643
  0x21133fa0, 0x07081014, 0x070a1112, 0x03060202,   // af.et.jw_322 be.uk.bg_666  ro.mk.bg_654 da.de.nl_222
  // [5280]
  0x1a000c04, 0x1e1c13ec, 0x6b1f3f12, 0x03000113,   // sv.tl.un_320 et.id.ms_644  af.cy.ceb_654 en.nl.un_650
  0x16000307, 0x3f2a180c, 0x011a250c, 0x55102912,   // nl.hr.un_420 ga.mt.af_543  eu.tl.en_543 sl.lt.rw_654
  0x07101104, 0x551e1c11, 0x1a1025a4, 0x55001a2a,   // ro.be.bg_332 id.ms.rw_653  eu.lt.tl_433 tl.rw.un_970
  0x2d0d1007, 0x2d001114, 0x64531f0c, 0x3f041aee,   // lt.cs.sk_432 ro.sk.un_660  cy.ht.lg_543 tl.fi.af_422
  // [5290]
  0x020306a4, 0x2d162355, 0x2d002707, 0x120519ee,   // de.nl.da_433 ca.hr.sk_442  gd.sk.un_420 gl.fr.hu_422
  0x2a1801ee, 0x551e1cec, 0x2319060c, 0x53286405,   // en.ga.mt_422 id.ms.rw_644  de.gl.ca_543 lg.sw.ht_333
  0x5323090c, 0x2a00230c, 0x28001f1a, 0x0700550d,   // pl.ca.ht_543 ca.mt.un_530  cy.sw.un_760 rw.it.un_540
  0x25001105, 0x122864ee, 0x046b29a0, 0x17000a2c,   // ro.eu.un_330 lg.sw.hu_422  sl.ceb.fi_322 mk.sr.un_990
  // [52a0]
  0x20251007, 0x02160607, 0x2d000702, 0x233f0504,   // lt.eu.sq_432 de.hr.da_432  it.sk.un_220 fr.af.ca_332
  0x2a061b05, 0x060501a4, 0x1700210c, 0x03200baf,   // tr.de.mt_333 en.fr.de_433  jw.sr.un_530 es.sq.nl_655
  0x122164a4, 0x2309110c, 0x28532111, 0x251e1c05,   // lg.jw.hu_433 ro.pl.ca_543  jw.ht.sw_653 id.ms.eu_333
  0x08002819, 0x1e091c0d, 0x2d0d12b2, 0x0a00050c,   // sw.no.un_750 id.pl.ms_554  hu.cs.sk_732 fr.pt.un_530
  // [52b0]
  0x08005311, 0x1205010c, 0x64552811, 0x1a1f6ba4,   // ht.no.un_630 en.fr.hu_543  sw.rw.lg_653 ceb.cy.tl_433
  0x2b000e02, 0x060107a4, 0x6b2a1ea7, 0x2b1812ee,   // is.vi.un_220 it.en.de_433  ms.mt.ceb_532 hu.ga.vi_422
  0x010a0f5a, 0x1629045a, 0x2b00182b, 0x530b120c,   // lv.pt.en_553 fi.sl.hr_553  ga.vi.un_980 hu.es.ht_543
  0x100407af, 0x23190112, 0x0523010c, 0x121e1c08,   // bg.ru.be_655 en.gl.ca_654  en.ca.fr_543 id.ms.hu_443
  // [52c0]
  0x211f3fa4, 0x23182ba7, 0x0f2916a0, 0x063f0504,   // af.cy.jw_433 vi.ga.ca_532  hr.sl.lv_322 fr.af.de_332
  0x1b2129ee, 0x0111530c, 0x120501a4, 0x08001f18,   // sl.jw.tr_422 ht.ro.en_543  en.fr.hu_433 cy.no.un_740
  0x08201f04, 0x100429a4, 0x0e2b0a07, 0x041710af,   // cy.sq.no_332 sl.fi.lt_433  pt.vi.is_432 be.sr.ru_655
  0x16291bec, 0x25042904, 0x3f005309, 0x13091ca4,   // tr.sl.hr_644 sl.fi.eu_332  ht.af.un_440 mr.hi.bh_433
  // [52d0]
  0x042a23a4, 0x1200190c, 0x2d0d0409, 0x2d6409a7,   // ca.mt.fi_433 gl.hu.un_530  fi.cs.sk_444 pl.lg.sk_532
  0x0d092daf, 0x12000508, 0x20002819, 0x04132dee,   // sk.pl.cs_655 fr.hu.un_430  sw.sq.un_750 sk.et.fi_422
  0x2d1e21a0, 0x136404ec, 0x13111004, 0x64050ca0,   // jw.ms.sk_322 fi.lg.et_644  lt.ro.et_332 sv.fr.lg_322
  0x20091708, 0x13311b0b, 0x022a0407, 0x0e001305,   // sr.pl.sq_443 tr.az.et_542  fi.mt.da_432 et.is.un_330
  // [52e0]
  0x2a000c12, 0x292d04ad, 0x1e1c1ba0, 0x08040d0c,   // sv.mt.un_640 fi.sk.sl_643  tr.id.ms_322 cs.fi.no_543
  0x033f0e07, 0x0e130f08, 0x08001104, 0x2d0d1107,   // is.af.nl_432 lv.et.is_443  ro.uk.un_320 ro.cs.sk_432
  0x100a07a9, 0x09000c1a, 0x170408a7, 0x16101707,   // bg.mk.be_544 sv.pl.un_760  uk.ru.sr_532 sr.lt.hr_432
  0x0c082102, 0x0f000504, 0x040f10ad, 0x100f1b07,   // jw.no.sv_222 fr.lv.un_320  lt.lv.fi_643 tr.lv.lt_432
  // [52f0]
  0x28002109, 0x18002805, 0x0b002318, 0x0d000204,   // jw.sw.un_440 sw.ga.un_330  ca.es.un_740 da.cs.un_320
  0x0e3109ad, 0x030c020c, 0x10311b04, 0x29171213,   // pl.az.is_643 da.sv.nl_543  tr.az.lt_332 hu.sr.sl_665
  0x53001b02, 0x170a0107, 0x170916af, 0x1255280c,   // tr.ht.un_220 en.pt.sr_432  hr.pl.sr_655 sw.rw.hu_543
  0x203121a4, 0x316b2a07, 0x13001a09, 0x04000e0e,   // jw.az.sq_433 mt.ceb.az_432  tl.et.un_440 is.fi.un_550
  // [5300]
  0x07171108, 0x090e2908, 0x53041007, 0x191125a0,   // ro.sr.bg_443 sl.is.pl_443  lt.fi.ht_432 eu.ro.gl_322
  0x6b0104ee, 0x09171655, 0x10001c04, 0x1b210407,   // fi.en.ceb_422 hr.sr.pl_442  id.lt.un_320 fi.jw.tr_432
  0x1a211cad, 0x0d64200c, 0x642128a7, 0x3f060313,   // id.jw.tl_643 sq.lg.cs_543  sw.jw.lg_532 nl.de.af_665
  0x171610b2, 0x042d0d55, 0x641302ee, 0x0e001604,   // lt.hr.sr_732 cs.sk.fi_442  da.et.lg_422 hr.is.un_320
  // [5310]
  0x2b641004, 0x55290c07, 0x0d001e0c, 0x05011ea4,   // lt.lg.vi_332 sv.sl.rw_432  ms.cs.un_530 ms.en.fr_433
  0x291753ad, 0x170916a0, 0x04101baf, 0x1b171613,   // ht.sr.sl_643 hr.pl.sr_322  tr.lt.fi_655 hr.sr.tr_665
  0x1b126e02, 0x531208a0, 0x0d1c09ac, 0x0e1a0ba9,   // blu.hu.tr_222 no.hu.ht_322  hi.mr.ne_632 es.tl.is_544
  0x2a530da7, 0x202916a4, 0x292d0d0c, 0x64033fad,   // cs.ht.mt_532 hr.sl.sq_433  cs.sk.sl_543 af.nl.lg_643
  // [5320]
  0x04001119, 0x101708ec, 0x0c001204, 0x2d0a2104,   // ro.ru.un_750 no.sr.lt_644  hu.sv.un_320 jw.pt.sk_332
  0x13005302, 0x1a1012ec, 0x2002210c, 0x11311b02,   // ht.et.un_220 hu.lt.tl_644  jw.da.sq_543 tr.az.ro_222
  0x13091c07, 0x230b01a9, 0x190a0baf, 0x06000d02,   // mr.hi.bh_432 en.es.ca_544  es.pt.gl_655 cs.de.un_220
  0x2a1716ac, 0x0c100804, 0x31103f04, 0x03273fa7,   // hr.sr.mt_632 no.lt.sv_332  af.lt.az_332 af.gd.nl_532
  // [5330]
  0x02103fad, 0x64033fa4, 0x01070b12, 0x3f001014,   // af.lt.da_643 af.nl.lg_433  es.it.en_654 lt.af.un_660
  0x0d171609, 0x0f002923, 0x09002902, 0x130111a4,   // hr.sr.cs_444 sl.lv.un_880  sl.pl.un_220 ro.en.et_433
  0x2900090c, 0x04000304, 0x283f0307, 0x11530cee,   // pl.sl.un_530 nl.fi.un_320  nl.af.sw_432 sv.ht.ro_422
  0x1b5531ee, 0x0b2706a4, 0x0a6b2a0b, 0x11002a12,   // az.rw.tr_422 de.gd.es_433  mt.ceb.pt_542 mt.ro.un_640
  // [5340]
  0x2d0d6e55, 0x1012040e, 0x11000a11, 0x121004a6,   // blu.cs.sk_442 fi.hu.lt_555  pt.ro.un_630 fi.lt.hu_521
  0x12002004, 0x03233f60, 0x123f04ee, 0x08171611,   // sq.hu.un_320 af.ca.nl_664  fi.af.hu_422 hr.sr.no_653
  0x130e1704, 0x110864a0, 0x07002b0c, 0x1617100d,   // sr.is.et_332 lg.no.ro_322  vi.it.un_530 lt.sr.hr_554
  0x0a080409, 0x12256404, 0x311f1907, 0x0d000504,   // ru.uk.mk_444 lg.eu.hu_332  gl.cy.az_432 fr.cs.un_320
  // [5350]
  0x1f010cee, 0x642523a4, 0x3f0c64ec, 0x07040aac,   // sv.en.cy_422 ca.eu.lg_433  lg.sv.af_644 mk.ru.bg_632
  0x0802640c, 0x55641905, 0x0c006412, 0x3f011fee,   // lg.da.no_543 gl.lg.rw_333  lg.sv.un_640 cy.en.af_422
  0x29080ea4, 0x5301050c, 0x251f1907, 0x100453ec,   // is.no.sl_433 fr.en.ht_543  gl.cy.eu_432 ht.fi.lt_644
  0x552021ec, 0x16001718, 0x27000c04, 0x1b09640b,   // jw.sq.rw_644 sr.hr.un_740  sv.gd.un_320 lg.pl.tr_542
  // [5360]
  0x252813ad, 0x250b5505, 0x011f0ea0, 0x3f0c25a4,   // et.sw.eu_643 rw.es.eu_333  is.cy.en_322 eu.sv.af_433
  0x092811ee, 0x2a1320a9, 0x01080204, 0x1b000f0e,   // ro.sw.pl_422 sq.et.mt_544  da.no.en_332 lv.tr.un_550
  0x25002a1b, 0x31102aa4, 0x081a6bac, 0x0e0c25ad,   // mt.eu.un_770 mt.lt.az_433  ceb.tl.no_632 eu.sv.is_643
  0x16172911, 0x13552804, 0x04080709, 0x25006b08,   // sl.sr.hr_653 sw.rw.et_332  bg.uk.ru_444 ceb.eu.un_430
  // [5370]
  0x09281702, 0x13272507, 0x21006b0c, 0x1b001605,   // sr.sw.pl_222 eu.gd.et_432  ceb.jw.un_530 hr.tr.un_330
  0x0225010b, 0x1700090e, 0x25003f07, 0x130f040c,   // en.eu.da_542 pl.sr.un_550  af.eu.un_420 fi.lv.et_543
  0x0a002521, 0x180a230b, 0x25095313, 0x0c206ba0,   // eu.pt.un_860 ca.pt.ga_542  ht.pl.eu_665 ceb.sq.sv_322
  0x0f100e05, 0x1c091f07, 0x1e1a1c0c, 0x12042508,   // is.lt.lv_333 cy.pl.id_432  id.tl.ms_543 eu.fi.hu_443
  // [5380]
  0x0c1c2107, 0x16530505, 0x0813290d, 0x130453a4,   // jw.id.sv_432 fr.ht.hr_333  sl.et.no_554 ht.fi.et_433
  0x12001312, 0x201811a0, 0x13080405, 0x281711ec,   // et.hu.un_640 ro.ga.sq_322  fi.no.et_333 ro.sr.sw_644
  0x2a001114, 0x12312002, 0x182527ec, 0x181a6bee,   // ro.mt.un_660 sq.az.hu_222  gd.eu.ga_644 ceb.tl.ga_422
  0x04170709, 0x060b01a0, 0x1117160b, 0x053f0e04,   // bg.sr.ru_444 en.es.de_322  hr.sr.ro_542 is.af.fr_332
  // [5390]
  0x1a1b5308, 0x211a1e0b, 0x021f0904, 0x06002d05,   // ht.tr.tl_443 ms.tl.jw_542  pl.cy.da_332 sk.de.un_330
  0x3f00020e, 0x20000c05, 0x071017ee, 0x04530507,   // da.af.un_550 sv.sq.un_330  sr.be.bg_422 fr.ht.fi_432
  0x1b001307, 0x05530d0c, 0x19000704, 0x102d090c,   // et.tr.un_420 cs.ht.fr_543  it.gl.un_320 pl.sk.lt_543
  0x100a17af, 0x1b556408, 0x25096407, 0x29002308,   // sr.mk.be_655 lg.rw.tr_443  lg.pl.eu_432 ca.sl.un_430
  // [53a0]
  0x21556407, 0x551b64a0, 0x3f080202, 0x10080205,   // lg.rw.jw_432 lg.tr.rw_322  da.no.af_222 da.no.lt_333
  0x64531bec, 0x21006409, 0x1b5564ad, 0x091f0204,   // tr.ht.lg_644 lg.jw.un_440  lg.rw.tr_643 da.cy.pl_332
  0x1a052307, 0x64005319, 0x091a5312, 0x5564535a,   // ca.fr.tl_432 ht.lg.un_750  ht.tl.pl_654 ht.lg.rw_553
  0x05642308, 0x53556407, 0x102916a0, 0x060e2712,   // ca.lg.fr_443 lg.rw.ht_432  hr.sl.lt_322 gd.is.de_654
  // [53b0]
  0x551b64af, 0x12002d0d, 0x0804110b, 0x232b0507,   // lg.tr.rw_655 sk.hu.un_540  ro.ru.uk_542 fr.vi.ca_432
  0x0b1b53a7, 0x1b5301a4, 0x21005513, 0x08070412,   // ht.tr.es_532 en.ht.tr_433  rw.jw.un_650 ru.bg.uk_654
  0x08031304, 0x0b0a230c, 0x315553ee, 0x0c550605,   // et.nl.no_332 ca.pt.es_543  ht.rw.az_422 de.rw.sv_333
  0x531b6412, 0x120c0802, 0x2800210d, 0x535564a9,   // lg.tr.ht_654 no.sv.hu_222  jw.sw.un_540 lg.rw.ht_544
  // [53c0]
  0x083113a0, 0x0a002b08, 0x080e1204, 0x2d002914,   // et.az.no_322 vi.pt.un_430  hu.is.no_332 sl.sk.un_660
  0x2100182b, 0x0a002b04, 0x0b002320, 0x01091fad,   // ar.fa.un_980 vi.pt.un_320  ca.es.un_850 cy.pl.en_643
  0x1b31080b, 0x08100208, 0x100802ec, 0x0d000304,   // no.az.tr_542 da.lt.no_443  da.no.lt_644 nl.cs.un_320
  0x0f002d19, 0x0d282dad, 0x3f020811, 0x0c060e07,   // sk.lv.un_750 sk.sw.cs_643  no.da.af_653 is.de.sv_432
  // [53d0]
  0x2103080c, 0x0a002b0b, 0x2b000a07, 0x10005304,   // no.nl.jw_543 vi.pt.un_520  pt.vi.un_420 ht.lt.un_320
  0x10000204, 0x11000421, 0x53001002, 0x060e0c13,   // da.lt.un_320 ru.ro.un_860  lt.ht.un_220 sv.is.de_665
  0x201c55a6, 0x171e310c, 0x0b1107a0, 0x21005313,   // rw.id.sq_521 az.ms.sr_543  it.ro.es_322 ht.jw.un_650
  0x0700231e, 0x09190b04, 0x1f2316a0, 0x0805190c,   // ca.it.un_830 es.gl.pl_332  hr.ca.cy_322 gl.fr.no_543
  // [53e0]
  0x022b0107, 0x2155640c, 0x1e000308, 0x111708a4,   // en.vi.da_432 lg.rw.jw_543  nl.ms.un_430 uk.sr.ro_433
  0x252131a4, 0x023f0813, 0x6400130c, 0x0a171613,   // az.jw.eu_433 no.af.da_665  et.lg.un_530 hr.sr.pt_665
  0x64001f14, 0x211a2007, 0x09190a0c, 0x29000d0d,   // cy.lg.un_660 sq.tl.jw_432  pt.gl.pl_543 cs.sl.un_540
  0x02130ea4, 0x53002114, 0x0b160912, 0x06311ba7,   // is.et.da_433 jw.ht.un_660  pl.hr.es_654 tr.az.de_532
  // [53f0]
  0x200b0a02, 0x012d0d08, 0x02002809, 0x11002107,   // pt.es.sq_222 cs.sk.en_443  sw.da.un_440 jw.ro.un_420
  0x0b6b1005, 0x100923ee, 0x0708040d, 0x28001814,   // lt.ceb.es_333 ca.pl.lt_422  ru.uk.bg_554 ga.sw.un_660
  0x1b003f0d, 0x230b3107, 0x276401ac, 0x2a1101a0,   // af.tr.un_540 az.es.ca_432  en.lg.gd_632 en.ro.mt_322
  0x17160911, 0x0700060c, 0x6b0901ee, 0x0c170112,   // pl.hr.sr_653 de.it.un_530  en.pl.ceb_422 en.sr.sv_654

  // [5400]
  0x0f202908, 0x6e6b01ad, 0x0400270d, 0x07100402,   // sl.sq.lv_443 en.ceb.blu_643  gd.fi.un_540 ru.be.bg_222
  0x0c0802ac, 0x2b00040c, 0x200b11a0, 0x02172902,   // da.no.sv_632 fi.vi.un_530  ro.es.sq_322 sl.sr.da_222
  0x0a001b09, 0x31011b0c, 0x052b01a0, 0x2b171607,   // tr.pt.un_440 tr.en.az_543  en.vi.fr_322 hr.sr.vi_432
  0x1900210d, 0x1b001e13, 0x31191ba4, 0x53000207,   // jw.gl.un_540 ms.tr.un_650  tr.gl.az_433 da.ht.un_420
  // [5410]
  0x2a000807, 0x04122955, 0x02232a0c, 0x2d291104,   // no.mt.un_420 sl.hu.fi_442  mt.ca.da_543 ro.sl.sk_332
  0x0100280d, 0x072d010c, 0x171304a9, 0x281a01ee,   // sw.en.un_540 en.sk.it_543  fi.et.sr_544 en.tl.sw_422
  0x01276ba0, 0x0f002011, 0x53642808, 0x04001805,   // ceb.gd.en_322 sq.lv.un_630  sw.lg.ht_443 ga.fi.un_330
  0x04002002, 0x2a0c3f07, 0x161064ec, 0x03023f04,   // sq.fi.un_220 af.sv.mt_432  lg.lt.hr_644 af.da.nl_332
  // [5420]
  0x07000b0d, 0x02530702, 0x1e1c0414, 0x0900120c,   // es.it.un_540 it.ht.da_222  fi.id.ms_666 hu.pl.un_530
  0x07000604, 0x08000a08, 0x0d001c2a, 0x2d000802,   // de.it.un_320 mk.uk.un_430  mr.ne.un_970 no.sk.un_220
  0x00002037, 0x17092912, 0x2a003104, 0x2d000314,   // sq.un.un_B00 sl.pl.sr_654  az.mt.un_320 nl.sk.un_660
  0x09001e04, 0x0c3f0304, 0x29072107, 0x03110fee,   // ms.pl.un_320 nl.af.sv_332  jw.it.sl_432 lv.ro.nl_422
  // [5430]
  0x1a210707, 0x0400082b, 0x17100a0c, 0x3f000805,   // it.jw.tl_432 uk.ru.un_980  mk.be.sr_543 no.af.un_330
  0x0b6b08a0, 0x1200550c, 0x0d091c05, 0x311c6402,   // no.ceb.es_322 rw.hu.un_530  mr.hi.ne_333 lg.id.az_222
  0x05002b04, 0x0e001b0d, 0x180520a7, 0x062a0713,   // vi.fr.un_320 tr.is.un_540  sq.fr.ga_532 it.mt.de_665
  0x04001209, 0x3f31080c, 0x08020c08, 0x171612a4,   // hu.fi.un_440 no.az.af_543  sv.da.no_443 hu.hr.sr_433
  // [5440]
  0x11040711, 0x0d1e1c0c, 0x25290f11, 0x1c001e1a,   // bg.ru.ro_653 id.ms.cs_543  lv.sl.eu_653 ms.id.un_760
  0x00002042, 0x04100a0c, 0x170a10ad, 0x10080255,   // sq.un.un_C00 mk.be.ru_543  be.mk.sr_643 da.no.lt_442
  0x53110507, 0x100701a0, 0x063f0111, 0x115521a0,   // fr.ro.ht_432 en.it.lt_322  en.af.de_653 jw.rw.ro_322
  0x0d2004af, 0x04001e1a, 0x202d0daf, 0x09000d29,   // fi.sq.cs_655 ms.fi.un_760  cs.sk.sq_655 ne.hi.un_960
  // [5450]
  0x071716ad, 0x040807a4, 0x205307ad, 0x2d2a0d04,   // hr.sr.it_643 bg.uk.ru_433  it.ht.sq_643 cs.mt.sk_332
  0x17000708, 0x10000a07, 0x1f0c0ea4, 0x1a2d0d04,   // bg.sr.un_430 mk.be.un_420  is.sv.cy_433 cs.sk.tl_332
  0x07081055, 0x2d002304, 0x531711ad, 0x2d001107,   // be.uk.bg_442 ca.sk.un_320  ro.sr.ht_643 ro.sk.un_420
  0x2d001e05, 0x0f2917a0, 0x2d29170e, 0x20000e13,   // ms.sk.un_330 sr.sl.lv_322  sr.sl.sk_555 is.sq.un_650
  // [5460]
  0x31000514, 0x01000d02, 0x0f1025ad, 0x1c2d0d08,   // fr.az.un_660 cs.en.un_220  eu.lt.lv_643 cs.sk.id_443
  0x020c0f08, 0x1c5321a7, 0x0c021307, 0x0a081712,   // lv.sv.da_443 jw.ht.id_532  et.da.sv_432 sr.uk.mk_654
  0x25230707, 0x2300050e, 0x101b1208, 0x070627a0,   // it.ca.eu_432 fr.ca.un_550  hu.tr.lt_443 gd.de.it_322
  0x64551b09, 0x20210802, 0x180a2708, 0x03182708,   // tr.rw.lg_444 no.jw.sq_222  gd.pt.ga_443 gd.ga.nl_443
  // [5470]
  0x21062ba4, 0x072503ee, 0x64001f1a, 0x0f13040c,   // vi.de.jw_433 nl.eu.it_422  cy.lg.un_760 fi.et.lv_543
  0x1a080c04, 0x64000402, 0x060f0207, 0x110755a4,   // sv.no.tl_332 fi.lg.un_220  da.lv.de_432 rw.it.ro_433
  0x232d05ee, 0x05002323, 0x081711a0, 0x0d002b02,   // fr.sk.ca_422 ca.fr.un_880  ro.sr.uk_322 vi.cs.un_220
  0x552305a7, 0x0a000719, 0x18006e0e, 0x25001b1b,   // fr.ca.rw_532 bg.mk.un_750  blu.ga.un_550 tr.eu.un_770
  // [5480]
  0x272b1807, 0x19005507, 0x0b000907, 0x09006b04,   // ga.vi.gd_432 rw.gl.un_420  pl.es.un_420 ceb.pl.un_320
  0x16001f07, 0x2a000912, 0x100407a4, 0x090f1fa0,   // cy.hr.un_420 pl.mt.un_640  bg.ru.be_433 cy.lv.pl_322
  0x1f0925af, 0x2b1f27a7, 0x1f00180d, 0x08062105,   // eu.pl.cy_655 gd.cy.vi_532  ga.cy.un_540 jw.de.no_333
  0x1c552104, 0x25190b07, 0x281304a0, 0x28000911,   // jw.rw.id_332 es.gl.eu_432  fi.et.sw_322 pl.sw.un_630
  // [5490]
  0x0c0e08af, 0x20020807, 0x21291007, 0x0c001b0c,   // no.is.sv_655 no.da.sq_432  lt.sl.jw_432 tr.sv.un_530
  0x0f6b01a0, 0x066b1ba4, 0x25001b0d, 0x0600040e,   // en.ceb.lv_322 tr.ceb.de_433  tr.eu.un_540 fi.de.un_550
  0x1b251e0b, 0x21122512, 0x016b1fa7, 0x640328a7,   // ms.eu.tr_542 eu.hu.jw_654  cy.ceb.en_532 sw.nl.lg_532
  0x2025210d, 0x1e1c16a9, 0x2a001904, 0x28001909,   // jw.eu.sq_554 hr.id.ms_544  gl.mt.un_320 gl.sw.un_440
  // [54a0]
  0x01002502, 0x02132d0b, 0x25001b07, 0x21251c07,   // eu.en.un_220 sk.et.da_542  tr.eu.un_420 id.eu.jw_432
  0x0d281602, 0x28130407, 0x21001b2a, 0x21080907,   // hr.sw.cs_222 fi.et.sw_432  tr.jw.un_970 pl.no.jw_432
  0x11250607, 0x08001e04, 0x0900040e, 0x08001f07,   // de.eu.ro_432 ms.no.un_320  fi.pl.un_550 cy.no.un_420
  0x0a0428a7, 0x09000412, 0x25001e08, 0x29160d0c,   // sw.fi.pt_532 fi.pl.un_640  ms.eu.un_430 cs.hr.sl_543
  // [54b0]
  0x0c001b07, 0x1c1e1a0c, 0x080c0205, 0x1e251ca9,   // tr.sv.un_420 tl.ms.id_543  da.sv.no_333 id.eu.ms_544
  0x28000c0e, 0x20001707, 0x251b1ea9, 0x09000c0d,   // sv.sw.un_550 sr.sq.un_420  ms.tr.eu_544 sv.pl.un_540
  0x0a001707, 0x09292da4, 0x1b000c1a, 0x022a0755,   // sr.mk.un_420 sk.sl.pl_433  sv.tr.un_760 it.mt.da_442
  0x190a1109, 0x0e07100d, 0x06090460, 0x312a0c07,   // ro.pt.gl_444 lt.it.is_554  fi.pl.de_664 sv.mt.az_432
  // [54c0]
  0x28100612, 0x530421ee, 0x25000608, 0x07101755,   // de.lt.sw_654 jw.fi.ht_422  de.eu.un_430 sr.be.bg_442
  0x16001209, 0x13001f04, 0x08101b08, 0x176e2aa9,   // hu.hr.un_440 cy.et.un_320  tr.lt.no_443 mt.blu.sr_544
  0x10211ca9, 0x081b2108, 0x1b1620af, 0x0a23190c,   // id.jw.lt_544 jw.tr.no_443  sq.hr.tr_655 gl.ca.pt_543
  0x3f1021a4, 0x08000734, 0x2a081102, 0x11190b08,   // jw.lt.af_433 bg.uk.un_A80  ro.no.mt_222 es.gl.ro_443
  // [54d0]
  0x04170a09, 0x3f020e55, 0x1e211c11, 0x040711a7,   // mk.sr.ru_444 is.da.af_442  id.jw.ms_653 ro.bg.ru_532
  0x0a041705, 0x1b250912, 0x17001105, 0x13041b04,   // sr.ru.mk_333 pl.eu.tr_654  ro.sr.un_330 tr.fi.et_332
  0x3f006419, 0x2d000d2a, 0x20001b1b, 0x0e0c080b,   // lg.af.un_750 cs.sk.un_970  tr.sq.un_770 no.sv.is_542
  0x642a01a0, 0x0406130d, 0x0c08010b, 0x1e211c55,   // en.mt.lg_322 et.de.fi_554  en.no.sv_542 id.jw.ms_442
  // [54e0]
  0x0c252aee, 0x0a080408, 0x1b3f06ec, 0x1a1b6b09,   // mt.eu.sv_422 ru.uk.mk_443  de.af.tr_644 ceb.tr.tl_444
  0x01000c08, 0x020413ad, 0x2a00010d, 0x08021ba7,   // sv.en.un_430 et.fi.da_643  en.mt.un_540 tr.da.no_532
  0x042a2305, 0x2800031a, 0x10000802, 0x03080605,   // ca.mt.fi_333 nl.sw.un_760  uk.be.un_220 de.no.nl_333
  0x280c0411, 0x0300021b, 0x09131c0d, 0x0e2d1fee,   // fi.sv.sw_653 da.nl.un_770  mr.bh.hi_554 cy.sk.is_422
  // [54f0]
  0x0c0407a4, 0x3f0603a4, 0x2b002102, 0x2a0c0812,   // it.fi.sv_433 nl.de.af_433  jw.vi.un_220 no.sv.mt_654
  0x11001205, 0x04033fad, 0x200f17a0, 0x13003f07,   // hu.ro.un_330 af.nl.fi_643  sr.lv.sq_322 af.et.un_420
  0x211f1102, 0x29000205, 0x080a040e, 0x1300091e,   // ro.cy.jw_222 da.sl.un_330  ru.mk.uk_555 pl.et.un_830
  0x08000a19, 0x1c002a04, 0x1c0d13ec, 0x1f3f02af,   // mk.uk.un_750 mt.id.un_320  bh.ne.mr_644 da.af.cy_655
  // [5500]
  0x232a0aaf, 0x3f081e05, 0x532b31ee, 0x1f2d0d11,   // pt.mt.ca_655 ms.no.af_333  az.vi.ht_422 cs.sk.cy_653
  0x3f06030c, 0x053f030d, 0x6b281aee, 0x2800212a,   // nl.de.af_543 nl.af.fr_554  tl.sw.ceb_422 jw.sw.un_970
  0x1608170b, 0x211a1e12, 0x093f0ca7, 0x0b230aac,   // sr.no.hr_542 ms.tl.jw_654  sv.af.pl_532 pt.ca.es_632
  0x1711100d, 0x1f000119, 0x20001009, 0x070a2308,   // be.ro.sr_554 en.cy.un_750  lt.sq.un_440 ca.pt.it_443
  // [5510]
  0x200929ee, 0x0d2d2913, 0x1a001104, 0x13002912,   // sl.pl.sq_422 sl.sk.cs_665  ro.tl.un_320 sl.et.un_640
  0x04170813, 0x13201704, 0x1629200c, 0x091629a4,   // uk.sr.ru_665 sr.sq.et_332  sq.sl.hr_543 sl.hr.pl_433
  0x050601a7, 0x29001313, 0x12000618, 0x076b18a0,   // en.de.fr_532 et.sl.un_650  de.hu.un_740 ga.ceb.it_322
  0x0f105313, 0x11171655, 0x18171608, 0x1700111a,   // ht.lt.lv_665 hr.sr.ro_442  hr.sr.ga_443 ro.sr.un_760
  // [5520]
  0x171609af, 0x0d092d07, 0x17091608, 0x101b3104,   // pl.hr.sr_655 sk.pl.cs_432  hr.pl.sr_443 az.tr.lt_332
  0x16092904, 0x0e550907, 0x17181655, 0x09001f05,   // sl.pl.hr_332 pl.rw.is_432  hr.ga.sr_442 cy.pl.un_330
  0x2a290605, 0x020108a4, 0x16291307, 0x17002909,   // de.sl.mt_333 no.en.da_433  et.sl.hr_432 sl.sr.un_440
  0x31002308, 0x01006b14, 0x28311baf, 0x09003107,   // ca.az.un_430 ceb.en.un_660  tr.az.sw_655 az.pl.un_420
  // [5530]
  0x16005307, 0x53126b02, 0x121310ee, 0x04101112,   // ht.hr.un_420 ceb.hu.ht_222  lt.et.hu_422 ro.be.ru_654
  0x13251107, 0x0a6b01a0, 0x0a0b53ad, 0x281a550c,   // ro.eu.et_432 en.ceb.pt_322  ht.es.pt_643 rw.tl.sw_543
  0x181b27ee, 0x1c112107, 0x3f0313ad, 0x13005304,   // gd.tr.ga_422 jw.ro.id_432  et.nl.af_643 ht.et.un_320
  0x1911180b, 0x03643f13, 0x281a6ba4, 0x19033f07,   // ga.ro.gl_542 af.lg.nl_665  ceb.tl.sw_433 af.nl.gl_432
  // [5540]
  0x093f1302, 0x0f186407, 0x211a55a4, 0x55006b09,   // et.af.pl_222 lg.ga.lv_432  rw.tl.jw_433 ceb.rw.un_440
  0x071704a9, 0x052a1102, 0x03001c04, 0x070c1104,   // ru.sr.bg_544 ro.mt.fr_222  id.nl.un_320 ro.sv.it_332
  0x19130b0d, 0x06001205, 0x55211a60, 0x27000b04,   // es.et.gl_554 hu.de.un_330  tl.jw.rw_664 es.gd.un_320
  0x081007a7, 0x021c23a0, 0x133f6405, 0x1a1613a0,   // bg.be.uk_532 ca.id.da_322  lg.af.et_333 et.hr.tl_322
  // [5550]
  0x133f6402, 0x17110aa9, 0x02000c1a, 0x0c2502a7,   // lg.af.et_222 mk.ro.sr_544  sv.da.un_760 da.eu.sv_532
  0x0a0511a7, 0x0302250c, 0x3f002102, 0x53103f04,   // ro.fr.pt_532 eu.da.nl_543  jw.af.un_220 af.lt.ht_332
  0x0e000308, 0x1e1c28a9, 0x641716ac, 0x08020c07,   // nl.is.un_430 sw.id.ms_544  hr.sr.lg_632 sv.da.no_432
  0x0f001108, 0x0b000302, 0x0c012aa0, 0x16000905,   // ro.lv.un_430 nl.es.un_220  mt.en.sv_322 pl.hr.un_330
  // [5560]
  0x1a250b07, 0x112a2504, 0x04070809, 0x0f000c0c,   // es.eu.tl_432 eu.mt.ro_332  uk.bg.ru_444 sv.lv.un_530
  0x211b1704, 0x0b002507, 0x09006e08, 0x080e0704,   // sr.tr.jw_332 eu.es.un_420  blu.pl.un_430 it.is.no_332
  0x0a04070d, 0x290728a4, 0x1c210f07, 0x01072a0b,   // bg.ru.mk_554 sw.it.sl_433  lv.jw.id_432 mt.it.en_542
  0x6e5305af, 0x19000a11, 0x64001c09, 0x1a0831ee,   // fr.ht.blu_655 pt.gl.un_630  id.lg.un_440 az.no.tl_422
  // [5570]
  0x100308a0, 0x19100fa0, 0x31136408, 0x19070bad,   // no.nl.lt_322 lv.lt.gl_322  lg.et.az_443 es.it.gl_643
  0x1f100aee, 0x311827a4, 0x19550a07, 0x31000604,   // pt.lt.cy_422 gd.ga.az_433  pt.rw.gl_432 de.az.un_320
  0x0e3f0ca0, 0x2a072305, 0x6b1a2907, 0x3f0302ec,   // sv.af.is_322 ca.it.mt_333  sl.tl.ceb_432 da.nl.af_644
  0x1e1c13af, 0x030e0707, 0x056b07a0, 0x0c000707,   // et.id.ms_655 it.is.nl_432  it.ceb.fr_322 it.sv.un_420
  // [5580]
  0x08000611, 0x1f00080e, 0x1709160c, 0x0a080412,   // de.no.un_630 no.cy.un_550  hr.pl.sr_543 ru.uk.mk_654
  0x05002907, 0x08021f12, 0x01000405, 0x066b07ee,   // sl.fr.un_420 cy.da.no_654  fi.en.un_330 it.ceb.de_422
  0x0f002820, 0x64006b08, 0x0f100a04, 0x1b1f09a0,   // sw.lv.un_850 ceb.lg.un_430  pt.lt.lv_332 pl.cy.tr_322
  0x16212908, 0x21006b12, 0x04070a11, 0x08312b0c,   // sl.jw.hr_443 ceb.jw.un_640  mk.bg.ru_653 vi.az.no_543
  // [5590]
  0x04106407, 0x311318a4, 0x213f035a, 0x1f001b19,   // lg.lt.fi_432 ga.et.az_433  nl.af.jw_553 tr.cy.un_750
  0x060108a0, 0x1f2701a7, 0x3f1b1307, 0x02033fa4,   // no.en.de_322 en.gd.cy_532  et.tr.af_432 af.nl.da_433
  0x6b0c04a0, 0x04062507, 0x0f006405, 0x0c001b13,   // fi.sv.ceb_322 eu.de.fi_432  lg.lv.un_330 tr.sv.un_650
  0x09102daf, 0x0f033f0e, 0x02040855, 0x2d000920,   // sk.lt.pl_655 af.nl.lv_555  no.fi.da_442 pl.sk.un_850
  // [55a0]
  0x171628a4, 0x17070414, 0x640f1005, 0x1000641a,   // sw.hr.sr_433 ru.bg.sr_666  lt.lv.lg_333 lg.lt.un_760
  0x3f000634, 0x6b121a07, 0x08023fee, 0x190a0ba6,   // de.af.un_A80 tl.hu.ceb_432  af.da.no_422 es.pt.gl_521
  0x17121604, 0x6b0610a0, 0x070e0a04, 0x64311ba6,   // hr.hu.sr_332 lt.de.ceb_322  pt.is.it_332 tr.az.lg_521
  0x120f10ee, 0x21001a05, 0x2d290dad, 0x0c1f53a0,   // lt.lv.hu_422 tl.jw.un_330  cs.sl.sk_643 ht.cy.sv_322
  // [55b0]
  0x060b0708, 0x110f2d12, 0x0f042d0c, 0x062a0914,   // it.es.de_443 sk.lv.ro_654  sk.fi.lv_543 pl.mt.de_666
  0x10000f2b, 0x01033f12, 0x193f0ba4, 0x2d040da0,   // lv.lt.un_980 af.nl.en_654  es.af.gl_433 cs.fi.sk_322
  0x3f00080d, 0x130804a7, 0x311a1ba9, 0x05075308,   // no.af.un_540 fi.no.et_532  tr.tl.az_544 ht.it.fr_443
  0x17161ca0, 0x09190b08, 0x2a292da0, 0x1100100d,   // id.hr.sr_322 es.gl.pl_443  sk.sl.mt_322 be.ro.un_540
  // [55c0]
  0x0e12180b, 0x19111013, 0x130904ad, 0x53053fee,   // ga.hu.is_542 lt.ro.gl_665  fi.pl.et_643 af.fr.ht_422
  0x2b200c55, 0x170811a0, 0x3f001207, 0x091c1313,   // sv.sq.vi_442 ro.uk.sr_322  hu.af.un_420 bh.mr.hi_665
  0x0f000604, 0x02000704, 0x0a0410ee, 0x20170aa4,   // de.lv.un_320 it.da.un_320  be.ru.mk_422 pt.sr.sq_433
  0x170316ee, 0x0b001012, 0x11100a12, 0x110b0107,   // hr.nl.sr_422 lt.es.un_640  mk.be.ro_654 en.es.ro_432
  // [55d0]
  0x2012045a, 0x17110da0, 0x0f001c04, 0x01006b09,   // fi.hu.sq_553 cs.ro.sr_322  id.lv.un_320 ceb.en.un_440
  0x21200455, 0x13190a07, 0x100f08a0, 0x03002108,   // fi.sq.jw_442 pt.gl.et_432  no.lv.lt_322 jw.nl.un_430
  0x10000f34, 0x01001912, 0x190a120c, 0x100f1c0c,   // lv.lt.un_A80 gl.en.un_640  hu.pt.gl_543 id.lv.lt_543
  0x1b0e31af, 0x11292da4, 0x1a0f1e0c, 0x10070aa4,   // az.is.tr_655 sk.sl.ro_433  ms.lv.tl_543 mk.bg.be_433
  // [55e0]
  0x21200e12, 0x0e1121a6, 0x040711a0, 0x0e041005,   // is.sq.jw_654 jw.ro.is_521  ro.bg.ru_322 lt.fi.is_333
  0x3f0603ee, 0x03000202, 0x31000e14, 0x0c0308ee,   // nl.de.af_422 da.nl.un_220  is.az.un_660 no.nl.sv_422
  0x09190b09, 0x0f006b02, 0x08020e04, 0x6b1a0ba4,   // es.gl.pl_444 ceb.lv.un_220  is.da.no_332 es.tl.ceb_433
  0x6407040b, 0x21066bec, 0x0f1c0e07, 0x040113ee,   // fi.it.lg_542 ceb.de.jw_644  is.id.lv_432 et.en.fi_422
  // [55f0]
  0x13006e07, 0x1c001f11, 0x122d18af, 0x093f29ee,   // blu.et.un_420 cy.id.un_630  ga.sk.hu_655 sl.af.pl_422
  0x08010607, 0x091c13a7, 0x310e1b13, 0x102903ee,   // de.en.no_432 bh.mr.hi_532  tr.is.az_665 nl.sl.lt_422
  0x071008a0, 0x201612a0, 0x28005502, 0x071710ad,   // uk.be.bg_322 hu.hr.sq_322  rw.sw.un_220 be.sr.bg_643
  0x1a6b55ad, 0x190608a0, 0x10170404, 0x191f23a9,   // rw.ceb.tl_643 no.de.gl_322  ru.sr.be_332 ca.cy.gl_544
  // [5600]
  0x1e6e2007, 0x2a0b0a05, 0x0b192555, 0x2d000704,   // sq.blu.ms_432 pt.es.mt_333  eu.gl.es_442 it.sk.un_320
  0x0a001711, 0x190a0bac, 0x2a070f07, 0x06000709,   // sr.mk.un_630 es.pt.gl_632  lv.it.mt_432 it.de.un_440
  0x07281008, 0x230b0a07, 0x28005313, 0x1f002105,   // lt.sw.it_443 pt.es.ca_432  ht.sw.un_650 jw.cy.un_330
  0x09001009, 0x290d2d0b, 0x0d000704, 0x09002d0c,   // lt.pl.un_440 sk.cs.sl_542  it.cs.un_320 sk.pl.un_530
  // [5610]
  0x100f0204, 0x31006e07, 0x1e1c07a4, 0x13006e0e,   // da.lv.lt_332 blu.az.un_420  it.id.ms_433 blu.et.un_550
  0x031f3fa4, 0x2d2307a0, 0x071310ad, 0x092d0705,   // af.cy.nl_433 it.ca.sk_322  lt.et.it_643 it.sk.pl_333
  0x3f1f035a, 0x281007ee, 0x12001a0e, 0x122d1907,   // nl.cy.af_553 it.lt.sw_422  tl.hu.un_550 gl.sk.hu_432
  0x200a07a9, 0x0e033fec, 0x231007a4, 0x2d280707,   // it.pt.sq_544 af.nl.is_644  it.lt.ca_433 it.sw.sk_432
  // [5620]
  0x1700290e, 0x1907100c, 0x082b10a7, 0x041810a4,   // sl.sr.un_550 lt.it.gl_543  lt.vi.no_532 lt.ga.fi_433
  0x07191004, 0x53006e08, 0x27050711, 0x040c1307,   // lt.gl.it_332 blu.ht.un_430  it.fr.gd_653 et.sv.fi_432
  0x3f001f13, 0x043f0312, 0x051c2104, 0x27052108,   // cy.af.un_650 nl.af.fi_654  jw.id.fr_332 jw.fr.gd_443
  0x1901250c, 0x070a1712, 0x29000f1a, 0x0a19070c,   // eu.en.gl_543 sr.mk.bg_654  lv.sl.un_760 it.gl.pt_543
  // [5630]
  0x23033fec, 0x23190707, 0x11002004, 0x060e1ea0,   // af.nl.ca_644 it.gl.ca_432  sq.ro.un_320 ms.is.de_322
  0x033f25a4, 0x1b1e1c04, 0x01040ca0, 0x03002512,   // eu.af.nl_433 id.ms.tr_332  sv.fi.en_322 eu.nl.un_640
  0x5300190c, 0x2b005319, 0x111b0107, 0x05042704,   // gl.ht.un_530 ht.vi.un_750  en.tr.ro_432 gd.fi.fr_332
  0x0c21080c, 0x1b002108, 0x08001114, 0x10001a02,   // no.jw.sv_543 jw.tr.un_430  ro.no.un_660 tl.lt.un_220
  // [5640]
  0x08001f08, 0x1c1f1008, 0x12210807, 0x17552808,   // cy.no.un_430 lt.cy.id_443  no.jw.hu_432 sw.rw.sr_443
  0x2004060c, 0x532a28ee, 0x096b0b02, 0x1e000a04,   // de.fi.sq_543 sw.mt.ht_422  es.ceb.pl_222 pt.ms.un_320
  0x1f000205, 0x040128a0, 0x136b55ec, 0x31001104,   // da.cy.un_330 sw.en.fi_322  rw.ceb.et_644 ro.az.un_320
  0x08210204, 0x041008a7, 0x11001b07, 0x64531a08,   // da.jw.no_332 uk.be.ru_532  tr.ro.un_420 tl.ht.lg_443
  // [5650]
  0x1a6b200d, 0x201e1c13, 0x31001119, 0x110b0704,   // sq.ceb.tl_554 id.ms.sq_665  ro.az.un_750 it.es.ro_332
  0x1710080c, 0x1a1301ee, 0x64000f02, 0x27171608,   // uk.be.sr_543 en.et.tl_422  lv.lg.un_220 hr.sr.gd_443
  0x6b1b1004, 0x2d1729a9, 0x0e106404, 0x12641a5a,   // lt.tr.ceb_332 sl.sr.sk_544  lg.lt.is_332 tl.lg.hu_553
  0x04002914, 0x07003104, 0x07050ba7, 0x042d0d04,   // sl.fi.un_660 az.it.un_320  es.fr.it_532 cs.sk.fi_332
  // [5660]
  0x212a1c02, 0x060f11ee, 0x281f5512, 0x1a0711a0,   // id.mt.jw_222 ro.lv.de_422  rw.cy.sw_654 ro.it.tl_322
  0x0d210404, 0x200c0a07, 0x060c31ee, 0x6e060205,   // fi.jw.cs_332 pt.sv.sq_432  az.sv.de_422 da.de.blu_333
  0x19250ba9, 0x1b0c01a0, 0x18060cec, 0x12105308,   // es.eu.gl_544 en.sv.tr_322  sv.de.ga_644 ht.lt.hu_443
  0x0a1127a0, 0x1b001102, 0x1b001112, 0x280e640c,   // gd.ro.pt_322 ro.tr.un_220  ro.tr.un_640 lg.is.sw_543
  // [5670]
  0x1a1f2807, 0x20002804, 0x11005505, 0x0f001018,   // sw.cy.tl_432 sw.sq.un_320  rw.ro.un_330 lt.lv.un_740
  0x0a081705, 0x64000e0e, 0x1a216bad, 0x016b0607,   // sr.uk.mk_333 is.lg.un_550  ceb.jw.tl_643 de.ceb.en_432
  0x23110909, 0x21060c02, 0x6b1f1804, 0x013f06a0,   // pl.ro.ca_444 sv.de.jw_222  ga.cy.ceb_332 de.af.en_322
  0x0f161004, 0x2100110e, 0x0b0a170c, 0x02060107,   // lt.hr.lv_332 ro.jw.un_550  sr.pt.es_543 en.de.da_432
  // [5680]
  0x020e29a0, 0x060c2107, 0x6b1a3104, 0x55021104,   // sl.is.da_322 jw.sv.de_432  az.tl.ceb_332 ro.da.rw_332
  0x172d2aee, 0x17000b02, 0x641a6e55, 0x1e216e07,   // mt.sk.sr_422 es.sr.un_220  blu.tl.lg_442 blu.jw.ms_432
  0x04002507, 0x19100b12, 0x2a0c21a0, 0x20061f0c,   // eu.fi.un_420 es.lt.gl_654  jw.sv.mt_322 cy.de.sq_543
  0x31231ca4, 0x0f131702, 0x2d000204, 0x19041104,   // id.ca.az_433 sr.et.lv_222  da.sk.un_320 ro.fi.gl_332
  // [5690]
  0x126b1a0c, 0x281a04af, 0x17100409, 0x02001602,   // tl.ceb.hu_543 fi.tl.sw_655  ru.be.sr_444 hr.da.un_220
  0x256b1a08, 0x55046b04, 0x04081307, 0x6b04230c,   // tl.ceb.eu_443 ceb.fi.rw_332  et.no.fi_432 ca.fi.ceb_543
  0x1b1a25a4, 0x110410a4, 0x1a001313, 0x13255504,   // eu.tl.tr_433 be.ru.ro_433  et.tl.un_650 rw.eu.et_332
  0x28002014, 0x043f0eee, 0x6b2808a4, 0x28552508,   // sq.sw.un_660 is.af.fi_422  no.sw.ceb_433 eu.rw.sw_443
  // [56a0]
  0x0f006e08, 0x1e000c04, 0x23000107, 0x552531ec,   // blu.lv.un_430 sv.ms.un_320  en.ca.un_420 az.eu.rw_644
  0x28042da4, 0x0411250c, 0x1e1c28a4, 0x080e0fad,   // sk.fi.sw_433 eu.ro.fi_543  sw.id.ms_433 lv.is.no_643
  0x5504280c, 0x2804130e, 0x033f0507, 0x17201608,   // sw.fi.rw_543 et.fi.sw_555  fr.af.nl_432 hr.sq.sr_443
  0x533f05ad, 0x1a101ea4, 0x251a6b5a, 0x20001814,   // fr.af.ht_643 ms.lt.tl_433  ceb.tl.eu_553 ga.sq.un_660
  // [56b0]
  0x016b0507, 0x08040a02, 0x202855af, 0x281e1aa4,   // fr.ceb.en_432 mk.ru.uk_222  rw.sw.sq_655 tl.ms.sw_433
  0x065564a0, 0x5300250b, 0x120407ac, 0x030e02ee,   // lg.rw.de_322 eu.ht.un_520  it.fi.hu_632 da.is.nl_422
  0x1f122807, 0x533f0209, 0x120a2d08, 0x0211180d,   // sw.hu.cy_432 da.af.ht_444  sk.pt.hu_443 ga.ro.da_554
  0x0500030d, 0x20000807, 0x3f00050c, 0x0b000619,   // nl.fr.un_540 no.sq.un_420  fr.af.un_530 de.es.un_750
  // [56c0]
  0x640208a4, 0x1b3111ee, 0x6b0507a0, 0x6b010807,   // no.da.lg_433 ro.az.tr_422  it.fr.ceb_322 no.en.ceb_432
  0x1c033fa0, 0x10010fad, 0x081f1213, 0x532564a9,   // af.nl.id_322 lv.en.lt_643  hu.cy.no_665 lg.eu.ht_544
  0x03000105, 0x07020a04, 0x0b0805ee, 0x13002805,   // en.nl.un_330 pt.da.it_332  fr.no.es_422 sw.et.un_330
  0x3f0305ad, 0x53002308, 0x033f05a7, 0x1620290b,   // fr.nl.af_643 ca.ht.un_430  fr.af.nl_532 sl.sq.hr_542
  // [56d0]
  0x06030507, 0x2a001319, 0x0a0417a6, 0x531a6b02,   // fr.nl.de_432 et.mt.un_750  sr.ru.mk_521 ceb.tl.ht_222
  0x64002118, 0x120a2a07, 0x120e2daf, 0x53002809,   // jw.lg.un_740 mt.pt.hu_432  sk.is.hu_655 sw.ht.un_440
  0x25190b13, 0x310f1702, 0x2b001809, 0x2a061804,   // es.gl.eu_665 sr.lv.az_222  ga.vi.un_440 ga.de.mt_332
  0x2a3f07ad, 0x09003f08, 0x04000c09, 0x20002502,   // it.af.mt_643 af.pl.un_430  sv.fi.un_440 eu.sq.un_220
  // [56e0]
  0x64002a0d, 0x0e001813, 0x0a002a05, 0x18000e07,   // mt.lg.un_540 ga.is.un_650  mt.pt.un_330 is.ga.un_420
  0x0400060b, 0x12000a02, 0x04081714, 0x20002507,   // de.fi.un_520 pt.hu.un_220  sr.uk.ru_666 eu.sq.un_420
  0x081704af, 0x06003f05, 0x16000407, 0x530c03a7,   // ru.sr.uk_655 af.de.un_330  fi.hr.un_420 nl.sv.ht_532
  0x3f060302, 0x171603a0, 0x06000107, 0x211c1bee,   // nl.de.af_222 nl.hr.sr_322  en.de.un_420 tr.id.jw_422
  // [56f0]
  0x2300010d, 0x2d290d02, 0x25005505, 0x3f171614,   // en.ca.un_540 cs.sl.sk_222  rw.eu.un_330 hr.sr.af_666
  0x092004a0, 0x31002d08, 0x0a000407, 0x1a1355a0,   // fi.sq.pl_322 sk.az.un_430  ru.mk.un_420 rw.et.tl_322
  0x060c3fa4, 0x13000d23, 0x29000108, 0x23006405,   // af.sv.de_433 ne.bh.un_880  en.sl.un_430 lg.ca.un_330
  0x010c02ac, 0x1f0e0705, 0x0d2d120c, 0x072d0d07,   // da.sv.en_632 it.is.cy_333  hu.sk.cs_543 cs.sk.it_432
  // [5700]
  0x040a1004, 0x0f000b04, 0x2d000904, 0x0b211002,   // be.mk.ru_332 es.lv.un_320  pl.sk.un_320 lt.jw.es_222
  0x280218ee, 0x1e1c0aa4, 0x0b0a1005, 0x10076b08,   // ga.da.sw_422 pt.id.ms_433  lt.pt.es_333 ceb.it.lt_443
  0x101729a9, 0x040c0a0c, 0x061f08ad, 0x0b005521,   // sl.sr.lt_544 pt.sv.fi_543  no.cy.de_643 rw.es.un_860
  0x64531f02, 0x2d0d1205, 0x1f001002, 0x03083fa0,   // cy.ht.lg_222 hu.cs.sk_333  lt.cy.un_220 af.no.nl_322
  // [5710]
  0x2d00100c, 0x1c2a6404, 0x0e2a2804, 0x0309280c,   // lt.sk.un_530 lg.mt.id_332  sw.mt.is_332 sw.pl.nl_543
  0x042a080b, 0x1a1028a0, 0x042b0202, 0x17190b09,   // no.mt.fi_542 sw.lt.tl_322  da.vi.fi_222 es.gl.sr_444
  0x09130404, 0x072916a4, 0x2d0d290e, 0x19070ba0,   // fi.et.pl_332 hr.sl.it_433  sl.cs.sk_555 es.it.gl_322
  0x0f1716a7, 0x13200404, 0x11230508, 0x1b130413,   // hr.sr.lv_532 fi.sq.et_332  fr.ca.ro_443 fi.et.tr_665
  // [5720]
  0x070b0a08, 0x0b040708, 0x232d13a0, 0x2d190b04,   // pt.es.it_443 it.fi.es_443  et.sk.ca_322 es.gl.sk_332
  0x0f2d090c, 0x53130aa7, 0x1a311b0b, 0x5500131a,   // pl.sk.lv_543 pt.et.ht_532  tr.az.tl_542 et.rw.un_760
  0x040c1ea7, 0x0c55280c, 0x110a170c, 0x02112304,   // ms.sv.fi_532 sw.rw.sv_543  sr.mk.ro_543 ca.ro.da_332
  0x03002b04, 0x16000902, 0x18001909, 0x20212807,   // vi.nl.un_320 pl.hr.un_220  gl.ga.un_440 sw.jw.sq_432
  // [5730]
  0x08271802, 0x280f27ad, 0x20646bec, 0x16202a0c,   // ga.gd.no_222 gd.lv.sw_643  ceb.lg.sq_644 mt.sq.hr_543
  0x080209a7, 0x171e1c55, 0x3f080205, 0x0d3f0307,   // pl.da.no_532 id.ms.sr_442  da.no.af_333 nl.af.cs_432
  0x6b6413ac, 0x023f03a0, 0x08290f0c, 0x20103fec,   // et.lg.ceb_632 nl.af.da_322  lv.sl.no_543 af.lt.sq_644
  0x10002012, 0x2a211ea0, 0x2500131a, 0x2800210c,   // sq.lt.un_640 ms.jw.mt_322  et.eu.un_760 jw.sw.un_530
  // [5740]
  0x08000236, 0x13201014, 0x2b03060b, 0x0c55250c,   // da.no.un_AA0 lt.sq.et_666  de.nl.vi_542 eu.rw.sv_543
  0x10130407, 0x06000313, 0x132012ee, 0x211b1e04,   // fi.et.lt_432 nl.de.un_650  hu.sq.et_422 ms.tr.jw_332
  0x20311b0e, 0x27212007, 0x07100a0c, 0x0b001807,   // tr.az.sq_555 sq.jw.gd_432  mk.be.bg_543 ga.es.un_420
  0x03006b04, 0x0e00060d, 0x1f002b0e, 0x3f020cee,   // ceb.nl.un_320 de.is.un_540  vi.cy.un_550 sv.da.af_422
  // [5750]
  0x0c000e05, 0x08062308, 0x02005513, 0x1f002b19,   // is.sv.un_330 ca.de.no_443  rw.da.un_650 vi.cy.un_750
  0x6b1f12ac, 0x111a10a4, 0x0d001c07, 0x1f0412ee,   // hu.cy.ceb_632 lt.tl.ro_433  mr.ne.un_420 hu.fi.cy_422
  0x25041aaf, 0x08070aa7, 0x311012a9, 0x07000c02,   // tl.fi.eu_655 mk.bg.uk_532  hu.lt.az_544 sv.it.un_220
  0x100809ec, 0x08110cee, 0x2500101b, 0x19116ea4,   // pl.no.lt_644 sv.ro.no_422  lt.eu.un_770 blu.ro.gl_433
  // [5760]
  0x1f002b22, 0x1012110c, 0x10110805, 0x010d19a0,   // vi.cy.un_870 ro.hu.lt_543  uk.ro.be_333 gl.cs.en_322
  0x553112ee, 0x1011045a, 0x061a0308, 0x23120107,   // hu.az.rw_422 fi.ro.lt_553  nl.tl.de_443 en.hu.ca_432
  0x04311008, 0x1f1004a4, 0x101a0405, 0x0c1008a0,   // lt.az.fi_443 fi.lt.cy_433  fi.tl.lt_333 no.lt.sv_322
  0x12000d0b, 0x04080205, 0x0a071005, 0x290c0e04,   // cs.hu.un_520 da.no.fi_333  be.bg.mk_333 is.sv.sl_332
  // [5770]
  0x1f003104, 0x23001207, 0x6b2855a4, 0x130c060c,   // az.cy.un_320 hu.ca.un_420  rw.sw.ceb_433 de.sv.et_543
  0x03532107, 0x1720105a, 0x100b55a7, 0x0e00121a,   // jw.ht.nl_432 lt.sq.sr_553  rw.es.lt_532 hu.is.un_760
  0x100c3fa0, 0x120523ec, 0x07112107, 0x2d0d05ac,   // af.sv.lt_322 ca.fr.hu_644  jw.ro.it_432 fr.cs.sk_632
  0x03012304, 0x0e13640c, 0x64041304, 0x1c011eee,   // ca.en.nl_332 lg.et.is_543  et.fi.lg_332 ms.en.id_422
  // [5780]
  0x11310705, 0x3f0503a9, 0x050e1b0b, 0x53002b08,   // it.az.ro_333 nl.fr.af_544  tr.is.fr_542 vi.ht.un_430
  0x08016b02, 0x28001604, 0x55280e0e, 0x1a531f09,   // ceb.en.no_222 hr.sw.un_320  is.sw.rw_555 cy.ht.tl_444
  0x012b0605, 0x05080255, 0x17070aee, 0x0a0c01a0,   // de.vi.en_333 da.no.fr_442  mk.bg.sr_422 en.sv.pt_322
  0x20033fa0, 0x29003f07, 0x1f000504, 0x08001c08,   // af.nl.sq_322 af.sl.un_420  fr.cy.un_320 id.no.un_430
  // [5790]
  0x27002b04, 0x1e2d0d02, 0x2b000619, 0x0316170c,   // vi.gd.un_320 cs.sk.ms_222  de.vi.un_750 sr.hr.nl_543
  0x2b002707, 0x11170a13, 0x2b002708, 0x132104a7,   // gd.vi.un_420 mk.sr.ro_665  gd.vi.un_430 fi.jw.et_532
  0x033f5312, 0x28000204, 0x18002009, 0x12001c08,   // ht.af.nl_654 da.sw.un_320  sq.ga.un_440 id.hu.un_430
  0x231029a4, 0x29105508, 0x02010902, 0x17000405,   // sl.lt.ca_433 rw.lt.sl_443  pl.en.da_222 ru.sr.un_330
  // [57a0]
  0x062a2ba0, 0x55106408, 0x0e0c0805, 0x2d0d1fad,   // vi.mt.de_322 lg.lt.rw_443  no.sv.is_333 cy.cs.sk_643
  0x09000f07, 0x102928a4, 0x0d171004, 0x28002005,   // lv.pl.un_420 sw.sl.lt_433  lt.sr.cs_332 sq.sw.un_330
  0x0e0664a0, 0x55132002, 0x1900250e, 0x2d3f0305,   // lg.de.is_322 sq.et.rw_222  eu.gl.un_550 nl.af.sk_333
  0x080613a0, 0x0f1f060c, 0x1f0f0955, 0x080717a9,   // et.de.no_322 de.cy.lv_543  pl.lv.cy_442 sr.bg.uk_544
  // [57b0]
  0x06000319, 0x53001b12, 0x286b1a0b, 0x0a001605,   // nl.de.un_750 tr.ht.un_640  tl.ceb.sw_542 hr.pt.un_330
  0x53002805, 0x2a210104, 0x2a002307, 0x12531ea4,   // sw.ht.un_330 en.jw.mt_332  ca.mt.un_420 ms.ht.hu_433
  0x3f0419ee, 0x1055290c, 0x556428a9, 0x3f030fad,   // gl.fi.af_422 sl.rw.lt_543  sw.lg.rw_544 lv.nl.af_643
  0x64311b12, 0x28002d0d, 0x64001233, 0x05290707,   // tr.az.lg_654 sk.sw.un_540  hu.lg.un_A70 it.sl.fr_432
  // [57c0]
  0x071008a7, 0x080c3fa0, 0x1000091b, 0x53091bee,   // uk.be.bg_532 af.sv.no_322  pl.lt.un_770 tr.pl.ht_422
  0x205528ee, 0x0d061fa7, 0x0c060804, 0x1a2831ad,   // sw.rw.sq_422 cy.de.cs_532  no.de.sv_332 az.sw.tl_643
  0x1f000422, 0x12001f0d, 0x0f2d1f08, 0x2a005304,   // fi.cy.un_870 cy.hu.un_540  cy.sk.lv_443 ht.mt.un_320
  0x1a556b04, 0x0f190b08, 0x21050304, 0x08200707,   // ceb.rw.tl_332 es.gl.lv_443  nl.fr.jw_332 it.sq.no_432
  // [57d0]
  0x122a0d02, 0x310964a7, 0x1700111b, 0x3f00040e,   // cs.mt.hu_222 lg.pl.az_532  ro.sr.un_770 fi.af.un_550
  0x311b6455, 0x1f002b07, 0x0d00280d, 0x08020302,   // lg.tr.az_442 vi.cy.un_420  sw.cs.un_540 nl.da.no_222
  0x0c08025a, 0x081704ad, 0x53091007, 0x02121807,   // da.no.sv_553 ru.sr.uk_643  lt.pl.ht_432 ga.hu.da_432
  0x12005302, 0x6b101b04, 0x281310af, 0x293f0413,   // ht.hu.un_220 tr.lt.ceb_332  lt.et.sw_655 fi.af.sl_665
  // [57e0]
  0x3f28310c, 0x102d0d5a, 0x29530b07, 0x6b3f1ea0,   // az.sw.af_543 cs.sk.lt_553  es.ht.sl_432 ms.af.ceb_322
  0x10002805, 0x110503a0, 0x281316a0, 0x20001602,   // sw.lt.un_330 nl.fr.ro_322  hr.et.sw_322 hr.sq.un_220
  0x5300100d, 0x01033f07, 0x1b0853a0, 0x231812ec,   // lt.ht.un_540 af.nl.en_432  ht.no.tr_322 hu.ga.ca_644
  0x53060307, 0x13645508, 0x06190305, 0x12000705,   // nl.de.ht_432 rw.lg.et_443  nl.gl.de_333 it.hu.un_330
  // [57f0]
  0x0a2d0dec, 0x2d5531a7, 0x28643155, 0x131901a0,   // cs.sk.pt_644 az.rw.sk_532  az.lg.sw_442 en.gl.et_322
  0x12002304, 0x0c3f130c, 0x03001705, 0x0a1704a9,   // ca.hu.un_320 et.af.sv_543  sr.nl.un_330 ru.sr.mk_544
  0x3f311ea4, 0x20171604, 0x64043fa4, 0x10160f04,   // ms.az.af_433 hr.sr.sq_332  af.fi.lg_433 lv.hr.lt_332
  0x1b001e04, 0x5508310c, 0x13000f04, 0x23001212,   // ms.tr.un_320 az.no.rw_543  lv.et.un_320 hu.ca.un_640

  // [5800]
  0x0e080c07, 0x12002308, 0x12001b0d, 0x130725ad,   // sv.no.is_432 ca.hu.un_430  tr.hu.un_540 eu.it.et_643
  0x01001c02, 0x2a002907, 0x07050b02, 0x16291202,   // id.en.un_220 sl.mt.un_420  es.fr.it_222 hu.sl.hr_222
  0x01070ba0, 0x16002105, 0x07190a05, 0x20101ca9,   // es.it.en_322 jw.hr.un_330  pt.gl.it_333 id.lt.sq_544
  0x12001f12, 0x01211fee, 0x11012bec, 0x2a170c07,   // cy.hu.un_640 cy.jw.en_422  vi.en.ro_644 sv.sr.mt_432
  // [5810]
  0x08551c07, 0x10111705, 0x0c002a08, 0x1e1c2909,   // id.rw.no_432 sr.ro.be_333  mt.sv.un_430 sl.id.ms_444
  0x291b55a6, 0x111b3112, 0x0f001f22, 0x282155a6,   // rw.tr.sl_521 az.tr.ro_654  cy.lv.un_870 rw.jw.sw_521
  0x2900170b, 0x1b002508, 0x5355115a, 0x1b006413,   // sr.sl.un_520 eu.tr.un_430  ro.rw.ht_553 lg.tr.un_650
  0x040c2807, 0x18002b02, 0x25001102, 0x0c00090b,   // sw.sv.fi_432 vi.ga.un_220  ro.eu.un_220 pl.sv.un_520
  // [5820]
  0x2b0c04a0, 0x1f1c1ea7, 0x2500550d, 0x3f0b0fee,   // fi.sv.vi_322 ms.id.cy_532  rw.eu.un_540 lv.es.af_422
  0x08000b11, 0x0c062107, 0x08023f0d, 0x11000e2a,   // es.no.un_630 jw.de.sv_432  af.da.no_554 is.ro.un_970
  0x075320a4, 0x1b1e0402, 0x1c211a5a, 0x100225ee,   // sq.ht.it_433 fi.ms.tr_222  tl.jw.id_553 eu.da.lt_422
  0x190b01ee, 0x020c03a4, 0x1a002102, 0x2b002a04,   // en.es.gl_422 nl.sv.da_433  jw.tl.un_220 mt.vi.un_320
  // [5830]
  0x17041060, 0x21000e0c, 0x0464530c, 0x20160ba4,   // be.ru.sr_664 is.jw.un_530  ht.lg.fi_543 es.hr.sq_433
  0x16201104, 0x0308170c, 0x19201f08, 0x0464130c,   // ro.sq.hr_332 sr.no.nl_543  cy.sq.gl_443 et.lg.fi_543
  0x1c000604, 0x0b0f19a4, 0x21000c02, 0x19001f04,   // de.id.un_320 gl.lv.es_433  sv.jw.un_220 cy.gl.un_320
  0x311655a0, 0x09002505, 0x203f0fa4, 0x0b006405,   // rw.hr.az_322 eu.pl.un_330  lv.af.sq_433 lg.es.un_330
  // [5840]
  0x25001913, 0x04191708, 0x172029ec, 0x0a181fad,   // gl.eu.un_650 sr.gl.fi_443  sl.sq.sr_644 cy.ga.pt_643
  0x64000913, 0x2009170c, 0x070417a9, 0x29160f5a,   // pl.lg.un_650 sr.pl.sq_543  sr.ru.bg_544 lv.hr.sl_553
  0x556b1a08, 0x12000c0e, 0x6b01200d, 0x170804af,   // tl.ceb.rw_443 sv.hu.un_550  sq.en.ceb_554 ru.uk.sr_655
  0x011f06a6, 0x0e00200b, 0x08000407, 0x030106a9,   // de.cy.en_521 sq.is.un_520  ru.uk.un_420 de.en.nl_544
  // [5850]
  0x28001f08, 0x1a2101ec, 0x232d0d60, 0x092d0dec,   // cy.sw.un_430 en.jw.tl_644  cs.sk.ca_664 cs.sk.pl_644
  0x080e0c13, 0x121809a7, 0x19000a04, 0x2d0d0414,   // sv.is.no_665 pl.ga.hu_532  pt.gl.un_320 fi.cs.sk_666
  0x0c0e1f12, 0x131f0f04, 0x20080205, 0x1b002509,   // cy.is.sv_654 lv.cy.et_332  da.no.sq_333 eu.tr.un_440
  0x230a1912, 0x081f1007, 0x1800090b, 0x11001b08,   // gl.pt.ca_654 lt.cy.no_432  pl.ga.un_520 tr.ro.un_430
  // [5860]
  0x0d001c0e, 0x0d292d12, 0x1200101a, 0x190a1fee,   // mr.ne.un_550 sk.sl.cs_654  lt.hu.un_760 cy.pt.gl_422
  0x2a1105a0, 0x6b001818, 0x070811ee, 0x08070aee,   // fr.ro.mt_322 ga.ceb.un_740  ro.uk.bg_422 mk.bg.uk_422
  0x2a002102, 0x2500040e, 0x17080dee, 0x20000c02,   // jw.mt.un_220 fi.eu.un_550  cs.no.sr_422 sv.sq.un_220
  0x07001f12, 0x11100705, 0x55001714, 0x0a0610a7,   // cy.it.un_640 bg.be.ro_333  sr.rw.un_660 lt.de.pt_532
  // [5870]
  0x531c1ea0, 0x55062108, 0x09280b02, 0x13060cad,   // ms.id.ht_322 jw.de.rw_443  es.sw.pl_222 sv.de.et_643
  0x53001904, 0x281e1c13, 0x032855a6, 0x0900281a,   // gl.ht.un_320 id.ms.sw_665  rw.sw.nl_521 sw.pl.un_760
  0x55002519, 0x645513a4, 0x0c06120b, 0x03000221,   // eu.rw.un_750 et.rw.lg_433  hu.de.sv_542 da.nl.un_860
  0x25042105, 0x1707100c, 0x25006419, 0x281e2a04,   // jw.fi.eu_333 be.bg.sr_543  lg.eu.un_750 mt.ms.sw_332
  // [5880]
  0x031f0208, 0x28006b0c, 0x0f252307, 0x64201ea0,   // da.cy.nl_443 ceb.sw.un_530  ca.eu.lv_432 ms.sq.lg_322
  0x3f250355, 0x060208ad, 0x530510a0, 0x3f20210c,   // nl.eu.af_442 no.da.de_643  lt.fr.ht_322 jw.sq.af_543
  0x03120607, 0x64002509, 0x1f285504, 0x12250fa4,   // de.hu.nl_432 eu.lg.un_440  rw.sw.cy_332 lv.eu.hu_433
  0x033f0212, 0x1c1221ee, 0x2164280c, 0x31536405,   // da.af.nl_654 jw.hu.id_422  sw.lg.jw_543 lg.ht.az_333
  // [5890]
  0x07211fee, 0x25000b02, 0x0c291bad, 0x6b001005,   // cy.jw.it_422 es.eu.un_220  tr.sl.sv_643 lt.ceb.un_330
  0x31211aa4, 0x200f0805, 0x28552a12, 0x132a2908,   // tl.jw.az_433 no.lv.sq_333  mt.rw.sw_654 sl.mt.et_443
  0x0a1021a0, 0x2100230d, 0x0d102dee, 0x16002023,   // jw.lt.pt_322 ca.jw.un_540  sk.lt.cs_422 sq.hr.un_880
  0x53645511, 0x190b1ca0, 0x202917a0, 0x2000160e,   // rw.lg.ht_653 id.es.gl_322  sr.sl.sq_322 hr.sq.un_550
  // [58a0]
  0x08281e07, 0x03062508, 0x06002534, 0x64216bee,   // ms.sw.no_432 eu.de.nl_443  eu.de.un_A80 ceb.jw.lg_422
  0x2817160e, 0x03023f12, 0x060317a0, 0x03000619,   // hr.sr.sw_555 af.da.nl_654  sr.nl.de_322 de.nl.un_750
  0x28535508, 0x10002522, 0x102d070c, 0x31645305,   // rw.ht.sw_443 eu.lt.un_870  it.sk.lt_543 ht.lg.az_333
  0x121b53ee, 0x28130412, 0x0e00180d, 0x20002305,   // ht.tr.hu_422 fi.et.sw_654  ga.is.un_540 ca.sq.un_330
  // [58b0]
  0x1c001a05, 0x230a19ec, 0x060309ee, 0x64000805,   // tl.id.un_330 gl.pt.ca_644  pl.nl.de_422 no.lg.un_330
  0x102d23a0, 0x10231111, 0x21001c0e, 0x3f1808a7,   // ca.sk.lt_322 ro.ca.lt_653  id.jw.un_550 no.ga.af_532
  0x08006419, 0x2b130704, 0x25001a21, 0x21000405,   // lg.no.un_750 it.et.vi_332  tl.eu.un_860 fi.jw.un_330
  0x170116a4, 0x2a002302, 0x3f000c08, 0x6455280d,   // hr.en.sr_433 ca.mt.un_220  sv.af.un_430 sw.rw.lg_554
  // [58c0]
  0x08100a08, 0x010203a0, 0x556b1a05, 0x191028a4,   // mk.be.uk_443 nl.da.en_322  tl.ceb.rw_333 sw.lt.gl_433
  0x2d002918, 0x1a280404, 0x64551ca4, 0x0d292d11,   // sl.sk.un_740 fi.sw.tl_332  id.rw.lg_433 sk.sl.cs_653
  0x10040907, 0x6400130d, 0x3f1f0c13, 0x0f000b22,   // pl.fi.lt_432 et.lg.un_540  sv.cy.af_665 es.lv.un_870
  0x13071807, 0x203f03a0, 0x1b001105, 0x080731a4,   // ga.it.et_432 nl.af.sq_322  ro.tr.un_330 az.it.no_433
  // [58d0]
  0x100b2707, 0x55002d04, 0x0b001e07, 0x18000704,   // gd.es.lt_432 sk.rw.un_320  ms.es.un_420 it.ga.un_320
  0x0b0a0705, 0x051b5312, 0x6b1a6405, 0x0e06250b,   // it.pt.es_333 ht.tr.fr_654  lg.tl.ceb_333 eu.de.is_542
  0x6b0b1a60, 0x29006e08, 0x3f002a05, 0x1e1c0da4,   // tl.es.ceb_664 blu.sl.un_430  mt.af.un_330 cs.id.ms_433
  0x251b07ad, 0x180755ad, 0x13001b0c, 0x08001804,   // it.tr.eu_643 rw.it.ga_643  tr.et.un_530 ga.no.un_320
  // [58e0]
  0x2d002921, 0x086b0307, 0x120b0a07, 0x64556b09,   // sl.sk.un_860 nl.ceb.no_432  pt.es.hu_432 ceb.rw.lg_444
  0x0a100407, 0x2d29020e, 0x0d090811, 0x3f000605,   // fi.lt.pt_432 da.sl.sk_555  no.pl.cs_653 de.af.un_330
  0x06000e1b, 0x101b08a4, 0x55532855, 0x13311b08,   // is.de.un_770 no.tr.lt_433  sw.ht.rw_442 tr.az.et_443
  0x23270b02, 0x07111707, 0x2800100d, 0x216b1ca0,   // es.gd.ca_222 sr.ro.bg_432  lt.sw.un_540 id.ceb.jw_322
  // [58f0]
  0x2a1355ee, 0x3f00010c, 0x101628a4, 0x29190a14,   // rw.et.mt_422 en.af.un_530  sw.hr.lt_433 pt.gl.sl_666
  0x09171ea0, 0x17161314, 0x641b5507, 0x190a11ee,   // ms.sr.pl_322 et.hr.sr_666  rw.tr.lg_432 ro.pt.gl_422
  0x03213fa0, 0x31005504, 0x13171605, 0x080212ec,   // af.jw.nl_322 rw.az.un_320  hr.sr.et_333 hu.da.no_644
  0x21083fa0, 0x0a001312, 0x170c16a7, 0x28211208,   // af.no.jw_322 et.pt.un_640  hr.sv.sr_532 hu.jw.sw_443
  // [5900]
  0x28645514, 0x170c1604, 0x640802ad, 0x04000c20,   // rw.lg.sw_666 hr.sv.sr_332  da.no.lg_643 sv.fi.un_850
  0x180609a0, 0x531812ee, 0x1217160d, 0x13002017,   // pl.de.ga_322 hu.ga.ht_422  hr.sr.hu_554 sq.et.un_730
  0x135528a4, 0x0b00270b, 0x17080204, 0x16170f0b,   // sw.rw.et_433 gd.es.un_520  da.no.sr_332 lv.sr.hr_542
  0x28001f0e, 0x3f00550c, 0x171011a0, 0x0c02125a,   // cy.sw.un_550 rw.af.un_530  ro.be.sr_322 hu.da.sv_553
  // [5910]
  0x171612ee, 0x29001214, 0x2a171655, 0x23001f0e,   // hu.hr.sr_422 hu.sl.un_660  hr.sr.mt_442 cy.ca.un_550
  0x080a100c, 0x07000805, 0x06001f13, 0x1f002305,   // be.mk.uk_543 uk.bg.un_330  cy.de.un_650 ca.cy.un_330
  0x0c0602a4, 0x1221180b, 0x20311b08, 0x3f035304,   // da.de.sv_433 ar.fa.ur_542  tr.az.sq_443 ht.nl.af_332
  0x11001f04, 0x23251fee, 0x0e2d1902, 0x311f12a7,   // cy.ro.un_320 cy.eu.ca_422  gl.sk.is_222 hu.cy.az_532
  // [5920]
  0x1c0312a7, 0x040a10ad, 0x25121bee, 0x18230713,   // hu.nl.id_532 be.mk.ru_643  tr.hu.eu_422 it.ca.ga_665
  0x235305a7, 0x032a5504, 0x64115513, 0x0a002902,   // fr.ht.ca_532 rw.mt.nl_332  rw.ro.lg_665 sl.pt.un_220
  0x2a120e08, 0x031901ee, 0x1b001c02, 0x16291002,   // is.hu.mt_443 en.gl.nl_422  id.tr.un_220 lt.sl.hr_222
  0x3f0612a0, 0x212864a0, 0x1a271ba0, 0x2a005512,   // hu.de.af_322 lg.sw.jw_322  tr.gd.tl_322 rw.mt.un_640
  // [5930]
  0x03133f12, 0x2325130c, 0x0a1a6b07, 0x2d2504a4,   // af.et.nl_654 et.eu.ca_543  ceb.tl.pt_432 fi.eu.sk_433
  0x12070a0d, 0x03163faf, 0x12000708, 0x25121ba4,   // pt.it.hu_554 af.hr.nl_655  it.hu.un_430 tr.hu.eu_433
  0x1a080208, 0x280a2112, 0x080201ee, 0x3f200607,   // da.no.tl_443 jw.pt.sw_654  en.da.no_422 de.sq.af_432
  0x176b06ad, 0x06210802, 0x6e6b21a0, 0x11136e0c,   // de.ceb.sr_643 no.jw.de_222  jw.ceb.blu_322 blu.et.ro_543
  // [5940]
  0x01186ba0, 0x2b1b0ea6, 0x06023fa0, 0x080a10a6,   // ceb.ga.en_322 is.tr.vi_521  af.da.de_322 be.mk.uk_521
  0x070a1009, 0x23271f04, 0x052723a4, 0x3f1f27ad,   // be.mk.bg_444 cy.gd.ca_332  ca.gd.fr_433 gd.cy.af_643
  0x0a1613ee, 0x27000621, 0x18000702, 0x060d13a7,   // et.hr.pt_422 de.gd.un_860  it.ga.un_220 et.cs.de_532
  0x272311af, 0x53000107, 0x01020807, 0x07081011,   // ro.ca.gd_655 en.ht.un_420  no.da.en_432 be.uk.bg_653
  // [5950]
  0x04170812, 0x170a100c, 0x28001a2b, 0x282555ad,   // uk.sr.ru_654 be.mk.sr_543  tl.sw.un_980 rw.eu.sw_643
  0x022d1aa0, 0x1200160d, 0x03113f60, 0x02063f07,   // tl.sk.da_322 hr.hu.un_540  af.ro.nl_664 af.de.da_432
  0x11530911, 0x271f23a4, 0x10132811, 0x3f0601a0,   // pl.ht.ro_653 ca.cy.gd_433  sw.et.lt_653 en.de.af_322
  0x286455ad, 0x13001704, 0x16291205, 0x29552504,   // rw.lg.sw_643 sr.et.un_320  hu.sl.hr_333 eu.rw.sl_332
  // [5960]
  0x53001602, 0x53642807, 0x17160cec, 0x070a04ad,   // hr.ht.un_220 sw.lg.ht_432  sv.hr.sr_644 ru.mk.bg_643
  0x53001222, 0x2511280c, 0x170a10ec, 0x1207230d,   // hu.ht.un_870 sw.ro.eu_543  be.mk.sr_644 ca.it.hu_554
  0x0a1020a9, 0x28006b05, 0x102718a4, 0x2d00110d,   // sq.lt.pt_544 ceb.sw.un_330  ga.gd.lt_433 ro.sk.un_540
  0x1b001a04, 0x12162902, 0x01002102, 0x160717a9,   // tl.tr.un_320 sl.hr.hu_222  jw.en.un_220 sr.it.hr_544
  // [5970]
  0x0107020c, 0x28001714, 0x08005318, 0x53001e1a,   // da.it.en_543 sr.sw.un_660  ht.no.un_740 ms.ht.un_760
  0x1100530e, 0x28552dee, 0x043f0304, 0x11002d0d,   // ht.ro.un_550 sk.rw.sw_422  nl.af.fi_332 sk.ro.un_540
  0x071708ee, 0x133f0307, 0x040e0c07, 0x033f0f05,   // uk.sr.bg_422 nl.af.et_432  sv.is.fi_432 lv.af.nl_333
  0x211c27a0, 0x0e006b04, 0x0b231e04, 0x23212da4,   // gd.id.jw_322 ceb.is.un_320  ms.ca.es_332 sk.jw.ca_433
  // [5980]
  0x0c1e1cee, 0x211b55a4, 0x1c0c2107, 0x191720a7,   // id.ms.sv_422 rw.tr.jw_433  jw.sv.id_432 sq.sr.gl_532
  0x2d000208, 0x2a001804, 0x080405ad, 0x55311b0d,   // da.sk.un_430 ga.mt.un_320  fr.fi.no_643 tr.az.rw_554
  0x2300190d, 0x08041b07, 0x11282709, 0x181625a4,   // gl.ca.un_540 tr.fi.no_432  gd.sw.ro_444 eu.hr.ga_433
  0x17161102, 0x016b1e02, 0x3100190e, 0x01000304,   // ro.hr.sr_222 ms.ceb.en_222  gl.az.un_550 nl.en.un_320
  // [5990]
  0x013f035a, 0x3f0323a7, 0x1c1e310c, 0x185527a9,   // nl.af.en_553 ca.nl.af_532  az.ms.id_543 gd.rw.ga_544
  0x2a1e200c, 0x1c1020a6, 0x23000304, 0x21002505,   // sq.ms.mt_543 sq.lt.id_521  nl.ca.un_320 eu.jw.un_330
  0x05122d0c, 0x27000604, 0x030c0607, 0x09000e13,   // sk.hu.fr_543 de.gd.un_320  de.sv.nl_432 is.pl.un_650
  0x09001805, 0x1a013fa0, 0x05000419, 0x1a0864a7,   // ga.pl.un_330 af.en.tl_322  fi.fr.un_750 lg.no.tl_532
  // [59a0]
  0x08000e22, 0x21282dee, 0x04002d07, 0x070b10ec,   // is.no.un_870 sk.sw.jw_422  sk.fi.un_420 lt.es.it_644
  0x0e172d0c, 0x53005504, 0x64000704, 0x09171107,   // sk.sr.is_543 rw.ht.un_320  it.lg.un_320 ro.sr.pl_432
  0x21006e02, 0x28180aee, 0x16190a04, 0x0f1907a0,   // blu.jw.un_220 pt.ga.sw_422  pt.gl.hr_332 it.gl.lv_322
  0x08061f04, 0x0b1a64ad, 0x07171660, 0x0600180d,   // cy.de.no_332 lg.tl.es_643  hr.sr.it_664 ga.de.un_540
  // [59b0]
  0x6b001207, 0x19211aa0, 0x032d0d08, 0x21170904,   // hu.ceb.un_420 tl.jw.gl_322  cs.sk.nl_443 pl.sr.jw_332
  0x07045504, 0x29000e14, 0x1b001a07, 0x1a2128ee,   // rw.fi.it_332 is.sl.un_660  tl.tr.un_420 sw.jw.tl_422
  0x2a016b07, 0x022705ad, 0x19120a08, 0x25002805,   // ceb.en.mt_432 fr.gd.da_643  pt.hu.gl_443 sw.eu.un_330
  0x06002009, 0x061f0804, 0x062d0404, 0x3f282008,   // sq.de.un_440 no.cy.de_332  fi.sk.de_332 sq.sw.af_443
  // [59c0]
  0x102305a0, 0x0f006404, 0x0a0806a0, 0x040f12a9,   // fr.ca.lt_322 lg.lv.un_320  de.no.pt_322 hu.lv.fi_544
  0x10040855, 0x0e0713ad, 0x20231304, 0x08071005,   // uk.ru.be_442 et.it.is_643  et.ca.sq_332 be.bg.uk_333
  0x2d0d0405, 0x200523a9, 0x0f230514, 0x1b002708,   // fi.cs.sk_333 ca.fr.sq_544  fr.ca.lv_666 gd.tr.un_430
  0x04002911, 0x2d0b29a4, 0x0f2110ad, 0x290c16ec,   // sl.fi.un_630 sl.es.sk_433  lt.jw.lv_643 hr.sv.sl_644
  // [59d0]
  0x101a6b12, 0x25000b12, 0x271801af, 0x0a000c05,   // ceb.tl.lt_654 es.eu.un_640  en.ga.gd_655 sv.pt.un_330
  0x0a071702, 0x190b0aea, 0x0a001921, 0x1b1f10ad,   // sr.bg.mk_222 pt.es.gl_822  gl.pt.un_860 lt.cy.tr_643
  0x101f27a0, 0x25290fac, 0x1b001305, 0x0e002b02,   // gd.cy.lt_322 lv.sl.eu_632  et.tr.un_330 vi.is.un_220
  0x23006e04, 0x102304a0, 0x053f10ee, 0x1a002b05,   // blu.ca.un_320 fi.ca.lt_322  lt.af.fr_422 vi.tl.un_330
  // [59e0]
  0x11002a11, 0x1a1c1ea7, 0x1f020ca0, 0x17080a02,   // mt.ro.un_630 ms.id.tl_532  sv.da.cy_322 mk.uk.sr_222
  0x0b200dad, 0x6b000107, 0x2d002514, 0x0c001212,   // cs.sq.es_643 en.ceb.un_420  eu.sk.un_660 hu.sv.un_640
  0x2a1716ad, 0x091302a0, 0x033f080c, 0x121f050d,   // hr.sr.mt_643 da.et.pl_322  no.af.nl_543 fr.cy.hu_554
  0x0502010c, 0x06033f12, 0x08285507, 0x083f2da0,   // en.da.fr_543 af.nl.de_654  rw.sw.no_432 sk.af.no_322
  // [59f0]
  0x2a016ba4, 0x04002902, 0x2d00041a, 0x18001b0e,   // ceb.en.mt_433 sl.fi.un_220  fi.sk.un_760 tr.ga.un_550
  0x2a000e02, 0x2d005307, 0x180127ee, 0x0a00180d,   // is.mt.un_220 ht.sk.un_420  gd.en.ga_422 ga.pt.un_540
  0x10080aec, 0x070a100c, 0x232b1ea0, 0x060428a0,   // mk.uk.be_644 be.mk.bg_543  ms.vi.ca_322 sw.fi.de_322
  0x130427ad, 0x041925a0, 0x0a1b20a7, 0x180d2907,   // gd.fi.et_643 eu.gl.fi_322  sq.tr.pt_532 sl.cs.ga_432
  // [5a00]
  0x17100805, 0x0d161007, 0x6e002018, 0x17001f19,   // uk.be.sr_333 lt.hr.cs_432  sq.blu.un_740 cy.sr.un_750
  0x0a070807, 0x08061ba4, 0x64002907, 0x6b1e01ee,   // uk.bg.mk_432 tr.de.no_433  sl.lg.un_420 en.ms.ceb_422
  0x20006e08, 0x19120702, 0x13270407, 0x0c1a2507,   // blu.sq.un_430 it.hu.gl_222  fi.gd.et_432 eu.tl.sv_432
  0x28001702, 0x270820ee, 0x64551fa4, 0x0c0e20ec,   // sr.sw.un_220 sq.no.gd_422  cy.rw.lg_433 sq.is.sv_644
  // [5a10]
  0x556b1a0e, 0x07033f0d, 0x08280207, 0x5355640c,   // tl.ceb.rw_555 af.nl.it_554  da.sw.no_432 lg.rw.ht_543
  0x20006e19, 0x0e080c55, 0x280a07ad, 0x6b2d6404,   // blu.sq.un_750 sv.no.is_442  it.pt.sw_643 lg.sk.ceb_332
  0x0e232007, 0x290410a4, 0x0a1707a7, 0x1f002a02,   // sq.ca.is_432 lt.fi.sl_433  bg.sr.mk_532 mt.cy.un_220
  0x29190a0e, 0x2d1619a4, 0x556b5304, 0x1a082704,   // pt.gl.sl_555 gl.hr.sk_433  ht.ceb.rw_332 gd.no.tl_332
  // [5a20]
  0x042d0d0e, 0x2a000414, 0x1a645507, 0x120507a0,   // cs.sk.fi_555 fi.mt.un_660  rw.lg.tl_432 it.fr.hu_322
  0x16250fee, 0x11165507, 0x0c0e20ad, 0x1b2353a0,   // lv.eu.hr_422 rw.hr.ro_432  sq.is.sv_643 ht.ca.tr_322
  0x29190a04, 0x161e1c0d, 0x551f6402, 0x23130c08,   // pt.gl.sl_332 id.ms.hr_554  lg.cy.rw_222 sv.et.ca_443
  0x53172907, 0x1e1c0ca0, 0x20231f0d, 0x12551ea0,   // sl.sr.ht_432 sv.id.ms_322  cy.ca.sq_554 ms.rw.hu_322
  // [5a30]
  0x20002302, 0x0710170d, 0x256b1a04, 0x21070da4,   // ca.sq.un_220 sr.be.bg_554  tl.ceb.eu_332 cs.it.jw_433
  0x3f0302af, 0x23000b1b, 0x12000408, 0x21121809,   // da.nl.af_655 es.ca.un_770  fi.hu.un_430 ar.ur.fa_444
  0x11005304, 0x2a0e04a4, 0x11102307, 0x0100640c,   // ht.ro.un_320 fi.is.mt_433  ca.lt.ro_432 lg.en.un_530
  0x1b3112a0, 0x2000290c, 0x271128af, 0x10001f13,   // hu.az.tr_322 sl.sq.un_530  sw.ro.gd_655 cy.lt.un_650
  // [5a40]
  0x0900120e, 0x5300051a, 0x1f00060e, 0x0f040cee,   // hu.pl.un_550 fr.ht.un_760  de.cy.un_550 sv.fi.lv_422
  0x09001209, 0x04170a14, 0x31192aa4, 0x0c2a2013,   // hu.pl.un_440 mk.sr.ru_666  mt.gl.az_433 sq.mt.sv_665
  0x020c0404, 0x12002a12, 0x1f00640e, 0x07001713,   // fi.sv.da_332 mt.hu.un_640  lg.cy.un_550 sr.bg.un_650
  0x0c171660, 0x0c121304, 0x2a000418, 0x040a1709,   // hr.sr.sv_664 et.hu.sv_332  fi.mt.un_740 sr.mk.ru_444
  // [5a50]
  0x073f01a4, 0x1b002904, 0x06070107, 0x0e070c08,   // en.af.it_433 sl.tr.un_320  en.it.de_432 sv.it.is_443
  0x18010607, 0x17040aaf, 0x05000307, 0x0a101702,   // de.en.ga_432 mk.ru.sr_655  nl.fr.un_420 sr.be.mk_222
  0x070e04ee, 0x28001914, 0x16006407, 0x0727180c,   // fi.is.it_422 gl.sw.un_660  lg.hr.un_420 ga.gd.it_543
  0x0b550da7, 0x29282da4, 0x1f201213, 0x01190b02,   // cs.rw.es_532 sk.sw.sl_433  hu.sq.cy_665 es.gl.en_222
  // [5a60]
  0x111827a4, 0x21190b04, 0x09001207, 0x2713180c,   // gd.ga.ro_433 es.gl.jw_332  hu.pl.un_420 ga.et.gd_543
  0x29000a04, 0x17000a33, 0x11000508, 0x2b006b04,   // pt.sl.un_320 mk.sr.un_A70  fr.ro.un_430 ceb.vi.un_320
  0x2831120b, 0x020c1702, 0x310d1204, 0x2a1829af,   // hu.az.sw_542 sr.sv.da_222  hu.cs.az_332 sl.ga.mt_655
  0x0d13090c, 0x2d0d55a0, 0x04180807, 0x250b19a0,   // hi.bh.ne_543 rw.cs.sk_322  no.ga.fi_432 gl.es.eu_322
  // [5a70]
  0x0b090da6, 0x100f19ee, 0x2718110c, 0x3f0302a7,   // cs.pl.es_521 gl.lv.lt_422  ro.ga.gd_543 da.nl.af_532
  0x130a04ad, 0x16100f04, 0x172d1604, 0x1c00131a,   // fi.pt.et_643 lv.lt.hr_332  hr.sk.sr_332 bh.mr.un_760
  0x0308025a, 0x2305080c, 0x1b1310a0, 0x13000f02,   // da.no.nl_553 no.fr.ca_543  lt.et.tr_322 lv.et.un_220
  0x1b061355, 0x020f10a4, 0x17070413, 0x116429a0,   // et.de.tr_442 lt.lv.da_433  ru.bg.sr_665 sl.lg.ro_322
  // [5a80]
  0x17081004, 0x05000b1a, 0x190a5314, 0x13003f19,   // be.uk.sr_332 es.fr.un_760  ht.pt.gl_666 af.et.un_750
  0x0c001004, 0x230501a4, 0x20030e07, 0x05230112,   // lt.sv.un_320 en.fr.ca_433  is.nl.sq_432 en.ca.fr_654
  0x18000808, 0x10002305, 0x05231055, 0x5300290e,   // no.ga.un_430 ca.lt.un_330  lt.ca.fr_442 sl.ht.un_550
  0x2a000512, 0x10003f19, 0x181f1007, 0x6e100f04,   // fr.mt.un_640 af.lt.un_750  lt.cy.ga_432 lv.lt.blu_332
  // [5a90]
  0x0408100b, 0x216e1007, 0x1c130107, 0x3f1f030c,   // be.uk.ru_542 lt.blu.jw_432  en.et.id_432 nl.cy.af_543
  0x0f100555, 0x1c001e2b, 0x2d1a2107, 0x020d0608,   // fr.lt.lv_442 ms.id.un_980  jw.tl.sk_432 de.cs.da_443
  0x013f10a0, 0x290f18ad, 0x20081fee, 0x29161307,   // lt.af.en_322 ga.lv.sl_643  cy.no.sq_422 et.hr.sl_432
  0x08311704, 0x53111ba0, 0x18276e60, 0x120c06ad,   // sr.az.no_332 tr.ro.ht_322  blu.gd.ga_664 de.sv.hu_643
  // [5aa0]
  0x13000302, 0x1a033f05, 0x0c0f10a0, 0x171602af,   // nl.et.un_220 af.nl.tl_333  lt.lv.sv_322 da.hr.sr_655
  0x02281e12, 0x2d000302, 0x6b0f21a9, 0x20002d04,   // ms.sw.da_654 nl.sk.un_220  jw.lv.ceb_544 sk.sq.un_320
  0x02003f23, 0x04002509, 0x18202712, 0x080121a0,   // af.da.un_880 eu.fi.un_440  gd.sq.ga_654 jw.en.no_322
  0x172501a0, 0x1f1e1c0e, 0x231e1c08, 0x2a000411,   // en.eu.sr_322 id.ms.cy_555  id.ms.ca_443 fi.mt.un_630
  // [5ab0]
  0x10002d18, 0x08003f0e, 0x3f030808, 0x64000412,   // sk.lt.un_740 af.no.un_550  no.nl.af_443 fi.lg.un_640
  0x120f18a4, 0x3f020609, 0x190b12a4, 0x1f033fa4,   // ga.lv.hu_433 de.da.af_444  hu.es.gl_433 af.nl.cy_433
  0x120f1a08, 0x2b005304, 0x04080bee, 0x25000b1b,   // tl.lv.hu_443 ht.vi.un_320  es.no.fi_422 es.eu.un_770
  0x190604a0, 0x040519a4, 0x10190b08, 0x16002d07,   // fi.de.gl_322 gl.fr.fi_433  es.gl.lt_443 sk.hr.un_420
  // [5ac0]
  0x080711af, 0x250b19a4, 0x19002514, 0x112305a0,   // ro.bg.uk_655 gl.es.eu_433  eu.gl.un_660 fr.ca.ro_322
  0x0400060c, 0x21090d04, 0x102508a0, 0x2d120f02,   // de.fi.un_530 cs.pl.jw_332  no.eu.lt_322 lv.hu.sk_222
  0x0a0410a7, 0x04532aac, 0x190b10af, 0x112320a0,   // be.ru.mk_532 mt.ht.fi_632  lt.es.gl_655 sq.ca.ro_322
  0x1303040c, 0x0e1b3112, 0x23271807, 0x0a002904,   // fi.nl.et_543 az.tr.is_654  ga.gd.ca_432 sl.pt.un_320
  // [5ad0]
  0x531319a4, 0x1700080d, 0x100823a4, 0x10000302,   // gl.et.ht_433 uk.sr.un_540  ca.no.lt_433 nl.lt.un_220
  0x31000a0c, 0x1e1b31a0, 0x3f200308, 0x16002707,   // pt.az.un_530 az.tr.ms_322  nl.sq.af_443 gd.hr.un_420
  0x12080cee, 0x100f040c, 0x2a002b08, 0x08010605,   // sv.no.hu_422 fi.lv.lt_543  vi.mt.un_430 de.en.no_333
  0x290f2daf, 0x0c020404, 0x0812100c, 0x08000429,   // sk.lv.sl_655 fi.da.sv_332  lt.hu.no_543 ru.uk.un_960
  // [5ae0]
  0x270b1fa0, 0x070a1007, 0x250829ee, 0x16256407,   // cy.es.gd_322 be.mk.bg_432  sl.no.eu_422 lg.eu.hr_432
  0x280e13ee, 0x53000e0b, 0x08201fa6, 0x100411a4,   // et.is.sw_422 is.ht.un_520  cy.sq.no_521 ro.ru.be_433
  0x55216408, 0x080f10a0, 0x23190a02, 0x0e0955a0,   // lg.jw.rw_443 lt.lv.no_322  pt.gl.ca_222 rw.pl.is_322
  0x0d312d04, 0x202a2907, 0x09072da0, 0x28001204,   // sk.az.cs_332 sl.mt.sq_432  sk.it.pl_322 hu.sw.un_320
  // [5af0]
  0x556b2107, 0x311b110c, 0x25205511, 0x53211fa0,   // jw.ceb.rw_432 ro.tr.az_543  rw.sq.eu_653 cy.jw.ht_322
  0x07115505, 0x31121baf, 0x641f12a7, 0x28295507,   // rw.ro.it_333 tr.hu.az_655  hu.cy.lg_532 rw.sl.sw_432
  0x556401a4, 0x25030f07, 0x031c3f07, 0x1c000402,   // en.lg.rw_433 lv.nl.eu_432  af.id.nl_432 fi.id.un_220
  0x131f03a7, 0x3f000a04, 0x13292d0b, 0x20231fa7,   // nl.cy.et_532 pt.af.un_320  sk.sl.et_542 cy.ca.sq_532
  // [5b00]
  0x170704a6, 0x07001a04, 0x03010aa0, 0x211e3fa0,   // ru.bg.sr_521 tl.it.un_320  pt.en.nl_322 af.ms.jw_322
  0x202503ec, 0x251729a9, 0x2a000a02, 0x2b282155,   // nl.eu.sq_644 sl.sr.eu_544  pt.mt.un_220 jw.sw.vi_442
  0x3f2103a0, 0x25311b07, 0x063f0360, 0x20006e07,   // nl.jw.af_322 tr.az.eu_432  nl.af.de_664 blu.sq.un_420
  0x12002111, 0x06000213, 0x6b0c0608, 0x1c2a20ad,   // fa.ur.un_630 da.de.un_650  de.sv.ceb_443 sq.mt.id_643
  // [5b10]
  0x1e081c08, 0x032a1307, 0x02061f02, 0x211c2807,   // id.no.ms_443 et.mt.nl_432  cy.de.da_222 sw.id.jw_432
  0x07052a04, 0x53002a04, 0x1221180e, 0x2a1b1fa7,   // mt.fr.it_332 mt.ht.un_320  ar.fa.ur_555 cy.tr.mt_532
  0x03006404, 0x08001a09, 0x27001104, 0x06050102,   // lg.nl.un_320 tl.no.un_440  ro.gd.un_320 en.fr.de_222
  0x12062304, 0x08001708, 0x120c0610, 0x0a0704ad,   // ca.de.hu_332 sr.no.un_430  de.sv.hu_642 ru.bg.mk_643
  // [5b20]
  0x09006b02, 0x1b001f14, 0x12000613, 0x101631a4,   // ceb.pl.un_220 cy.tr.un_660  de.hu.un_650 az.hr.lt_433
  0x13250411, 0x0c211a04, 0x0e000608, 0x02061b04,   // fi.eu.et_653 tl.jw.sv_332  de.is.un_430 tr.de.da_332
  0x033f1e07, 0x0c001604, 0x16001302, 0x07001f02,   // ms.af.nl_432 hr.sv.un_320  et.hr.un_220 cy.it.un_220
  0x0a17075a, 0x1600290e, 0x2a000607, 0x0d060202,   // bg.sr.mk_553 sl.hr.un_550  de.mt.un_420 da.de.cs_222
  // [5b30]
  0x010512ee, 0x10130faf, 0x211328a4, 0x2d101609,   // hu.fr.en_422 lv.et.lt_655  sw.et.jw_433 hr.lt.sk_444
  0x64001705, 0x13170407, 0x042021a0, 0x551716a4,   // sr.lg.un_330 fi.sr.et_432  jw.sq.fi_322 hr.sr.rw_433
  0x1710070c, 0x0e003f21, 0x10292d09, 0x290b0a0c,   // it.lt.sr_543 af.is.un_860  sk.sl.lt_444 pt.es.sl_543
  0x080e0213, 0x03272a04, 0x112305a9, 0x1704105a,   // da.is.no_665 mt.gd.nl_332  fr.ca.ro_544 be.ru.sr_553
  // [5b40]
  0x0911180c, 0x6b192507, 0x64070a07, 0x55291760,   // ga.ro.pl_543 eu.gl.ceb_432  pt.it.lg_432 sr.sl.rw_664
  0x17000608, 0x091a6b5a, 0x21091607, 0x06002505,   // de.sr.un_430 ceb.tl.pl_553  hr.pl.jw_432 eu.de.un_330
  0x6b080205, 0x55002002, 0x160f170c, 0x0a171111,   // da.no.ceb_333 sq.rw.un_220  sr.lv.hr_543 ro.sr.mk_653
  0x17160ca0, 0x07001313, 0x291709a4, 0x0a0811ee,   // sv.hr.sr_322 et.it.un_650  pl.sr.sl_433 ro.uk.mk_422
  // [5b50]
  0x072904a0, 0x2810135a, 0x28553fac, 0x0f211aa7,   // fi.sl.it_322 et.lt.sw_553  af.rw.sw_632 tl.jw.lv_532
  0x0a291055, 0x0407080e, 0x0c0e0705, 0x1b1c21a4,   // lt.sl.pt_442 uk.bg.ru_555  it.is.sv_333 jw.id.tr_433
  0x076b1a05, 0x12000d13, 0x12201ba7, 0x6b0b0104,   // tl.ceb.it_333 cs.hu.un_650  tr.sq.hu_532 en.es.ceb_332
  0x1008020d, 0x0255080c, 0x273f230c, 0x17161902,   // da.no.lt_554 no.rw.da_543  ca.af.gd_543 gl.hr.sr_222
  // [5b60]
  0x04080711, 0x02126ba9, 0x10002808, 0x21001307,   // bg.uk.ru_653 ceb.hu.da_544  sw.lt.un_430 et.jw.un_420
  0x036b3f13, 0x130220a4, 0x08070a0c, 0x171625ee,   // af.ceb.nl_665 sq.da.et_433  mk.bg.uk_543 eu.hr.sr_422
  0x0200130c, 0x0e000504, 0x6b083fa0, 0x0c033f05,   // et.da.un_530 fr.is.un_320  af.no.ceb_322 af.nl.sv_333
  0x53642811, 0x640c1302, 0x1b000c05, 0x1f110504,   // sw.lg.ht_653 et.sv.lg_222  sv.tr.un_330 fr.ro.cy_332
  // [5b70]
  0x08171005, 0x3f0e1fa0, 0x2a0c3f04, 0x6b551aa9,   // be.sr.uk_333 cy.is.af_322  af.sv.mt_332 tl.rw.ceb_544
  0x020308a0, 0x01001907, 0x181221a4, 0x1c0806a4,   // no.nl.da_322 gl.en.un_420  fa.ur.ar_433 de.no.id_433
  0x16002008, 0x050c64a7, 0x07551a08, 0x201a2a02,   // sq.hr.un_430 lg.sv.fr_532  tl.rw.it_443 mt.tl.sq_222
  0x25001f11, 0x2800211b, 0x256404a0, 0x090d1312,   // cy.eu.un_630 jw.sw.un_770  fi.lg.eu_322 bh.ne.hi_654
  // [5b80]
  0x3f001f04, 0x1600280d, 0x101204ec, 0x041329a0,   // cy.af.un_320 sw.hr.un_540  fi.hu.lt_644 sl.et.fi_322
  0x18002b0c, 0x64210404, 0x6b2855a7, 0x040a0755,   // vi.ga.un_530 fi.jw.lg_332  rw.sw.ceb_532 bg.mk.ru_442
  0x080206a9, 0x060b08a0, 0x55002820, 0x2d0e64a0,   // de.da.no_544 no.es.de_322  sw.rw.un_850 lg.is.sk_322
  0x201c25a9, 0x132325af, 0x2908200c, 0x645511a0,   // eu.id.sq_544 eu.ca.et_655  sq.no.sl_543 ro.rw.lg_322
  // [5b90]
  0x011f2704, 0x311a6b08, 0x25001919, 0x1c201e12,   // gd.cy.en_332 ceb.tl.az_443  gl.eu.un_750 ms.sq.id_654
  0x28001e0c, 0x1007010c, 0x1c0906a9, 0x216b1a0c,   // ms.sw.un_530 en.it.lt_543  de.pl.id_544 tl.ceb.jw_543
  0x110904a4, 0x13092507, 0x080925ad, 0x200411ad,   // fi.pl.ro_433 eu.pl.et_432  eu.pl.no_643 ro.fi.sq_643
  0x6b3f0107, 0x21000920, 0x0e001302, 0x2d0d09a6,   // en.af.ceb_432 pl.jw.un_850  et.is.un_220 pl.cs.sk_521
  // [5ba0]
  0x5500280d, 0x1b002a09, 0x2d00090c, 0x1b001f04,   // sw.rw.un_540 mt.tr.un_440  pl.sk.un_530 cy.tr.un_320
  0x09006414, 0x211753a0, 0x17006404, 0x28000920,   // lg.pl.un_660 ht.sr.jw_322  lg.sr.un_320 pl.sw.un_850
  0x10001713, 0x07190b0c, 0x06001f08, 0x1711070d,   // sr.be.un_650 es.gl.it_543  cy.de.un_430 bg.ro.sr_554
  0x16645502, 0x55002802, 0x5328090c, 0x033f090c,   // rw.lg.hr_222 sw.rw.un_220  pl.sw.ht_543 pl.af.nl_543
  // [5bb0]
  0x23002107, 0x110208a0, 0x3f1f020c, 0x3f0603a9,   // jw.ca.un_420 no.da.ro_322  da.cy.af_543 nl.de.af_544
  0x021f3f0b, 0x0a1710ec, 0x0f080d04, 0x2a1716a0,   // af.cy.da_542 be.sr.mk_644  cs.no.lv_332 hr.sr.mt_322
  0x012b6ba0, 0x311b1111, 0x13090d0d, 0x07001604,   // ceb.vi.en_322 ro.tr.az_653  ne.hi.bh_554 hr.it.un_320
  0x280501a4, 0x10003f12, 0x0a00131a, 0x25041c02,   // en.fr.sw_433 af.lt.un_640  et.pt.un_760 id.fi.eu_222
  // [5bc0]
  0x276e6b11, 0x0d051907, 0x1a556b0c, 0x1a0e08a0,   // ceb.blu.gd_653 gl.fr.cs_432  ceb.rw.tl_543 no.is.tl_322
  0x2a64130c, 0x64130302, 0x53001f0b, 0x18120bec,   // et.lg.mt_543 nl.et.lg_222  cy.ht.un_520 es.hu.ga_644
  0x253f03ac, 0x1f002513, 0x171e20ac, 0x033f05af,   // nl.af.eu_632 eu.cy.un_650  sq.ms.sr_632 fr.af.nl_655
  0x02092d04, 0x18271c0c, 0x1a2001ac, 0x2d0102a0,   // sk.pl.da_332 id.gd.ga_543  en.sq.tl_632 da.en.sk_322
  // [5bd0]
  0x10003f1a, 0x130d05a9, 0x25281112, 0x09001004,   // af.lt.un_760 fr.cs.et_544  ro.sw.eu_654 lt.pl.un_320
  0x18000a12, 0x250e2007, 0x64002305, 0x0c003102,   // pt.ga.un_640 sq.is.eu_432  ca.lg.un_330 az.sv.un_220
  0x03000c07, 0x08020e02, 0x10001122, 0x1f001a07,   // sv.nl.un_420 is.da.no_222  ro.be.un_870 tl.cy.un_420
  0x27000c12, 0x0e00180e, 0x081712a4, 0x05006402,   // sv.gd.un_640 ga.is.un_550  hu.sr.no_433 lg.fr.un_220
  // [5be0]
  0x3f001313, 0x0b033f11, 0x03001f0d, 0x130e64a7,   // et.af.un_650 af.nl.es_653  cy.nl.un_540 lg.is.et_532
  0x533f0dee, 0x0100242a, 0x2d100907, 0x3f280108,   // cs.af.ht_422 yi.iw.un_970  pl.lt.sk_432 en.sw.af_443
  0x20010407, 0x0a2119a0, 0x10023fa9, 0x0c05080c,   // fi.en.sq_432 gl.jw.pt_322  af.da.lt_544 no.fr.sv_543
  0x0f060512, 0x311b550b, 0x05005319, 0x16080fac,   // fr.de.lv_654 rw.tr.az_542  ht.fr.un_750 lv.no.hr_632
  // [5bf0]
  0x0425110c, 0x01051911, 0x25001122, 0x641e1aa4,   // ro.eu.fi_543 gl.fr.en_653  ro.eu.un_870 tl.ms.lg_433
  0x091953ee, 0x0f080ba7, 0x130208af, 0x281125ad,   // ht.gl.pl_422 es.no.lv_532  no.da.et_655 eu.ro.sw_643
  0x080c020b, 0x05001e02, 0x05000d04, 0x02050807,   // da.sv.no_542 ms.fr.un_220  cs.fr.un_320 no.fr.da_432
  0x12092007, 0x0b0523ee, 0x12552811, 0x02060f55,   // sq.pl.hu_432 ca.fr.es_422  sw.rw.hu_653 lv.de.da_442

  // [5c00]
  0x19110507, 0x05233fa0, 0x0913040c, 0x25005512,   // fr.ro.gl_432 af.ca.fr_322  fi.et.pl_543 rw.eu.un_640
  0x23001013, 0x3f0a0507, 0x0c001e04, 0x3f0704ec,   // lt.ca.un_650 fr.pt.af_432  ms.sv.un_320 fi.it.af_644
  0x09003109, 0x0a530d07, 0x211a25a4, 0x2d290fad,   // az.pl.un_440 cs.ht.pt_432  eu.tl.jw_433 lv.sl.sk_643
  0x17160805, 0x230f05ac, 0x1a005511, 0x1e1c29a9,   // no.hr.sr_333 fr.lv.ca_632  rw.tl.un_630 sl.id.ms_544
  // [5c10]
  0x0b02080b, 0x6e1f010b, 0x3f055311, 0x1f001e08,   // no.da.es_542 en.cy.blu_542  ht.fr.af_653 ms.cy.un_430
  0x09641e07, 0x16130fa6, 0x20550d04, 0x01180504,   // ms.lg.pl_432 lv.et.hr_521  cs.rw.sq_332 fr.ga.en_332
  0x6b1f64ad, 0x55201108, 0x11002b0d, 0x0c0802af,   // lg.cy.ceb_643 ro.sq.rw_443  vi.ro.un_540 da.no.sv_655
  0x18160a07, 0x23000702, 0x28005535, 0x18013fee,   // pt.hr.ga_432 it.ca.un_220  rw.sw.un_A90 af.en.ga_422
  // [5c20]
  0x2a060da0, 0x2d0d18ec, 0x0c0701a4, 0x286455a4,   // cs.de.mt_322 ga.cs.sk_644  en.it.sv_433 rw.lg.sw_433
  0x215528ad, 0x2a0701a4, 0x0c2a070c, 0x02132307,   // sw.rw.jw_643 en.it.mt_433  it.mt.sv_543 ca.et.da_432
  0x06640708, 0x021220ad, 0x1100040d, 0x0c0413a4,   // it.lg.de_443 sq.hu.da_643  fi.ro.un_540 et.fi.sv_433
  0x070801a4, 0x1b000c0d, 0x18003f0c, 0x182a0107,   // en.no.it_433 sv.tr.un_540  af.ga.un_530 en.mt.ga_432
  // [5c30]
  0x12000f12, 0x16000621, 0x06001805, 0x18001f0d,   // lv.hu.un_640 de.hr.un_860  ga.de.un_330 cy.ga.un_540
  0x2900310c, 0x06001804, 0x040817ad, 0x041011ee,   // az.sl.un_530 ga.de.un_320  sr.uk.ru_643 ro.be.ru_422
  0x1a016bee, 0x120e2d0b, 0x0e080c0c, 0x23051aa4,   // ceb.en.tl_422 sk.is.hu_542  sv.no.is_543 tl.fr.ca_433
  0x2a001204, 0x646b2804, 0x64290eee, 0x11211a0c,   // hu.mt.un_320 sw.ceb.lg_332  is.sl.lg_422 tl.jw.ro_543
  // [5c40]
  0x09001c21, 0x121a5555, 0x1a1101a0, 0x0d0b0a02,   // mr.hi.un_860 rw.tl.hu_442  en.ro.tl_322 pt.es.cs_222
  0x2d0d1fa0, 0x0e280caf, 0x10001a09, 0x00001137,   // cy.cs.sk_322 sv.sw.is_655  tl.lt.un_440 ro.un.un_B00
  0x55002508, 0x08006e0c, 0x255564a4, 0x1107045a,   // eu.rw.un_430 blu.no.un_530  lg.rw.eu_433 ru.bg.ro_553
  0x6b1f0ca9, 0x171608a0, 0x250b2304, 0x2d0e0d04,   // sv.cy.ceb_544 no.hr.sr_322  ca.es.eu_332 cs.is.sk_332
  // [5c50]
  0x2d180d0c, 0x55251aad, 0x53000521, 0x28082aa4,   // cs.ga.sk_543 tl.eu.rw_643  fr.ht.un_860 mt.no.sw_433
  0x0d1021a0, 0x0719200c, 0x20133f07, 0x291608a9,   // jw.lt.cs_322 sq.gl.it_543  af.et.sq_432 no.hr.sl_544
  0x28172104, 0x080f28a0, 0x1f0c03a0, 0x1a6b5504,   // jw.sr.sw_332 sw.lv.no_322  nl.sv.cy_322 rw.ceb.tl_332
  0x1100230c, 0x3f002819, 0x1a210913, 0x040c02a7,   // ca.ro.un_530 sw.af.un_750  pl.jw.tl_665 da.sv.fi_532
  // [5c60]
  0x3f6b27a0, 0x55190a0c, 0x05000613, 0x3f000e21,   // gd.ceb.af_322 pt.gl.rw_543  de.fr.un_650 is.af.un_860
  0x10645508, 0x556b2812, 0x063f53a7, 0x1b001f02,   // rw.lg.lt_443 sw.ceb.rw_654  ht.af.de_532 cy.tr.un_220
  0x28001822, 0x250f10ee, 0x1612290c, 0x25001f02,   // ga.sw.un_870 lt.lv.eu_422  sl.hu.hr_543 cy.eu.un_220
  0x3f040f0c, 0x05001b14, 0x0c003f0d, 0x1a000119,   // lv.fi.af_543 tr.fr.un_660  af.sv.un_540 en.tl.un_750
  // [5c70]
  0x05010712, 0x190a2814, 0x1000160c, 0x3f000f23,   // it.en.fr_654 sw.pt.gl_666  hr.lt.un_530 lv.af.un_880
  0x053f010c, 0x11022907, 0x3f0123af, 0x10006e1a,   // en.af.fr_543 sl.da.ro_432  ca.en.af_655 blu.lt.un_760
  0x01052309, 0x04000820, 0x0d000911, 0x3f012aa4,   // ca.fr.en_444 uk.ru.un_850  hi.ne.un_630 mt.en.af_433
  0x080411ec, 0x19230111, 0x11001009, 0x01531307,   // ro.ru.uk_644 en.ca.gl_653  lt.ro.un_440 et.ht.en_432
  // [5c80]
  0x31161b07, 0x23075308, 0x06090f07, 0x016418a0,   // tr.hr.az_432 ht.it.ca_443  lv.pl.de_432 ga.lg.en_322
  0x01002305, 0x1f063f04, 0x030f0112, 0x28002514,   // ca.en.un_330 af.de.cy_332  en.lv.nl_654 eu.sw.un_660
  0x0e00020c, 0x052301a9, 0x1e0f3f0d, 0x233f0107,   // da.is.un_530 en.ca.fr_544  af.lv.ms_554 en.af.ca_432
  0x2800130e, 0x1f001213, 0x2400012a, 0x04182707,   // et.sw.un_550 hu.cy.un_650  iw.yi.un_970 gd.ga.fi_432
  // [5c90]
  0x09000605, 0x0816020c, 0x03001702, 0x02030e0c,   // de.pl.un_330 da.hr.no_543  sr.nl.un_220 is.nl.da_543
  0x04020c02, 0x1f2d03a0, 0x0c1f02ee, 0x080f0e08,   // sv.da.fi_222 nl.sk.cy_322  da.cy.sv_422 is.lv.no_443
  0x13040e0c, 0x100e1c04, 0x04130eee, 0x1c121008,   // is.fi.et_543 id.is.lt_332  is.et.fi_422 lt.hu.id_443
  0x010c0eee, 0x110e13a0, 0x08030ea0, 0x110e0fa0,   // is.sv.en_422 et.is.ro_322  is.nl.no_322 lv.is.ro_322
  // [5ca0]
  0x0e3f0307, 0x01000904, 0x01530ea0, 0x170a110d,   // nl.af.is_432 pl.en.un_320  is.ht.en_322 ro.mk.sr_554
  0x10000f18, 0x211b040c, 0x1e1c1b02, 0x1a6b55ec,   // lv.lt.un_740 fi.tr.jw_543  tr.id.ms_222 rw.ceb.tl_644
  0x6400210e, 0x280903a4, 0x04536404, 0x645355a9,   // jw.lg.un_550 nl.pl.sw_433  lg.ht.fi_332 rw.ht.lg_544
  0x19000305, 0x162909a7, 0x251f02a0, 0x0a171005,   // nl.gl.un_330 pl.sl.hr_532  da.cy.eu_322 be.sr.mk_333
  // [5cb0]
  0x0a005307, 0x06531f5a, 0x0b000208, 0x28000319,   // ht.pt.un_420 cy.ht.de_553  da.es.un_430 nl.sw.un_750
  0x20000704, 0x28001812, 0x07000304, 0x27181e04,   // it.sq.un_320 ga.sw.un_640  nl.it.un_320 ms.ga.gd_332
  0x5300060d, 0x092917ec, 0x1f252b07, 0x281204a7,   // de.ht.un_540 sr.sl.pl_644  vi.eu.cy_432 fi.hu.sw_532
  0x131827a0, 0x18000d04, 0x0a171007, 0x282d0d0e,   // gd.ga.et_322 cs.ga.un_320  be.sr.mk_432 cs.sk.sw_555
  // [5cc0]
  0x2a256407, 0x07001804, 0x100b2807, 0x0600020d,   // lg.eu.mt_432 ga.it.un_320  sw.es.lt_432 da.de.un_540
  0x02121aee, 0x0a002a02, 0x31070b08, 0x0413100d,   // tl.hu.da_422 mt.pt.un_220  es.it.az_443 lt.et.fi_554
  0x12041305, 0x1200090d, 0x051f040c, 0x04001602,   // et.fi.hu_333 pl.hu.un_540  fi.cy.fr_543 hr.fi.un_220
  0x180a08a4, 0x12101a0c, 0x13180f07, 0x16102905,   // no.pt.ga_433 tl.lt.hu_543  lv.ga.et_432 sl.lt.hr_333
  // [5cd0]
  0x0d000c05, 0x00001337, 0x641a6b08, 0x1b1101a4,   // sv.cs.un_330 bh.un.un_B00  ceb.tl.lg_443 en.ro.tr_433
  0x3f000d04, 0x21001f21, 0x122a02ee, 0x3f0603a0,   // cs.af.un_320 cy.jw.un_860  da.mt.hu_422 nl.de.af_322
  0x0e0608a0, 0x0b000508, 0x1a29645a, 0x191605a0,   // no.de.is_322 fr.es.un_430  lg.sl.tl_553 fr.hr.gl_322
  0x1e0c08a0, 0x2a1e1c04, 0x0c000802, 0x10041708,   // no.sv.ms_322 id.ms.mt_332  no.sv.un_220 sr.ru.be_443
  // [5ce0]
  0x200c0605, 0x11282512, 0x030625a0, 0x03211c07,   // de.sv.sq_333 eu.sw.ro_654  eu.de.nl_322 id.jw.nl_432
  0x040306ad, 0x201b060c, 0x0c1b08a4, 0x0400281b,   // de.nl.fi_643 de.tr.sq_543  no.tr.sv_433 sw.fi.un_770
  0x030c200c, 0x2a272302, 0x020106a0, 0x1008040e,   // sq.sv.nl_543 ca.gd.mt_222  de.en.da_322 ru.uk.be_555
  0x13182708, 0x0e3f06a0, 0x170a1002, 0x0603110c,   // gd.ga.et_443 de.af.is_322  be.mk.sr_222 ro.nl.de_543
  // [5cf0]
  0x0c0623a0, 0x020608a4, 0x06023fa7, 0x0d000e12,   // ca.de.sv_322 no.de.da_433  af.da.de_532 is.cs.un_640
  0x20000e12, 0x0200061b, 0x080e06a0, 0x25000607,   // is.sq.un_640 de.da.un_770  de.is.no_322 de.eu.un_420
  0x23000320, 0x182723ad, 0x12211807, 0x21001905,   // nl.ca.un_850 ca.gd.ga_643  ar.fa.ur_432 gl.jw.un_330
  0x0c1f1008, 0x20083f04, 0x23001023, 0x06000c18,   // lt.cy.sv_443 af.no.sq_332  lt.ca.un_880 sv.de.un_740
  // [5d00]
  0x3f000404, 0x03250605, 0x281a6b08, 0x093f10a4,   // fi.af.un_320 de.eu.nl_333  ceb.tl.sw_443 lt.af.pl_433
  0x0a230709, 0x10001f05, 0x21001a18, 0x080a040c,   // it.ca.pt_444 cy.lt.un_330  tl.jw.un_740 ru.mk.uk_543
  0x642809ec, 0x273f0313, 0x28211c04, 0x1c2128ee,   // pl.sw.lg_644 nl.af.gd_665  id.jw.sw_332 sw.jw.id_422
  0x21640907, 0x0902100c, 0x09002107, 0x3f001f2a,   // pl.lg.jw_432 lt.da.pl_543  jw.pl.un_420 cy.af.un_970
  // [5d10]
  0x3f1f100c, 0x6400280d, 0x17160fac, 0x1f0110ee,   // lt.cy.af_543 sw.lg.un_540  lv.hr.sr_632 lt.en.cy_422
  0x230a0ea9, 0x1a002109, 0x3f002307, 0x53216bee,   // is.pt.ca_544 jw.tl.un_440  ca.af.un_420 ceb.jw.ht_422
  0x23000e04, 0x19071207, 0x0e2a0b08, 0x1b0f1012,   // is.ca.un_320 hu.it.gl_432  es.mt.is_443 lt.lv.tr_654
  0x171b1604, 0x1a0e12a6, 0x6e6b2104, 0x10072d12,   // hr.tr.sr_332 hu.is.tl_521  jw.ceb.blu_332 sk.it.lt_654
  // [5d20]
  0x190e0aee, 0x186b1305, 0x55292d02, 0x5319280b,   // pt.is.gl_422 et.ceb.ga_333  sk.sl.rw_222 sw.gl.ht_542
  0x130b0404, 0x6b111aa4, 0x1a000e19, 0x0800190d,   // fi.es.et_332 tl.ro.ceb_433  is.tl.un_750 gl.no.un_540
  0x20001f12, 0x082a010c, 0x04641308, 0x1a006e07,   // cy.sq.un_640 en.mt.no_543  et.lg.fi_443 blu.tl.un_420
  0x0f000807, 0x6b0301ee, 0x132a6404, 0x29000809,   // no.lv.un_420 en.nl.ceb_422  lg.mt.et_332 no.sl.un_440
  // [5d30]
  0x081a6b13, 0x0a00280c, 0x6400040e, 0x0400641a,   // ceb.tl.no_665 sw.pt.un_530  fi.lg.un_550 lg.fi.un_760
  0x0a000b13, 0x0b18530c, 0x645513af, 0x1f2305a0,   // es.pt.un_650 ht.ga.es_543  et.rw.lg_655 fr.ca.cy_322
  0x19230a55, 0x6b1a1313, 0x13081b14, 0x2a000721,   // pt.ca.gl_442 et.tl.ceb_665  tr.no.et_666 it.mt.un_860
  0x0c000e22, 0x0b1a6b60, 0x5500280b, 0x2a556405,   // is.sv.un_870 ceb.tl.es_664  sw.rw.un_520 lg.rw.mt_333
  // [5d40]
  0x06003f09, 0x27061f07, 0x5513290c, 0x2b003f04,   // af.de.un_440 cy.de.gd_432  sl.et.rw_543 af.vi.un_320
  0x03006414, 0x1a190b08, 0x1a000412, 0x642804a9,   // lg.nl.un_660 es.gl.tl_443  fi.tl.un_640 fi.sw.lg_544
  0x23002502, 0x046413a9, 0x04136408, 0x1f000805,   // eu.ca.un_220 et.lg.fi_544  lg.et.fi_443 no.cy.un_330
  0x033f1f07, 0x25271104, 0x3f061fa4, 0x12001023,   // cy.af.nl_432 ro.gd.eu_332  cy.de.af_433 lt.hu.un_880
  // [5d50]
  0x03002d02, 0x1210010c, 0x112520a4, 0x04001220,   // sk.nl.un_220 en.lt.hu_543  sq.eu.ro_433 hu.fi.un_850
  0x20002113, 0x1c0c25ad, 0x2b006402, 0x04071755,   // jw.sq.un_650 eu.sv.id_643  lg.vi.un_220 sr.bg.ru_442
  0x21101c0d, 0x230a1007, 0x050601a4, 0x091c0da0,   // id.lt.jw_554 lt.pt.ca_432  en.de.fr_433 ne.mr.hi_322
  0x0e1c2102, 0x12282004, 0x1a282007, 0x18000121,   // jw.id.is_222 sq.sw.hu_332  sq.sw.tl_432 en.ga.un_860
  // [5d60]
  0x3f250b55, 0x1e001007, 0x0416130c, 0x1a0855a0,   // es.eu.af_442 lt.ms.un_420  et.hr.fi_543 rw.no.tl_322
  0x6e002808, 0x1c212311, 0x116e2004, 0x28000a04,   // sw.blu.un_430 ca.jw.id_653  sq.blu.ro_332 pt.sw.un_320
  0x0f2820a0, 0x211c10a7, 0x11001611, 0x18200107,   // sq.sw.lv_322 lt.id.jw_532  hr.ro.un_630 en.sq.ga_432
  0x04006e04, 0x20005504, 0x05001802, 0x1c271e07,   // blu.fi.un_320 rw.sq.un_320  ga.fr.un_220 ms.gd.id_432
  // [5d70]
  0x0b2a230c, 0x31005521, 0x291c1ea4, 0x1c002b0c,   // ca.mt.es_543 rw.az.un_860  ms.id.sl_433 vi.id.un_530
  0x551c2855, 0x19641fa6, 0x20170808, 0x1a2555ec,   // sw.id.rw_442 cy.lg.gl_521  no.sr.sq_443 rw.eu.tl_644
  0x6b2b280c, 0x1b18210c, 0x211f53ee, 0x0a0701a4,   // sw.vi.ceb_543 jw.ga.tr_543  ht.cy.jw_422 en.it.pt_433
  0x200855a7, 0x055528a0, 0x64001c08, 0x2800200e,   // rw.no.sq_532 sw.rw.fr_322  id.lg.un_430 sq.sw.un_550
  // [5d80]
  0x10002002, 0x31001709, 0x06000504, 0x2a001f12,   // sq.lt.un_220 sr.az.un_440  fr.de.un_320 cy.mt.un_640
  0x10211f04, 0x17002d08, 0x11551aa9, 0x10132013,   // cy.jw.lt_332 sk.sr.un_430  tl.rw.ro_544 sq.et.lt_665
  0x08040a07, 0x09003f02, 0x23000b0b, 0x0b002319,   // mk.ru.uk_432 af.pl.un_220  es.ca.un_520 ca.es.un_750
  0x6b190107, 0x01093fa4, 0x08030ea4, 0x020c0e08,   // en.gl.ceb_432 af.pl.en_433  is.nl.no_433 is.sv.da_443
  // [5d90]
  0x100407ee, 0x0600040d, 0x171603ee, 0x08001219,   // bg.ru.be_422 fi.de.un_540  nl.hr.sr_422 hu.no.un_750
  0x5318270b, 0x3f0c08a4, 0x270618ac, 0x063f0e08,   // gd.ga.ht_542 no.sv.af_433  ga.de.gd_632 is.af.de_443
  0x0a002704, 0x110a0708, 0x230225ec, 0x0c1a3f11,   // gd.pt.un_320 bg.mk.ro_443  eu.da.ca_644 af.tl.sv_653
  0x0e3f1004, 0x041c25a7, 0x01190e04, 0x18000e0d,   // lt.af.is_332 eu.id.fi_532  is.gl.en_332 is.ga.un_540
  // [5da0]
  0x03080608, 0x060325ee, 0x0d005304, 0x033f0ea4,   // de.no.nl_443 eu.nl.de_422  ht.cs.un_320 is.af.nl_433
  0x1a000e09, 0x2b001008, 0x1a1e1c05, 0x130d095a,   // is.tl.un_440 lt.vi.un_430  id.ms.tl_333 hi.ne.bh_553
  0x0408070e, 0x11000809, 0x2d200d04, 0x1300200b,   // bg.uk.ru_555 uk.ro.un_440  cs.sq.sk_332 sq.et.un_520
  0x12311b5a, 0x1716310c, 0x556428ac, 0x08022507,   // tr.az.hu_553 az.hr.sr_543  sw.lg.rw_632 eu.da.no_432
  // [5db0]
  0x1c00210c, 0x041a0f08, 0x0f2510ad, 0x040910ec,   // jw.id.un_530 lv.tl.fi_443  lt.eu.lv_643 lt.pl.fi_644
  0x6b0604a4, 0x04130e08, 0x250c02a0, 0x08021005,   // fi.de.ceb_433 is.et.fi_443  da.sv.eu_322 lt.da.no_333
  0x2b001f05, 0x17163102, 0x28551e0b, 0x1c0312ee,   // cy.vi.un_330 az.hr.sr_222  ms.rw.sw_542 hu.nl.id_422
  0x060f2108, 0x282b21a4, 0x17040855, 0x64285508,   // jw.lv.de_443 jw.vi.sw_433  uk.ru.sr_442 rw.sw.lg_443
  // [5dc0]
  0x1f1b1214, 0x01182004, 0x2b215504, 0x1c091312,   // hu.tr.cy_666 sq.ga.en_332  rw.jw.vi_332 bh.hi.mr_654
  0x53130205, 0x10640f55, 0x171653ad, 0x03110604,   // da.et.ht_333 lv.lg.lt_442  ht.hr.sr_643 de.ro.nl_332
  0x0b2704a6, 0x110a04a4, 0x53210fec, 0x036455ad,   // fi.gd.es_521 ru.mk.ro_433  lv.jw.ht_644 rw.lg.nl_643
  0x17033f04, 0x6b0f1011, 0x282721ee, 0x2b005302,   // af.nl.sr_332 lt.lv.ceb_653  jw.gd.sw_422 ht.vi.un_220
  // [5dd0]
  0x1923270c, 0x5521640c, 0x276b18ad, 0x23071f07,   // gd.ca.gl_543 lg.jw.rw_543  ga.ceb.gd_643 cy.it.ca_432
  0x13060408, 0x2000530c, 0x5564080b, 0x0b0828a4,   // fi.de.et_443 ht.sq.un_530  no.lg.rw_542 sw.no.es_433
  0x1600170b, 0x0900080d, 0x21002821, 0x28095507,   // sr.hr.un_520 no.pl.un_540  sw.jw.un_860 rw.pl.sw_432
  0x12000521, 0x28002522, 0x2300530c, 0x6b001a04,   // fr.hu.un_860 eu.sw.un_870  ht.ca.un_530 tl.ceb.un_320
  // [5de0]
  0x28211aee, 0x18000914, 0x536b0107, 0x211a6405,   // tl.jw.sw_422 pl.ga.un_660  en.ceb.ht_432 lg.tl.jw_333
  0x10200302, 0x291e1c08, 0x13001119, 0x160d2955,   // nl.sq.lt_222 id.ms.sl_443  ro.et.un_750 sl.cs.hr_442
  0x18120911, 0x07000423, 0x286b64ad, 0x641328ee,   // pl.hu.ga_653 ru.bg.un_880  lg.ceb.sw_643 sw.et.lg_422
  0x1e1a28ad, 0x0d251007, 0x556b2802, 0x121013a0,   // sw.tl.ms_643 lt.eu.cs_432  sw.ceb.rw_222 et.lt.hu_322
  // [5df0]
  0x110721ec, 0x2a0e1bec, 0x6b0f6e55, 0x06021b0c,   // jw.it.ro_644 tr.is.mt_644  blu.lv.ceb_442 tr.da.de_543
  0x08130207, 0x021a5507, 0x1b2a2314, 0x0e311f12,   // da.et.no_432 rw.tl.da_432  ca.mt.tr_666 cy.az.is_654
  0x1c211aad, 0x53080cad, 0x21205513, 0x0c083faf,   // tl.jw.id_643 sv.no.ht_643  rw.sq.jw_665 af.no.sv_655
  0x0c0220ad, 0x64000108, 0x532009a4, 0x13091112,   // sq.da.sv_643 en.lg.un_430  pl.sq.ht_433 ro.pl.et_654
  // [5e00]
  0x645525ad, 0x09001119, 0x64000e12, 0x55002509,   // eu.rw.lg_643 ro.pl.un_750  is.lg.un_640 eu.rw.un_440
  0x0a170409, 0x2500020e, 0x1b001202, 0x0b03060c,   // ru.sr.mk_444 da.eu.un_550  hu.tr.un_220 de.nl.es_543
  0x53040cee, 0x2500550e, 0x11081012, 0x20000a23,   // sv.fi.ht_422 rw.eu.un_550  be.uk.ro_654 pt.sq.un_880
  0x1000070d, 0x1e061204, 0x1f2b0713, 0x17001005,   // bg.be.un_540 hu.de.ms_332  it.vi.cy_665 lt.sr.un_330
  // [5e10]
  0x1f2008a0, 0x01285512, 0x531b2504, 0x1200041a,   // no.sq.cy_322 rw.sw.en_654  eu.tr.ht_332 fi.hu.un_760
  0x21202507, 0x550802a9, 0x0417110b, 0x18001a0b,   // eu.sq.jw_432 da.no.rw_544  ro.sr.ru_542 tl.ga.un_520
  0x3f6e1312, 0x1900070c, 0x1e280755, 0x032806ec,   // et.blu.af_654 it.gl.un_530  it.sw.ms_442 de.sw.nl_644
  0x3f136e02, 0x2d1001a0, 0x1107270c, 0x6b00550e,   // blu.et.af_222 en.lt.sk_322  gd.it.ro_543 rw.ceb.un_550
  // [5e20]
  0x1a1028ad, 0x2700061a, 0x213f0307, 0x09002813,   // sw.lt.tl_643 de.gd.un_760  nl.af.jw_432 sw.pl.un_650
  0x28000d12, 0x08100a07, 0x28070513, 0x276b07ec,   // cs.sw.un_640 mk.be.uk_432  fr.it.sw_665 it.ceb.gd_644
  0x285507a4, 0x130823a4, 0x64132308, 0x1c5521a4,   // it.rw.sw_433 ca.no.et_433  ca.et.lg_443 jw.rw.id_433
  0x211155a9, 0x291753a9, 0x033f6e04, 0x01250f11,   // rw.ro.jw_544 ht.sr.sl_544  blu.af.nl_332 lv.eu.en_653
  // [5e30]
  0x1200030d, 0x6429550b, 0x03136ea0, 0x09005304,   // nl.hu.un_540 rw.sl.lg_542  blu.et.nl_322 ht.pl.un_320
  0x20171614, 0x072853ee, 0x160a0ba0, 0x0a6b070c,   // hr.sr.sq_666 ht.sw.it_422  es.pt.hr_322 it.ceb.pt_543
  0x3f2707ec, 0x171653ec, 0x25001107, 0x27060312,   // it.gd.af_644 ht.hr.sr_644  ro.eu.un_420 nl.de.gd_654
  0x0700280d, 0x282706a9, 0x311b6b13, 0x16552955,   // sw.it.un_540 de.gd.sw_544  ceb.tr.az_665 sl.rw.hr_442
  // [5e40]
  0x3117160d, 0x171653a4, 0x162d0d09, 0x28251e0c,   // hr.sr.az_554 ht.hr.sr_433  cs.sk.hr_444 ms.eu.sw_543
  0x293f160c, 0x53276407, 0x21001e0c, 0x162d29a7,   // hr.af.sl_543 lg.gd.ht_432  ms.jw.un_530 sl.sk.hr_532
  0x2a000f12, 0x030553a7, 0x10110704, 0x02000c12,   // lv.mt.un_640 ht.fr.nl_532  it.ro.lt_332 sv.da.un_640
  0x020c2107, 0x07001312, 0x17160ea0, 0x211b1c12,   // jw.sv.da_432 et.it.un_640  is.hr.sr_322 id.tr.jw_654
  // [5e50]
  0x25002902, 0x16291712, 0x0a1710ac, 0x102d290d,   // sl.eu.un_220 sr.sl.hr_654  be.sr.mk_632 sl.sk.lt_554
  0x27016ba0, 0x03001e02, 0x0c021f04, 0x18121007,   // ceb.en.gd_322 ms.nl.un_220  cy.da.sv_332 lt.hu.ga_432
  0x2a1c1f04, 0x080c02ec, 0x061029a4, 0x530f01a0,   // cy.id.mt_332 da.sv.no_644  sl.lt.de_433 en.lv.ht_322
  0x21000805, 0x64002904, 0x01200204, 0x1a041ea7,   // no.jw.un_330 sl.lg.un_320  da.sq.en_332 ms.fi.tl_532
  // [5e60]
  0x53171008, 0x02001902, 0x230501a0, 0x061b3102,   // lt.sr.ht_443 gl.da.un_220  en.fr.ca_322 az.tr.de_222
  0x0a0410a9, 0x1b0e25ad, 0x551a6ba4, 0x641a5509,   // be.ru.mk_544 eu.is.tr_643  ceb.tl.rw_433 rw.tl.lg_444
  0x070e31a0, 0x18000d11, 0x1a5564ad, 0x1720530c,   // az.is.it_322 cs.ga.un_630  lg.rw.tl_643 ht.sq.sr_543
  0x13001204, 0x53552108, 0x55000f1a, 0x05192304,   // hu.et.un_320 jw.rw.ht_443  lv.rw.un_760 ca.gl.fr_332
  // [5e70]
  0x041f100c, 0x642a2104, 0x64551aad, 0x1a642114,   // lt.cy.fi_543 jw.mt.lg_332  tl.rw.lg_643 jw.lg.tl_666
  0x53002802, 0x03012ba0, 0x03216404, 0x040c2505,   // sw.ht.un_220 vi.en.nl_322  lg.jw.nl_332 eu.sv.fi_333
  0x211f0d02, 0x10120405, 0x0804115a, 0x0200280d,   // cs.cy.jw_222 fi.hu.lt_333  ro.ru.uk_553 sw.da.un_540
  0x64280807, 0x2502080c, 0x03642aa7, 0x12000b0e,   // no.sw.lg_432 no.da.eu_543  mt.lg.nl_532 es.hu.un_550
  // [5e80]
  0x271a01ad, 0x23200c08, 0x06311b11, 0x0e211a0c,   // en.tl.gd_643 sv.sq.ca_443  tr.az.de_653 tl.jw.is_543
  0x230210a7, 0x08252307, 0x11642508, 0x0f000104,   // lt.da.ca_532 ca.eu.no_432  eu.lg.ro_443 en.lv.un_320
  0x230b11ee, 0x10081702, 0x64211a09, 0x17000d02,   // ro.es.ca_422 sr.uk.be_222  tl.jw.lg_444 cs.sr.un_220
  0x211a6b0c, 0x02081212, 0x012b5504, 0x10250605,   // ceb.tl.jw_543 hu.no.da_654  rw.vi.en_332 de.eu.lt_333
  // [5e90]
  0x640c02a4, 0x04211f0c, 0x25060fad, 0x0e1809ad,   // da.sv.lg_433 cy.jw.fi_543  lv.de.eu_643 pl.ga.is_643
  0x2800270c, 0x0e061312, 0x2b1b0107, 0x28136408,   // gd.sw.un_530 et.de.is_654  en.tr.vi_432 lg.et.sw_443
  0x08033f04, 0x531e1c02, 0x08316407, 0x100f0e08,   // af.nl.no_332 id.ms.ht_222  lg.az.no_432 is.lv.lt_443
  0x18001704, 0x6b000619, 0x12230ba4, 0x17162005,   // sr.ga.un_320 de.ceb.un_750  es.ca.hu_433 sq.hr.sr_333
  // [5ea0]
  0x11002a05, 0x0f040205, 0x0400132c, 0x05001e04,   // mt.ro.un_330 da.fi.lv_333  et.fi.un_990 ms.fr.un_320
  0x096b1a0b, 0x18062714, 0x27005307, 0x1a6b0108,   // tl.ceb.pl_542 gd.de.ga_666  ht.gd.un_420 en.ceb.tl_443
  0x27002b13, 0x1f09065a, 0x27000121, 0x6b06010c,   // vi.gd.un_650 de.pl.cy_553  en.gd.un_860 en.de.ceb_543
  0x122520a6, 0x2b532707, 0x1f062bee, 0x2b005308,   // sq.eu.hu_521 gd.ht.vi_432  vi.de.cy_422 ht.vi.un_430
  // [5eb0]
  0x13211aac, 0x06531f11, 0x0b002707, 0x282120a0,   // tl.jw.et_632 cy.ht.de_653  gd.es.un_420 sq.jw.sw_322
  0x07552aa0, 0x6b1a110c, 0x0e001907, 0x17001120,   // mt.rw.it_322 ro.tl.ceb_543  gl.is.un_420 ro.sr.un_850
  0x03002504, 0x08190b5a, 0x05530ca0, 0x0f00640c,   // eu.nl.un_320 es.gl.no_553  sv.ht.fr_322 lg.lv.un_530
  0x020308a9, 0x6e6b64a0, 0x0a00112b, 0x02080411,   // no.nl.da_544 lg.ceb.blu_322  ro.pt.un_980 fi.no.da_653
  // [5ec0]
  0x16202904, 0x030802ee, 0x030c02a7, 0x251b0713,   // sl.sq.hr_332 da.no.nl_422  da.sv.nl_532 it.tr.eu_665
  0x020e0607, 0x100d1607, 0x060c02a7, 0x112d0ba0,   // de.is.da_432 hr.cs.lt_432  da.sv.de_532 es.sk.ro_322
  0x64070407, 0x19000204, 0x08001119, 0x3f00291a,   // fi.it.lg_432 da.gl.un_320  ro.uk.un_750 sl.af.un_760
  0x212a6b07, 0x12033f02, 0x6b070113, 0x0e000419,   // ceb.mt.jw_432 af.nl.hu_222  en.it.ceb_665 fi.is.un_750
  // [5ed0]
  0x29161204, 0x0c190b55, 0x020c0308, 0x08001304,   // hu.hr.sl_332 es.gl.sv_442  nl.sv.da_443 et.no.un_320
  0x080206af, 0x17311f07, 0x1c0c020c, 0x1e2d0d08,   // de.da.no_655 cy.az.sr_432  da.sv.id_543 cs.sk.ms_443
  0x030608a9, 0x16291704, 0x291617ac, 0x020c04a7,   // no.de.nl_544 sr.sl.hr_332  sr.hr.sl_632 fi.sv.da_532
  0x041e1cee, 0x200c12af, 0x3f2a06a0, 0x030b20ee,   // id.ms.fi_422 hu.sv.sq_655  de.mt.af_322 sq.es.nl_422
  // [5ee0]
  0x20000314, 0x201603ad, 0x291703ad, 0x20000309,   // nl.sq.un_660 nl.hr.sq_643  nl.sr.sl_643 nl.sq.un_440
  0x23002512, 0x27001108, 0x08020da6, 0x1300060c,   // eu.ca.un_640 ro.gd.un_430  cs.da.no_521 de.et.un_530
  0x1c002519, 0x080229af, 0x21132a0c, 0x2028010c,   // eu.id.un_750 sl.da.no_655  mt.et.jw_543 en.sw.sq_543
  0x04000c02, 0x0807100c, 0x552801a4, 0x210810a4,   // sv.fi.un_220 be.bg.uk_543  en.sw.rw_433 lt.no.jw_433
  // [5ef0]
  0x205528af, 0x2000031b, 0x0f1310a9, 0x3f00061a,   // sw.rw.sq_655 nl.sq.un_770  lt.et.lv_544 de.af.un_760
  0x2028550e, 0x2055280c, 0x0300201a, 0x20000313,   // rw.sw.sq_555 sw.rw.sq_543  sq.nl.un_760 nl.sq.un_650
  0x2a202813, 0x18085307, 0x28101a05, 0x28001c02,   // sw.sq.mt_665 ht.no.ga_432  tl.lt.sw_333 id.sw.un_220
  0x20552811, 0x0b006402, 0x120a06a7, 0x11211a0b,   // sw.rw.sq_653 lg.es.un_220  de.pt.hu_532 tl.jw.ro_542
  // [5f00]
  0x0b070107, 0x0f1027a4, 0x64002a02, 0x312855ad,   // en.it.es_432 gd.lt.lv_433  mt.lg.un_220 rw.sw.az_643
  0x2909170e, 0x1f00100c, 0x230213a6, 0x1a106b07,   // sr.pl.sl_555 lt.cy.un_530  et.da.ca_521 ceb.lt.tl_432
  0x0e1e1c08, 0x20552812, 0x0408070c, 0x1c000a04,   // id.ms.is_443 sw.rw.sq_654  bg.uk.ru_543 pt.id.un_320
  0x552820af, 0x010910ee, 0x0b010609, 0x11002808,   // sq.sw.rw_655 lt.pl.en_422  de.en.es_444 sw.ro.un_430
  // [5f10]
  0x076b20a0, 0x04070a0d, 0x1c001319, 0x08170408,   // sq.ceb.it_322 mk.bg.ru_554  bh.mr.un_750 ru.sr.uk_443
  0x07170a5a, 0x011f2804, 0x1b001213, 0x21002002,   // mk.sr.bg_553 sw.cy.en_332  hu.tr.un_650 sq.jw.un_220
  0x18000604, 0x12042a12, 0x0f000207, 0x16000b02,   // de.ga.un_320 mt.fi.hu_654  da.lv.un_420 es.hr.un_220
  0x16002a13, 0x295312a0, 0x2a070509, 0x2d2b1107,   // mt.hr.un_650 hu.ht.sl_322  fr.it.mt_444 ro.vi.sk_432
  // [5f20]
  0x16206ba0, 0x01281fad, 0x3f000914, 0x07010602,   // ceb.sq.hr_322 cy.sw.en_643  pl.af.un_660 de.en.it_222
  0x06130c08, 0x0c001321, 0x06000c22, 0x251128ad,   // sv.et.de_443 et.sv.un_860  sv.de.un_870 sw.ro.eu_643
  0x23190aee, 0x55286409, 0x55000913, 0x01090d0d,   // pt.gl.ca_422 lg.sw.rw_444  pl.rw.un_650 cs.pl.en_554
  0x170804a9, 0x09005514, 0x13000d0e, 0x2d1716a7,   // ru.uk.sr_544 rw.pl.un_660  ne.bh.un_550 hr.sr.sk_532
  // [5f30]
  0x1c311b08, 0x06130412, 0x55000912, 0x06040caf,   // tr.az.id_443 fi.et.de_654  pl.rw.un_640 sv.fi.de_655
  0x28002019, 0x2d0d12ac, 0x08026ba9, 0x0500280b,   // sq.sw.un_750 hu.cs.sk_632  ceb.da.no_544 sw.fr.un_520
  0x2a000507, 0x0c0613ee, 0x551e1ca9, 0x280810a4,   // fr.mt.un_420 et.de.sv_422  id.ms.rw_544 lt.no.sw_433
  0x13000c13, 0x19060ea0, 0x11030507, 0x0e035509,   // sv.et.un_650 is.de.gl_322  fr.nl.ro_432 rw.nl.is_444
  // [5f40]
  0x311b0a0c, 0x551a2805, 0x29161311, 0x1c2821a7,   // pt.tr.az_543 sw.tl.rw_333  et.hr.sl_653 jw.sw.id_532
  0x11171604, 0x1a2855ee, 0x0f64280c, 0x0d006404,   // hr.sr.ro_332 rw.sw.tl_422  sw.lg.lv_543 lg.cs.un_320
  0x01271808, 0x23000808, 0x05002a02, 0x01643fa7,   // ga.gd.en_443 no.ca.un_430  mt.fr.un_220 af.lg.en_532
  0x190a2305, 0x211955ee, 0x170410a0, 0x10641e0b,   // ca.pt.gl_333 rw.gl.jw_422  be.ru.sr_322 ms.lg.lt_542
  // [5f50]
  0x02072a55, 0x311b13ec, 0x161729a7, 0x2855110b,   // mt.it.da_442 et.tr.az_644  sl.sr.hr_532 ro.rw.sw_542
  0x2b6b0107, 0x0b005508, 0x551107a6, 0x55642004,   // en.ceb.vi_432 rw.es.un_430  it.ro.rw_521 sq.lg.rw_332
  0x020f105a, 0x081104ec, 0x23091ca0, 0x532555a4,   // lt.lv.da_553 ru.ro.uk_644  id.pl.ca_322 rw.eu.ht_433
  0x27000f07, 0x16102904, 0x0a000f02, 0x530a03a0,   // lv.gd.un_420 sl.lt.hr_332  lv.pt.un_220 nl.pt.ht_322
  // [5f60]
  0x53051aa0, 0x2a075511, 0x0a041709, 0x291310af,   // tl.fr.ht_322 rw.it.mt_653  sr.ru.mk_444 lt.et.sl_655
  0x641e1c14, 0x071f10a4, 0x052906ee, 0x0f070507,   // id.ms.lg_666 lt.cy.it_433  de.sl.fr_422 fr.it.lv_432
  0x55131a55, 0x17255507, 0x0b18020c, 0x190a07af,   // tl.et.rw_442 rw.eu.sr_432  da.ga.es_543 it.pt.gl_655
  0x01552808, 0x3f030207, 0x08070402, 0x20251202,   // sw.rw.en_443 da.nl.af_432  ru.bg.uk_222 hu.eu.sq_222
  // [5f70]
  0x2d0d180c, 0x060308a4, 0x010507a4, 0x1b2d27a0,   // ga.cs.sk_543 no.nl.de_433  it.fr.en_433 gd.sk.tr_322
  0x116b6409, 0x10050707, 0x0f0710af, 0x04081704,   // lg.ceb.ro_444 it.fr.lt_432  lt.it.lv_655 sr.uk.ru_332
  0x0a1a2904, 0x0a052107, 0x070525a4, 0x110701a0,   // sl.tl.pt_332 jw.fr.pt_432  eu.fr.it_433 en.it.ro_322
  0x061304ad, 0x13060c0c, 0x07025512, 0x130c04a4,   // fi.et.de_643 sv.de.et_543  rw.da.it_654 fi.sv.et_433
  // [5f80]
  0x1b130407, 0x1013020c, 0x02081c0d, 0x08171604,   // fi.et.tr_432 da.et.lt_543  id.no.da_554 hr.sr.no_332
  0x3f030612, 0x022701a0, 0x010c0405, 0x53002313,   // de.nl.af_654 en.gd.da_322  fi.sv.en_333 ca.ht.un_650
  0x0b0a23a6, 0x082d0d04, 0x12001822, 0x0d122d5a,   // ca.pt.es_521 cs.sk.no_332  ar.ur.un_870 sk.hu.cs_553
  0x216e6ba0, 0x1e002109, 0x1c190602, 0x2b18010c,   // ceb.blu.jw_322 jw.ms.un_440  de.gl.id_222 en.ga.vi_543
  // [5f90]
  0x2d002009, 0x09003f0e, 0x2d0d21ee, 0x0200100c,   // sq.sk.un_440 af.pl.un_550  jw.cs.sk_422 lt.da.un_530
  0x16292013, 0x08001b12, 0x28052302, 0x0b1923a0,   // sq.sl.hr_665 tr.no.un_640  ca.fr.sw_222 ca.gl.es_322
  0x31000e05, 0x0f1304ad, 0x25000f14, 0x2500100c,   // is.az.un_330 fi.et.lv_643  lv.eu.un_660 lt.eu.un_530
  0x2812250c, 0x28211e07, 0x190b2505, 0x056b1aaf,   // eu.hu.sw_543 ms.jw.sw_432  eu.es.gl_333 tl.ceb.fr_655
  // [5fa0]
  0x1a001e1a, 0x11000a13, 0x0a00200e, 0x2900200d,   // ms.tl.un_760 pt.ro.un_650  sq.pt.un_550 sq.sl.un_540
  0x202d0412, 0x10040705, 0x6b101aec, 0x05002105,   // fi.sk.sq_654 bg.ru.be_333  tl.lt.ceb_644 jw.fr.un_330
  0x016411a0, 0x1f002708, 0x13002817, 0x042917a0,   // ro.lg.en_322 gd.cy.un_430  sw.et.un_730 sr.sl.fi_322
  0x1b0601a4, 0x25001a02, 0x1f5325a4, 0x0e006b23,   // en.de.tr_433 tl.eu.un_220  eu.ht.cy_433 ceb.is.un_880
  // [5fb0]
  0x10040f08, 0x311b1e0c, 0x04311bad, 0x1a556408,   // lv.fi.lt_443 ms.tr.az_543  tr.az.fi_643 lg.rw.tl_443
  0x06010504, 0x0e0407ec, 0x2325190c, 0x0f130c0c,   // fr.en.de_332 it.fi.is_644  gl.eu.ca_543 sv.et.lv_543
  0x0704080e, 0x18190a0c, 0x0c12090b, 0x210c2307,   // uk.ru.bg_555 pt.gl.ga_543  pl.hu.sv_542 ca.sv.jw_432
  0x130408a9, 0x0f6b1a12, 0x1e1c2aee, 0x250a19a9,   // no.fi.et_544 tl.ceb.lv_654  mt.id.ms_422 gl.pt.eu_544
  // [5fc0]
  0x08041104, 0x311e1b09, 0x13003107, 0x0e3f0cee,   // ro.ru.uk_332 tr.ms.az_444  az.et.un_420 sv.af.is_422
  0x640428af, 0x0207055a, 0x280920a4, 0x0d532d5a,   // sw.fi.lg_655 fr.it.da_553  sq.pl.sw_433 sk.ht.cs_553
  0x193f01a9, 0x290710ee, 0x28640a04, 0x110305a9,   // en.af.gl_544 lt.it.sl_422  pt.lg.sw_332 fr.nl.ro_544
  0x050601ad, 0x55002529, 0x271825ad, 0x10202307,   // en.de.fr_643 eu.rw.un_960  eu.ga.gd_643 ca.sq.lt_432
  // [5fd0]
  0x3f08020d, 0x20000a1a, 0x1a0701ac, 0x08065511,   // da.no.af_554 pt.sq.un_760  en.it.tl_632 rw.de.no_653
  0x1f182708, 0x12002a04, 0x083f060c, 0x27181102,   // gd.ga.cy_443 mt.hu.un_320  de.af.no_543 ro.ga.gd_222
  0x1b006405, 0x25001f23, 0x0625030c, 0x31090dec,   // lg.tr.un_330 cy.eu.un_880  nl.eu.de_543 cs.pl.az_644
  0x2718050c, 0x28212012, 0x1700291b, 0x3f0308a4,   // fr.ga.gd_543 sq.jw.sw_654  sl.sr.un_770 no.nl.af_433
  // [5fe0]
  0x051001a0, 0x190a0709, 0x060325a0, 0x06020811,   // en.lt.fr_322 it.pt.gl_444  eu.nl.de_322 no.da.de_653
  0x06001813, 0x281e1c09, 0x130206a9, 0x642510a7,   // ga.de.un_650 id.ms.sw_444  de.da.et_544 lt.eu.lg_532
  0x11001e1a, 0x18270d0c, 0x033f06a9, 0x07081213,   // ms.ro.un_760 cs.gd.ga_543  de.af.nl_544 hu.no.it_665
  0x0a04080d, 0x17080aaf, 0x25076408, 0x102718ad,   // uk.ru.mk_554 mk.uk.sr_655  lg.it.eu_443 ga.gd.lt_643
  // [5ff0]
  0x18190a08, 0x06036407, 0x28001c08, 0x02035312,   // pt.gl.ga_443 lg.nl.de_432  id.sw.un_430 ht.nl.da_654
  0x3f0306a9, 0x030608a4, 0x06026405, 0x17160209,   // de.nl.af_544 no.de.nl_433  lg.da.de_333 da.hr.sr_444
  0x05001f0c, 0x04001a09, 0x060d25ee, 0x2500030d,   // cy.fr.un_530 tl.fi.un_440  eu.cs.de_422 nl.eu.un_540
  0x17162d09, 0x060325ac, 0x036e1305, 0x060f3fa0,   // sk.hr.sr_444 eu.nl.de_632  et.blu.nl_333 af.lv.de_322

  // [6000]
  0x04000605, 0x13001a02, 0x1e285304, 0x3f006e19,   // de.fi.un_330 tl.et.un_220  ht.sw.ms_332 blu.af.un_750
  0x041328ee, 0x2d120d02, 0x17001109, 0x0a1117af,   // sw.et.fi_422 cs.hu.sk_222  ro.sr.un_440 sr.ro.mk_655
  0x163f2960, 0x0409080e, 0x12083f04, 0x2d002104,   // sl.af.hr_664 no.pl.fi_555  af.no.hu_332 jw.sk.un_320
  0x18001205, 0x640313a7, 0x3f130314, 0x3f0813a4,   // ur.ar.un_330 et.nl.lg_532  nl.et.af_666 et.no.af_433
  // [6010]
  0x1104170c, 0x2a002802, 0x23192809, 0x04002113,   // sr.ru.ro_543 sw.mt.un_220  sw.gl.ca_444 jw.fi.un_650
  0x29006e0b, 0x12002911, 0x0a001204, 0x091c1312,   // blu.sl.un_520 sl.hu.un_630  hu.pt.un_320 bh.mr.hi_654
  0x120820ee, 0x1b311108, 0x2d1c210e, 0x230e08ac,   // sq.no.hu_422 ro.az.tr_443  jw.id.sk_555 no.is.ca_632
  0x1a002808, 0x281b1c0c, 0x161304ad, 0x55282113,   // sw.tl.un_430 id.tr.sw_543  fi.et.hr_643 jw.sw.rw_665
  // [6020]
  0x28006413, 0x06122004, 0x2500200e, 0x060f0802,   // lg.sw.un_650 sq.hu.de_332  sq.eu.un_550 no.lv.de_222
  0x3f060204, 0x080223a0, 0x31190b02, 0x11190a08,   // da.de.af_332 ca.da.no_322  es.gl.az_222 pt.gl.ro_443
  0x060c0202, 0x02006407, 0x18001e04, 0x171628af,   // da.sv.de_222 lg.da.un_420  ms.ga.un_320 sw.hr.sr_655
  0x64282109, 0x55281fec, 0x1a5308a0, 0x00002a37,   // jw.sw.lg_444 cy.sw.rw_644  no.ht.tl_322 mt.un.un_B00
  // [6030]
  0x21001f22, 0x11041ca0, 0x102864af, 0x035505ee,   // cy.jw.un_870 id.fi.ro_322  lg.sw.lt_655 fr.rw.nl_422
  0x28000d02, 0x1328210c, 0x1c1210ad, 0x060e0807,   // cs.sw.un_220 jw.sw.et_543  lt.hu.id_643 no.is.de_432
  0x1a64555a, 0x08033fa0, 0x20100f60, 0x1e1c25a9,   // rw.lg.tl_553 af.nl.no_322  lv.lt.sq_664 eu.id.ms_544
  0x64100ea9, 0x1c212008, 0x55006b22, 0x0f3f0ca9,   // is.lt.lg_544 sq.jw.id_443  ceb.rw.un_870 sv.af.lv_544
  // [6040]
  0x020f0807, 0x1f000c04, 0x08190f07, 0x2d022012,   // no.lv.da_432 sv.cy.un_320  lv.gl.no_432 sq.da.sk_654
  0x021f0cee, 0x040e28af, 0x3f000c09, 0x131c0d09,   // sv.cy.da_422 sw.is.fi_655  sv.af.un_440 ne.mr.bh_444
  0x27000107, 0x53002105, 0x291216a0, 0x026b01ee,   // en.gd.un_420 jw.ht.un_330  hr.hu.sl_322 en.ceb.da_422
  0x0a050f07, 0x09001211, 0x10002507, 0x182b01a6,   // lv.fr.pt_432 hu.pl.un_630  eu.lt.un_420 en.vi.ga_521
  // [6050]
  0x12171609, 0x29001721, 0x0c216407, 0x1a000112,   // hr.sr.hu_444 sr.sl.un_860  lg.jw.sv_432 en.tl.un_640
  0x040a2507, 0x08110405, 0x1b2a21a4, 0x090229ad,   // eu.pt.fi_432 ru.ro.uk_333  jw.mt.tr_433 sl.da.pl_643
  0x170407a4, 0x093f01a0, 0x21001b08, 0x21121e0c,   // bg.ru.sr_433 en.af.pl_322  tr.jw.un_430 ms.hu.jw_543
  0x0d002909, 0x1e2d0d04, 0x12002d05, 0x2a6b01ee,   // sl.cs.un_440 cs.sk.ms_332  sk.hu.un_330 en.ceb.mt_422
  // [6060]
  0x0a100405, 0x2025040c, 0x211e1b0c, 0x082d25af,   // ru.be.mk_333 fi.eu.sq_543  tr.ms.jw_543 eu.sk.no_655
  0x16000907, 0x03001a0c, 0x121b25a4, 0x2b000718,   // pl.hr.un_420 tl.nl.un_530  eu.tr.hu_433 it.vi.un_740
  0x12311b04, 0x0a08110c, 0x0c6b0e0c, 0x29001619,   // tr.az.hu_332 ro.uk.mk_543  is.ceb.sv_543 hr.sl.un_750
  0x16092912, 0x3f1c1ea4, 0x08170a09, 0x04070aad,   // sl.pl.hr_654 ms.id.af_433  mk.sr.uk_444 mk.bg.ru_643
  // [6070]
  0x6b060c12, 0x0c080608, 0x211e1caf, 0x052704a7,   // sv.de.ceb_654 de.no.sv_443  id.ms.jw_655 fi.gd.fr_532
  0x55092812, 0x641e1c04, 0x0b050108, 0x12033f55,   // sw.pl.rw_654 id.ms.lg_332  en.fr.es_443 af.nl.hu_442
  0x033f6413, 0x033f06a0, 0x23100805, 0x551a1102,   // lg.af.nl_665 de.af.nl_322  no.lt.ca_333 ro.tl.rw_222
  0x2864090c, 0x6e00180d, 0x55252855, 0x211b3107,   // pl.lg.sw_543 ga.blu.un_540  sw.eu.rw_442 az.tr.jw_432
  // [6080]
  0x3f0613ee, 0x0d0e2d0d, 0x0a001022, 0x28005520,   // et.de.af_422 sk.is.cs_554  be.mk.un_870 rw.sw.un_850
  0x3f2164a0, 0x31041304, 0x292312a9, 0x12292304,   // lg.jw.af_322 et.fi.az_332  hu.ca.sl_544 ca.sl.hu_332
  0x122d0dec, 0x052d0d0d, 0x1f060eee, 0x1200090c,   // cs.sk.hu_644 cs.sk.fr_554  is.de.cy_422 pl.hu.un_530
  0x09130d04, 0x0e0c0a04, 0x0c006b14, 0x09000202,   // ne.bh.hi_332 pt.sv.is_332  ceb.sv.un_660 da.pl.un_220
  // [6090]
  0x6b000105, 0x2a000c07, 0x2d0208ad, 0x232d0d09,   // en.ceb.un_330 sv.mt.un_420  no.da.sk_643 cs.sk.ca_444
  0x13110da4, 0x2900230d, 0x13002702, 0x292312a7,   // cs.ro.et_433 ca.sl.un_540  gd.et.un_220 hu.ca.sl_532
  0x23121904, 0x09020eac, 0x190b2da0, 0x6b000c12,   // gl.hu.ca_332 is.da.pl_632  sk.es.gl_322 sv.ceb.un_640
  0x1b00100c, 0x08170c04, 0x5500110d, 0x0708170c,   // lt.tr.un_530 sv.sr.no_332  ro.rw.un_540 sr.uk.bg_543
  // [60a0]
  0x11252004, 0x0b0f0a07, 0x083101a0, 0x02040ca6,   // sq.eu.ro_332 pt.lv.es_432  en.az.no_322 sv.fi.da_521
  0x2d120e0c, 0x17071112, 0x530c0da0, 0x06171604,   // is.hu.sk_543 ro.bg.sr_654  cs.sv.ht_322 hr.sr.de_332
  0x16001722, 0x0f23010c, 0x052301af, 0x0f0501a4,   // sr.hr.un_870 en.ca.lv_543  en.ca.fr_655 en.fr.lv_433
  0x23002b08, 0x0600010e, 0x091355ee, 0x0a551105,   // vi.ca.un_430 en.de.un_550  rw.et.pl_422 ro.rw.pt_333
  // [60b0]
  0x041c1ea7, 0x310d16ee, 0x21001104, 0x1e1f1ca4,   // ms.id.fi_532 hr.cs.az_422  ro.jw.un_320 id.cy.ms_433
  0x64550607, 0x0c050f05, 0x0313040c, 0x0a211911,   // de.rw.lg_432 lv.fr.sv_333  fi.et.nl_543 gl.jw.pt_653
  0x6b1c5307, 0x13205302, 0x21082aaf, 0x2a000e19,   // ht.id.ceb_432 ht.sq.et_222  mt.no.jw_655 is.mt.un_750
  0x25211fa4, 0x013f02a0, 0x2a2107ee, 0x0e002a33,   // cy.jw.eu_433 da.af.en_322  it.jw.mt_422 mt.is.un_A70
  // [60c0]
  0x0f001b19, 0x3f031b04, 0x23210a05, 0x13271860,   // tr.lv.un_750 tr.nl.af_332  pt.jw.ca_333 ga.gd.et_664
  0x230a290c, 0x03233f04, 0x08023fec, 0x21641705,   // sl.pt.ca_543 af.ca.nl_332  af.da.no_644 sr.lg.jw_333
  0x190a2302, 0x6b310c04, 0x10205312, 0x012a0804,   // ca.pt.gl_222 sv.az.ceb_332  ht.sq.lt_654 no.mt.en_332
  0x1f002104, 0x01050fa4, 0x230f01a9, 0x0c1108a4,   // jw.cy.un_320 lv.fr.en_433  en.lv.ca_544 no.ro.sv_433
  // [60d0]
  0x180f010c, 0x08030107, 0x17000812, 0x641f550c,   // en.lv.ga_543 en.nl.no_432  uk.sr.un_640 rw.cy.lg_543
  0x1b000e04, 0x08290f08, 0x25000b09, 0x531921ee,   // is.tr.un_320 lv.sl.no_443  es.eu.un_440 jw.gl.ht_422
  0x29132107, 0x0e3f03a0, 0x031e1c04, 0x0e00272a,   // jw.et.sl_432 nl.af.is_322  id.ms.nl_332 gd.is.un_970
  0x07291614, 0x190b0ea4, 0x25033f0c, 0x0200200d,   // hr.sl.it_666 is.es.gl_433  af.nl.eu_543 sq.da.un_540
  // [60e0]
  0x080c53a7, 0x0818270d, 0x05033f07, 0x17002804,   // ht.sv.no_532 gd.ga.no_554  af.nl.fr_432 sw.sr.un_320
  0x2d2955a0, 0x64005305, 0x53013fa0, 0x10070a04,   // rw.sl.sk_322 ht.lg.un_330  af.en.ht_322 mk.bg.be_332
  0x5528640c, 0x08170a55, 0x17160d14, 0x1a286b60,   // lg.sw.rw_543 mk.sr.uk_442  cs.hr.sr_666 ceb.sw.tl_664
  0x20000512, 0x0900030d, 0x050b6e04, 0x28001b14,   // fr.sq.un_640 nl.pl.un_540  blu.es.fr_332 tr.sw.un_660
  // [60f0]
  0x3f032304, 0x08130411, 0x1b1110a4, 0x12000d1a,   // ca.nl.af_332 fi.et.no_653  lt.ro.tr_433 cs.hu.un_760
  0x113104a0, 0x05002d02, 0x2d120da6, 0x040e09af,   // fi.az.ro_322 sk.fr.un_220  cs.hu.sk_521 pl.is.fi_655
  0x100417a4, 0x11001004, 0x1a000607, 0x131c0d08,   // sr.ru.be_433 lt.ro.un_320  de.tl.un_420 ne.mr.bh_443
  0x1a1f25a6, 0x19000a08, 0x0c090304, 0x21000312,   // eu.cy.tl_521 pt.gl.un_430  nl.pl.sv_332 nl.jw.un_640
  // [6100]
  0x211205a0, 0x101b11a4, 0x1a6b2813, 0x20090305,   // fr.hu.jw_322 ro.tr.lt_433  sw.ceb.tl_665 nl.pl.sq_333
  0x00002b37, 0x05002305, 0x04311207, 0x12000d12,   // vi.un.un_B00 ca.fr.un_330  hu.az.fi_432 cs.hu.un_640
  0x1b1131a0, 0x2d200907, 0x19002308, 0x19090bad,   // az.ro.tr_322 pl.sq.sk_432  ca.gl.un_430 es.pl.gl_643
  0x100f1360, 0x110513ac, 0x131607a0, 0x3100200c,   // et.lv.lt_664 et.fr.ro_632  it.hr.et_322 sq.az.un_530
  // [6110]
  0x18122904, 0x55190b04, 0x1f29125a, 0x0d000408,   // sl.hu.ga_332 es.gl.rw_332  hu.sl.cy_553 fi.cs.un_430
  0x0a255307, 0x1f006e0e, 0x0f1f13ee, 0x530b0107,   // ht.eu.pt_432 blu.cy.un_550  et.cy.lv_422 en.es.ht_432
  0x0a170804, 0x2a072513, 0x531b3155, 0x040c0655,   // uk.sr.mk_332 eu.it.mt_665  az.tr.ht_442 de.sv.fi_442
  0x2112185a, 0x09006b07, 0x021f6e04, 0x101e1c11,   // ar.ur.fa_553 ceb.pl.un_420  blu.cy.da_332 id.ms.lt_653
  // [6120]
  0x01006e04, 0x2a006e07, 0x130f10a9, 0x16131711,   // blu.en.un_320 blu.mt.un_420  lt.lv.et_544 sr.et.hr_653
  0x10130f05, 0x16101704, 0x270a2507, 0x310c27a9,   // lv.et.lt_333 sr.lt.hr_332  eu.pt.gd_432 gd.sv.az_544
  0x19122da9, 0x12310408, 0x13120404, 0x06536ba0,   // sk.hu.gl_544 fi.az.hu_443  fi.hu.et_332 ceb.ht.de_322
  0x070301a9, 0x171008ee, 0x050164a0, 0x1e0d3112,   // en.nl.it_544 uk.be.sr_422  lg.en.fr_322 az.cs.ms_654
  // [6130]
  0x04101712, 0x53171602, 0x0704130c, 0x070a10a6,   // sr.be.ru_654 hr.sr.ht_222  et.fi.it_543 be.mk.bg_521
  0x07190a13, 0x16001b09, 0x2a001007, 0x16003f0d,   // pt.gl.it_665 tr.hr.un_440  lt.mt.un_420 af.hr.un_540
  0x0700011a, 0x53000a0e, 0x2a25110b, 0x0409120c,   // en.it.un_760 pt.ht.un_550  ro.eu.mt_542 hu.pl.fi_543
  0x1300310d, 0x100a1713, 0x040710af, 0x1600130b,   // az.et.un_540 sr.mk.be_665  be.bg.ru_655 et.hr.un_520
  // [6140]
  0x13121608, 0x13023105, 0x1a1f1004, 0x18001907,   // hr.hu.et_443 az.da.et_333  lt.cy.tl_332 gl.ga.un_420
  0x2d0d0a09, 0x0a122907, 0x0a001718, 0x3f0c0204,   // pt.cs.sk_444 sl.hu.pt_432  sr.mk.un_740 da.sv.af_332
  0x232d0d0b, 0x1100120e, 0x0a000d08, 0x09001f12,   // cs.sk.ca_542 hu.ro.un_550  cs.pt.un_430 cy.pl.un_640
  0x08000504, 0x1f3f0304, 0x2a1e1c05, 0x01121f0b,   // fr.no.un_320 nl.af.cy_332  id.ms.mt_333 cy.hu.en_542
  // [6150]
  0x11002804, 0x071117ec, 0x13280404, 0x170a13a0,   // sw.ro.un_320 sr.ro.bg_644  fi.sw.et_332 et.pt.sr_322
  0x646b0404, 0x3f061ea4, 0x11230a05, 0x0a2d0d0e,   // fi.ceb.lg_332 ms.de.af_433  pt.ca.ro_333 cs.sk.pt_555
  0x17161009, 0x2a0820ee, 0x273f1108, 0x1f1c1e0c,   // lt.hr.sr_444 sq.no.mt_422  ro.af.gd_443 ms.id.cy_543
  0x13100f0d, 0x1123070d, 0x27001c07, 0x10131ea4,   // lv.lt.et_554 it.ca.ro_554  id.gd.un_420 ms.et.lt_433
  // [6160]
  0x03120660, 0x281801ee, 0x0813020c, 0x2a19200c,   // de.hu.nl_664 en.ga.sw_422  da.et.no_543 sq.gl.mt_543
  0x120f10a9, 0x110f13a9, 0x1e281ca4, 0x21080607,   // lt.lv.hu_544 et.lv.ro_544  id.sw.ms_433 de.no.jw_432
  0x55001e05, 0x04120cec, 0x1b1f0912, 0x20131209,   // ms.rw.un_330 sv.hu.fi_644  pl.cy.tr_654 hu.et.sq_444
  0x53000905, 0x03002104, 0x21063f07, 0x171316a4,   // pl.ht.un_330 jw.nl.un_320  af.de.jw_432 hr.et.sr_433
  // [6170]
  0x211a31a0, 0x08001719, 0x13100f14, 0x0d091c55,   // az.tl.jw_322 sr.uk.un_750  lv.lt.et_666 mr.hi.ne_442
  0x121629a0, 0x213f1ca9, 0x182111a4, 0x0b2a0708,   // sl.hr.hu_322 id.af.jw_544  ro.jw.ga_433 it.mt.es_443
  0x041c55a0, 0x135564af, 0x020e0811, 0x23111ca0,   // rw.id.fi_322 lg.rw.et_655  no.is.da_653 id.ro.ca_322
  0x0802030e, 0x0e000302, 0x1900040c, 0x3f00640d,   // nl.da.no_555 nl.is.un_220  fi.gl.un_530 lg.af.un_540
  // [6180]
  0x08002d18, 0x080205a0, 0x05001119, 0x010b07a0,   // sk.no.un_740 fr.da.no_322  ro.fr.un_750 it.es.en_322
  0x04311b09, 0x286404ee, 0x100f08ad, 0x16172d55,   // tr.az.fi_444 fi.lg.sw_422  no.lv.lt_643 sk.sr.hr_442
  0x190b0e0c, 0x01130607, 0x1e1c1b04, 0x033f0f55,   // is.es.gl_543 de.et.en_432  tr.id.ms_332 lv.af.nl_442
  0x231f20a6, 0x02641308, 0x11170a60, 0x0f1a6b55,   // sq.cy.ca_521 et.lg.da_443  mk.sr.ro_664 ceb.tl.lv_442
  // [6190]
  0x20092dee, 0x03001c02, 0x0d171655, 0x0764040b,   // sk.pl.sq_422 id.nl.un_220  hr.sr.cs_442 fi.lg.it_542
  0x2b00010b, 0x070804ad, 0x0a17045a, 0x11190107,   // en.vi.un_520 ru.uk.bg_643  ru.sr.mk_553 en.gl.ro_432
  0x20160da6, 0x311b09ee, 0x1c003f08, 0x19050a0c,   // cs.hr.sq_521 pl.tr.az_422  af.id.un_430 pt.fr.gl_543
  0x0e000414, 0x2b1a0107, 0x04071708, 0x2017160c,   // fi.is.un_660 en.tl.vi_432  sr.bg.ru_443 hr.sr.sq_543
  // [61a0]
  0x1c1a01ee, 0x2b000912, 0x1704070e, 0x013f055a,   // en.tl.id_422 pl.vi.un_640  bg.ru.sr_555 fr.af.en_553
  0x19000d0c, 0x02253f04, 0x53211ca7, 0x5504640d,   // cs.gl.un_530 af.eu.da_332  id.jw.ht_532 lg.fi.rw_554
  0x555309a7, 0x212904ec, 0x1f0c3fa0, 0x2800011a,   // pl.ht.rw_532 fi.sl.jw_644  af.sv.cy_322 en.sw.un_760
  0x12022dee, 0x10001111, 0x2a0620ee, 0x05000607,   // sk.da.hu_422 ro.be.un_630  sq.de.mt_422 de.fr.un_420
  // [61b0]
  0x211c2007, 0x0a002308, 0x1600291a, 0x291612ee,   // sq.id.jw_432 ca.pt.un_430  sl.hr.un_760 hu.hr.sl_422
  0x215316a9, 0x06080c0e, 0x230a19a9, 0x29126ea4,   // hr.ht.jw_544 sv.no.de_555  gl.pt.ca_544 blu.hu.sl_433
  0x23190a55, 0x1e002a19, 0x043f0aee, 0x100c04ec,   // pt.gl.ca_442 mt.ms.un_750  pt.af.fi_422 fi.sv.lt_644
  0x06030f11, 0x130f08a4, 0x16001213, 0x2a0a2307,   // lv.nl.de_653 no.lv.et_433  hu.hr.un_650 ca.pt.mt_432
  // [61c0]
  0x1a006e02, 0x55281aa0, 0x1c211602, 0x270b18af,   // blu.tl.un_220 tl.sw.rw_322  hr.jw.id_222 ga.es.gd_655
  0x04001e12, 0x161101ee, 0x1b162507, 0x2a5564ad,   // ms.fi.un_640 en.ro.hr_422  eu.hr.tr_432 lg.rw.mt_643
  0x552a64ee, 0x101707a0, 0x27071fa7, 0x23000a09,   // lg.mt.rw_422 bg.sr.be_322  cy.it.gd_532 pt.ca.un_440
  0x04002809, 0x21161207, 0x5300640c, 0x160d2105,   // sw.fi.un_440 hu.hr.jw_432  lg.ht.un_530 jw.cs.hr_333
  // [61d0]
  0x1a2864a4, 0x11001202, 0x1b316b0b, 0x291716a6,   // lg.sw.tl_433 hu.ro.un_220  ceb.az.tr_542 hr.sr.sl_521
  0x31000f12, 0x29170d0c, 0x0d062da9, 0x09001a05,   // lv.az.un_640 cs.sr.sl_543  sk.de.cs_544 tl.pl.un_330
  0x0300050c, 0x291c0e08, 0x1e1c0ea0, 0x2d0d31a4,   // fr.nl.un_530 is.id.sl_443  is.id.ms_322 az.cs.sk_433
  0x022d0d02, 0x060e29a0, 0x29070b04, 0x290f16a0,   // cs.sk.da_222 sl.is.de_322  es.it.sl_332 hr.lv.sl_322
  // [61e0]
  0x100d2d0c, 0x19000511, 0x1c0e19ee, 0x0e002107,   // sk.cs.lt_543 fr.gl.un_630  gl.is.id_422 jw.is.un_420
  0x641c55af, 0x01042aee, 0x286b5513, 0x2a281b07,   // rw.id.lg_655 mt.fi.en_422  rw.ceb.sw_665 tr.sw.mt_432
  0x2b000604, 0x042031ec, 0x1b311aa4, 0x0a11080c,   // de.vi.un_320 az.sq.fi_644  tl.az.tr_433 uk.ro.mk_543
  0x28046407, 0x2d0d0702, 0x08006407, 0x3f135508,   // lg.fi.sw_432 it.cs.sk_222  lg.no.un_420 rw.et.af_443
  // [61f0]
  0x1b04310d, 0x31131bad, 0x17002502, 0x641a5507,   // az.fi.tr_554 tr.et.az_643  eu.sr.un_220 rw.tl.lg_432
  0x2100550d, 0x1e1c210c, 0x1716070e, 0x31000407,   // rw.jw.un_540 jw.id.ms_543  it.hr.sr_555 fi.az.un_420
  0x0464280c, 0x642855a4, 0x23053f08, 0x3f040304,   // sw.lg.fi_543 rw.sw.lg_433  af.fr.ca_443 nl.fi.af_332
  0x312d1ba0, 0x641a1005, 0x04033f0d, 0x3f000505,   // tr.sk.az_322 lt.tl.lg_333  af.nl.fi_554 fr.af.un_330
  // [6200]
  0x1f090da4, 0x0806045a, 0x18001202, 0x20001c05,   // cs.pl.cy_433 fi.de.no_553  ur.ar.un_220 id.sq.un_330
  0x0f2804a0, 0x133f0404, 0x041b0f04, 0x2d171660,   // fi.sw.lv_322 fi.af.et_332  lv.tr.fi_332 hr.sr.sk_664
  0x05001f04, 0x20171611, 0x1a132004, 0x11001e05,   // cy.fr.un_320 hr.sr.sq_653  sq.et.tl_332 ms.ro.un_330
  0x01002008, 0x00002837, 0x0d281e05, 0x53002823,   // sq.en.un_430 sw.un.un_B00  ms.sw.cs_333 sw.ht.un_880
  // [6210]
  0x53006423, 0x070d5305, 0x0f033fa7, 0x13033fa7,   // lg.ht.un_880 ht.cs.it_333  af.nl.lv_532 af.nl.et_532
  0x05003f0c, 0x3f036ea0, 0x0f6404a0, 0x1a646baf,   // af.fr.un_530 blu.nl.af_322  fi.lg.lv_322 ceb.lg.tl_655
  0x0a552008, 0x53645513, 0x6b645512, 0x0900532a,   // sq.rw.pt_443 rw.lg.ht_665  rw.lg.ceb_654 ht.pl.un_970
  0x130802a4, 0x1f003f12, 0x21096411, 0x080417ac,   // da.no.et_433 af.cy.un_640  lg.pl.jw_653 sr.ru.uk_632
  // [6220]
  0x64003f12, 0x230501a7, 0x0d0a2d07, 0x2120530c,   // af.lg.un_640 en.fr.ca_532  sk.pt.cs_432 ht.sq.jw_543
  0x19231104, 0x1f5564af, 0x23070a08, 0x2502120c,   // ro.ca.gl_332 lg.rw.cy_655  pt.it.ca_443 hu.da.eu_543
  0x2a001f21, 0x0a000408, 0x64012113, 0x27201008,   // cy.mt.un_860 ru.mk.un_430  jw.en.lg_665 lt.sq.gd_443
  0x04200702, 0x081707a0, 0x6b3f1a0e, 0x6b1a1faf,   // it.sq.fi_222 bg.sr.uk_322  tl.af.ceb_555 cy.tl.ceb_655
  // [6230]
  0x3f001805, 0x10002309, 0x0600050b, 0x556b1ca0,   // ga.af.un_330 ca.lt.un_440  fr.de.un_520 id.ceb.rw_322
  0x53112aa4, 0x0e6b1305, 0x23005312, 0x28110d07,   // mt.ro.ht_433 et.ceb.is_333  ht.ca.un_640 cs.ro.sw_432
  0x13101155, 0x10080413, 0x101113ee, 0x1b000602,   // ro.lt.et_442 ru.uk.be_665  et.ro.lt_422 de.tr.un_220
  0x03002702, 0x065325a4, 0x100f1609, 0x02040807,   // gd.nl.un_220 eu.ht.de_433  hr.lv.lt_444 no.fi.da_432
  // [6240]
  0x55110f55, 0x1b1208a0, 0x64006b04, 0x13530f0d,   // lv.ro.rw_442 no.hu.tr_322  ceb.lg.un_320 lv.ht.et_554
  0x55026b04, 0x08041702, 0x020608a0, 0x0e101307,   // ceb.da.rw_332 sr.ru.uk_222  no.de.da_322 et.lt.is_432
  0x20000c04, 0x101a1305, 0x08000e0e, 0x10041355,   // sv.sq.un_320 et.tl.lt_333  is.no.un_550 et.fi.lt_442
  0x02000c19, 0x062a5511, 0x29551112, 0x05001604,   // sv.da.un_750 rw.mt.de_653  ro.rw.sl_654 hr.fr.un_320
  // [6250]
  0x28001213, 0x64005304, 0x1f080202, 0x2a08010c,   // hu.sw.un_650 ht.lg.un_320  da.no.cy_222 en.no.mt_543
  0x18136402, 0x040a11ad, 0x112155a9, 0x200d53a0,   // lg.et.ga_222 ro.mk.ru_643  rw.jw.ro_544 ht.cs.sq_322
  0x08040205, 0x12001a08, 0x07100a14, 0x13000f1a,   // da.fi.no_333 tl.hu.un_430  mk.be.bg_666 lv.et.un_760
  0x531b2807, 0x1c000e04, 0x010628ee, 0x0d6b0307,   // sw.tr.ht_432 is.id.un_320  sw.de.en_422 nl.ceb.cs_432
  // [6260]
  0x0825130c, 0x0e02200c, 0x110d2d11, 0x6e25135a,   // et.eu.no_543 sq.da.is_543  sk.cs.ro_653 et.eu.blu_553
  0x16111908, 0x3113120c, 0x0a0408ad, 0x0c001319,   // gl.ro.hr_443 hu.et.az_543  uk.ru.mk_643 et.sv.un_750
  0x102d16a0, 0x1f0d0904, 0x0b190112, 0x02271104,   // hr.sk.lt_322 pl.cs.cy_332  en.gl.es_654 ro.gd.da_332
  0x0c002804, 0x080206a0, 0x021a6eee, 0x16295504,   // sw.sv.un_320 de.da.no_322  blu.tl.da_422 rw.sl.hr_332
  // [6270]
  0x12001a23, 0x0a2855a6, 0x2d001609, 0x04131aee,   // tl.hu.un_880 rw.sw.pt_521  hr.sk.un_440 tl.et.fi_422
  0x25532307, 0x11030b0c, 0x08001b05, 0x130c0807,   // ca.ht.eu_432 es.nl.ro_543  tr.no.un_330 no.sv.et_432
  0x030b060d, 0x1825040c, 0x161119a4, 0x130c25a9,   // de.es.nl_554 fi.eu.ga_543  gl.ro.hr_433 eu.sv.et_544
  0x05000b07, 0x052d5311, 0x0806130c, 0x111e1c12,   // es.fr.un_420 ht.sk.fr_653  et.de.no_543 id.ms.ro_654
  // [6280]
  0x1c171e07, 0x55122808, 0x190b1207, 0x6b2501a9,   // ms.sr.id_432 sw.hu.rw_443  hu.es.gl_432 en.eu.ceb_544
  0x25001309, 0x0411050e, 0x2527045a, 0x121b28a0,   // et.eu.un_440 fr.ro.fi_555  fi.gd.eu_553 sw.tr.hu_322
  0x20002105, 0x28006414, 0x130d09ac, 0x550f28a0,   // jw.sq.un_330 lg.sw.un_660  hi.ne.bh_632 sw.lv.rw_322
  0x1900120d, 0x110a0812, 0x23003f09, 0x032012ec,   // hu.gl.un_540 uk.mk.ro_654  af.ca.un_440 hu.sq.nl_644
  // [6290]
  0x3f130307, 0x130c3fa0, 0x31531c04, 0x0f3f03ad,   // nl.et.af_432 af.sv.et_322  id.ht.az_332 nl.af.lv_643
  0x09000305, 0x25001905, 0x2100530d, 0x100704a9,   // nl.pl.un_330 gl.eu.un_330  ht.jw.un_540 ru.bg.be_544
  0x55000e08, 0x100804a0, 0x29122004, 0x080255a0,   // is.rw.un_430 ru.uk.be_322  sq.hu.sl_332 rw.da.no_322
  0x06291607, 0x3f1c08a0, 0x170410a7, 0x23050702,   // hr.sl.de_432 no.id.af_322  be.ru.sr_532 it.fr.ca_222
  // [62a0]
  0x1127180c, 0x1f00110d, 0x10040807, 0x2d052511,   // ga.gd.ro_543 ro.cy.un_540  uk.ru.be_432 eu.fr.sk_653
  0x0c3f0107, 0x070a08a0, 0x04081002, 0x18126ba0,   // en.af.sv_432 uk.mk.bg_322  be.uk.ru_222 ceb.hu.ga_322
  0x0d122dad, 0x05235309, 0x53000a10, 0x311b250c,   // sk.hu.cs_643 ht.ca.fr_444  pt.ht.un_620 eu.tr.az_543
  0x2d1116a0, 0x02313f02, 0x1c000709, 0x231e1c02,   // hr.ro.sk_322 af.az.da_222  it.id.un_440 id.ms.ca_222
  // [62b0]
  0x27012304, 0x1c00210e, 0x1f1b190b, 0x13002304,   // ca.en.gd_332 jw.id.un_550  gl.tr.cy_542 ca.et.un_320
  0x07001118, 0x6b041aee, 0x0d190b05, 0x11550f07,   // ro.bg.un_740 tl.fi.ceb_422  es.gl.cs_333 lv.rw.ro_432
  0x0f1617ee, 0x12190ba9, 0x6b551a60, 0x0d1207a4,   // sr.hr.lv_422 es.gl.hu_544  tl.rw.ceb_664 it.hu.cs_433
  0x1e312802, 0x1a00200d, 0x09001c2a, 0x0a1312a0,   // sw.az.ms_222 sq.tl.un_540  mr.hi.un_970 hu.et.pt_322
  // [62c0]
  0x0213080c, 0x1f131a04, 0x13001602, 0x1900202b,   // no.et.da_543 tl.et.cy_332  hr.et.un_220 sq.gl.un_980
  0x00002537, 0x070a1711, 0x17196405, 0x2a005508,   // eu.un.un_B00 sr.mk.bg_653  lg.gl.sr_333 rw.mt.un_430
  0x6455250c, 0x1a000c0c, 0x1f0804a0, 0x1107290c,   // eu.rw.lg_543 sv.tl.un_530  fi.no.cy_322 sl.it.ro_543
  0x10201a07, 0x29201007, 0x03283f08, 0x11162d04,   // tl.sq.lt_432 lt.sq.sl_432  af.sw.nl_443 sk.hr.ro_332
  // [62d0]
  0x2b001707, 0x09041604, 0x0621010c, 0x2d290d5a,   // sr.vi.un_420 hr.fi.pl_332  en.jw.de_543 cs.sl.sk_553
  0x13042902, 0x062811a0, 0x31121b08, 0x6b001b07,   // sl.fi.et_222 ro.sw.de_322  tr.hu.az_443 tr.ceb.un_420
  0x3f1621a4, 0x0e2909ac, 0x0b2d0d02, 0x0c0813a0,   // jw.hr.af_433 pl.sl.is_632  cs.sk.es_222 et.no.sv_322
  0x55203108, 0x1e211ca9, 0x13001c33, 0x28025304,   // az.sq.rw_443 id.jw.ms_544  mr.bh.un_A70 ht.da.sw_332
  // [62e0]
  0x212028ee, 0x0d0f0913, 0x536404a0, 0x0a1125a4,   // sw.sq.jw_422 pl.lv.cs_665  fi.lg.ht_322 eu.ro.pt_433
  0x1800201a, 0x2d0d23a4, 0x1a126407, 0x12060ca7,   // sq.ga.un_760 ca.cs.sk_433  lg.hu.tl_432 sv.de.hu_532
  0x0500531b, 0x310409ad, 0x200525a6, 0x07006402,   // ht.fr.un_770 pl.fi.az_643  eu.fr.sq_521 lg.it.un_220
  0x06012aa4, 0x250410ad, 0x01106b02, 0x130c0e07,   // mt.en.de_433 lt.fi.eu_643  ceb.lt.en_222 is.sv.et_432
  // [62f0]
  0x1300101b, 0x552120af, 0x23211ca7, 0x64061204,   // lt.et.un_770 sq.jw.rw_655  id.jw.ca_532 hu.de.lg_332
  0x21001334, 0x1f006419, 0x07051112, 0x060105a0,   // et.jw.un_A80 lg.cy.un_750  ro.fr.it_654 fr.en.de_322
  0x251b3112, 0x0f033f12, 0x55136408, 0x01002014,   // az.tr.eu_654 af.nl.lv_654  lg.et.rw_443 sq.en.un_660
  0x0d005305, 0x53006405, 0x1e2a20a4, 0x1e1c06a4,   // ht.cs.un_330 lg.ht.un_330  sq.mt.ms_433 de.id.ms_433
  // [6300]
  0x64002009, 0x31013fee, 0x10171609, 0x641b3108,   // sq.lg.un_440 af.en.az_422  hr.sr.lt_444 az.tr.lg_443
  0x02202a0c, 0x0704110d, 0x550864a4, 0x531c1e0c,   // mt.sq.da_543 ro.ru.bg_554  lg.no.rw_433 ms.id.ht_543
  0x171655a6, 0x0655280c, 0x23050107, 0x01100f11,   // rw.hr.sr_521 sw.rw.de_543  en.fr.ca_432 lv.lt.en_653
  0x1c640707, 0x063f0309, 0x10130f13, 0x015528a4,   // it.lg.id_432 nl.af.de_444  lv.et.lt_665 sw.rw.en_433
  // [6310]
  0x130f100b, 0x032b0a07, 0x0f131005, 0x31000719,   // lt.lv.et_542 pt.vi.nl_432  lt.et.lv_333 it.az.un_750
  0x0b006404, 0x06000f0d, 0x2b001905, 0x072305ec,   // lg.es.un_320 lv.de.un_540  gl.vi.un_330 fr.ca.it_644
  0x101325ad, 0x12091104, 0x04171008, 0x19001213,   // eu.et.lt_643 ro.pl.hu_332  be.sr.ru_443 hu.gl.un_650
  0x64281e08, 0x19002b18, 0x531901a4, 0x1c285502,   // ms.sw.lg_443 vi.gl.un_740  en.gl.ht_433 rw.sw.id_222
  // [6320]
  0x08110407, 0x16210e0e, 0x1a556404, 0x02006b07,   // ru.ro.uk_432 is.jw.hr_555  lg.rw.tl_332 ceb.da.un_420
  0x08006e02, 0x552028ec, 0x010f1055, 0x2b002012,   // blu.no.un_220 sw.sq.rw_644  lt.lv.en_442 sq.vi.un_640
  0x2d120d04, 0x28552055, 0x1e000f13, 0x0408020e,   // cs.hu.sk_332 sq.rw.sw_442  lv.ms.un_650 da.no.fi_555
  0x2855010b, 0x10311a08, 0x552820a7, 0x172d290b,   // en.rw.sw_542 tl.az.lt_443  sq.sw.rw_532 sl.sk.sr_542
  // [6330]
  0x2d2128ee, 0x0e001807, 0x20002a05, 0x19050705,   // sw.jw.sk_422 ga.is.un_420  mt.sq.un_330 it.fr.gl_333
  0x04050111, 0x072a0107, 0x292018a0, 0x1100290d,   // en.fr.fi_653 en.mt.it_432  ga.sq.sl_322 sl.ro.un_540
  0x211e1c07, 0x3100230c, 0x02000104, 0x6b1f1a07,   // id.ms.jw_432 ca.az.un_530  en.da.un_320 tl.cy.ceb_432
  0x050806ec, 0x3f536bee, 0x0e072a0c, 0x08021ca4,   // de.no.fr_644 ceb.ht.af_422  mt.it.is_543 id.da.no_433
  // [6340]
  0x02000608, 0x04071113, 0x080a04a0, 0x2a00130c,   // de.da.un_430 ro.bg.ru_665  ru.mk.uk_322 et.mt.un_530
  0x02003f22, 0x130601a7, 0x2300050c, 0x55280408,   // af.da.un_870 en.de.et_532  fr.ca.un_530 fi.sw.rw_443
  0x080a07af, 0x0d172960, 0x013f0cee, 0x23291702,   // bg.mk.uk_655 sl.sr.cs_664  sv.af.en_422 sr.sl.ca_222
  0x1f3f2307, 0x1300551a, 0x31002702, 0x1f033f04,   // ca.af.cy_432 rw.et.un_760  gd.az.un_220 af.nl.cy_332
  // [6350]
  0x070a11a0, 0x53000404, 0x0d0a2dee, 0x190b0dec,   // ro.mk.bg_322 fi.ht.un_320  sk.pt.cs_422 cs.es.gl_644
  0x53552807, 0x10070405, 0x2b1e1c05, 0x11002913,   // sw.rw.ht_432 ru.bg.be_333  id.ms.vi_333 sl.ro.un_650
  0x053f030b, 0x1f040ea4, 0x04130e12, 0x312913ad,   // nl.af.fr_542 is.fi.cy_433  is.et.fi_654 et.sl.az_643
  0x040e290d, 0x11040902, 0x1a002911, 0x230501af,   // sl.is.fi_554 pl.fi.ro_222  sl.tl.un_630 en.fr.ca_655
  // [6360]
  0x086b0107, 0x09551a09, 0x06190b55, 0x641a1ea0,   // en.ceb.no_432 tl.rw.pl_444  es.gl.de_442 ms.tl.lg_322
  0x1f0e1a07, 0x2a000b04, 0x64251a0c, 0x2d290da0,   // tl.is.cy_432 es.mt.un_320  tl.eu.lg_543 cs.sl.sk_322
  0x25002134, 0x09000f19, 0x180413a0, 0x64551e04,   // jw.eu.un_A80 lv.pl.un_750  et.fi.ga_322 ms.rw.lg_332
  0x04556455, 0x2300180c, 0x212808af, 0x550e0b04,   // lg.rw.fi_442 ga.ca.un_530  no.sw.jw_655 es.is.rw_332
  // [6370]
  0x210e550c, 0x27005505, 0x642a070d, 0x2a002819,   // rw.is.jw_543 rw.gd.un_330  it.mt.lg_554 sw.mt.un_750
  0x1c080555, 0x01001004, 0x285564af, 0x04552155,   // fr.no.id_442 lt.en.un_320  lg.rw.sw_655 jw.rw.fi_442
  0x55206455, 0x1b0903ec, 0x281a64ad, 0x03071005,   // lg.sq.rw_442 nl.pl.tr_644  lg.tl.sw_643 lt.it.nl_333
  0x1c071e07, 0x28006e19, 0x215564af, 0x25551c11,   // ms.it.id_432 blu.sw.un_750  lg.rw.jw_655 id.rw.eu_653
  // [6380]
  0x211e2809, 0x20281e0b, 0x20002b2b, 0x180a11a4,   // sw.ms.jw_444 ms.sw.sq_542  vi.sq.un_980 ro.pt.ga_433
  0x106b2107, 0x555311a7, 0x033f0460, 0x0f5516a9,   // jw.ceb.lt_432 ro.ht.rw_532  fi.af.nl_664 hr.rw.lv_544
  0x3f2808a4, 0x06002805, 0x100f5512, 0x2b0818ac,   // no.sw.af_433 sw.de.un_330  rw.lv.lt_654 ga.no.vi_632
  0x232b6e11, 0x1c000d18, 0x1c6e1e12, 0x2129270c,   // blu.vi.ca_653 ne.mr.un_740  ms.blu.id_654 gd.sl.jw_543
  // [6390]
  0x0a000202, 0x53006421, 0x55001102, 0x2b006e0d,   // da.pt.un_220 lg.ht.un_860  ro.rw.un_220 blu.vi.un_540
  0x555364a9, 0x29161707, 0x186e0a12, 0x6e070a11,   // lg.ht.rw_544 sr.hr.sl_432  pt.blu.ga_654 pt.it.blu_653
  0x0b0553ee, 0x1f076ea9, 0x25000b13, 0x6e6b0ba7,   // ht.fr.es_422 blu.it.cy_544  es.eu.un_650 es.ceb.blu_532
  0x030e25af, 0x13003f0d, 0x06050b04, 0x17000719,   // eu.is.nl_655 af.et.un_540  es.fr.de_332 bg.sr.un_750
  // [63a0]
  0x12250ea9, 0x113f0a07, 0x020e0813, 0x0600551b,   // is.eu.hu_544 pt.af.ro_432  no.is.da_665 rw.de.un_770
  0x0e000809, 0x16000f16, 0x25062b55, 0x01002805,   // no.is.un_440 lv.hr.un_720  vi.de.eu_442 sw.en.un_330
  0x1a000b04, 0x020d2d0b, 0x0d1c2bb4, 0x29160f07,   // es.tl.un_320 sk.cs.da_542  vi.id.cs_754 lv.hr.sl_432
  0x2d130d04, 0x1a552512, 0x1300100d, 0x0e122d07,   // cs.et.sk_332 eu.rw.tl_654  lt.et.un_540 sk.hu.is_432
  // [63b0]
  0x0b001e04, 0x23211c07, 0x64001f02, 0x0e3f03a9,   // ms.es.un_320 id.jw.ca_432  cy.lg.un_220 nl.af.is_544
  0x2a6b0104, 0x1b0e640d, 0x06000904, 0x0c0e01a0,   // en.ceb.mt_332 lg.is.tr_554  pl.de.un_320 en.is.sv_322
  0x5300130c, 0x060e03a4, 0x012707a0, 0x07030ca4,   // et.ht.un_530 nl.is.de_433  it.gd.en_322 sv.nl.it_433
  0x0c2b01a4, 0x070e0cee, 0x130504a9, 0x0a182310,   // en.vi.sv_433 sv.is.it_422  fi.fr.et_544 ca.ga.pt_642
  // [63c0]
  0x042508a0, 0x05001808, 0x0c066bee, 0x2d0312a7,   // no.eu.fi_322 ga.fr.un_430  ceb.de.sv_422 hu.nl.sk_532
  0x0305075a, 0x181c2d04, 0x1a552804, 0x160d29ee,   // it.fr.nl_553 sk.id.ga_332  sw.rw.tl_332 sl.cs.hr_422
  0x05211a0b, 0x01001f08, 0x03252304, 0x0f001102,   // tl.jw.fr_542 cy.en.un_430  ca.eu.nl_332 ro.lv.un_220
  0x53002312, 0x1a645511, 0x210f1307, 0x081117ec,   // ca.ht.un_640 rw.lg.tl_653  et.lv.jw_432 sr.ro.uk_644
  // [63d0]
  0x64281208, 0x091f3155, 0x0e002019, 0x11041360,   // hu.sw.lg_443 az.cy.pl_442  sq.is.un_750 et.fi.ro_664
  0x2d0e0d05, 0x25040ea0, 0x27016bee, 0x16171f07,   // cs.is.sk_333 is.fi.eu_322  ceb.en.gd_422 cy.sr.hr_432
  0x120f2a07, 0x0b0a6b02, 0x110521a0, 0x0d001705,   // mt.lv.hu_432 ceb.pt.es_222  jw.fr.ro_322 sr.cs.un_330
  0x0e0208ee, 0x0400030b, 0x13033f02, 0x02080507,   // no.da.is_422 nl.fi.un_520  af.nl.et_222 fr.no.da_432
  // [63e0]
  0x21002a19, 0x02000512, 0x101311a4, 0x25003f08,   // mt.jw.un_750 fr.da.un_640  ro.et.lt_433 af.eu.un_430
  0x53001a0b, 0x10000d19, 0x030b060c, 0x3f0e090c,   // tl.ht.un_520 cs.lt.un_750  de.es.nl_543 pl.is.af_543
  0x10000d0d, 0x01536402, 0x01080607, 0x10110809,   // cs.lt.un_540 lg.ht.en_222  de.no.en_432 uk.ro.be_444
  0x1600250c, 0x3f0f1012, 0x201121a0, 0x530609af,   // eu.hr.un_530 lt.lv.af_654  jw.ro.sq_322 pl.de.ht_655
  // [63f0]
  0x0b0519a0, 0x53000f12, 0x3f0c0905, 0x6b002007,   // gl.fr.es_322 lv.ht.un_640  pl.sv.af_333 sq.ceb.un_420
  0x0910040d, 0x0a040714, 0x0e0210ee, 0x1f0205ee,   // fi.lt.pl_554 bg.ru.mk_666  lt.da.is_422 fr.da.cy_422
  0x0c3f0207, 0x110608ac, 0x1100101a, 0x05006b18,   // da.af.sv_432 no.de.ro_632  be.ro.un_760 ceb.fr.un_740
  0x6455280e, 0x230a05ad, 0x21000605, 0x02160da0,   // sw.rw.lg_555 fr.pt.ca_643  de.jw.un_330 cs.hr.da_322

  // [6400]
  0x282a01a0, 0x07080a02, 0x1f000908, 0x07081702,   // en.mt.sw_322 mk.uk.bg_222  pl.cy.un_430 sr.uk.bg_222
  0x18122d07, 0x3f0c08a6, 0x0a000210, 0x0b0601ec,   // sk.hu.ga_432 no.sv.af_521  da.pt.un_620 en.de.es_644
  0x02100804, 0x280306a0, 0x125525ad, 0x06040504,   // no.lt.da_332 de.nl.sw_322  eu.rw.hu_643 fr.fi.de_332
  0x21641aa4, 0x6b211aa9, 0x270623a7, 0x1a281e0c,   // tl.lg.jw_433 tl.jw.ceb_544  ca.de.gd_532 ms.sw.tl_543
  // [6410]
  0x27001a02, 0x060c045a, 0x1a1964ee, 0x64006e08,   // tl.gd.un_220 fi.sv.de_553  lg.gl.tl_422 blu.lg.un_430
  0x211e2808, 0x0e122d0c, 0x09006b22, 0x042a0e0c,   // sw.ms.jw_443 sk.hu.is_543  ceb.pl.un_870 is.mt.fi_543
  0x64001b04, 0x0704170d, 0x1e6b1c07, 0x1b250e0c,   // tr.lg.un_320 sr.ru.bg_554  id.ceb.ms_432 is.eu.tr_543
  0x0a00041b, 0x3f0304a6, 0x13002108, 0x1f311b07,   // ru.mk.un_770 fi.nl.af_521  jw.et.un_430 tr.az.cy_432
  // [6420]
  0x18002012, 0x1716110e, 0x21062aa0, 0x641b3113,   // sq.ga.un_640 ro.hr.sr_555  mt.de.jw_322 az.tr.lg_665
  0x09002804, 0x1c1a640c, 0x07041012, 0x03213f07,   // sw.pl.un_320 lg.tl.id_543  be.ru.bg_654 af.jw.nl_432
  0x23000a2c, 0x0a170860, 0x28641a0c, 0x6b1a1e07,   // pt.ca.un_990 uk.sr.mk_664  tl.lg.sw_543 ms.tl.ceb_432
  0x0e00200e, 0x2a000e23, 0x0964210c, 0x01640ba0,   // sq.is.un_550 is.mt.un_880  jw.lg.pl_543 es.lg.en_322
  // [6430]
  0x08020eee, 0x13001114, 0x2a122108, 0x21230507,   // is.da.no_422 ro.et.un_660  jw.hu.mt_443 fr.ca.jw_432
  0x0f062a04, 0x08170707, 0x10110460, 0x1e1c6ba0,   // mt.de.lv_332 bg.sr.uk_432  ru.ro.be_664 ceb.id.ms_322
  0x0e000607, 0x070811a4, 0x02050812, 0x1f010c07,   // de.is.un_420 ro.uk.bg_433  no.fr.da_654 sv.en.cy_432
  0x01000508, 0x1a17160e, 0x080407ad, 0x080904ee,   // fr.en.un_430 hr.sr.tl_555  bg.ru.uk_643 fi.pl.no_422
  // [6440]
  0x080205ad, 0x6b230507, 0x6e0407a0, 0x6b041a07,   // fr.da.no_643 fr.ca.ceb_432  it.fi.blu_322 tl.fi.ceb_432
  0x07170a0b, 0x13046407, 0x20000107, 0x071008a4,   // mk.sr.bg_542 lg.fi.et_432  en.sq.un_420 uk.be.bg_433
  0x2a17160d, 0x0d0b190c, 0x07062512, 0x0c163f0c,   // hr.sr.mt_554 gl.es.cs_543  eu.de.it_654 af.hr.sv_543
  0x3f0d2dec, 0x12642102, 0x2a0a23a9, 0x3f1808a9,   // sk.cs.af_644 jw.lg.hu_222  ca.pt.mt_544 no.ga.af_544
  // [6450]
  0x080a04ee, 0x641b5502, 0x2a002b0c, 0x0a2d0d0d,   // ru.mk.uk_422 rw.tr.lg_222  vi.mt.un_530 cs.sk.pt_554
  0x070601ad, 0x64002004, 0x2a000209, 0x043f0311,   // en.de.it_643 sq.lg.un_320  da.mt.un_440 nl.af.fi_653
  0x012305ee, 0x040610a9, 0x04100e05, 0x3f0304a9,   // fr.ca.en_422 lt.de.fi_544  is.lt.fi_333 fi.nl.af_544
  0x060a040c, 0x06001f19, 0x6e00061a, 0x23041011,   // fi.pt.de_543 cy.de.un_750  de.blu.un_760 lt.fi.ca_653
  // [6460]
  0x1f033f08, 0x08110304, 0x06010505, 0x291f1e0b,   // af.nl.cy_443 nl.ro.no_332  fr.en.de_333 ms.cy.sl_542
  0x2d002518, 0x0c002a07, 0x6b0501a7, 0x0c002108,   // eu.sk.un_740 mt.sv.un_420  en.fr.ceb_532 jw.sv.un_430
  0x5300210d, 0x23001c04, 0x0f183fee, 0x062031a7,   // jw.ht.un_540 id.ca.un_320  af.ga.lv_422 az.sq.de_532
  0x201b1855, 0x06041007, 0x0313040d, 0x060421a0,   // ga.tr.sq_442 lt.fi.de_432  fi.et.nl_554 jw.fi.de_322
  // [6470]
  0x10040612, 0x29172d07, 0x03041004, 0x070a0804,   // de.fi.lt_654 sk.sr.sl_432  lt.fi.nl_332 uk.mk.bg_332
  0x2d0d06ee, 0x53232104, 0x31002a08, 0x20002321,   // de.cs.sk_422 jw.ca.ht_332  mt.az.un_430 ca.sq.un_860
  0x110804ee, 0x0728010c, 0x0c100107, 0x06002902,   // fi.no.ro_422 en.sw.it_543  en.lt.sv_432 sl.de.un_220
  0x190a05a0, 0x1e000404, 0x28000a0e, 0x02060ca9,   // fr.pt.gl_322 fi.ms.un_320  pt.sw.un_550 sv.de.da_544
  // [6480]
  0x28205560, 0x182827a0, 0x11311b0b, 0x25282704,   // rw.sq.sw_664 gd.sw.ga_322  tr.az.ro_542 gd.sw.eu_332
  0x040c060d, 0x030213ad, 0x172d16a9, 0x1e122155,   // de.sv.fi_554 et.da.nl_643  hr.sk.sr_544 jw.hu.ms_442
  0x03250507, 0x23000a1a, 0x3f02180c, 0x55110b04,   // fr.eu.nl_432 pt.ca.un_760  ga.da.af_543 es.ro.rw_332
  0x1027185a, 0x11170a12, 0x06000312, 0x100f0ca0,   // ga.gd.lt_553 mk.sr.ro_654  nl.de.un_640 sv.lv.lt_322
  // [6490]
  0x552764ee, 0x17165507, 0x0f002808, 0x12000a07,   // lg.gd.rw_422 rw.hr.sr_432  sw.lv.un_430 pt.hu.un_420
  0x03133f07, 0x03133f13, 0x06032013, 0x28003f14,   // af.et.nl_432 af.et.nl_665  sq.nl.de_665 af.sw.un_660
  0x03215307, 0x6402010c, 0x0a2d0d0b, 0x282155ee,   // ht.jw.nl_432 en.da.lg_543  cs.sk.pt_542 rw.jw.sw_422
  0x035321a0, 0x0f001608, 0x211e1aa0, 0x55003f0c,   // jw.ht.nl_322 hr.lv.un_430  tl.ms.jw_322 af.rw.un_530
  // [64a0]
  0x03533fee, 0x170710ad, 0x0e0608a9, 0x2a00071b,   // af.ht.nl_422 be.bg.sr_643  no.de.is_544 it.mt.un_770
  0x13063fec, 0x205309a0, 0x083f0309, 0x53111ea0,   // af.de.et_644 pl.ht.sq_322  nl.af.no_444 ms.ro.ht_322
  0x0f2017a4, 0x3125640c, 0x18276b0c, 0x18076b07,   // sr.sq.lv_433 lg.eu.az_543  ceb.gd.ga_543 ceb.it.ga_432
  0x19012d0c, 0x0e080cad, 0x27001805, 0x1100030c,   // sk.en.gl_543 sv.no.is_643  ga.gd.un_330 nl.ro.un_530
  // [64b0]
  0x18102707, 0x532305a9, 0x3f00551a, 0x21005309,   // gd.lt.ga_432 fr.ca.ht_544  rw.af.un_760 ht.jw.un_440
  0x1e1c21ad, 0x0f000e08, 0x311e1ca0, 0x0d000607,   // jw.id.ms_643 is.lv.un_430  id.ms.az_322 de.cs.un_420
  0x0d002a07, 0x211a2ba9, 0x10022b0c, 0x0f6b08a0,   // mt.cs.un_420 vi.tl.jw_544  vi.da.lt_543 no.ceb.lv_322
  0x07000a2c, 0x1228210e, 0x06002020, 0x07002a21,   // mk.bg.un_990 jw.sw.hu_555  sq.de.un_850 mt.it.un_860
  // [64c0]
  0x643f030b, 0x04000309, 0x12000522, 0x271e1c13,   // nl.af.lg_542 nl.fi.un_440  fr.hu.un_870 id.ms.gd_665
  0x06251f12, 0x230f0c04, 0x07006b0d, 0x011b050c,   // cy.eu.de_654 sv.lv.ca_332  ceb.it.un_540 fr.tr.en_543
  0x64551ea4, 0x1b31210e, 0x3f000b04, 0x2d0d050e,   // ms.rw.lg_433 jw.az.tr_555  es.af.un_320 fr.cs.sk_555
  0x070804a9, 0x272155ee, 0x0d2d12ad, 0x2b001812,   // ru.uk.bg_544 rw.jw.gd_422  hu.sk.cs_643 ga.vi.un_640
  // [64d0]
  0x231e1c07, 0x230f0b04, 0x0f05010c, 0x01000602,   // id.ms.ca_432 es.lv.ca_332  en.fr.lv_543 de.en.un_220
  0x6b0c08a9, 0x55286404, 0x120d0a0c, 0x2a010fa7,   // no.sv.ceb_544 lg.sw.rw_332  pt.cs.hu_543 lv.en.mt_532
  0x2d0a0da0, 0x071711ad, 0x02110308, 0x2d002913,   // cs.pt.sk_322 ro.sr.bg_643  nl.ro.da_443 sl.sk.un_650
  0x292d1602, 0x23000c09, 0x1900120c, 0x23000a13,   // hr.sk.sl_222 sv.ca.un_440  hu.gl.un_530 pt.ca.un_650
  // [64e0]
  0x3f310707, 0x1700100c, 0x07002a09, 0x0a17085a,   // it.az.af_432 be.sr.un_530  mt.it.un_440 uk.sr.mk_553
  0x2d00180e, 0x18211205, 0x05072a09, 0x12000e0b,   // ga.sk.un_550 ur.fa.ar_333  mt.it.fr_444 is.hu.un_520
  0x01002d04, 0x213f25a9, 0x032a1004, 0x06283fa4,   // sk.en.un_320 eu.af.jw_544  lt.mt.nl_332 af.sw.de_433
  0x0e2d0d04, 0x0c00040c, 0x060c0407, 0x016b3fee,   // cs.sk.is_332 fi.sv.un_530  fi.sv.de_432 af.ceb.en_422
  // [64f0]
  0x05001f0d, 0x18270608, 0x18272814, 0x0200091a,   // cy.fr.un_540 de.gd.ga_443  sw.gd.ga_666 pl.da.un_760
  0x16000302, 0x080e1812, 0x06002511, 0x0627185a,   // nl.hr.un_220 ga.is.no_654  eu.de.un_630 ga.gd.de_553
  0x0d201212, 0x0c120805, 0x12000505, 0x06033fad,   // hu.sq.cs_654 no.hu.sv_333  fr.hu.un_330 af.nl.de_643
  0x2b5328ec, 0x060327ad, 0x0e0f1055, 0x033f0612,   // sw.ht.vi_644 gd.nl.de_643  lt.lv.is_442 de.af.nl_654
  // [6500]
  0x1c000e0d, 0x21272813, 0x2b2d1ea0, 0x0a001019,   // is.id.un_540 sw.gd.jw_665  ms.sk.vi_322 be.mk.un_750
  0x0600281a, 0x1a12270c, 0x232d0da0, 0x1700200c,   // sw.de.un_760 gd.hu.tl_543  cs.sk.ca_322 sq.sr.un_530
  0x170a1012, 0x1f2a2312, 0x31295312, 0x081b3107,   // be.mk.sr_654 ca.mt.cy_654  ht.sl.az_654 az.tr.no_432
  0x290d10af, 0x31045307, 0x6e532a14, 0x281e1c05,   // lt.cs.sl_655 ht.fi.az_432  mt.ht.blu_666 id.ms.sw_333
  // [6510]
  0x1a5528af, 0x03062813, 0x18270111, 0x13310407,   // sw.rw.tl_655 sw.de.nl_665  en.gd.ga_653 fi.az.et_432
  0x6e07310d, 0x29002107, 0x1e1c07af, 0x281a0608,   // az.it.blu_554 jw.sl.un_420  it.id.ms_655 de.tl.sw_443
  0x2818090e, 0x041f130e, 0x2a04110d, 0x10086b0d,   // pl.ga.sw_555 et.cy.fi_555  ro.fi.mt_554 ceb.no.lt_554
  0x2804060c, 0x06010812, 0x64201111, 0x212b1a08,   // de.fi.sw_543 no.en.de_654  ro.sq.lg_653 tl.vi.jw_443
  // [6520]
  0x2d002b0c, 0x6e001b19, 0x0c232a55, 0x2555040c,   // vi.sk.un_530 tr.blu.un_750  mt.ca.sv_442 fi.rw.eu_543
  0x23120407, 0x286b1aad, 0x532027ad, 0x02000a08,   // fi.hu.ca_432 tl.ceb.sw_643  gd.sq.ht_643 pt.da.un_430
  0x211a280c, 0x641a5512, 0x1c6e20a0, 0x0c023fa4,   // sw.tl.jw_543 rw.tl.lg_654  sq.blu.id_322 af.da.sv_433
  0x2016530e, 0x040e1e0c, 0x2a002504, 0x0e0c02a4,   // ht.hr.sq_555 ms.is.fi_543  eu.mt.un_320 da.sv.is_433
  // [6530]
  0x121c2b04, 0x18002b29, 0x090c020c, 0x1b00550e,   // vi.id.hu_332 vi.ga.un_960  da.sv.pl_543 rw.tr.un_550
  0x292d1108, 0x192a6b02, 0x1c131ea4, 0x13041a02,   // ro.sk.sl_443 ceb.mt.gl_222  ms.et.id_433 tl.fi.et_222
  0x06001c07, 0x0a0f0ea4, 0x13211a05, 0x211e2855,   // id.de.un_420 is.lv.pt_433  tl.jw.et_333 sw.ms.jw_442
  0x2d000502, 0x0a2520ad, 0x1a3f09ad, 0x06003f1a,   // fr.sk.un_220 sq.eu.pt_643  pl.af.tl_643 af.de.un_760
  // [6540]
  0x0d00130d, 0x181f010c, 0x09172908, 0x1b3109a0,   // bh.ne.un_540 en.cy.ga_543  sl.sr.pl_443 pl.az.tr_322
  0x3f2b01ee, 0x2d001013, 0x0c0306a0, 0x110401a0,   // en.vi.af_422 lt.sk.un_650  de.nl.sv_322 en.fi.ro_322
  0x29000705, 0x2000111a, 0x10171105, 0x640411ad,   // it.sl.un_330 ro.sq.un_760  ro.sr.be_333 ro.fi.lg_643
  0x020e21a0, 0x192d0d05, 0x120b2dee, 0x0a001807,   // jw.is.da_322 cs.sk.gl_333  sk.es.hu_422 ga.pt.un_420
  // [6550]
  0x17001014, 0x18190b02, 0x04001305, 0x2a04130c,   // be.sr.un_660 es.gl.ga_222  et.fi.un_330 et.fi.mt_543
  0x02130408, 0x2d060d12, 0x1f06010c, 0x04000312,   // fi.et.da_443 cs.de.sk_654  en.de.cy_543 nl.fi.un_640
  0x080264ee, 0x08001023, 0x2d0d1aa4, 0x21080202,   // lg.da.no_422 be.uk.un_880  tl.cs.sk_433 da.no.jw_222
  0x13040cec, 0x1017160c, 0x20171613, 0x0c206e0c,   // sv.fi.et_644 hr.sr.lt_543  hr.sr.sq_665 blu.sq.sv_543
  // [6560]
  0x08000d04, 0x10002007, 0x640408a0, 0x2a0c0608,   // cs.no.un_320 sq.lt.un_420  no.fi.lg_322 de.sv.mt_443
  0x080204ec, 0x13005520, 0x062a31a0, 0x032913a7,   // fi.da.no_644 rw.et.un_850  az.mt.de_322 et.sl.nl_532
  0x2a3f1e07, 0x316b1bad, 0x17100802, 0x6e00200e,   // ms.af.mt_432 tr.ceb.az_643  uk.be.sr_222 sq.blu.un_550
  0x061a21a0, 0x08071705, 0x0d202d0c, 0x13002511,   // jw.tl.de_322 sr.bg.uk_333  sk.sq.cs_543 eu.et.un_630
  // [6570]
  0x0e1b04a4, 0x532123ec, 0x011c18a0, 0x0f00040e,   // fi.tr.is_433 ca.jw.ht_644  ga.id.en_322 fi.lv.un_550
  0x04002009, 0x290820ee, 0x0f1002ee, 0x1b002304,   // sq.fi.un_440 sq.no.sl_422  da.lt.lv_422 ca.tr.un_320
  0x061f0107, 0x21291a07, 0x2b006b0c, 0x64101a04,   // en.cy.de_432 tl.sl.jw_432  ceb.vi.un_530 tl.lt.lg_332
  0x07100408, 0x1b640ca0, 0x2a040aa7, 0x0a00051b,   // ru.be.bg_443 sv.lg.tr_322  pt.fi.mt_532 fr.pt.un_770
  // [6580]
  0x07131fa6, 0x03002d04, 0x05230aec, 0x0100641a,   // cy.et.it_521 sk.nl.un_320  pt.ca.fr_644 lg.en.un_760
  0x17161b0b, 0x53232109, 0x231b0aac, 0x090d0407,   // tr.hr.sr_542 jw.ca.ht_444  pt.tr.ca_632 fi.cs.pl_432
  0x2331250c, 0x05001f02, 0x25000d13, 0x282718a0,   // eu.az.ca_543 cy.fr.un_220  cs.eu.un_650 ga.gd.sw_322
  0x2a170604, 0x100a1702, 0x55000808, 0x130d1c08,   // de.sr.mt_332 sr.mk.be_222  no.rw.un_430 mr.ne.bh_443
  // [6590]
  0x0c041307, 0x033f13ee, 0x02005304, 0x16000c08,   // et.fi.sv_432 et.af.nl_422  ht.da.un_320 sv.hr.un_430
  0x04201307, 0x020f04a4, 0x202a1308, 0x1e28550b,   // et.sq.fi_432 fi.lv.da_433  et.mt.sq_443 rw.sw.ms_542
  0x01042009, 0x2b552812, 0x0e001f12, 0x042855ee,   // sq.fi.en_444 sw.rw.vi_654  cy.is.un_640 rw.sw.fi_422
  0x0b190a55, 0x20005519, 0x20002a02, 0x020e2a07,   // pt.gl.es_442 rw.sq.un_750  mt.sq.un_220 mt.is.da_432
  // [65a0]
  0x07002702, 0x1e1c04ac, 0x08645507, 0x21201a08,   // gd.it.un_220 fi.id.ms_632  rw.lg.no_432 tl.sq.jw_443
  0x282055ad, 0x091a1c07, 0x6b641a13, 0x17100a0d,   // rw.sq.sw_643 id.tl.pl_432  tl.lg.ceb_665 mk.be.sr_554
  0x1c0a6ea7, 0x0d00120d, 0x1a21640c, 0x21112707,   // blu.pt.id_532 hu.cs.un_540  lg.jw.tl_543 gd.ro.jw_432
  0x01285507, 0x53002307, 0x200c1208, 0x281712ee,   // rw.sw.en_432 ca.ht.un_420  hu.sv.sq_443 hu.sr.sw_422
  // [65b0]
  0x171004af, 0x05060204, 0x211c1005, 0x3f2855a4,   // ru.be.sr_655 da.de.fr_332  lt.id.jw_333 rw.sw.af_433
  0x120a0da0, 0x2d1716a0, 0x20005522, 0x31112302,   // cs.pt.hu_322 hr.sr.sk_322  rw.sq.un_870 ca.ro.az_222
  0x08551ca0, 0x0b0e19ec, 0x291612a4, 0x0f2028ec,   // id.rw.no_322 gl.is.es_644  hu.hr.sl_433 sw.sq.lv_644
  0x230b1ea4, 0x04130d0b, 0x2a07010c, 0x06030c02,   // ms.es.ca_433 cs.et.fi_542  en.it.mt_543 sv.nl.de_222
  // [65c0]
  0x21640908, 0x64131a12, 0x11000d16, 0x13006b07,   // pl.lg.jw_443 tl.et.lg_654  cs.ro.un_720 ceb.et.un_420
  0x2a1a5304, 0x20090dee, 0x0b0a1907, 0x090317a0,   // ht.tl.mt_332 cs.pl.sq_422  gl.pt.es_432 sr.nl.pl_322
  0x162d0d60, 0x040817af, 0x06182708, 0x2d100d05,   // cs.sk.hr_664 sr.uk.ru_655  gd.ga.de_443 cs.lt.sk_333
  0x09000613, 0x53182712, 0x5318270e, 0x28216407,   // de.pl.un_650 gd.ga.ht_654  gd.ga.ht_555 lg.jw.sw_432
  // [65d0]
  0x645528a9, 0x64552855, 0x25121b12, 0x29130408,   // sw.rw.lg_544 sw.rw.lg_442  tr.hu.eu_654 fi.et.sl_443
  0x283120ee, 0x53001b19, 0x181605a0, 0x1e281ca0,   // sq.az.sw_422 tr.ht.un_750  fr.hr.ga_322 id.sw.ms_322
  0x3f0c0207, 0x28641e02, 0x18080e05, 0x121918a0,   // da.sv.af_432 ms.lg.sw_222  is.no.ga_333 ga.gl.hu_322
  0x012b06a0, 0x060e0c07, 0x050106a0, 0x190b09ee,   // de.vi.en_322 sv.is.de_432  de.en.fr_322 pl.es.gl_422
  // [65e0]
  0x28002722, 0x080407af, 0x55001f14, 0x08090ca4,   // gd.sw.un_870 bg.ru.uk_655  cy.rw.un_660 sv.pl.no_433
  0x162b1aa4, 0x0a2b27ad, 0x06271f0c, 0x281a2905,   // tl.vi.hr_433 gd.vi.pt_643  cy.gd.de_543 sl.tl.sw_333
  0x0e27280c, 0x2a251ba7, 0x1c0d1ea4, 0x0d17160c,   // sw.gd.is_543 tr.eu.mt_532  ms.cs.id_433 hr.sr.cs_543
  0x552b1f07, 0x170e08a0, 0x2b206eec, 0x09082a60,   // cy.vi.rw_432 no.is.sr_322  blu.sq.vi_644 mt.no.pl_664
  // [65f0]
  0x0b1113ee, 0x13060da9, 0x1b000c08, 0x1a00210d,   // et.ro.es_422 cs.de.et_544  sv.tr.un_430 jw.tl.un_540
  0x160105a0, 0x641a1ea9, 0x1c002304, 0x070a25ee,   // fr.en.hr_322 ms.tl.lg_544  ca.id.un_320 eu.pt.it_422
  0x3f0309ad, 0x04001204, 0x28556b12, 0x190b20a4,   // pl.nl.af_643 hu.fi.un_320  ceb.rw.sw_654 sq.es.gl_433
  0x1c211e07, 0x02292d07, 0x04172911, 0x060c02a4,   // ms.jw.id_432 sk.sl.da_432  sl.sr.fi_653 da.sv.de_433
  // [6600]
  0x0f1a55ee, 0x531f0611, 0x3f092dee, 0x091a100c,   // rw.tl.lv_422 de.cy.ht_653  sk.pl.af_422 lt.tl.pl_543
  0x082002a0, 0x1e641c0b, 0x1b000f1b, 0x10312008,   // da.sq.no_322 id.lg.ms_542  lv.tr.un_770 sq.az.lt_443
  0x55211f07, 0x113f55a4, 0x21136b08, 0x01020604,   // cy.jw.rw_432 rw.af.ro_433  ceb.et.jw_443 de.da.en_332
  0x0b002008, 0x25191caf, 0x290d13ee, 0x2700070e,   // sq.es.un_430 id.gl.eu_655  et.cs.sl_422 it.gd.un_550
  // [6610]
  0x276b0908, 0x0f550ba4, 0x19001108, 0x1b2025ee,   // pl.ceb.gd_443 es.rw.lv_433  ro.gl.un_430 eu.sq.tr_422
  0x28641e0b, 0x1f2113a4, 0x53202a04, 0x281a55a9,   // ms.lg.sw_542 et.jw.cy_433  mt.sq.ht_332 rw.tl.sw_544
  0x1c552512, 0x201b2507, 0x130d1c0e, 0x0764210c,   // eu.rw.id_654 eu.tr.sq_432  mr.ne.bh_555 jw.lg.it_543
  0x070c1307, 0x281a6ba9, 0x21090fad, 0x12072007,   // et.sv.it_432 ceb.tl.sw_544  lv.pl.jw_643 sq.it.hu_432
  // [6620]
  0x2d190a13, 0x0c080eaf, 0x09213f04, 0x19002005,   // pt.gl.sk_665 is.no.sv_655  af.jw.pl_332 sq.gl.un_330
  0x210f1108, 0x0b18190c, 0x08020c60, 0x206b25a0,   // ro.lv.jw_443 gl.ga.es_543  sv.da.no_664 eu.ceb.sq_322
  0x0c201205, 0x05201f07, 0x21006402, 0x05031b09,   // hu.sq.sv_333 cy.sq.fr_432  lg.jw.un_220 tr.nl.fr_444
  0x08190b05, 0x1c2821a0, 0x251b2a07, 0x12090605,   // es.gl.no_333 jw.sw.id_322  mt.tr.eu_432 de.pl.hu_333
  // [6630]
  0x53121ba4, 0x1c100ea0, 0x29160d07, 0x291610a7,   // tr.hu.ht_433 is.lt.id_322  cs.hr.sl_432 lt.hr.sl_532
  0x18000505, 0x1b010c05, 0x0b002807, 0x2a002807,   // fr.ga.un_330 sv.en.tr_333  sw.es.un_420 sw.mt.un_420
  0x53211ba0, 0x171629a7, 0x1300081a, 0x033f130c,   // tr.jw.ht_322 sl.hr.sr_532  no.et.un_760 et.af.nl_543
  0x170a0402, 0x6b1a3fa0, 0x12211808, 0x1b132a07,   // ru.mk.sr_222 af.tl.ceb_322  ar.fa.ur_443 mt.et.tr_432
  // [6640]
  0x27000919, 0x11000b02, 0x191227a0, 0x2800550b,   // pl.gd.un_750 es.ro.un_220  gd.hu.gl_322 rw.sw.un_520
  0x080a1713, 0x0d171607, 0x16290d07, 0x16170d0c,   // sr.mk.uk_665 hr.sr.cs_432  cs.sl.hr_432 cs.sr.hr_543
  0x531b0512, 0x21051bee, 0x641b055a, 0x0300550e,   // fr.tr.ht_654 tr.fr.jw_422  fr.tr.lg_553 rw.nl.un_550
  0x0a002009, 0x0c110504, 0x3f000508, 0x640501a0,   // sq.pt.un_440 fr.ro.sv_332  fr.af.un_430 en.fr.lg_322
  // [6650]
  0x0c6408a4, 0x16211c55, 0x0f005512, 0x19051208,   // no.lg.sv_433 id.jw.hr_442  rw.lv.un_640 hu.fr.gl_443
  0x02102aa0, 0x020621ad, 0x0b000509, 0x050603a9,   // mt.lt.da_322 jw.de.da_643  fr.es.un_440 nl.de.fr_544
  0x2d000f04, 0x0f002d0d, 0x0c06025a, 0x08135507,   // lv.sk.un_320 sk.lv.un_540  da.de.sv_553 rw.et.no_432
  0x29002005, 0x0705190c, 0x0800550c, 0x0e0413ee,   // sq.sl.un_330 gl.fr.it_543  rw.no.un_530 et.fi.is_422
  // [6660]
  0x170a0405, 0x550d0fa4, 0x071725a6, 0x29082d0b,   // ru.mk.sr_333 lv.cs.rw_433  eu.sr.it_521 sk.no.sl_542
  0x121b3f55, 0x3f311b08, 0x03001704, 0x64040cad,   // af.tr.hu_442 tr.az.af_443  sr.nl.un_320 sv.fi.lg_643
  0x1120290c, 0x313f1b13, 0x282155a0, 0x0500290d,   // sl.sq.ro_543 tr.af.az_665  rw.jw.sw_322 sl.fr.un_540
  0x01051309, 0x136b1e05, 0x28000108, 0x211b3f08,   // et.fr.en_444 ms.ceb.et_333  en.sw.un_430 af.tr.jw_443
  // [6670]
  0x051221ee, 0x2a311ba7, 0x3100130e, 0x25210404,   // jw.hu.fr_422 tr.az.mt_532  et.az.un_550 fi.jw.eu_332
  0x530425ad, 0x13003f13, 0x1c181f0c, 0x311b3faf,   // eu.fi.ht_643 af.et.un_650  cy.ga.id_543 af.tr.az_655
  0x0f3f0c04, 0x0b002d21, 0x1b003f13, 0x17001021,   // sv.af.lv_332 sk.es.un_860  af.tr.un_650 be.sr.un_860
  0x0127200c, 0x10001c02, 0x20531c0c, 0x16290d5a,   // sq.gd.en_543 id.lt.un_220  id.ht.sq_543 cs.sl.hr_553
  // [6680]
  0x080f090c, 0x311b3fa0, 0x53120b02, 0x063f1307,   // pl.lv.no_543 af.tr.az_322  es.hu.ht_222 et.af.de_432
  0x13162a04, 0x0a0817a4, 0x311b13a7, 0x21642912,   // mt.hr.et_332 sr.uk.mk_433  et.tr.az_532 sl.lg.jw_654
  0x1100011a, 0x2a000921, 0x08070414, 0x11551307,   // en.ro.un_760 pl.mt.un_860  ru.bg.uk_666 et.rw.ro_432
  0x190c0107, 0x27201e0c, 0x290c12ec, 0x09002a13,   // en.sv.gl_432 ms.sq.gd_543  hu.sv.sl_644 mt.pl.un_650
  // [6690]
  0x011a28a0, 0x6b210407, 0x250c1f0c, 0x20000707,   // sw.tl.en_322 fi.jw.ceb_432  cy.sv.eu_543 it.sq.un_420
  0x1c2b1ea0, 0x040c08a0, 0x080210a7, 0x1b2108a0,   // ms.vi.id_322 no.sv.fi_322  lt.da.no_532 no.jw.tr_322
  0x1b002018, 0x3f001107, 0x13000f09, 0x17161109,   // sq.tr.un_740 ro.af.un_420  lv.et.un_440 ro.hr.sr_444
  0x291610ac, 0x530f2da0, 0x310d0cee, 0x0c0f08a4,   // lt.hr.sl_632 sk.lv.ht_322  sv.cs.az_422 no.lv.sv_433
  // [66a0]
  0x64215502, 0x0900210d, 0x200c01a4, 0x0f000914,   // rw.jw.lg_222 jw.pl.un_540  en.sv.sq_433 pl.lv.un_660
  0x2a1b1c07, 0x040307a0, 0x2910160c, 0x11000a02,   // id.tr.mt_432 it.nl.fi_322  hr.lt.sl_543 pt.ro.un_220
  0x03063f02, 0x250f2908, 0x2a18110c, 0x0c080f0d,   // af.de.nl_222 sl.lv.eu_443  ro.ga.mt_543 lv.no.sv_554
  0x1000290d, 0x1c000105, 0x531e1c0d, 0x550501ec,   // sl.lt.un_540 en.id.un_330  id.ms.ht_554 en.fr.rw_644
  // [66b0]
  0x050608a0, 0x16292805, 0x050255af, 0x0a101713,   // no.de.fr_322 sw.sl.hr_333  rw.da.fr_655 sr.be.mk_665
  0x056b01ee, 0x022a085a, 0x13556402, 0x2a0305a7,   // en.ceb.fr_422 no.mt.da_553  lg.rw.et_222 fr.nl.mt_532
  0x0b19230b, 0x2900171a, 0x0c13040b, 0x0b1918ee,   // ca.gl.es_542 sr.sl.un_760  fi.et.sv_542 ga.gl.es_422
  0x040c13a7, 0x0c1304a9, 0x530c0808, 0x05550111,   // et.sv.fi_532 fi.et.sv_544  no.sv.ht_443 en.rw.fr_653
  // [66c0]
  0x28182a08, 0x060105ee, 0x09001208, 0x13000934,   // mt.ga.sw_443 fr.en.de_422  hu.pl.un_430 hi.bh.un_A80
  0x3f5528a7, 0x02031255, 0x1c21285a, 0x25230ba0,   // sw.rw.af_532 hu.nl.da_442  sw.jw.id_553 es.ca.eu_322
  0x64080202, 0x64095502, 0x021a6bee, 0x080e2104,   // da.no.lg_222 rw.pl.lg_222  ceb.tl.da_422 jw.is.no_332
  0x29200307, 0x23000204, 0x086e29ad, 0x291621ad,   // nl.sq.sl_432 da.ca.un_320  sl.blu.no_643 jw.hr.sl_643
  // [66d0]
  0x12005502, 0x0900291b, 0x28060204, 0x201225a0,   // rw.hu.un_220 sl.pl.un_770  da.de.sw_332 eu.hu.sq_322
  0x64060207, 0x0c1008ee, 0x041b12af, 0x53100fee,   // da.de.lg_432 no.lt.sv_422  hu.tr.fi_655 lv.lt.ht_422
  0x031629a4, 0x2b001a12, 0x64070e07, 0x532029ec,   // sl.hr.nl_433 tl.vi.un_640  is.it.lg_432 sl.sq.ht_644
  0x551629a7, 0x21002a0d, 0x0e2001a0, 0x020e03a0,   // sl.hr.rw_532 mt.jw.un_540  en.sq.is_322 nl.is.da_322
  // [66e0]
  0x0f122504, 0x290f03ee, 0x0d092da0, 0x063f1b02,   // eu.hu.lv_332 nl.lv.sl_422  sk.pl.cs_322 tr.af.de_222
  0x3f0d04a4, 0x1300280c, 0x10171112, 0x162b1307,   // fi.cs.af_433 sw.et.un_530  ro.sr.be_654 et.vi.hr_432
  0x16290311, 0x07000204, 0x01070504, 0x210328a9,   // nl.sl.hr_653 da.it.un_320  fr.it.en_332 sw.nl.jw_544
  0x0228010c, 0x0e000802, 0x2d005334, 0x11002019,   // en.sw.da_543 no.is.un_220  ht.sk.un_A80 sq.ro.un_750
  // [66f0]
  0x0f292012, 0x2800022a, 0x16290308, 0x00003f37,   // sq.sl.lv_654 da.sw.un_970  nl.sl.hr_443 af.un.un_B00
  0x21000f08, 0x086e2904, 0x100f1707, 0x1e121b07,   // lv.jw.un_430 sl.blu.no_332  sr.lv.lt_432 tr.hu.ms_432
  0x2d0d0cee, 0x2800291b, 0x0e002704, 0x00002d2d,   // sv.cs.sk_422 sl.sw.un_770  gd.is.un_320 sk.un.un_A00
  0x0f0c090e, 0x3f002818, 0x0a110714, 0x022508a4,   // pl.sv.lv_555 sw.af.un_740  bg.ro.mk_666 no.eu.da_433
  // [6700]
  0x0b041012, 0x1e001904, 0x09201c04, 0x0c00200e,   // lt.fi.es_654 gl.ms.un_320  id.sq.pl_332 sq.sv.un_550
  0x283f0912, 0x11000909, 0x01000805, 0x0917160e,   // pl.af.sw_654 pl.ro.un_440  no.en.un_330 hr.sr.pl_555
  0x1e09640c, 0x050108a7, 0x2d1c1fa0, 0x3f211f07,   // lg.pl.ms_543 no.en.fr_532  cy.id.sk_322 cy.jw.af_432
  0x643f2112, 0x090c1e07, 0x09286404, 0x53286455,   // jw.af.lg_654 ms.sv.pl_432  lg.sw.pl_332 lg.sw.ht_442
  // [6710]
  0x11040f05, 0x55070fa7, 0x09110f0c, 0x211a09ec,   // lv.fi.ro_333 lv.it.rw_532  lv.ro.pl_543 pl.tl.jw_644
  0x200a1ba4, 0x09002819, 0x1e001107, 0x04101314,   // tr.pt.sq_433 sw.pl.un_750  ro.ms.un_420 et.lt.fi_666
  0x64165507, 0x12000805, 0x0d0208ec, 0x200f1a0c,   // rw.hr.lg_432 no.hu.un_330  no.da.cs_644 tl.lv.sq_543
  0x05002312, 0x1729080d, 0x0d001c33, 0x0c1b120c,   // ca.fr.un_640 no.sl.sr_554  mr.ne.un_A70 hu.tr.sv_543
  // [6720]
  0x17001212, 0x1900010d, 0x3f030607, 0x2a0720a4,   // hu.sr.un_640 en.gl.un_540  de.nl.af_432 sq.it.mt_433
  0x3f030609, 0x0f230504, 0x100717a0, 0x12002d23,   // de.nl.af_444 fr.ca.lv_332  sr.bg.be_322 sk.hu.un_880
  0x276b01ee, 0x1a0204a0, 0x273f13ee, 0x0b12180c,   // en.ceb.gd_422 fi.da.tl_322  et.af.gd_422 ga.hu.es_543
  0x53311a09, 0x6e133113, 0x0f001a02, 0x31131ea4,   // tl.az.ht_444 az.et.blu_665  tl.lv.un_220 ms.et.az_433
  // [6730]
  0x030d02a0, 0x531331ec, 0x07080ca7, 0x55122807,   // da.cs.nl_322 az.et.ht_644  sv.no.it_532 sw.hu.rw_432
  0x04170707, 0x13002a21, 0x1c311e0c, 0x53281b13,   // bg.sr.ru_432 mt.et.un_860  ms.az.id_543 tr.sw.ht_665
  0x1c3153ad, 0x28002904, 0x17001636, 0x5300311a,   // ht.az.id_643 sl.sw.un_320  hr.sr.un_AA0 az.ht.un_760
  0x31006e09, 0x25002102, 0x0f2910a4, 0x03001c08,   // blu.az.un_440 jw.eu.un_220  lt.sl.lv_433 id.nl.un_430
  // [6740]
  0x1300312a, 0x2a1f6ea9, 0x212803a0, 0x160f10ec,   // az.et.un_970 blu.cy.mt_544  nl.sw.jw_322 lt.lv.hr_644
  0x19001304, 0x09200408, 0x06080ca4, 0x0a081104,   // et.gl.un_320 fi.sq.pl_443  sv.no.de_433 ro.uk.mk_332
  0x28100fee, 0x110103a0, 0x282d0dec, 0x03023f0c,   // lv.lt.sw_422 nl.en.ro_322  cs.sk.sw_644 af.da.nl_543
  0x095525ee, 0x100704a6, 0x53645507, 0x181912ad,   // eu.rw.pl_422 ru.bg.be_521  rw.lg.ht_432 hu.gl.ga_643
  // [6750]
  0x21642804, 0x19002805, 0x170e2aa4, 0x21002a02,   // sw.lg.jw_332 sw.gl.un_330  mt.is.sr_433 mt.jw.un_220
  0x2d000619, 0x102820a6, 0x1b133160, 0x6b131b08,   // de.sk.un_750 sq.sw.lt_521  az.et.tr_664 tr.et.ceb_443
  0x2b1810a0, 0x20041311, 0x6b1a20a4, 0x312a1fad,   // lt.ga.vi_322 et.fi.sq_653  sq.tl.ceb_433 cy.mt.az_643
  0x13000705, 0x3f002312, 0x201a6b07, 0x536e0512,   // it.et.un_330 ca.af.un_640  ceb.tl.sq_432 fr.blu.ht_654
  // [6760]
  0x2000060c, 0x3f092807, 0x110501a0, 0x09002812,   // de.sq.un_530 sw.pl.af_432  en.fr.ro_322 sw.pl.un_640
  0x2d120da4, 0x0d180ead, 0x041b3108, 0x0d000813,   // cs.hu.sk_433 is.ga.cs_643  az.tr.fi_443 no.cs.un_650
  0x041a0104, 0x03060ca4, 0x03003104, 0x03063f05,   // en.tl.fi_332 sv.de.nl_433  az.nl.un_320 af.de.nl_333
  0x1b1331a4, 0x210820a7, 0x23002a12, 0x1b0718a0,   // az.et.tr_433 sq.no.jw_532  mt.ca.un_640 ga.it.tr_322
  // [6770]
  0x010306ee, 0x07110a04, 0x53021b02, 0x113f0305,   // de.nl.en_422 mk.ro.bg_332  tr.da.ht_222 nl.af.ro_333
  0x01002d07, 0x13000f19, 0x31001b34, 0x03001321,   // sk.en.un_420 lv.et.un_750  tr.az.un_A80 et.nl.un_860
  0x2a000712, 0x27033f04, 0x53251b0e, 0x13100207,   // it.mt.un_640 af.nl.gd_332  tr.eu.ht_555 da.lt.et_432
  0x190b25ad, 0x0f002d08, 0x1e2031a0, 0x1b0225ec,   // eu.es.gl_643 sk.lv.un_430  az.sq.ms_322 eu.da.tr_644
  // [6780]
  0x202a1b0b, 0x102d0faf, 0x21252904, 0x04200fad,   // tr.mt.sq_542 lv.sk.lt_655  sl.eu.jw_332 lv.sq.fi_643
  0x16291b08, 0x311b25a7, 0x1b00531b, 0x091617a0,   // tr.sl.hr_443 eu.tr.az_532  ht.tr.un_770 sr.hr.pl_322
  0x213f1e11, 0x210108a0, 0x53201b07, 0x0a005302,   // ms.af.jw_653 no.en.jw_322  tr.sq.ht_432 ht.pt.un_220
  0x1a003f07, 0x1b3f1a07, 0x0a311ba4, 0x251b3160,   // af.tl.un_420 tl.af.tr_432  tr.az.pt_433 az.tr.eu_664
  // [6790]
  0x020109a7, 0x1b000202, 0x17202912, 0x050d01a0,   // pl.en.da_532 da.tr.un_220  sl.sq.sr_654 en.cs.fr_322
  0x1b0c0802, 0x21282a02, 0x1a211ba4, 0x231f3f04,   // no.sv.tr_222 mt.sw.jw_222  tr.jw.tl_433 af.cy.ca_332
  0x160f100c, 0x2d2909ee, 0x2d0d13ec, 0x291316a4,   // lt.lv.hr_543 pl.sl.sk_422  et.cs.sk_644 hr.et.sl_433
  0x281609ee, 0x3f080e04, 0x27000602, 0x04110708,   // pl.hr.sw_422 is.no.af_332  de.gd.un_220 bg.ro.ru_443
  // [67a0]
  0x0a1710ee, 0x06002707, 0x09010da0, 0x27030655,   // be.sr.mk_422 gd.de.un_420  cs.en.pl_322 de.nl.gd_442
  0x2b001702, 0x0a00101a, 0x0e275307, 0x0c532707,   // sr.vi.un_220 be.mk.un_760  ht.gd.is_432 gd.ht.sv_432
  0x09280604, 0x111353a7, 0x270a0307, 0x0c530807,   // de.sw.pl_332 ht.et.ro_532  nl.pt.gd_432 no.ht.sv_432
  0x18130612, 0x080a1107, 0x1b0208ee, 0x0655040b,   // de.et.ga_654 ro.mk.uk_432  no.da.tr_422 fi.rw.de_542
  // [67b0]
  0x0f010302, 0x2d0d0a02, 0x04081304, 0x0900290d,   // nl.en.lv_222 pt.cs.sk_222  et.no.fi_332 sl.pl.un_540
  0x053f18a7, 0x3f130907, 0x55000207, 0x1c1329a9,   // ga.af.fr_532 pl.et.af_432  da.rw.un_420 sl.et.id_544
  0x040a1112, 0x25006e0c, 0x210106a7, 0x16020ca4,   // ro.mk.ru_654 blu.eu.un_530  de.en.jw_532 sv.da.hr_433
  0x06080c11, 0x03200804, 0x040a0802, 0x09002919,   // sv.no.de_653 no.sq.nl_332  uk.mk.ru_222 sl.pl.un_750
  // [67c0]
  0x162d09a0, 0x180c3fa4, 0x0c080ea0, 0x0e1312a6,   // pl.sk.hr_322 af.sv.ga_433  is.no.sv_322 hu.et.is_521
  0x101a2804, 0x0e110407, 0x0d0a2da4, 0x04190a04,   // sw.tl.lt_332 fi.ro.is_432  sk.pt.cs_433 pt.gl.fi_332
  0x092d2908, 0x1308020e, 0x2909120b, 0x1f00641a,   // sl.sk.pl_443 da.no.et_555  hu.pl.sl_542 lg.cy.un_760
  0x03080e07, 0x091a6b0c, 0x290916a4, 0x0e311b0d,   // is.no.nl_432 ceb.tl.pl_543  hr.pl.sl_433 tr.az.is_554
  // [67d0]
  0x060c0e0b, 0x23050e0e, 0x210e1ca4, 0x311b18af,   // is.sv.de_542 is.fr.ca_555  id.is.jw_433 ga.tr.az_655
  0x081b3160, 0x1007110b, 0x050a530c, 0x0a0717ee,   // az.tr.no_664 ro.bg.be_542  ht.pt.fr_543 sr.bg.mk_422
  0x311b0e09, 0x230e0812, 0x0d001607, 0x162a29a4,   // is.tr.az_444 no.is.ca_654  hr.cs.un_420 sl.mt.hr_433
  0x2a0704af, 0x18002720, 0x071e1c0c, 0x0f04130d,   // fi.it.mt_655 gd.ga.un_850  id.ms.it_543 et.fi.lv_554
  // [67e0]
  0x2507165a, 0x3f020c04, 0x1b00310b, 0x110a1714,   // hr.it.eu_553 sv.da.af_332  az.tr.un_520 sr.mk.ro_666
  0x12042d0c, 0x0a003108, 0x280455ee, 0x1b003120,   // sk.fi.hu_543 az.pt.un_430  rw.fi.sw_422 az.tr.un_850
  0x233119ee, 0x17110404, 0x291612a0, 0x2d00050c,   // gl.az.ca_422 ru.ro.sr_332  hu.hr.sl_322 fr.sk.un_530
  0x0e001c08, 0x551a6b13, 0x2500071a, 0x23310ead,   // id.is.un_430 ceb.tl.rw_665  it.eu.un_760 is.az.ca_643
  // [67f0]
  0x0a001221, 0x122d1904, 0x192d0d12, 0x0e022105,   // hu.pt.un_860 gl.sk.hu_332  cs.sk.gl_654 jw.da.is_333
  0x642511ee, 0x040a07ac, 0x3f002804, 0x0a000508,   // ro.eu.lg_422 bg.mk.ru_632  sw.af.un_320 fr.pt.un_430
  0x172d290c, 0x0e001804, 0x290c21a0, 0x06000d0e,   // sl.sk.sr_543 ga.is.un_320  jw.sv.sl_322 cs.de.un_550
  0x282512a0, 0x21250604, 0x20110d07, 0x05002802,   // hu.eu.sw_322 de.eu.jw_332  cs.ro.sq_432 sw.fr.un_220

  // [6800]
  0x6b1a04a4, 0x28002112, 0x12002d0e, 0x170f100c,   // fi.tl.ceb_433 jw.sw.un_640  sk.hu.un_550 lt.lv.sr_543
  0x100a0808, 0x190b2da9, 0x042711af, 0x080504a4,   // uk.mk.be_443 sk.es.gl_544  ro.gd.fi_655 fi.fr.no_433
  0x0e3f040c, 0x033f0412, 0x041f0e11, 0x03061fa0,   // fi.af.is_543 fi.af.nl_654  is.cy.fi_653 cy.de.nl_322
  0x05110bee, 0x05033f02, 0x20000b02, 0x2d0d1905,   // es.ro.fr_422 af.nl.fr_222  es.sq.un_220 gl.cs.sk_333
  // [6810]
  0x04001b12, 0x03250609, 0x01070602, 0x040503a4,   // tr.fi.un_640 de.eu.nl_444  de.it.en_222 nl.fr.fi_433
  0x05040612, 0x07080a0c, 0x13036407, 0x2505040b,   // de.fi.fr_654 mk.uk.bg_543  lg.nl.et_432 fi.fr.eu_542
  0x25531aa0, 0x6b006409, 0x04002519, 0x273f0312,   // tl.ht.eu_322 lg.ceb.un_440  eu.fi.un_750 nl.af.gd_654
  0x53190a02, 0x64171605, 0x2a001a04, 0x0d001a04,   // pt.gl.ht_222 hr.sr.lg_333  tl.mt.un_320 tl.cs.un_320
  // [6820]
  0x0c3f030c, 0x0c1029a0, 0x033f64a0, 0x08000714,   // nl.af.sv_543 sl.lt.sv_322  lg.af.nl_322 bg.uk.un_660
  0x030c0807, 0x19641a05, 0x170d1607, 0x64191005,   // no.sv.nl_432 tl.lg.gl_333  hr.cs.sr_432 lt.gl.lg_333
  0x0a190b60, 0x03083f13, 0x1b315511, 0x0a190b65,   // es.gl.pt_664 af.no.nl_665  rw.az.tr_653 es.gl.pt_763
  0x0c000e09, 0x08000e1b, 0x13033fec, 0x552164ad,   // is.sv.un_440 is.no.un_770  af.nl.et_644 lg.jw.rw_643
  // [6830]
  0x12002514, 0x120d08a0, 0x100621a4, 0x3f1f0302,   // eu.hu.un_660 no.cs.hu_322  jw.de.lt_433 nl.cy.af_222
  0x1e005508, 0x0c211c0b, 0x091e1c55, 0x290c06ac,   // rw.ms.un_430 id.jw.sv_542  id.ms.pl_442 de.sv.sl_632
  0x0e120d11, 0x641a6b12, 0x092a0d07, 0x0d2d0507,   // cs.hu.is_653 ceb.tl.lg_654  cs.mt.pl_432 fr.sk.cs_432
  0x211f0aa0, 0x21081ca0, 0x0d160804, 0x0b0a12ee,   // pt.cy.jw_322 id.no.jw_322  no.hr.cs_332 hu.pt.es_422
  // [6840]
  0x201f2d0c, 0x040f2104, 0x09000413, 0x0a1f25a9,   // sk.cy.sq_543 jw.lv.fi_332  fi.pl.un_650 eu.cy.pt_544
  0x20002d0d, 0x112510a7, 0x18122107, 0x17161aa4,   // sk.sq.un_540 lt.eu.ro_532  fa.ur.ar_432 tl.hr.sr_433
  0x6b1b53a4, 0x1f171604, 0x111907a0, 0x041a53a4,   // ht.tr.ceb_433 hr.sr.cy_332  it.gl.ro_322 ht.tl.fi_433
  0x200811ac, 0x23310a07, 0x08020c02, 0x0a002314,   // ro.no.sq_632 pt.az.ca_432  sv.da.no_222 ca.pt.un_660
  // [6850]
  0x0400530d, 0x10291708, 0x0b531c13, 0x1c130d0b,   // ht.fi.un_540 sr.sl.lt_443  id.ht.es_665 ne.bh.mr_542
  0x1a006b23, 0x21041fa0, 0x28041f55, 0x3f090412,   // ceb.tl.un_880 cy.fi.jw_322  cy.fi.sw_442 fi.pl.af_654
  0x16000e08, 0x64000407, 0x130406a4, 0x6412280c,   // is.hr.un_430 fi.lg.un_420  de.fi.et_433 sw.hu.lg_543
  0x17161a09, 0x31002020, 0x1a003102, 0x162018a9,   // tl.hr.sr_444 sq.az.un_850  az.tl.un_220 ga.sq.hr_544
  // [6860]
  0x081a6ba0, 0x23000a21, 0x25645512, 0x09002a1a,   // ceb.tl.no_322 pt.ca.un_860  rw.lg.eu_654 mt.pl.un_760
  0x230b1907, 0x6b005521, 0x18071107, 0x171316a6,   // gl.es.ca_432 rw.ceb.un_860  ro.it.ga_432 hr.et.sr_521
  0x20101b08, 0x552a0414, 0x646b5308, 0x08042807,   // tr.lt.sq_443 fi.mt.rw_666  ht.ceb.lg_443 sw.fi.no_432
  0x17041055, 0x200713a9, 0x182a20a4, 0x531a2a05,   // be.ru.sr_442 et.it.sq_544  sq.mt.ga_433 mt.tl.ht_333
  // [6870]
  0x0b000708, 0x08070aa9, 0x0c001b12, 0x0b00070d,   // it.es.un_430 mk.bg.uk_544  tr.sv.un_640 it.es.un_540
  0x1a1f0b07, 0x08100a04, 0x236b0b07, 0x07041108,   // es.cy.tl_432 mk.be.uk_332  es.ceb.ca_432 ro.ru.bg_443
  0x2d001908, 0x042718a0, 0x18270107, 0x04182712,   // gl.sk.un_430 ga.gd.fi_322  en.gd.ga_432 gd.ga.fi_654
  0x04006e0c, 0x181127ee, 0x100829a0, 0x272511a9,   // blu.fi.un_530 gd.ro.ga_422  sl.no.lt_322 ro.eu.gd_544
  // [6880]
  0x0f17160b, 0x1e230704, 0x130d1ca4, 0x1127090d,   // hr.sr.lv_542 it.ca.ms_332  mr.ne.bh_433 pl.gd.ro_554
  0x3f03640e, 0x21000112, 0x192d0d02, 0x3f130309,   // lg.nl.af_555 en.jw.un_640  cs.sk.gl_222 nl.et.af_444
  0x19002807, 0x101125a4, 0x0c1a280c, 0x1311270c,   // sw.gl.un_420 eu.ro.lt_433  sw.tl.sv_543 gd.ro.et_543
  0x180a1302, 0x25282aec, 0x216b280c, 0x642129a7,   // et.pt.ga_222 mt.sw.eu_644  sw.ceb.jw_543 sl.jw.lg_532
  // [6890]
  0x2a5510a9, 0x0f292d0c, 0x0f002a07, 0x10001602,   // lt.rw.mt_544 sk.sl.lv_543  mt.lv.un_420 hr.lt.un_220
  0x171606ec, 0x020421a0, 0x0a0d2d0b, 0x01050614,   // de.hr.sr_644 jw.fi.da_322  sk.cs.pt_542 de.fr.en_666
  0x53282a02, 0x0102080b, 0x642853a4, 0x190410a7,   // mt.sw.ht_222 no.da.en_542  ht.sw.lg_433 lt.fi.gl_532
  0x0b060111, 0x55211c07, 0x17162aaf, 0x6b642807,   // en.de.es_653 id.jw.rw_432  mt.hr.sr_655 sw.lg.ceb_432
  // [68a0]
  0x1b00640c, 0x11002a0c, 0x070106a4, 0x232b0a11,   // lg.tr.un_530 mt.ro.un_530  de.en.it_433 pt.vi.ca_653
  0x050b1ea4, 0x28002a12, 0x2b041fad, 0x1c120f05,   // ms.es.fr_433 mt.sw.un_640  cy.fi.vi_643 lv.hu.id_333
  0x04033fee, 0x122d25ad, 0x292d2aee, 0x642112a4,   // af.nl.fi_422 eu.sk.hu_643  mt.sk.sl_422 hu.jw.lg_433
  0x0d002d2a, 0x1e001a08, 0x07050bee, 0x04131a08,   // sk.cs.un_970 tl.ms.un_430  es.fr.it_422 tl.et.fi_443
  // [68b0]
  0x1a3f1704, 0x01071ea7, 0x11001005, 0x070b0104,   // sr.af.tl_332 ms.it.en_532  be.ro.un_330 en.es.it_332
  0x29072d5a, 0x0a0b190b, 0x23000607, 0x310c1bee,   // sk.it.sl_553 gl.es.pt_542  de.ca.un_420 tr.sv.az_422
  0x0100060b, 0x21002304, 0x060a0e13, 0x03001e04,   // de.en.un_520 ca.jw.un_320  is.pt.de_665 ms.nl.un_320
  0x19120e0c, 0x012718ee, 0x11000419, 0x190a28ec,   // is.hu.gl_543 ga.gd.en_422  ru.ro.un_750 sw.pt.gl_644
  // [68c0]
  0x0b0a2805, 0x552821ee, 0x120c0804, 0x070412a4,   // sw.pt.es_333 jw.sw.rw_422  no.sv.hu_332 hu.fi.it_433
  0x04000c12, 0x311c1ea4, 0x21000a07, 0x28000812,   // sv.fi.un_640 ms.id.az_433  pt.jw.un_420 no.sw.un_640
  0x0c210804, 0x191e1c0d, 0x531a21a7, 0x0b00231b,   // no.jw.sv_332 id.ms.gl_554  jw.tl.ht_532 ca.es.un_770
  0x120925ad, 0x286e1b05, 0x2d001c0e, 0x06005305,   // eu.pl.hu_643 tr.blu.sw_333  id.sk.un_550 ht.de.un_330
  // [68d0]
  0x1a2a55a0, 0x27311bee, 0x18001c02, 0x08000707,   // rw.mt.tl_322 tr.az.gd_422  id.ga.un_220 it.no.un_420
  0x0c3f0ea7, 0x2a000713, 0x1c210708, 0x110a045a,   // is.af.sv_532 it.mt.un_650  it.jw.id_443 ru.mk.ro_553
  0x2d190aec, 0x0a09070c, 0x290a17a0, 0x0a1101a0,   // pt.gl.sk_644 it.pl.pt_543  sr.pt.sl_322 en.ro.pt_322
  0x130e04a0, 0x11060107, 0x1b13040c, 0x07251204,   // fi.is.et_322 en.de.ro_432  fi.et.tr_543 hu.eu.it_332
  // [68e0]
  0x6e0e01a4, 0x0b00230b, 0x1611080b, 0x081e0e07,   // en.is.blu_433 ca.es.un_520  no.ro.hr_542 is.ms.no_432
  0x090c1fa4, 0x290e0c12, 0x19000e04, 0x20033f0d,   // cy.sv.pl_433 sv.is.sl_654  is.gl.un_320 af.nl.sq_554
  0x6b0901a0, 0x18120eee, 0x55002912, 0x08130209,   // en.pl.ceb_322 is.hu.ga_422  sl.rw.un_640 da.et.no_444
  0x07170460, 0x290e0ca4, 0x281a3f07, 0x2d1218ec,   // ru.sr.bg_664 sv.is.sl_433  af.tl.sw_432 ga.hu.sk_644
  // [68f0]
  0x231b01a4, 0x19001813, 0x551b64a4, 0x0e001213,   // en.tr.ca_433 ga.gl.un_650  lg.tr.rw_433 hu.is.un_650
  0x55641a07, 0x6b090855, 0x641c1e0c, 0x64551108,   // tl.lg.rw_432 no.pl.ceb_442  ms.id.lg_543 ro.rw.lg_443
  0x1e00210e, 0x0b28530d, 0x072d0d02, 0x190b11a4,   // jw.ms.un_550 ht.sw.es_554  cs.sk.it_222 ro.es.gl_433
  0x0a230508, 0x23005305, 0x10000f2c, 0x19000a0d,   // fr.ca.pt_443 ht.ca.un_330  lv.lt.un_990 pt.gl.un_540
  // [6900]
  0x0b1804ee, 0x081004a9, 0x130817a9, 0x29002d1b,   // fi.ga.es_422 ru.be.uk_544  sr.no.et_544 sk.sl.un_770
  0x29212007, 0x0a072a08, 0x101704ad, 0x1e282013,   // sq.jw.sl_432 mt.it.pt_443  ru.sr.be_643 sq.sw.ms_665
  0x13006405, 0x2300072c, 0x232a0aa4, 0x12161b07,   // lg.et.un_330 it.ca.un_990  pt.mt.ca_433 tr.hr.hu_432
  0x1f0d2d12, 0x2a0b19ee, 0x13000429, 0x230a55a7,   // sk.cs.cy_654 gl.es.mt_422  fi.et.un_960 rw.pt.ca_532
  // [6910]
  0x29023f07, 0x31006421, 0x10551355, 0x2a13070c,   // af.da.sl_432 lg.az.un_860  et.rw.lt_442 it.et.mt_543
  0x551b6b04, 0x03110aa4, 0x12103f55, 0x2d00291b,   // ceb.tr.rw_332 pt.ro.nl_433  af.lt.hu_442 sl.sk.un_770
  0x0a0701a0, 0x101a6b07, 0x071708a9, 0x251123a9,   // en.it.pt_322 ceb.tl.lt_432  uk.sr.bg_544 ca.ro.eu_544
  0x1c531702, 0x06001c05, 0x1200050c, 0x0800010d,   // sr.ht.id_222 id.de.un_330  fr.hu.un_530 en.no.un_540
  // [6920]
  0x0e0806a0, 0x080e060c, 0x2b1a01a4, 0x0e000d04,   // de.no.is_322 de.is.no_543  en.tl.vi_433 cs.is.un_320
  0x060d6ba0, 0x040a080d, 0x19000205, 0x13001805,   // ceb.cs.de_322 uk.mk.ru_554  da.gl.un_330 ga.et.un_330
  0x110e130b, 0x080e28ec, 0x07170a60, 0x13110e05,   // et.is.ro_542 sw.is.no_644  mk.sr.bg_664 is.ro.et_333
  0x04070a0c, 0x3f08020b, 0x1f311ba7, 0x1b000107,   // mk.bg.ru_543 da.no.af_542  tr.az.cy_532 en.tr.un_420
  // [6930]
  0x12060e55, 0x3f2801a4, 0x211613a0, 0x21286411,   // is.de.hu_442 en.sw.af_433  et.hr.jw_322 lg.sw.jw_653
  0x1a04130d, 0x110e5508, 0x03020708, 0x16000602,   // et.fi.tl_554 rw.is.ro_443  it.da.nl_443 de.hr.un_220
  0x062507af, 0x021f08a9, 0x161e2908, 0x04002108,   // it.eu.de_655 no.cy.da_544  sl.ms.hr_443 jw.fi.un_430
  0x090c1f0d, 0x081007ad, 0x17070805, 0x0f07110c,   // cy.sv.pl_554 bg.be.uk_643  uk.bg.sr_333 ro.it.lv_543
  // [6940]
  0x641121ee, 0x07172908, 0x556b64ee, 0x120e110b,   // jw.ro.lg_422 sl.sr.it_443  lg.ceb.rw_422 ro.is.hu_542
  0x291e25a6, 0x1a0f6bad, 0x2064070c, 0x11000a08,   // eu.ms.sl_521 ceb.lv.tl_643  it.lg.sq_543 mk.ro.un_430
  0x2d0d0aa0, 0x2007640c, 0x10250711, 0x6b1a07a4,   // pt.cs.sk_322 lg.it.sq_543  it.eu.lt_653 it.tl.ceb_433
  0x1300020d, 0x1a6b07a9, 0x1c0111ee, 0x0b1c1ea7,   // da.et.un_540 it.ceb.tl_544  ro.en.id_422 ms.id.es_532
  // [6950]
  0x170410ee, 0x251028ee, 0x07190aec, 0x310f17a0,   // be.ru.sr_422 sw.lt.eu_422  pt.gl.it_644 sr.lv.az_322
  0x18020604, 0x25033fa0, 0x07556412, 0x1c292107,   // de.da.ga_332 af.nl.eu_322  lg.rw.it_654 jw.sl.id_432
  0x110b0a02, 0x12190dee, 0x19122d07, 0x052d0d05,   // pt.es.ro_222 cs.gl.hu_422  sk.hu.gl_432 cs.sk.fr_333
  0x55001c02, 0x0e28250c, 0x0a1007a0, 0x171664a6,   // id.rw.un_220 eu.sw.is_543  bg.be.mk_322 lg.hr.sr_521
  // [6960]
  0x0a2807ee, 0x0e002108, 0x13080304, 0x1711040c,   // it.sw.pt_422 jw.is.un_430  nl.no.et_332 ru.ro.sr_543
  0x041a64ec, 0x08002712, 0x04130313, 0x04006414,   // lg.tl.fi_644 gd.no.un_640  nl.et.fi_665 lg.fi.un_660
  0x2d006b07, 0x28046408, 0x64551f08, 0x0711080c,   // ceb.sk.un_420 lg.fi.sw_443  cy.rw.lg_443 uk.ro.bg_543
  0x211964a0, 0x31551312, 0x28550d0c, 0x13080213,   // lg.gl.jw_322 et.rw.az_654  cs.rw.sw_543 da.no.et_665
  // [6970]
  0x1e0119a4, 0x25311ba4, 0x03096412, 0x05072a13,   // gl.en.ms_433 tr.az.eu_433  lg.pl.nl_654 mt.it.fr_665
  0x190b1f0c, 0x3f120204, 0x1a536b13, 0x010602ee,   // cy.es.gl_543 da.hu.af_332  ceb.ht.tl_665 da.de.en_422
  0x0c0e0213, 0x290d08a0, 0x210f1ca4, 0x050601af,   // da.is.sv_665 no.cs.sl_322  id.lv.jw_433 en.de.fr_655
  0x2a1f01a4, 0x1f311ba9, 0x03043f13, 0x31041308,   // en.cy.mt_433 tr.az.cy_544  af.fi.nl_665 et.fi.az_443
  // [6980]
  0x1c0e6407, 0x0c022aad, 0x55000719, 0x01050ba4,   // lg.is.id_432 mt.da.sv_643  it.rw.un_750 es.fr.en_433
  0x6b006407, 0x033f64ad, 0x036404ee, 0x23000b36,   // lg.ceb.un_420 lg.af.nl_643  fi.lg.nl_422 es.ca.un_AA0
  0x130c08a4, 0x0e1c1e0c, 0x532d29ad, 0x28212907,   // no.sv.et_433 ms.id.is_543  sl.sk.ht_643 sl.jw.sw_432
  0x2b000609, 0x080e1b07, 0x0f2a09a4, 0x01003102,   // de.vi.un_440 tr.is.no_432  pl.mt.lv_433 az.en.un_220
  // [6990]
  0x29005508, 0x12190b60, 0x2a551a08, 0x0e001809,   // rw.sl.un_430 es.gl.hu_664  tl.rw.mt_443 ga.is.un_440
  0x2a1809ec, 0x170410ad, 0x060701a7, 0x23002b07,   // pl.ga.mt_644 be.ru.sr_643  en.it.de_532 vi.ca.un_420
  0x292b0a02, 0x2b1a1bad, 0x2800640e, 0x050b01ee,   // pt.vi.sl_222 tr.tl.vi_643  lg.sw.un_550 en.es.fr_422
  0x0900110d, 0x2a250413, 0x165564ad, 0x0a230b07,   // ro.pl.un_540 fi.eu.mt_665  lg.rw.hr_643 es.ca.pt_432
  // [69a0]
  0x536428ad, 0x230b250d, 0x280e5504, 0x04081711,   // sw.lg.ht_643 eu.es.ca_554  rw.is.sw_332 sr.uk.ru_653
  0x535564ec, 0x55001a07, 0x20286408, 0x255564ec,   // lg.rw.ht_644 tl.rw.un_420  lg.sw.sq_443 lg.rw.eu_644
  0x17070802, 0x10110f07, 0x6b1b530b, 0x1a0453ec,   // uk.bg.sr_222 lv.ro.lt_432  ht.tr.ceb_542 ht.fi.tl_644
  0x1a55040c, 0x0b070d04, 0x1c001702, 0x25553105,   // fi.rw.tl_543 cs.it.es_332  sr.id.un_220 az.rw.eu_333
  // [69b0]
  0x31556412, 0x6b071a09, 0x033f1c12, 0x530f5507,   // lg.rw.az_654 tl.it.ceb_444  id.af.nl_654 rw.lv.ht_432
  0x53001605, 0x04171113, 0x05190a5a, 0x6455100d,   // hr.ht.un_330 ro.sr.ru_665  pt.gl.fr_553 lt.rw.lg_554
  0x1b175507, 0x12046404, 0x3f122105, 0x13552813,   // rw.sr.tr_432 lg.fi.hu_332  jw.hu.af_333 sw.rw.et_665
  0x2a07210c, 0x31001107, 0x05001211, 0x0f16100c,   // jw.it.mt_543 ro.az.un_420  hu.fr.un_630 lt.hr.lv_543
  // [69c0]
  0x201b5507, 0x07132a04, 0x033f2107, 0x1c2a1ea4,   // rw.tr.sq_432 mt.et.it_332  jw.af.nl_432 ms.mt.id_433
  0x08000e20, 0x53006b08, 0x096b1aaf, 0x213f0ea0,   // is.no.un_850 ceb.ht.un_430  tl.ceb.pl_655 is.af.jw_322
  0x07080aaf, 0x2a110704, 0x1e1c5505, 0x1f002707,   // mk.uk.bg_655 it.ro.mt_332  rw.id.ms_333 gd.cy.un_420
  0x04001f0d, 0x031208a4, 0x10001f09, 0x1202080c,   // cy.fi.un_540 no.hu.nl_433  cy.lt.un_440 no.da.hu_543
  // [69d0]
  0x18102a04, 0x051907a0, 0x10190b04, 0x31002305,   // mt.lt.ga_332 it.gl.fr_322  es.gl.lt_332 ca.az.un_330
  0x1c1f1e12, 0x080a10a4, 0x2b000202, 0x0c110308,   // ms.cy.id_654 be.mk.uk_433  da.vi.un_220 nl.ro.sv_443
  0x3f030613, 0x0c1710a0, 0x175503a9, 0x10006b07,   // de.nl.af_665 lt.sr.sv_322  nl.rw.sr_544 ceb.lt.un_420
  0x0c3f03ec, 0x181912ec, 0x066401a4, 0x18002d13,   // nl.af.sv_644 hu.gl.ga_644  en.lg.de_433 sk.ga.un_650
  // [69e0]
  0x021b13a4, 0x170a10ee, 0x06210207, 0x23003f07,   // et.tr.da_433 be.mk.sr_422  da.jw.de_432 af.ca.un_420
  0x6403060b, 0x21031313, 0x10000207, 0x11530660,   // de.nl.lg_542 et.nl.jw_665  da.lt.un_420 de.ht.ro_664
  0x29000d0e, 0x6b1a64a4, 0x1155070c, 0x19000512,   // cs.sl.un_550 lg.tl.ceb_433  it.rw.ro_543 fr.gl.un_640
  0x02033f11, 0x31001a0e, 0x170a04a9, 0x3f000d08,   // af.nl.da_653 tl.az.un_550  ru.mk.sr_544 cs.af.un_430
  // [69f0]
  0x0f121607, 0x21001704, 0x080428a7, 0x1a311bad,   // hr.hu.lv_432 sr.jw.un_320  sw.fi.no_532 tr.az.tl_643
  0x04000913, 0x64001e08, 0x21002007, 0x10000a19,   // pl.fi.un_650 ms.lg.un_430  sq.jw.un_420 mk.be.un_750
  0x1f276ba7, 0x0b640107, 0x0610120c, 0x3f2d0d55,   // ceb.gd.cy_532 en.lg.es_432  hu.lt.de_543 cs.sk.af_442
  0x29000522, 0x070a11a6, 0x0802130c, 0x202912a9,   // fr.sl.un_870 ro.mk.bg_521  et.da.no_543 hu.sl.sq_544
  // [6a00]
  0x21000511, 0x0000082d, 0x0e052155, 0x071b1102,   // fr.jw.un_630 no.un.un_A00  jw.fr.is_442 ro.tr.it_222
  0x080d1911, 0x1b642805, 0x0b0d53a0, 0x3f00530c,   // gl.cs.no_653 sw.lg.tr_333  ht.cs.es_322 ht.af.un_530
  0x211a3f05, 0x0b000112, 0x55001b02, 0x2a00130e,   // af.tl.jw_333 en.es.un_640  tr.rw.un_220 et.mt.un_550
  0x04001a0e, 0x0d0553a0, 0x53000409, 0x53050108,   // tl.fi.un_550 ht.fr.cs_322  fi.ht.un_440 en.fr.ht_443
  // [6a10]
  0x250428a0, 0x1c551e12, 0x0a04170e, 0x550421a4,   // sw.fi.eu_322 ms.rw.id_654  sr.ru.mk_555 jw.fi.rw_433
  0x21531108, 0x2b6b010c, 0x1e1c53ec, 0x21645511,   // ro.ht.jw_443 en.ceb.vi_543  ht.id.ms_644 rw.lg.jw_653
  0x0811040e, 0x07005529, 0x05190a55, 0x1e1c31a4,   // ru.ro.uk_555 rw.it.un_960  pt.gl.fr_442 az.id.ms_433
  0x1e001c34, 0x0b192d07, 0x07000e12, 0x2d006e05,   // id.ms.un_A80 sk.gl.es_432  is.it.un_640 blu.sk.un_330
  // [6a20]
  0x0f2528ac, 0x01251904, 0x17160f09, 0x17100407,   // sw.eu.lv_632 gl.eu.en_332  lv.hr.sr_444 ru.be.sr_432
  0x11001b0b, 0x07002a12, 0x20041ea0, 0x12190a07,   // tr.ro.un_520 mt.it.un_640  ms.fi.sq_322 pt.gl.hu_432
  0x0f000714, 0x0410070b, 0x211c1108, 0x2d0d0ab6,   // it.lv.un_660 bg.be.ru_542  ro.id.jw_443 pt.cs.sk_766
  0x55212055, 0x10070407, 0x112a070e, 0x290c0804,   // sq.jw.rw_442 fi.it.lt_432  it.mt.ro_555 no.sv.sl_332
  // [6a30]
  0x12006b14, 0x64135513, 0x0b642504, 0x290f16a4,   // ceb.hu.un_660 rw.et.lg_665  eu.lg.es_332 hr.lv.sl_433
  0x25002113, 0x090d2dee, 0x2d0d3fa9, 0x062d0d55,   // jw.eu.un_650 sk.cs.pl_422  af.cs.sk_544 cs.sk.de_442
  0x03083f08, 0x010306a0, 0x1300120e, 0x062d0d14,   // af.no.nl_443 de.nl.en_322  hu.et.un_550 cs.sk.de_666
  0x295301a0, 0x280664ee, 0x06033f02, 0x216e6b04,   // en.ht.sl_322 lg.de.sw_422  af.nl.de_222 ceb.blu.jw_332
  // [6a40]
  0x0c171608, 0x55002505, 0x0f200207, 0x0c0d2da4,   // hr.sr.sv_443 eu.rw.un_330  da.sq.lv_432 sk.cs.sv_433
  0x100455a7, 0x042d1ba4, 0x2d0d0614, 0x07110112,   // rw.fi.lt_532 tr.sk.fi_433  de.cs.sk_666 en.ro.it_654
  0x13005505, 0x09060d02, 0x0a170412, 0x08071108,   // rw.et.un_330 cs.de.pl_222  ru.sr.mk_654 ro.bg.uk_443
  0x0400550d, 0x07080a13, 0x64045507, 0x170a0855,   // rw.fi.un_540 mk.uk.bg_665  rw.fi.lg_432 uk.mk.sr_442
  // [6a50]
  0x073f080c, 0x08021b07, 0x03001708, 0x1000130d,   // no.af.it_543 tr.da.no_432  sr.nl.un_430 et.lt.un_540
  0x2d3f0308, 0x0c17290c, 0x0f1003ee, 0x10081108,   // nl.af.sk_443 sl.sr.sv_543  nl.lt.lv_422 ro.uk.be_443
  0x1000550d, 0x0a111904, 0x64315507, 0x6455280c,   // rw.lt.un_540 gl.ro.pt_332  rw.az.lg_432 sw.rw.lg_543
  0x25210107, 0x030c2102, 0x2d0d55a4, 0x2b3f2aa0,   // en.jw.eu_432 jw.sv.nl_222  rw.cs.sk_433 mt.af.vi_322
  // [6a60]
  0x160d2905, 0x04001f08, 0x13000e08, 0x070411ee,   // sl.cs.hr_333 cy.fi.un_430  is.et.un_430 ro.ru.bg_422
  0x0d033f12, 0x100f0407, 0x1a106b13, 0x0a00111a,   // af.nl.cs_654 fi.lv.lt_432  ceb.lt.tl_665 ro.mk.un_760
  0x23042ba4, 0x100b0712, 0x1a1716ec, 0x121f10ee,   // vi.fi.ca_433 it.es.lt_654  hr.sr.tl_644 lt.cy.hu_422
  0x172306a0, 0x08170702, 0x270c020c, 0x0b041305,   // de.ca.sr_322 bg.sr.uk_222  da.sv.gd_543 et.fi.es_333
  // [6a70]
  0x251a5560, 0x27181a12, 0x6e070baf, 0x08026b02,   // rw.tl.eu_664 tl.ga.gd_654  es.it.blu_655 ceb.da.no_222
  0x046b1aaf, 0x091f01ee, 0x0900132a, 0x1a28100c,   // tl.ceb.fi_655 en.cy.pl_422  bh.hi.un_970 lt.sw.tl_543
  0x120d06ac, 0x19000a36, 0x095529a9, 0x042112a4,   // de.cs.hu_632 pt.gl.un_AA0  sl.rw.pl_544 hu.jw.fi_433
  0x211a28ad, 0x162b1804, 0x0c2021a0, 0x531f27a9,   // sw.tl.jw_643 ga.vi.hr_332  jw.sq.sv_322 gd.cy.ht_544
  // [6a80]
  0x21071c07, 0x010c23ac, 0x552d030d, 0x1a126ba7,   // id.it.jw_432 ca.sv.en_632  nl.sk.rw_554 ceb.hu.tl_532
  0x00005342, 0x1e201355, 0x2d0d1109, 0x1b281ca0,   // ht.un.un_C00 et.sq.ms_442  ro.cs.sk_444 id.sw.tr_322
  0x02062504, 0x55001304, 0x53271111, 0x0600012b,   // eu.de.da_332 et.rw.un_320  ro.gd.ht_653 en.de.un_980
  0x190a23a0, 0x05001c04, 0x2b532dad, 0x21281e07,   // ca.pt.gl_322 id.fr.un_320  sk.ht.vi_643 ms.sw.jw_432
  // [6a90]
  0x066455a9, 0x18060111, 0x00000137, 0x1200231a,   // rw.lg.de_544 en.de.ga_653  en.un.un_B00 ca.hu.un_760
  0x07110aec, 0x6b1a2108, 0x12000a0d, 0x0e2718ad,   // mk.ro.bg_644 jw.tl.ceb_443  pt.hu.un_540 ga.gd.is_643
  0x02190b0c, 0x092321a4, 0x091c21a7, 0x3f0921a4,   // es.gl.da_543 jw.ca.pl_433  jw.id.pl_532 jw.pl.af_433
  0x1c090d05, 0x272a2008, 0x101c1e0c, 0x27211ea0,   // ne.hi.mr_333 sq.mt.gd_443  ms.id.lt_543 ms.jw.gd_322
  // [6aa0]
  0x2921100c, 0x0600210e, 0x0d2a21ee, 0x3f0306ad,   // lt.jw.sl_543 jw.de.un_550  jw.mt.cs_422 de.nl.af_643
  0x6400100c, 0x1c1e0e11, 0x556421ad, 0x013f2155,   // lt.lg.un_530 is.ms.id_653  jw.lg.rw_643 jw.af.en_442
  0x0f001e08, 0x1a002812, 0x256b1a12, 0x2d000613,   // ms.lv.un_430 sw.tl.un_640  tl.ceb.eu_654 de.sk.un_650
  0x5500642c, 0x033f0ead, 0x641c2111, 0x551b25ec,   // lg.rw.un_990 is.af.nl_643  jw.id.lg_653 eu.tr.rw_644
  // [6ab0]
  0x04000a19, 0x29001e02, 0x181f275a, 0x6413250d,   // mk.ru.un_750 ms.sl.un_220  gd.cy.ga_553 eu.et.lg_554
  0x312925a0, 0x0e202802, 0x192a0709, 0x10041714,   // eu.sl.az_322 sw.sq.is_222  it.mt.gl_444 sr.ru.be_666
  0x0208010c, 0x0a002d11, 0x12080402, 0x04200e07,   // en.no.da_543 sk.pt.un_630  fi.no.hu_222 is.sq.fi_432
  0x282164a7, 0x131b29a4, 0x17160dac, 0x2d0d2002,   // lg.jw.sw_532 sl.tr.et_433  cs.hr.sr_632 sq.cs.sk_222
  // [6ac0]
  0x0e002d04, 0x07130455, 0x2d1f0104, 0x0b1f5355,   // sk.is.un_320 fi.et.it_442  en.cy.sk_332 ht.cy.es_442
  0x0e000218, 0x070410a0, 0x122a29a0, 0x21121312,   // da.is.un_740 be.ru.bg_322  sl.mt.hu_322 et.hu.jw_654
  0x0a081055, 0x29205304, 0x2900110b, 0x293f0c04,   // be.uk.mk_442 ht.sq.sl_332  ro.sl.un_520 sv.af.sl_332
  0x281304ad, 0x6b001309, 0x0300010c, 0x21002013,   // fi.et.sw_643 et.ceb.un_440  en.nl.un_530 sq.jw.un_650
  // [6ad0]
  0x12005507, 0x0c001c02, 0x20292155, 0x1e642102,   // rw.hu.un_420 id.sv.un_220  jw.sl.sq_442 jw.lg.ms_222
  0x18042708, 0x051c04ec, 0x1a182707, 0x271718af,   // gd.fi.ga_443 fi.id.fr_644  gd.ga.tl_432 ga.sr.gd_655
  0x53003f04, 0x0c11010c, 0x25041a0c, 0x06000e04,   // af.ht.un_320 en.ro.sv_543  tl.fi.eu_543 is.de.un_320
  0x050b0107, 0x070105a0, 0x18000a07, 0x020e06a0,   // en.es.fr_432 fr.en.it_322  pt.ga.un_420 de.is.da_322
  // [6ae0]
  0x05281f0b, 0x10252713, 0x08006e19, 0x21033fa0,   // cy.sw.fr_542 gd.eu.lt_665  blu.no.un_750 af.nl.jw_322
  0x0c002105, 0x1110535a, 0x13091c5a, 0x0c001e08,   // jw.sv.un_330 ht.lt.ro_553  mr.hi.bh_553 ms.sv.un_430
  0x19051113, 0x282d0d13, 0x111a07ee, 0x17272d05,   // ro.fr.gl_665 cs.sk.sw_665  it.tl.ro_422 sk.gd.sr_333
  0x0104050c, 0x02001b07, 0x080216a4, 0x0525010c,   // fr.fi.en_543 tr.da.un_420  hr.da.no_433 en.eu.fr_543
  // [6af0]
  0x02000312, 0x2531040c, 0x21020807, 0x1f000e02,   // nl.da.un_640 fi.az.eu_543  no.da.jw_432 is.cy.un_220
  0x6b000408, 0x08130204, 0x011e6407, 0x060817a0,   // fi.ceb.un_430 da.et.no_332  lg.ms.en_432 sr.no.de_322
  0x07170aec, 0x0408075a, 0x16006405, 0x080225af,   // mk.sr.bg_644 bg.uk.ru_553  lg.hr.un_330 eu.da.no_655
  0x04101708, 0x0c08120c, 0x0d001813, 0x29080204,   // sr.be.ru_443 hu.no.sv_543  ga.cs.un_650 da.no.sl_332
  // [6b00]
  0x11001b11, 0x1217160c, 0x0f000307, 0x021b08a4,   // tr.ro.un_630 hr.sr.hu_543  nl.lv.un_420 no.tr.da_433
  0x1b0c0804, 0x16211207, 0x11002505, 0x0a071109,   // no.sv.tr_332 hu.jw.hr_432  eu.ro.un_330 ro.bg.mk_444
  0x2a112508, 0x091629a0, 0x17161202, 0x31001304,   // eu.ro.mt_443 sl.hr.pl_322  hu.hr.sr_222 et.az.un_320
  0x0a1218ee, 0x122529ad, 0x25001123, 0x286409a4,   // ga.hu.pt_422 sl.eu.hu_643  ro.eu.un_880 pl.lg.sw_433
  // [6b10]
  0x1a002511, 0x08000309, 0x10070a02, 0x6e006b05,   // eu.tl.un_630 nl.no.un_440  mk.bg.be_222 ceb.blu.un_330
  0x17161b05, 0x25281ea0, 0x17160eee, 0x10081712,   // tr.hr.sr_333 ms.sw.eu_322  is.hr.sr_422 sr.uk.be_654
  0x201a28ee, 0x05000411, 0x23171004, 0x081707ee,   // sw.tl.sq_422 fi.fr.un_630  lt.sr.ca_332 bg.sr.uk_422
  0x19000109, 0x02081b0c, 0x0e001c02, 0x2d1e09a4,   // en.gl.un_440 tr.no.da_543  id.is.un_220 pl.ms.sk_433
  // [6b20]
  0x1e092d0c, 0x09002d22, 0x211f09ad, 0x53006402,   // sk.pl.ms_543 sk.pl.un_870  pl.cy.jw_643 lg.ht.un_220
  0x06000d05, 0x20002d13, 0x291609a4, 0x2d001e0d,   // cs.de.un_330 sk.sq.un_650  pl.hr.sl_433 ms.sk.un_540
  0x3100250e, 0x12171602, 0x1b102a07, 0x0b001c05,   // eu.az.un_550 hr.sr.hu_222  mt.lt.tr_432 id.es.un_330
  0x202d29a7, 0x292d0914, 0x53080e11, 0x011719a0,   // sl.sk.sq_532 pl.sk.sl_666  is.no.ht_653 gl.sr.en_322
  // [6b30]
  0x100a04af, 0x12005308, 0x040b10a6, 0x6b002b05,   // ru.mk.be_655 ht.hu.un_430  lt.es.fi_521 vi.ceb.un_330
  0x13001014, 0x06001f0c, 0x1a190aa0, 0x29022dad,   // lt.et.un_660 cy.de.un_530  pt.gl.tl_322 sk.da.sl_643
  0x09202da4, 0x131b0fec, 0x53072aa0, 0x2528640c,   // sk.sq.pl_433 lv.tr.et_644  mt.it.ht_322 lg.sw.eu_543
  0x080f2dad, 0x6e001e0d, 0x20002a08, 0x20002711,   // sk.lv.no_643 ms.blu.un_540  mt.sq.un_430 gd.sq.un_630
  // [6b40]
  0x55000c02, 0x2d0d18ed, 0x316455a4, 0x281a2004,   // sv.rw.un_220 ga.cs.sk_622  rw.lg.az_433 sq.tl.sw_332
  0x552a28ad, 0x13640f0c, 0x17000f21, 0x10041107,   // sw.mt.rw_643 lv.lg.et_543  lv.sr.un_860 ro.ru.be_432
  0x1a046407, 0x130f28ec, 0x040306a0, 0x2d001b0c,   // lg.fi.tl_432 sw.lv.et_644  de.nl.fi_322 tr.sk.un_530
  0x640413af, 0x04061907, 0x100a0f08, 0x171a6b13,   // et.fi.lg_655 gl.de.fi_432  lv.pt.lt_443 ceb.tl.sr_665
  // [6b50]
  0x3f0403ad, 0x1a136408, 0x03133fec, 0x130464ee,   // nl.fi.af_643 lg.et.tl_443  af.et.nl_644 lg.fi.et_422
  0x31550fa4, 0x1a1364ec, 0x060701ac, 0x6e2d2b0c,   // lv.rw.az_433 lg.et.tl_644  en.it.de_632 vi.sk.blu_543
  0x0f2864af, 0x53010555, 0x0f28550c, 0x0a0d18b3,   // lg.sw.lv_655 fr.en.ht_442  rw.sw.lv_543 ga.cs.pt_743
  0x081307a4, 0x0d0309a7, 0x3100640d, 0x211c25a0,   // it.et.no_433 pl.nl.cs_532  lg.az.un_540 eu.id.jw_322
  // [6b60]
  0x0100062c, 0x131b0407, 0x3f2864ec, 0x64280308,   // de.en.un_990 fi.tr.et_432  lg.sw.af_644 nl.sw.lg_443
  0x112b0c08, 0x070417af, 0x1a081ba0, 0x130464ad,   // sv.vi.ro_443 sr.ru.bg_655  tr.no.tl_322 lg.fi.et_643
  0x3f1a030c, 0x0c1a6bee, 0x00001f42, 0x2d0d0c02,   // nl.tl.af_543 ceb.tl.sv_422  cy.un.un_C00 sv.cs.sk_222
  0x030d2907, 0x01000708, 0x050c0604, 0x0b0701a0,   // sl.cs.nl_432 it.en.un_430  de.sv.fr_332 en.it.es_322
  // [6b70]
  0x083f030c, 0x100f08a4, 0x080c0f04, 0x050408a0,   // nl.af.no_543 no.lv.lt_433  lv.sv.no_332 no.fi.fr_322
  0x070a0c02, 0x0e001309, 0x21003108, 0x10002302,   // sv.pt.it_222 et.is.un_440  az.jw.un_430 ca.lt.un_220
  0x1a003f05, 0x0f2010a7, 0x18210f02, 0x070b2a07,   // af.tl.un_330 lt.sq.lv_532  lv.jw.ga_222 mt.es.it_432
  0x05001a02, 0x1a005519, 0x19002313, 0x07170805,   // tl.fr.un_220 rw.tl.un_750  ca.gl.un_650 uk.sr.bg_333
  // [6b80]
  0x1c001a02, 0x1c281e12, 0x06250c05, 0x1f001322,   // tl.id.un_220 ms.sw.id_654  sv.eu.de_333 et.cy.un_870
  0x310d1fa4, 0x031a6b09, 0x0d001a09, 0x2a136e12,   // cy.cs.az_433 ceb.tl.nl_444  tl.cs.un_440 blu.et.mt_654
  0x2909080c, 0x1b0a19ee, 0x2a211604, 0x1f0802a9,   // no.pl.sl_543 gl.pt.tr_422  hr.jw.mt_332 da.no.cy_544
  0x0c6b1a12, 0x2a080202, 0x0600020e, 0x2b000608,   // tl.ceb.sv_654 da.no.mt_222  da.de.un_550 de.vi.un_430
  // [6b90]
  0x29001105, 0x270e1ca0, 0x2a1b11a0, 0x6e2a1f13,   // ro.sl.un_330 id.is.gd_322  ro.tr.mt_322 cy.mt.blu_665
  0x020c0f0c, 0x13002a14, 0x1e0625a4, 0x19110107,   // lv.sv.da_543 mt.et.un_660  eu.de.ms_433 en.ro.gl_432
  0x290806a4, 0x3f000722, 0x530806a7, 0x3f020707,   // de.no.sl_433 it.af.un_870  de.no.ht_532 it.da.af_432
  0x020119a0, 0x02001a04, 0x13001121, 0x083f0ea0,   // gl.en.da_322 tl.da.un_320  ro.et.un_860 is.af.no_322
  // [6ba0]
  0x1200060e, 0x270c18a6, 0x021206a0, 0x0a0711a9,   // de.hu.un_550 ga.sv.gd_521  de.hu.da_322 ro.bg.mk_544
  0x1c1a6e09, 0x0c081c0c, 0x033f0255, 0x17080455,   // blu.tl.id_444 id.no.sv_543  da.af.nl_442 ru.uk.sr_442
  0x3f000c04, 0x0600070c, 0x23000207, 0x10080712,   // sv.af.un_320 it.de.un_530  da.ca.un_420 bg.uk.be_654
  0x2b1f200b, 0x122a530c, 0x12002d07, 0x296b20ee,   // sq.cy.vi_542 ht.mt.hu_543  sk.hu.un_420 sq.ceb.sl_422
  // [6bb0]
  0x031129a0, 0x31531208, 0x3f005319, 0x311b6ba7,   // sl.ro.nl_322 hu.ht.az_443  ht.af.un_750 ceb.tr.az_532
  0x06001207, 0x3f1b6ba0, 0x01033f04, 0x53210f0c,   // hu.de.un_420 ceb.tr.af_322  af.nl.en_332 lv.jw.ht_543
  0x2b1123ad, 0x081153ee, 0x07051fa0, 0x16292d0b,   // ca.ro.vi_643 ht.ro.no_422  cy.fr.it_322 sk.sl.hr_542
  0x2b0501a7, 0x1b006b19, 0x12001119, 0x531b1ea4,   // en.fr.vi_532 ceb.tr.un_750  ro.hu.un_750 ms.tr.ht_433
  // [6bc0]
  0x531f11af, 0x11001922, 0x080a0108, 0x1f2d5307,   // ro.cy.ht_655 gl.ro.un_870  en.pt.no_443 ht.sk.cy_432
  0x1b002821, 0x1f211ca4, 0x13006b22, 0x0b010505,   // sw.tr.un_860 id.jw.cy_433  ceb.et.un_870 fr.en.es_333
  0x53172d0c, 0x056b1aa9, 0x1e1c02a9, 0x531b64ee,   // sk.sr.ht_543 tl.ceb.fr_544  da.id.ms_544 lg.tr.ht_422
  0x1e2b530c, 0x20190b5a, 0x082b530c, 0x1203010c,   // ht.vi.ms_543 es.gl.sq_553  ht.vi.no_543 en.nl.hu_543
  // [6bd0]
  0x64000207, 0x1b316b0c, 0x1c100655, 0x1b0f21a7,   // da.lg.un_420 ceb.az.tr_543  de.lt.id_442 jw.lv.tr_532
  0x2b2510a0, 0x02006b08, 0x29006e04, 0x0f6e060c,   // lt.eu.vi_322 ceb.da.un_430  blu.sl.un_320 de.blu.lv_543
  0x1c041e04, 0x6e00210d, 0x1c210607, 0x12051ba4,   // ms.fi.id_332 jw.blu.un_540  de.jw.id_432 tr.fr.hu_433
  0x1a6e6b0c, 0x0b25050c, 0x1704080c, 0x290525ad,   // ceb.blu.tl_543 fr.eu.es_543  uk.ru.sr_543 eu.fr.sl_643
  // [6be0]
  0x0500120d, 0x05010ba0, 0x3f1f0804, 0x1c021307,   // hu.fr.un_540 es.en.fr_322  no.cy.af_332 et.da.id_432
  0x051823ee, 0x1220250b, 0x0b2011a0, 0x231105a6,   // ca.ga.fr_422 eu.sq.hu_542  ro.sq.es_322 fr.ro.ca_521
  0x12052560, 0x292d16a4, 0x10002d0d, 0x230425ad,   // eu.fr.hu_664 hr.sk.sl_433  sk.lt.un_540 eu.fi.ca_643
  0x092a25ee, 0x1b000509, 0x0e190ba4, 0x29171104,   // eu.mt.pl_422 fr.tr.un_440  es.gl.is_433 ro.sr.sl_332
  // [6bf0]
  0x25311b04, 0x18052a05, 0x131b25ad, 0x110525a4,   // tr.az.eu_332 mt.fr.ga_333  eu.tr.et_643 eu.fr.ro_433
  0x1c0d13a4, 0x04002511, 0x031f23a0, 0x1105255a,   // bh.ne.mr_433 eu.fi.un_630  ca.cy.nl_322 eu.fr.ro_553
  0x05042904, 0x6b000305, 0x25200508, 0x112505ad,   // sl.fi.fr_332 nl.ceb.un_330  fr.sq.eu_443 fr.eu.ro_643
  0x2d290daf, 0x1a001307, 0x171627a0, 0x07000420,   // cs.sl.sk_655 et.tl.un_420  gd.hr.sr_322 fi.it.un_850

  // [6c00]
  0x11001a04, 0x111827ad, 0x1e216ba0, 0x532801a4,   // tl.ro.un_320 gd.ga.ro_643  ceb.jw.ms_322 en.sw.ht_433
  0x032d0d04, 0x0d1617ad, 0x0a0817ee, 0x070a04ec,   // cs.sk.nl_332 sr.hr.cs_643  sr.uk.mk_422 ru.mk.bg_644
  0x055564ee, 0x271801a9, 0x190b01a9, 0x13052a04,   // lg.rw.fr_422 en.ga.gd_544  en.es.gl_544 mt.fr.et_332
  0x12286e0b, 0x11270107, 0x062a0711, 0x122916a7,   // blu.sw.hu_542 en.gd.ro_432  it.mt.de_653 hr.sl.hu_532
  // [6c10]
  0x530801ee, 0x12006e08, 0x07181108, 0x641203a0,   // en.no.ht_422 blu.hu.un_430  ro.ga.it_443 nl.hu.lg_322
  0x11281907, 0x11080204, 0x5308050c, 0x081302ec,   // gl.sw.ro_432 da.no.ro_332  fr.no.ht_543 da.et.no_644
  0x29000e04, 0x0e002307, 0x2b2d0d02, 0x1a00551b,   // is.sl.un_320 ca.is.un_420  cs.sk.vi_222 rw.tl.un_770
  0x0f000c0d, 0x05002109, 0x136e1aad, 0x170a070b,   // sv.lv.un_540 jw.fr.un_440  tl.blu.et_643 bg.mk.sr_542
  // [6c20]
  0x0d001f12, 0x1f092d04, 0x201e1c60, 0x5300070e,   // cy.cs.un_640 sk.pl.cy_332  id.ms.sq_664 it.ht.un_550
  0x122301a4, 0x20006b35, 0x16130460, 0x07002a35,   // en.ca.hu_433 ceb.sq.un_A90  fi.et.hr_664 mt.it.un_A90
  0x083f0b0c, 0x073f2aee, 0x050b2314, 0x0506010d,   // es.af.no_543 mt.af.it_422  ca.es.fr_666 en.de.fr_554
  0x110b1b08, 0x031a2804, 0x0b0208ac, 0x6e001313,   // tr.es.ro_443 sw.tl.nl_332  no.da.es_632 et.blu.un_650
  // [6c30]
  0x29160307, 0x6b641a0e, 0x022b11ad, 0x182511af,   // nl.hr.sl_432 tl.lg.ceb_555  ro.vi.da_643 ro.eu.ga_655
  0x201b0808, 0x07002323, 0x092d06ec, 0x25211ca4,   // no.tr.sq_443 ca.it.un_880  de.sk.pl_644 id.jw.eu_433
  0x05000713, 0x21001313, 0x2b6e1913, 0x1a006b34,   // it.fr.un_650 et.jw.un_650  gl.blu.vi_665 ceb.tl.un_A80
  0x1900130c, 0x120a0d07, 0x00000c37, 0x2005010c,   // et.gl.un_530 cs.pt.hu_432  sv.un.un_B00 en.fr.sq_543
  // [6c40]
  0x1a256b12, 0x0c00230c, 0x210b23a4, 0x216b2b13,   // ceb.eu.tl_654 ca.sv.un_530  ca.es.jw_433 vi.ceb.jw_665
  0x10171611, 0x531a6b12, 0x1f3f01a9, 0x1a2953af,   // hr.sr.lt_653 ceb.tl.ht_654  en.af.cy_544 ht.sl.tl_655
  0x0a556bec, 0x6b1c1a55, 0x023f060c, 0x311b050e,   // ceb.rw.pt_644 tl.id.ceb_442  de.af.da_543 fr.tr.az_555
  0x5323110e, 0x0c033f09, 0x53202aec, 0x281b3104,   // ro.ca.ht_555 af.nl.sv_444  mt.sq.ht_644 az.tr.sw_332
  // [6c50]
  0x1b001704, 0x530a1b07, 0x201611a0, 0x3f0329af,   // sr.tr.un_320 tr.pt.ht_432  ro.hr.sq_322 sl.nl.af_655
  0x1e5531a4, 0x20033f09, 0x29003f11, 0x091716ad,   // az.rw.ms_433 af.nl.sq_444  af.sl.un_630 hr.sr.pl_643
  0x180f0302, 0x1b1e280c, 0x28311b12, 0x05000722,   // nl.lv.ga_222 sw.ms.tr_543  tr.az.sw_654 it.fr.un_870
  0x046b1a5a, 0x023f0ca0, 0x6b3121a9, 0x0f000b12,   // tl.ceb.fi_553 sv.af.da_322  jw.az.ceb_544 es.lv.un_640
  // [6c60]
  0x13043108, 0x281a6bee, 0x1c000305, 0x0d0208a0,   // az.fi.et_443 ceb.tl.sw_422  nl.id.un_330 no.da.cs_322
  0x17161b0c, 0x02002907, 0x12251bac, 0x1b171608,   // tr.hr.sr_543 sl.da.un_420  tr.eu.hu_632 hr.sr.tr_443
  0x23012a02, 0x281b55a7, 0x10000818, 0x6b003f04,   // mt.en.ca_222 rw.tr.sw_532  uk.be.un_740 af.ceb.un_320
  0x130a01a4, 0x0d040707, 0x0c000708, 0x552521a4,   // en.pt.et_433 it.fi.cs_432  it.sv.un_430 jw.eu.rw_433
  // [6c70]
  0x25031bee, 0x29005314, 0x290816a0, 0x2a080cee,   // tr.nl.eu_422 ht.sl.un_660  hr.no.sl_322 sv.no.mt_422
  0x13000c05, 0x0511010b, 0x04000314, 0x64041ea4,   // sv.et.un_330 en.ro.fr_542  nl.fi.un_660 ms.fi.lg_433
  0x07081755, 0x121b04a4, 0x55281b13, 0x0c0f25ad,   // sr.uk.bg_442 fi.tr.hu_433  tr.sw.rw_665 eu.lv.sv_643
  0x046421af, 0x071710ee, 0x08002a0c, 0x19641c07,   // jw.lg.fi_655 be.sr.bg_422  mt.no.un_530 id.lg.gl_432
  // [6c80]
  0x071811a0, 0x53551b05, 0x53002b07, 0x18001a04,   // ro.ga.it_322 tr.rw.ht_333  vi.ht.un_420 tl.ga.un_320
  0x07271fa7, 0x0c002705, 0x21641e04, 0x12042aee,   // cy.gd.it_532 gd.sv.un_330  ms.lg.jw_332 mt.fi.hu_422
  0x190410a4, 0x0800110e, 0x27181fa7, 0x53000121,   // lt.fi.gl_433 ro.uk.un_550  cy.ga.gd_532 en.ht.un_860
  0x55211b12, 0x130604ec, 0x0a2b01a7, 0x21100407,   // tr.jw.rw_654 fi.de.et_644  en.vi.pt_532 fi.lt.jw_432
  // [6c90]
  0x130e0407, 0x100f0eee, 0x101b2504, 0x11040705,   // fi.is.et_432 is.lv.lt_422  eu.tr.lt_332 bg.ru.ro_333
  0x2500530c, 0x130131a0, 0x311f07a7, 0x1a006b2a,   // ht.eu.un_530 az.en.et_322  it.cy.az_532 ceb.tl.un_970
  0x6b1a64a9, 0x0e00102a, 0x181327ad, 0x251c3fee,   // lg.tl.ceb_544 lt.is.un_970  gd.et.ga_643 af.id.eu_422
  0x07190fee, 0x07081007, 0x11002b05, 0x07052704,   // lv.gl.it_422 be.uk.bg_432  vi.ro.un_330 gd.fr.it_332
  // [6ca0]
  0x1706160c, 0x6b0201a0, 0x29000404, 0x100804a9,   // hr.de.sr_543 en.da.ceb_322  fi.sl.un_320 ru.uk.be_544
  0x3f006409, 0x1716200e, 0x64006b07, 0x101117a9,   // lg.af.un_440 sq.hr.sr_555  ceb.lg.un_420 sr.ro.be_544
  0x2a230702, 0x122016a4, 0x02171604, 0x040a08ad,   // it.ca.mt_222 hr.sq.hu_433  hr.sr.da_332 uk.mk.ru_643
  0x08070460, 0x1c000805, 0x0d162905, 0x2d000f1a,   // ru.bg.uk_664 no.id.un_330  sl.hr.cs_333 lv.sk.un_760
  // [6cb0]
  0x0a1708af, 0x0100041b, 0x3f1b0f04, 0x1b000302,   // uk.sr.mk_655 fi.en.un_770  lv.tr.af_332 nl.tr.un_220
  0x08000a14, 0x10040702, 0x250f1204, 0x280d20a0,   // mk.uk.un_660 bg.ru.be_222  hu.lv.eu_332 sq.cs.sw_322
  0x022906a6, 0x551e1a0b, 0x0b12190c, 0x181912a9,   // de.sl.da_521 tl.ms.rw_542  gl.hu.es_543 hu.gl.ga_544
  0x64552804, 0x040208ee, 0x101711a7, 0x051827ad,   // sw.rw.lg_332 no.da.fi_422  ro.sr.be_532 gd.ga.fr_643
  // [6cc0]
  0x06000f07, 0x190d18a4, 0x271820af, 0x08003f08,   // lv.de.un_420 ga.cs.gl_433  sq.ga.gd_655 af.no.un_430
  0x53002d02, 0x0c1216ee, 0x270918ec, 0x120d2d07,   // sk.ht.un_220 hr.hu.sv_422  ga.pl.gd_644 sk.cs.hu_432
  0x270418a9, 0x10002812, 0x17162913, 0x06090ca0,   // ga.fi.gd_544 sw.lt.un_640  sl.hr.sr_665 sv.pl.de_322
  0x190d12ec, 0x0f0910af, 0x0b10280c, 0x20182712,   // hu.cs.gl_644 lt.pl.lv_655  sw.lt.es_543 gd.ga.sq_654
  // [6cd0]
  0x19120b09, 0x2000250d, 0x23190bad, 0x07271807,   // es.hu.gl_444 eu.sq.un_540  es.gl.ca_643 ga.gd.it_432
  0x0b001307, 0x19121812, 0x2907200c, 0x1a646ba0,   // et.es.un_420 ga.hu.gl_654  sq.it.sl_543 ceb.lg.tl_322
  0x13001a34, 0x2a000d13, 0x0c2008a0, 0x1f006e07,   // tl.et.un_A80 cs.mt.un_650  no.sq.sv_322 blu.cy.un_420
  0x25552112, 0x19270aad, 0x0d2d1604, 0x552001a4,   // jw.rw.eu_654 pt.gd.gl_643  hr.sk.cs_332 en.sq.rw_433
  // [6ce0]
  0x0c002719, 0x06033f0d, 0x020601af, 0x2d1209ee,   // gd.sv.un_750 af.nl.de_554  en.de.da_655 pl.hu.sk_422
  0x2d1629ee, 0x172128ee, 0x10000f0e, 0x0f000920,   // sl.hr.sk_422 sw.jw.sr_422  lv.lt.un_550 pl.lv.un_850
  0x0f005308, 0x2b001818, 0x1b3155ee, 0x2a00160c,   // ht.lv.un_430 ga.vi.un_740  rw.az.tr_422 hr.mt.un_530
  0x6b2818ad, 0x21001605, 0x0f1017a9, 0x04081004,   // ga.sw.ceb_643 hr.jw.un_330  sr.lt.lv_544 be.uk.ru_332
  // [6cf0]
  0x292d0fa4, 0x08020e12, 0x643f0905, 0x020608ad,   // lv.sk.sl_433 is.da.no_654  pl.af.lg_333 no.de.da_643
  0x1b641aa0, 0x131e1c0d, 0x06120ca0, 0x6b531aa9,   // tl.lg.tr_322 id.ms.et_554  sv.hu.de_322 tl.ht.ceb_544
  0x53000d22, 0x04005307, 0x3f005302, 0x0c003f05,   // cs.ht.un_870 ht.fi.un_420  ht.af.un_220 af.sv.un_330
  0x0c060405, 0x040d3f08, 0x081004ec, 0x19030202,   // fi.de.sv_333 af.cs.fi_443  fi.lt.no_644 da.nl.gl_222
  // [6d00]
  0x0608250b, 0x02030fa7, 0x17166ea0, 0x190b120e,   // eu.no.de_542 lv.nl.da_532  blu.hr.sr_322 hu.es.gl_555
  0x53050daf, 0x53050a0e, 0x6b031a05, 0x012b2108,   // cs.fr.ht_655 pt.fr.ht_555  tl.nl.ceb_333 jw.vi.en_443
  0x0c041f07, 0x53000d20, 0x0c001308, 0x13000411,   // cy.fi.sv_432 cs.ht.un_850  et.sv.un_430 fi.et.un_630
  0x10255507, 0x211a2560, 0x2d000b04, 0x111b0412,   // rw.eu.lt_432 eu.tl.jw_664  es.sk.un_320 fi.tr.ro_654
  // [6d10]
  0x251e1b09, 0x231308a4, 0x06005502, 0x021f1ba7,   // tr.ms.eu_444 no.et.ca_433  rw.de.un_220 tr.cy.da_532
  0x64255508, 0x1e6b1a13, 0x19001214, 0x06296e60,   // rw.eu.lg_443 tl.ceb.ms_665  hu.gl.un_660 blu.sl.de_664
  0x1b0828af, 0x2300120c, 0x13010507, 0x641b5305,   // sw.no.tr_655 hu.ca.un_530  fr.en.et_432 ht.tr.lg_333
  0x02091607, 0x170a0812, 0x25071b07, 0x07020c02,   // hr.pl.da_432 uk.mk.sr_654  tr.it.eu_432 sv.da.it_222
  // [6d20]
  0x0c06640d, 0x08060fa4, 0x1200191a, 0x10020807,   // lg.de.sv_554 lv.de.no_433  gl.hu.un_760 no.da.lt_432
  0x03250608, 0x20130407, 0x01060b14, 0x17001121,   // de.eu.nl_443 fi.et.sq_432  es.de.en_666 ro.sr.un_860
  0x0700232a, 0x0f2d0655, 0x086b1aee, 0x6428550e,   // ca.it.un_970 de.sk.lv_442  tl.ceb.no_422 rw.sw.lg_555
  0x1f001b02, 0x1b000912, 0x2d0d25a0, 0x213f0e04,   // tr.cy.un_220 pl.tr.un_640  eu.cs.sk_322 is.af.jw_332
  // [6d30]
  0x2900250c, 0x0a010507, 0x211b1f07, 0x02016b02,   // eu.sl.un_530 fr.en.pt_432  cy.tr.jw_432 ceb.en.da_222
  0x0e0302a4, 0x030802a4, 0x13010807, 0x1f1611a7,   // da.nl.is_433 da.no.nl_433  no.en.et_432 ro.hr.cy_532
  0x10003f02, 0x08236eec, 0x1a003f14, 0x3100120e,   // af.lt.un_220 blu.ca.no_644  af.tl.un_660 hu.az.un_550
  0x101804a7, 0x170a0455, 0x08023faf, 0x1100180d,   // fi.ga.lt_532 ru.mk.sr_442  af.da.no_655 ga.ro.un_540
  // [6d40]
  0x1c000d02, 0x2b001219, 0x1e1c28a0, 0x2b00120c,   // cs.id.un_220 hu.vi.un_750  sw.id.ms_322 hu.vi.un_530
  0x2b001b05, 0x083f1160, 0x6b013fa0, 0x3f000221,   // tr.vi.un_330 ro.af.no_664  af.en.ceb_322 da.af.un_860
  0x0c0e02ec, 0x11001f1a, 0x13021107, 0x06002d02,   // da.is.sv_644 cy.ro.un_760  ro.da.et_432 sk.de.un_220
  0x0211130c, 0x2a003f02, 0x06033fec, 0x201b6b0c,   // et.ro.da_543 af.mt.un_220  af.nl.de_644 ceb.tr.sq_543
  // [6d50]
  0x0c00550c, 0x3f002018, 0x1a6b28a4, 0x2900090d,   // rw.sv.un_530 sq.af.un_740  sw.ceb.tl_433 pl.sl.un_540
  0x1a0428a4, 0x09213fa0, 0x06002108, 0x3f060307,   // sw.fi.tl_433 af.jw.pl_322  jw.de.un_430 nl.de.af_432
  0x063f0205, 0x1a6b21a4, 0x21201aec, 0x0a04170b,   // da.af.de_333 jw.ceb.tl_433  tl.sq.jw_644 sr.ru.mk_542
  0x0700111b, 0x210228ad, 0x1e1c01a9, 0x11080455,   // ro.it.un_770 sw.da.jw_643  en.id.ms_544 fi.no.ro_442
  // [6d60]
  0x1a250707, 0x182101a0, 0x1b00110e, 0x09002308,   // it.eu.tl_432 en.jw.ga_322  ro.tr.un_550 ca.pl.un_430
  0x201b1ea0, 0x0c020707, 0x18536b07, 0x090d1c14,   // ms.tr.sq_322 it.da.sv_432  ceb.ht.ga_432 mr.ne.hi_666
  0x0d0728ee, 0x640907a9, 0x08021cee, 0x31110707,   // sw.it.cs_422 it.pl.lg_544  id.da.no_422 it.ro.az_432
  0x0e311b08, 0x130e1e07, 0x04002518, 0x07002821,   // tr.az.is_443 ms.is.et_432  eu.fi.un_740 sw.it.un_860
  // [6d70]
  0x1e0e1ca0, 0x200364a4, 0x07002b09, 0x170a1113,   // id.is.ms_322 lg.nl.sq_433  vi.it.un_440 ro.mk.sr_665
  0x6b1e1c14, 0x1c531e0c, 0x0b0105a9, 0x1b003135,   // id.ms.ceb_666 ms.ht.id_543  fr.en.es_544 az.tr.un_A90
  0x21006407, 0x11042505, 0x210910ee, 0x28201202,   // lg.jw.un_420 eu.fi.ro_333  lt.pl.jw_422 hu.sq.sw_222
  0x1a160d0e, 0x12171607, 0x0300640e, 0x55120755,   // cs.hr.tl_555 hr.sr.hu_432  lg.nl.un_550 it.hu.rw_442
  // [6d80]
  0x250f1ead, 0x25086407, 0x2025550d, 0x121621a0,   // ms.lv.eu_643 lg.no.eu_432  rw.eu.sq_554 jw.hr.hu_322
  0x121304af, 0x16090d05, 0x25070608, 0x110625a7,   // fi.et.hu_655 cs.pl.hr_333  de.it.eu_443 eu.de.ro_532
  0x13640507, 0x070b0a04, 0x3f001212, 0x110607a7,   // fr.lg.et_432 pt.es.it_332  hu.af.un_640 it.de.ro_532
  0x6b1a01ad, 0x0b0a0802, 0x2100281b, 0x062a0107,   // en.tl.ceb_643 no.pt.es_222  sw.jw.un_770 en.mt.de_432
  // [6d90]
  0x0400112b, 0x0e2a3f04, 0x02005502, 0x0c000223,   // ro.ru.un_980 af.mt.is_332  rw.da.un_220 da.sv.un_880
  0x292a07ad, 0x21551e08, 0x0d001e08, 0x062d0d13,   // it.mt.sl_643 ms.rw.jw_443  ms.cs.un_430 cs.sk.de_665
  0x08100a09, 0x091e0d0c, 0x642d0d55, 0x2d0d18a4,   // mk.be.uk_444 cs.ms.pl_543  cs.sk.lg_442 ga.cs.sk_433
  0x3f2155ee, 0x06020c0c, 0x530928ee, 0x1e171c0c,   // rw.jw.af_422 sv.da.de_543  sw.pl.ht_422 id.sr.ms_543
  // [6da0]
  0x16002809, 0x0c0313a0, 0x2d210dad, 0x2a5504a7,   // sw.hr.un_440 et.nl.sv_322  cs.jw.sk_643 fi.rw.mt_532
  0x08000a07, 0x051a1307, 0x1c552804, 0x08000d08,   // mk.uk.un_420 et.tl.fr_432  sw.rw.id_332 cs.no.un_430
  0x2a071e12, 0x020c0660, 0x0818270c, 0x28182711,   // ms.it.mt_654 de.sv.da_664  gd.ga.no_543 gd.ga.sw_653
  0x1600020d, 0x18212707, 0x1016170b, 0x18272a02,   // da.hr.un_540 gd.jw.ga_432  sr.hr.lt_542 mt.gd.ga_222
  // [6db0]
  0x0b231908, 0x060e0402, 0x132a0eaf, 0x29001308,   // gl.ca.es_443 fi.is.de_222  is.mt.et_655 et.sl.un_430
  0x1f2113ee, 0x06201ba4, 0x1b0f13a7, 0x20002904,   // et.jw.cy_422 tr.sq.de_433  et.lv.tr_532 sl.sq.un_320
  0x2d001308, 0x2d000307, 0x04170855, 0x08002304,   // et.sk.un_430 nl.sk.un_420  uk.sr.ru_442 ca.no.un_320
  0x2b05010c, 0x20033fad, 0x0c1c13ac, 0x31000a0e,   // en.fr.vi_543 af.nl.sq_643  et.id.sv_632 pt.az.un_550
  // [6dc0]
  0x10070412, 0x031b6ba4, 0x08100a0c, 0x10291704,   // ru.bg.be_654 ceb.tr.nl_433  mk.be.uk_543 sr.sl.lt_332
  0x292d1b0c, 0x170f2d0c, 0x202953a4, 0x31091b04,   // tr.sk.sl_543 sk.lv.sr_543  ht.sl.sq_433 tr.pl.az_332
  0x16002911, 0x0900292b, 0x29092d14, 0x02001e04,   // sl.hr.un_630 sl.pl.un_980  sk.pl.sl_666 ms.da.un_320
  0x53201204, 0x1e006b04, 0x12162904, 0x1b005504,   // hu.sq.ht_332 ceb.ms.un_320  sl.hr.hu_332 rw.tr.un_320
  // [6dd0]
  0x1e1c08a4, 0x1b000d0d, 0x133f11a0, 0x06010705,   // no.id.ms_433 cs.tr.un_540  ro.af.et_322 it.en.de_333
  0x6e3153ad, 0x0b000c08, 0x27000b02, 0x29165308,   // ht.az.blu_643 sv.es.un_430  es.gd.un_220 ht.hr.sl_443
  0x18131aa0, 0x2a000911, 0x532d0908, 0x011b0c04,   // tl.et.ga_322 pl.mt.un_630  pl.sk.ht_443 sv.tr.en_332
  0x0953290c, 0x20000202, 0x53201ba9, 0x165329ac,   // sl.ht.pl_543 da.sq.un_220  tr.sq.ht_544 sl.ht.hr_632
  // [6de0]
  0x3f5310a9, 0x1c031ea4, 0x03023f07, 0x291f2112,   // lt.ht.af_544 ms.nl.id_433  af.da.nl_432 jw.cy.sl_654
  0x171e2104, 0x31001b07, 0x04061b04, 0x25085304,   // jw.ms.sr_332 tr.az.un_420  tr.de.fi_332 ht.no.eu_332
  0x19000c14, 0x0100060e, 0x042001a0, 0x530111af,   // sv.gl.un_660 de.en.un_550  en.sq.fi_322 ro.en.ht_655
  0x64013fa4, 0x3f0a2307, 0x202d0707, 0x0c000407,   // af.en.lg_433 ca.pt.af_432  it.sk.sq_432 fi.sv.un_420
  // [6df0]
  0x21111ca0, 0x1107080d, 0x01060555, 0x0305210b,   // id.ro.jw_322 no.it.ro_554  fr.de.en_442 jw.fr.nl_542
  0x07231ea4, 0x060c0204, 0x18101aa0, 0x3f0127ee,   // ms.ca.it_433 da.sv.de_332  tl.lt.ga_322 gd.en.af_422
  0x0e001c04, 0x01001e07, 0x643f2812, 0x13172aa4,   // id.is.un_320 ms.en.un_420  sw.af.lg_654 mt.sr.et_433
  0x120b18ee, 0x0c280f07, 0x083f0c02, 0x0e2d1212,   // ga.es.hu_422 lv.sw.sv_432  sv.af.no_222 hu.sk.is_654
  // [6e00]
  0x0d120aa4, 0x030611a9, 0x280621ad, 0x106b530c,   // pt.hu.cs_433 ro.de.nl_544  jw.de.sw_643 ht.ceb.lt_543
  0x02085304, 0x1a06210c, 0x21002908, 0x112806ad,   // ht.no.da_332 jw.de.tl_543  sl.jw.un_430 de.sw.ro_643
  0x09001f1b, 0x0c2527a0, 0x0a081109, 0x1e292104,   // cy.pl.un_770 gd.eu.sv_322  ro.uk.mk_444 jw.sl.ms_332
  0x04100760, 0x3f05230c, 0x20001107, 0x111c210c,   // bg.be.ru_664 ca.fr.af_543  ro.sq.un_420 jw.id.ro_543
  // [6e10]
  0x200613ad, 0x021220a7, 0x29000f22, 0x02203f08,   // et.de.sq_643 sq.hu.da_532  lv.sl.un_870 af.sq.da_443
  0x06023fec, 0x050601ee, 0x06002312, 0x11210bee,   // af.da.de_644 en.de.fr_422  ca.de.un_640 es.jw.ro_422
  0x28001b07, 0x01100807, 0x0d032b02, 0x0a111007,   // tr.sw.un_420 no.lt.en_432  vi.nl.cs_222 be.ro.mk_432
  0x06000512, 0x2d000f19, 0x0205080c, 0x032305a7,   // fr.de.un_640 lv.sk.un_750  no.fr.da_543 fr.ca.nl_532
  // [6e20]
  0x29161711, 0x0c123fee, 0x130523a9, 0x0c230f08,   // sr.hr.sl_653 af.hu.sv_422  ca.fr.et_544 lv.ca.sv_443
  0x0d001f04, 0x071704a7, 0x0700172b, 0x53131e07,   // cy.cs.un_320 ru.sr.bg_532  sr.bg.un_980 ms.et.ht_432
  0x53311308, 0x17001023, 0x2d0d0aaf, 0x5313020c,   // et.az.ht_443 be.sr.un_880  pt.cs.sk_655 da.et.ht_543
  0x28211307, 0x10001121, 0x532113ec, 0x050e2355,   // et.jw.sw_432 ro.be.un_860  et.jw.ht_644 ca.is.fr_442
  // [6e30]
  0x08020409, 0x0c1f6b02, 0x3f0613af, 0x07080eee,   // fi.da.no_444 ceb.cy.sv_222  et.de.af_655 is.no.it_422
  0x042008a7, 0x1a005305, 0x1300311a, 0x2a13310b,   // no.sq.fi_532 ht.tl.un_330  az.et.un_760 az.et.mt_542
  0x170804a6, 0x31006e04, 0x53005519, 0x020708a0,   // ru.uk.sr_521 blu.az.un_320  rw.ht.un_750 no.it.da_322
  0x3f1c0eee, 0x64002105, 0x1900180c, 0x02002908,   // is.id.af_422 jw.lg.un_330  ga.gl.un_530 sl.da.un_430
  // [6e40]
  0x2b2853a0, 0x17092da4, 0x08191f08, 0x211a5507,   // ht.sw.vi_322 sk.pl.sr_433  cy.gl.no_443 rw.tl.jw_432
  0x0c126b0c, 0x1c1021a7, 0x1c0b0a04, 0x25002108,   // ceb.hu.sv_543 jw.lt.id_532  pt.es.id_332 jw.eu.un_430
  0x06033f60, 0x200855a0, 0x25190b0c, 0x3f0316ad,   // af.nl.de_664 rw.no.sq_322  es.gl.eu_543 hr.nl.af_643
  0x0a001809, 0x13006414, 0x04536e0c, 0x1f271812,   // ga.pt.un_440 lg.et.un_660  blu.ht.fi_543 ga.gd.cy_654
  // [6e50]
  0x020c3107, 0x1c1a6b07, 0x21081cad, 0x180f01a4,   // az.sv.da_432 ceb.tl.id_432  id.no.jw_643 en.lv.ga_433
  0x0e270aa0, 0x3f230f0c, 0x17000a0b, 0x64001904,   // pt.gd.is_322 lv.ca.af_543  mk.sr.un_520 gl.lg.un_320
  0x0b072305, 0x04100a02, 0x05001304, 0x31111b08,   // ca.it.es_333 mk.be.ru_222  et.fr.un_320 tr.ro.az_443
  0x066413a9, 0x062a19ac, 0x21311c04, 0x100408ec,   // et.lg.de_544 gl.mt.de_632  id.az.jw_332 uk.ru.be_644
  // [6e60]
  0x05070111, 0x030c550c, 0x25001605, 0x011931ee,   // en.it.fr_653 rw.sv.nl_543  hr.eu.un_330 az.gl.en_422
  0x29171b07, 0x02530807, 0x11002b10, 0x043110a0,   // tr.sr.sl_432 no.ht.da_432  vi.ro.un_620 lt.az.fi_322
  0x17251909, 0x0f311baf, 0x17162514, 0x5312250c,   // gl.eu.sr_444 tr.az.lv_655  eu.hr.sr_666 eu.hu.ht_543
  0x31211b07, 0x6b000102, 0x13000c11, 0x0b092507,   // tr.jw.az_432 en.ceb.un_220  sv.et.un_630 eu.pl.es_432
  // [6e70]
  0x07080a07, 0x0400160e, 0x1e530a04, 0x1b552507,   // mk.uk.bg_432 hr.fi.un_550  pt.ht.ms_332 eu.rw.tr_432
  0x18005505, 0x6b282505, 0x1b2553a0, 0x64002113,   // rw.ga.un_330 eu.sw.ceb_333  ht.eu.tr_322 jw.lg.un_650
  0x08060ca0, 0x216b2509, 0x0a1125ee, 0x0e3f030d,   // sv.de.no_322 eu.ceb.jw_444  eu.ro.pt_422 nl.af.is_554
  0x1c001f04, 0x1a00250b, 0x6b6401ec, 0x09002513,   // cy.id.un_320 eu.tl.un_520  en.lg.ceb_644 eu.pl.un_650
  // [6e80]
  0x13000d22, 0x102925ee, 0x05072a05, 0x0d002509,   // ne.bh.un_870 eu.sl.lt_422  mt.it.fr_333 eu.cs.un_440
  0x09252da9, 0x211c6ba0, 0x2d0d250c, 0x255553a7,   // sk.eu.pl_544 ceb.id.jw_322  eu.cs.sk_543 ht.rw.eu_532
  0x31000608, 0x0c062505, 0x06011f0c, 0x21002a09,   // de.az.un_430 eu.de.sv_333  cy.en.de_543 mt.jw.un_440
  0x6b102509, 0x122d19a0, 0x64552a07, 0x645525a9,   // eu.lt.ceb_444 gl.sk.hu_322  mt.rw.lg_432 eu.rw.lg_544
  // [6e90]
  0x01041307, 0x07120107, 0x101213ee, 0x251a6b12,   // et.fi.en_432 en.hu.it_432  et.hu.lt_422 ceb.tl.eu_654
  0x10090fa0, 0x1c5564a4, 0x1a000e07, 0x53061a07,   // lv.pl.lt_322 lg.rw.id_433  is.tl.un_420 tl.de.ht_432
  0x0c280807, 0x160b0ea0, 0x2500211a, 0x13000c22,   // no.sw.sv_432 is.es.hr_322  jw.eu.un_760 sv.et.un_870
  0x6e6b010c, 0x100c2805, 0x08642804, 0x291208a0,   // en.ceb.blu_543 sw.sv.lt_333  sw.lg.no_332 no.hu.sl_322
  // [6ea0]
  0x0c0e08a4, 0x06050aa0, 0x2a001108, 0x1008190c,   // no.is.sv_433 pt.fr.de_322  ro.mt.un_430 gl.no.lt_543
  0x556b6405, 0x1b1e6405, 0x0a001816, 0x0c002122,   // lg.ceb.rw_333 lg.ms.tr_333  ga.pt.un_720 jw.sv.un_870
  0x10230eaf, 0x192a0c07, 0x0a270f02, 0x550f2808,   // is.ca.lt_655 sv.mt.gl_432  lv.gd.pt_222 sw.lv.rw_443
  0x5512640c, 0x5500130e, 0x0a04070b, 0x030d1207,   // lg.hu.rw_543 et.rw.un_550  bg.ru.mk_542 hu.cs.nl_432
  // [6eb0]
  0x18000204, 0x1b121f07, 0x3f2a53a0, 0x06002a08,   // da.ga.un_320 cy.hu.tr_432  ht.mt.af_322 mt.de.un_430
  0x0d291308, 0x17130c0c, 0x2a6b010c, 0x16211212,   // et.sl.cs_443 sv.et.sr_543  en.ceb.mt_543 hu.jw.hr_654
  0x191f0b0c, 0x6b171607, 0x2a011fa0, 0x062d0fee,   // es.cy.gl_543 hr.sr.ceb_432  cy.en.mt_322 lv.sk.de_422
  0x1a12250d, 0x28001102, 0x20050113, 0x0f101fad,   // eu.hu.tl_554 ro.sw.un_220  en.fr.sq_665 cy.lt.lv_643
  // [6ec0]
  0x21001f19, 0x0f070907, 0x02001204, 0x0b211c04,   // cy.jw.un_750 pl.it.lv_432  hu.da.un_320 id.jw.es_332
  0x08021fa7, 0x2702080c, 0x28533fa0, 0x2a1c1fee,   // cy.da.no_532 no.da.gd_543  af.ht.sw_322 cy.id.mt_422
  0x2d120204, 0x1a211c5a, 0x2d0d29a7, 0x556453ec,   // da.hu.sk_332 id.jw.tl_553  sl.cs.sk_532 ht.lg.rw_644
  0x050207a0, 0x1c090dac, 0x080c0ead, 0x080706a0,   // it.da.fr_322 ne.hi.mr_632  is.sv.no_643 de.it.no_322
  // [6ed0]
  0x090f01a4, 0x023f03a9, 0x2d051207, 0x31182aa7,   // en.lv.pl_433 nl.af.da_544  hu.fr.sk_432 mt.ga.az_532
  0x052320a7, 0x020520ad, 0x130e040d, 0x20000119,   // sq.ca.fr_532 sq.fr.da_643  fi.is.et_554 en.sq.un_750
  0x101225ee, 0x080223a4, 0x0b002005, 0x0500232c,   // eu.hu.lt_422 ca.da.no_433  sq.es.un_330 ca.fr.un_990
  0x29001c04, 0x0f001319, 0x19002102, 0x190a08af,   // id.sl.un_320 et.lv.un_750  jw.gl.un_220 no.pt.gl_655
  // [6ee0]
  0x18251ea0, 0x0b2a1e0c, 0x180e1ea4, 0x05002107,   // ms.eu.ga_322 ms.mt.es_543  ms.is.ga_433 jw.fr.un_420
  0x05001a05, 0x2a0511a9, 0x2d160d02, 0x230701a4,   // tl.fr.un_330 ro.fr.mt_544  cs.hr.sk_222 en.it.ca_433
  0x1b211e0c, 0x190a2309, 0x17080713, 0x05202307,   // ms.jw.tr_543 ca.pt.gl_444  bg.uk.sr_665 ca.sq.fr_432
  0x3f0f1005, 0x23000804, 0x1b006b07, 0x202a3112,   // lt.lv.af_333 no.ca.un_320  ceb.tr.un_420 az.mt.sq_654
  // [6ef0]
  0x01212aac, 0x063f030b, 0x120f1055, 0x1b082aa0,   // mt.jw.en_632 nl.af.de_542  lt.lv.hu_442 mt.no.tr_322
  0x20060107, 0x0f106e0c, 0x6b1207a9, 0x0e002304,   // en.de.sq_432 blu.lt.lv_543  it.hu.ceb_544 ca.is.un_320
  0x1929070c, 0x2700280c, 0x28180107, 0x08006e08,   // it.sl.gl_543 sw.gd.un_530  en.ga.sw_432 blu.no.un_430
  0x2b6e1f04, 0x2700070c, 0x08000c21, 0x052a13ec,   // cy.blu.vi_332 it.gd.un_530  sv.no.un_860 et.mt.fr_644
  // [6f00]
  0x200b29a7, 0x01100408, 0x0f13100c, 0x3f131ca4,   // sl.es.sq_532 fi.lt.en_443  lt.et.lv_543 id.et.af_433
  0x281a21af, 0x18016b02, 0x040a1755, 0x010b07af,   // jw.tl.sw_655 ceb.en.ga_222  sr.mk.ru_442 it.es.en_655
  0x2b0a0504, 0x032b0c07, 0x19002904, 0x532a08a9,   // fr.pt.vi_332 sv.vi.nl_432  sl.gl.un_320 no.mt.ht_544
  0x080501a7, 0x2700022a, 0x05000f02, 0x080209ec,   // en.fr.no_532 da.gd.un_970  lv.fr.un_220 pl.da.no_644
  // [6f10]
  0x03013f04, 0x13013fa0, 0x0b030807, 0x011153a0,   // af.en.nl_332 af.en.et_322  no.nl.es_432 ht.ro.en_322
  0x23050ba7, 0x01190b5a, 0x231f0512, 0x07002919,   // es.fr.ca_532 es.gl.en_553  fr.cy.ca_654 sl.it.un_750
  0x231901a4, 0x16172007, 0x21003f12, 0x051923ad,   // en.gl.ca_433 sq.sr.hr_432  af.jw.un_640 ca.gl.fr_643
  0x1f0264ec, 0x11005307, 0x20080204, 0x0e000b0c,   // lg.da.cy_644 ht.ro.un_420  da.no.sq_332 es.is.un_530
  // [6f20]
  0x05231ea4, 0x231305af, 0x3f032508, 0x1f132507,   // ms.ca.fr_433 fr.et.ca_655  eu.nl.af_443 eu.et.cy_432
  0x0e080104, 0x081f250c, 0x10041709, 0x012b02a4,   // en.no.is_332 eu.cy.no_543  sr.ru.be_444 da.vi.en_433
  0x121c53ec, 0x07250c04, 0x2a2916a0, 0x3f0325a0,   // ht.id.hu_644 sv.eu.it_332  hr.sl.mt_322 eu.nl.af_322
  0x0a11190d, 0x171221ee, 0x03052b07, 0x0a001b1b,   // gl.ro.pt_554 jw.hu.sr_422  vi.fr.nl_432 tr.pt.un_770
  // [6f30]
  0x010a2bad, 0x23001204, 0x3f001308, 0x55080202,   // vi.pt.en_643 hu.ca.un_320  et.af.un_430 da.no.rw_222
  0x2a0201ec, 0x06006b08, 0x0b070105, 0x05010b13,   // en.da.mt_644 ceb.de.un_430  en.it.es_333 es.en.fr_665
  0x28130408, 0x1a23530c, 0x3f0305af, 0x066427a0,   // fi.et.sw_443 ht.ca.tl_543  fr.nl.af_655 gd.lg.de_322
  0x64041355, 0x080a13a0, 0x27190bee, 0x210f1cac,   // et.fi.lg_442 et.pt.no_322  es.gl.gd_422 id.lv.jw_632
  // [6f40]
  0x19001123, 0x203f035a, 0x190a2312, 0x2a0e07a4,   // ro.gl.un_880 nl.af.sq_553  ca.pt.gl_654 it.is.mt_433
  0x1b160955, 0x02001604, 0x6b0b2755, 0x17040755,   // pl.hr.tr_442 hr.da.un_320  gd.es.ceb_442 bg.ru.sr_442
  0x28000502, 0x10000a22, 0x2a0f3f04, 0x0f231bee,   // fr.sw.un_220 mk.be.un_870  af.lv.mt_332 tr.ca.lv_422
  0x251c1ead, 0x110612a9, 0x182112a0, 0x21641ca4,   // ms.id.eu_643 hu.de.ro_544  ur.fa.ar_322 id.lg.jw_433
  // [6f50]
  0x172912a0, 0x24000129, 0x211a6b14, 0x0523075a,   // hu.sl.sr_322 iw.yi.un_960  ceb.tl.jw_666 it.ca.fr_553
  0x031a6ba0, 0x030e0f04, 0x121819a0, 0x08071707,   // ceb.tl.nl_322 lv.is.nl_332  gl.ga.hu_322 sr.bg.uk_432
  0x21642814, 0x2a0b0504, 0x286b1a0c, 0x2b002322,   // sw.lg.jw_666 fr.es.mt_332  tl.ceb.sw_543 ca.vi.un_870
  0x641a21a9, 0x19110fa4, 0x04001309, 0x6425290c,   // jw.tl.lg_544 lv.ro.gl_433  et.fi.un_440 sl.eu.lg_543
  // [6f60]
  0x02090d0b, 0x1a216407, 0x536b2808, 0x53211e07,   // cs.pl.da_542 lg.jw.tl_432  sw.ceb.ht_443 ms.jw.ht_432
  0x1800120b, 0x2a28550c, 0x023f03a7, 0x16000f08,   // ur.ar.un_520 rw.sw.mt_543  nl.af.da_532 lv.hr.un_430
  0x64552160, 0x6b000904, 0x64285507, 0x092d25a0,   // jw.rw.lg_664 pl.ceb.un_320  rw.sw.lg_432 eu.sk.pl_322
  0x641a2111, 0x2d530d07, 0x0a040711, 0x201004a4,   // jw.tl.lg_653 cs.ht.sk_432  bg.ru.mk_653 fi.lt.sq_433
  // [6f70]
  0x03041207, 0x0a080455, 0x292d170c, 0x28551211,   // hu.fi.nl_432 ru.uk.mk_442  sr.sk.sl_543 hu.rw.sw_653
  0x0a002513, 0x17000f0d, 0x12001818, 0x25001007,   // eu.pt.un_650 lv.sr.un_540  ar.ur.un_740 lt.eu.un_420
  0x100717ad, 0x03003f2c, 0x102504a6, 0x3f005507,   // sr.bg.be_643 af.nl.un_990  fi.eu.lt_521 rw.af.un_420
  0x1a6b2a0c, 0x2700280b, 0x042507ad, 0x092a1807,   // mt.ceb.tl_543 sw.gd.un_520  it.eu.fi_643 ga.mt.pl_432
  // [6f80]
  0x191a6b0b, 0x28001008, 0x0e000c18, 0x041a6b60,   // ceb.tl.gl_542 lt.sw.un_430  sv.is.un_740 ceb.tl.fi_664
  0x07000b05, 0x0d31090e, 0x316b13ee, 0x08000e09,   // es.it.un_330 pl.az.cs_555  et.ceb.az_422 is.no.un_440
  0x55061aa0, 0x05002902, 0x170f04af, 0x0f002814,   // tl.de.rw_322 sl.fr.un_220  fi.lv.sr_655 sw.lv.un_660
  0x551828a0, 0x28000f08, 0x11002811, 0x08001129,   // sw.ga.rw_322 lv.sw.un_430  sw.ro.un_630 ro.uk.un_960
  // [6f90]
  0x270c0204, 0x1a001022, 0x1e000f05, 0x1f6406ee,   // da.sv.gd_332 lt.tl.un_870  lv.ms.un_330 de.lg.cy_422
  0x1a046ba9, 0x17100aa4, 0x1c1e55ad, 0x04003f12,   // ceb.fi.tl_544 mk.be.sr_433  rw.ms.id_643 af.fi.un_640
  0x03006407, 0x211e1cee, 0x18050107, 0x035301a7,   // lg.nl.un_420 id.ms.jw_422  en.fr.ga_432 en.ht.nl_532
  0x20532809, 0x531e1c0e, 0x04136b0c, 0x286b0302,   // sw.ht.sq_444 id.ms.ht_555  ceb.et.fi_543 nl.ceb.sw_222
  // [6fa0]
  0x020164a0, 0x31110aa0, 0x53003f05, 0x10001607,   // lg.en.da_322 pt.ro.az_322  af.ht.un_330 hr.lt.un_420
  0x29083f12, 0x29206413, 0x0b530f07, 0x090d13ee,   // af.no.sl_654 lg.sq.sl_665  lv.ht.es_432 bh.ne.hi_422
  0x2b182108, 0x1720160c, 0x280f2aa9, 0x05001136,   // jw.ga.vi_443 hr.sq.sr_543  mt.lv.sw_544 ro.fr.un_AA0
  0x1c17280c, 0x64002a04, 0x1b1c280c, 0x1f00532b,   // sw.sr.id_543 mt.lg.un_320  sw.id.tr_543 ht.cy.un_980
  // [6fb0]
  0x6b250b07, 0x270c64a9, 0x55046455, 0x19001007,   // es.eu.ceb_432 lg.sv.gd_544  lg.fi.rw_442 lt.gl.un_420
  0x5553640d, 0x0c270204, 0x016b1f07, 0x100864a7,   // lg.ht.rw_554 da.gd.sv_332  cy.ceb.en_432 lg.no.lt_532
  0x1a3125ad, 0x202d0d09, 0x0b050114, 0x06250bee,   // eu.az.tl_643 cs.sk.sq_444  en.fr.es_666 es.eu.de_422
  0x09002705, 0x181219a0, 0x31001108, 0x0c006404,   // gd.pl.un_330 gl.hu.ga_322  ro.az.un_430 lg.sv.un_320
  // [6fc0]
  0x0d1b0111, 0x231302a4, 0x050123a0, 0x3f532013,   // en.tr.cs_653 da.et.ca_433  ca.en.fr_322 sq.ht.af_665
  0x0f050107, 0x0f00030e, 0x3f211c0c, 0x20192304,   // en.fr.lv_432 nl.lv.un_550  id.jw.af_543 ca.gl.sq_332
  0x0c550704, 0x17002905, 0x18002307, 0x53045504,   // it.rw.sv_332 sl.sr.un_330  ca.ga.un_420 rw.fi.ht_332
  0x0b0e12a9, 0x0f033f60, 0x09051102, 0x270711ee,   // hu.is.es_544 af.nl.lv_664  ro.fr.pl_222 ro.it.gd_422
  // [6fd0]
  0x3f0813ac, 0x06000507, 0x110201a0, 0x020507ec,   // et.no.af_632 fr.de.un_420  en.da.ro_322 it.fr.da_644
  0x12230a04, 0x270107ee, 0x11052313, 0x0a001f05,   // pt.ca.hu_332 it.en.gd_422  ca.fr.ro_665 cy.pt.un_330
  0x20210a07, 0x030d3f0c, 0x2d0d0ca0, 0x0c010ba0,   // pt.jw.sq_432 af.cs.nl_543  sv.cs.sk_322 es.en.sv_322
  0x23002707, 0x16172904, 0x29006413, 0x111a0e07,   // gd.ca.un_420 sl.sr.hr_332  lg.sl.un_650 is.tl.ro_432
  // [6fe0]
  0x111b645a, 0x2a0821a0, 0x551a1b0c, 0x23070a04,   // lg.tr.ro_553 jw.no.mt_322  tr.tl.rw_543 pt.it.ca_332
  0x0f1f1307, 0x255528a9, 0x1b001e02, 0x05002102,   // et.cy.lv_432 sw.rw.eu_544  ms.tr.un_220 jw.fr.un_220
  0x0b001808, 0x07112808, 0x23110755, 0x25005513,   // ga.es.un_430 sw.ro.it_443  it.ro.ca_442 rw.eu.un_650
  0x5500090e, 0x1b552908, 0x64551ba7, 0x05001004,   // pl.rw.un_550 sl.rw.tr_443  tr.rw.lg_532 lt.fr.un_320
  // [6ff0]
  0x060c3fee, 0x11072907, 0x09005509, 0x6411550c,   // af.sv.de_422 sl.it.ro_432  rw.pl.un_440 rw.ro.lg_543
  0x066b13a0, 0x3f050407, 0x01000609, 0x311a0107,   // et.ceb.de_322 fi.fr.af_432  de.en.un_440 en.tl.az_432
  0x01111b0c, 0x1c090da0, 0x25041304, 0x062d0da0,   // tr.ro.en_543 ne.hi.mr_322  et.fi.eu_332 cs.sk.de_322
  0x030d0404, 0x131c09a4, 0x0a0405ac, 0x1b005312,   // fi.cs.nl_332 hi.mr.bh_433  fr.fi.pt_632 ht.tr.un_640

  // [7000]
  0x060d2d07, 0x0b5305ee, 0x040a0807, 0x230c0409,   // sk.cs.de_432 fr.ht.es_422  uk.mk.ru_432 fi.sv.ca_444
  0x210553a9, 0x55282102, 0x5355090b, 0x5500091b,   // ht.fr.jw_544 jw.sw.rw_222  pl.rw.ht_542 pl.rw.un_770
  0x28206bec, 0x28530111, 0x0c050807, 0x1e000502,   // ceb.sq.sw_644 en.ht.sw_653  no.fr.sv_432 fr.ms.un_220
  0x1f0e0c0e, 0x3f005307, 0x531104ee, 0x3f640da0,   // sv.is.cy_555 ht.af.un_420  fi.ro.ht_422 cs.lg.af_322
  // [7010]
  0x060829ad, 0x0b000e07, 0x0f002d07, 0x310a1ba9,   // sl.no.de_643 is.es.un_420  sk.lv.un_420 tr.pt.az_544
  0x3f002302, 0x08311b0c, 0x102820a7, 0x0c311b0b,   // ca.af.un_220 tr.az.no_543  sq.sw.lt_532 tr.az.sv_542
  0x0c2a07a0, 0x173108a0, 0x022005a0, 0x101120ad,   // it.mt.sv_322 no.az.sr_322  fr.sq.da_322 sq.ro.lt_643
  0x021b0eec, 0x060c0f0c, 0x0a001729, 0x11070808,   // is.tr.da_644 lv.sv.de_543  sr.mk.un_960 uk.bg.ro_443
  // [7020]
  0x6b100f0d, 0x1f2d0d5a, 0x010b050c, 0x07000811,   // lv.lt.ceb_554 cs.sk.cy_553  fr.es.en_543 uk.bg.un_630
  0x04170a55, 0x07250f09, 0x282507af, 0x11170a09,   // mk.sr.ru_442 lv.eu.it_444  it.eu.sw_655 mk.sr.ro_444
  0x171625a9, 0x17282004, 0x25000719, 0x04000a14,   // eu.hr.sr_544 sq.sw.sr_332  it.eu.un_750 mk.ru.un_660
  0x53033f05, 0x252007a0, 0x07080aa6, 0x10170709,   // af.nl.ht_333 it.sq.eu_322  mk.uk.bg_521 bg.sr.be_444
  // [7030]
  0x55256408, 0x3f000608, 0x28316407, 0x171007af,   // lg.eu.rw_443 de.af.un_430  lg.az.sw_432 it.lt.sr_655
  0x53002702, 0x11080a05, 0x532507a9, 0x2500072b,   // gd.ht.un_220 mk.uk.ro_333  it.eu.ht_544 it.eu.un_980
  0x55072507, 0x0e270c55, 0x0f250709, 0x311b0f05,   // eu.it.rw_432 sv.gd.is_442  it.eu.lv_444 lv.tr.az_333
  0x55283f04, 0x06006b12, 0x1c211e11, 0x2a1f3f04,   // af.sw.rw_332 ceb.de.un_640  ms.jw.id_653 af.cy.mt_332
  // [7040]
  0x2a006414, 0x31000302, 0x0d0628ad, 0x13002a05,   // lg.mt.un_660 nl.az.un_220  sw.de.cs_643 mt.et.un_330
  0x0a110704, 0x0a110807, 0x530c08ad, 0x53000912,   // bg.ro.mk_332 uk.ro.mk_432  no.sv.ht_643 pl.ht.un_640
  0x03006e07, 0x530105ad, 0x090d2dec, 0x29090da4,   // blu.nl.un_420 fr.en.ht_643  sk.cs.pl_644 cs.pl.sl_433
  0x013108a0, 0x08000e13, 0x292d1604, 0x53033f13,   // no.az.en_322 is.no.un_650  hr.sk.sl_332 af.nl.ht_665
  // [7050]
  0x03060907, 0x101708ee, 0x015305a0, 0x17000818,   // pl.de.nl_432 uk.sr.be_422  fr.ht.en_322 uk.sr.un_740
  0x06280b04, 0x18000908, 0x0806020d, 0x643f030c,   // es.sw.de_332 pl.ga.un_430  da.de.no_554 nl.af.lg_543
  0x031b25ee, 0x6b5564a9, 0x0a00250e, 0x1a00550d,   // eu.tr.nl_422 lg.rw.ceb_544  eu.pt.un_550 rw.tl.un_540
  0x111f6ba4, 0x05005335, 0x1729195a, 0x2a0125ad,   // ceb.cy.ro_433 ht.fr.un_A90  gl.sl.sr_553 eu.en.mt_643
  // [7060]
  0x28006e08, 0x026406ee, 0x2d0d050c, 0x0f531a09,   // blu.sw.un_430 de.lg.da_422  fr.cs.sk_543 tl.ht.lv_444
  0x10092dee, 0x2a006418, 0x09100f5a, 0x2555640c,   // sk.pl.lt_422 lg.mt.un_740  lv.lt.pl_553 lg.rw.eu_543
  0x230f6407, 0x100f0308, 0x20286407, 0x64001221,   // lg.lv.ca_432 nl.lv.lt_443  lg.sw.sq_432 hu.lg.un_860
  0x0700030e, 0x042325a0, 0x25091009, 0x29080f05,   // nl.it.un_550 eu.ca.fi_322  lt.pl.eu_444 lv.no.sl_333
  // [7070]
  0x102a0f11, 0x2a2564ad, 0x3f072508, 0x0b282304,   // lv.mt.lt_653 lg.eu.mt_643  eu.it.af_443 ca.sw.es_332
  0x1f3f03a4, 0x133f2511, 0x25090660, 0x070264af,   // nl.af.cy_433 eu.af.et_653  de.pl.eu_664 lg.da.it_655
  0x64003f09, 0x0a000b21, 0x64002d13, 0x0d1f2da7,   // af.lg.un_440 es.pt.un_860  sk.lg.un_650 sk.cy.cs_532
  0x3f2125a4, 0x20191ca0, 0x6400041a, 0x0a071111,   // eu.jw.af_433 id.gl.sq_322  fi.lg.un_760 ro.bg.mk_653
  // [7080]
  0x0a2a25a0, 0x2d100fad, 0x2a000919, 0x030f040c,   // eu.mt.pt_322 lv.lt.sk_643  pl.mt.un_750 fi.lv.nl_543
  0x1c2b27a7, 0x062019a4, 0x080717a4, 0x06190b02,   // gd.vi.id_532 gl.sq.de_433  sr.bg.uk_433 es.gl.de_222
  0x0f002309, 0x072564a4, 0x11231909, 0x052d03a0,   // ca.lv.un_440 lg.eu.it_433  gl.ca.ro_444 nl.sk.fr_322
  0x10001308, 0x17080a11, 0x070a1055, 0x0f130204,   // et.lt.un_430 mk.uk.sr_653  be.mk.bg_442 da.et.lv_332
  // [7090]
  0x10000714, 0x3f001007, 0x28551ea0, 0x311b2107,   // bg.be.un_660 lt.af.un_420  ms.rw.sw_322 jw.tr.az_432
  0x28552509, 0x210e280b, 0x28022a09, 0x6b20550c,   // eu.rw.sw_444 sw.is.jw_542  mt.da.sw_444 rw.sq.ceb_543
  0x6b1a530c, 0x17081105, 0x17000819, 0x0a002113,   // ht.tl.ceb_543 ro.uk.sr_333  uk.sr.un_750 jw.pt.un_650
  0x1b04130c, 0x5511250c, 0x55281aec, 0x1a1b53ee,   // et.fi.tr_543 eu.ro.rw_543  tl.sw.rw_644 ht.tr.tl_422
  // [70a0]
  0x190a3102, 0x130d2dad, 0x1c000519, 0x1b1a530c,   // az.pt.gl_222 sk.cs.et_643  fr.id.un_750 ht.tl.tr_543
  0x0d1c13ad, 0x04071005, 0x1a1b53a0, 0x31251bad,   // bh.mr.ne_643 be.bg.ru_333  ht.tr.tl_322 tr.eu.az_643
  0x1b2101a0, 0x10000902, 0x6b1a53a4, 0x3f0e0212,   // en.jw.tr_322 pl.lt.un_220  ht.tl.ceb_433 da.is.af_654
  0x3f200e0c, 0x1a1b53a9, 0x53001c0e, 0x0100050e,   // is.sq.af_543 ht.tr.tl_544  id.ht.un_550 fr.en.un_550
  // [70b0]
  0x6b531a12, 0x06010ba0, 0x1f000e2a, 0x0c050305,   // tl.ht.ceb_654 es.en.de_322  is.cy.un_970 nl.fr.sv_333
  0x06010709, 0x1b6453a7, 0x05060104, 0x21230505,   // it.en.de_444 ht.lg.tr_532  en.de.fr_332 fr.ca.jw_333
  0x642353a7, 0x01060502, 0x530f0514, 0x29160a07,   // ht.ca.lg_532 fr.de.en_222  fr.lv.ht_666 pt.hr.sl_432
  0x101707ec, 0x0a182510, 0x0510530c, 0x0a1008ad,   // bg.sr.be_644 eu.ga.pt_642  ht.lt.fr_543 uk.be.mk_643
  // [70c0]
  0x0e0c64a0, 0x1b002113, 0x2a120f11, 0x2d170d08,   // lg.sv.is_322 jw.tr.un_650  lv.hu.mt_653 cs.sr.sk_443
  0x0f00040c, 0x11270111, 0x281609a4, 0x08021304,   // fi.lv.un_530 en.gd.ro_653  pl.hr.sw_433 et.da.no_332
  0x020e08ac, 0x062d0d05, 0x2b000d04, 0x03292107,   // no.is.da_632 cs.sk.de_333  cs.vi.un_320 jw.sl.nl_432
  0x27001a04, 0x130e0404, 0x2a002007, 0x0d002d20,   // tl.gd.un_320 fi.is.et_332  sq.mt.un_420 sk.cs.un_850
  // [70d0]
  0x0a002804, 0x2d170d02, 0x2a120f07, 0x02002b04,   // sw.pt.un_320 cs.sr.sk_222  lv.hu.mt_432 vi.da.un_320
  0x2909130c, 0x113123a4, 0x111617ee, 0x550f2905,   // et.pl.sl_543 ca.az.ro_433  sr.hr.ro_422 sl.lv.rw_333
  0x2a1608a0, 0x0b002908, 0x3f2d0912, 0x5511530c,   // no.hr.mt_322 sl.es.un_430  pl.sk.af_654 ht.ro.rw_543
  0x020428a0, 0x173f0302, 0x28001002, 0x2d000602,   // sw.fi.da_322 nl.af.sr_222  lt.sw.un_220 de.sk.un_220
  // [70e0]
  0x13000808, 0x08040760, 0x6b00060d, 0x0b00530c,   // no.et.un_430 bg.ru.uk_664  de.ceb.un_540 ht.es.un_530
  0x530b21ee, 0x060208ee, 0x131a6b0c, 0x532d0d02,   // jw.es.ht_422 no.da.de_422  ceb.tl.et_543 cs.sk.ht_222
  0x1609290d, 0x0f211ea4, 0x0d291607, 0x28641a09,   // sl.pl.hr_554 ms.jw.lv_433  hr.sl.cs_432 tl.lg.sw_444
  0x1c211e0b, 0x1304280c, 0x21001a22, 0x5364210c,   // ms.jw.id_542 sw.fi.et_543  tl.jw.un_870 jw.lg.ht_543
  // [70f0]
  0x101b1112, 0x55641aec, 0x20002813, 0x31211a0c,   // ro.tr.lt_654 tl.lg.rw_644  sw.sq.un_650 tl.jw.az_543
  0x642028a4, 0x201355a4, 0x53013fee, 0x55282aad,   // sw.sq.lg_433 rw.et.sq_433  af.en.ht_422 mt.sw.rw_643
  0x1b311aa9, 0x132855a6, 0x64205560, 0x1c051e0b,   // tl.az.tr_544 rw.sw.et_521  rw.sq.lg_664 ms.fr.id_542
  0x2a071e0c, 0x21641a0c, 0x64041aa0, 0x12060204,   // ms.it.mt_543 tl.lg.jw_543  tl.fi.lg_322 da.de.hu_332
  // [7100]
  0x285513a0, 0x290d2dee, 0x202855ad, 0x55202807,   // et.rw.sw_322 sk.cs.sl_422  rw.sw.sq_643 sw.sq.rw_432
  0x0f291607, 0x10000707, 0x0c000e0e, 0x1f080ea4,   // hr.sl.lv_432 bg.be.un_420  is.sv.un_550 is.no.cy_433
  0x092d0da4, 0x2d0d18a9, 0x070206ee, 0x2a201805,   // cs.sk.pl_433 ga.cs.sk_544  de.da.it_422 ga.sq.mt_333
  0x04001808, 0x6b2101a7, 0x0d6428a6, 0x0b001205,   // ga.fi.un_430 en.jw.ceb_532  sw.lg.cs_521 hu.es.un_330
  // [7110]
  0x6b0c08ee, 0x12061fa0, 0x270418ad, 0x292b1aa0,   // no.sv.ceb_422 cy.de.hu_322  ga.fi.gd_643 tl.vi.sl_322
  0x230f09a0, 0x18270812, 0x072d27a0, 0x1b2308ee,   // pl.lv.ca_322 no.gd.ga_654  gd.sk.it_322 no.ca.tr_422
  0x13110107, 0x2a001f0c, 0x020f0e0c, 0x3f0306ee,   // en.ro.et_432 cy.mt.un_530  is.lv.da_543 de.nl.af_422
  0x6b291604, 0x10200107, 0x030c0804, 0x06213fa0,   // hr.sl.ceb_332 en.sq.lt_432  no.sv.nl_332 af.jw.de_322
  // [7120]
  0x0f0a6bee, 0x03000613, 0x0c030611, 0x6b00130d,   // ceb.pt.lv_422 de.nl.un_650  de.nl.sv_653 et.ceb.un_540
  0x552d0d08, 0x0c0306ec, 0x036b06ad, 0x29002802,   // cs.sk.rw_443 de.nl.sv_644  de.ceb.nl_643 sw.sl.un_220
  0x02060304, 0x060312a0, 0x0206030b, 0x011c53a0,   // nl.de.da_332 hu.nl.de_322  nl.de.da_542 ht.id.en_322
  0x3f2d0602, 0x1f016ba0, 0x211a640d, 0x0c030607,   // de.sk.af_222 ceb.en.cy_322  lg.tl.jw_554 de.nl.sv_432
  // [7130]
  0x0c0a120c, 0x1a216b0d, 0x130608a4, 0x0628550c,   // hu.pt.sv_543 ceb.jw.tl_554  no.de.et_433 rw.sw.de_543
  0x64551ca9, 0x25126b08, 0x0c122060, 0x1e0621a9,   // id.rw.lg_544 ceb.hu.eu_443  sq.hu.sv_664 jw.de.ms_544
  0x01270a0c, 0x1b001221, 0x21005512, 0x08020e14,   // pt.gd.en_543 hu.tr.un_860  rw.jw.un_640 is.da.no_666
  0x13001212, 0x64001a34, 0x551c1e0c, 0x642507a9,   // hu.et.un_640 tl.lg.un_A80  ms.id.rw_543 it.eu.lg_544
  // [7140]
  0x280306ad, 0x0705110c, 0x182a2007, 0x0300062c,   // de.nl.sw_643 ro.fr.it_543  sq.mt.ga_432 de.nl.un_990
  0x0600031b, 0x1f21230c, 0x09291607, 0x16002013,   // nl.de.un_770 ca.jw.cy_543  hr.sl.pl_432 sq.hr.un_650
  0x552164af, 0x06552109, 0x0121120c, 0x6421060d,   // lg.jw.rw_655 jw.rw.de_444  hu.jw.en_543 de.jw.lg_554
  0x291b2da4, 0x08042704, 0x120c0812, 0x21042809,   // sk.tr.sl_433 gd.fi.no_332  no.sv.hu_654 sw.fi.jw_444
  // [7150]
  0x0c1220a0, 0x010c1209, 0x6b1e1aa4, 0x13000305,   // sq.hu.sv_322 hu.sv.en_444  tl.ms.ceb_433 nl.et.un_330
  0x11212aee, 0x21070d07, 0x210609a7, 0x0a210804,   // mt.jw.ro_422 cs.it.jw_432  pl.de.jw_532 no.jw.pt_332
  0x1f07180c, 0x00006b37, 0x1812110c, 0x6b281fee,   // ga.it.cy_543 ceb.un.un_B00  ro.hu.ga_543 cy.sw.ceb_422
  0x251a1caf, 0x1f1e01ee, 0x1c2120ad, 0x162d1704,   // id.tl.eu_655 en.ms.cy_422  sq.jw.id_643 sr.sk.hr_332
  // [7160]
  0x193128a4, 0x211a6bad, 0x27002318, 0x25000f05,   // sw.az.gl_433 ceb.tl.jw_643  ca.gd.un_740 lv.eu.un_330
  0x1b00130d, 0x201304ad, 0x2d0d31ec, 0x120e2b12,   // et.tr.un_540 fi.et.sq_643  az.cs.sk_644 vi.is.hu_654
  0x311a1ea4, 0x20003105, 0x311923a9, 0x046413a0,   // ms.tl.az_433 az.sq.un_330  ca.gl.az_544 et.lg.fi_322
  0x21000421, 0x0e3f0304, 0x06130c09, 0x0307010c,   // fi.jw.un_860 nl.af.is_332  sv.et.de_444 en.it.nl_543
  // [7170]
  0x13000614, 0x12192d08, 0x040711ac, 0x02000612,   // de.et.un_660 sk.gl.hu_443  ro.bg.ru_632 de.da.un_640
  0x0600030d, 0x13200355, 0x033f08a0, 0x13063f55,   // nl.de.un_540 nl.sq.et_442  no.af.nl_322 af.de.et_442
  0x16000d13, 0x1e1c01ee, 0x1c130907, 0x080a17a9,   // cs.hr.un_650 en.id.ms_422  hi.bh.mr_432 sr.mk.uk_544
  0x1617290b, 0x1827280e, 0x070f55a4, 0x530e27ee,   // sl.sr.hr_542 sw.gd.ga_555  rw.lv.it_433 gd.is.ht_422
  // [7180]
  0x1f182704, 0x09042da0, 0x010c2a02, 0x0400112a,   // gd.ga.cy_332 sk.fi.pl_322  mt.sv.en_222 ro.ru.un_970
  0x04100fa4, 0x1328070c, 0x13000307, 0x13311ba9,   // lv.lt.fi_433 it.sw.et_543  nl.et.un_420 tr.az.et_544
  0x233f13a0, 0x1b041805, 0x29281707, 0x31001e02,   // et.af.ca_322 ga.fi.tr_333  sr.sw.sl_432 ms.az.un_220
  0x270a18af, 0x0c0e0812, 0x02033f07, 0x1600121a,   // ga.pt.gd_655 no.is.sv_654  af.nl.da_432 hu.hr.un_760
  // [7190]
  0x2d090fee, 0x6e0164a4, 0x041e1c07, 0x1c1153a0,   // lv.pl.sk_422 lg.en.blu_433  id.ms.fi_432 ht.ro.id_322
  0x12311ba7, 0x1a001004, 0x121b3113, 0x1e1c0a05,   // tr.az.hu_532 lt.tl.un_320  az.tr.hu_665 pt.id.ms_333
  0x23072aa0, 0x29160f04, 0x1b31550b, 0x08001c0c,   // mt.it.ca_322 lv.hr.sl_332  rw.az.tr_542 id.no.un_530
  0x03085504, 0x1e251c0c, 0x10016ba4, 0x21001a2a,   // rw.no.nl_332 id.eu.ms_543  ceb.en.lt_433 tl.jw.un_970
  // [71a0]
  0x08101f11, 0x291a1cee, 0x1b2507a4, 0x10256b0c,   // cy.lt.no_653 id.tl.sl_422  it.eu.tr_433 ceb.eu.lt_543
  0x033f1fad, 0x0f2305af, 0x1a013f07, 0x29552508,   // cy.af.nl_643 fr.ca.lv_655  af.en.tl_432 eu.rw.sl_443
  0x1f3f0360, 0x2b001202, 0x02250812, 0x23005319,   // nl.af.cy_664 hu.vi.un_220  no.eu.da_654 ht.ca.un_750
  0x0f0c25a4, 0x251b0413, 0x5321230c, 0x3f031308,   // eu.sv.lv_433 fi.tr.eu_665  ca.jw.ht_543 et.nl.af_443
  // [71b0]
  0x03002a08, 0x23551304, 0x13001a0d, 0x25001c02,   // mt.nl.un_430 et.rw.ca_332  tl.et.un_540 id.eu.un_220
  0x27001305, 0x21532312, 0x2d0d1017, 0x31000707,   // et.gd.un_330 ca.ht.jw_654  lt.cs.sk_753 it.az.un_420
  0x3f1603af, 0x3f2a25ee, 0x3f1f0209, 0x0603010c,   // nl.hr.af_655 eu.mt.af_422  da.cy.af_444 en.nl.de_543
  0x29111e0c, 0x172016ee, 0x12131b0c, 0x2123530d,   // ms.ro.sl_543 hr.sq.sr_422  tr.et.hu_543 ht.ca.jw_554
  // [71c0]
  0x2800090d, 0x1b25010c, 0x532305af, 0x2500210d,   // pl.sw.un_540 en.eu.tr_543  fr.ca.ht_655 jw.eu.un_540
  0x29006b0c, 0x1b00110c, 0x0d002907, 0x16001308,   // ceb.sl.un_530 ro.tr.un_530  sl.cs.un_420 et.hr.un_430
  0x01640504, 0x011f3fa9, 0x19001f05, 0x0c1306a7,   // fr.lg.en_332 af.cy.en_544  cy.gl.un_330 de.et.sv_532
  0x0c000418, 0x10171605, 0x1a002907, 0x02111607,   // fi.sv.un_740 hr.sr.lt_333  sl.tl.un_420 hr.ro.da_432
  // [71d0]
  0x16290d02, 0x0a05010c, 0x2b001204, 0x2b001602,   // cs.sl.hr_222 en.fr.pt_543  hu.vi.un_320 hr.vi.un_220
  0x12311b12, 0x2731250c, 0x17101604, 0x0200080b,   // tr.az.hu_654 eu.az.gd_543  hr.lt.sr_332 no.da.un_520
  0x03130407, 0x061e1c5a, 0x272818a4, 0x21531c0c,   // fi.et.nl_432 id.ms.de_553  ga.sw.gd_433 id.ht.jw_543
  0x051201a4, 0x2106110d, 0x18280a0c, 0x532864ac,   // en.hu.fr_433 ro.de.jw_554  pt.sw.ga_543 lg.sw.ht_632
  // [71e0]
  0x536b1aad, 0x033f0ba9, 0x1008170b, 0x19070aee,   // tl.ceb.ht_643 es.af.nl_544  sr.uk.be_542 pt.it.gl_422
  0x172105a0, 0x131e1c02, 0x17001104, 0x0a033fa4,   // fr.jw.sr_322 id.ms.et_222  ro.sr.un_320 af.nl.pt_433
  0x07063f0c, 0x231e1ca4, 0x07112a07, 0x231907ad,   // af.de.it_543 id.ms.ca_433  mt.ro.it_432 it.gl.ca_643
  0x0e03080c, 0x3f00011a, 0x292d0d12, 0x0a1710a9,   // no.nl.is_543 en.af.un_760  cs.sk.sl_654 be.sr.mk_544
  // [71f0]
  0x5300230c, 0x2d000e04, 0x1e036405, 0x0c080a08,   // ca.ht.un_530 is.sk.un_320  lg.nl.ms_333 pt.no.sv_443
  0x080a0405, 0x1b03060c, 0x0a130107, 0x2a1c0d02,   // ru.mk.uk_333 de.nl.tr_543  en.et.pt_432 cs.id.mt_222
  0x130c0813, 0x0807110b, 0x1b00530c, 0x1b6b1a05,   // no.sv.et_665 ro.bg.uk_542  ht.tr.un_530 tl.ceb.tr_333
  0x10161107, 0x531b6b09, 0x0b042302, 0x091c0d04,   // ro.hr.lt_432 ceb.tr.ht_444  ca.fi.es_222 ne.mr.hi_332
  // [7200]
  0x16002914, 0x3f000705, 0x13002812, 0x251e090b,   // sl.hr.un_660 it.af.un_330  sw.et.un_640 pl.ms.eu_542
  0x231101a0, 0x28000413, 0x03130f05, 0x2d271f07,   // en.ro.ca_322 fi.sw.un_650  lv.et.nl_333 cy.gd.sk_432
  0x180b19ac, 0x6400030c, 0x2d0d27a9, 0x31000502,   // gl.es.ga_632 nl.lg.un_530  gd.cs.sk_544 fr.az.un_220
  0x3f282a07, 0x181f2760, 0x09131c55, 0x03001307,   // mt.sw.af_432 gd.cy.ga_664  mr.bh.hi_442 et.nl.un_420
  // [7210]
  0x0e1219a7, 0x19052007, 0x1704115a, 0x3f28230c,   // gl.hu.is_532 sq.fr.gl_432  ro.ru.sr_553 ca.sw.af_543
  0x09290d05, 0x12000204, 0x0e2d0d09, 0x1e201604,   // cs.sl.pl_333 da.hu.un_320  cs.sk.is_444 hr.sq.ms_332
  0x1600090e, 0x10170413, 0x08192505, 0x122d0c08,   // pl.hr.un_550 ru.sr.be_665  eu.gl.no_333 sv.sk.hu_443
  0x06080205, 0x0d1709a7, 0x2d060da4, 0x0217120c,   // da.no.de_333 pl.sr.cs_532  cs.de.sk_433 hu.sr.da_543
  // [7220]
  0x062b0a02, 0x2a0d18a7, 0x17101607, 0x642718a7,   // pt.vi.de_222 ga.cs.mt_532  hr.lt.sr_432 ga.gd.lg_532
  0x0d285507, 0x270e1811, 0x0b0411af, 0x12001707,   // rw.sw.cs_432 ga.is.gd_653  ro.fi.es_655 sr.hu.un_420
  0x202a1702, 0x04081112, 0x2d0928a7, 0x0900050e,   // sr.mt.sq_222 ro.uk.ru_654  sw.pl.sk_532 fr.pl.un_550
  0x052803ee, 0x16002502, 0x5500210d, 0x642855ac,   // nl.sw.fr_422 eu.hr.un_220  jw.rw.un_540 rw.sw.lg_632
  // [7230]
  0x08002a04, 0x25190a5a, 0x18061fee, 0x232507a7,   // mt.no.un_320 pt.gl.eu_553  cy.de.ga_422 it.eu.ca_532
  0x18002d0c, 0x0c006b08, 0x27061807, 0x0b0106a0,   // sk.ga.un_530 ceb.sv.un_430  ga.de.gd_432 de.en.es_322
  0x5500640b, 0x046407a4, 0x2a532807, 0x0628530d,   // lg.rw.un_520 it.lg.fi_433  sw.ht.mt_432 ht.sw.de_554
  0x2d000d33, 0x311b64ad, 0x290f09a4, 0x020307a0,   // cs.sk.un_A70 lg.tr.az_643  pl.lv.sl_433 it.nl.da_322
  // [7240]
  0x12002504, 0x2153280c, 0x0364550c, 0x2a000408,   // eu.hu.un_320 sw.ht.jw_543  rw.lg.nl_543 fi.mt.un_430
  0x6400130e, 0x070a1f04, 0x556b2d07, 0x28550613,   // et.lg.un_550 cy.pt.it_332  sk.ceb.rw_432 de.rw.sw_665
  0x190b1e02, 0x0d0612ee, 0x20001614, 0x0c160408,   // ms.es.gl_222 hu.de.cs_422  hr.sq.un_660 fi.hr.sv_443
  0x2a19310c, 0x292a1605, 0x04641004, 0x06180da0,   // az.gl.mt_543 hr.mt.sl_333  lt.lg.fi_332 cs.ga.de_322
  // [7250]
  0x0d0c2da4, 0x1304200c, 0x130e6405, 0x2a001304,   // sk.sv.cs_433 sq.fi.et_543  lg.is.et_333 et.mt.un_320
  0x0e000c05, 0x04162911, 0x552109ec, 0x216b1c0c,   // sv.is.un_330 sl.hr.fi_653  pl.jw.rw_644 id.ceb.jw_543
  0x10001709, 0x13006408, 0x2d0d1217, 0x16002a07,   // sr.be.un_440 lg.et.un_430  hu.cs.sk_753 mt.hr.un_420
  0x0411170c, 0x04170714, 0x07120ca0, 0x08171609,   // sr.ro.ru_543 bg.sr.ru_666  sv.hu.it_322 hr.sr.no_444
  // [7260]
  0x200b2908, 0x23002710, 0x2a2016a7, 0x64252807,   // sl.es.sq_443 gd.ca.un_620  hr.sq.mt_532 sw.eu.lg_432
  0x2a120702, 0x17250d0b, 0x55642511, 0x256416ee,   // it.hu.mt_222 cs.eu.sr_542  eu.lg.rw_653 hr.lg.eu_422
  0x176453af, 0x06210804, 0x041a1204, 0x12002a21,   // ht.lg.sr_655 no.jw.de_332  hu.tl.fi_332 mt.hu.un_860
  0x25166402, 0x5500252a, 0x645525af, 0x12002d0c,   // lg.hr.eu_222 eu.rw.un_970  eu.rw.lg_655 sk.hu.un_530
  // [7270]
  0x55642507, 0x04110709, 0x28001807, 0x042d1707,   // eu.lg.rw_432 bg.ro.ru_444  ga.sw.un_420 sr.sk.fi_432
  0x3f0429a4, 0x0a1710a4, 0x01050704, 0x12000d0c,   // sl.fi.af_433 be.sr.mk_433  it.fr.en_332 cs.hu.un_530
  0x29002702, 0x072129ad, 0x13060c05, 0x3f036405,   // gd.sl.un_220 sl.jw.it_643  sv.de.et_333 lg.nl.af_333
  0x1f000605, 0x07033f0b, 0x12000d19, 0x3f6403a9,   // de.cy.un_330 af.nl.it_542  cs.hu.un_750 nl.lg.af_544
  // [7280]
  0x1a6b0baf, 0x080a17af, 0x0e000612, 0x27005319,   // es.ceb.tl_655 sr.mk.uk_655  de.is.un_640 ht.gd.un_750
  0x532555af, 0x0b005305, 0x06212da0, 0x23003f04,   // rw.eu.ht_655 ht.es.un_330  sk.jw.de_322 af.ca.un_320
  0x1c641a04, 0x06040c0d, 0x11006b09, 0x18000e12,   // tl.lg.id_332 sv.fi.de_554  ceb.ro.un_440 is.ga.un_640
  0x211c1a04, 0x5500530d, 0x112155af, 0x0200060e,   // tl.id.jw_332 ht.rw.un_540  rw.jw.ro_655 de.da.un_550
  // [7290]
  0x6b001a2c, 0x28080ba0, 0x05002013, 0x6b531a11,   // tl.ceb.un_990 es.no.sw_322  sq.fr.un_650 tl.ht.ceb_653
  0x040b1304, 0x01033fee, 0x111955af, 0x0b1107a4,   // et.es.fi_332 af.nl.en_422  rw.gl.ro_655 it.ro.es_433
  0x6400530d, 0x23000913, 0x0d000608, 0x251120a4,   // ht.lg.un_540 pl.ca.un_650  de.cs.un_430 sq.ro.eu_433
  0x20006b05, 0x090603ee, 0x2000642b, 0x0a0b0604,   // ceb.sq.un_330 nl.de.pl_422  lg.sq.un_980 de.es.pt_332
  // [72a0]
  0x090d01a0, 0x55092105, 0x2b640107, 0x1b00041a,   // en.cs.pl_322 jw.pl.rw_333  en.lg.vi_432 fi.tr.un_760
  0x1e003102, 0x00001a37, 0x1607280c, 0x0b2a1912,   // az.ms.un_220 tl.un.un_B00  sw.it.hr_543 gl.mt.es_654
  0x0d6401ec, 0x1f002022, 0x31006429, 0x55001b0e,   // en.lg.cs_644 sq.cy.un_870  lg.az.un_960 tr.rw.un_550
  0x21000a05, 0x08021702, 0x2d100b02, 0x07062a12,   // pt.jw.un_330 sr.da.no_222  es.lt.sk_222 mt.de.it_654
  // [72b0]
  0x1c0f21a0, 0x043f55ec, 0x1f003f35, 0x2d1b2007,   // jw.lv.id_322 rw.af.fi_644  af.cy.un_A90 sq.tr.sk_432
  0x09001b08, 0x2b2d0d13, 0x3f1f0955, 0x09072a11,   // tr.pl.un_430 cs.sk.vi_665  pl.cy.af_442 mt.it.pl_653
  0x0b120a12, 0x20002b0d, 0x6b1a2b0c, 0x1b101aac,   // pt.hu.es_654 vi.sq.un_540  vi.tl.ceb_543 tl.lt.tr_632
  0x2000530e, 0x01042704, 0x210853a0, 0x0c002502,   // ht.sq.un_550 gd.fi.en_332  ht.no.jw_322 eu.sv.un_220
  // [72c0]
  0x04161302, 0x28002302, 0x53002302, 0x16042002,   // et.hr.fi_222 ca.sw.un_220  ca.ht.un_220 sq.fi.hr_222
  0x09131cad, 0x0e001205, 0x290d2da9, 0x092d10ee,   // mr.bh.hi_643 hu.is.un_330  sk.cs.sl_544 lt.sk.pl_422
  0x0b2311ac, 0x25101907, 0x0b0a01ee, 0x230a07a0,   // ro.ca.es_632 gl.lt.eu_432  en.pt.es_422 it.pt.ca_322
  0x06081f04, 0x53002305, 0x21000707, 0x2d0f2004,   // cy.no.de_332 ca.ht.un_330  it.jw.un_420 sq.lv.sk_332
  // [72d0]
  0x3f000602, 0x0f0e13a0, 0x170810a4, 0x0d122dec,   // de.af.un_220 et.is.lv_322  be.uk.sr_433 sk.hu.cs_644
  0x645355a4, 0x04080204, 0x53001b08, 0x310523a4,   // rw.ht.lg_433 da.no.fi_332  tr.ht.un_430 ca.fr.az_433
  0x1a6b64a4, 0x12002009, 0x04091e07, 0x1a551ba0,   // lg.ceb.tl_433 sq.hu.un_440  ms.pl.fi_432 tr.rw.tl_322
  0x10082aad, 0x1b0b6ba0, 0x071f100c, 0x072321a4,   // mt.no.lt_643 ceb.es.tr_322  lt.cy.it_543 jw.ca.it_433
  // [72e0]
  0x11271811, 0x076455a4, 0x2300271a, 0x11071ba4,   // ga.gd.ro_653 rw.lg.it_433  gd.ca.un_760 tr.it.ro_433
  0x05200c04, 0x100f0a0c, 0x1b6b64a4, 0x2a012ba4,   // sv.sq.fr_332 pt.lv.lt_543  lg.ceb.tr_433 vi.en.mt_433
  0x0621090c, 0x0400120c, 0x02080660, 0x53050707,   // pl.jw.de_543 hu.fi.un_530  de.no.da_664 it.fr.ht_432
  0x1b001a0d, 0x21121005, 0x07160107, 0x0a000823,   // tl.tr.un_540 lt.hu.jw_333  en.hr.it_432 uk.mk.un_880
  // [72f0]
  0x53250107, 0x10051a05, 0x2128555a, 0x1b2731ee,   // en.eu.ht_432 tl.fr.lt_333  rw.sw.jw_553 az.gd.tr_422
  0x1b005302, 0x12161307, 0x1004110b, 0x0c083f02,   // ht.tr.un_220 et.hr.hu_432  ro.ru.be_542 af.no.sv_222
  0x53002904, 0x071b0508, 0x180419a4, 0x0e12040e,   // sl.ht.un_320 fr.tr.it_443  gl.fi.ga_433 fi.hu.is_555
  0x01005504, 0x013f09ad, 0x02130407, 0x042a1314,   // rw.en.un_320 pl.af.en_643  fi.et.da_432 et.mt.fi_666
  // [7300]
  0x120f0e07, 0x130210ad, 0x08061b04, 0x1001230c,   // is.lv.hu_432 lt.da.et_643  tr.de.no_332 ca.en.lt_543
  0x01001008, 0x12000407, 0x23080205, 0x013f13a0,   // lt.en.un_430 fi.hu.un_420  da.no.ca_333 et.af.en_322
  0x050823a0, 0x120104a0, 0x23000f04, 0x2100180b,   // ca.no.fr_322 fi.en.hu_322  lv.ca.un_320 ar.fa.un_520
  0x0c081204, 0x04070808, 0x0f100da0, 0x1301080c,   // hu.no.sv_332 uk.bg.ru_443  cs.lt.lv_322 no.en.et_543
  // [7310]
  0x1711160c, 0x1000070e, 0x170d16a7, 0x16002b05,   // hr.ro.sr_543 bg.be.un_550  hr.cs.sr_532 vi.hr.un_330
  0x17070460, 0x120a2da9, 0x09001102, 0x09191fa4,   // ru.bg.sr_664 sk.pt.hu_544  ro.pl.un_220 cy.gl.pl_433
  0x27002b02, 0x020c1304, 0x030709ee, 0x09002a0d,   // vi.gd.un_220 et.sv.da_332  pl.it.nl_422 mt.pl.un_540
  0x0f2d1702, 0x0e1328a4, 0x132155ec, 0x08280eaf,   // sr.sk.lv_222 sw.et.is_433  rw.jw.et_644 is.sw.no_655
  // [7320]
  0x1b1153a4, 0x04203f04, 0x21531c0b, 0x25290f60,   // ht.ro.tr_433 af.sq.fi_332  id.ht.jw_542 lv.sl.eu_664
  0x0b0a2ba0, 0x0e642807, 0x04006405, 0x641a2108,   // vi.pt.es_322 sw.lg.is_432  lg.fi.un_330 jw.tl.lg_443
  0x1c0a0702, 0x191e1ca9, 0x64002319, 0x2100190d,   // it.pt.id_222 id.ms.gl_544  ca.lg.un_750 gl.jw.un_540
  0x120e0908, 0x271823a4, 0x0f2d10a4, 0x09000c0e,   // pl.is.hu_443 ca.ga.gd_433  lt.sk.lv_433 sv.pl.un_550
  // [7330]
  0x061f020c, 0x0e3f0308, 0x18256402, 0x030a2aee,   // da.cy.de_543 nl.af.is_443  lg.eu.ga_222 mt.pt.nl_422
  0x20230ba4, 0x0d642da9, 0x19230b0d, 0x101a19a0,   // es.ca.sq_433 sk.lg.cs_544  es.ca.gl_554 gl.tl.lt_322
  0x1a210107, 0x31191b05, 0x0820230c, 0x53002d0d,   // en.jw.tl_432 tr.gl.az_333  ca.sq.no_543 sk.ht.un_540
  0x2d0d09a7, 0x20120ea7, 0x280755a0, 0x0f080d07,   // pl.cs.sk_532 is.hu.sq_532  rw.it.sw_322 cs.no.lv_432
  // [7340]
  0x0800102c, 0x1a2153a9, 0x2317200c, 0x06203f09,   // be.uk.un_990 ht.jw.tl_544  sq.sr.ca_543 af.sq.de_444
  0x071119a6, 0x10090704, 0x1c002a0c, 0x0a002309,   // gl.ro.it_521 it.pl.lt_332  mt.id.un_530 ca.pt.un_440
  0x080204a0, 0x012a09a0, 0x01060bee, 0x07002813,   // fi.da.no_322 pl.mt.en_322  es.de.en_422 sw.it.un_650
  0x230a010c, 0x215508a9, 0x1a0b530c, 0x060107a0,   // en.pt.ca_543 no.rw.jw_544  ht.es.tl_543 it.en.de_322
  // [7350]
  0x536409a9, 0x2b002008, 0x0a0408ee, 0x13040e07,   // pl.lg.ht_544 sq.vi.un_430  uk.ru.mk_422 is.fi.et_432
  0x0c1223ee, 0x07081705, 0x060507a0, 0x131602ee,   // ca.hu.sv_422 sr.uk.bg_333  it.fr.de_322 da.hr.et_422
  0x06002508, 0x13003f08, 0x02200807, 0x10043fa7,   // eu.de.un_430 af.et.un_430  no.sq.da_432 af.fi.lt_532
  0x030413a9, 0x030e12a7, 0x2a071b14, 0x3f64040c,   // et.fi.nl_544 hu.is.nl_532  tr.it.mt_666 fi.lg.af_543
  // [7360]
  0x21082007, 0x1e201ca0, 0x1e000e14, 0x25131f02,   // sq.no.jw_432 id.sq.ms_322  is.ms.un_660 cy.et.eu_222
  0x231f0ea4, 0x2a000f08, 0x1704070d, 0x0c04100c,   // is.cy.ca_433 lv.mt.un_430  bg.ru.sr_554 lt.fi.sv_543
  0x64072aaf, 0x070853a0, 0x0d000e04, 0x6b001319,   // mt.it.lg_655 ht.no.it_322  is.cs.un_320 et.ceb.un_750
  0x0e010808, 0x08006b0e, 0x2a006413, 0x08210ea4,   // no.en.is_443 ceb.no.un_550  lg.mt.un_650 is.jw.no_433
  // [7370]
  0x1a6b210c, 0x162d2905, 0x06640cee, 0x11020807,   // jw.ceb.tl_543 sl.sk.hr_333  sv.lg.de_422 no.da.ro_432
  0x642a0713, 0x161017ee, 0x2a00641a, 0x04072a02,   // it.mt.lg_665 sr.lt.hr_422  lg.mt.un_760 mt.it.fi_222
  0x252a5312, 0x1f180e0c, 0x1a0b6b04, 0x083f11ee,   // ht.mt.eu_654 is.ga.cy_543  ceb.es.tl_332 ro.af.no_422
  0x29001002, 0x3f000213, 0x3f1a6b5a, 0x04081107,   // lt.sl.un_220 da.af.un_650  ceb.tl.af_553 ro.uk.ru_432
  // [7380]
  0x2b002d02, 0x130353a9, 0x18080c04, 0x08101709,   // sk.vi.un_220 ht.nl.et_544  sv.no.ga_332 sr.be.uk_444
  0x0f2d10ee, 0x08110704, 0x101711a6, 0x086b0204,   // lt.sk.lv_422 bg.ro.uk_332  ro.sr.be_521 da.ceb.no_332
  0x190723af, 0x05061fa7, 0x07110404, 0x645328ee,   // ca.it.gl_655 cy.de.fr_532  ru.ro.bg_332 sw.ht.lg_422
  0x131911ad, 0x0300110c, 0x160d1755, 0x131102ec,   // ro.gl.et_643 ro.nl.un_530  sr.cs.hr_442 da.ro.et_644
  // [7390]
  0x13005507, 0x3f0306a7, 0x0e210f04, 0x02063f13,   // rw.et.un_420 de.nl.af_532  lv.jw.is_332 af.de.da_665
  0x16002d18, 0x201728ee, 0x1a006b2c, 0x190b0aa9,   // sk.hr.un_740 sw.sr.sq_422  ceb.tl.un_990 pt.es.gl_544
  0x01001113, 0x3f6b1805, 0x27001f08, 0x182705a7,   // ro.en.un_650 ga.ceb.af_333  cy.gd.un_430 fr.gd.ga_532
  0x19001702, 0x10002a0c, 0x2d17295a, 0x2d0811a0,   // sr.gl.un_220 mt.lt.un_530  sl.sr.sk_553 ro.no.sk_322
  // [73a0]
  0x030813a4, 0x051307a0, 0x100313ee, 0x1300080e,   // et.no.nl_433 it.et.fr_322  et.nl.lt_422 no.et.un_550
  0x2908210c, 0x641303a0, 0x1b0c13ee, 0x550c10a0,   // jw.no.sl_543 nl.et.lg_322  et.sv.tr_422 lt.sv.rw_322
  0x11070aa4, 0x10001213, 0x0e00050c, 0x1764280c,   // mk.bg.ro_433 hu.lt.un_650  fr.is.un_530 sw.lg.sr_543
  0x3f031307, 0x165303ad, 0x170b5307, 0x2a011c02,   // et.nl.af_432 nl.ht.hr_643  ht.es.sr_432 id.en.mt_222
  // [73b0]
  0x1e011702, 0x1b08120c, 0x0a0811a9, 0x0c060e0e,   // sr.en.ms_222 hu.no.tr_543  ro.uk.mk_544 is.de.sv_555
  0x04060ea7, 0x130e1005, 0x0e0c1305, 0x2a3f0308,   // is.de.fi_532 lt.is.et_333  et.sv.is_333 nl.af.mt_443
  0x170316ad, 0x3f0e08a0, 0x0f0e2507, 0x29000c0c,   // hr.nl.sr_643 no.is.af_322  eu.is.lv_432 sv.sl.un_530
  0x1728160c, 0x20046ba0, 0x310e1b09, 0x16130e07,   // hr.sw.sr_543 ceb.fi.sq_322  tr.is.az_444 is.et.hr_432
  // [73c0]
  0x16000f04, 0x312113a4, 0x211c0e09, 0x100c0e05,   // lv.hr.un_320 et.jw.az_433  is.id.jw_444 is.sv.lt_333
  0x095312ac, 0x200e08ec, 0x132d0d55, 0x316b0d07,   // hu.ht.pl_632 no.is.sq_644  cs.sk.et_442 cs.ceb.az_432
  0x0e6b31a4, 0x04000912, 0x1b002802, 0x0a2d0d04,   // az.ceb.is_433 pl.fi.un_640  sw.tr.un_220 cs.sk.pt_332
  0x172d0d14, 0x552d0d04, 0x08042004, 0x0e002013,   // cs.sk.sr_666 cs.sk.rw_332  sq.fi.no_332 sq.is.un_650
  // [73d0]
  0x6b1907a0, 0x111e28a0, 0x0d2829a0, 0x07100812,   // it.gl.ceb_322 sw.ms.ro_322  sl.sw.cs_322 uk.be.bg_654
  0x0a251fad, 0x07002705, 0x17311bee, 0x552a5305,   // cy.eu.pt_643 gd.it.un_330  tr.az.sr_422 ht.mt.rw_333
  0x28002a0b, 0x102818ee, 0x06180804, 0x640c0213,   // mt.sw.un_520 ga.sw.lt_422  no.ga.de_332 da.sv.lg_665
  0x182d0dec, 0x06080fa0, 0x081f64a4, 0x09062a08,   // cs.sk.ga_644 lv.no.de_322  lg.cy.no_433 mt.de.pl_443
  // [73e0]
  0x01080ea7, 0x09033fa4, 0x03016407, 0x165328ad,   // is.no.en_532 af.nl.pl_433  lg.en.nl_432 sw.ht.hr_643
  0x3f00010b, 0x1f1c2aee, 0x25006421, 0x1b005307,   // en.af.un_520 mt.id.cy_422  lg.eu.un_860 ht.tr.un_420
  0x3f000418, 0x0e1109ee, 0x162701a0, 0x6b641a05,   // fi.af.un_740 pl.ro.is_422  en.gd.hr_322 tl.lg.ceb_333
  0x6b0304a0, 0x04136405, 0x2a2808ac, 0x0912640b,   // fi.nl.ceb_322 lg.et.fi_333  no.sw.mt_632 lg.hu.pl_542
  // [73f0]
  0x0c001f11, 0x29171b08, 0x18060c55, 0x0c04080c,   // cy.sv.un_630 tr.sr.sl_443  sv.de.ga_442 no.fi.sv_543
  0x64001f22, 0x2b6b01a9, 0x0f006407, 0x251364ee,   // cy.lg.un_870 en.ceb.vi_544  lg.lv.un_420 lg.et.eu_422
  0x53281112, 0x64021fa7, 0x2a006422, 0x060c25ac,   // ro.sw.ht_654 cy.da.lg_532  lg.mt.un_870 eu.sv.de_632
  0x6b0906ad, 0x6400281a, 0x20170f04, 0x08130e12,   // de.pl.ceb_643 sw.lg.un_760  lv.sr.sq_332 is.et.no_654

  // [7400]
  0x28063f04, 0x07010504, 0x53642855, 0x0327640c,   // af.de.sw_332 fr.en.it_332  sw.lg.ht_442 lg.gd.nl_543
  0x13042509, 0x133f0312, 0x18000607, 0x121821a0,   // eu.fi.et_444 nl.af.et_654  de.ga.un_420 fa.ar.ur_322
  0x161b11a0, 0x295317a0, 0x25001307, 0x29101aa4,   // ro.tr.hr_322 sr.ht.sl_322  et.eu.un_420 tl.lt.sl_433
  0x55055307, 0x190d0aee, 0x1b006e14, 0x03083f0d,   // ht.fr.rw_432 pt.cs.gl_422  blu.tr.un_660 af.no.nl_554
  // [7410]
  0x170623ad, 0x0628640d, 0x531908a0, 0x550628a7,   // ca.de.sr_643 lg.sw.de_554  no.gl.ht_322 sw.de.rw_532
  0x1028530c, 0x16131707, 0x12001a13, 0x03233fa0,   // ht.sw.lt_543 sr.et.hr_432  tl.hu.un_650 af.ca.nl_322
  0x21001f07, 0x1b001113, 0x173f02a0, 0x0a001a08,   // cy.jw.un_420 ro.tr.un_650  da.af.sr_322 tl.pt.un_430
  0x532510a4, 0x1b1004a4, 0x0a1710ad, 0x0d080555,   // lt.eu.ht_433 fi.lt.tr_433  be.sr.mk_643 fr.no.cs_442
  // [7420]
  0x1731100c, 0x17110805, 0x12002702, 0x013f0802,   // lt.az.sr_543 uk.ro.sr_333  gd.hu.un_220 no.af.en_222
  0x09101a0c, 0x0700290c, 0x0a231907, 0x1b0d2aa0,   // tl.lt.pl_543 sl.it.un_530  gl.ca.pt_432 mt.cs.tr_322
  0x050f2002, 0x075525a4, 0x1617080c, 0x0410080b,   // sq.lv.fr_222 eu.rw.it_433  no.sr.hr_543 uk.be.ru_542
  0x532910a4, 0x06002a0e, 0x2d170ca4, 0x05000f14,   // lt.sl.ht_433 mt.de.un_550  sv.sr.sk_433 lv.fr.un_660
  // [7430]
  0x1f1611ee, 0x2500552a, 0x0f536402, 0x03110512,   // ro.hr.cy_422 rw.eu.un_970  lg.ht.lv_222 fr.ro.nl_654
  0x0f0e23ac, 0x0f00230e, 0x640c04a4, 0x0228200c,   // ca.is.lv_632 ca.lv.un_550  fi.sv.lg_433 sq.sw.da_543
  0x10000e09, 0x04080aec, 0x072504a0, 0x230f050c,   // is.lt.un_440 mk.uk.ru_644  fi.eu.it_322 fr.lv.ca_543
  0x110725a4, 0x250501a0, 0x0f0523ee, 0x022025a4,   // eu.it.ro_433 en.fr.eu_322  ca.fr.lv_422 eu.sq.da_433
  // [7440]
  0x052520ee, 0x01000f08, 0x64000219, 0x530b1107,   // sq.eu.fr_422 lv.en.un_430  da.lg.un_750 ro.es.ht_432
  0x642701a4, 0x643f1f04, 0x0c640307, 0x28005309,   // en.gd.lg_433 cy.af.lg_332  nl.lg.sv_432 ht.sw.un_440
  0x190b1b05, 0x0d025311, 0x29161007, 0x2a0c0ead,   // tr.es.gl_333 ht.da.cs_653  lt.hr.sl_432 is.sv.mt_643
  0x01080c04, 0x080e0202, 0x120c06ee, 0x3f001305,   // sv.no.en_332 da.is.no_222  de.sv.hu_422 et.af.un_330
  // [7450]
  0x0c3f2507, 0x0c022aa0, 0x2b000507, 0x022a01ee,   // eu.af.sv_432 mt.da.sv_322  fr.vi.un_420 en.mt.da_422
  0x552b05a4, 0x1b190bad, 0x050f0208, 0x07040a55,   // fr.vi.rw_433 es.gl.tr_643  da.lv.fr_443 mk.ru.bg_442
  0x28532a0c, 0x0c060fa0, 0x0f122804, 0x0a120e04,   // mt.ht.sw_543 lv.de.sv_322  sw.hu.lv_332 is.hu.pt_332
  0x12000502, 0x0f002a10, 0x12001005, 0x13090da0,   // fr.hu.un_220 mt.lv.un_620  lt.hu.un_330 ne.hi.bh_322
  // [7460]
  0x1017110c, 0x05011f07, 0x02050604, 0x31000108,   // ro.sr.be_543 cy.en.fr_432  de.fr.da_332 en.az.un_430
  0x1b000809, 0x120610a0, 0x64281e0c, 0x211b0fec,   // no.tr.un_440 lt.de.hu_322  ms.sw.lg_543 lv.tr.jw_644
  0x2b281fee, 0x1b102aa0, 0x161210a4, 0x3f0e0855,   // cy.sw.vi_422 mt.lt.tr_322  lt.hu.hr_433 no.is.af_442
  0x0f0e3f05, 0x2a1b2804, 0x02012304, 0x033f08a9,   // af.is.lv_333 sw.tr.mt_332  ca.en.da_332 no.af.nl_544
  // [7470]
  0x19271fee, 0x1e1c25ec, 0x010618a0, 0x0c311f04,   // cy.gd.gl_422 eu.id.ms_644  ga.de.en_322 cy.az.sv_332
  0x280806a7, 0x0c020eee, 0x0f3f0355, 0x080c02a4,   // de.no.sw_532 is.da.sv_422  nl.af.lv_442 da.sv.no_433
  0x2d290d14, 0x13001e02, 0x11000a07, 0x1f1a0307,   // cs.sl.sk_666 ms.et.un_220  pt.ro.un_420 nl.tl.cy_432
  0x0d0420ee, 0x1b13210c, 0x2d1209a4, 0x0c030fa0,   // sq.fi.cs_422 jw.et.tr_543  pl.hu.sk_433 lv.nl.sv_322
  // [7480]
  0x0e081307, 0x042917a9, 0x080e0f07, 0x180413a7,   // et.no.is_432 sr.sl.fi_544  lv.is.no_432 et.fi.ga_532
  0x080c0107, 0x17001308, 0x040f1304, 0x04003102,   // en.sv.no_432 et.sr.un_430  et.lv.fi_332 az.fi.un_220
  0x6b120204, 0x17001207, 0x04132807, 0x180e090c,   // da.hu.ceb_332 hu.sr.un_420  sw.et.fi_432 pl.is.ga_543
  0x110510a0, 0x0c0f0e08, 0x04081712, 0x1b2555ec,   // lt.fr.ro_322 is.lv.sv_443  sr.uk.ru_654 rw.eu.tr_644
  // [7490]
  0x25001f1a, 0x2d0d0ea0, 0x02080c5a, 0x1e210802,   // cy.eu.un_760 is.cs.sk_322  sv.no.da_553 no.jw.ms_222
  0x0c1008a4, 0x13002522, 0x070a2a07, 0x16100608,   // no.lt.sv_433 eu.et.un_870  mt.pt.it_432 de.lt.hr_443
  0x13080c08, 0x1b0a01a4, 0x0800130e, 0x280103a0,   // sv.no.et_443 en.pt.tr_433  et.no.un_550 nl.en.sw_322
  0x1f072a07, 0x020c0e07, 0x6404130d, 0x21045555,   // mt.it.cy_432 is.sv.da_432  et.fi.lg_554 rw.fi.jw_442
  // [74a0]
  0x18002802, 0x04556405, 0x12003104, 0x64280fad,   // sw.ga.un_220 lg.rw.fi_333  az.hu.un_320 lv.sw.lg_643
  0x1f18270b, 0x0c0823ee, 0x29162da4, 0x08021202,   // gd.ga.cy_542 ca.no.sv_422  sk.hr.sl_433 hu.da.no_222
  0x0d001321, 0x25006413, 0x166425ec, 0x6b64250c,   // bh.ne.un_860 lg.eu.un_650  eu.lg.hr_644 eu.lg.ceb_543
  0x64251609, 0x04092d07, 0x64256b0b, 0x556425af,   // hr.eu.lg_444 sk.pl.fi_432  ceb.eu.lg_542 eu.lg.rw_655
  // [74b0]
  0x04001608, 0x64282508, 0x0c063107, 0x0c002002,   // hr.fi.un_430 eu.sw.lg_443  az.de.sv_432 sq.sv.un_220
  0x556425ad, 0x130812a0, 0x0d002804, 0x28006419,   // eu.lg.rw_643 hu.no.et_322  sw.cs.un_320 lg.sw.un_750
  0x6400252b, 0x64251060, 0x1a29250b, 0x0d280e12,   // eu.lg.un_980 lt.eu.lg_664  eu.sl.tl_542 is.sw.cs_654
  0x04061fa0, 0x6b00251a, 0x03533fa0, 0x25000a07,   // cy.de.fi_322 eu.ceb.un_760  af.ht.nl_322 pt.eu.un_420
  // [74c0]
  0x64551b5a, 0x1c21170c, 0x55001a05, 0x111c08ee,   // tr.rw.lg_553 sr.jw.id_543  tl.rw.un_330 no.id.ro_422
  0x1f000a0c, 0x25202807, 0x31281ba4, 0x0a003102,   // pt.cy.un_530 sw.sq.eu_432  tr.sw.az_433 az.pt.un_220
  0x1a0b01a0, 0x132510a4, 0x1b1a280d, 0x01230508,   // en.es.tl_322 lt.eu.et_433  sw.tl.tr_554 fr.ca.en_443
  0x0d09110c, 0x0d0c130c, 0x532128ad, 0x2a276b02,   // ro.pl.cs_543 et.sv.cs_543  sw.jw.ht_643 ceb.gd.mt_222
  // [74d0]
  0x080228ec, 0x133f0808, 0x0d003f04, 0x2706180c,   // sw.da.no_644 no.af.et_443  af.cs.un_320 ga.de.gd_543
  0x050301ac, 0x09006e0d, 0x31001f12, 0x13091cad,   // en.nl.fr_632 blu.pl.un_540  cy.az.un_640 mr.hi.bh_643
  0x0e080209, 0x0e001208, 0x06041307, 0x070a17ec,   // da.no.is_444 hu.is.un_430  et.fi.de_432 sr.mk.bg_644
  0x086b01a0, 0x100e0704, 0x12041912, 0x3f6403a4,   // en.ceb.no_322 it.is.lt_332  gl.fi.hu_654 nl.lg.af_433
  // [74e0]
  0x161304ee, 0x04121b07, 0x12000208, 0x0a171002,   // fi.et.hr_422 tr.hu.fi_432  da.hu.un_430 be.sr.mk_222
  0x03043fa0, 0x53021b55, 0x0c1a120c, 0x271804a4,   // af.fi.nl_322 tr.da.ht_442  hu.tl.sv_543 fi.ga.gd_433
  0x0411080c, 0x200c08a0, 0x071117a7, 0x1f0e0cac,   // uk.ro.ru_543 no.sv.sq_322  sr.ro.bg_532 sv.is.cy_632
  0x1708040e, 0x0f120ba6, 0x210801ad, 0x250912ad,   // ru.uk.sr_555 es.hu.lv_521  en.no.jw_643 hu.pl.eu_643
  // [74f0]
  0x0d292d0c, 0x1f020812, 0x022731a7, 0x131617a4,   // sk.sl.cs_543 no.da.cy_654  az.gd.da_532 sr.hr.et_433
  0x2d001f02, 0x0e642aec, 0x12131113, 0x0e120d02,   // cy.sk.un_220 mt.lg.is_644  ro.et.hu_665 cs.hu.is_222
  0x10120807, 0x1f08025a, 0x120d0ea0, 0x08130c0c,   // no.hu.lt_432 da.no.cy_553  is.cs.hu_322 sv.et.no_543
  0x16132913, 0x3f090d12, 0x1f0208ec, 0x12002b1a,   // sl.et.hr_665 cs.pl.af_654  no.da.cy_644 vi.hu.un_760
  // [7500]
  0x21000c07, 0x085323ad, 0x171310ad, 0x0802200c,   // sv.jw.un_420 ca.ht.no_643  lt.et.sr_643 sq.da.no_543
  0x19130708, 0x1b0620a7, 0x2a00130d, 0x200608a6,   // it.et.gl_443 sq.de.tr_532  et.mt.un_540 no.de.sq_521
  0x0e002512, 0x53080c12, 0x10001108, 0x0e171bee,   // eu.is.un_640 sv.no.ht_654  ro.be.un_430 tr.sr.is_422
  0x20190b04, 0x2d011802, 0x071325a0, 0x055501a0,   // es.gl.sq_332 ga.en.sk_222  eu.et.it_322 en.rw.fr_322
  // [7510]
  0x050720ad, 0x25271804, 0x05006407, 0x55111802,   // sq.it.fr_643 ga.gd.eu_332  lg.fr.un_420 ga.ro.rw_222
  0x0b2520a4, 0x550705a0, 0x0a005304, 0x0a07045a,   // sq.eu.es_433 fr.it.rw_322  ht.pt.un_320 ru.bg.mk_553
  0x2d120ead, 0x3f020355, 0x640a0655, 0x20001807,   // is.hu.sk_643 nl.da.af_442  de.pt.lg_442 ga.sq.un_420
  0x01192302, 0x080a070e, 0x10170a04, 0x27002007,   // ca.gl.en_222 bg.mk.uk_555  mk.sr.be_332 sq.gd.un_420
  // [7520]
  0x05200814, 0x191606ad, 0x03190aa0, 0x070c01a4,   // no.sq.fr_666 de.hr.gl_643  pt.gl.nl_322 en.sv.it_433
  0x190a5505, 0x0e002002, 0x0c001704, 0x1b062907,   // rw.pt.gl_333 sq.is.un_220  sr.sv.un_320 sl.de.tr_432
  0x6b126405, 0x190b0505, 0x08556404, 0x060c19a4,   // lg.hu.ceb_333 fr.es.gl_333  lg.rw.no_332 gl.sv.de_433
  0x1a033f12, 0x212a18a0, 0x1118230c, 0x27180105,   // af.nl.tl_654 ga.mt.jw_322  ca.ga.ro_543 en.ga.gd_333
  // [7530]
  0x25130409, 0x0c050107, 0x6b6401a0, 0x06181f0d,   // fi.et.eu_444 en.fr.sv_432  en.lg.ceb_322 cy.ga.de_554
  0x0f281aa4, 0x27001e07, 0x18006b0c, 0x2318270c,   // tl.sw.lv_433 ms.gd.un_420  ceb.ga.un_530 gd.ga.ca_543
  0x07101708, 0x180403a0, 0x170a04ad, 0x3f000604,   // sr.be.bg_443 nl.fi.ga_322  ru.mk.sr_643 de.af.un_320
  0x05000b0c, 0x203f1f04, 0x172916ec, 0x18002004,   // es.fr.un_530 cy.af.sq_332  hr.sl.sr_644 sq.ga.un_320
  // [7540]
  0x120701a4, 0x171320ee, 0x281a0107, 0x040710ec,   // en.it.hu_433 sq.et.sr_422  en.tl.sw_432 be.bg.ru_644
  0x0f006b07, 0x1e2801a0, 0x2a1a13a4, 0x19132a02,   // ceb.lv.un_420 en.sw.ms_322  et.tl.mt_433 mt.et.gl_222
  0x07011cee, 0x28091a07, 0x2907250c, 0x010c2307,   // id.en.it_422 tl.pl.sw_432  eu.it.sl_543 ca.sv.en_432
  0x17031611, 0x0e3f0607, 0x1900250c, 0x01230504,   // hr.nl.sr_653 de.af.is_432  eu.gl.un_530 fr.ca.en_332
  // [7550]
  0x0c001213, 0x6b0c1304, 0x310b2302, 0x06030ca4,   // hu.sv.un_650 et.sv.ceb_332  ca.es.az_222 sv.nl.de_433
  0x1b0519ad, 0x29160907, 0x28060eee, 0x05230107,   // gl.fr.tr_643 pl.hr.sl_432  is.de.sw_422 en.ca.fr_432
  0x2b00210c, 0x130d1c0c, 0x532d0604, 0x1b002804,   // jw.vi.un_530 mr.ne.bh_543  de.sk.ht_332 sw.tr.un_320
  0x07060807, 0x070a1113, 0x2d1309a9, 0x532d0d05,   // no.de.it_432 ro.mk.bg_665  pl.et.sk_544 cs.sk.ht_333
  // [7560]
  0x290913a4, 0x6b081007, 0x551716ee, 0x6b201aee,   // et.pl.sl_433 lt.no.ceb_432  hr.sr.rw_422 tl.sq.ceb_422
  0x13041108, 0x08003f0d, 0x110a0405, 0x11041307,   // ro.fi.et_443 af.no.un_540  ru.mk.ro_333 et.fi.ro_432
  0x31280107, 0x31040ea0, 0x02161304, 0x130801a4,   // en.sw.az_432 is.fi.az_322  et.hr.da_332 en.no.et_433
  0x171b310c, 0x0d005302, 0x53001902, 0x17160e5a,   // az.tr.sr_543 ht.cs.un_220  gl.ht.un_220 is.hr.sr_553
  // [7570]
  0x13001113, 0x186b01a6, 0x192d0ba7, 0x120c0302,   // ro.et.un_650 en.ceb.ga_521  es.sk.gl_532 nl.sv.hu_222
  0x230b13a4, 0x0b002d04, 0x531c2a07, 0x1e102104,   // et.es.ca_433 sk.es.un_320  mt.id.ht_432 jw.lt.ms_332
  0x12080e0c, 0x250e0814, 0x21191704, 0x091001a4,   // is.no.hu_543 no.is.eu_666  sr.gl.jw_332 en.lt.pl_433
  0x070a175a, 0x20002104, 0x070a080d, 0x192d290c,   // sr.mk.bg_553 jw.sq.un_320  uk.mk.bg_554 sl.sk.gl_543
  // [7580]
  0x03120802, 0x0929110c, 0x0c001602, 0x550c0eaf,   // no.hu.nl_222 ro.sl.pl_543  hr.sv.un_220 is.sv.rw_655
  0x04131c07, 0x07002804, 0x28070107, 0x5300280b,   // id.et.fi_432 sw.it.un_320  en.it.sw_432 sw.ht.un_520
  0x070601a0, 0x3f1b03ee, 0x21065307, 0x641f095a,   // en.de.it_322 nl.tr.af_422  ht.de.jw_432 pl.cy.lg_553
  0x311b55ad, 0x06270fa0, 0x0b00290c, 0x230705a0,   // rw.tr.az_643 lv.gd.de_322  sl.es.un_530 fr.it.ca_322
  // [7590]
  0x171609ad, 0x06130413, 0x17000612, 0x050b1104,   // pl.hr.sr_643 fi.et.de_665  de.sr.un_640 ro.es.fr_332
  0x040f13a4, 0x082a0502, 0x08553fa0, 0x08000508,   // et.lv.fi_433 fr.mt.no_222  af.rw.no_322 fr.no.un_430
  0x07110a55, 0x131a06a6, 0x101613a4, 0x21006404,   // mk.ro.bg_442 de.tl.et_521  et.hr.lt_433 lg.jw.un_320
  0x6b2a01ee, 0x1e1105ee, 0x0a0712a4, 0x2d190bad,   // en.mt.ceb_422 fr.ro.ms_422  hu.it.pt_433 es.gl.sk_643
  // [75a0]
  0x64101aa0, 0x6b010a07, 0x231827ee, 0x091025a7,   // tl.lt.lg_322 pt.en.ceb_432  gd.ga.ca_422 eu.lt.pl_532
  0x0b0e19a6, 0x2d0d0f0c, 0x25000d04, 0x3f250c0c,   // gl.is.es_521 lv.cs.sk_543  cs.eu.un_320 sv.eu.af_543
  0x0c5323a7, 0x29170f07, 0x0e2718ee, 0x53000519,   // ca.ht.sv_532 lv.sr.sl_432  ga.gd.is_422 fr.ht.un_750
  0x25310312, 0x130a0fa7, 0x251a550c, 0x041708a7,   // nl.az.eu_654 lv.pt.et_532  rw.tl.eu_543 uk.sr.ru_532
  // [75b0]
  0x022b0e5a, 0x23002902, 0x191801a0, 0x1b181fee,   // is.vi.da_553 sl.ca.un_220  en.ga.gl_322 cy.ga.tr_422
  0x2d0d160c, 0x04171602, 0x07102013, 0x1c0f1eaf,   // hr.cs.sk_543 hr.sr.fi_222  sq.lt.it_665 ms.lv.id_655
  0x04001b08, 0x2902060c, 0x05180a02, 0x07005514,   // tr.fi.un_430 de.da.sl_543  pt.ga.fr_222 rw.it.un_660
  0x2d090d12, 0x09642d09, 0x0c2b0107, 0x04212da9,   // cs.pl.sk_654 sk.lg.pl_444  en.vi.sv_432 sk.jw.fi_544
  // [75c0]
  0x04071012, 0x29102108, 0x112153ee, 0x53005512,   // be.bg.ru_654 jw.lt.sl_443  ht.jw.ro_422 rw.ht.un_640
  0x05211ca0, 0x2b550aa4, 0x16000e0d, 0x0f0721a7,   // id.jw.fr_322 pt.rw.vi_433  is.hr.un_540 jw.it.lv_532
  0x0e130107, 0x04001814, 0x29002508, 0x011c55a6,   // en.et.is_432 ga.fi.un_660  eu.sl.un_430 rw.id.en_521
  0x04061b07, 0x211210a6, 0x28001802, 0x04101702,   // tr.de.fi_432 lt.hu.jw_521  ga.sw.un_220 sr.be.ru_222
  // [75d0]
  0x09171609, 0x1a282107, 0x215301ad, 0x0425135a,   // hr.sr.pl_444 jw.sw.tl_432  en.ht.jw_643 et.eu.fi_553
  0x01042855, 0x1119235a, 0x1b312d02, 0x21033faf,   // sw.fi.en_442 ca.gl.ro_553  sk.az.tr_222 af.nl.jw_655
  0x2a1f18ad, 0x07210107, 0x23112da4, 0x0b000714,   // ga.cy.mt_643 en.jw.it_432  sk.ro.ca_433 it.es.un_660
  0x10311b55, 0x0f033f08, 0x64080455, 0x190e180c,   // tr.az.lt_442 af.nl.lv_443  fi.no.lg_442 ga.is.gl_543
  // [75e0]
  0x0e001007, 0x10081fa4, 0x11100460, 0x2b001902,   // lt.is.un_420 cy.no.lt_433  ru.be.ro_664 gl.vi.un_220
  0x030812ad, 0x271a2aee, 0x09001019, 0x232513a9,   // hu.no.nl_643 mt.tl.gd_422  lt.pl.un_750 et.eu.ca_544
  0x270818a0, 0x230501ee, 0x081710a0, 0x13236baf,   // ga.no.gd_322 en.fr.ca_422  be.sr.uk_322 ceb.ca.et_655
  0x280f0404, 0x311c0b05, 0x64286ea0, 0x230a05af,   // fi.lv.sw_332 es.id.az_333  blu.sw.lg_322 fr.pt.ca_655
  // [75f0]
  0x033f04a4, 0x112a01a0, 0x292305a0, 0x2817160c,   // fi.af.nl_433 en.mt.ro_322  fr.ca.sl_322 hr.sr.sw_543
  0x1b1304ad, 0x1c13100c, 0x0f002319, 0x28180b02,   // fi.et.tr_643 lt.et.id_543  ca.lv.un_750 es.ga.sw_222
  0x21286ba4, 0x2a0e31a0, 0x171604a4, 0x1f000f21,   // ceb.sw.jw_433 az.is.mt_322  fi.hr.sr_433 lv.cy.un_860
  0x1e080208, 0x28001a0d, 0x11070508, 0x640b27a4,   // da.no.ms_443 tl.sw.un_540  fr.it.ro_443 gd.es.lg_433
  // [7600]
  0x231101a4, 0x0b0a2302, 0x29090d0c, 0x310e12ee,   // en.ro.ca_433 ca.pt.es_222  cs.pl.sl_543 hu.is.az_422
  0x1b2513a0, 0x10000104, 0x6b030612, 0x25081308,   // et.eu.tr_322 en.lt.un_320  de.nl.ceb_654 et.no.eu_443
  0x6b1a1305, 0x02250813, 0x1b1c31a0, 0x0a27250c,   // et.tl.ceb_333 no.eu.da_665  az.id.tr_322 eu.gd.pt_543
  0x100a170d, 0x10043f0c, 0x08130e14, 0x21170407,   // sr.mk.be_554 af.fi.lt_543  is.et.no_666 fi.sr.jw_432
  // [7610]
  0x1709290e, 0x08022508, 0x0d1609a4, 0x28211aa9,   // sl.pl.sr_555 eu.da.no_443  pl.hr.cs_433 tl.jw.sw_544
  0x021a25a0, 0x172d160c, 0x11000204, 0x25001313,   // eu.tl.da_322 hr.sk.sr_543  da.ro.un_320 et.eu.un_650
  0x190b23af, 0x0b0a0604, 0x536b1a11, 0x0f001611,   // ca.es.gl_655 de.pt.es_332  tl.ceb.ht_653 hr.lv.un_630
  0x041708af, 0x0e3f25a4, 0x0b002519, 0x07080aad,   // uk.sr.ru_655 eu.af.is_433  eu.es.un_750 mk.uk.bg_643
  // [7620]
  0x2d0d05ee, 0x20000f04, 0x2119050c, 0x01001a07,   // fr.cs.sk_422 lv.sq.un_320  fr.gl.jw_543 tl.en.un_420
  0x3f0c08a0, 0x201710a7, 0x050c01a4, 0x186413a9,   // no.sv.af_322 lt.sr.sq_532  en.sv.fr_433 et.lg.ga_544
  0x0e1b53a4, 0x0e082107, 0x6b1e20ee, 0x130e2aa0,   // ht.tr.is_433 jw.no.is_432  sq.ms.ceb_422 mt.is.et_322
  0x2a130409, 0x0f000607, 0x1b006b08, 0x0711100b,   // fi.et.mt_444 de.lv.un_420  ceb.tr.un_430 be.ro.bg_542
  // [7630]
  0x27640705, 0x105521ec, 0x6b641b12, 0x0800131a,   // it.lg.gd_333 jw.rw.lt_644  tr.lg.ceb_654 et.no.un_760
  0x0c133155, 0x0c2864ee, 0x1b310907, 0x641c2107,   // az.et.sv_442 lg.sw.sv_422  pl.az.tr_432 jw.id.lg_432
  0x1f2b28ad, 0x08062905, 0x0b000a23, 0x270864a0,   // sw.vi.cy_643 sl.de.no_333  pt.es.un_880 lg.no.gd_322
  0x0e0c1baf, 0x550713a0, 0x291725ad, 0x6b001e13,   // tr.sv.is_655 et.it.rw_322  eu.sr.sl_643 ms.ceb.un_650
  // [7640]
  0x2d000a0c, 0x2517270c, 0x3f001b02, 0x21131aaf,   // pt.sk.un_530 gd.sr.eu_543  tr.af.un_220 tl.et.jw_655
  0x0c062307, 0x0f110ca4, 0x08002808, 0x021b1c0c,   // ca.de.sv_432 sv.ro.lv_433  sw.no.un_430 id.tr.da_543
  0x21251c11, 0x25092009, 0x2a00270c, 0x28001321,   // id.eu.jw_653 sq.pl.eu_444  gd.mt.un_530 et.sw.un_860
  0x0e121808, 0x5306280c, 0x16001711, 0x2500190d,   // ga.hu.is_443 sw.de.ht_543  sr.hr.un_630 gl.eu.un_540
  // [7650]
  0x10002a02, 0x64211ea0, 0x080c1f04, 0x0b1b55a9,   // mt.lt.un_220 ms.jw.lg_322  cy.sv.no_332 rw.tr.es_544
  0x21192502, 0x21000f05, 0x1b312aee, 0x0f042805,   // eu.gl.jw_222 lv.jw.un_330  mt.az.tr_422 sw.fi.lv_333
  0x211a6ba4, 0x1f1e1c12, 0x6b1a040b, 0x080e2707,   // ceb.tl.jw_433 id.ms.cy_654  fi.tl.ceb_542 gd.is.no_432
  0x0b000802, 0x17162911, 0x1a550608, 0x1a216ea0,   // no.es.un_220 sl.hr.sr_653  de.rw.tl_443 blu.jw.tl_322
  // [7660]
  0x04000e07, 0x080228af, 0x041c2111, 0x64000f04,   // is.fi.un_420 sw.da.no_655  jw.id.fi_653 lv.lg.un_320
  0x55000b04, 0x19002b14, 0x64286bad, 0x0a002d09,   // es.rw.un_320 vi.gl.un_660  ceb.sw.lg_643 sk.pt.un_440
  0x2b000e19, 0x080e64ad, 0x31071f07, 0x3f020c0c,   // is.vi.un_750 lg.is.no_643  cy.it.az_432 sv.da.af_543
  0x310e04a0, 0x081627a0, 0x1c2a1e0c, 0x01002a0b,   // fi.is.az_322 gd.hr.no_322  ms.mt.id_543 mt.en.un_520
  // [7670]
  0x1a002914, 0x130425a4, 0x2d161704, 0x16211ca0,   // sl.tl.un_660 eu.fi.et_433  sr.hr.sk_332 id.jw.hr_322
  0x0d130c13, 0x03005502, 0x122d0d0c, 0x070817a9,   // sv.et.cs_665 rw.nl.un_220  cs.sk.hu_543 sr.uk.bg_544
  0x3f1b31a9, 0x0800040b, 0x06311bec, 0x2d53090d,   // az.tr.af_544 ru.uk.un_520  tr.az.de_644 pl.ht.sk_554
  0x10081f04, 0x04002a08, 0x2d120511, 0x2a0e1b05,   // cy.no.lt_332 mt.fi.un_430  fr.hu.sk_653 tr.is.mt_333
  // [7680]
  0x532d0d0e, 0x552821a4, 0x1f000e14, 0x11001605,   // cs.sk.ht_555 jw.sw.rw_433  is.cy.un_660 hr.ro.un_330
  0x6e002009, 0x31171608, 0x216e0d04, 0x1b0e1a07,   // sq.blu.un_440 hr.sr.az_443  cs.blu.jw_332 tl.is.tr_432
  0x0b120511, 0x10201f11, 0x0c041e04, 0x211b64ee,   // fr.hu.es_653 cy.sq.lt_653  ms.fi.sv_332 lg.tr.jw_422
  0x55190b02, 0x236e19a0, 0x3f2d0d60, 0x095505a4,   // es.gl.rw_222 gl.blu.ca_322  cs.sk.af_664 fr.rw.pl_433
  // [7690]
  0x55001004, 0x111e1c08, 0x232d0dec, 0x1f0413ee,   // lt.rw.un_320 id.ms.ro_443  cs.sk.ca_644 et.fi.cy_422
  0x09001b0c, 0x04121ea0, 0x0c020105, 0x64001204,   // tr.pl.un_530 ms.hu.fi_322  en.da.sv_333 hu.lg.un_320
  0x1a6b0e08, 0x100464af, 0x201b2307, 0x061608ec,   // is.ceb.tl_443 lg.fi.lt_655  ca.tr.sq_432 no.hr.de_644
  0x190701ee, 0x0d001c02, 0x1a2a08a0, 0x120a05ac,   // en.it.gl_422 id.cs.un_220  no.mt.tl_322 fr.pt.hu_632
  // [76a0]
  0x1f005502, 0x2900091b, 0x03043fa4, 0x062b0112,   // rw.cy.un_220 pl.sl.un_770  af.fi.nl_433 en.vi.de_654
  0x6400552a, 0x2a070907, 0x0500061a, 0x3f1627a0,   // rw.lg.un_970 pl.it.mt_432  de.fr.un_760 gd.hr.af_322
  0x06001219, 0x64001321, 0x10552102, 0x3f6401a0,   // hu.de.un_750 et.lg.un_860  jw.rw.lt_222 en.lg.af_322
  0x08000619, 0x64551113, 0x2713040c, 0x0a001720,   // de.no.un_750 ro.rw.lg_665  fi.et.gd_543 sr.mk.un_850
  // [76b0]
  0x211b11ee, 0x1b20310d, 0x0d1617ee, 0x111801a0,   // ro.tr.jw_422 az.sq.tr_554  sr.hr.cs_422 en.ga.ro_322
  0x1f230b08, 0x05001908, 0x2b171608, 0x25001202,   // es.ca.cy_443 gl.fr.un_430  hr.sr.vi_443 hu.eu.un_220
  0x20001b0d, 0x182d0d04, 0x0f2a0712, 0x290b2104,   // tr.sq.un_540 cs.sk.ga_332  it.mt.lv_654 jw.es.sl_332
  0x1c231304, 0x1c092955, 0x08290960, 0x28000c0b,   // et.ca.id_332 sl.pl.id_442  pl.sl.no_664 sv.sw.un_520
  // [76c0]
  0x04170aad, 0x64551314, 0x13000107, 0x2321110c,   // mk.sr.ru_643 et.rw.lg_666  en.et.un_420 ro.jw.ca_543
  0x6b2b0b0c, 0x1c000d1b, 0x1e001c0c, 0x0755250c,   // es.vi.ceb_543 ne.mr.un_770  id.ms.un_530 eu.rw.it_543
  0x08256b05, 0x1b312508, 0x08000c20, 0x0e190da0,   // ceb.eu.no_333 eu.az.tr_443  sv.no.un_850 cs.gl.is_322
  0x6b071ca0, 0x19110a07, 0x11070da7, 0x1f000c05,   // id.it.ceb_322 pt.ro.gl_432  cs.it.ro_532 sv.cy.un_330
  // [76d0]
  0x07230102, 0x0c08021a, 0x080a1714, 0x0c2a19ee,   // en.ca.it_222 da.no.sv_776  sr.mk.uk_666 gl.mt.sv_422
  0x180c04ee, 0x1c0e1ea9, 0x01532ba7, 0x2a0f1012,   // fi.sv.ga_422 ms.is.id_544  vi.ht.en_532 lt.lv.mt_654
  0x1606010d, 0x552120ad, 0x0e0c0212, 0x06130fa0,   // en.de.hr_554 sq.jw.rw_643  da.sv.is_654 lv.et.de_322
  0x091716a0, 0x533121a0, 0x2d190a02, 0x55645304,   // hr.sr.pl_322 jw.az.ht_322  pt.gl.sk_222 ht.lg.rw_332
  // [76e0]
  0x216b55a7, 0x3f022102, 0x0f1f1813, 0x28550aa9,   // rw.ceb.jw_532 jw.da.af_222  ga.cy.lv_665 pt.rw.sw_544
  0x29000c07, 0x010821a0, 0x0e080214, 0x023f03af,   // sv.sl.un_420 jw.no.en_322  da.no.is_666 nl.af.da_655
  0x3f030e0c, 0x0d060ca0, 0x17163fee, 0x062d01ee,   // is.nl.af_543 sv.de.cs_322  af.hr.sr_422 en.sk.de_422
  0x18006408, 0x190a2daf, 0x0521530c, 0x0f0c08a4,   // lg.ga.un_430 sk.pt.gl_655  ht.jw.fr_543 no.sv.lv_433
  // [76f0]
  0x190b120c, 0x1a000304, 0x31000613, 0x110f29a0,   // hu.es.gl_543 nl.tl.un_320  de.az.un_650 sl.lv.ro_322
  0x10000821, 0x12002a08, 0x29270aa4, 0x31532108,   // uk.be.un_860 mt.hu.un_430  pt.gd.sl_433 jw.ht.az_443
  0x11291309, 0x111e200c, 0x10060c0e, 0x0e061f05,   // et.sl.ro_444 sq.ms.ro_543  sv.de.lt_555 cy.de.is_333
  0x2855640e, 0x07210608, 0x530a190c, 0x1e1b2b14,   // lg.rw.sw_555 de.jw.it_443  gl.pt.ht_543 vi.tr.ms_666
  // [7700]
  0x530507a4, 0x21002d08, 0x16172d11, 0x290c27a9,   // it.fr.ht_433 sk.jw.un_430  sk.sr.hr_653 gd.sv.sl_544
  0x08020faf, 0x0d001107, 0x64135507, 0x18002d05,   // lv.da.no_655 ro.cs.un_420  rw.et.lg_432 sk.ga.un_330
  0x0a070107, 0x1804270c, 0x0b1c0f05, 0x3f03120e,   // en.it.pt_432 gd.fi.ga_543  lv.id.es_333 hu.nl.af_555
  0x1804270d, 0x171b2508, 0x1f1b08a4, 0x0c251bee,   // gd.fi.ga_554 eu.tr.sr_443  no.tr.cy_433 tr.eu.sv_422
  // [7710]
  0x0e0c08a4, 0x211f090b, 0x08010407, 0x3f0764ee,   // no.sv.is_433 pl.cy.jw_542  fi.en.no_432 lg.it.af_422
  0x0a052355, 0x13060ca7, 0x05201b0c, 0x20051ba9,   // ca.fr.pt_442 sv.de.et_532  tr.sq.fr_543 tr.fr.sq_544
  0x3f030c0c, 0x052029a4, 0x190528a4, 0x03080205,   // sv.nl.af_543 sl.sq.fr_433  sw.fr.gl_433 da.no.nl_333
  0x646b1a12, 0x051104ad, 0x090f10ee, 0x0b0f06ee,   // tl.ceb.lg_654 fi.ro.fr_643  lt.lv.pl_422 de.lv.es_422
  // [7720]
  0x1c0806a0, 0x25090f04, 0x191205ec, 0x05280107,   // de.no.id_322 lv.pl.eu_332  fr.hu.gl_644 en.sw.fr_432
  0x170a1055, 0x25000911, 0x2b000909, 0x062a09ad,   // be.mk.sr_442 pl.eu.un_630  pl.vi.un_440 pl.mt.de_643
  0x64001f04, 0x17161ca4, 0x0f00310d, 0x09170d09,   // cy.lg.un_320 id.hr.sr_433  az.lv.un_540 cs.sr.pl_444
  0x23190b07, 0x213120a0, 0x09062a07, 0x25060307,   // es.gl.ca_432 sq.az.jw_322  mt.de.pl_432 nl.de.eu_432
  // [7730]
  0x093f0607, 0x06250708, 0x0a1008a4, 0x2d000a04,   // de.af.pl_432 it.eu.de_443  uk.be.mk_433 pt.sk.un_320
  0x01050b05, 0x190a0514, 0x18000b19, 0x0f040607,   // es.fr.en_333 fr.pt.gl_666  es.ga.un_750 de.fi.lv_432
  0x100f04a7, 0x04100faf, 0x06031304, 0x07006408,   // fi.lv.lt_532 lv.lt.fi_655  et.nl.de_332 lg.it.un_430
  0x12001012, 0x191a06ec, 0x1c1908ee, 0x0d00550c,   // lt.hu.un_640 de.tl.gl_644  no.gl.id_422 rw.cs.un_530
  // [7740]
  0x20001b12, 0x03062011, 0x12640709, 0x122a07af,   // tr.sq.un_640 sq.de.nl_653  it.lg.hu_444 it.mt.hu_655
  0x200c0811, 0x1b001804, 0x0e1025a4, 0x23050ba9,   // no.sv.sq_653 ga.tr.un_320  eu.lt.is_433 es.fr.ca_544
  0x12000709, 0x17080e07, 0x07002a0c, 0x28202a02,   // it.hu.un_440 is.no.sr_432  mt.it.un_530 mt.sq.sw_222
  0x06120eee, 0x211e1a13, 0x033f2808, 0x641a2812,   // is.hu.de_422 tl.ms.jw_665  sw.af.nl_443 sw.tl.lg_654
  // [7750]
  0x161a1712, 0x281a6412, 0x08020eec, 0x0a001007,   // sr.tl.hr_654 lg.tl.sw_654  is.da.no_644 be.mk.un_420
  0x1a646ba9, 0x21003f13, 0x121c2104, 0x2d0d2311,   // ceb.lg.tl_544 af.jw.un_650  jw.id.hu_332 ca.cs.sk_653
  0x1a1e1c60, 0x172529ee, 0x0700120d, 0x171625a4,   // id.ms.tl_664 sl.eu.sr_422  hu.it.un_540 eu.hr.sr_433
  0x311b64af, 0x20002812, 0x1b6428a9, 0x642a070c,   // lg.tr.az_655 sw.sq.un_640  sw.lg.tr_544 it.mt.lg_543
  // [7760]
  0x12072a0c, 0x0c081f09, 0x20001302, 0x0a531e04,   // mt.it.hu_543 cy.no.sv_444  et.sq.un_220 ms.ht.pt_332
  0x10002108, 0x310f20ee, 0x6e0701a0, 0x1a00640d,   // jw.lt.un_430 sq.lv.az_422  en.it.blu_322 lg.tl.un_540
  0x21556413, 0x111012ad, 0x1e1c1aa9, 0x0e6b1aec,   // lg.rw.jw_665 hu.lt.ro_643  tl.id.ms_544 tl.ceb.is_644
  0x03250407, 0x0b5564af, 0x55311b12, 0x2821640e,   // fi.eu.nl_432 lg.rw.es_655  tr.az.rw_654 lg.jw.sw_555
  // [7770]
  0x31002114, 0x12001b04, 0x21000502, 0x110110ee,   // jw.az.un_660 tr.hu.un_320  fr.jw.un_220 lt.en.ro_422
  0x1b00200d, 0x0f092508, 0x1a21010c, 0x1a056eee,   // sq.tr.un_540 eu.pl.lv_443  en.jw.tl_543 blu.fr.tl_422
  0x1c0b5307, 0x181f3f0b, 0x04101307, 0x0b1004a4,   // ht.es.id_432 af.cy.ga_542  et.lt.fi_432 fi.lt.es_433
  0x071204ad, 0x131c2a04, 0x19000802, 0x16131002,   // fi.hu.it_643 mt.id.et_332  no.gl.un_220 lt.et.hr_222
  // [7780]
  0x19055355, 0x6b1104a0, 0x18120da9, 0x256b2807,   // ht.fr.gl_442 fi.ro.ceb_322  cs.hu.ga_544 sw.ceb.eu_432
  0x110a2ba4, 0x02030504, 0x0d002a09, 0x0a116b04,   // vi.pt.ro_433 fr.nl.da_332  mt.cs.un_440 ceb.ro.pt_332
  0x12130ead, 0x3f0e1004, 0x1100080b, 0x0b071104,   // is.et.hu_643 lt.is.af_332  no.ro.un_520 ro.it.es_332
  0x0d2d2907, 0x1a0406a0, 0x0d000721, 0x25000708,   // sl.sk.cs_432 de.fi.tl_322  it.cs.un_860 it.eu.un_430
  // [7790]
  0x08112804, 0x1000070c, 0x1e001104, 0x192811a0,   // sw.ro.no_332 it.lt.un_530  ro.ms.un_320 ro.sw.gl_322
  0x2b2110a6, 0x25000714, 0x20003f0d, 0x122d0dad,   // lt.jw.vi_521 it.eu.un_660  af.sq.un_540 cs.sk.hu_643
  0x0a0417ee, 0x271820a0, 0x053f0302, 0x1708535a,   // sr.ru.mk_422 sq.ga.gd_322  nl.af.fr_222 ht.no.sr_553
  0x2a5305ee, 0x020e08a4, 0x04033f13, 0x193f0fa4,   // fr.ht.mt_422 no.is.da_433  af.nl.fi_665 lv.af.gl_433
  // [77a0]
  0x0600090e, 0x55282a05, 0x090353a0, 0x05000b13,   // pl.de.un_550 mt.sw.rw_333  ht.nl.pl_322 es.fr.un_650
  0x53001f19, 0x0600070e, 0x17190808, 0x6e190a13,   // cy.ht.un_750 it.de.un_550  no.gl.sr_443 pt.gl.blu_665
  0x16021907, 0x11551e07, 0x0600031a, 0x551c1e07,   // gl.da.hr_432 ms.rw.ro_432  nl.de.un_760 ms.id.rw_432
  0x060802a0, 0x550501ee, 0x211b6b0d, 0x07010b0e,   // da.no.de_322 en.fr.rw_422  ceb.tr.jw_554 es.en.it_555
  // [77b0]
  0x09162505, 0x010b05a4, 0x04052308, 0x2a1e530c,   // eu.hr.pl_333 fr.es.en_433  ca.fr.fi_443 ht.ms.mt_543
  0x29191708, 0x23060b0e, 0x645328a4, 0x0f0610a0,   // sr.gl.sl_443 es.de.ca_555  sw.ht.lg_433 lt.de.lv_322
  0x31001907, 0x53042da0, 0x0e131e07, 0x55002023,   // gl.az.un_420 sk.fi.ht_322  ms.et.is_432 sq.rw.un_880
  0x0f001302, 0x536409ec, 0x1c251ea4, 0x120f2904,   // et.lv.un_220 pl.lg.ht_644  ms.eu.id_433 sl.lv.hu_332
  // [77c0]
  0x231f0a0c, 0x010227a0, 0x08001c04, 0x1e1f1a05,   // pt.cy.ca_543 gd.da.en_322  id.no.un_320 tl.cy.ms_333
  0x05005323, 0x190a64a4, 0x042d250c, 0x191a0807,   // ht.fr.un_880 lg.pt.gl_433  eu.sk.fi_543 no.tl.gl_432
  0x271a6bad, 0x2a002705, 0x090f1f0c, 0x09162d09,   // ceb.tl.gd_643 gd.mt.un_330  cy.lv.pl_543 sk.hr.pl_444
  0x06091108, 0x1c2855ad, 0x0c010212, 0x6b642da4,   // ro.pl.de_443 rw.sw.id_643  da.en.sv_654 sk.lg.ceb_433
  // [77d0]
  0x6b1a640d, 0x071e1c08, 0x11211c0d, 0x21082b05,   // lg.tl.ceb_554 id.ms.it_443  id.jw.ro_554 vi.no.jw_333
  0x210f1c07, 0x28251aaf, 0x1a101ca4, 0x211e280c,   // id.lv.jw_432 tl.eu.sw_655  id.lt.tl_433 sw.ms.jw_543
  0x311210a0, 0x06080c04, 0x1c2128af, 0x110453a4,   // lt.hu.az_322 sv.no.de_332  sw.jw.id_655 ht.fi.ro_433
  0x0e1b120c, 0x6b006412, 0x06101ba4, 0x0d122da4,   // hu.tr.is_543 lg.ceb.un_640  tr.lt.de_433 sk.hu.cs_433
  // [77e0]
  0x041c1ea4, 0x2516640c, 0x2a080904, 0x1c041eec,   // ms.id.fi_433 lg.hr.eu_543  pl.no.mt_332 ms.fi.id_644
  0x041e1c60, 0x28005523, 0x3f020807, 0x1e1c11a4,   // id.ms.fi_664 rw.sw.un_880  no.da.af_432 ro.id.ms_433
  0x011b0ea0, 0x160a070c, 0x070810ee, 0x21001b13,   // is.tr.en_322 it.pt.hr_543  be.uk.bg_422 tr.jw.un_650
  0x1600100c, 0x3f000a0d, 0x0a003f14, 0x1c002902,   // lt.hr.un_530 pt.af.un_540  af.pt.un_660 sl.id.un_220
  // [77f0]
  0x1e281c04, 0x0f001304, 0x2000231b, 0x02033faf,   // id.sw.ms_332 et.lv.un_320  ca.sq.un_770 af.nl.da_655
  0x17100aee, 0x230a20a7, 0x0b230aee, 0x0a2d0ea0,   // mk.be.sr_422 sq.pt.ca_532  pt.ca.es_422 is.sk.pt_322
  0x0f210b02, 0x31002322, 0x083f2aee, 0x0c000e2c,   // es.jw.lv_222 ca.az.un_870  mt.af.no_422 is.sv.un_990
  0x070417ac, 0x100e0cad, 0x19180aa9, 0x53003f0c,   // sr.ru.bg_632 sv.is.lt_643  pt.ga.gl_544 af.ht.un_530

  // [7800]
  0x04011307, 0x08235302, 0x080e010c, 0x31001004,   // et.en.fi_432 ht.ca.no_222  en.is.no_543 lt.az.un_320
  0x060e010c, 0x29001a04, 0x29020c08, 0x130f1011,   // en.is.de_543 tl.sl.un_320  sv.da.sl_443 lt.lv.et_653
  0x080c02a9, 0x6b0f1004, 0x060e1f0c, 0x0a000b09,   // da.sv.no_544 lt.lv.ceb_332  cy.is.de_543 es.pt.un_440
  0x2b002107, 0x2b002907, 0x21002a04, 0x28002508,   // jw.vi.un_420 sl.vi.un_420  mt.jw.un_320 eu.sw.un_430
  // [7810]
  0x0c5325a7, 0x100c2a07, 0x2a036b02, 0x2000091a,   // eu.ht.sv_532 mt.sv.lt_432  ceb.nl.mt_222 pl.sq.un_760
  0x05082705, 0x31080205, 0x09003f12, 0x08020c13,   // gd.no.fr_333 da.no.az_333  af.pl.un_640 sv.da.no_665
  0x030625a9, 0x2a2818a4, 0x16100404, 0x190625a7,   // eu.de.nl_544 ga.sw.mt_433  fi.lt.hr_332 eu.de.gl_532
  0x1800070b, 0x3f1c1e0c, 0x1e13210c, 0x020e010c,   // it.ga.un_520 ms.id.af_543  jw.et.ms_543 en.is.da_543
  // [7820]
  0x18270513, 0x2d002314, 0x02290ca4, 0x0c001821,   // fr.gd.ga_665 ca.sk.un_660  sv.sl.da_433 ga.sv.un_860
  0x17161aa0, 0x03215309, 0x23060513, 0x0d2d0907,   // tl.hr.sr_322 ht.jw.nl_444  fr.de.ca_665 pl.sk.cs_432
  0x6e00090c, 0x02532907, 0x0e270804, 0x162d090c,   // pl.blu.un_530 sl.ht.da_432  no.gd.is_332 pl.sk.hr_543
  0x0a002514, 0x01250605, 0x29096e0c, 0x2b1a53ee,   // eu.pt.un_660 de.eu.en_333  blu.pl.sl_543 ht.tl.vi_422
  // [7830]
  0x0b191808, 0x25001911, 0x3f211ca4, 0x110417a4,   // ga.gl.es_443 gl.eu.un_630  id.jw.af_433 sr.ru.ro_433
  0x25210c07, 0x53552aad, 0x31230aa0, 0x2100251a,   // sv.jw.eu_432 mt.rw.ht_643  pt.ca.az_322 eu.jw.un_760
  0x31002a0d, 0x53311b04, 0x311323a4, 0x1300080d,   // mt.az.un_540 tr.az.ht_332  ca.et.az_433 no.et.un_540
  0x29002007, 0x0c0201a0, 0x1100010c, 0x0600130b,   // sq.sl.un_420 en.da.sv_322  en.ro.un_530 et.de.un_520
  // [7840]
  0x06230107, 0x010928a6, 0x2319130c, 0x033f23ec,   // en.ca.de_432 sw.pl.en_521  et.gl.ca_543 ca.af.nl_644
  0x1a130c07, 0x0f003f0c, 0x2d000a09, 0x3f230507,   // sv.et.tl_432 af.lv.un_530  pt.sk.un_440 fr.ca.af_432
  0x030f3fad, 0x03053faf, 0x170711ad, 0x12001f05,   // af.lv.nl_643 af.fr.nl_655  ro.bg.sr_643 cy.hu.un_330
  0x0c006b02, 0x092a03ee, 0x25070402, 0x01640f04,   // ceb.sv.un_220 nl.mt.pl_422  fi.it.eu_222 lv.lg.en_332
  // [7850]
  0x3f0910a0, 0x01171604, 0x55001607, 0x09002a02,   // lt.pl.af_322 hr.sr.en_332  hr.rw.un_420 mt.pl.un_220
  0x1f002b02, 0x23090aa4, 0x6e1331a9, 0x020c03a0,   // vi.cy.un_220 pt.pl.ca_433  az.et.blu_544 nl.sv.da_322
  0x6e0102a7, 0x6e131fa7, 0x2d001907, 0x0408170d,   // da.en.blu_532 cy.et.blu_532  gl.sk.un_420 sr.uk.ru_554
  0x023f0312, 0x020e0ca4, 0x0b0105a0, 0x0c002319,   // nl.af.da_654 sv.is.da_433  fr.en.es_322 ca.sv.un_750
  // [7860]
  0x17080cee, 0x19080202, 0x0d00530e, 0x2b0b0155,   // sv.no.sr_422 da.no.gl_222  ht.cs.un_550 en.es.vi_442
  0x010c08a0, 0x0e2806ee, 0x012a03ee, 0x100806a4,   // no.sv.en_322 de.sw.is_422  nl.mt.en_422 de.no.lt_433
  0x08000c19, 0x642103a0, 0x133f06a0, 0x1f2d0d0e,   // sv.no.un_750 nl.jw.lg_322  de.af.et_322 cs.sk.cy_555
  0x090a01ee, 0x316e13a4, 0x1a0507a4, 0x1321310c,   // en.pt.pl_422 et.blu.az_433  it.fr.tl_433 az.jw.et_543
  // [7870]
  0x0b111904, 0x060d1fad, 0x1e211311, 0x216e2b11,   // gl.ro.es_332 cy.cs.de_643  et.jw.ms_653 vi.blu.jw_653
  0x18006414, 0x052b5304, 0x2b1a01ac, 0x6b2005ee,   // lg.ga.un_660 ht.vi.fr_332  en.tl.vi_632 fr.sq.ceb_422
  0x1e3f0304, 0x1b061208, 0x08003105, 0x28130413,   // nl.af.ms_332 hu.de.tr_443  az.no.un_330 fi.et.sw_665
  0x136b04a0, 0x27000208, 0x132804a9, 0x116b0104,   // fi.ceb.et_322 da.gd.un_430  fi.sw.et_544 en.ceb.ro_332
  // [7880]
  0x040e1aa0, 0x25033f0e, 0x2721180e, 0x1104130d,   // tl.is.fi_322 af.nl.eu_555  ga.jw.gd_555 et.fi.ro_554
  0x2d0d6407, 0x64110405, 0x64132da0, 0x21051808,   // lg.cs.sk_432 fi.ro.lg_333  sk.et.lg_322 ga.fr.jw_443
  0x25171fa7, 0x281b64ee, 0x061f03a4, 0x0209640c,   // cy.sr.eu_532 lg.tr.sw_422  nl.cy.de_433 lg.pl.da_543
  0x28162905, 0x23041004, 0x31000202, 0x1f0513ee,   // sl.hr.sw_333 lt.fi.ca_332  da.az.un_220 et.fr.cy_422
  // [7890]
  0x10271f04, 0x0c0102a4, 0x27180407, 0x1b286b09,   // cy.gd.lt_332 da.en.sv_433  fi.ga.gd_432 ceb.sw.tr_444
  0x190b1ea4, 0x230b1109, 0x251c21a9, 0x281a6b14,   // ms.es.gl_433 ro.es.ca_444  jw.id.eu_544 ceb.tl.sw_666
  0x19002507, 0x04001a05, 0x6b286455, 0x08000d0d,   // eu.gl.un_420 tl.fi.un_330  lg.sw.ceb_442 cs.no.un_540
  0x0c00280c, 0x1c080207, 0x250f55a9, 0x19080da4,   // sw.sv.un_530 da.no.id_432  rw.lv.eu_544 cs.no.gl_433
  // [78a0]
  0x31000b02, 0x190b23a6, 0x21111e02, 0x03000207,   // es.az.un_220 ca.es.gl_521  ms.ro.jw_222 da.nl.un_420
  0x531a100d, 0x211e28ec, 0x1a001c08, 0x0d082dad,   // lt.tl.ht_554 sw.ms.jw_644  id.tl.un_430 sk.no.cs_643
  0x0c082904, 0x29172da7, 0x05006e07, 0x0c0817a0,   // sl.no.sv_332 sk.sr.sl_532  blu.fr.un_420 sr.no.sv_322
  0x0c020e09, 0x0e020c04, 0x0d1629a0, 0x0a05110c,   // is.da.sv_444 sv.da.is_332  sl.hr.cs_322 ro.fr.pt_543
  // [78b0]
  0x1b00250e, 0x08100709, 0x64002a05, 0x0c020e04,   // eu.tr.un_550 bg.be.uk_444  mt.lg.un_330 is.da.sv_332
  0x28001805, 0x1b000c07, 0x23171602, 0x1b113108,   // ga.sw.un_330 sv.tr.un_420  hr.sr.ca_222 az.ro.tr_443
  0x2b00110c, 0x1711070c, 0x1b251104, 0x10552807,   // ro.vi.un_530 bg.ro.sr_543  ro.eu.tr_332 sw.rw.lt_432
  0x1900180d, 0x17080402, 0x2d0c0da0, 0x1753160c,   // ga.gl.un_540 ru.uk.sr_222  cs.sv.sk_322 hr.ht.sr_543
  // [78c0]
  0x211e1c0b, 0x5300250c, 0x3f0313a4, 0x1300250c,   // id.ms.jw_542 eu.ht.un_530  et.nl.af_433 eu.et.un_530
  0x531a21ee, 0x53311cee, 0x081b255a, 0x64001309,   // jw.tl.ht_422 id.az.ht_422  eu.tr.no_553 et.lg.un_440
  0x31251b60, 0x0f31050c, 0x0d002504, 0x29002713,   // tr.eu.az_664 fr.az.lv_543  eu.cs.un_320 gd.sl.un_650
  0x3f6b64a7, 0x53116ba0, 0x04000509, 0x19001207,   // lg.ceb.af_532 ceb.ro.ht_322  fr.fi.un_440 hu.gl.un_420
  // [78d0]
  0x12002512, 0x17040713, 0x02000e12, 0x0e0811ec,   // eu.hu.un_640 bg.ru.sr_665  is.da.un_640 ro.no.is_644
  0x071104a4, 0x1f000404, 0x3f080c07, 0x29000e08,   // ru.ro.bg_433 fi.cy.un_320  sv.no.af_432 is.sl.un_430
  0x10000718, 0x64000f09, 0x01131fee, 0x2810090c,   // bg.be.un_740 lv.lg.un_440  cy.et.en_422 pl.lt.sw_543
  0x072801a0, 0x1f092808, 0x1f0c0204, 0x6b0a1f05,   // en.sw.it_322 sw.pl.cy_443  da.sv.cy_332 cy.pt.ceb_333
  // [78e0]
  0x230229ee, 0x1a10285a, 0x2a00280d, 0x080d01ee,   // sl.da.ca_422 sw.lt.tl_553  sw.mt.un_540 en.cs.no_422
  0x2d0603a7, 0x2d0d53a4, 0x1f0518a9, 0x2a1716a9,   // nl.de.sk_532 ht.cs.sk_433  ga.fr.cy_544 hr.sr.mt_544
  0x0f092902, 0x176416a0, 0x192d0805, 0x281b0755,   // sl.pl.lv_222 hr.lg.sr_322  no.sk.gl_333 it.tr.sw_442
  0x251807a4, 0x12002d1b, 0x0d092da7, 0x050108a0,   // it.ga.eu_433 sk.hu.un_770  sk.pl.cs_532 no.en.fr_322
  // [78f0]
  0x28000b09, 0x03022b04, 0x6b033f04, 0x1f10280c,   // es.sw.un_440 vi.da.nl_332  af.nl.ceb_332 sw.lt.cy_543
  0x0920070c, 0x0d1a01a4, 0x2a136b05, 0x0a1017a4,   // it.sq.pl_543 en.tl.cs_433  ceb.et.mt_333 sr.be.mk_433
  0x08111308, 0x1a033f07, 0x11005521, 0x64110705,   // et.ro.no_443 af.nl.tl_432  rw.ro.un_860 it.ro.lg_333
  0x1c0131ee, 0x1117040c, 0x25001702, 0x6b2d1b05,   // az.en.id_422 ru.sr.ro_543  sr.eu.un_220 tr.sk.ceb_333
  // [7900]
  0x1b3121a0, 0x1c000a02, 0x1100071b, 0x191106ee,   // jw.az.tr_322 pt.id.un_220  it.ro.un_770 de.ro.gl_422
  0x2d000b08, 0x2d0d0502, 0x02001314, 0x1e0e1ca9,   // es.sk.un_430 fr.cs.sk_222  et.da.un_660 id.is.ms_544
  0x3f001e05, 0x20121113, 0x210e1ea4, 0x211c310c,   // ms.af.un_330 ro.hu.sq_665  ms.is.jw_433 az.id.jw_543
  0x046b1aa4, 0x2b003107, 0x1b310e60, 0x010853a4,   // tl.ceb.fi_433 az.vi.un_420  is.az.tr_664 ht.no.en_433
  // [7910]
  0x133f0da0, 0x1a2164a4, 0x2a033f04, 0x21201e07,   // cs.af.et_322 lg.jw.tl_433  af.nl.mt_332 ms.sq.jw_432
  0x200e1e0c, 0x03000a07, 0x07211ea0, 0x13291707,   // ms.is.sq_543 pt.nl.un_420  ms.jw.it_322 sr.sl.et_432
  0x23110ead, 0x23190aad, 0x21032ba0, 0x040813ec,   // is.ro.ca_643 pt.gl.ca_643  vi.nl.jw_322 et.no.fi_644
  0x081304ad, 0x2b000907, 0x29130209, 0x0c190a14,   // fi.et.no_643 pl.vi.un_420  da.et.sl_444 pt.gl.sv_666
  // [7920]
  0x04170708, 0x042810a0, 0x0c2d02a0, 0x25001b0e,   // bg.sr.ru_443 lt.sw.fi_322  da.sk.sv_322 tr.eu.un_550
  0x2a2721a0, 0x1b252005, 0x130c0207, 0x290507a9,   // jw.gd.mt_322 sq.eu.tr_333  da.sv.et_432 it.fr.sl_544
  0x1b110f04, 0x060e2aee, 0x04001a08, 0x190a0e19,   // lv.ro.tr_332 mt.is.de_422  tl.fi.un_430 is.pt.gl_765
  0x200e1c0c, 0x0b230aa4, 0x310e2008, 0x1e1c20a9,   // id.is.sq_543 pt.ca.es_433  sq.is.az_443 sq.id.ms_544
  // [7930]
  0x1f0e2009, 0x212d10a0, 0x31002104, 0x130207a0,   // sq.is.cy_444 lt.sk.jw_322  jw.az.un_320 it.da.et_322
  0x2500270c, 0x2d0a2308, 0x1f006b07, 0x311729a4,   // gd.eu.un_530 ca.pt.sk_443  ceb.cy.un_420 sl.sr.az_433
  0x04001f12, 0x290413a4, 0x132917a0, 0x2a16170b,   // cy.fi.un_640 et.fi.sl_433  sr.sl.et_322 sr.hr.mt_542
  0x2d290ca0, 0x551a28ec, 0x072911a0, 0x201b0fee,   // sv.sl.sk_322 sw.tl.rw_644  ro.sl.it_322 lv.tr.sq_422
  // [7940]
  0x3f120eee, 0x25081211, 0x531120ec, 0x5500200d,   // is.hu.af_422 hu.no.eu_653  sq.ro.ht_644 sq.rw.un_540
  0x6b53280c, 0x1a12535a, 0x0f001708, 0x6408250c,   // sw.ht.ceb_543 ht.hu.tl_553  sr.lv.un_430 eu.no.lg_543
  0x0c070ea9, 0x29000908, 0x2d000a1b, 0x120a2d0d,   // is.it.sv_544 pl.sl.un_430  pt.sk.un_770 sk.pt.hu_554
  0x120a2dac, 0x53000708, 0x010e3f07, 0x250d090c,   // sk.pt.hu_632 it.ht.un_430  af.is.en_432 pl.cs.eu_543
  // [7950]
  0x06050111, 0x2718060c, 0x0f072da7, 0x28171614,   // en.fr.de_653 de.ga.gd_543  sk.it.lv_532 hr.sr.sw_666
  0x1712160c, 0x06001121, 0x202d0f07, 0x10292d02,   // hr.hu.sr_543 ro.de.un_860  lv.sk.sq_432 sk.sl.lt_222
  0x122a070c, 0x1b3f0307, 0x131c0d0d, 0x2d230a0c,   // it.mt.hu_543 nl.af.tr_432  ne.mr.bh_554 pt.ca.sk_543
  0x12002d14, 0x0e1e1c09, 0x072910a7, 0x0c182704,   // sk.hu.un_660 id.ms.is_444  lt.sl.it_532 gd.ga.sv_332
  // [7960]
  0x0a11170c, 0x2128270c, 0x040807ad, 0x0c0523a4,   // sr.ro.mk_543 gd.sw.jw_543  bg.uk.ru_643 ca.fr.sv_433
  0x280301a4, 0x03080ca0, 0x06020ea4, 0x1a020ca4,   // en.nl.sw_433 sv.no.nl_322  is.da.de_433 sv.da.tl_433
  0x10002011, 0x27001e0d, 0x080c02ee, 0x6b271a0c,   // sq.lt.un_630 ms.gd.un_540  da.sv.no_422 tl.gd.ceb_543
  0x2718010c, 0x05000e12, 0x166429ac, 0x19001211,   // en.ga.gd_543 is.fr.un_640  sl.lg.hr_632 hu.gl.un_630
  // [7970]
  0x11000f02, 0x28550112, 0x012a0ea4, 0x1c040304,   // lv.ro.un_220 en.rw.sw_654  is.mt.en_433 nl.fi.id_332
  0x2000121a, 0x17160fad, 0x28000a08, 0x64000307,   // hu.sq.un_760 lv.hr.sr_643  pt.sw.un_430 nl.lg.un_420
  0x0c0201a4, 0x0b002704, 0x1b3123a4, 0x6b1c01a0,   // en.da.sv_433 gd.es.un_320  ca.az.tr_433 en.id.ceb_322
  0x0c030802, 0x09000809, 0x1f000705, 0x06020e07,   // no.nl.sv_222 no.pl.un_440  it.cy.un_330 is.da.de_432
  // [7980]
  0x043f03a4, 0x25000e02, 0x2a00201b, 0x1f000e04,   // nl.af.fi_433 is.eu.un_220  sq.mt.un_770 is.cy.un_320
  0x3f0308a0, 0x0a641ea0, 0x311b08a0, 0x09000304,   // no.nl.af_322 ms.lg.pt_322  no.tr.az_322 nl.pl.un_320
  0x1b1331a0, 0x08020c55, 0x041353ad, 0x12002307,   // az.et.tr_322 sv.da.no_442  ht.et.fi_643 ca.hu.un_420
  0x04070a13, 0x100d2da6, 0x04080aa9, 0x5300230b,   // mk.bg.ru_665 sk.cs.lt_521  mk.uk.ru_544 ca.ht.un_520
  // [7990]
  0x3f000419, 0x2d030704, 0x0c00020c, 0x17161a02,   // fi.af.un_750 it.nl.sk_332  da.sv.un_530 tl.hr.sr_222
  0x64001f0d, 0x642907ee, 0x070501ee, 0x10110408,   // cy.lg.un_540 it.sl.lg_422  en.fr.it_422 ru.ro.be_443
  0x03171613, 0x02002704, 0x0c002507, 0x31031b09,   // hr.sr.nl_665 gd.da.un_320  eu.sv.un_420 tr.nl.az_444
  0x2a281805, 0x1a6b09ee, 0x31080c0c, 0x120c080c,   // ga.sw.mt_333 pl.ceb.tl_422  sv.no.az_543 no.sv.hu_543
  // [79a0]
  0x29000105, 0x1c086407, 0x292a53a9, 0x070f23a0,   // en.sl.un_330 lg.no.id_432  ht.mt.sl_544 ca.lv.it_322
  0x3f1803a0, 0x250f0305, 0x5300080e, 0x09042507,   // nl.ga.af_322 nl.lv.eu_333  no.ht.un_550 eu.fi.pl_432
  0x02060a07, 0x05042aa0, 0x23000407, 0x3f28035a,   // pt.de.da_432 mt.fi.fr_322  fi.ca.un_420 nl.sw.af_553
  0x111020a4, 0x1725165a, 0x03121304, 0x041107af,   // sq.lt.ro_433 hr.eu.sr_553  et.hu.nl_332 bg.ro.ru_655
  // [79b0]
  0x0c081a08, 0x272821a9, 0x1900060c, 0x23110a04,   // tl.no.sv_443 jw.sw.gd_544  de.gl.un_530 pt.ro.ca_332
  0x181a6bad, 0x3f0405ec, 0x04000204, 0x20002521,   // ceb.tl.ga_643 fr.fi.af_644  da.fi.un_320 eu.sq.un_860
  0x271a1813, 0x2025280d, 0x1f013fa0, 0x640828ee,   // ga.tl.gd_665 sw.eu.sq_554  af.en.cy_322 sw.no.lg_422
  0x10040107, 0x04010d04, 0x041001a4, 0x041729a4,   // en.fi.lt_432 cs.en.fi_332  en.lt.fi_433 sl.sr.fi_433
  // [79c0]
  0x3f25100b, 0x11252907, 0x13641a0c, 0x29000e02,   // lt.eu.af_542 sl.eu.ro_432  tl.lg.et_543 is.sl.un_220
  0x202718ad, 0x28182a12, 0x556410a4, 0x211310ad,   // ga.gd.sq_643 mt.ga.sw_654  lt.lg.rw_433 lt.et.jw_643
  0x0e641105, 0x10291604, 0x2d1729a0, 0x13005512,   // ro.lg.is_333 hr.sl.lt_332  sl.sr.sk_322 rw.et.un_640
  0x3f310e04, 0x1a006412, 0x16001b04, 0x081f02ee,   // is.az.af_332 lg.tl.un_640  tr.hr.un_320 da.cy.no_422
  // [79d0]
  0x16041b0c, 0x0e081b55, 0x070321a0, 0x041b0e08,   // tr.fi.hr_543 tr.no.is_442  jw.nl.it_322 is.tr.fi_443
  0x20002112, 0x0e001011, 0x2a0f13a0, 0x2802080c,   // jw.sq.un_640 lt.is.un_630  et.lv.mt_322 no.da.sw_543
  0x130e1b0c, 0x131b2507, 0x020e1bad, 0x28001b12,   // tr.is.et_543 eu.tr.et_432  tr.is.da_643 tr.sw.un_640
  0x01000202, 0x270e1b13, 0x2a001202, 0x0c080107,   // da.en.un_220 tr.is.gd_665  hu.mt.un_220 en.no.sv_432
  // [79e0]
  0x281a1312, 0x1b0e2509, 0x1e101c55, 0x13000b04,   // et.tl.sw_654 eu.is.tr_444  id.lt.ms_442 es.et.un_320
  0x05001b0d, 0x25001b19, 0x12311bee, 0x0d1b0e0c,   // tr.fr.un_540 tr.eu.un_750  tr.az.hu_422 is.tr.cs_543
  0x1b0913ec, 0x086b0104, 0x13000612, 0x1b2d0ca0,   // et.pl.tr_644 en.ceb.no_332  de.et.un_640 sv.sk.tr_322
  0x07040a5a, 0x1e000707, 0x07642aaf, 0x12002a07,   // mk.ru.bg_553 it.ms.un_420  mt.lg.it_655 mt.hu.un_420
  // [79f0]
  0x16006402, 0x25001608, 0x2b001304, 0x13002019,   // lg.hr.un_220 hr.eu.un_430  et.vi.un_320 sq.et.un_750
  0x555328ee, 0x64552514, 0x05022d0c, 0x190a08a4,   // sw.ht.rw_422 eu.rw.lg_666  sk.da.fr_543 no.pt.gl_433
  0x07002a13, 0x07010509, 0x02000e1a, 0x0c532104,   // mt.it.un_650 fr.en.it_444  is.da.un_760 jw.ht.sv_332
  0x2000531b, 0x0100051b, 0x55110507, 0x16005512,   // ht.sq.un_770 fr.en.un_770  fr.ro.rw_432 rw.hr.un_640
  // [7a00]
  0x190720a0, 0x0206200c, 0x25000605, 0x53213fa0,   // sq.it.gl_322 sq.de.da_543  de.eu.un_330 af.jw.ht_322
  0x180e27ad, 0x072a0d07, 0x1a642807, 0x09005508,   // gd.is.ga_643 cs.mt.it_432  sw.lg.tl_432 rw.pl.un_430
  0x28005522, 0x1f0623a0, 0x08065355, 0x1b316bad,   // rw.sw.un_870 ca.de.cy_322  ht.de.no_442 ceb.az.tr_643
  0x20285360, 0x53000c04, 0x05000114, 0x292d0dee,   // ht.sw.sq_664 sv.ht.un_320  en.fr.un_660 cs.sk.sl_422
  // [7a10]
  0x210106a0, 0x1b2d0d08, 0x08170705, 0x060c080c,   // de.en.jw_322 cs.sk.tr_443  bg.sr.uk_333 no.sv.de_543
  0x2b0119a0, 0x131b1909, 0x042b02a0, 0x052d0d08,   // gl.en.vi_322 gl.tr.et_444  da.vi.fi_322 cs.sk.fr_443
  0x1f2d0d60, 0x29211107, 0x20211b12, 0x1b132512,   // cs.sk.cy_664 ro.jw.sl_432  tr.jw.sq_654 eu.et.tr_654
  0x23131007, 0x1c531bee, 0x100e640c, 0x12190a55,   // lt.et.ca_432 tr.ht.id_422  lg.is.lt_543 pt.gl.hu_442
  // [7a20]
  0x04000e05, 0x11132312, 0x020f03a0, 0x2d060d55,   // is.fi.un_330 ca.et.ro_654  nl.lv.da_322 cs.de.sk_442
  0x05000308, 0x0a00172a, 0x3f05030c, 0x1e206ba0,   // nl.fr.un_430 sr.mk.un_970  nl.fr.af_543 ceb.sq.ms_322
  0x100d2d0b, 0x0f1629a4, 0x10310d0b, 0x06160c12,   // sk.cs.lt_542 sl.hr.lv_433  cs.az.lt_542 sv.hr.de_654
  0x07002102, 0x21090607, 0x120b2d13, 0x0c0213a4,   // jw.it.un_220 de.pl.jw_432  sk.es.hu_665 et.da.sv_433
  // [7a30]
  0x01001202, 0x09200f07, 0x0c1323a4, 0x0c000904,   // hu.en.un_220 lv.sq.pl_432  ca.et.sv_433 pl.sv.un_320
  0x100a17a0, 0x1e1c09a4, 0x131b31ad, 0x0d536402,   // sr.mk.be_322 pl.id.ms_433  az.tr.et_643 lg.ht.cs_222
  0x2b0305a0, 0x03000521, 0x06171304, 0x06052b02,   // fr.nl.vi_322 fr.nl.un_860  et.sr.de_332 vi.fr.de_222
  0x080a1709, 0x190b04af, 0x04190aa0, 0x100f55ec,   // sr.mk.uk_444 fi.es.gl_655  pt.gl.fi_322 rw.lv.lt_644
  // [7a40]
  0x6b040809, 0x1e531a0b, 0x0e001008, 0x311b1ea0,   // no.fi.ceb_444 tl.ht.ms_542  lt.is.un_430 ms.tr.az_322
  0x03533fac, 0x202a08a4, 0x1e001607, 0x1e286409,   // af.ht.nl_632 no.mt.sq_433  hr.ms.un_420 lg.sw.ms_444
  0x071e1c04, 0x112507a4, 0x030725a0, 0x2000250e,   // id.ms.it_332 it.eu.ro_433  eu.it.nl_322 eu.sq.un_550
  0x202825af, 0x55256407, 0x071017a0, 0x060a070c,   // eu.sw.sq_655 lg.eu.rw_432  sr.be.bg_322 it.pt.de_543
  // [7a50]
  0x0611090b, 0x091c0dac, 0x162864ac, 0x6b1a2508,   // pl.ro.de_542 ne.mr.hi_632  lg.sw.hr_632 eu.tl.ceb_443
  0x2b2113ee, 0x64550708, 0x190b12a9, 0x11000712,   // et.jw.vi_422 it.rw.lg_443  hu.es.gl_544 it.ro.un_640
  0x1e063107, 0x040813a4, 0x2a5510ec, 0x090d29a9,   // az.de.ms_432 et.no.fi_433  lt.rw.mt_644 sl.cs.pl_544
  0x160c0fee, 0x041a13a7, 0x2a0901a0, 0x00000f2d,   // lv.sv.hr_422 et.tl.fi_532  en.pl.mt_322 lv.un.un_A00
  // [7a60]
  0x032d6ea4, 0x1f2a1b11, 0x0c000835, 0x2025070b,   // blu.sk.nl_433 tr.mt.cy_653  no.sv.un_A90 it.eu.sq_542
  0x2b3f0308, 0x2b0e23af, 0x09002922, 0x1b010604,   // nl.af.vi_443 ca.is.vi_655  sl.pl.un_870 de.en.tr_332
  0x07106402, 0x1f182707, 0x171253a6, 0x2a641f60,   // lg.lt.it_222 gd.ga.cy_432  ht.hu.sr_521 cy.lg.mt_664
  0x0d1c0911, 0x182b2704, 0x08170aad, 0x06000105,   // hi.mr.ne_653 gd.vi.ga_332  mk.sr.uk_643 en.de.un_330
  // [7a70]
  0x19120dad, 0x16120807, 0x0a0407ac, 0x2a1f1aad,   // cs.hu.gl_643 no.hu.hr_432  bg.ru.mk_632 tl.cy.mt_643
  0x0501060d, 0x1f005305, 0x213f090c, 0x03531f09,   // de.en.fr_554 ht.cy.un_330  pl.af.jw_543 cy.ht.nl_444
  0x171c2107, 0x252d16ee, 0x0f642804, 0x64100f55,   // jw.id.sr_432 hr.sk.eu_422  sw.lg.lv_332 lv.lt.lg_442
  0x1806275a, 0x0e2910ec, 0x552164a7, 0x02080ba4,   // gd.de.ga_553 lt.sl.is_644  lg.jw.rw_532 es.no.da_433
  // [7a80]
  0x55080ca7, 0x2553640c, 0x07000113, 0x3f0902ec,   // sv.no.rw_532 lg.ht.eu_543  en.it.un_650 da.pl.af_644
  0x0c082da0, 0x04253fa7, 0x2a2d07ee, 0x2d0e0c04,   // sk.no.sv_322 af.eu.fi_532  it.sk.mt_422 sv.is.sk_332
  0x53211a04, 0x08171614, 0x0d000e19, 0x050911ad,   // tl.jw.ht_332 hr.sr.no_666  is.cs.un_750 ro.pl.fr_643
  0x20010b07, 0x281c210c, 0x20000a19, 0x25010607,   // es.en.sq_432 jw.id.sw_543  pt.sq.un_750 de.en.eu_432
  // [7a90]
  0x2500170e, 0x16210804, 0x28000105, 0x0b11010c,   // sr.eu.un_550 no.jw.hr_332  en.sw.un_330 en.ro.es_543
  0x28530107, 0x070410ad, 0x2d081307, 0x11020709,   // en.ht.sw_432 be.ru.bg_643  et.no.sk_432 it.da.ro_444
  0x0e003f12, 0x1c090607, 0x0e2d3f0c, 0x1f001814,   // af.is.un_640 de.pl.id_432  af.sk.is_543 ga.cy.un_660
  0x0e080c0d, 0x041117af, 0x2d0e0da4, 0x0d2b0eee,   // sv.no.is_554 sr.ro.ru_655  cs.is.sk_433 is.vi.cs_422
  // [7aa0]
  0x12061ea4, 0x20115508, 0x03063fee, 0x1f642813,   // ms.de.hu_433 rw.ro.sq_443  af.de.nl_422 sw.lg.cy_665
  0x1e6b1a0c, 0x0e115508, 0x0d27180d, 0x08000609,   // tl.ceb.ms_543 rw.ro.is_443  ga.gd.cs_554 de.no.un_440
  0x0e210c07, 0x205516ad, 0x033f0ca4, 0x0e20550c,   // sv.jw.is_432 hr.rw.sq_643  sv.af.nl_433 rw.sq.is_543
  0x13111008, 0x1a21280c, 0x3f020607, 0x280e550c,   // lt.ro.et_443 sw.jw.tl_543  de.da.af_432 rw.is.sw_543
  // [7ab0]
  0x552001a0, 0x13000121, 0x1e061c07, 0x112a5508,   // en.sq.rw_322 en.et.un_860  id.de.ms_432 rw.mt.ro_443
  0x1a000804, 0x186b08a0, 0x01270ba0, 0x1a000604,   // no.tl.un_320 no.ceb.ga_322  es.gd.en_322 de.tl.un_320
  0x6b551ea4, 0x1a211fec, 0x64552809, 0x216b1a08,   // ms.rw.ceb_433 cy.jw.tl_644  sw.rw.lg_444 tl.ceb.jw_443
  0x100e0707, 0x55251107, 0x10002904, 0x1a00550c,   // it.is.lt_432 ro.eu.rw_432  sl.lt.un_320 rw.tl.un_530
  // [7ac0]
  0x05000204, 0x07000e04, 0x1f000308, 0x160c1aa0,   // da.fr.un_320 is.it.un_320  nl.cy.un_430 tl.sv.hr_322
  0x02013fee, 0x0c02060c, 0x11001802, 0x23060112,   // af.en.da_422 de.da.sv_543  ga.ro.un_220 en.de.ca_654
  0x11315508, 0x6b3f1aac, 0x210f100c, 0x3f132809,   // rw.az.ro_443 tl.af.ceb_632  lt.lv.jw_543 sw.et.af_444
  0x1b0c12ec, 0x0f3f23ad, 0x21311b0c, 0x16292108,   // hu.sv.tr_644 ca.af.lv_643  tr.az.jw_543 jw.sl.hr_443
  // [7ad0]
  0x08230fa9, 0x2a012311, 0x28002521, 0x1b3f2511,   // lv.ca.no_544 ca.en.mt_653  eu.sw.un_860 eu.af.tr_653
  0x10001a04, 0x3f121b07, 0x536b250c, 0x08001204,   // tl.lt.un_320 tr.hu.af_432  eu.ceb.ht_543 hu.no.un_320
  0x0e2b12a6, 0x641f2108, 0x0c0123a4, 0x190123ec,   // hu.vi.is_521 jw.cy.lg_443  ca.en.sv_433 ca.en.gl_644
  0x0e3f640c, 0x0e6b07ec, 0x17160412, 0x0d120aa7,   // lg.af.is_543 it.ceb.is_644  fi.hr.sr_654 pt.hu.cs_532
  // [7ae0]
  0x0e64020c, 0x0a07110e, 0x010e3fa0, 0x120802a0,   // da.lg.is_543 ro.bg.mk_555  af.is.en_322 da.no.hu_322
  0x07006404, 0x13162d02, 0x290d2da7, 0x3f530d05,   // lg.it.un_320 sk.hr.et_222  sk.cs.sl_532 cs.ht.af_333
  0x060c02ec, 0x09171607, 0x2a086ba0, 0x0c0e07ec,   // da.sv.de_644 hr.sr.pl_432  ceb.no.mt_322 it.is.sv_644
  0x0d022b55, 0x010553a0, 0x1a053fee, 0x3f005314,   // vi.da.cs_442 ht.fr.en_322  af.fr.tl_422 ht.af.un_660
  // [7af0]
  0x190764ad, 0x281801a4, 0x2d0d0fec, 0x0a001208,   // lg.it.gl_643 en.ga.sw_433  lv.cs.sk_644 hu.pt.un_430
  0x010c080c, 0x64000505, 0x190b0a60, 0x3f172d07,   // no.sv.en_543 fr.lg.un_330  pt.es.gl_664 sk.sr.af_432
  0x0d0b0a08, 0x1b210c08, 0x18000d19, 0x2d000a2b,   // pt.es.cs_443 sv.jw.tr_443  cs.ga.un_750 pt.sk.un_980
  0x53002d04, 0x09171602, 0x122755a0, 0x13000c0e,   // sk.ht.un_320 hr.sr.pl_222  rw.gd.hu_322 sv.et.un_550
  // [7b00]
  0x021e1cee, 0x315528ad, 0x0e020ca0, 0x0c2831ad,   // id.ms.da_422 sw.rw.az_643  sv.da.is_322 az.sw.sv_643
  0x28000e13, 0x230e55a0, 0x0a190b5a, 0x035505a4,   // is.sw.un_650 rw.is.ca_322  es.gl.pt_553 fr.rw.nl_433
  0x063f0355, 0x5300041b, 0x21000e14, 0x16212a05,   // nl.af.de_442 fi.ht.un_770  is.jw.un_660 mt.jw.hr_333
  0x170301a4, 0x03002509, 0x230b0a0d, 0x08210e07,   // en.nl.sr_433 eu.nl.un_440  pt.es.ca_554 is.jw.no_432
  // [7b10]
  0x2d0d12ee, 0x31002a02, 0x11202509, 0x1e002818,   // hu.cs.sk_422 mt.az.un_220  eu.sq.ro_444 sw.ms.un_740
  0x29000912, 0x0e6428a4, 0x1e5518a4, 0x09553f0c,   // pl.sl.un_640 sw.lg.is_433  ga.rw.ms_433 af.rw.pl_543
  0x282a640c, 0x04550509, 0x532705ee, 0x066e6b12,   // lg.mt.sw_543 fr.rw.fi_444  fr.gd.ht_422 ceb.blu.de_654
  0x21281f0b, 0x1e1c0c0c, 0x01000211, 0x12202aad,   // cy.sw.jw_542 sv.id.ms_543  da.en.un_630 mt.sq.hu_643
  // [7b20]
  0x1b0603a4, 0x13051007, 0x3f080260, 0x05101ea0,   // nl.de.tr_433 lt.fr.et_432  da.no.af_664 ms.lt.fr_322
  0x112a0508, 0x1b001f0d, 0x063f030d, 0x08100fa4,   // fr.mt.ro_443 cy.tr.un_540  nl.af.de_554 lv.lt.no_433
  0x063f2102, 0x06016ea0, 0x1a062aa0, 0x0b0506ee,   // jw.af.de_222 blu.en.de_322  mt.de.tl_322 de.fr.es_422
  0x1a000b05, 0x28556e0b, 0x06001b0c, 0x192d0d5a,   // es.tl.un_330 blu.rw.sw_542  tr.de.un_530 cs.sk.gl_553
  // [7b30]
  0x192d0d09, 0x18271f08, 0x21100fec, 0x1a2125a0,   // cs.sk.gl_444 cy.gd.ga_443  lv.lt.jw_644 eu.jw.tl_322
  0x0a001308, 0x080212ee, 0x0c083fa9, 0x3f122007,   // et.pt.un_430 hu.da.no_422  af.no.sv_544 sq.hu.af_432
  0x29001b19, 0x550a01a0, 0x25001e0d, 0x1b0601a9,   // tr.sl.un_750 en.pt.rw_322  ms.eu.un_540 en.de.tr_544
  0x17000d13, 0x29092ba0, 0x3f002a0c, 0x1100270d,   // cs.sr.un_650 vi.pl.sl_322  mt.af.un_530 gd.ro.un_540
  // [7b40]
  0x0e08100c, 0x06001e02, 0x10000208, 0x0b002502,   // lt.no.is_543 ms.de.un_220  da.lt.un_430 eu.es.un_220
  0x110531a0, 0x18270907, 0x10130ea0, 0x120d2d12,   // az.fr.ro_322 pl.gd.ga_432  is.et.lt_322 sk.cs.hu_654
  0x0e020811, 0x031317a9, 0x033f1b05, 0x201107a6,   // no.da.is_653 sr.et.nl_544  tr.af.nl_333 it.ro.sq_521
  0x19000d08, 0x1b53210b, 0x02640811, 0x061308a0,   // cs.gl.un_430 jw.ht.tr_542  no.lg.da_653 no.et.de_322
  // [7b50]
  0x21550808, 0x250f1012, 0x20000705, 0x082006ee,   // no.rw.jw_443 lt.lv.eu_654  it.sq.un_330 de.sq.no_422
  0x3f060809, 0x27090a07, 0x2d1112ee, 0x08002708,   // no.de.af_444 pt.pl.gd_432  hu.ro.sk_422 gd.no.un_430
  0x0d091cac, 0x64091f0d, 0x09001b04, 0x211b0804,   // mr.hi.ne_632 cy.pl.lg_554  tr.pl.un_320 no.tr.jw_332
  0x17160812, 0x011908a0, 0x091218a4, 0x0c001107,   // no.hr.sr_654 no.gl.en_322  ga.hu.pl_433 ro.sv.un_420
  // [7b60]
  0x080216a9, 0x0600080c, 0x0a072508, 0x11000813,   // hr.da.no_544 no.de.un_530  eu.it.pt_443 no.ro.un_650
  0x110501ee, 0x64033f07, 0x6b2a01a0, 0x1f00121a,   // en.fr.ro_422 af.nl.lg_432  en.mt.ceb_322 hu.cy.un_760
  0x20000a07, 0x08000505, 0x24000117, 0x123f03a0,   // pt.sq.un_420 fr.no.un_330  iw.yi.un_730 nl.af.hu_322
  0x060312a9, 0x130c040c, 0x1a556ba4, 0x11131bad,   // hu.nl.de_544 fi.sv.et_543  ceb.rw.tl_433 tr.et.ro_643
  // [7b70]
  0x6400090c, 0x02190804, 0x2d180d14, 0x050701ee,   // pl.lg.un_530 no.gl.da_332  cs.ga.sk_666 en.it.fr_422
  0x2d001809, 0x040a11ee, 0x10171655, 0x64005309,   // ga.sk.un_440 ro.mk.ru_422  hr.sr.lt_442 ht.lg.un_440
  0x08291607, 0x2d00120e, 0x0603120c, 0x0a1017ee,   // hr.sl.no_432 hu.sk.un_550  hu.nl.de_543 sr.be.mk_422
  0x64001314, 0x64001308, 0x0f0d10ee, 0x092d2502,   // et.lg.un_660 et.lg.un_430  lt.cs.lv_422 eu.sk.pl_222
  // [7b80]
  0x171113a0, 0x20216b07, 0x11210204, 0x25030204,   // et.ro.sr_322 ceb.jw.sq_432  da.jw.ro_332 da.nl.eu_332
  0x6b171608, 0x641b315a, 0x170a08ee, 0x2d0d12a7,   // hr.sr.ceb_443 az.tr.lg_553  uk.mk.sr_422 hu.cs.sk_532
  0x17033f05, 0x1a165502, 0x0a121808, 0x286453a4,   // af.nl.sr_333 rw.hr.tl_222  ga.hu.pt_443 ht.lg.sw_433
  0x1a0b6b13, 0x23001e04, 0x64005313, 0x6e080e12,   // ceb.es.tl_665 ms.ca.un_320  ht.lg.un_650 is.no.blu_654
  // [7b90]
  0x1a646b55, 0x1716020e, 0x03040855, 0x03000407,   // ceb.lg.tl_442 da.hr.sr_555  no.fi.nl_442 fi.nl.un_420
  0x18001007, 0x023f04ad, 0x0a081709, 0x03010c02,   // lt.ga.un_420 fi.af.da_643  sr.uk.mk_444 sv.en.nl_222
  0x645355a7, 0x1e000907, 0x201b2baf, 0x31006b07,   // rw.ht.lg_532 pl.ms.un_420  vi.tr.sq_655 ceb.az.un_420
  0x07002a07, 0x1c1b25a0, 0x033f0405, 0x2a6e6bad,   // mt.it.un_420 eu.tr.id_322  fi.af.nl_333 ceb.blu.mt_643
  // [7ba0]
  0x102b2709, 0x23181f04, 0x201716a7, 0x07230b05,   // gd.vi.lt_444 cy.ga.ca_332  hr.sr.sq_532 es.ca.it_333
  0x080417a9, 0x31001f02, 0x16002307, 0x116409a0,   // sr.ru.uk_544 cy.az.un_220  ca.hr.un_420 pl.lg.ro_322
  0x2d1b20a0, 0x1304110e, 0x290f2d0c, 0x043113af,   // sq.tr.sk_322 ro.fi.et_555  sk.lv.sl_543 et.az.fi_655
  0x292d20a4, 0x21006b08, 0x010a20ac, 0x53001308,   // sq.sk.sl_433 ceb.jw.un_430  sq.pt.en_632 et.ht.un_430
  // [7bb0]
  0x0e3f0c0c, 0x09006408, 0x0f1b23a4, 0x31292d08,   // sv.af.is_543 lg.pl.un_430  ca.tr.lv_433 sk.sl.az_443
  0x1b2d31af, 0x0f001308, 0x3f002a07, 0x082a0e08,   // az.sk.tr_655 et.lv.un_430  mt.af.un_420 is.mt.no_443
  0x53000707, 0x10170405, 0x2d3120a4, 0x042d090c,   // it.ht.un_420 ru.sr.be_333  sq.az.sk_433 pl.sk.fi_543
  0x1b292da7, 0x0c060802, 0x2d0d2014, 0x0d0a1210,   // sk.sl.tr_532 no.de.sv_222  sq.cs.sk_666 hu.pt.cs_642
  // [7bc0]
  0x55161207, 0x1210130c, 0x132a07a4, 0x1c102d07,   // hu.hr.rw_432 et.lt.hu_543  it.mt.et_433 sk.lt.id_432
  0x1e312a12, 0x6e00532a, 0x2a2b10a4, 0x210513a0,   // mt.az.ms_654 ht.blu.un_970  lt.vi.mt_433 et.fr.jw_322
  0x08040a0e, 0x2a010707, 0x0d311308, 0x0000102d,   // mk.ru.uk_555 it.en.mt_432  et.az.cs_443 lt.un.un_A00
  0x09126b55, 0x08001113, 0x311b5507, 0x06232b08,   // ceb.hu.pl_442 ro.uk.un_650  rw.tr.az_432 vi.ca.de_443
  // [7bd0]
  0x080205af, 0x20216412, 0x2b1201ad, 0x272118a0,   // fr.da.no_655 lg.jw.sq_654  en.hu.vi_643 ga.jw.gd_322
  0x55110aa4, 0x080a1105, 0x0807040e, 0x530801a0,   // pt.ro.rw_433 ro.mk.uk_333  ru.bg.uk_555 en.no.ht_322
  0x0b1a6bee, 0x6b2120ee, 0x280611ee, 0x1c012ba0,   // ceb.tl.es_422 sq.jw.ceb_422  ro.de.sw_422 vi.en.id_322
  0x55012805, 0x290c2b08, 0x0c00082c, 0x2304010c,   // sw.en.rw_333 vi.sv.sl_443  no.sv.un_990 en.fi.ca_543
  // [7be0]
  0x0e3f110c, 0x111c21a4, 0x05205304, 0x1702160c,   // ro.af.is_543 jw.id.ro_433  ht.sq.fr_332 hr.da.sr_543
  0x3f000507, 0x171623af, 0x120e1904, 0x112301a0,   // fr.af.un_420 ca.hr.sr_655  gl.is.hu_332 en.ca.ro_322
  0x6b001b04, 0x13023f02, 0x16001a02, 0x19000e19,   // tr.ceb.un_320 af.da.et_222  tl.hr.un_220 is.gl.un_750
  0x286404ad, 0x0c040805, 0x53001a12, 0x0d291110,   // fi.lg.sw_643 no.fi.sv_333  tl.ht.un_640 ro.sl.cs_642
  // [7bf0]
  0x0b162da0, 0x2900110d, 0x1006200c, 0x070a23a0,   // sk.hr.es_322 ro.sl.un_540  sq.de.lt_543 ca.pt.it_322
  0x06000335, 0x05006419, 0x05282b07, 0x03122102,   // nl.de.un_A90 lg.fr.un_750  vi.sw.fr_432 jw.hu.nl_222
  0x2b1b0ea0, 0x0308010c, 0x08000409, 0x10033f08,   // is.tr.vi_322 en.no.nl_543  ru.uk.un_440 af.nl.lt_443
  0x11050111, 0x2000270d, 0x110264a4, 0x080407ee,   // en.fr.ro_653 gd.sq.un_540  lg.da.ro_433 bg.ru.uk_422

  // [7c00]
  0x060c0214, 0x292003ee, 0x083f01a4, 0x1c211eaf,   // da.sv.de_666 nl.sq.sl_422  en.af.no_433 ms.jw.id_655
  0x1017010c, 0x0e230f12, 0x0c290d07, 0x130c2313,   // en.sr.lt_543 lv.ca.is_654  cs.sl.sv_432 ca.sv.et_665
  0x3f101a02, 0x050623ac, 0x0405010c, 0x0a05230e,   // tl.lt.af_222 ca.de.fr_632  en.fr.fi_543 ca.fr.pt_555
  0x25000512, 0x0500012b, 0x0203080c, 0x1e111c07,   // fr.eu.un_640 en.fr.un_980  no.nl.da_543 id.ro.ms_432
  // [7c10]
  0x0c052312, 0x310a0eec, 0x0a08040d, 0x023f03ad,   // ca.fr.sv_654 is.pt.az_644  ru.uk.mk_554 nl.af.da_643
  0x050c23ad, 0x31001005, 0x1b083f04, 0x11120807,   // ca.sv.fr_643 lt.az.un_330  af.no.tr_332 no.hu.ro_432
  0x05002320, 0x6b110304, 0x31001908, 0x31033fa0,   // ca.fr.un_850 nl.ro.ceb_332  gl.az.un_430 af.nl.az_322
  0x10033f0c, 0x070c0407, 0x06040507, 0x07170809,   // af.nl.lt_543 fi.sv.it_432  fr.fi.de_432 uk.sr.bg_444
  // [7c20]
  0x18006b09, 0x10230107, 0x030c08ee, 0x21101608,   // ceb.ga.un_440 en.ca.lt_432  no.sv.nl_422 hr.lt.jw_443
  0x27001304, 0x0c2a0407, 0x1c6421ad, 0x1f000809,   // et.gd.un_320 fi.mt.sv_432  jw.lg.id_643 no.cy.un_440
  0x250c230c, 0x1a0c2307, 0x181f2712, 0x25001602,   // ca.sv.eu_543 ca.sv.tl_432  gd.cy.ga_654 hr.eu.un_220
  0x20110f0c, 0x0e070ca9, 0x532023ee, 0x230a0507,   // lv.ro.sq_543 sv.it.is_544  ca.sq.ht_422 fr.pt.ca_432
  // [7c30]
  0x281827a0, 0x2718280e, 0x13002a1a, 0x23120c07,   // gd.ga.sw_322 sw.ga.gd_555  mt.et.un_760 sv.hu.ca_432
  0x13642a0c, 0x0164070c, 0x19000d10, 0x1a6b1ca9,   // mt.lg.et_543 it.lg.en_543  cs.gl.un_620 id.ceb.tl_544
  0x07102708, 0x20000619, 0x203f08a7, 0x53003102,   // gd.lt.it_443 de.sq.un_750  no.af.sq_532 az.ht.un_220
  0x121e1c04, 0x1f18270e, 0x6b033fa4, 0x17161b09,   // id.ms.hu_332 gd.ga.cy_555  af.nl.ceb_433 tr.hr.sr_444
  // [7c40]
  0x08111713, 0x0a012302, 0x1b200ea4, 0x6b003107,   // sr.ro.uk_665 ca.en.pt_222  is.sq.tr_433 az.ceb.un_420
  0x08552d0b, 0x1b002905, 0x641f2a07, 0x31131b08,   // sk.rw.no_542 sl.tr.un_330  mt.cy.lg_432 tr.et.az_443
  0x08110411, 0x0c006b05, 0x1b2117a0, 0x2b2a21a0,   // ru.ro.uk_653 ceb.sv.un_330  sr.jw.tr_322 jw.mt.vi_322
  0x036b28ee, 0x0a041002, 0x0c081fad, 0x032a3fa0,   // sw.ceb.nl_422 be.ru.mk_222  cy.no.sv_643 af.mt.nl_322
  // [7c50]
  0x0817040e, 0x0f095504, 0x081f120c, 0x23071104,   // ru.sr.uk_555 rw.pl.lv_332  hu.cy.no_543 ro.it.ca_332
  0x080c0e12, 0x0f090b04, 0x21160209, 0x23000f05,   // is.sv.no_654 es.pl.lv_332  da.hr.jw_444 lv.ca.un_330
  0x0f281f04, 0x1300110c, 0x1e061155, 0x231b0aa0,   // cy.sw.lv_332 ro.et.un_530  ro.de.ms_442 pt.tr.ca_322
  0x161b2507, 0x0c06010c, 0x5300550d, 0x08022012,   // eu.tr.hr_432 en.de.sv_543  rw.ht.un_540 sq.da.no_654
  // [7c60]
  0x5500200c, 0x5500210c, 0x2b1a6bee, 0x53082007,   // sq.rw.un_530 jw.rw.un_530  ceb.tl.vi_422 sq.no.ht_432
  0x0f2029ad, 0x12006e23, 0x53001022, 0x0b1f13ec,   // sl.sq.lv_643 blu.hu.un_880  lt.ht.un_870 et.cy.es_644
  0x09536e0c, 0x201607a9, 0x0e006407, 0x1c3f0605,   // blu.ht.pl_543 it.hr.sq_544  lg.is.un_420 de.af.id_333
  0x6e27185a, 0x212a06ad, 0x0e190b04, 0x165320a7,   // ga.gd.blu_553 de.mt.jw_643  es.gl.is_332 sq.ht.hr_532
  // [7c70]
  0x056e3f0c, 0x100a07a4, 0x0a063f04, 0x1f002a29,   // af.blu.fr_543 bg.mk.be_433  af.de.pt_332 mt.cy.un_960
  0x6b0d08ee, 0x230a20ad, 0x11006e1b, 0x1e006e0c,   // no.cs.ceb_422 sq.pt.ca_643  blu.ro.un_770 blu.ms.un_530
  0x0e00060e, 0x1700070e, 0x1a00111a, 0x10001f04,   // de.is.un_550 bg.sr.un_550  ro.tl.un_760 cy.lt.un_320
  0x170807ee, 0x6e00272a, 0x1b1f0c04, 0x092331a4,   // bg.uk.sr_422 gd.blu.un_970  sv.cy.tr_332 az.ca.pl_433
  // [7c80]
  0x18001904, 0x6e000104, 0x061a1704, 0x27131004,   // gl.ga.un_320 en.blu.un_320  sr.tl.de_332 lt.et.gd_332
  0x3f090304, 0x1a041812, 0x1e010802, 0x27000407,   // nl.pl.af_332 ga.fi.tl_654  no.en.ms_222 fi.gd.un_420
  0x53291112, 0x101a2913, 0x64021f12, 0x0d0c06ad,   // ro.sl.ht_654 sl.tl.lt_665  cy.da.lg_654 de.sv.cs_643
  0x17166ba4, 0x031b2807, 0x2d2809a9, 0x2a126e14,   // ceb.hr.sr_433 sw.tr.nl_432  pl.sw.sk_544 blu.hu.mt_666
  // [7c90]
  0x20556460, 0x09100fa0, 0x130c200d, 0x27556460,   // lg.rw.sq_664 lv.lt.pl_322  sq.sv.et_554 lg.rw.gd_664
  0x27033fa7, 0x190a53af, 0x020c1112, 0x1f1b3113,   // af.nl.gd_532 ht.pt.gl_655  ro.sv.da_654 az.tr.cy_665
  0x28110513, 0x27311b60, 0x1900230e, 0x0c0508af,   // fr.ro.sw_665 tr.az.gd_664  ca.gl.un_550 no.fr.sv_655
  0x110a1faf, 0x07001f1b, 0x1b2a0708, 0x08100a13,   // cy.pt.ro_655 cy.it.un_770  it.mt.tr_443 mk.be.uk_665
  // [7ca0]
  0x161a6e04, 0x252d0d04, 0x1c1b21a4, 0x16292808,   // blu.tl.hr_332 cs.sk.eu_332  jw.tr.id_433 sw.sl.hr_443
  0x0d002913, 0x2a6e2b11, 0x03002519, 0x29161004,   // sl.cs.un_650 vi.blu.mt_653  eu.nl.un_750 lt.hr.sl_332
  0x09031212, 0x3f130411, 0x23190a13, 0x10310f09,   // hu.nl.pl_654 fi.et.af_653  pt.gl.ca_665 lv.az.lt_444
  0x230f0ba0, 0x2d0705ee, 0x19230a12, 0x102b050c,   // es.lv.ca_322 fr.it.sk_422  pt.ca.gl_654 fr.vi.lt_543
  // [7cb0]
  0x29001019, 0x55011ca0, 0x05280b0d, 0x190b1ca4,   // lt.sl.un_750 id.en.rw_322  es.sw.fr_554 id.es.gl_433
  0x0c1a01a4, 0x13071f0c, 0x29001005, 0x21190a08,   // en.tl.sv_433 cy.it.et_543  lt.sl.un_330 pt.gl.jw_443
  0x31550655, 0x291625a0, 0x2a130907, 0x29200402,   // de.rw.az_442 eu.hr.sl_322  pl.et.mt_432 fi.sq.sl_222
  0x1b0e3113, 0x2d0d2502, 0x171607ec, 0x0407645a,   // az.is.tr_665 eu.cs.sk_222  it.hr.sr_644 lg.it.fi_553
  // [7cc0]
  0x13002902, 0x012d0907, 0x29001014, 0x2a232707,   // sl.et.un_220 pl.sk.en_432  lt.sl.un_660 gd.ca.mt_432
  0x10001604, 0x02002712, 0x1b31090c, 0x16033fac,   // hr.lt.un_320 gd.da.un_640  pl.az.tr_543 af.nl.hr_632
  0x13311bee, 0x180221a0, 0x1f00090b, 0x0e311b0c,   // tr.az.et_422 jw.da.ga_322  pl.cy.un_520 tr.az.is_543
  0x132507ee, 0x07311b0d, 0x0b000e04, 0x05001307,   // it.eu.et_422 tr.az.it_554  is.es.un_320 et.fr.un_420
  // [7cd0]
  0x210a190c, 0x10172907, 0x0a0711ec, 0x110806a4,   // gl.pt.jw_543 sl.sr.lt_432  ro.bg.mk_644 de.no.ro_433
  0x1f0406ad, 0x25040805, 0x0e061f07, 0x1f0612ee,   // de.fi.cy_643 no.fi.eu_333  cy.de.is_432 hu.de.cy_422
  0x311b12ad, 0x121b3112, 0x06080ea0, 0x0b171602,   // hu.tr.az_643 az.tr.hu_654  is.no.de_322 hr.sr.es_222
  0x53050302, 0x13000512, 0x0d091c07, 0x0912250c,   // nl.fr.ht_222 fr.et.un_640  mr.hi.ne_432 eu.hu.pl_543
  // [7ce0]
  0x2028120c, 0x270c08a9, 0x120e0608, 0x07100460,   // hu.sw.sq_543 no.sv.gd_544  de.is.hu_443 ru.be.bg_664
  0x190a0509, 0x2a271807, 0x182d1207, 0x1b04080c,   // fr.pt.gl_444 ga.gd.mt_432  hu.sk.ga_432 no.fi.tr_543
  0x0c212004, 0x1312040c, 0x2d080205, 0x030102a0,   // sq.jw.sv_332 fi.hu.et_543  da.no.sk_333 da.en.nl_322
  0x1a002704, 0x6b0c0204, 0x29002805, 0x1a001b22,   // gd.tl.un_320 da.sv.ceb_332  sw.sl.un_330 tr.tl.un_870
  // [7cf0]
  0x0d201cee, 0x18282b0c, 0x063f03af, 0x19001c04,   // id.sq.cs_422 vi.sw.ga_543  nl.af.de_655 id.gl.un_320
  0x02001f07, 0x041b01a0, 0x1b00250c, 0x13003119,   // cy.da.un_420 en.tr.fi_322  eu.tr.un_530 az.et.un_750
  0x2118120b, 0x1f2718af, 0x1a0627ee, 0x110710ac,   // ur.ar.fa_542 ga.gd.cy_655  gd.de.tl_422 be.bg.ro_632
  0x2a0805a6, 0x0f001714, 0x040609ee, 0x18125304,   // fr.no.mt_521 sr.lv.un_660  pl.de.fi_422 ht.hu.ga_332
  // [7d00]
  0x0f290407, 0x17100f0e, 0x0b0105af, 0x1b6b1a12,   // fi.sl.lv_432 lv.lt.sr_555  fr.en.es_655 tl.ceb.tr_654
  0x091208a0, 0x1900010b, 0x210b08a0, 0x53002309,   // no.hu.pl_322 en.gl.un_520  no.es.jw_322 ca.ht.un_440
  0x04005502, 0x6b1e1c0e, 0x0c0831a0, 0x0a2301a9,   // rw.fi.un_220 id.ms.ceb_555  az.no.sv_322 en.ca.pt_544
  0x17160311, 0x53000b07, 0x103f0907, 0x641a530b,   // nl.hr.sr_653 es.ht.un_420  pl.af.lt_432 ht.tl.lg_542
  // [7d10]
  0x23051105, 0x12001705, 0x080e0205, 0x0700250c,   // ro.fr.ca_333 sr.hu.un_330  da.is.no_333 eu.it.un_530
  0x55210ead, 0x07110408, 0x6b1028a4, 0x17131ea0,   // is.jw.rw_643 ru.ro.bg_443  sw.lt.ceb_433 ms.et.sr_322
  0x0200100d, 0x556428a4, 0x1c1708ee, 0x100b1307,   // lt.da.un_540 sw.lg.rw_433  no.sr.id_422 et.es.lt_432
  0x1c0608ee, 0x121c1ba4, 0x0b000a12, 0x130e2aa4,   // no.de.id_422 tr.id.hu_433  pt.es.un_640 mt.is.et_433
  // [7d20]
  0x29642d02, 0x55006b18, 0x0c2808a0, 0x255528a4,   // sk.lg.sl_222 ceb.rw.un_740  no.sw.sv_322 sw.rw.eu_433
  0x256407a9, 0x312d0d08, 0x290c2a55, 0x2a2d0d5a,   // it.lg.eu_544 cs.sk.az_443  mt.sv.sl_442 cs.sk.mt_553
  0x0f551004, 0x0710080c, 0x211b1ea0, 0x2a280e08,   // lt.rw.lv_332 uk.be.bg_543  ms.tr.jw_322 is.sw.mt_443
  0x170811a4, 0x010705a0, 0x190b1202, 0x1b000614,   // ro.uk.sr_433 fr.it.en_322  hu.es.gl_222 de.tr.un_660
  // [7d30]
  0x180b280c, 0x1000311b, 0x1b00081a, 0x04202b04,   // sw.es.ga_543 az.lt.un_770  no.tr.un_760 vi.sq.fi_332
  0x04252008, 0x2b2004a4, 0x2d0d19a0, 0x081e3f04,   // sq.eu.fi_443 fi.sq.vi_433  gl.cs.sk_322 af.ms.no_332
  0x0c00310d, 0x31000c08, 0x25112007, 0x02001208,   // az.sv.un_540 sv.az.un_430  sq.ro.eu_432 hu.da.un_430
  0x2a1f0904, 0x1b0e2d07, 0x25201f13, 0x17160905,   // pl.cy.mt_332 sk.is.tr_432  cy.sq.eu_665 pl.hr.sr_333
  // [7d40]
  0x2a003119, 0x2b1123a0, 0x2800181a, 0x02201b07,   // az.mt.un_750 ca.ro.vi_322  ga.sw.un_760 tr.sq.da_432
  0x0a110713, 0x11001808, 0x06531f0d, 0x25131b0c,   // bg.ro.mk_665 ga.ro.un_430  cy.ht.de_554 tr.et.eu_543
  0x25002014, 0x07212a12, 0x08041304, 0x050811a0,   // sq.eu.un_660 mt.jw.it_654  et.fi.no_332 ro.no.fr_322
  0x192520a0, 0x55002523, 0x041105a4, 0x041f2013,   // sq.eu.gl_322 eu.rw.un_880  fr.ro.fi_433 sq.cy.fi_665
  // [7d50]
  0x051801a4, 0x111f200c, 0x250420a4, 0x062718a4,   // en.ga.fr_433 sq.cy.ro_543  sq.fi.eu_433 ga.gd.de_433
  0x27111813, 0x190b210e, 0x0e2364af, 0x2102110c,   // ga.ro.gd_665 jw.es.gl_555  lg.ca.is_655 ro.da.jw_543
  0x01061f07, 0x28181108, 0x07642502, 0x070a1109,   // cy.de.en_432 ro.ga.sw_443  eu.lg.it_222 ro.mk.bg_444
  0x08170412, 0x0e28110e, 0x1225530d, 0x02080c04,   // ru.sr.uk_654 ro.sw.is_555  ht.eu.hu_554 sv.no.da_332
  // [7d60]
  0x061c21ee, 0x13000d12, 0x1f2d0d09, 0x04211c08,   // jw.id.de_422 ne.bh.un_640  cs.sk.cy_444 id.jw.fi_443
  0x282a010c, 0x080206ee, 0x0553060d, 0x07001012,   // en.mt.sw_543 de.da.no_422  de.ht.fr_554 be.bg.un_640
  0x0b182302, 0x0817040c, 0x17161f0c, 0x251805ad,   // ca.ga.es_222 ru.sr.uk_543  cy.hr.sr_543 fr.ga.eu_643
  0x646b12a7, 0x02080c0d, 0x16111f11, 0x1e1c19ec,   // hu.ceb.lg_532 sv.no.da_554  cy.ro.hr_653 gl.id.ms_644
  // [7d70]
  0x231c550c, 0x2d003108, 0x29130ea4, 0x6400120d,   // rw.id.ca_543 az.sk.un_430  is.et.sl_433 hu.lg.un_540
  0x0c1f0807, 0x200c0202, 0x182d0d08, 0x0d001c20,   // no.cy.sv_432 da.sv.sq_222  cs.sk.ga_443 mr.ne.un_850
  0x2b1304ee, 0x281b5308, 0x17095502, 0x075311a0,   // fi.et.vi_422 ht.tr.sw_443  rw.pl.sr_222 ro.ht.it_322
  0x18002b05, 0x64532055, 0x2000531a, 0x1b000e18,   // vi.ga.un_330 sq.ht.lg_442  ht.sq.un_760 is.tr.un_740
  // [7d80]
  0x0b2711ad, 0x53002008, 0x0a170414, 0x1b020ea7,   // ro.gd.es_643 sq.ht.un_430  ru.sr.mk_666 is.da.tr_532
  0x280c0ea4, 0x0608020d, 0x06100f04, 0x171f55ee,   // is.sv.sw_433 da.no.de_554  lv.lt.de_332 rw.cy.sr_422
  0x1f00012a, 0x16170e07, 0x182a01ee, 0x07100808,   // en.cy.un_970 is.sr.hr_432  en.mt.ga_422 uk.be.bg_443
  0x090418a4, 0x27010d07, 0x160e17a9, 0x280d0107,   // ga.fi.pl_433 cs.en.gd_432  sr.is.hr_544 en.cs.sw_432
  // [7d90]
  0x552007a0, 0x0d000119, 0x120329ee, 0x171b0707,   // it.sq.rw_322 en.cs.un_750  sl.nl.hu_422 it.tr.sr_432
  0x09121112, 0x093f1f02, 0x55001f08, 0x183f0111,   // ro.hu.pl_654 cy.af.pl_222  cy.rw.un_430 en.af.ga_653
  0x1f070fa9, 0x0428250c, 0x0b25040b, 0x2500041b,   // lv.it.cy_544 eu.sw.fi_543  fi.eu.es_542 fi.eu.un_770
  0x2b001319, 0x04211ca4, 0x042825ad, 0x28042508,   // et.vi.un_750 id.jw.fi_433  eu.sw.fi_643 eu.fi.sw_443
  // [7da0]
  0x19282513, 0x080e040b, 0x04130cac, 0x280425a9,   // eu.sw.gl_665 fi.is.no_542  sv.et.fi_632 eu.fi.sw_544
  0x190a25ec, 0x0a080205, 0x130f04a0, 0x19002a02,   // eu.pt.gl_644 da.no.pt_333  fi.lv.et_322 mt.gl.un_220
  0x01000d08, 0x2d2b0dac, 0x2100010c, 0x28192512,   // cs.en.un_430 cs.vi.sk_632  en.jw.un_530 eu.gl.sw_654
  0x6b002107, 0x312d0e07, 0x1a001b12, 0x0a0817ec,   // jw.ceb.un_420 is.sk.az_432  tr.tl.un_640 sr.uk.mk_644
  // [7db0]
  0x19250aa0, 0x033f0211, 0x551b6ba0, 0x19002512,   // pt.eu.gl_322 da.af.nl_653  ceb.tr.rw_322 eu.gl.un_640
  0x16170455, 0x25042812, 0x19042512, 0x6b211a12,   // fi.sr.hr_442 sw.fi.eu_654  eu.fi.gl_654 tl.jw.ceb_654
  0x280425ec, 0x1b002305, 0x28250408, 0x051123af,   // eu.fi.sw_644 ca.tr.un_330  fi.eu.sw_443 ca.ro.fr_655
  0x02033fa0, 0x0c002904, 0x6b1a55a4, 0x0f135504,   // af.nl.da_322 sl.sv.un_320  rw.tl.ceb_433 rw.et.lv_332
  // [7dc0]
  0x12001f23, 0x281355af, 0x0a08100c, 0x1a000e0d,   // cy.hu.un_880 rw.et.sw_655  be.uk.mk_543 is.tl.un_540
  0x29000a22, 0x101108a4, 0x555305a4, 0x100f17a4,   // pt.sl.un_870 uk.ro.be_433  fr.ht.rw_433 sr.lv.lt_433
  0x2509290c, 0x043f20a6, 0x1f252305, 0x1309270c,   // sl.pl.eu_543 sq.af.fi_521  ca.eu.cy_333 gd.pl.et_543
  0x1f001113, 0x3f170107, 0x1b0e1304, 0x232501a4,   // ro.cy.un_650 en.sr.af_432  et.is.tr_332 en.eu.ca_433
  // [7dd0]
  0x07552a0c, 0x0f2855a0, 0x28000c08, 0x6b0601ee,   // mt.rw.it_543 rw.sw.lv_322  sv.sw.un_430 en.de.ceb_422
  0x2b002513, 0x0e002d02, 0x09080607, 0x21050dac,   // eu.vi.un_650 sk.is.un_220  de.no.pl_432 cs.fr.jw_632
  0x070501a9, 0x1a00120c, 0x31002013, 0x12190bee,   // en.fr.it_544 hu.tl.un_530  sq.az.un_650 es.gl.hu_422
  0x6b042809, 0x092928a9, 0x072d03a7, 0x0f00041a,   // sw.fi.ceb_444 sw.sl.pl_544  nl.sk.it_532 fi.lv.un_760
  // [7de0]
  0x0a071114, 0x19002b08, 0x01001b11, 0x0b0a250c,   // ro.bg.mk_666 vi.gl.un_430  tr.en.un_630 eu.pt.es_543
  0x3f031fa4, 0x251a5507, 0x642a0c02, 0x100f17ad,   // cy.nl.af_433 rw.tl.eu_432  sv.mt.lg_222 sr.lv.lt_643
  0x530628a7, 0x08021fee, 0x311c0802, 0x53032aa7,   // sw.de.ht_532 cy.da.no_422  no.id.az_222 mt.nl.ht_532
  0x110802ec, 0x210806a7, 0x64001a05, 0x23211ca0,   // da.no.ro_644 de.no.jw_532  tl.lg.un_330 id.jw.ca_322
  // [7df0]
  0x170f1009, 0x3f060804, 0x08022aa0, 0x0c021f07,   // lt.lv.sr_444 no.de.af_332  mt.da.no_322 cy.da.sv_432
  0x0e1f1b55, 0x2a001e22, 0x01000612, 0x645521af,   // tr.cy.is_442 ms.mt.un_870  de.en.un_640 jw.rw.lg_655
  0x312b1b07, 0x1f070eee, 0x08550607, 0x0900250d,   // tr.vi.az_432 is.it.cy_422  de.rw.no_432 eu.pl.un_540
  0x0b001108, 0x0f040555, 0x23000409, 0x04182708,   // ro.es.un_430 fr.fi.lv_442  fi.ca.un_440 gd.ga.fi_443
  // [7e00]
  0x06053fa7, 0x11001022, 0x04001811, 0x311b0fad,   // af.fr.de_532 be.ro.un_870  ga.fi.un_630 lv.tr.az_643
  0x53001004, 0x13001e04, 0x13005305, 0x041125a0,   // lt.ht.un_320 ms.et.un_320  ht.et.un_330 eu.ro.fi_322
  0x0a1827af, 0x29001f0d, 0x2013075a, 0x121f0eec,   // gd.ga.pt_655 cy.sl.un_540  it.et.sq_553 is.cy.hu_644
  0x6b011aac, 0x293120ee, 0x07081708, 0x290e1c0c,   // tl.en.ceb_632 sq.az.sl_422  sr.uk.bg_443 id.is.sl_543
  // [7e10]
  0x13192307, 0x1e05110c, 0x2a0f1f08, 0x1f000e21,   // ca.gl.et_432 ro.fr.ms_543  cy.lv.mt_443 is.cy.un_860
  0x2a000709, 0x01641aee, 0x2d1706a7, 0x6413280c,   // it.mt.un_440 tl.lg.en_422  de.sr.sk_532 sw.et.lg_543
  0x0f041804, 0x1f00230c, 0x182753a0, 0x012b1a07,   // ga.fi.lv_332 ca.cy.un_530  ht.gd.ga_322 tl.vi.en_432
  0x6b230b08, 0x3f1753a0, 0x27171605, 0x21001f05,   // es.ca.ceb_443 ht.sr.af_322  hr.sr.gd_333 cy.jw.un_330
  // [7e20]
  0x201617ec, 0x0b0a11a4, 0x213f0e0c, 0x09000e08,   // sr.hr.sq_644 ro.pt.es_433  is.af.jw_543 is.pl.un_430
  0x5300110c, 0x211308a4, 0x6b55230c, 0x09001f1a,   // ro.ht.un_530 no.et.jw_433  ca.rw.ceb_543 cy.pl.un_760
  0x21000807, 0x1a000b19, 0x6b1a21a9, 0x1355210c,   // no.jw.un_420 es.tl.un_750  jw.tl.ceb_544 jw.rw.et_543
  0x0e6411a7, 0x27230d07, 0x316b1b07, 0x2912160c,   // ro.lg.is_532 cs.ca.gd_432  tr.ceb.az_432 hr.hu.sl_543
  // [7e30]
  0x1a006b18, 0x6b1a250c, 0x09000807, 0x09210808,   // ceb.tl.un_740 eu.tl.ceb_543  no.pl.un_420 no.jw.pl_443
  0x1b250ea4, 0x21551aa4, 0x23000e05, 0x282101a4,   // is.eu.tr_433 tl.rw.jw_433  is.ca.un_330 en.jw.sw_433
  0x07110907, 0x120a05a4, 0x020a0ea0, 0x1a0a64a0,   // pl.ro.it_432 fr.pt.hu_433  is.pt.da_322 lg.pt.tl_322
  0x09550aa0, 0x231f2a05, 0x10033fa4, 0x0e0801a4,   // pt.rw.pl_322 mt.cy.ca_333  af.nl.lt_433 en.no.is_433
  // [7e40]
  0x556e21ad, 0x11040a13, 0x10135507, 0x5500041b,   // jw.blu.rw_643 mk.ru.ro_665  rw.et.lt_432 fi.rw.un_770
  0x1c130da4, 0x21000922, 0x25211a08, 0x21082da4,   // ne.bh.mr_433 pl.jw.un_870  tl.jw.eu_443 sk.no.jw_433
  0x1b642812, 0x212a1e13, 0x0e5513ad, 0x170711a9,   // sw.lg.tr_654 ms.mt.jw_665  et.rw.is_643 ro.bg.sr_544
  0x1b00100e, 0x11131a0c, 0x28001207, 0x3f1f0907,   // lt.tr.un_550 tl.et.ro_543  hu.sw.un_420 pl.cy.af_432
  // [7e50]
  0x20112805, 0x271025ec, 0x16001205, 0x256b1a09,   // sw.ro.sq_333 eu.lt.gd_644  hu.hr.un_330 tl.ceb.eu_444
  0x08281b12, 0x0c311ba4, 0x2d160f02, 0x04110a0b,   // tr.sw.no_654 tr.az.sv_433  lv.hr.sk_222 mk.ro.ru_542
  0x1f182713, 0x0c081b0c, 0x07251ca4, 0x01001319,   // gd.ga.cy_665 tr.no.sv_543  id.eu.it_433 et.en.un_750
  0x1a6b5513, 0x08280309, 0x293112a4, 0x1b081212,   // rw.ceb.tl_665 nl.sw.no_444  hu.az.sl_433 hu.no.tr_654
  // [7e60]
  0x080a0208, 0x17290912, 0x641e1c0c, 0x2d0521a9,   // da.pt.no_443 pl.sl.sr_654  id.ms.lg_543 jw.fr.sk_544
  0x1b001219, 0x55130e05, 0x211b0407, 0x533f03ee,   // hu.tr.un_750 is.et.rw_333  fi.tr.jw_432 nl.af.ht_422
  0x25002a04, 0x531716ee, 0x030f0a09, 0x020f01a0,   // mt.eu.un_320 hr.sr.ht_422  pt.lv.nl_444 en.lv.da_322
  0x0b0a1ba4, 0x1a211e07, 0x2317010c, 0x550b0904,   // tr.pt.es_433 ms.jw.tl_432  en.sr.ca_543 pl.es.rw_332
  // [7e70]
  0x1b091214, 0x110a21a7, 0x0f100aec, 0x0b081208,   // hu.pl.tr_666 jw.pt.ro_532  pt.lt.lv_644 hu.no.es_443
  0x3f031213, 0x111b12a9, 0x121b0107, 0x0b3f28a4,   // hu.nl.af_665 hu.tr.ro_544  en.tr.hu_432 sw.af.es_433
  0x080704a0, 0x1e1c55a9, 0x10170a0e, 0x18000e14,   // ru.bg.uk_322 rw.id.ms_544  mk.sr.be_555 is.ga.un_660
  0x17100860, 0x0f1b10ee, 0x1e1c1ba9, 0x29161ba9,   // uk.be.sr_664 lt.tr.lv_422  tr.id.ms_544 tr.hr.sl_544
  // [7e80]
  0x0e101c04, 0x07001111, 0x2d001708, 0x10001b08,   // id.lt.is_332 ro.bg.un_630  sr.sk.un_430 tr.lt.un_430
  0x3100550b, 0x101e1c04, 0x030553a0, 0x0c002b04,   // rw.az.un_520 id.ms.lt_332  ht.fr.nl_322 vi.sv.un_320
  0x1e00060c, 0x2300250c, 0x21002805, 0x0e02080c,   // de.ms.un_530 eu.ca.un_530  sw.jw.un_330 no.da.is_543
  0x13100c5a, 0x1b000e0e, 0x053f28a7, 0x3f0408a0,   // sv.lt.et_553 is.tr.un_550  sw.af.fr_532 no.fi.af_322
  // [7e90]
  0x08100f12, 0x122d1812, 0x2d181213, 0x0c082108,   // lv.lt.no_654 ga.sk.hu_654  hu.ga.sk_665 jw.no.sv_443
  0x12182155, 0x10093f04, 0x2d120e11, 0x10001a07,   // fa.ar.ur_442 af.pl.lt_332  is.hu.sk_653 tl.lt.un_420
  0x0c1f3f02, 0x281108a0, 0x31002a14, 0x0e18640e,   // af.cy.sv_222 no.ro.sw_322  mt.az.un_660 lg.ga.is_555
  0x181f090b, 0x21002721, 0x2d1812ec, 0x29001622,   // pl.cy.ga_542 gd.jw.un_860  hu.ga.sk_644 hr.sl.un_870
  // [7ea0]
  0x2d000f02, 0x050123ee, 0x04020c07, 0x040f2509,   // lv.sk.un_220 ca.en.fr_422  sv.da.fi_432 eu.lv.fi_444
  0x030e08a0, 0x0e002a2b, 0x11020c07, 0x2a070e0d,   // no.is.nl_322 mt.is.un_980  sv.da.ro_432 is.it.mt_554
  0x060c02a9, 0x11186412, 0x0e080713, 0x29160905,   // da.sv.de_544 lg.ga.ro_654  it.no.is_665 pl.hr.sl_333
  0x041128a9, 0x1f0206a0, 0x0928110c, 0x200e01a0,   // sw.ro.fi_544 de.da.cy_322  ro.sw.pl_543 en.is.sq_322
  // [7eb0]
  0x0e080260, 0x280911ec, 0x016b1ba0, 0x0f000602,   // da.no.is_664 ro.pl.sw_644  tr.ceb.en_322 de.lv.un_220
  0x092811ad, 0x020c2904, 0x310e090d, 0x0d042804,   // ro.sw.pl_643 sl.sv.da_332  pl.is.az_554 sw.fi.cs_332
  0x23001107, 0x11002805, 0x08023f07, 0x10210204,   // ro.ca.un_420 sw.ro.un_330  af.da.no_432 da.jw.lt_332
  0x170d0612, 0x131b0c55, 0x0d091108, 0x08030208,   // de.cs.sr_654 sv.tr.et_442  ro.pl.cs_443 da.nl.no_443
  // [7ec0]
  0x290208a4, 0x1b080213, 0x28316b08, 0x290c0d07,   // no.da.sl_433 da.no.tr_665  ceb.az.sw_443 cs.sv.sl_432
  0x1b311008, 0x2d001123, 0x03000222, 0x3f071208,   // lt.az.tr_443 ro.sk.un_880  da.nl.un_870 hu.it.af_443
  0x211b1207, 0x0e0208ad, 0x1708160c, 0x641207a9,   // hu.tr.jw_432 no.da.is_643  hr.no.sr_543 it.hu.lg_544
  0x11130e07, 0x530305a4, 0x06080211, 0x19080307,   // is.et.ro_432 fr.nl.ht_433  da.no.de_653 nl.no.gl_432
  // [7ed0]
  0x215508a0, 0x0c020613, 0x64002502, 0x25070255,   // no.rw.jw_322 de.da.sv_665  eu.lg.un_220 da.it.eu_442
  0x0a1e1c02, 0x2d0d11ec, 0x28000904, 0x64080c09,   // id.ms.pt_222 ro.cs.sk_644  pl.sw.un_320 sv.no.lg_444
  0x11000d1a, 0x042d110c, 0x096427ee, 0x190a3f14,   // cs.ro.un_760 ro.sk.fi_543  gd.lg.pl_422 af.pt.gl_666
  0x0904110c, 0x250912ee, 0x1a000a0e, 0x0d071108,   // ro.fi.pl_543 hu.pl.eu_422  pt.tl.un_550 ro.it.cs_443
  // [7ee0]
  0x080a11a4, 0x1f211a55, 0x1a6b53ec, 0x111029a0,   // ro.mk.uk_433 tl.jw.cy_442  ht.ceb.tl_644 sl.lt.ro_322
  0x1b1a0ca0, 0x1a6b53af, 0x122925a4, 0x1b020e04,   // sv.tl.tr_322 ht.ceb.tl_655  eu.sl.hu_433 is.da.tr_332
  0x040c13af, 0x3f031f0c, 0x0e001102, 0x1f1e1c0c,   // et.sv.fi_655 cy.nl.af_543  ro.is.un_220 id.ms.cy_543
  0x2a311b0c, 0x3f270607, 0x11170405, 0x1a2153a0,   // tr.az.mt_543 de.gd.af_432  ru.sr.ro_333 ht.jw.tl_322
  // [7ef0]
  0x080a0404, 0x162d0d64, 0x0a17100d, 0x1729165a,   // ru.mk.uk_332 cs.sk.hr_762  be.sr.mk_554 hr.sl.sr_553
  0x040e3f0c, 0x1a005319, 0x03053f04, 0x1b081fa0,   // af.is.fi_543 ht.tl.un_750  af.fr.nl_332 cy.no.tr_322
  0x3f005313, 0x19000c05, 0x0212080b, 0x02230107,   // ht.af.un_650 sv.gl.un_330  no.hu.da_542 en.ca.da_432
  0x1b050cee, 0x2d0d12a0, 0x05002004, 0x530102ee,   // sv.fr.tr_422 hu.cs.sk_322  sq.fr.un_320 da.en.ht_422
  // [7f00]
  0x1808020d, 0x09251fad, 0x04001118, 0x0d0603a0,   // da.no.ga_554 cy.eu.pl_643  ro.ru.un_740 nl.de.cs_322
  0x0e0c01a4, 0x276b07a0, 0x1f0c0e07, 0x293f1ba4,   // en.sv.is_433 it.ceb.gd_322  is.sv.cy_432 tr.af.sl_433
  0x16000104, 0x190a2aee, 0x103f03a9, 0x010a0507,   // en.hr.un_320 mt.pt.gl_422  nl.af.lt_544 fr.pt.en_432
  0x6400211a, 0x17290d07, 0x6b5521ec, 0x6b2b01ad,   // jw.lg.un_760 cs.sl.sr_432  jw.rw.ceb_644 en.vi.ceb_643
  // [7f10]
  0x0d2d3f0c, 0x070811a0, 0x0f0d10a9, 0x120c1a02,   // af.sk.cs_543 ro.uk.bg_322  lt.cs.lv_544 tl.sv.hu_222
  0x13000f07, 0x01213f09, 0x3f060c09, 0x532a0c55,   // lv.et.un_420 af.jw.en_444  sv.de.af_444 sv.mt.ht_442
  0x550416a0, 0x0e006408, 0x0c081107, 0x181f27ee,   // hr.fi.rw_322 lg.is.un_430  ro.no.sv_432 gd.cy.ga_422
  0x27101f08, 0x215564ad, 0x0f046b0c, 0x27033f0b,   // cy.lt.gd_443 lg.rw.jw_643  ceb.fi.lv_543 af.nl.gd_542
  // [7f20]
  0x2a130702, 0x291607a0, 0x101c0fec, 0x6b0e0607,   // it.et.mt_222 it.hr.sl_322  lv.id.lt_644 de.is.ceb_432
  0x1e001307, 0x1e1c2d05, 0x0f1810a0, 0x1e1c0f05,   // et.ms.un_420 sk.id.ms_333  lt.ga.lv_322 lv.id.ms_333
  0x033f0eee, 0x08062504, 0x10071109, 0x10271faf,   // is.af.nl_422 eu.de.no_332  ro.bg.be_444 cy.gd.lt_655
  0x20002808, 0x08001f12, 0x071028ee, 0x01091fa9,   // sw.sq.un_430 cy.no.un_640  sw.lt.it_422 cy.pl.en_544
  // [7f30]
  0x05041fee, 0x2a162508, 0x10170aa4, 0x1a080507,   // cy.fi.fr_422 eu.hr.mt_443  mk.sr.be_433 fr.no.tl_432
  0x020c0602, 0x1e1827a9, 0x53000919, 0x0f1804a4,   // de.sv.da_222 gd.ga.ms_544  pl.ht.un_750 fi.ga.lv_433
  0x0d2d0912, 0x230428a9, 0x16000e02, 0x070a6e09,   // pl.sk.cs_654 sw.fi.ca_544  is.hr.un_220 blu.pt.it_444
  0x23052a07, 0x0d2d09ad, 0x04000919, 0x1b001f20,   // mt.fr.ca_432 pl.sk.cs_643  pl.fi.un_750 cy.tr.un_850
  // [7f40]
  0x2004280c, 0x0e000611, 0x040a08a7, 0x0a071112,   // sw.fi.sq_543 de.is.un_630  uk.mk.ru_532 ro.bg.mk_654
  0x0d051a02, 0x05060707, 0x11130705, 0x3f000908,   // tl.fr.cs_222 it.de.fr_432  it.et.ro_333 pl.af.un_430
  0x250409a4, 0x2a0b3f05, 0x10040aa4, 0x2100010e,   // pl.fi.eu_433 af.es.mt_333  mk.ru.be_433 en.jw.un_550
  0x0c2a0b14, 0x090b06a7, 0x10041f07, 0x1107250d,   // es.mt.sv_666 de.es.pl_532  cy.fi.lt_432 eu.it.ro_554
  // [7f50]
  0x060b095a, 0x09110b08, 0x11282da9, 0x09005305,   // pl.es.de_553 es.ro.pl_443  sk.sw.ro_544 ht.pl.un_330
  0x0a070802, 0x2509060c, 0x64555307, 0x25062a0d,   // uk.bg.mk_222 de.pl.eu_543  ht.rw.lg_432 mt.de.eu_554
  0x12000307, 0x551a2807, 0x0f05060c, 0x0b06255a,   // nl.hu.un_420 sw.tl.rw_432  de.fr.lv_543 eu.de.es_553
  0x6455535a, 0x25130e07, 0x2d0f1008, 0x11070aa9,   // ht.rw.lg_553 is.et.eu_432  lt.lv.sk_443 mk.bg.ro_544
  // [7f60]
  0x07171008, 0x6b1f250c, 0x0e006b08, 0x0f6b1a04,   // be.sr.bg_443 eu.cy.ceb_543  ceb.is.un_430 tl.ceb.lv_332
  0x2105010c, 0x05001205, 0x6b001008, 0x051f2707,   // en.fr.jw_543 hu.fr.un_330  lt.ceb.un_430 gd.cy.fr_432
  0x64280302, 0x0500181a, 0x29002019, 0x2d001704,   // nl.sw.lg_222 ga.fr.un_760  sq.sl.un_750 sr.sk.un_320
  0x250b0f07, 0x2d002019, 0x0f001009, 0x1b113107,   // lv.es.eu_432 sq.sk.un_750  lt.lv.un_440 az.ro.tr_432
  // [7f70]
  0x25050107, 0x29002008, 0x0a3105a0, 0x13000d1b,   // en.fr.eu_432 sq.sl.un_430  fr.az.pt_322 ne.bh.un_770
  0x0f2053ee, 0x0302080b, 0x0b005302, 0x050e06a0,   // ht.sq.lv_422 no.da.nl_542  ht.es.un_220 de.is.fr_322
  0x100e0f11, 0x1f130414, 0x1a050107, 0x17000409,   // lv.is.lt_653 fi.et.cy_666  en.fr.tl_432 ru.sr.un_440
  0x2000291a, 0x171620ee, 0x01002b07, 0x0f002519,   // sl.sq.un_760 sq.hr.sr_422  vi.en.un_420 eu.lv.un_750
  // [7f80]
  0x0f17100c, 0x31002914, 0x28001319, 0x1c000c0b,   // lt.sr.lv_543 sl.az.un_660  et.sw.un_750 sv.id.un_520
  0x0c041205, 0x27001f0d, 0x0e001908, 0x53000407,   // hu.fi.sv_333 cy.gd.un_540  gl.is.un_430 fi.ht.un_420
  0x085305ec, 0x2d0d0802, 0x060305a7, 0x1a010604,   // fr.ht.no_644 no.cs.sk_222  fr.nl.de_532 de.en.tl_332
  0x531101a0, 0x27000404, 0x3f001f14, 0x230506a0,   // en.ro.ht_322 fi.gd.un_320  cy.af.un_660 de.fr.ca_322
  // [7f90]
  0x11042b07, 0x283153a0, 0x2b001b04, 0x1c2b21ee,   // vi.fi.ro_432 ht.az.sw_322  tr.vi.un_320 jw.vi.id_422
  0x08031207, 0x2d190a05, 0x202128af, 0x31005302,   // hu.nl.no_432 pt.gl.sk_333  sw.jw.sq_655 ht.az.un_220
  0x53002022, 0x112a0712, 0x08002d05, 0x080c0e07,   // sq.ht.un_870 it.mt.ro_654  sk.no.un_330 is.sv.no_432
  0x11202da0, 0x04080ca9, 0x112807a9, 0x13000933,   // sk.sq.ro_322 sv.no.fi_544  it.sw.ro_544 hi.bh.un_A70
  // [7fa0]
  0x0c282508, 0x20000d08, 0x2b050107, 0x19052307,   // eu.sw.sv_443 cs.sq.un_430  en.fr.vi_432 ca.fr.gl_432
  0x201712ec, 0x2053110b, 0x213f12a4, 0x20006e1a,   // hu.sr.sq_644 ro.ht.sq_542  hu.af.jw_433 blu.sq.un_760
  0x0c2501a9, 0x162d09a9, 0x1f212808, 0x2d0d55a9,   // en.eu.sv_544 pl.sk.hr_544  sw.jw.cy_443 rw.cs.sk_544
  0x28003102, 0x11310404, 0x552028ad, 0x0700532a,   // az.sw.un_220 fi.az.ro_332  sw.sq.rw_643 ht.it.un_970
  // [7fb0]
  0x1b001222, 0x53190a08, 0x2864120c, 0x130c1207,   // hu.tr.un_870 pt.gl.ht_443  hu.lg.sw_543 hu.sv.et_432
  0x311b0c12, 0x033f64af, 0x08022009, 0x280553a4,   // sv.tr.az_654 lg.af.nl_655  sq.da.no_444 ht.fr.sw_433
  0x25182711, 0x0c001307, 0x2006120c, 0x1a04250c,   // gd.ga.eu_653 et.sv.un_420  hu.de.sq_543 eu.fi.tl_543
  0x12131e0c, 0x20001e07, 0x1025270d, 0x18001f12,   // ms.et.hu_543 ms.sq.un_420  gd.eu.lt_554 cy.ga.un_640
  // [7fc0]
  0x203f0304, 0x532105ec, 0x052728a4, 0x6e001709,   // nl.af.sq_332 fr.jw.ht_644  sw.gd.fr_433 sr.blu.un_440
  0x6e002a08, 0x3f000414, 0x1a033fee, 0x100f25a9,   // mt.blu.un_430 fi.af.un_660  af.nl.tl_422 eu.lv.lt_544
  0x04000f1a, 0x0e00210d, 0x271001a4, 0x080c1ba4,   // lv.fi.un_760 jw.is.un_540  en.lt.gd_433 tr.sv.no_433
  0x050425af, 0x0b051207, 0x2a000305, 0x3f171604,   // eu.fi.fr_655 hu.fr.es_432  nl.mt.un_330 hr.sr.af_332
  // [7fd0]
  0x01080e0c, 0x04131aec, 0x6b2d0d04, 0x03043f05,   // is.no.en_543 tl.et.fi_644  cs.sk.ceb_332 af.fi.nl_333
  0x0f002b02, 0x21000811, 0x021f0c02, 0x1e001907,   // vi.lv.un_220 no.jw.un_630  sv.cy.da_222 gl.ms.un_420
  0x12171608, 0x10051fa7, 0x020a08ee, 0x11070408,   // hr.sr.hu_443 cy.fr.lt_532  no.pt.da_422 ru.bg.ro_443
  0x18002a0c, 0x02000e1b, 0x16002304, 0x0f00170d,   // mt.ga.un_530 is.da.un_770  ca.hr.un_320 sr.lv.un_540
  // [7fe0]
  0x061204ee, 0x0900530d, 0x25000521, 0x0b231904,   // fi.hu.de_422 ht.pl.un_540  fr.eu.un_860 gl.ca.es_332
  0x041225ee, 0x190b0eee, 0x0b1a01a0, 0x556421a4,   // eu.hu.fi_422 is.es.gl_422  en.tl.es_322 jw.lg.rw_433
  0x28251aa0, 0x64002511, 0x04091002, 0x0400550b,   // tl.eu.sw_322 eu.lg.un_630  lt.pl.fi_222 rw.fi.un_520
  0x0e2d0d0e, 0x6b1a0204, 0x136b0404, 0x091b280c,   // cs.sk.is_555 da.tl.ceb_332  fi.ceb.et_332 sw.tr.pl_543
  // [7ff0]
  0x10552511, 0x28006b02, 0x231a0b02, 0x01091ba4,   // eu.rw.lt_653 ceb.sw.un_220  es.tl.ca_222 tr.pl.en_433
  0x1304100d, 0x04131aa0, 0x281a64ee, 0x17001f04,   // lt.fi.et_554 tl.et.fi_322  lg.tl.sw_422 cy.sr.un_320
  0x16002921, 0x01056ba0, 0x2a290aaf, 0x201a2a07,   // sl.hr.un_860 ceb.fr.en_322  pt.sl.mt_655 mt.tl.sq_432
  0x1628550c, 0x231b060d, 0x1a000808, 0x17002a0c,   // rw.sw.hr_543 de.tr.ca_554  no.tl.un_430 mt.sr.un_530

  // [8000]
  0x20282112, 0x5500251b, 0x3f250a11, 0x17166b09,   // jw.sw.sq_654 eu.rw.un_770  pt.eu.af_653 ceb.hr.sr_444
  0x25286ba4, 0x271828af, 0x10040a0c, 0x182a27a4,   // ceb.sw.eu_433 sw.ga.gd_655  mk.ru.be_543 gd.mt.ga_433
  0x0a081005, 0x0b2818af, 0x6b2164a4, 0x5305010c,   // be.uk.mk_333 ga.sw.es_655  lg.jw.ceb_433 en.fr.ht_543
  0x19000e02, 0x64000907, 0x02110708, 0x042913a9,   // is.gl.un_220 pl.lg.un_420  it.ro.da_443 et.sl.fi_544
  // [8010]
  0x0f002005, 0x130e04ad, 0x06050112, 0x171609ee,   // sq.lv.un_330 fi.is.et_643  en.fr.de_654 pl.hr.sr_422
  0x6e002012, 0x13092913, 0x2a090f12, 0x182027a9,   // sq.blu.un_640 sl.pl.et_665  lv.pl.mt_654 gd.sq.ga_544
  0x27003112, 0x2a091804, 0x0a040da0, 0x31002005,   // az.gd.un_640 ga.pl.mt_332  cs.fi.pt_322 sq.az.un_330
  0x55281e07, 0x13096407, 0x28641aa4, 0x212b01ad,   // ms.sw.rw_432 lg.pl.et_432  tl.lg.sw_433 en.vi.jw_643
  // [8020]
  0x311e0d11, 0x04112312, 0x08200608, 0x0900251b,   // cs.ms.az_653 ca.ro.fi_654  de.sq.no_443 eu.pl.un_770
  0x6b1c13a0, 0x04643f0c, 0x131a64a4, 0x0429095a,   // et.id.ceb_322 af.lg.fi_543  lg.tl.et_433 pl.sl.fi_553
  0x3f006421, 0x28000508, 0x53090fa0, 0x131b0808,   // lg.af.un_860 fr.sw.un_430  lv.pl.ht_322 no.tr.et_443
  0x291b09a4, 0x130f1009, 0x12182105, 0x212804ee,   // pl.tr.sl_433 lt.lv.et_444  fa.ar.ur_333 fi.sw.jw_422
  // [8030]
  0x1a286411, 0x2803640c, 0x041a6408, 0x1e1c640c,   // lg.sw.tl_653 lg.nl.sw_543  lg.tl.fi_443 lg.id.ms_543
  0x046b1a08, 0x2a000412, 0x2a00640e, 0x0a002319,   // tl.ceb.fi_443 fi.mt.un_640  lg.mt.un_550 ca.pt.un_750
  0x04080aad, 0x6b001004, 0x09271fa0, 0x536b1a13,   // mk.uk.ru_643 lt.ceb.un_320  cy.gd.pl_322 tl.ceb.ht_665
  0x11000b07, 0x03001e07, 0x1b0d0f12, 0x1a6b0908,   // es.ro.un_420 ms.nl.un_420  lv.cs.tr_654 pl.ceb.tl_443
  // [8040]
  0x02002d02, 0x311a1005, 0x0a100408, 0x06532505,   // sk.da.un_220 lt.tl.az_333  ru.be.mk_443 eu.ht.de_333
  0x2b6427a0, 0x023f06a9, 0x2816170c, 0x0b00550d,   // gd.lg.vi_322 de.af.da_544  sr.hr.sw_543 rw.es.un_540
  0x010b07a4, 0x6b002505, 0x10000f09, 0x19270a0c,   // it.es.en_433 eu.ceb.un_330  lv.lt.un_440 pt.gd.gl_543
  0x282064a0, 0x050f18a0, 0x1b002007, 0x17160502,   // lg.sq.sw_322 ga.lv.fr_322  sq.tr.un_420 fr.hr.sr_222
  // [8050]
  0x1000550e, 0x27000504, 0x532a05a4, 0x3f2008a0,   // rw.lt.un_550 fr.gd.un_320  fr.mt.ht_433 no.sq.af_322
  0x27186eee, 0x04000202, 0x1e001804, 0x12002902,   // blu.ga.gd_422 da.fi.un_220  ga.ms.un_320 sl.hu.un_220
  0x190a2705, 0x0f292007, 0x281064a6, 0x0d000a0c,   // gd.pt.gl_333 sq.sl.lv_432  lg.lt.sw_521 pt.cs.un_530
  0x046408a0, 0x07100412, 0x0d000104, 0x0e2812a0,   // no.lg.fi_322 ru.be.bg_654  en.cs.un_320 hu.sw.is_322
  // [8060]
  0x130f6408, 0x0d000a08, 0x040364ee, 0x182801a6,   // lg.lv.et_443 pt.cs.un_430  lg.nl.fi_422 en.sw.ga_521
  0x200c0d0b, 0x09131c0c, 0x030e1212, 0x09250d07,   // cs.sv.sq_542 mr.bh.hi_543  hu.is.nl_654 cs.eu.pl_432
  0x03250107, 0x2a002512, 0x060c01af, 0x0e10640b,   // en.eu.nl_432 eu.mt.un_640  en.sv.de_655 lg.lt.is_542
  0x2d290dec, 0x050b0a08, 0x030f17a0, 0x04120305,   // cs.sl.sk_644 pt.es.fr_443  sr.lv.nl_322 nl.hu.fi_333
  // [8070]
  0x030201a4, 0x531b310b, 0x21000404, 0x022d0d05,   // en.da.nl_433 az.tr.ht_542  fi.jw.un_320 cs.sk.da_333
  0x250453ad, 0x19002804, 0x1f1827ec, 0x0c0e0da4,   // ht.fi.eu_643 sw.gl.un_320  gd.ga.cy_644 cs.is.sv_433
  0x210c0ea0, 0x0c1a21a0, 0x6b1a0f04, 0x122108a0,   // is.sv.jw_322 jw.tl.sv_322  lv.tl.ceb_332 no.jw.hu_322
  0x08032da4, 0x190b1fec, 0x0c00200b, 0x120d2d11,   // sk.nl.no_433 cy.es.gl_644  sq.sv.un_520 sk.cs.hu_653
  // [8080]
  0x08530504, 0x100f01a0, 0x13045308, 0x555328a0,   // fr.ht.no_332 en.lv.lt_322  ht.fi.et_443 sw.ht.rw_322
  0x08000207, 0x25001e0e, 0x11002007, 0x1c000107,   // da.no.un_420 ms.eu.un_550  sq.ro.un_420 en.id.un_420
  0x121b1807, 0x01532707, 0x1c3f2b07, 0x170a110b,   // ga.tr.hu_432 gd.ht.en_432  vi.af.id_432 ro.mk.sr_542
  0x2b1b1fa6, 0x213f29a0, 0x1f0e18ad, 0x130d09ee,   // cy.tr.vi_521 sl.af.jw_322  ga.is.cy_643 hi.ne.bh_422
  // [8090]
  0x3f000335, 0x0d1a6b13, 0x06000212, 0x55001e09,   // nl.af.un_A90 ceb.tl.cs_665  da.de.un_640 ms.rw.un_440
  0x3f080c13, 0x0d2d1211, 0x01033fa4, 0x170516a0,   // sv.no.af_665 hu.sk.cs_653  af.nl.en_433 hr.fr.sr_322
  0x123f530c, 0x18002014, 0x6b281807, 0x166b1805,   // ht.af.hu_543 sq.ga.un_660  ga.sw.ceb_432 ga.ceb.hr_333
  0x2d0b19ee, 0x21641bad, 0x033f06a7, 0x0300010d,   // gl.es.sk_422 tr.lg.jw_643  de.af.nl_532 en.nl.un_540
  // [80a0]
  0x033f1aa6, 0x180916a0, 0x16020302, 0x040a17a9,   // tl.af.nl_521 hr.pl.ga_322  nl.da.hr_222 sr.mk.ru_544
  0x09080c04, 0x19001008, 0x2d00070e, 0x1e1c55ee,   // sv.no.pl_332 lt.gl.un_430  it.sk.un_550 rw.id.ms_422
  0x28080212, 0x1e2108a4, 0x6b061f07, 0x2d1a1207,   // da.no.sw_654 no.jw.ms_433  cy.de.ceb_432 hu.tl.sk_432
  0x133f0360, 0x1f0623a4, 0x013f030d, 0x11190b14,   // nl.af.et_664 ca.de.cy_433  nl.af.en_554 es.gl.ro_666
  // [80b0]
  0x12006423, 0x121b3102, 0x2d1e6b07, 0x3f0e0107,   // lg.hu.un_880 az.tr.hu_222  ceb.ms.sk_432 en.is.af_432
  0x101f0404, 0x101f18a9, 0x2a162dad, 0x08022702,   // fi.cy.lt_332 ga.cy.lt_544  sk.hr.mt_643 gd.da.no_222
  0x2d001212, 0x311b2814, 0x03001f07, 0x19002004,   // hu.sk.un_640 sw.tr.az_666  cy.nl.un_420 sq.gl.un_320
  0x08040204, 0x2a003f0c, 0x050b120c, 0x5500090c,   // da.fi.no_332 af.mt.un_530  hu.es.fr_543 pl.rw.un_530
  // [80c0]
  0x21282060, 0x6b001204, 0x28642a0c, 0x21162a07,   // sq.sw.jw_664 hu.ceb.un_320  mt.lg.sw_543 mt.hr.jw_432
  0x0c00130c, 0x04001f14, 0x190a1f09, 0x1f0410ad,   // et.sv.un_530 cy.fi.un_660  cy.pt.gl_444 lt.fi.cy_643
  0x53292aa0, 0x012d0d0d, 0x27201f04, 0x28003f08,   // mt.sl.ht_322 cs.sk.en_554  cy.sq.gd_332 af.sw.un_430
  0x3f0403a0, 0x20005523, 0x2a00091b, 0x040708a9,   // nl.fi.af_322 rw.sq.un_880  pl.mt.un_770 uk.bg.ru_544
  // [80d0]
  0x290f2a55, 0x230603af, 0x55005313, 0x210e29af,   // mt.lv.sl_442 nl.de.ca_655  ht.rw.un_650 sl.is.jw_655
  0x162864ee, 0x312a290d, 0x0f002a13, 0x070a0f0e,   // lg.sw.hr_422 sl.mt.az_554  mt.lv.un_650 lv.pt.it_555
  0x0e0a230c, 0x180f2712, 0x17002508, 0x2d003104,   // ca.pt.is_543 gd.lv.ga_654  eu.sr.un_430 az.sk.un_320
  0x13061804, 0x11002013, 0x080a04a7, 0x13005509,   // ga.de.et_332 sq.ro.un_650  ru.mk.uk_532 rw.et.un_440
  // [80e0]
  0x1a006408, 0x28216baf, 0x02002904, 0x11100808,   // lg.tl.un_430 ceb.jw.sw_655  sl.da.un_320 uk.be.ro_443
  0x64556b55, 0x281a5512, 0x641f07ee, 0x09000b02,   // ceb.rw.lg_442 rw.tl.sw_654  it.cy.lg_422 es.pl.un_220
  0x0f1310a0, 0x23001b07, 0x29556b04, 0x1a050f10,   // lt.et.lv_322 tr.ca.un_420  ceb.rw.sl_332 lv.fr.tl_642
  0x1c1b1e12, 0x64286b13, 0x1300292a, 0x06001e05,   // ms.tr.id_654 ceb.sw.lg_665  sl.et.un_970 ms.de.un_330
  // [80f0]
  0x2864555a, 0x13556411, 0x1a6b64ad, 0x0d001b05,   // rw.lg.sw_553 lg.rw.et_653  lg.ceb.tl_643 tr.cs.un_330
  0x07190a04, 0x11160ba4, 0x173f2007, 0x0e00210e,   // pt.gl.it_332 es.hr.ro_433  sq.af.sr_432 jw.is.un_550
  0x1a556407, 0x10551aa9, 0x011011a4, 0x250b08a4,   // lg.rw.tl_432 tl.rw.lt_544  ro.lt.en_433 no.es.eu_433
  0x2900210d, 0x2d161711, 0x2b531107, 0x061b0307,   // jw.sl.un_540 sr.hr.sk_653  ro.ht.vi_432 nl.tr.de_432
  // [8100]
  0x53033f0c, 0x25172907, 0x1f000d0d, 0x10645505,   // af.nl.ht_543 sl.sr.eu_432  cs.cy.un_540 rw.lg.lt_333
  0x27211ea7, 0x2511550c, 0x130d0509, 0x100e21a7,   // ms.jw.gd_532 rw.ro.eu_543  fr.cs.et_444 jw.is.lt_532
  0x04131e05, 0x19642508, 0x19050b0c, 0x280710a0,   // ms.et.fi_333 eu.lg.gl_443  es.fr.gl_543 lt.it.sw_322
  0x292d17af, 0x191a6bad, 0x121a1002, 0x010b1a5a,   // sr.sk.sl_655 ceb.tl.gl_643  lt.tl.hu_222 tl.es.en_553
  // [8110]
  0x6b0f1aa7, 0x1b100aa0, 0x0d1110a0, 0x1609250c,   // tl.lv.ceb_532 pt.lt.tr_322  lt.ro.cs_322 eu.pl.hr_543
  0x1a1b6407, 0x28231ca0, 0x09001b05, 0x2300111b,   // lg.tr.tl_432 id.ca.sw_322  tr.pl.un_330 ro.ca.un_770
  0x0302080c, 0x3f080eaf, 0x12002813, 0x171611ee,   // no.da.nl_543 is.no.af_655  sw.hu.un_650 ro.hr.sr_422
  0x1911120c, 0x05010705, 0x21001f12, 0x061320ad,   // hu.ro.gl_543 it.en.fr_333  cy.jw.un_640 sq.et.de_643
  // [8120]
  0x202b2708, 0x2812080b, 0x020620a0, 0x11210408,   // gd.vi.sq_443 no.hu.sw_542  sq.de.da_322 fi.jw.ro_443
  0x27091802, 0x23070104, 0x0a111005, 0x2500121b,   // ga.pl.gd_222 en.it.ca_332  be.ro.mk_333 hu.eu.un_770
  0x0b0501a0, 0x09000421, 0x0b2b23a7, 0x061220ec,   // en.fr.es_322 fi.pl.un_860  ca.vi.es_532 sq.hu.de_644
  0x0925040c, 0x190a2da4, 0x060812ee, 0x1b095355,   // fi.eu.pl_543 sk.pt.gl_433  hu.no.de_422 ht.pl.tr_442
  // [8130]
  0x24000134, 0x0a170413, 0x1b552111, 0x02001205,   // iw.yi.un_A80 ru.sr.mk_665  jw.rw.tr_653 hu.da.un_330
  0x1b556410, 0x3f021107, 0x03060207, 0x2a0e20a4,   // lg.rw.tr_642 ro.da.af_432  da.de.nl_432 sq.is.mt_433
  0x3f001b12, 0x04201313, 0x08200e0c, 0x2a006434,   // tr.af.un_640 et.sq.fi_665  is.sq.no_543 lg.mt.un_A80
  0x12292a14, 0x0f10160c, 0x131b25a4, 0x20090f55,   // mt.sl.hu_666 hr.lt.lv_543  eu.tr.et_433 lv.pl.sq_442
  // [8140]
  0x20290e12, 0x21120e0c, 0x201a1f04, 0x04000f04,   // is.sl.sq_654 is.hu.jw_543  cy.tl.sq_332 lv.fi.un_320
  0x53002112, 0x13042014, 0x53311ba0, 0x1b040ea7,   // jw.ht.un_640 sq.fi.et_666  tr.az.ht_322 is.fi.tr_532
  0x12292aaf, 0x021103a0, 0x080221a0, 0x06002109,   // mt.sl.hu_655 nl.ro.da_322  jw.da.no_322 jw.de.un_440
  0x085528a4, 0x20000821, 0x2864250c, 0x09291fad,   // sw.rw.no_433 no.sq.un_860  eu.lg.sw_543 cy.sl.pl_643
  // [8150]
  0x202a090c, 0x53000d02, 0x06251b13, 0x02001102,   // pl.mt.sq_543 cs.ht.un_220  tr.eu.de_665 ro.da.un_220
  0x122a1b0c, 0x122a29a4, 0x6b1c2109, 0x120b6402,   // tr.mt.hu_543 sl.mt.hu_433  jw.id.ceb_444 lg.es.hu_222
  0x1f2313a4, 0x64110f08, 0x64311bee, 0x2a092014,   // et.ca.cy_433 lv.ro.lg_443  tr.az.lg_422 sq.pl.mt_666
  0x202a12af, 0x1c1f1ea0, 0x23001f0d, 0x21231355,   // hu.mt.sq_655 ms.cy.id_322  cy.ca.un_540 et.ca.jw_442
  // [8160]
  0x02081608, 0x2d080107, 0x10020402, 0x210208a9,   // hr.no.da_443 en.no.sk_432  fi.da.lt_222 no.da.jw_544
  0x0213230b, 0x31001909, 0x27001b02, 0x0b071309,   // ca.et.da_542 gl.az.un_440  tr.gd.un_220 et.it.es_444
  0x091f21af, 0x0b000804, 0x1300230c, 0x17161f14,   // jw.cy.pl_655 no.es.un_320  ca.et.un_530 cy.hr.sr_666
  0x29041605, 0x06130314, 0x1b1f21ee, 0x190c23ee,   // hr.fi.sl_333 nl.et.de_666  jw.cy.tr_422 ca.sv.gl_422
  // [8170]
  0x2300130d, 0x1f132308, 0x1b0f1205, 0x1b000b04,   // et.ca.un_540 ca.et.cy_443  hu.lv.tr_333 es.tr.un_320
  0x0c230905, 0x170a100e, 0x0a101114, 0x313f03ee,   // pl.ca.sv_333 be.mk.sr_555  ro.be.mk_666 nl.af.az_422
  0x091c13a6, 0x2d1b3107, 0x31131baf, 0x01005502,   // bh.mr.hi_521 az.tr.sk_432  tr.et.az_655 rw.en.un_220
  0x551b31a9, 0x1b5331a6, 0x550464a9, 0x0f001011,   // az.tr.rw_544 az.ht.tr_521  lg.fi.rw_544 lt.lv.un_630
  // [8180]
  0x0e190a05, 0x192a25a7, 0x27080607, 0x53110705,   // pt.gl.is_333 eu.mt.gl_532  de.no.gd_432 it.ro.ht_333
  0x022a09a0, 0x1b1f310d, 0x0410645a, 0x060701a0,   // pl.mt.da_322 az.cy.tr_554  lg.lt.fi_553 en.it.de_322
  0x1c130d05, 0x3f0611a4, 0x0a110809, 0x080211a0,   // ne.bh.mr_333 ro.de.af_433  uk.ro.mk_444 ro.da.no_322
  0x070810a4, 0x1b6431a9, 0x250a0b07, 0x12001f1a,   // be.uk.bg_433 az.lg.tr_544  es.pt.eu_432 cy.hu.un_760
  // [8190]
  0x1f136ea0, 0x1600030d, 0x06040aa0, 0x0600121a,   // blu.et.cy_322 nl.hr.un_540  pt.fi.de_322 hu.de.un_760
  0x0a5509ad, 0x53081aa0, 0x2a002d07, 0x10170a09,   // pl.rw.pt_643 tl.no.ht_322  sk.mt.un_420 mk.sr.be_444
  0x1f030611, 0x5318275a, 0x21120e04, 0x250653a7,   // de.nl.cy_653 gd.ga.ht_553  is.hu.jw_332 ht.de.eu_532
  0x06000b04, 0x11000a09, 0x0f041207, 0x072a0a04,   // es.de.un_320 mk.ro.un_440  hu.fi.lv_432 pt.mt.it_332
  // [81a0]
  0x5317010c, 0x31201bad, 0x0f1023a4, 0x0d000b02,   // en.sr.ht_543 tr.sq.az_643  ca.lt.lv_433 es.cs.un_220
  0x0e000622, 0x2100101a, 0x040f13a7, 0x55255302,   // de.is.un_870 lt.jw.un_760  et.lv.fi_532 ht.eu.rw_222
  0x2d0c02a4, 0x640b550c, 0x021e64ac, 0x1f000419,   // da.sv.sk_433 rw.es.lg_543  lg.ms.da_632 fi.cy.un_750
  0x1e1c64ee, 0x136e2807, 0x1e1c6405, 0x6e6b2a02,   // lg.id.ms_422 sw.blu.et_432  lg.id.ms_333 mt.ceb.blu_222
  // [81b0]
  0x031e1fa7, 0x10002a12, 0x6e0208a4, 0x02086408,   // cy.ms.nl_532 mt.lt.un_640  no.da.blu_433 lg.no.da_443
  0x3f6e1eaf, 0x0a1c1e11, 0x11100412, 0x3f6e20af,   // ms.blu.af_655 ms.id.pt_653  fi.lt.ro_654 sq.blu.af_655
  0x07080460, 0x23000e13, 0x0b006e35, 0x640e1309,   // ru.uk.bg_664 is.ca.un_650  blu.es.un_A90 et.is.lg_444
  0x10005302, 0x033f6eac, 0x6b011ea0, 0x03193f05,   // ht.lt.un_220 blu.af.nl_632  ms.en.ceb_322 af.gl.nl_333
  // [81c0]
  0x11250408, 0x23010707, 0x0b190a60, 0x27532308,   // fi.eu.ro_443 it.en.ca_432  pt.gl.es_664 ca.ht.gd_443
  0x27230e04, 0x033f6e08, 0x31006e0c, 0x05190b55,   // is.ca.gd_332 blu.af.nl_443  blu.az.un_530 es.gl.fr_442
  0x1c001302, 0x0e0264ec, 0x1e1c02a4, 0x1c6e3f0c,   // bh.mr.un_220 lg.da.is_644  da.id.ms_433 af.blu.id_543
  0x10230512, 0x06210904, 0x100f6eec, 0x28000604,   // fr.ca.lt_654 pl.jw.de_332  blu.lv.lt_644 de.sw.un_320
  // [81d0]
  0x1c1228a4, 0x080c0eec, 0x0d110c09, 0x02002512,   // sw.hu.id_433 is.sv.no_644  sv.ro.cs_444 eu.da.un_640
  0x1f12100d, 0x27281aa7, 0x010910a4, 0x232b180c,   // lt.hu.cy_554 tl.sw.gd_532  lt.pl.en_433 ga.vi.ca_543
  0x212503a0, 0x1a026ba0, 0x06031f07, 0x19291ba0,   // nl.eu.jw_322 ceb.da.tl_322  cy.nl.de_432 tr.sl.gl_322
  0x08171104, 0x180828ee, 0x1a000212, 0x2a0801a7,   // ro.sr.uk_332 sw.no.ga_422  da.tl.un_640 en.no.mt_532
  // [81e0]
  0x0a1004af, 0x1f100907, 0x070b0107, 0x1e003f18,   // ru.be.mk_655 pl.lt.cy_432  en.es.it_432 af.ms.un_740
  0x31002112, 0x20000323, 0x0700170c, 0x1603210d,   // jw.az.un_640 nl.sq.un_880  sr.bg.un_530 jw.nl.hr_554
  0x0b532502, 0x03111613, 0x29001f08, 0x1f002a0b,   // eu.ht.es_222 hr.ro.nl_665  cy.sl.un_430 mt.cy.un_520
  0x1b12130c, 0x2511130c, 0x052a01a9, 0x2504130c,   // et.hu.tr_543 et.ro.eu_543  en.mt.fr_544 et.fi.eu_543
  // [81f0]
  0x29162d0c, 0x25131f08, 0x020e0c09, 0x05080c07,   // sk.hr.sl_543 cy.et.eu_443  sv.is.da_444 sv.no.fr_432
  0x1b00110d, 0x0e071ba0, 0x07001304, 0x0a2523a4,   // ro.tr.un_540 tr.it.is_322  et.it.un_320 ca.eu.pt_433
  0x6e2a0107, 0x12250909, 0x201b2d5a, 0x02001b0c,   // en.mt.blu_432 pl.eu.hu_444  sk.tr.sq_553 tr.da.un_530
  0x640e2555, 0x53052d05, 0x1e1c2da0, 0x121004af,   // eu.is.lg_442 sk.fr.ht_333  sk.id.ms_322 fi.lt.hu_655
  // [8200]
  0x03062007, 0x0200250d, 0x04645507, 0x080e0209,   // sq.de.nl_432 eu.da.un_540  rw.lg.fi_432 da.is.no_444
  0x12110705, 0x552d0d0d, 0x07002b02, 0x0a0804a4,   // it.ro.hu_333 cs.sk.rw_554  vi.it.un_220 ru.uk.mk_433
  0x0e531b0c, 0x1b120da0, 0x6b2055ee, 0x031f0107,   // tr.ht.is_543 cs.hu.tr_322  rw.sq.ceb_422 en.cy.nl_432
  0x21181209, 0x071f1355, 0x0f132805, 0x10002521,   // ur.ar.fa_444 et.cy.it_442  sw.et.lv_333 eu.lt.un_860
  // [8210]
  0x011a12ee, 0x08023f09, 0x10040713, 0x1000042c,   // hu.tl.en_422 af.da.no_444  bg.ru.be_665 ru.be.un_990
  0x1b311f0c, 0x2a000708, 0x310e2a04, 0x231216a0,   // cy.az.tr_543 it.mt.un_430  mt.is.az_332 hr.hu.ca_322
  0x64071307, 0x311c2104, 0x2d550907, 0x1300290d,   // et.it.lg_432 jw.id.az_332  pl.rw.sk_432 sl.et.un_540
  0x060201a4, 0x03132aee, 0x1f311b11, 0x1b0912ee,   // en.da.de_433 mt.et.nl_422  tr.az.cy_653 hu.pl.tr_422
  // [8220]
  0x27180d04, 0x250f07a4, 0x1b31080c, 0x0a001014,   // cs.ga.gd_332 it.lv.eu_433  no.az.tr_543 be.mk.un_660
  0x1c1231a0, 0x0804170e, 0x31001a0b, 0x0d552508,   // az.hu.id_322 sr.ru.uk_555  tl.az.un_520 eu.rw.cs_443
  0x28556405, 0x64000902, 0x132d0d0d, 0x251101a4,   // lg.rw.sw_333 pl.lg.un_220  cs.sk.et_554 en.ro.eu_433
  0x2d000304, 0x1325050c, 0x16001202, 0x11081005,   // nl.sk.un_320 fr.eu.et_543  hu.hr.un_220 be.uk.ro_333
  // [8230]
  0x081b12a4, 0x03002d0e, 0x04001219, 0x06290d02,   // hu.tr.no_433 sk.nl.un_550  hu.fi.un_750 cs.sl.de_222
  0x01020309, 0x1200010d, 0x11040814, 0x0d1c210b,   // nl.da.en_444 en.hu.un_540  uk.ru.ro_666 jw.id.cs_542
  0x3f100309, 0x311306a4, 0x1b001021, 0x040a0711,   // nl.lt.af_444 de.et.az_433  lt.tr.un_860 bg.mk.ru_653
  0x090723a0, 0x010307ee, 0x2d0311ee, 0x0d1716af,   // ca.it.pl_322 it.nl.en_422  ro.nl.sk_422 hr.sr.cs_655
  // [8240]
  0x09000d2b, 0x25041011, 0x3f0e030d, 0x21531e0c,   // cs.pl.un_980 lt.fi.eu_653  nl.is.af_554 ms.ht.jw_543
  0x1e162909, 0x21121eaf, 0x3f23030c, 0x023120a0,   // sl.hr.ms_444 ms.hu.jw_655  nl.ca.af_543 sq.az.da_322
  0x1600211a, 0x641e1c05, 0x21276bee, 0x2a001c08,   // jw.hr.un_760 id.ms.lg_333  ceb.gd.jw_422 id.mt.un_430
  0x641253ad, 0x2d0d1709, 0x211812a6, 0x03005319,   // ht.hu.lg_643 sr.cs.sk_444  ur.ar.fa_521 ht.nl.un_750
  // [8250]
  0x200c0204, 0x1b002102, 0x071827ad, 0x31201b07,   // da.sv.sq_332 jw.tr.un_220  gd.ga.it_643 tr.sq.az_432
  0x1a2753ee, 0x21171605, 0x25002707, 0x532921a7,   // ht.gd.tl_422 hr.sr.jw_333  gd.eu.un_420 jw.sl.ht_532
  0x11000a12, 0x091310a4, 0x27011fee, 0x0d212014,   // pt.ro.un_640 lt.et.pl_433  cy.en.gd_422 sq.jw.cs_666
  0x64212dad, 0x123f03a4, 0x17290904, 0x25001022,   // sk.jw.lg_643 nl.af.hu_433  pl.sl.sr_332 lt.eu.un_870
  // [8260]
  0x0a080413, 0x2d211c07, 0x2000110c, 0x1a252111,   // ru.uk.mk_665 id.jw.sk_432  ro.sq.un_530 jw.eu.tl_653
  0x0b003108, 0x18002d07, 0x1100040e, 0x03060204,   // az.es.un_430 sk.ga.un_420  ru.ro.un_550 da.de.nl_332
  0x110b6e04, 0x201821a0, 0x0b19250b, 0x08311b5a,   // blu.es.ro_332 jw.ga.sq_322  eu.gl.es_542 tr.az.no_553
  0x0118060b, 0x10002a08, 0x18001607, 0x31645513,   // de.ga.en_542 mt.lt.un_430  hr.ga.un_420 rw.lg.az_665
  // [8270]
  0x0f04230c, 0x201b310c, 0x27042aa4, 0x03003f34,   // ca.fi.lv_543 az.tr.sq_543  mt.fi.gd_433 af.nl.un_A80
  0x0c642a0d, 0x2a0b2d0c, 0x31000522, 0x53230204,   // mt.lg.sv_554 sk.es.mt_543  fr.az.un_870 da.ca.ht_332
  0x13100f12, 0x6b081a09, 0x19112809, 0x0c3f230c,   // lv.lt.et_654 tl.no.ceb_444  sw.ro.gl_444 ca.af.sv_543
  0x31282a0c, 0x0304080c, 0x1b2021ad, 0x02000322,   // mt.sw.az_543 no.fi.nl_543  jw.sq.tr_643 nl.da.un_870
  // [8280]
  0x0f006b12, 0x1f000208, 0x3f0307a4, 0x17531611,   // ceb.lv.un_640 da.cy.un_430  it.nl.af_433 hr.ht.sr_653
  0x2506040d, 0x3f1308ee, 0x1f1b3112, 0x06080e55,   // fi.de.eu_554 no.et.af_422  az.tr.cy_654 is.no.de_442
  0x530d2809, 0x0f643f04, 0x0d082d08, 0x27292da0,   // sw.cs.ht_444 af.lg.lv_332  sk.no.cs_443 sk.sl.gd_322
  0x2a000913, 0x130f10a4, 0x03180c02, 0x6b3127a4,   // pl.mt.un_650 lt.lv.et_433  sv.ga.nl_222 gd.az.ceb_433
  // [8290]
  0x02092a07, 0x3f021fa4, 0x53311204, 0x2a003120,   // mt.pl.da_432 cy.da.af_433  hu.az.ht_332 az.mt.un_850
  0x1923060d, 0x05010708, 0x2d1b310b, 0x0603070e,   // de.ca.gl_554 it.en.fr_443  az.tr.sk_542 it.nl.de_555
  0x161b12ee, 0x081306a4, 0x05000621, 0x170408a6,   // hu.tr.hr_422 de.et.no_433  de.fr.un_860 uk.ru.sr_521
  0x535528a7, 0x13640411, 0x3f060312, 0x6413040d,   // sw.rw.ht_532 fi.lg.et_653  nl.de.af_654 fi.et.lg_554
  // [82a0]
  0x03082508, 0x28001b05, 0x19250b12, 0x080d0ea4,   // eu.no.nl_443 tr.sw.un_330  es.eu.gl_654 is.cs.no_433
  0x02550512, 0x1e1c0309, 0x17131ba0, 0x06001b0d,   // fr.rw.da_654 nl.id.ms_444  tr.et.sr_322 tr.de.un_540
  0x2900020e, 0x13170807, 0x12076407, 0x08130ead,   // da.sl.un_550 no.sr.et_432  lg.it.hu_432 is.et.no_643
  0x311b5502, 0x0c031fee, 0x0c002907, 0x17080414,   // rw.tr.az_222 cy.nl.sv_422  sl.sv.un_420 ru.uk.sr_666
  // [82b0]
  0x1c000609, 0x0e1b06a0, 0x20001a04, 0x1b0e0607,   // de.id.un_440 de.tr.is_322  tl.sq.un_320 de.is.tr_432
  0x2b271ba0, 0x2d130c11, 0x050b2da7, 0x08001311,   // tr.gd.vi_322 sv.et.sk_653  sk.es.fr_532 et.no.un_630
  0x09002a0e, 0x10192307, 0x08060e08, 0x110105a7,   // mt.pl.un_550 ca.gl.lt_432  is.de.no_443 fr.en.ro_532
  0x1a216ba7, 0x2d0b09a0, 0x05182b07, 0x6b3f1a0c,   // ceb.jw.tl_532 pl.es.sk_322  vi.ga.fr_432 tl.af.ceb_543
  // [82c0]
  0x1e1813ee, 0x0f00110c, 0x10203fec, 0x080a04af,   // et.ga.ms_422 ro.lv.un_530  af.sq.lt_644 ru.mk.uk_655
  0x0e081fa0, 0x06110a07, 0x10123fa4, 0x230a12a0,   // cy.no.is_322 pt.ro.de_432  af.hu.lt_433 hu.pt.ca_322
  0x12110fa4, 0x0a0f0ba0, 0x170916a9, 0x010b05ad,   // lv.ro.hu_433 es.lv.pt_322  hr.pl.sr_544 fr.es.en_643
  0x12102514, 0x103f060c, 0x0f0a11a4, 0x051f10a0,   // eu.lt.hu_666 de.af.lt_543  ro.pt.lv_433 lt.cy.fr_322
  // [82d0]
  0x1a6b100c, 0x0f0611a4, 0x19000a18, 0x021827ec,   // lt.ceb.tl_543 ro.de.lv_433  pt.gl.un_740 gd.ga.da_644
  0x190a11a9, 0x100f1108, 0x06041108, 0x0c203f11,   // ro.pt.gl_544 ro.lv.lt_443  ro.fi.de_443 af.sq.sv_653
  0x0f1211a4, 0x071211a4, 0x086b17a0, 0x230c0804,   // ro.hu.lv_433 ro.hu.it_433  sr.ceb.no_322 no.sv.ca_332
  0x02002a02, 0x080e0caf, 0x3f092a13, 0x09062902,   // mt.da.un_220 sv.is.no_655  mt.pl.af_665 sl.de.pl_222
  // [82e0]
  0x13120411, 0x0c00082b, 0x0a110708, 0x2a190a5a,   // fi.hu.et_653 no.sv.un_980  bg.ro.mk_443 pt.gl.mt_553
  0x03000f07, 0x08002a1a, 0x07042507, 0x2a000218,   // lv.nl.un_420 mt.no.un_760  eu.fi.it_432 da.mt.un_740
  0x171a0404, 0x1f005304, 0x250306ee, 0x1a6b31af,   // fi.tl.sr_332 ht.cy.un_320  de.nl.eu_422 az.ceb.tl_655
  0x25000614, 0x02030607, 0x02001221, 0x17080607,   // de.eu.un_660 de.nl.da_432  hu.da.un_860 de.no.sr_432
  // [82f0]
  0x12030607, 0x12000c12, 0x023f0607, 0x041f0dad,   // de.nl.hu_432 sv.hu.un_640  de.af.da_432 cs.cy.fi_643
  0x0e0c6404, 0x2d001211, 0x3f2a0607, 0x6b0325ee,   // lg.sv.is_332 hu.sk.un_630  de.mt.af_432 eu.nl.ceb_422
  0x211204ad, 0x12002b04, 0x0c3f02ee, 0x2a060302,   // fi.hu.jw_643 vi.hu.un_320  da.af.sv_422 nl.de.mt_222
  0x16000404, 0x250806a4, 0x202917ee, 0x25030607,   // fi.hr.un_320 de.no.eu_433  sr.sl.sq_422 de.nl.eu_432
  // [8300]
  0x020c0607, 0x061e1b04, 0x0c003f14, 0x16172107,   // de.sv.da_432 tr.ms.de_332  af.sv.un_660 jw.sr.hr_432
  0x55100cee, 0x02036402, 0x2a1a1e0c, 0x28196408,   // sv.lt.rw_422 lg.nl.da_222  ms.tl.mt_543 lg.gl.sw_443
  0x171664af, 0x28183f07, 0x28131a0d, 0x13040cee,   // lg.hr.sr_655 af.ga.sw_432  tl.et.sw_554 sv.fi.et_422
  0x1a642809, 0x032a0c11, 0x081364a9, 0x19006b0b,   // sw.lg.tl_444 sv.mt.nl_653  lg.et.no_544 ceb.gl.un_520
  // [8310]
  0x0c5327a0, 0x18010b11, 0x1125640c, 0x25211312,   // gd.ht.sv_322 es.en.ga_653  lg.eu.ro_543 et.jw.eu_654
  0x0a1104ec, 0x13000b0c, 0x641225a4, 0x0f110a55,   // ru.ro.mk_644 es.et.un_530  eu.hu.lg_433 pt.ro.lv_442
  0x2b280908, 0x6400211b, 0x1a1764ad, 0x17070808,   // pl.sw.vi_443 jw.lg.un_770  lg.sr.tl_643 uk.bg.sr_443
  0x0800270d, 0x27112312, 0x041164a7, 0x31003f02,   // gd.no.un_540 ca.ro.gd_654  lg.ro.fi_532 af.az.un_220
  // [8320]
  0x55003122, 0x12180ea0, 0x1709200c, 0x0400072a,   // az.rw.un_870 is.ga.hu_322  sq.pl.sr_543 bg.ru.un_970
  0x20000908, 0x1e1c2ba4, 0x1e0a0f07, 0x080221a4,   // pl.sq.un_430 vi.id.ms_433  lv.pt.ms_432 jw.da.no_433
  0x2528115a, 0x111b3107, 0x112528af, 0x0b2511a9,   // ro.sw.eu_553 az.tr.ro_432  sw.eu.ro_655 ro.eu.es_544
  0x030906ee, 0x5300010c, 0x070501a0, 0x2d000a05,   // de.pl.nl_422 en.ht.un_530  en.fr.it_322 pt.sk.un_330
  // [8330]
  0x2500281a, 0x0d1125a9, 0x11000822, 0x03136405,   // sw.eu.un_760 eu.ro.cs_544  uk.ro.un_870 lg.et.nl_333
  0x1e251107, 0x0301130c, 0x282511af, 0x05002d0d,   // ro.eu.ms_432 et.en.nl_543  ro.eu.sw_655 sk.fr.un_540
  0x643f0312, 0x23001c02, 0x112825ec, 0x1a000121,   // nl.af.lg_654 id.ca.un_220  eu.sw.ro_644 en.tl.un_860
  0x6b1911a6, 0x08006408, 0x1b002a07, 0x072319a4,   // ro.gl.ceb_521 lg.no.un_430  mt.tr.un_420 gl.ca.it_433
  // [8340]
  0x03136407, 0x0313640c, 0x1210210c, 0x28250d0c,   // lg.et.nl_432 lg.et.nl_543  jw.lt.hu_543 cs.eu.sw_543
  0x0d1c0907, 0x21005302, 0x17040f07, 0x28251160,   // hi.mr.ne_432 ht.jw.un_220  lv.fi.sr_432 ro.eu.sw_664
  0x25001134, 0x110804ec, 0x081e6404, 0x1f00210c,   // ro.eu.un_A80 ru.uk.ro_644  lg.ms.no_332 jw.cy.un_530
  0x17165305, 0x64031355, 0x1923530d, 0x08033fa4,   // ht.hr.sr_333 et.nl.lg_442  ht.ca.gl_554 af.nl.no_433
  // [8350]
  0x170d1604, 0x03001309, 0x3f0e020c, 0x6403130d,   // hr.cs.sr_332 et.nl.un_440  da.is.af_543 et.nl.lg_554
  0x031364ec, 0x03136411, 0x29000308, 0x0a071009,   // lg.et.nl_644 lg.et.nl_653  nl.sl.un_430 be.bg.mk_444
  0x271c3fa0, 0x060308a9, 0x25100ca0, 0x112829a0,   // af.id.gd_322 no.nl.de_544  sv.lt.eu_322 sl.sw.ro_322
  0x0700640d, 0x55121007, 0x180b0755, 0x210625a0,   // lg.it.un_540 lt.hu.rw_432  it.es.ga_442 eu.de.jw_322
  // [8360]
  0x53006412, 0x131e1c55, 0x03001602, 0x1b2a13ee,   // lg.ht.un_640 id.ms.et_442  hr.nl.un_220 et.mt.tr_422
  0x21551807, 0x20000d07, 0x1c282155, 0x311011ee,   // ga.rw.jw_432 cs.sq.un_420  jw.sw.id_442 ro.lt.az_422
  0x236e01ac, 0x1b161307, 0x0c2313ec, 0x2a006b21,   // en.blu.ca_632 et.hr.tr_432  et.ca.sv_644 ceb.mt.un_860
  0x251716a7, 0x3f2110ee, 0x1a006e0d, 0x116b09a0,   // hr.sr.eu_532 lt.jw.af_422  blu.tl.un_540 pl.ceb.ro_322
  // [8370]
  0x040e6b07, 0x1800060c, 0x2b10120c, 0x281323ad,   // ceb.is.fi_432 de.ga.un_530  hu.lt.vi_543 ca.et.sw_643
  0x10002a19, 0x64231304, 0x27051e07, 0x23056eec,   // mt.lt.un_750 et.ca.lg_332  ms.fr.gd_432 blu.fr.ca_644
  0x063f090c, 0x230b0707, 0x190a06af, 0x550f2da6,   // pl.af.de_543 it.es.ca_432  de.pt.gl_655 sk.lv.rw_521
  0x2700130e, 0x276e5308, 0x0b0701ec, 0x1a1b6b08,   // et.gd.un_550 ht.blu.gd_443  en.it.es_644 ceb.tr.tl_443
  // [8380]
  0x6e2d0d0e, 0x0b552107, 0x09172dee, 0x311b6eec,   // cs.sk.blu_555 jw.rw.es_432  sk.sr.pl_422 blu.tr.az_644
  0x073f0a02, 0x070a08a9, 0x071331ee, 0x123f1a0c,   // pt.af.it_222 uk.mk.bg_544  az.et.it_422 tl.af.hu_543
  0x06090fa9, 0x190a13ec, 0x1f002514, 0x0a131c07,   // lv.pl.de_544 et.pt.gl_644  eu.cy.un_660 id.et.pt_432
  0x27002308, 0x21200512, 0x081b0ca9, 0x0e081f08,   // ca.gd.un_430 fr.sq.jw_654  sv.tr.no_544 cy.no.is_443
  // [8390]
  0x2a006e12, 0x0c020308, 0x3f040704, 0x0600012a,   // blu.mt.un_640 nl.da.sv_443  it.fi.af_332 en.de.un_970
  0x09040b0c, 0x1f051107, 0x64282104, 0x2a0f6e0e,   // es.fi.pl_543 ro.fr.cy_432  jw.sw.lg_332 blu.lv.mt_555
  0x07000f21, 0x04136bad, 0x04002d0d, 0x6b00090d,   // lv.it.un_860 ceb.et.fi_643  sk.fi.un_540 pl.ceb.un_540
  0x17040811, 0x20063107, 0x1f1b0eec, 0x1a000b0b,   // uk.ru.sr_653 az.de.sq_432  is.tr.cy_644 es.tl.un_520
  // [83a0]
  0x0e0c0802, 0x6b1a0b0d, 0x12000e22, 0x1c311e08,   // no.sv.is_222 es.tl.ceb_554  is.hu.un_870 ms.az.id_443
  0x21130407, 0x080c6b08, 0x23050b04, 0x0e000405,   // fi.et.jw_432 ceb.sv.no_443  es.fr.ca_332 fi.is.un_330
  0x0d2d09a7, 0x1f010802, 0x092d1007, 0x18232702,   // pl.sk.cs_532 no.en.cy_222  lt.sk.pl_432 gd.ca.ga_222
  0x18000519, 0x10000c08, 0x07080c08, 0x0a11070c,   // fr.ga.un_750 sv.lt.un_430  sv.no.it_443 bg.ro.mk_543
  // [83b0]
  0x2d180a07, 0x09292507, 0x2d1b0da0, 0x09000a02,   // pt.ga.sk_432 eu.sl.pl_432  cs.tr.sk_322 pt.pl.un_220
  0x10000a08, 0x070a0907, 0x102d0a0e, 0x25190ba0,   // pt.lt.un_430 pl.pt.it_432  pt.sk.lt_555 es.gl.eu_322
  0x1b31010c, 0x081b04ac, 0x12001e02, 0x112005ee,   // en.az.tr_543 fi.tr.no_632  ms.hu.un_220 fr.sq.ro_422
  0x6e002d02, 0x01310e07, 0x101e0a08, 0x1831250c,   // sk.blu.un_220 is.az.en_432  pt.ms.lt_443 eu.az.ga_543
  // [83c0]
  0x18001012, 0x2a001a0c, 0x02190ca0, 0x18251f0c,   // lt.ga.un_640 tl.mt.un_530  sv.gl.da_322 cy.eu.ga_543
  0x29072d05, 0x64001e04, 0x3f2a07a0, 0x061b2511,   // sk.it.sl_333 ms.lg.un_320  it.mt.af_322 eu.tr.de_653
  0x13002a08, 0x13013fee, 0x0f180a04, 0x012153a0,   // mt.et.un_430 af.en.et_422  pt.ga.lv_332 ht.jw.en_322
  0x02005302, 0x640153af, 0x2a255311, 0x122a5307,   // ht.da.un_220 ht.en.lg_655  ht.eu.mt_653 ht.mt.hu_432
  // [83d0]
  0x0a0804af, 0x052312ee, 0x2a3f05ad, 0x07002005,   // ru.uk.mk_655 hu.ca.fr_422  fr.af.mt_643 sq.it.un_330
  0x02051207, 0x252a0708, 0x01000b0e, 0x2b000102,   // hu.fr.da_432 it.mt.eu_443  es.en.un_550 en.vi.un_220
  0x04101705, 0x041b0fa0, 0x2d29170c, 0x530e1ba0,   // sr.be.ru_333 lv.tr.fi_322  sr.sl.sk_543 tr.is.ht_322
  0x2a0c2904, 0x2b1a1204, 0x171f0ca0, 0x2b005502,   // sl.sv.mt_332 hu.tl.vi_332  sv.cy.sr_322 rw.vi.un_220
  // [83e0]
  0x10132104, 0x170127a0, 0x28000e0d, 0x2d292aee,   // jw.et.lt_332 gd.en.sr_322  is.sw.un_540 mt.sl.sk_422
  0x23080ea4, 0x06080e05, 0x29001b14, 0x0f041304,   // is.no.ca_433 is.no.de_333  tr.sl.un_660 et.fi.lv_332
  0x0400121a, 0x0e001f04, 0x072a01a9, 0x083f0207,   // hu.fi.un_760 cy.is.un_320  en.mt.it_544 da.af.no_432
  0x04001213, 0x201b0404, 0x060e1307, 0x0f211b07,   // hu.fi.un_650 fi.tr.sq_332  et.is.de_432 tr.jw.lv_432
  // [83f0]
  0x040f1302, 0x060508a0, 0x0e2953a0, 0x061e1c0d,   // et.lv.fi_222 no.fr.de_322  ht.sl.is_322 id.ms.de_554
  0x111f0e0c, 0x072a1f12, 0x2a11190c, 0x10001b13,   // is.cy.ro_543 cy.mt.it_654  gl.ro.mt_543 tr.lt.un_650
  0x061323a4, 0x13001f05, 0x020e1f08, 0x12000413,   // ca.et.de_433 cy.et.un_330  cy.is.da_443 fi.hu.un_650
  0x182d0d02, 0x082a0c07, 0x53003f02, 0x1e311b08,   // cs.sk.ga_222 sv.mt.no_432  af.ht.un_220 tr.az.ms_443

  // [8400]
  0x5528310c, 0x11200a07, 0x08000f18, 0x071155ad,   // az.sw.rw_543 pt.sq.ro_432  lv.no.un_740 rw.ro.it_643
  0x25000923, 0x0b231907, 0x1a6b01af, 0x6b3128ad,   // pl.eu.un_880 gl.ca.es_432  en.ceb.tl_655 sw.az.ceb_643
  0x08101105, 0x6b001a23, 0x2d1f0dad, 0x1f003f07,   // ro.be.uk_333 tl.ceb.un_880  cs.cy.sk_643 af.cy.un_420
  0x04021aa0, 0x64551aaf, 0x281b2508, 0x015321ee,   // tl.da.fi_322 tl.rw.lg_655  eu.tr.sw_443 jw.ht.en_422
  // [8410]
  0x112d0d08, 0x03280602, 0x0d18060d, 0x010a6408,   // cs.sk.ro_443 de.sw.nl_222  de.ga.cs_554 lg.pt.en_443
  0x1e200202, 0x1f001c05, 0x1a211c0b, 0x033f050c,   // da.sq.ms_222 id.cy.un_330  id.jw.tl_542 fr.af.nl_543
  0x6b1a01a4, 0x013f05a4, 0x0e1b04af, 0x29002b07,   // en.tl.ceb_433 fr.af.en_433  fi.tr.is_655 vi.sl.un_420
  0x281e20ac, 0x03051f0e, 0x201b09a9, 0x080205ee,   // sq.ms.sw_632 cy.fr.nl_555  pl.tr.sq_544 fr.da.no_422
  // [8420]
  0x033f0504, 0x130e1baf, 0x17162dac, 0x056b0308,   // fr.af.nl_332 tr.is.et_655  sk.hr.sr_632 nl.ceb.fr_443
  0x2128640e, 0x070f1312, 0x21003102, 0x640e07ec,   // lg.sw.jw_555 et.lv.it_654  az.jw.un_220 it.is.lg_644
  0x1a6b130b, 0x05033fa0, 0x100f1604, 0x055319a0,   // et.ceb.tl_542 af.nl.fr_322  hr.lv.lt_332 gl.ht.fr_322
  0x04110a05, 0x233f05ee, 0x09311b12, 0x23001012,   // mk.ro.ru_333 fr.af.ca_422  tr.az.pl_654 lt.ca.un_640
  // [8430]
  0x11130f12, 0x27002a02, 0x292816af, 0x12000c11,   // lv.et.ro_654 mt.gd.un_220  hr.sw.sl_655 sv.hu.un_630
  0x212025a0, 0x12211809, 0x17162a09, 0x3f0701a4,   // eu.sq.jw_322 ar.fa.ur_444  mt.hr.sr_444 en.it.af_433
  0x04642808, 0x0f071007, 0x0c1e13a4, 0x28002708,   // sw.lg.fi_443 lt.it.lv_432  et.ms.sv_433 gd.sw.un_430
  0x132a0755, 0x29000907, 0x0a000b1a, 0x64002822,   // it.mt.et_442 pl.sl.un_420  es.pt.un_760 sw.lg.un_870
  // [8440]
  0x01023fee, 0x182853a0, 0x042d53a0, 0x27282a07,   // af.da.en_422 ht.sw.ga_322  ht.sk.fi_322 mt.sw.gd_432
  0x29002807, 0x160d17a0, 0x180a11a0, 0x020c0508,   // sw.sl.un_420 sr.cs.hr_322  ro.pt.ga_322 fr.sv.da_443
  0x20002114, 0x1e1c230c, 0x216428a7, 0x1b1a06ad,   // jw.sq.un_660 ca.id.ms_543  sw.lg.jw_532 de.tl.tr_643
  0x285521a0, 0x07285508, 0x030701a4, 0x310601a0,   // jw.rw.sw_322 rw.sw.it_443  en.it.nl_433 en.de.az_322
  // [8450]
  0x080711a6, 0x27210ba0, 0x6b005508, 0x11001319,   // ro.bg.uk_521 es.jw.gd_322  rw.ceb.un_430 et.ro.un_750
  0x252718ad, 0x032510a0, 0x1200051a, 0x0a280707,   // ga.gd.eu_643 lt.eu.nl_322  fr.hu.un_760 it.sw.pt_432
  0x310106ee, 0x2d0e0da0, 0x2006010c, 0x21000d12,   // de.en.az_422 cs.is.sk_322  en.de.sq_543 cs.jw.un_640
  0x230325a7, 0x280e210c, 0x2d0f0d12, 0x1200091b,   // eu.nl.ca_532 jw.is.sw_543  cs.lv.sk_654 pl.hu.un_770
  // [8460]
  0x10130207, 0x5500061a, 0x2821130c, 0x0828020c,   // da.et.lt_432 de.rw.un_760  et.jw.sw_543 da.sw.no_543
  0x0b00050c, 0x07010505, 0x072a29a4, 0x05000d08,   // fr.es.un_530 fr.en.it_333  sl.mt.it_433 cs.fr.un_430
  0x0417080b, 0x052d0d09, 0x08040aa4, 0x5304130c,   // uk.sr.ru_542 cs.sk.fr_444  mk.ru.uk_433 et.fi.ht_543
  0x311b0bad, 0x0c000a07, 0x0f000d05, 0x0a236ead,   // es.tr.az_643 pt.sv.un_420  cs.lv.un_330 blu.ca.pt_643
  // [8470]
  0x010e0aa6, 0x0a000204, 0x10270908, 0x020a0ca4,   // pt.is.en_521 da.pt.un_320  pl.gd.lt_443 sv.pt.da_433
  0x172d0f04, 0x0c006407, 0x07010607, 0x18011ea0,   // lv.sk.sr_332 lg.sv.un_420  de.en.it_432 ms.en.ga_322
  0x190911a6, 0x0a071755, 0x091655ac, 0x0a530907,   // ro.pl.gl_521 sr.bg.mk_442  rw.hr.pl_632 pl.ht.pt_432
  0x2d000908, 0x050b550b, 0x100a0407, 0x04120811,   // pl.sk.un_430 rw.es.fr_542  ru.mk.be_432 no.hu.fi_653
  // [8480]
  0x29312002, 0x08000905, 0x6b011e07, 0x0a00310c,   // sq.az.sl_222 pl.no.un_330  ms.en.ceb_432 az.pt.un_530
  0x2d0d6bee, 0x1b3110af, 0x21000a02, 0x1e002b04,   // ceb.cs.sk_422 lt.az.tr_655  pt.jw.un_220 vi.ms.un_320
  0x17160907, 0x2a000504, 0x1a1b6bad, 0x13091807,   // pl.hr.sr_432 fr.mt.un_320  ceb.tr.tl_643 ga.pl.et_432
  0x083f02a0, 0x556408a0, 0x0c1b2507, 0x18000e19,   // da.af.no_322 no.lg.rw_322  eu.tr.sv_432 is.ga.un_750
  // [8490]
  0x0700042b, 0x0f0713a4, 0x0c001c04, 0x10002013,   // ru.bg.un_980 et.it.lv_433  id.sv.un_320 sq.lt.un_650
  0x060425a0, 0x10000607, 0x17000307, 0x08041002,   // eu.fi.de_322 de.lt.un_420  nl.sr.un_420 be.ru.uk_222
  0x030804ee, 0x3f00060d, 0x1a000402, 0x136b280c,   // fi.no.nl_422 de.af.un_540  fi.tl.un_220 sw.ceb.et_543
  0x130c100b, 0x04281a09, 0x29001b07, 0x29136b02,   // lt.sv.et_542 tl.sw.fi_444  tr.sl.un_420 ceb.et.sl_222
  // [84a0]
  0x100f110c, 0x3f271a04, 0x3f0102a0, 0x2b001307,   // ro.lv.lt_543 tl.gd.af_332  da.en.af_322 et.vi.un_420
  0x29120aee, 0x100623a7, 0x1a132804, 0x1a0e1ca9,   // pt.hu.sl_422 ca.de.lt_532  sw.et.tl_332 id.is.tl_544
  0x20251c07, 0x030206a4, 0x1e001a22, 0x21136402,   // id.eu.sq_432 de.da.nl_433  tl.ms.un_870 lg.et.jw_222
  0x19081a07, 0x1f0d2ba9, 0x273f02a7, 0x55162804,   // tl.no.gl_432 vi.cs.cy_544  da.af.gd_532 sw.hr.rw_332
  // [84b0]
  0x01250ca4, 0x1f023f04, 0x010b25a4, 0x182725ec,   // sv.eu.en_433 af.da.cy_332  eu.es.en_433 eu.gd.ga_644
  0x07211111, 0x0e3f065a, 0x0a1104a4, 0x2b3f03ee,   // ro.jw.it_653 de.af.is_553  ru.ro.mk_433 nl.af.vi_422
  0x251a10a4, 0x2000250b, 0x10071709, 0x20092507,   // lt.tl.eu_433 eu.sq.un_520  sr.bg.be_444 eu.pl.sq_432
  0x1a6b13a0, 0x030f08a0, 0x0400210d, 0x1a003f02,   // et.ceb.tl_322 no.lv.nl_322  jw.fi.un_540 af.tl.un_220
  // [84c0]
  0x181a2b07, 0x11102907, 0x2b3f12a0, 0x6b1a180c,   // vi.tl.ga_432 sl.lt.ro_432  hu.af.vi_322 ga.tl.ceb_543
  0x063f0107, 0x0228550c, 0x64271f02, 0x162d1005,   // en.af.de_432 rw.sw.da_543  cy.gd.lg_222 lt.sk.hr_333
  0x0a0417ec, 0x2a051faf, 0x060c0e04, 0x0400290c,   // sr.ru.mk_644 cy.fr.mt_655  is.sv.de_332 sl.fi.un_530
  0x170a0804, 0x190b05a4, 0x0c010604, 0x0e0a1107,   // uk.mk.sr_332 fr.es.gl_433  de.en.sv_332 ro.pt.is_432
  // [84d0]
  0x31002321, 0x0100130d, 0x160706a7, 0x2b1301ee,   // ca.az.un_860 et.en.un_540  de.it.hr_532 en.et.vi_422
  0x1355010c, 0x3f2b01a7, 0x25003109, 0x6b2001a0,   // en.rw.et_543 en.vi.af_532  az.eu.un_440 en.sq.ceb_322
  0x2b1801ee, 0x25000904, 0x01001b02, 0x2d001a02,   // en.ga.vi_422 pl.eu.un_320  tr.en.un_220 tl.sk.un_220
  0x1a130404, 0x3f03530c, 0x1c1029a0, 0x0d252d0c,   // fi.et.tl_332 ht.nl.af_543  sl.lt.id_322 sk.eu.cs_543
  // [84e0]
  0x1300040b, 0x08000c2b, 0x093101ee, 0x6e016b02,   // fi.et.un_520 sv.no.un_980  en.az.pl_422 ceb.en.blu_222
  0x20291604, 0x0900251a, 0x0c00190c, 0x2a001902,   // hr.sl.sq_332 eu.pl.un_760  gl.sv.un_530 gl.mt.un_220
  0x08000c07, 0x250b1007, 0x01312a0c, 0x036b3fa0,   // sv.no.un_420 lt.es.eu_432  mt.az.en_543 af.ceb.nl_322
  0x1b00200c, 0x201e08a0, 0x10121f07, 0x081023ad,   // sq.tr.un_530 no.ms.sq_322  cy.hu.lt_432 ca.lt.no_643
  // [84f0]
  0x64032807, 0x1c29100b, 0x010e3fa7, 0x2a11180c,   // sw.nl.lg_432 lt.sl.id_542  af.is.en_532 ga.ro.mt_543
  0x0c193fee, 0x0c0855a9, 0x12000119, 0x1000230e,   // af.gl.sv_422 rw.no.sv_544  en.hu.un_750 ca.lt.un_550
  0x13010304, 0x170a04af, 0x09002702, 0x036b010c,   // nl.en.et_332 ru.mk.sr_655  gd.pl.un_220 en.ceb.nl_543
  0x0e0802a0, 0x0e08020c, 0x0b2810ee, 0x1e022702,   // da.no.is_322 da.no.is_543  lt.sw.es_422 gd.da.ms_222
  // [8500]
  0x1011120c, 0x111607a0, 0x182155ad, 0x1a282708,   // hu.ro.lt_543 it.hr.ro_322  rw.jw.ga_643 gd.sw.tl_443
  0x2a1023a0, 0x102711a0, 0x10001811, 0x111e1cec,   // ca.lt.mt_322 ro.gd.lt_322  ga.lt.un_630 id.ms.ro_644
  0x08003f0c, 0x3f280802, 0x1e3f1c0c, 0x190a27a6,   // af.no.un_530 no.sw.af_222  id.af.ms_543 gd.pt.gl_521
  0x17100a60, 0x072b6b0d, 0x645512a7, 0x2d002814,   // mk.be.sr_664 ceb.vi.it_554  hu.rw.lg_532 sw.sk.un_660
  // [8510]
  0x210b55a4, 0x311c530c, 0x1e1c6b02, 0x28182713,   // rw.es.jw_433 ht.id.az_543  ceb.id.ms_222 gd.ga.sw_665
  0x642911a4, 0x162d0908, 0x27180909, 0x1b002a0e,   // ro.sl.lg_433 pl.sk.hr_443  pl.ga.gd_444 mt.tr.un_550
  0x1105070d, 0x2a1809ad, 0x10001c1a, 0x1711310c,   // it.fr.ro_554 pl.ga.mt_643  id.lt.un_760 az.ro.sr_543
  0x0e040f0c, 0x20000e0c, 0x18042712, 0x08002a08,   // lv.fi.is_543 is.sq.un_530  gd.fi.ga_654 mt.no.un_430
  // [8520]
  0x27112108, 0x13100f08, 0x182101ee, 0x02285507,   // jw.ro.gd_443 lv.lt.et_443  en.jw.ga_422 rw.sw.da_432
  0x070b23ec, 0x192301a4, 0x110a0713, 0x0f100ca4,   // ca.es.it_644 en.ca.gl_433  bg.mk.ro_665 sv.lt.lv_433
  0x3f251904, 0x533f10ee, 0x1b1e0808, 0x182b0e0d,   // gl.eu.af_332 lt.af.ht_422  no.ms.tr_443 is.vi.ga_554
  0x080e1ea4, 0x080e0904, 0x2b0b1812, 0x1e002521,   // ms.is.no_433 pl.is.no_332  ga.es.vi_654 eu.ms.un_860
  // [8530]
  0x27001e04, 0x0d2d2912, 0x1e20080c, 0x23182bad,   // ms.gd.un_320 sl.sk.cs_654  no.sq.ms_543 vi.ga.ca_643
  0x0e1e1c07, 0x0d00182a, 0x29091ea0, 0x292509a4,   // id.ms.is_432 ga.cs.un_970  ms.pl.sl_322 pl.eu.sl_433
  0x100d040c, 0x110e0c0d, 0x1e1c0a0e, 0x1f1b31af,   // fi.cs.lt_543 sv.is.ro_554  pt.id.ms_555 az.tr.cy_655
  0x2b001822, 0x091e2512, 0x04170aec, 0x11171008,   // ga.vi.un_870 eu.ms.pl_654  mk.sr.ru_644 be.sr.ro_443
  // [8540]
  0x0d002919, 0x2b001804, 0x2b000e05, 0x0d17165a,   // sl.cs.un_750 ga.vi.un_320  is.vi.un_330 hr.sr.cs_553
  0x091b530c, 0x0a0804ee, 0x1b1c310c, 0x31002509,   // ht.tr.pl_543 ru.uk.mk_422  az.id.tr_543 eu.az.un_440
  0x041610ee, 0x1e1c0914, 0x0b2318af, 0x041b0f12,   // lt.hr.fi_422 pl.id.ms_666  ga.ca.es_655 lv.tr.fi_654
  0x6b1a28a4, 0x2a06010c, 0x07005307, 0x096b1ea0,   // sw.tl.ceb_433 en.de.mt_543  ht.it.un_420 ms.ceb.pl_322
  // [8550]
  0x08061202, 0x0d002b1a, 0x28001e07, 0x04081011,   // hu.de.no_222 vi.cs.un_760  ms.sw.un_420 be.uk.ru_653
  0x0d1f2d07, 0x2d2b1808, 0x0f082ba7, 0x07002712,   // sk.cy.cs_432 ga.vi.sk_443  vi.no.lv_532 gd.it.un_640
  0x2a6b01ad, 0x31641bad, 0x250b0a04, 0x55292d07,   // en.ceb.mt_643 tr.lg.az_643  pt.es.eu_332 sk.sl.rw_432
  0x0a11070e, 0x530b5504, 0x190b2ba4, 0x1c212808,   // bg.ro.mk_555 rw.es.ht_332  vi.es.gl_433 sw.jw.id_443
  // [8560]
  0x08120ca4, 0x06002105, 0x0b080c05, 0x1b081205,   // sv.hu.no_433 jw.de.un_330  sv.no.es_333 hu.no.tr_333
  0x2d080da4, 0x111210a4, 0x64311b05, 0x2b001302,   // cs.no.sk_433 lt.hu.ro_433  tr.az.lg_333 et.vi.un_220
  0x07001c05, 0x31531b0e, 0x1100550d, 0x2d0d21a9,   // id.it.un_330 tr.ht.az_555  rw.ro.un_540 jw.cs.sk_544
  0x100a070c, 0x0b001109, 0x29001c02, 0x10001e22,   // bg.mk.be_543 ro.es.un_440  id.sl.un_220 ms.lt.un_870
  // [8570]
  0x1e1c20a0, 0x076411a4, 0x100f1ea4, 0x0f00102b,   // sq.id.ms_322 ro.lg.it_433  ms.lv.lt_433 lt.lv.un_980
  0x10281eaf, 0x31120805, 0x1f2810a4, 0x041c21ad,   // ms.sw.lt_655 no.hu.az_333  lt.sw.cy_433 jw.id.fi_643
  0x11001b1a, 0x19230d04, 0x200f10ad, 0x120f0cee,   // tr.ro.un_760 cs.ca.gl_332  lt.lv.sq_643 sv.lv.hu_422
  0x111e12ee, 0x1b3111ac, 0x09002b08, 0x0a1e1ca4,   // hu.ms.ro_422 ro.az.tr_632  vi.pl.un_430 id.ms.pt_433
  // [8580]
  0x1b101255, 0x06136ba0, 0x121c1e0c, 0x25006e07,   // hu.lt.tr_442 ceb.et.de_322  ms.id.hu_543 blu.eu.un_420
  0x120f1011, 0x21196ba0, 0x23002d05, 0x120f10ad,   // lt.lv.hu_653 ceb.gl.jw_322  sk.ca.un_330 lt.lv.hu_643
  0x531c1ba4, 0x07030aa0, 0x0a281005, 0x0c6b0ea0,   // tr.id.ht_433 pt.nl.it_322  lt.sw.pt_333 is.ceb.sv_322
  0x280b2707, 0x2b002004, 0x27002821, 0x1b001114,   // gd.es.sw_432 sq.vi.un_320  sw.gd.un_860 ro.tr.un_660
  // [8590]
  0x2d0f0913, 0x0a171009, 0x272a11ec, 0x31250502,   // pl.lv.sk_665 be.sr.mk_444  ro.mt.gd_644 fr.eu.az_222
  0x18001e02, 0x1f0518a7, 0x051f18ec, 0x1c2728ad,   // ms.ga.un_220 ga.fr.cy_532  ga.cy.fr_644 sw.gd.id_643
  0x010f07a6, 0x2a162da0, 0x07062511, 0x1e00180d,   // it.lv.en_521 sk.hr.mt_322  eu.de.it_653 ga.ms.un_540
  0x1b251c04, 0x0f061212, 0x093f6ba0, 0x1a0910a0,   // id.eu.tr_332 hu.de.lv_654  ceb.af.pl_322 lt.pl.tl_322
  // [85a0]
  0x01001f0b, 0x10003f07, 0x53001f12, 0x1800051a,   // cy.en.un_520 af.lt.un_420  cy.ht.un_640 fr.ga.un_760
  0x050b3f04, 0x03003f36, 0x2d0d21af, 0x250c31ee,   // af.es.fr_332 af.nl.un_AA0  jw.cs.sk_655 az.sv.eu_422
  0x06005312, 0x13000f0d, 0x01102d04, 0x080225ad,   // ht.de.un_640 lv.et.un_540  sk.lt.en_332 eu.da.no_643
  0x190b55a0, 0x111704a4, 0x6b1b1aee, 0x0c060e04,   // rw.es.gl_322 ru.sr.ro_433  tl.tr.ceb_422 is.de.sv_332
  // [85b0]
  0x1b1e53ee, 0x08020c0c, 0x1a2a2104, 0x06001014,   // ht.ms.tr_422 sv.da.no_543  jw.mt.tl_332 lt.de.un_660
  0x200921a4, 0x06022a04, 0x06033f09, 0x121621ad,   // jw.pl.sq_433 mt.da.de_332  af.nl.de_444 jw.hr.hu_643
  0x09000c07, 0x052d0d11, 0x03083f0c, 0x21001f09,   // sv.pl.un_420 cs.sk.fr_653  af.no.nl_543 cy.jw.un_440
  0x1b1e3107, 0x1a0f13ad, 0x0b6b11ee, 0x3f032112,   // az.ms.tr_432 et.lv.tl_643  ro.ceb.es_422 jw.nl.af_654
  // [85c0]
  0x0b310107, 0x060d02a0, 0x110801a4, 0x293f21ee,   // en.az.es_432 da.cs.de_322  en.no.ro_433 jw.af.sl_422
  0x16292d0d, 0x2d0908a4, 0x1a211bad, 0x17002d12,   // sk.sl.hr_554 no.pl.sk_433  tr.jw.tl_643 sk.sr.un_640
  0x1b2008a0, 0x0a2d1902, 0x121716a7, 0x3f000902,   // no.sq.tr_322 gl.sk.pt_222  hr.sr.hu_532 pl.af.un_220
  0x03132904, 0x0a230207, 0x17100f08, 0x07002314,   // sl.et.nl_332 da.ca.pt_432  lv.lt.sr_443 ca.it.un_660
  // [85d0]
  0x280413af, 0x0f28040c, 0x27231807, 0x286b040d,   // et.fi.sw_655 fi.sw.lv_543  ga.ca.gd_432 fi.ceb.sw_554
  0x28046b13, 0x0f280411, 0x062311a0, 0x0704100c,   // ceb.fi.sw_665 fi.sw.lv_653  ro.ca.de_322 be.ru.bg_543
  0x0f281b08, 0x0602640b, 0x192d0d14, 0x040f28a0,   // tr.sw.lv_443 lg.da.de_542  cs.sk.gl_666 sw.lv.fi_322
  0x040c11a0, 0x286b0f04, 0x10170c0c, 0x16080602,   // ro.sv.fi_322 lv.ceb.sw_332  sv.sr.lt_543 de.no.hr_222
  // [85e0]
  0x1e1c2507, 0x530128ee, 0x1800122a, 0x02251f02,   // eu.id.ms_432 sw.en.ht_422  ur.ar.un_970 cy.eu.da_222
  0x0b0128a7, 0x3f002105, 0x0c00022a, 0x6b2804af,   // sw.en.es_532 jw.af.un_330  da.sv.un_970 fi.sw.ceb_655
  0x280f04ad, 0x21042855, 0x0f2804ad, 0x0e000a07,   // fi.lv.sw_643 sw.fi.jw_442  fi.sw.lv_643 pt.is.un_420
  0x03022d02, 0x060825a0, 0x1f002b05, 0x551a2804,   // sk.da.nl_222 eu.no.de_322  vi.cy.un_330 sw.tl.rw_332
  // [85f0]
  0x2a311e04, 0x271f2813, 0x3f045304, 0x0a0e1b0c,   // ms.az.mt_332 sw.cy.gd_665  ht.fi.af_332 tr.is.pt_543
  0x53040609, 0x0e116bac, 0x1b00642a, 0x08282aad,   // de.fi.ht_444 ceb.ro.is_632  lg.tr.un_970 mt.sw.no_643
  0x07172812, 0x1a006b11, 0x21132812, 0x0e041aa4,   // sw.sr.it_654 ceb.tl.un_630  sw.et.jw_654 tl.fi.is_433
  0x200417ad, 0x160e2a04, 0x020604a0, 0x0c000e2b,   // sr.fi.sq_643 mt.is.hr_332  fi.de.da_322 is.sv.un_980
  // [8600]
  0x180e1a0c, 0x212007a4, 0x176b25a4, 0x070b110c,   // tl.is.ga_543 it.sq.jw_433  eu.ceb.sr_433 ro.es.it_543
  0x02002013, 0x03060809, 0x0e006413, 0x08002009,   // sq.da.un_650 no.de.nl_444  lg.is.un_650 sq.no.un_440
  0x55171609, 0x1b311109, 0x1c0a2da0, 0x6412070c,   // hr.sr.rw_444 ro.az.tr_444  sk.pt.id_322 it.hu.lg_543
  0x20000b05, 0x1f1827a0, 0x2a010b02, 0x1f18270d,   // es.sq.un_330 gd.ga.cy_322  es.en.mt_222 gd.ga.cy_554
  // [8610]
  0x1a001208, 0x100b0704, 0x2a2827ee, 0x25062307,   // hu.tl.un_430 it.es.lt_332  gd.sw.mt_422 ca.de.eu_432
  0x11002520, 0x07001907, 0x0900030c, 0x03080613,   // eu.ro.un_850 gl.it.un_420  nl.pl.un_530 de.no.nl_665
  0x640e1a0c, 0x0306040d, 0x161a20a4, 0x0e211aa7,   // tl.is.lg_543 fi.de.nl_554  sq.tl.hr_433 tl.jw.is_532
  0x12192da0, 0x1e1c0b0c, 0x17215504, 0x105528a4,   // sk.gl.hu_322 es.id.ms_543  rw.jw.sr_332 sw.rw.lt_433
  // [8620]
  0x072855a4, 0x1b002a08, 0x09000707, 0x2a192507,   // rw.sw.it_433 mt.tr.un_430  it.pl.un_420 eu.gl.mt_432
  0x282b5355, 0x131e6402, 0x1b202aa4, 0x080e0407,   // ht.vi.sw_442 lg.ms.et_222  mt.sq.tr_433 fi.is.no_432
  0x231e1fa7, 0x08101755, 0x181927ad, 0x056b130c,   // cy.ms.ca_532 sr.be.uk_442  gd.gl.ga_643 et.ceb.fr_543
  0x23190b55, 0x641201a0, 0x061921ee, 0x202931ee,   // es.gl.ca_442 en.hu.lg_322  jw.gl.de_422 az.sl.sq_422
  // [8630]
  0x10110fad, 0x030109a0, 0x1a0b1807, 0x230a0555,   // lv.ro.lt_643 pl.en.nl_322  ga.es.tl_432 fr.pt.ca_442
  0x23200fa0, 0x2a082d04, 0x250d28a0, 0x07001809,   // lv.sq.ca_322 sk.no.mt_332  sw.cs.eu_322 ga.it.un_440
  0x182d0d09, 0x53000607, 0x0a2311a0, 0x0a00640e,   // cs.sk.ga_444 de.ht.un_420  ro.ca.pt_322 lg.pt.un_550
  0x31291f04, 0x210d12a4, 0x09002719, 0x02000108,   // cy.sl.az_332 hu.cs.jw_433  gd.pl.un_750 en.da.un_430
  // [8640]
  0x03063faf, 0x06050104, 0x290601a0, 0x070a0f07,   // af.de.nl_655 en.fr.de_332  en.de.sl_322 lv.pt.it_432
  0x550523ee, 0x29202daf, 0x100a0712, 0x271825a4,   // ca.fr.rw_422 sk.sq.sl_655  bg.mk.be_654 eu.ga.gd_433
  0x080102ee, 0x552a200b, 0x06033fee, 0x6b210aa0,   // da.en.no_422 sq.mt.rw_542  af.nl.de_422 pt.jw.ceb_322
  0x64000119, 0x531a6b60, 0x02006b04, 0x31000509,   // en.lg.un_750 ceb.tl.ht_664  ceb.da.un_320 fr.az.un_440
  // [8650]
  0x6b001a2a, 0x3f102855, 0x180107a4, 0x28102704,   // tl.ceb.un_970 sw.lt.af_442  it.en.ga_433 gd.lt.sw_332
  0x1c28010b, 0x0428100c, 0x6b531a13, 0x2d001b0e,   // en.sw.id_542 lt.sw.fi_543  tl.ht.ceb_665 tr.sk.un_550
  0x2800641a, 0x25002721, 0x1b6b1a11, 0x106429ad,   // lg.sw.un_760 gd.eu.un_860  tl.ceb.tr_653 sl.lg.lt_643
  0x215511a4, 0x0b002313, 0x13080404, 0x0e005511,   // ro.rw.jw_433 ca.es.un_650  fi.no.et_332 rw.is.un_630
  // [8660]
  0x10292502, 0x5500290e, 0x04170a0c, 0x1a00530e,   // eu.sl.lt_222 sl.rw.un_550  mk.sr.ru_543 ht.tl.un_550
  0x192d230b, 0x19050ba4, 0x280b29ee, 0x016b1a14,   // ca.sk.gl_542 es.fr.gl_433  sl.es.sw_422 tl.ceb.en_666
  0x0c1213ee, 0x536b1a0e, 0x070128a4, 0x1b5301af,   // et.hu.sv_422 tl.ceb.ht_555  sw.en.it_433 en.ht.tr_655
  0x016b1a0c, 0x1a536bec, 0x012b2aa0, 0x063f21a0,   // tl.ceb.en_543 ceb.ht.tl_644  mt.vi.en_322 jw.af.de_322
  // [8670]
  0x18131005, 0x0c530e07, 0x12011c04, 0x0c000702,   // lt.et.ga_333 is.ht.sv_432  id.en.hu_332 it.sv.un_220
  0x080210a0, 0x291204a4, 0x19001109, 0x20006405,   // lt.da.no_322 fi.hu.sl_433  ro.gl.un_440 lg.sq.un_330
  0x16002919, 0x020c29a4, 0x12250da0, 0x270c0ea0,   // sl.hr.un_750 sl.sv.da_433  cs.eu.hu_322 is.sv.gd_322
  0x06070da0, 0x0e000d1a, 0x252319a0, 0x21281fa4,   // cs.it.de_322 cs.is.un_760  gl.ca.eu_322 cy.sw.jw_433
  // [8680]
  0x181f27a0, 0x020c1605, 0x1b311aac, 0x211f23a0,   // gd.cy.ga_322 hr.sv.da_333  tl.az.tr_632 ca.cy.jw_322
  0x0a29120c, 0x2817165a, 0x2a2031ee, 0x0d5501a7,   // hu.sl.pt_543 hr.sr.sw_553  az.sq.mt_422 en.rw.cs_532
  0x09550107, 0x211218ee, 0x04000a1a, 0x06001204,   // en.rw.pl_432 ar.ur.fa_422  mk.ru.un_760 hu.de.un_320
  0x1123070c, 0x2a645504, 0x28641ea0, 0x0d2a100c,   // it.ca.ro_543 rw.lg.mt_332  ms.lg.sw_322 lt.mt.cs_543
  // [8690]
  0x25125305, 0x286b1a07, 0x10041207, 0x0f291702,   // ht.hu.eu_333 tl.ceb.sw_432  hu.fi.lt_432 sr.sl.lv_222
  0x290704a0, 0x2a640baf, 0x0f00060e, 0x08071105,   // fi.it.sl_322 es.lg.mt_655  de.lv.un_550 ro.bg.uk_333
  0x19641155, 0x0e0c2a0c, 0x0d002912, 0x016406a0,   // ro.lg.gl_442 mt.sv.is_543  sl.cs.un_640 de.lg.en_322
  0x3f010304, 0x0c031c07, 0x06012ba0, 0x1f002802,   // nl.en.af_332 id.nl.sv_432  vi.en.de_322 sw.cy.un_220
  // [86a0]
  0x07081112, 0x250853a9, 0x53100d04, 0x17111005,   // ro.uk.bg_654 ht.no.eu_544  cs.lt.ht_332 be.ro.sr_333
  0x096b1f04, 0x0e230ba0, 0x0e0c080c, 0x1a006b05,   // cy.ceb.pl_332 es.ca.is_322  no.sv.is_543 ceb.tl.un_330
  0x6b063f04, 0x3f080ca9, 0x170608a0, 0x2b000113,   // af.de.ceb_332 sv.no.af_544  no.de.sr_322 en.vi.un_650
  0x0d001a02, 0x070a11ad, 0x311b200c, 0x1820080e,   // tl.cs.un_220 ro.mk.bg_643  sq.tr.az_543 no.sq.ga_555
  // [86b0]
  0x101a6bac, 0x17292005, 0x21002b02, 0x2d002807,   // ceb.tl.lt_632 sq.sl.sr_333  vi.jw.un_220 sw.sk.un_420
  0x02080c08, 0x31002a1a, 0x08010260, 0x130c02ad,   // sv.no.da_443 mt.az.un_760  da.en.no_664 da.sv.et_643
  0x1600031a, 0x100f1107, 0x230255a0, 0x1a6b6408,   // nl.hr.un_760 ro.lv.lt_432  rw.da.ca_322 lg.ceb.tl_443
  0x0a1b3114, 0x0e002a0d, 0x17071904, 0x1b531ea0,   // az.tr.pt_666 mt.is.un_540  gl.it.sr_332 ms.ht.tr_322
  // [86c0]
  0x0a0710a6, 0x0b230f04, 0x05075305, 0x2a003129,   // be.bg.mk_521 lv.ca.es_332  ht.it.fr_333 az.mt.un_960
  0x2a00310c, 0x29090dad, 0x281807a4, 0x062a0804,   // az.mt.un_530 cs.pl.sl_643  it.ga.sw_433 no.mt.de_332
  0x0f1123a4, 0x010f6eee, 0x315564ee, 0x12001107,   // ca.ro.lv_433 blu.lv.en_422  lg.rw.az_422 ro.hu.un_420
  0x08072302, 0x0413280c, 0x23000536, 0x08002508,   // ca.it.no_222 sw.et.fi_543  fr.ca.un_AA0 eu.no.un_430
  // [86d0]
  0x100c11ad, 0x3f1f10ad, 0x211a6b5a, 0x18030607,   // ro.sv.lt_643 lt.cy.af_643  ceb.tl.jw_553 de.nl.ga_432
  0x29162da6, 0x05006e34, 0x23060512, 0x05002d04,   // sk.hr.sl_521 blu.fr.un_A80  fr.de.ca_654 sk.fr.un_320
  0x12211a07, 0x09000709, 0x040e13ec, 0x6e002314,   // tl.jw.hu_432 it.pl.un_440  et.is.fi_644 ca.blu.un_660
  0x061f0c07, 0x640855a4, 0x020155ee, 0x09072a08,   // sv.cy.de_432 rw.no.lg_433  rw.en.da_422 mt.it.pl_443
  // [86e0]
  0x6e000313, 0x6e00011a, 0x55051aa0, 0x3f31530c,   // nl.blu.un_650 en.blu.un_760  tl.fr.rw_322 ht.az.af_543
  0x021b050c, 0x532164ee, 0x1b005505, 0x0b2d2908,   // fr.tr.da_543 lg.jw.ht_422  rw.tr.un_330 sl.sk.es_443
  0x061e13a4, 0x0700010c, 0x53551c11, 0x3f0319a4,   // et.ms.de_433 en.it.un_530  id.rw.ht_653 gl.nl.af_433
  0x3f00211a, 0x3f6b01ad, 0x19056eec, 0x013f1302,   // jw.af.un_760 en.ceb.af_643  blu.fr.gl_644 et.af.en_222
  // [86f0]
  0x1a005502, 0x13002821, 0x03212a0c, 0x2728640d,   // rw.tl.un_220 sw.et.un_860  mt.jw.nl_543 lg.sw.gd_554
  0x0600551a, 0x182b6e07, 0x2b006e0b, 0x19211a04,   // rw.de.un_760 blu.vi.ga_432  blu.vi.un_520 tl.jw.gl_332
  0x0e081304, 0x06002a09, 0x3f0e07ad, 0x3f0f0804,   // et.no.is_332 mt.de.un_440  it.is.af_643 no.lv.af_332
  0x0206550d, 0x2d0703a7, 0x23001f1a, 0x020d0808,   // rw.de.da_554 nl.it.sk_532  cy.ca.un_760 no.cs.da_443
  // [8700]
  0x231f1113, 0x02000d05, 0x556413a4, 0x2d0d0214,   // ro.cy.ca_665 cs.da.un_330  et.lg.rw_433 da.cs.sk_666
  0x041013a0, 0x01053f07, 0x1f2718a0, 0x64045512,   // et.lt.fi_322 af.fr.en_432  ga.gd.cy_322 rw.fi.lg_654
  0x642928ee, 0x550425a7, 0x1b64130c, 0x3f03275a,   // sw.sl.lg_422 eu.fi.rw_532  et.lg.tr_543 gd.nl.af_553
  0x0600230d, 0x29080eac, 0x6b060cec, 0x64002814,   // ca.de.un_540 is.no.sl_632  sv.de.ceb_644 sw.lg.un_660
  // [8710]
  0x0e1008a4, 0x162d1109, 0x08070e05, 0x3f2b0107,   // no.lt.is_433 ro.sk.hr_444  is.it.no_333 en.vi.af_432
  0x07080212, 0x08121b0c, 0x0c3f1f07, 0x06041bac,   // da.no.it_654 tr.hu.no_543  cy.af.sv_432 tr.fi.de_632
  0x21083f07, 0x2d003f09, 0x100b19a4, 0x20000608,   // af.no.jw_432 af.sk.un_440  gl.es.lt_433 de.sq.un_430
  0x211b13ad, 0x2d29130c, 0x04131009, 0x10110705,   // et.tr.jw_643 et.sl.sk_543  lt.et.fi_444 bg.ro.be_333
  // [8720]
  0x130c2a0c, 0x17001312, 0x04133104, 0x201801af,   // mt.sv.et_543 et.sr.un_640  az.et.fi_332 en.ga.sq_655
  0x55640c02, 0x061f08a4, 0x08033f08, 0x230b0a05,   // sv.lg.rw_222 no.cy.de_433  af.nl.no_443 pt.es.ca_333
  0x1c132ab3, 0x55280a0d, 0x1f3f2aee, 0x21000a04,   // mt.et.id_743 pt.sw.rw_554  mt.af.cy_422 pt.jw.un_320
  0x130f3f5a, 0x111b5304, 0x231b1355, 0x64001607,   // af.lv.et_553 ht.tr.ro_332  et.tr.ca_442 hr.lg.un_420
  // [8730]
  0x18002509, 0x1153160c, 0x1b2a0807, 0x6e536b02,   // eu.ga.un_440 hr.ht.ro_543  no.mt.tr_432 ceb.ht.blu_222
  0x02070807, 0x53001214, 0x072a1f07, 0x052a1104,   // no.it.da_432 hu.ht.un_660  cy.mt.it_432 ro.mt.fr_332
  0x10120b0e, 0x0600081a, 0x05082aa0, 0x0f291602,   // es.hu.lt_555 no.de.un_760  mt.no.fr_322 hr.sl.lv_222
  0x0c3f2a07, 0x20100f09, 0x18190a02, 0x6b0f030c,   // mt.af.sv_432 lv.lt.sq_444  pt.gl.ga_222 nl.lv.ceb_543
  // [8740]
  0x111b310c, 0x170412ad, 0x281a2aa0, 0x1b002908,   // az.tr.ro_543 hu.fi.sr_643  mt.tl.sw_322 sl.tr.un_430
  0x1828090c, 0x0f2a09a0, 0x170a0411, 0x6e6b5307,   // pl.sw.ga_543 pl.mt.lv_322  ru.mk.sr_653 ht.ceb.blu_432
  0x2d181107, 0x012a0505, 0x012a07ad, 0x3f020eaf,   // ro.ga.sk_432 fr.mt.en_333  it.mt.en_643 is.da.af_655
  0x051118ee, 0x2b192302, 0x291b0bee, 0x31091ba4,   // ga.ro.fr_422 ca.gl.vi_222  es.tr.sl_422 tr.pl.az_433
  // [8750]
  0x2a3107a0, 0x0c020e02, 0x64012704, 0x2d1129a0,   // it.az.mt_322 is.da.sv_222  gd.en.lg_332 sl.ro.sk_322
  0x0a110fa0, 0x530c08a0, 0x23072da4, 0x292d090c,   // lv.ro.pt_322 no.sv.ht_322  sk.it.ca_433 pl.sk.sl_543
  0x23182704, 0x291801ee, 0x10020caf, 0x2a001709,   // gd.ga.ca_332 en.ga.sl_422  sv.da.lt_655 sr.mt.un_440
  0x070811ad, 0x06002809, 0x0300040c, 0x180c0204,   // ro.uk.bg_643 sw.de.un_440  fi.nl.un_530 da.sv.ga_332
  // [8760]
  0x210328ee, 0x06122705, 0x08060c04, 0x06052307,   // sw.nl.jw_422 gd.hu.de_333  sv.de.no_332 ca.fr.de_432
  0x3f0806a4, 0x1c002508, 0x6412130b, 0x01080fa0,   // de.no.af_433 eu.id.un_430  et.hu.lg_542 lv.no.en_322
  0x101117af, 0x55296404, 0x3f0803ec, 0x552864ad,   // sr.ro.be_655 lg.sl.rw_332  nl.no.af_644 lg.sw.rw_643
  0x211c1f0c, 0x07645505, 0x031125ec, 0x081707a4,   // cy.id.jw_543 rw.lg.it_333  eu.ro.nl_644 bg.sr.uk_433
  // [8770]
  0x250601a4, 0x21006b02, 0x16000608, 0x2713120b,   // en.de.eu_433 ceb.jw.un_220  de.hr.un_430 hu.et.gd_542
  0x031617ee, 0x1e1b2107, 0x061a6ba0, 0x1a6b55ee,   // sr.hr.nl_422 jw.tr.ms_432  ceb.tl.de_322 rw.ceb.tl_422
  0x3f55640b, 0x0b0a29a0, 0x3f5528a4, 0x550f25ee,   // lg.rw.af_542 sl.pt.es_322  sw.rw.af_433 eu.lv.rw_422
  0x02092ba0, 0x641a550c, 0x531610a0, 0x1b172907,   // vi.pl.da_322 rw.tl.lg_543  lt.hr.ht_322 sl.sr.tr_432
  // [8780]
  0x3f001b0d, 0x281f5507, 0x191f0aaf, 0x122025a4,   // tr.af.un_540 rw.cy.sw_432  pt.cy.gl_655 eu.sq.hu_433
  0x2517160c, 0x01063fa4, 0x23002802, 0x0e53040c,   // hr.sr.eu_543 af.de.en_433  sw.ca.un_220 fi.ht.is_543
  0x08111008, 0x531e1c12, 0x106b1aad, 0x16001b0c,   // be.ro.uk_443 id.ms.ht_654  tl.ceb.lt_643 tr.hr.un_530
  0x13640e09, 0x0408115a, 0x09002d12, 0x13023f04,   // is.lg.et_444 ro.uk.ru_553  sk.pl.un_640 af.da.et_332
  // [8790]
  0x07041112, 0x0655645a, 0x0e000819, 0x643f03a4,   // ro.ru.bg_654 lg.rw.de_553  no.is.un_750 nl.af.lg_433
  0x063f0207, 0x0c000e1b, 0x64551f55, 0x0c130ea4,   // da.af.de_432 is.sv.un_770  cy.rw.lg_442 is.et.sv_433
  0x53230aa4, 0x3f1003a4, 0x251a6b07, 0x3f042aad,   // pt.ca.ht_433 nl.lt.af_433  ceb.tl.eu_432 mt.fi.af_643
  0x0c080404, 0x020104a0, 0x27033f07, 0x10003f0d,   // fi.no.sv_332 fi.en.da_322  af.nl.gd_432 af.lt.un_540
  // [87a0]
  0x291a010c, 0x13013f07, 0x062704af, 0x13291709,   // en.tl.sl_543 af.en.et_432  fi.gd.de_655 sr.sl.et_444
  0x1310640b, 0x122a040b, 0x04072a13, 0x060364a0,   // lg.lt.et_542 fi.mt.hu_542  mt.it.fi_665 lg.nl.de_322
  0x2d001607, 0x03000611, 0x0e6455ad, 0x21002809,   // hr.sk.un_420 de.nl.un_630  rw.lg.is_643 sw.jw.un_440
  0x02050707, 0x173f0307, 0x1f1018ee, 0x13001b18,   // it.fr.da_432 nl.af.sr_432  ga.lt.cy_422 tr.et.un_740
  // [87b0]
  0x170102ee, 0x0e000418, 0x0a0804a9, 0x042a12a4,   // da.en.sr_422 fi.is.un_740  ru.uk.mk_544 hu.mt.fi_433
  0x1f001004, 0x233125a0, 0x3100230d, 0x1c0c02a0,   // lt.cy.un_320 eu.az.ca_322  ca.az.un_540 da.sv.id_322
  0x0b072508, 0x2700110c, 0x08022805, 0x531625a0,   // eu.it.es_443 ro.gd.un_530  sw.da.no_333 eu.hr.ht_322
  0x1628090b, 0x2700110e, 0x292d1608, 0x2d002704,   // pl.sw.hr_542 ro.gd.un_550  hr.sk.sl_443 gd.sk.un_320
  // [87c0]
  0x1004110c, 0x0a00040c, 0x1f0912ad, 0x041825a0,   // ro.ru.be_543 fi.pt.un_530  hu.pl.cy_643 eu.ga.fi_322
  0x115309ee, 0x3f070fa4, 0x13001817, 0x55006b04,   // pl.ht.ro_422 lv.it.af_433  ga.et.un_730 ceb.rw.un_320
  0x2a311b05, 0x1a126bee, 0x0802250c, 0x20116e08,   // tr.az.mt_333 ceb.hu.tl_422  eu.da.no_543 blu.ro.sq_443
  0x0d1719a0, 0x180d01ee, 0x201710a0, 0x1a122da0,   // gl.sr.cs_322 en.cs.ga_422  lt.sr.sq_322 sk.hu.tl_322
  // [87d0]
  0x2d1b11ad, 0x18081205, 0x0f0709ee, 0x13040c02,   // ro.tr.sk_643 hu.no.ga_333  pl.it.lv_422 sv.fi.et_222
  0x311b04ac, 0x0f5304ee, 0x080106ee, 0x03311baf,   // fi.tr.az_632 fi.ht.lv_422  de.en.no_422 tr.az.nl_655
  0x0c3f13a0, 0x0e2a0707, 0x010508a7, 0x01072aee,   // et.af.sv_322 it.mt.is_432  no.fr.en_532 mt.it.en_422
  0x17000809, 0x0f00201a, 0x29040ca0, 0x2a001805,   // uk.sr.un_440 sq.lv.un_760  sv.fi.sl_322 ga.mt.un_330
  // [87e0]
  0x0c2917af, 0x3f130404, 0x02130c04, 0x03081b07,   // sr.sl.sv_655 fi.et.af_332  sv.et.da_332 tr.no.nl_432
  0x3f0c0308, 0x08025302, 0x1b2a13a4, 0x020e0ca0,   // nl.sv.af_443 ht.da.no_222  et.mt.tr_433 sv.is.da_322
  0x2a000c02, 0x0e00100c, 0x2d0d2302, 0x641055a4,   // sv.mt.un_220 lt.is.un_530  ca.cs.sk_222 rw.lt.lg_433
  0x291a21af, 0x1a1031ad, 0x5553310b, 0x0f080cee,   // jw.tl.sl_655 az.lt.tl_643  az.ht.rw_542 sv.no.lv_422
  // [87f0]
  0x641b53a4, 0x0c0f02a0, 0x55001a0e, 0x1a645505,   // ht.tr.lg_433 da.lv.sv_322  tl.rw.un_550 rw.lg.tl_333
  0x286425a0, 0x086455af, 0x250c2aac, 0x27011ba6,   // eu.lg.sw_322 rw.lg.no_655  mt.sv.eu_632 tr.en.gd_521
  0x532555a9, 0x2a10550d, 0x060c0e12, 0x55232855,   // rw.eu.ht_544 rw.lt.mt_554  is.sv.de_654 sw.ca.rw_442
  0x531b55ad, 0x080c0e5a, 0x6400282a, 0x1e002908,   // rw.tr.ht_643 is.sv.no_553  sw.lg.un_970 sl.ms.un_430

  // [8800]
  0x53310804, 0x0200052b, 0x1a5564af, 0x29280ea0,   // no.az.ht_332 fr.da.un_980  lg.rw.tl_655 is.sw.sl_322
  0x64535513, 0x55640804, 0x25001302, 0x53000705,   // rw.ht.lg_665 no.lg.rw_332  et.eu.un_220 it.ht.un_330
  0x2a006b13, 0x041305af, 0x2d090dec, 0x0700640b,   // ceb.mt.un_650 fr.et.fi_655  cs.pl.sk_644 lg.it.un_520
  0x18011a04, 0x1c053f11, 0x2d0d28a4, 0x11532912,   // tl.en.ga_332 af.fr.id_653  sw.cs.sk_433 sl.ht.ro_654
  // [8810]
  0x083f0212, 0x0600250e, 0x25050a07, 0x2a3f2802,   // da.af.no_654 eu.de.un_550  pt.fr.eu_432 sw.af.mt_222
  0x052a07a4, 0x6b0c0812, 0x08040a0c, 0x3f0308ee,   // it.mt.fr_433 no.sv.ceb_654  mk.ru.uk_543 no.nl.af_422
  0x04290da0, 0x04130508, 0x28552104, 0x25002a02,   // cs.sl.fi_322 fr.et.fi_443  jw.rw.sw_332 mt.eu.un_220
  0x3f1f0212, 0x10250607, 0x02030e04, 0x01000f0b,   // da.cy.af_654 de.eu.lt_432  is.nl.da_332 lv.en.un_520
  // [8820]
  0x1e271ca0, 0x0b04100c, 0x53191fa7, 0x6418270c,   // id.gd.ms_322 lt.fi.es_543  cy.gl.ht_532 gd.ga.lg_543
  0x0a101108, 0x1b6b1a08, 0x2b000702, 0x1e1c5502,   // ro.be.mk_443 tl.ceb.tr_443  it.vi.un_220 rw.id.ms_222
  0x1b53210c, 0x21033fad, 0x100f25a7, 0x040e0809,   // jw.ht.tr_543 af.nl.jw_643  eu.lv.lt_532 no.is.fi_444
  0x3f030813, 0x01000f07, 0x3f020302, 0x0a1223ee,   // no.nl.af_665 lv.en.un_420  nl.da.af_222 ca.hu.pt_422
  // [8830]
  0x25181ea4, 0x1a095504, 0x03001807, 0x131c090c,   // ms.ga.eu_433 rw.pl.tl_332  ga.nl.un_420 hi.mr.bh_543
  0x531b5504, 0x1a556b08, 0x551a09a0, 0x536b1a05,   // rw.tr.ht_332 ceb.rw.tl_443  pl.tl.rw_322 tl.ceb.ht_333
  0x160c13ad, 0x13042da9, 0x211c3fa0, 0x6b190a04,   // et.sv.hr_643 sk.fi.et_544  af.id.jw_322 pt.gl.ceb_332
  0x111f180c, 0x031706ee, 0x13080ca7, 0x07002519,   // ga.cy.ro_543 de.sr.nl_422  sv.no.et_532 eu.it.un_750
  // [8840]
  0x23001b02, 0x0b112d07, 0x1f001908, 0x23251fec,   // tr.ca.un_220 sk.ro.es_432  gl.cy.un_430 cy.eu.ca_644
  0x16292dee, 0x13003f11, 0x0c2d0d05, 0x55000a02,   // sk.sl.hr_422 af.et.un_630  cs.sk.sv_333 pt.rw.un_220
  0x1f005308, 0x0f041013, 0x2a645302, 0x00001b2d,   // ht.cy.un_430 lt.fi.lv_665  ht.lg.mt_222 tr.un.un_A00
  0x53010604, 0x531f020e, 0x53190a5a, 0x08072a0c,   // de.en.ht_332 da.cy.ht_555  pt.gl.ht_553 mt.it.no_543
  // [8850]
  0x192053ee, 0x0f001113, 0x012508a0, 0x1c1e1b0c,   // ht.sq.gl_422 ro.lv.un_650  no.eu.en_322 tr.ms.id_543
  0x2a160907, 0x2a0a19ee, 0x0f041305, 0x08000e08,   // pl.hr.mt_432 gl.pt.mt_422  et.fi.lv_333 is.no.un_430
  0x0a6455a9, 0x1b21070c, 0x10040a07, 0x3f2864a0,   // rw.lg.pt_544 it.jw.tr_543  pt.fi.lt_432 lg.sw.af_322
  0x0f1004a4, 0x060e08ec, 0x20002307, 0x273f0e04,   // fi.lt.lv_433 no.is.de_644  ca.sq.un_420 is.af.gd_332
  // [8860]
  0x1b00641a, 0x203f0107, 0x130f04a6, 0x3f2103a6,   // lg.tr.un_760 en.af.sq_432  fi.lv.et_521 nl.jw.af_521
  0x0f1b0504, 0x2d132905, 0x0e102902, 0x210a0607,   // fr.tr.lv_332 sl.et.sk_333  sl.lt.is_222 de.pt.jw_432
  0x06003f21, 0x1a102109, 0x11171613, 0x0e2708a7,   // af.de.un_860 jw.lt.tl_444  hr.sr.ro_665 no.gd.is_532
  0x0602080b, 0x1b001a02, 0x02000f0e, 0x071b010c,   // no.da.de_542 tl.tr.un_220  lv.da.un_550 en.tr.it_543
  // [8870]
  0x1f0b1e07, 0x08210c07, 0x250b1b08, 0x06020c05,   // ms.es.cy_432 sv.jw.no_432  tr.es.eu_443 sv.da.de_333
  0x192301a0, 0x0c2b55a0, 0x02011105, 0x080c03af,   // en.ca.gl_322 rw.vi.sv_322  ro.en.da_333 nl.sv.no_655
  0x21090dad, 0x29001309, 0x08292daf, 0x08033f05,   // cs.pl.jw_643 et.sl.un_440  sk.sl.no_655 af.nl.no_333
  0x1308020d, 0x3f000502, 0x1e080404, 0x0e0213a0,   // da.no.et_554 fr.af.un_220  fi.no.ms_332 et.da.is_322
  // [8880]
  0x6b2b0404, 0x0c010207, 0x130928a0, 0x016b2dee,   // fi.vi.ceb_332 da.en.sv_432  sw.pl.et_322 sk.ceb.en_422
  0x1f641307, 0x2b002a07, 0x12023fa6, 0x2513640c,   // et.lg.cy_432 mt.vi.un_420  af.da.hu_521 lg.et.eu_543
  0x27001818, 0x100811a0, 0x0a081714, 0x1f000e05,   // ga.gd.un_740 ro.uk.be_322  sr.uk.mk_666 is.cy.un_330
  0x3f0413a4, 0x1b043fa0, 0x0e0203a7, 0x0e000a02,   // et.fi.af_433 af.fi.tr_322  nl.da.is_532 pt.is.un_220
  // [8890]
  0x080b27ee, 0x21041c02, 0x2925130c, 0x041f01a4,   // gd.es.no_422 id.fi.jw_222  et.eu.sl_543 en.cy.fi_433
  0x64001a0d, 0x0e001802, 0x28001e1a, 0x21641c0c,   // tl.lg.un_540 ga.is.un_220  ms.sw.un_760 id.lg.jw_543
  0x292364a0, 0x181320a7, 0x0f0613a4, 0x1000210d,   // lg.ca.sl_322 sq.et.ga_532  et.de.lv_433 jw.lt.un_540
  0x64001c0d, 0x180527a0, 0x17100aa9, 0x1c1a6b08,   // id.lg.un_540 gd.fr.ga_322  mk.be.sr_544 ceb.tl.id_443
  // [88a0]
  0x0c0712ee, 0x1827280c, 0x08641aa7, 0x1e25060d,   // hu.it.sv_422 sw.gd.ga_543  tl.lg.no_532 de.eu.ms_554
  0x11001033, 0x19000b22, 0x252a0714, 0x020e0808,   // be.ro.un_A70 es.gl.un_870  it.mt.eu_666 no.is.da_443
  0x08002a13, 0x6b0221ee, 0x0d000f07, 0x130c12a0,   // mt.no.un_650 jw.da.ceb_422  lv.cs.un_420 hu.sv.et_322
  0x1300110d, 0x1b003f04, 0x110a0805, 0x16202ba7,   // ro.et.un_540 af.tr.un_320  uk.mk.ro_333 vi.sq.hr_532
  // [88b0]
  0x060c0708, 0x21000f1b, 0x21121a0c, 0x6b1f0708,   // it.sv.de_443 lv.jw.un_770  tl.hu.jw_543 it.cy.ceb_443
  0x16130e0c, 0x043113ec, 0x21121804, 0x20002807,   // is.et.hr_543 et.az.fi_644  ar.ur.fa_332 sw.sq.un_420
  0x021f64a4, 0x08040a09, 0x012d02a0, 0x1a130111,   // lg.cy.da_433 mk.ru.uk_444  da.sk.en_322 en.et.tl_653
  0x312925a4, 0x530413a0, 0x2a011fec, 0x090e0802,   // eu.sl.az_433 et.fi.ht_322  cy.en.mt_644 no.is.pl_222
  // [88c0]
  0x170810a9, 0x6428555a, 0x06093fad, 0x062a0304,   // be.uk.sr_544 rw.sw.lg_553  af.pl.de_643 nl.mt.de_332
  0x06006421, 0x64553fec, 0x102d09a6, 0x645503ee,   // lg.de.un_860 af.rw.lg_644  pl.sk.lt_521 nl.rw.lg_422
  0x04001318, 0x13002b17, 0x130453a0, 0x551805a4,   // et.fi.un_740 vi.et.un_730  ht.fi.et_322 fr.ga.rw_433
  0x13000112, 0x1f001c1a, 0x1909125a, 0x16002702,   // en.et.un_640 id.cy.un_760  hu.pl.gl_553 gd.hr.un_220
  // [88d0]
  0x0f000408, 0x250612ad, 0x27002805, 0x21006413,   // fi.lv.un_430 hu.de.eu_643  sw.gd.un_330 lg.jw.un_650
  0x026b0ca0, 0x0a110414, 0x13006407, 0x0a081014,   // sv.ceb.da_322 ru.ro.mk_666  lg.et.un_420 be.uk.mk_666
  0x640f28a4, 0x09002a19, 0x0c060204, 0x060401af,   // sw.lv.lg_433 mt.pl.un_750  da.de.sv_332 en.fi.de_655
  0x0c0810ee, 0x06080408, 0x190a18a7, 0x06130c04,   // lt.no.sv_422 fi.no.de_443  ga.pt.gl_532 sv.et.de_332
  // [88e0]
  0x041012ec, 0x1c640407, 0x06002b02, 0x042a08ec,   // hu.lt.fi_644 fi.lg.id_432  vi.de.un_220 no.mt.fi_644
  0x53000b08, 0x06070808, 0x0d292da0, 0x090c0da7,   // es.ht.un_430 no.it.de_443  sk.sl.cs_322 cs.sv.pl_532
  0x0c0501ee, 0x02002805, 0x100a0804, 0x2a000307,   // en.fr.sv_422 sw.da.un_330  uk.mk.be_332 nl.mt.un_420
  0x2b001213, 0x0a0119a6, 0x2a030604, 0x08042aaf,   // hu.vi.un_650 gl.en.pt_521  de.nl.mt_332 mt.fi.no_655
  // [88f0]
  0x080407ec, 0x02281aa0, 0x1c0a1e0c, 0x2312050c,   // it.fi.no_644 tl.sw.da_322  ms.pt.id_543 fr.hu.ca_543
  0x27171604, 0x025510a0, 0x3f0e6bee, 0x0b2718a7,   // hr.sr.gd_332 lt.rw.da_322  ceb.is.af_422 ga.gd.es_532
  0x11052307, 0x1e121c0c, 0x0b251fa9, 0x0f101ea4,   // ca.fr.ro_432 id.hu.ms_543  cy.eu.es_544 ms.lt.lv_433
  0x2d232707, 0x6b250107, 0x27190a02, 0x07100813,   // gd.ca.sk_432 en.eu.ceb_432  pt.gl.gd_222 uk.be.bg_665
  // [8900]
  0x2a2801a0, 0x21001904, 0x27001a08, 0x182701a7,   // en.sw.mt_322 gl.jw.un_320  tl.gd.un_430 en.gd.ga_532
  0x19120b12, 0x070b19ee, 0x1200080e, 0x211a010c,   // es.hu.gl_654 gl.es.it_422  no.hu.un_550 en.tl.jw_543
  0x180a12ee, 0x5518270c, 0x101e1cec, 0x0b0107a0,   // hu.pt.ga_422 gd.ga.rw_543  id.ms.lt_644 it.en.es_322
  0x1c002704, 0x55121f12, 0x17296e07, 0x03061ca0,   // gd.id.un_320 cy.hu.rw_654  blu.sl.sr_432 id.de.nl_322
  // [8910]
  0x1e1f0fa0, 0x09110a0c, 0x0d0c02a0, 0x160625a7,   // lv.cy.ms_322 pt.ro.pl_543  da.sv.cs_322 eu.de.hr_532
  0x05230b02, 0x25011fee, 0x0b001229, 0x230501a9,   // es.ca.fr_222 cy.en.eu_422  hu.es.un_960 en.fr.ca_544
  0x1121070c, 0x07002b05, 0x01051905, 0x110e13ee,   // it.jw.ro_543 vi.it.un_330  gl.fr.en_333 et.is.ro_422
  0x180b120c, 0x10110155, 0x07552807, 0x080419ee,   // hu.es.ga_543 en.ro.lt_442  sw.rw.it_432 gl.fi.no_422
  // [8920]
  0x120e0555, 0x1b12030c, 0x07253fad, 0x13060405,   // fr.is.hu_442 nl.hu.tr_543  af.eu.it_643 fi.de.et_333
  0x2a00080d, 0x251321ad, 0x3100010d, 0x10162107,   // no.mt.un_540 jw.et.eu_643  en.az.un_540 jw.hr.lt_432
  0x0f0108ee, 0x04000d12, 0x20002d07, 0x13002112,   // no.en.lv_422 cs.fi.un_640  sk.sq.un_420 jw.et.un_640
  0x08000d02, 0x110f1307, 0x212513af, 0x230c10a0,   // cs.no.un_220 et.lv.ro_432  et.eu.jw_655 lt.sv.ca_322
  // [8930]
  0x020c010c, 0x012007ee, 0x0700051b, 0x053f1907,   // en.sv.da_543 it.sq.en_422  fr.it.un_770 gl.af.fr_432
  0x17281b07, 0x09110608, 0x1205310c, 0x09200f0c,   // tr.sw.sr_432 de.ro.pl_443  az.fr.hu_543 lv.sq.pl_543
  0x120704ad, 0x1b1028a0, 0x55001308, 0x29041907,   // fi.it.hu_643 sw.lt.tr_322  et.rw.un_430 gl.fi.sl_432
  0x20132112, 0x25002109, 0x0805010c, 0x010d19ee,   // jw.et.sq_654 jw.eu.un_440  en.fr.no_543 gl.cs.en_422
  // [8940]
  0x1c6406ee, 0x0e0f1fa7, 0x21061fec, 0x05531905,   // de.lg.id_422 cy.lv.is_532  cy.de.jw_644 gl.ht.fr_333
  0x0c0603ee, 0x0a112004, 0x170807ec, 0x10002112,   // nl.de.sv_422 sq.ro.pt_332  bg.uk.sr_644 jw.lt.un_640
  0x041021a0, 0x06001e07, 0x042d280c, 0x641b2811,   // jw.lt.fi_322 ms.de.un_420  sw.sk.fi_543 sw.tr.lg_653
  0x16281ba0, 0x202528a7, 0x101b18a0, 0x28002a0e,   // tr.sw.hr_322 sw.eu.sq_532  ga.tr.lt_322 mt.sw.un_550
  // [8950]
  0x2a645507, 0x642155ad, 0x1c0621ec, 0x17160c05,   // rw.lg.mt_432 rw.jw.lg_643  jw.de.id_644 sv.hr.sr_333
  0x551a28a0, 0x28001e22, 0x1f112708, 0x0b311ba4,   // sw.tl.rw_322 ms.sw.un_870  gd.ro.cy_443 tr.az.es_433
  0x55281ca0, 0x55000502, 0x25281ca4, 0x13001221,   // id.sw.rw_322 fr.rw.un_220  id.sw.eu_433 hu.et.un_860
  0x29061b04, 0x1a281ead, 0x1b0553a7, 0x02121ba0,   // tr.de.sl_332 ms.sw.tl_643  ht.fr.tr_532 tr.hu.da_322
  // [8960]
  0x290553a0, 0x171b10a0, 0x0400010d, 0x17001e04,   // ht.fr.sl_322 lt.tr.sr_322  en.fi.un_540 ms.sr.un_320
  0x18081fa6, 0x310d1ba4, 0x05001221, 0x04000723,   // cy.no.ga_521 tr.cs.az_433  hu.fr.un_860 bg.ru.un_880
  0x53310504, 0x05005314, 0x08100aa9, 0x290e2da4,   // fr.az.ht_332 ht.fr.un_660  mk.be.uk_544 sk.is.sl_433
  0x2d0d19a9, 0x190b07a9, 0x12051908, 0x0c0b6ea0,   // gl.cs.sk_544 it.es.gl_544  gl.fr.hu_443 blu.es.sv_322
  // [8970]
  0x0500530b, 0x11040808, 0x1b160d12, 0x0b0512ad,   // ht.fr.un_520 uk.ru.ro_443  cs.hr.tr_654 hu.fr.es_643
  0x1e1621a0, 0x230a05a0, 0x23120511, 0x0a006e0d,   // jw.hr.ms_322 fr.pt.ca_322  fr.hu.ca_653 blu.pt.un_540
  0x080b0aad, 0x3f1303a0, 0x230b0555, 0x0e006b12,   // pt.es.no_643 nl.et.af_322  fr.es.ca_442 ceb.is.un_640
  0x3f190a08, 0x082d02ee, 0x05190a04, 0x0500122c,   // pt.gl.af_443 da.sk.no_422  pt.gl.fr_332 hu.fr.un_990
  // [8980]
  0x07080aa9, 0x02006e07, 0x1205230c, 0x03050111,   // mk.uk.bg_544 blu.da.un_420  ca.fr.hu_543 en.fr.nl_653
  0x0b0a6e5a, 0x0b2306ee, 0x05001220, 0x0a0411a6,   // blu.pt.es_553 de.ca.es_422  hu.fr.un_850 ro.ru.mk_521
  0x532a070d, 0x17002808, 0x20072a08, 0x640a19af,   // it.mt.ht_554 sw.sr.un_430  mt.it.sq_443 gl.pt.lg_655
  0x10040811, 0x13070e07, 0x03013f08, 0x1e1c0a0c,   // uk.ru.be_653 is.it.et_432  af.en.nl_443 pt.id.ms_543
  // [8990]
  0x171613a6, 0x1a006b20, 0x21030605, 0x0c0203ee,   // et.hr.sr_521 ceb.tl.un_850  de.nl.jw_333 nl.da.sv_422
  0x55001c04, 0x0a1708a7, 0x281b2507, 0x0c0803ee,   // id.rw.un_320 uk.sr.mk_532  eu.tr.sw_432 nl.no.sv_422
  0x55253104, 0x29080207, 0x136b0fee, 0x6425550d,   // az.eu.rw_332 da.no.sl_432  lv.ceb.et_422 rw.eu.lg_554
  0x021601a0, 0x19080e0c, 0x072305a0, 0x2909230c,   // en.hr.da_322 is.no.gl_543  fr.ca.it_322 ca.pl.sl_543
  // [89a0]
  0x640655ee, 0x0d2a070b, 0x5500251a, 0x0f552a11,   // rw.de.lg_422 it.mt.cs_542  eu.rw.un_760 mt.rw.lv_653
  0x28001721, 0x1a1b1ea0, 0x531028a0, 0x281213a7,   // sr.sw.un_860 ms.tr.tl_322  sw.lt.ht_322 et.hu.sw_532
  0x0a2523af, 0x211a11af, 0x08023fa0, 0x3f092d07,   // ca.eu.pt_655 ro.tl.jw_655  af.da.no_322 sk.pl.af_432
  0x25000f04, 0x2d3f09af, 0x20112904, 0x101711ee,   // lv.eu.un_320 pl.af.sk_655  sl.ro.sq_332 ro.sr.be_422
  // [89b0]
  0x012506a0, 0x043f0904, 0x6b023fee, 0x2b0b3f5a,   // de.eu.en_322 pl.af.fi_332  af.da.ceb_422 af.es.vi_553
  0x0e002d0d, 0x06003f19, 0x0b3f09a4, 0x11100860,   // sk.is.un_540 af.de.un_750  pl.af.es_433 uk.be.ro_664
  0x16001a0c, 0x0f000904, 0x080c1212, 0x0f000912,   // tl.hr.un_530 pl.lv.un_320  hu.sv.no_654 pl.lv.un_640
  0x0a10080c, 0x0a001219, 0x030f0408, 0x03060913,   // uk.be.mk_543 hu.pt.un_750  fi.lv.nl_443 pl.de.nl_665
  // [89c0]
  0x033f0f08, 0x552916a4, 0x010c3f07, 0x090f3fa4,   // lv.af.nl_443 hr.sl.rw_433  af.sv.en_432 af.lv.pl_433
  0x04170aa7, 0x08170711, 0x2500050e, 0x04000c05,   // mk.sr.ru_532 bg.sr.uk_653  fr.eu.un_550 sv.fi.un_330
  0x53000c02, 0x0407530c, 0x0e0c08ec, 0x16001119,   // sv.ht.un_220 ht.it.fi_543  no.sv.is_644 ro.hr.un_750
  0x012521ad, 0x01070607, 0x1f003f0d, 0x011e1fa0,   // jw.eu.en_643 de.it.en_432  af.cy.un_540 cy.ms.en_322
  // [89d0]
  0x040213a4, 0x25181fa0, 0x100c0814, 0x2a0e64ad,   // et.da.fi_433 cy.ga.eu_322  no.sv.lt_666 lg.is.mt_643
  0x1f6b01ec, 0x026408ee, 0x010f6402, 0x2700230e,   // en.ceb.cy_644 no.lg.da_422  lg.lv.en_222 ca.gd.un_550
  0x07003f14, 0x055307ee, 0x190a12a9, 0x041927a9,   // af.it.un_660 it.ht.fr_422  hu.pt.gl_544 gd.gl.fi_544
  0x1b2a6412, 0x0500191a, 0x12190a13, 0x530421a4,   // lg.mt.tr_654 gl.fr.un_760  pt.gl.hu_665 jw.fi.ht_433
  // [89e0]
  0x21000508, 0x131b10ee, 0x08201908, 0x101a01ee,   // fr.jw.un_430 lt.tr.et_422  gl.sq.no_443 en.tl.lt_422
  0x060501af, 0x100e01a0, 0x130a19a0, 0x2013040d,   // en.fr.de_655 en.is.lt_322  gl.pt.et_322 fi.et.sq_554
  0x2a1716a7, 0x125564a9, 0x1a6b3f12, 0x0d006e09,   // hr.sr.mt_532 lg.rw.hu_544  af.ceb.tl_654 blu.cs.un_440
  0x551310a7, 0x2b002904, 0x130a05a4, 0x1905010c,   // lt.et.rw_532 sl.vi.un_320  fr.pt.et_433 en.fr.gl_543
  // [89f0]
  0x64556ba9, 0x17000504, 0x28111207, 0x0e0c04ad,   // ceb.rw.lg_544 fr.sr.un_320  hu.ro.sw_432 fi.sv.is_643
  0x1b310e0c, 0x31010ca9, 0x19250b0c, 0x1c000412,   // is.az.tr_543 sv.en.az_544  es.eu.gl_543 fi.id.un_640
  0x041319ac, 0x0e08010c, 0x17040aad, 0x1000010d,   // gl.et.fi_632 en.no.is_543  mk.ru.sr_643 en.lt.un_540
  0x202d0d0d, 0x010e1008, 0x6e182711, 0x210b0a05,   // cs.sk.sq_554 lt.is.en_443  gd.ga.blu_653 pt.es.jw_333
  // [8a00]
  0x01002804, 0x04002107, 0x1b092808, 0x05190aa6,   // sw.en.un_320 jw.fi.un_420  sw.pl.tr_443 pt.gl.fr_521
  0x2b000802, 0x050802a0, 0x181312a7, 0x0e1304af,   // no.vi.un_220 da.no.fr_322  hu.et.ga_532 fi.et.is_655
  0x181213a0, 0x190a1209, 0x0700081b, 0x0a0b190c,   // et.hu.ga_322 hu.pt.gl_444  uk.bg.un_770 gl.es.pt_543
  0x0e0c1304, 0x6e006b04, 0x2d001012, 0x2b00271b,   // et.sv.is_332 ceb.blu.un_320  lt.sk.un_640 gd.vi.un_770
  // [8a10]
  0x0608020b, 0x120e1304, 0x211e0ead, 0x0b1827a7,   // da.no.de_542 et.is.hu_332  is.ms.jw_643 gd.ga.es_532
  0x05000e13, 0x0a100713, 0x02103fee, 0x060c13a4,   // is.fr.un_650 bg.be.mk_665  af.lt.da_422 et.sv.de_433
  0x29080255, 0x2d0d1902, 0x121b250d, 0x20250ca6,   // da.no.sl_442 gl.cs.sk_222  eu.tr.hu_554 sv.eu.sq_521
  0x2b20010c, 0x1a6b12a4, 0x3f0402ee, 0x556b1a07,   // en.sq.vi_543 hu.ceb.tl_433  da.fi.af_422 tl.ceb.rw_432
  // [8a20]
  0x0a122d12, 0x05001209, 0x3f080208, 0x05190eb2,   // sk.hu.pt_654 hu.fr.un_440  da.no.af_443 is.gl.fr_732
  0x190711ee, 0x06120202, 0x6b041aa0, 0x0a001913,   // ro.it.gl_422 da.hu.de_222  tl.fi.ceb_322 gl.pt.un_650
  0x311020ee, 0x646b1aad, 0x0d190aac, 0x091f0d07,   // sq.lt.az_422 tl.ceb.lg_643  pt.gl.cs_632 cs.cy.pl_432
  0x6428210c, 0x11001a22, 0x1a00211a, 0x216b2807,   // jw.sw.lg_543 tl.ro.un_870  jw.tl.un_760 sw.ceb.jw_432
  // [8a30]
  0x0c021fa0, 0x100b0f12, 0x550964ac, 0x120a080d,   // cy.da.sv_322 lv.es.lt_654  lg.pl.rw_632 no.pt.hu_554
  0x0c1101ee, 0x1c000d23, 0x29002707, 0x122955a0,   // en.ro.sv_422 ne.mr.un_880  gd.sl.un_420 rw.sl.hu_322
  0x55006b13, 0x210b0507, 0x123f0c02, 0x09003f09,   // ceb.rw.un_650 fr.es.jw_432  sv.af.hu_222 af.pl.un_440
  0x29001004, 0x132d0da4, 0x040d6b55, 0x13161717,   // lt.sl.un_320 cs.sk.et_433  ceb.cs.fi_442 sr.hr.et_753
  // [8a40]
  0x0d6b2da4, 0x212864a9, 0x09211e07, 0x19000513,   // sk.ceb.cs_433 lg.sw.jw_544  ms.jw.pl_432 fr.gl.un_650
  0x12132507, 0x280804a0, 0x0a2307a4, 0x18000408,   // eu.et.hu_432 fi.no.sw_322  it.ca.pt_433 fi.ga.un_430
  0x53182707, 0x121a6b5a, 0x1e1c270e, 0x0d050a04,   // gd.ga.ht_432 ceb.tl.hu_553  gd.id.ms_555 pt.fr.cs_332
  0x07001109, 0x2a0a0507, 0x0b0a6405, 0x1a056bad,   // ro.bg.un_440 fr.pt.mt_432  lg.pt.es_333 ceb.fr.tl_643
  // [8a50]
  0x0d2d12b6, 0x1b286411, 0x192353ee, 0x53006422,   // hu.sk.cs_766 lg.sw.tr_653  ht.ca.gl_422 lg.ht.un_870
  0x3f000f02, 0x0b001216, 0x042512a4, 0x12180d08,   // lv.af.un_220 hu.es.un_720  hu.eu.fi_433 cs.ga.hu_443
  0x0f00130e, 0x1e0a19ee, 0x13000f05, 0x3f171605,   // et.lv.un_550 gl.pt.ms_422  lv.et.un_330 hr.sr.af_333
  0x160f2904, 0x12216b08, 0x190d125e, 0x64002008,   // sl.lv.hr_332 ceb.jw.hu_443  hu.cs.gl_652 sq.lg.un_430
  // [8a60]
  0x1a29640c, 0x07000112, 0x192025a0, 0x0f133fa9,   // lg.sl.tl_543 en.it.un_640  eu.sq.gl_322 af.et.lv_544
  0x285564ac, 0x10000b0e, 0x0a0b2907, 0x0204130c,   // lg.rw.sw_632 es.lt.un_550  sl.es.pt_432 et.fi.da_543
  0x13002011, 0x0a002a07, 0x0c0b2012, 0x080317a0,   // sq.et.un_630 mt.pt.un_420  sq.es.sv_654 sr.nl.no_322
  0x09101204, 0x07006b12, 0x04101a04, 0x532a0fee,   // hu.lt.pl_332 ceb.it.un_640  tl.lt.fi_332 lv.mt.ht_422
  // [8a70]
  0x09101904, 0x022820ad, 0x132827a0, 0x3f091ca0,   // gl.lt.pl_332 sq.sw.da_643  gd.sw.et_322 id.pl.af_322
  0x18042707, 0x086b01ee, 0x10001912, 0x08232707,   // gd.fi.ga_432 en.ceb.no_422  gl.lt.un_640 gd.ca.no_432
  0x17090512, 0x1c1029a4, 0x10290a11, 0x23190a60,   // fr.pl.sr_654 sl.lt.id_433  pt.sl.lt_653 pt.gl.ca_664
  0x29000b07, 0x110a080e, 0x1f0120a4, 0x080711a0,   // es.sl.un_420 no.pt.ro_555  sq.en.cy_433 ro.bg.uk_322
  // [8a80]
  0x1910090c, 0x28552007, 0x0b2a23a0, 0x13006e0c,   // pl.lt.gl_543 sq.rw.sw_432  ca.mt.es_322 blu.et.un_530
  0x1a121b07, 0x0a000509, 0x08002722, 0x120c0607,   // tr.hu.tl_432 fr.pt.un_440  gd.no.un_870 de.sv.hu_432
  0x0a270404, 0x1007170c, 0x040127a0, 0x2b1c200c,   // fi.gd.pt_332 sr.bg.be_543  gd.en.fi_322 sq.id.vi_543
  0x020107ee, 0x07001b04, 0x0d311b07, 0x17002702,   // it.en.da_422 tr.it.un_320  tr.az.cs_432 gd.sr.un_220
  // [8a90]
  0x212804a0, 0x050a0eee, 0x2920115a, 0x1b001119,   // fi.sw.jw_322 is.pt.fr_422  ro.sq.sl_553 ro.tr.un_750
  0x10090408, 0x122029a0, 0x0d000505, 0x0d000207,   // fi.pl.lt_443 sl.sq.hu_322  fr.cs.un_330 da.cs.un_420
  0x230b29a0, 0x0d00120e, 0x25000c02, 0x1b000f12,   // sl.es.ca_322 hu.cs.un_550  sv.eu.un_220 lv.tr.un_640
  0x10290fa4, 0x2a002923, 0x0b121904, 0x131f01ad,   // lv.sl.lt_433 sl.mt.un_880  gl.hu.es_332 en.cy.et_643
  // [8aa0]
  0x20002912, 0x0904100e, 0x091f0409, 0x2108020e,   // sl.sq.un_640 lt.fi.pl_555  fi.cy.pl_444 da.no.jw_555
  0x01000d13, 0x2a070c12, 0x2d002702, 0x3f1b010c,   // cs.en.un_650 sv.it.mt_654  gd.sk.un_220 en.tr.af_543
  0x1c082107, 0x0d2116ee, 0x10270a04, 0x0c1a080c,   // jw.no.id_432 hr.jw.cs_422  pt.gd.lt_332 no.tl.sv_543
  0x061b0ea4, 0x206b25ee, 0x31100209, 0x051221a4,   // is.tr.de_433 eu.ceb.sq_422  da.lt.az_444 jw.hu.fr_433
  // [8ab0]
  0x06001f14, 0x2a0103ee, 0x01001f0c, 0x0c0810ad,   // cy.de.un_660 nl.en.mt_422  cy.en.un_530 lt.no.sv_643
  0x1a0302ee, 0x531e1c55, 0x1a00010d, 0x07000418,   // da.nl.tl_422 id.ms.ht_442  en.tl.un_540 ru.bg.un_740
  0x131f0112, 0x31081f55, 0x3102080c, 0x27000802,   // en.cy.et_654 cy.no.az_442  no.da.az_543 no.gd.un_220
  0x3f005504, 0x18002734, 0x251827ad, 0x2a25070c,   // rw.af.un_320 gd.ga.un_A80  gd.ga.eu_643 it.eu.mt_543
  // [8ac0]
  0x182527af, 0x25001e05, 0x02101307, 0x08000d1a,   // gd.eu.ga_655 ms.eu.un_330  et.lt.da_432 cs.no.un_760
  0x0f160107, 0x18052708, 0x2b1b2004, 0x271f040c,   // en.hr.lv_432 gd.fr.ga_443  sq.tr.vi_332 fi.cy.gd_543
  0x25072a60, 0x01185508, 0x10640408, 0x531c1005,   // mt.it.eu_664 rw.ga.en_443  fi.lg.lt_443 lt.id.ht_333
  0x062053ee, 0x111c1ead, 0x080218ee, 0x2725180b,   // ht.sq.de_422 ms.id.ro_643  ga.da.no_422 ga.eu.gd_542
  // [8ad0]
  0x081c2011, 0x182725ad, 0x25206eee, 0x18230ba4,   // sq.id.no_653 eu.gd.ga_643  blu.sq.eu_422 es.ca.ga_433
  0x251e1c11, 0x53080209, 0x1e190b04, 0x28000d08,   // id.ms.eu_653 da.no.ht_444  es.gl.ms_332 cs.sw.un_430
  0x12000d14, 0x0f202904, 0x1716270c, 0x6b280907,   // cs.hu.un_660 sl.sq.lv_332  gd.hr.sr_543 pl.sw.ceb_432
  0x25000305, 0x6b0b07ad, 0x29080208, 0x191c1ea0,   // nl.eu.un_330 it.es.ceb_643  da.no.sl_443 ms.id.gl_322
  // [8ae0]
  0x11282aa4, 0x060953a4, 0x2b050a0c, 0x08070a55,   // mt.sw.ro_433 ht.pl.de_433  pt.fr.vi_543 mk.bg.uk_442
  0x291b23ee, 0x04081309, 0x3f192802, 0x281e1c0d,   // ca.tr.sl_422 et.no.fi_444  sw.gl.af_222 id.ms.sw_554
  0x131b10a0, 0x0a002007, 0x28000a13, 0x100828ee,   // lt.tr.et_322 sq.pt.un_420  pt.sw.un_650 sw.no.lt_422
  0x07110aa7, 0x1e2a1ca0, 0x070c0e0c, 0x0f000608,   // mk.ro.bg_532 id.mt.ms_322  is.sv.it_543 de.lv.un_430
  // [8af0]
  0x0a1123a7, 0x10292d0e, 0x53001f23, 0x06050fee,   // ca.ro.pt_532 sk.sl.lt_555  cy.ht.un_880 lv.fr.de_422
  0x071923a9, 0x07051904, 0x2d0d23ee, 0x07005302,   // ca.gl.it_544 gl.fr.it_332  ca.cs.sk_422 ht.it.un_220
  0x101b3107, 0x112a2507, 0x04061013, 0x070a08ad,   // az.tr.lt_432 eu.mt.ro_432  lt.de.fi_665 uk.mk.bg_643
  0x10000f0c, 0x19005521, 0x050d1a07, 0x080e1aa9,   // lv.lt.un_530 rw.gl.un_860  tl.cs.fr_432 tl.is.no_544
  // [8b00]
  0x311b110b, 0x12133f04, 0x1f111902, 0x020d17a0,   // ro.tr.az_542 af.et.hu_332  gl.ro.cy_222 sr.cs.da_322
  0x09115307, 0x250f0b55, 0x062003ec, 0x0a111804,   // ht.ro.pl_432 es.lv.eu_442  nl.sq.de_644 ga.ro.pt_332
  0x1b001f12, 0x1711530c, 0x3f031304, 0x2a283108,   // cy.tr.un_640 ht.ro.sr_543  et.nl.af_332 az.sw.mt_443
  0x1b0206a7, 0x070a0811, 0x53002821, 0x051b2707,   // de.da.tr_532 uk.mk.bg_653  sw.ht.un_860 gd.tr.fr_432
  // [8b10]
  0x1e180708, 0x530d280c, 0x2800010d, 0x28060308,   // it.ga.ms_443 sw.cs.ht_543  en.sw.un_540 nl.de.sw_443
  0x28180904, 0x27232108, 0x1c182704, 0x060d27ee,   // pl.ga.sw_332 jw.ca.gd_443  gd.ga.id_332 gd.cs.de_422
  0x64080707, 0x250b1911, 0x110b0a07, 0x3f096407,   // it.no.lg_432 gl.es.eu_653  pt.es.ro_432 lg.pl.af_432
  0x2a081b02, 0x23531f0c, 0x03070b09, 0x091601a0,   // tr.no.mt_222 cy.ht.ca_543  es.it.nl_444 en.hr.pl_322
  // [8b20]
  0x271905a9, 0x01270808, 0x03291302, 0x2d0d06af,   // fr.gl.gd_544 no.gd.en_443  et.sl.nl_222 de.cs.sk_655
  0x121306ee, 0x131b09a0, 0x05082807, 0x272501a4,   // de.et.hu_422 pl.tr.et_322  sw.no.fr_432 en.eu.gd_433
  0x2153100c, 0x11072508, 0x112507ee, 0x11252dad,   // lt.ht.jw_543 eu.it.ro_443  it.eu.ro_422 sk.eu.ro_643
  0x01060809, 0x061b01a0, 0x131b08a4, 0x2511070d,   // no.de.en_444 en.tr.de_322  no.tr.et_433 it.ro.eu_554
  // [8b30]
  0x10112504, 0x0c0204a9, 0x100a170c, 0x311b20a0,   // eu.ro.lt_332 fi.da.sv_544  sr.mk.be_543 sq.tr.az_322
  0x190e2d09, 0x1e1c0ca4, 0x0c022104, 0x11071204,   // sk.is.gl_444 sv.id.ms_433  jw.da.sv_332 hu.it.ro_332
  0x08132804, 0x1a286b04, 0x29006407, 0x1a12280c,   // sw.et.no_332 ceb.sw.tl_332  lg.sl.un_420 sw.hu.tl_543
  0x07202507, 0x01530605, 0x046b1a55, 0x28006b1b,   // eu.sq.it_432 de.ht.en_333  tl.ceb.fi_442 ceb.sw.un_770
  // [8b40]
  0x0b072d07, 0x0f092d11, 0x281164ec, 0x25112da0,   // sk.it.es_432 sk.pl.lv_653  lg.ro.sw_644 sk.ro.eu_322
  0x1107250e, 0x0500230c, 0x20002504, 0x25001104,   // eu.it.ro_555 ca.fr.un_530  eu.sq.un_320 ro.eu.un_320
  0x31006b08, 0x2d0a13a0, 0x29000f09, 0x28550812,   // ceb.az.un_430 et.pt.sk_322  lv.sl.un_440 no.rw.sw_654
  0x1c1e1811, 0x100a0702, 0x07642a14, 0x0e18190d,   // ga.ms.id_653 bg.mk.be_222  mt.lg.it_666 gl.ga.is_554
  // [8b50]
  0x0a1004a4, 0x3f0c1ea4, 0x0d6428a7, 0x250b64a4,   // ru.be.mk_433 ms.sv.af_433  sw.lg.cs_532 lg.es.eu_433
  0x110a07af, 0x190b6409, 0x1e051c07, 0x0f271008,   // bg.mk.ro_655 lg.es.gl_444  id.fr.ms_432 lt.gd.lv_443
  0x0e0c04a9, 0x050108a9, 0x071a2805, 0x55641c0c,   // fi.sv.is_544 no.en.fr_544  sw.tl.it_333 id.lg.rw_543
  0x641c1ea4, 0x070b640c, 0x2b1025a4, 0x1a6b2105,   // ms.id.lg_433 lg.es.it_543  eu.lt.vi_433 jw.ceb.tl_333
  // [8b60]
  0x0b271812, 0x550764a4, 0x18272813, 0x0f002722,   // ga.gd.es_654 lg.it.rw_433  sw.gd.ga_665 gd.lv.un_870
  0x282553a6, 0x2a000e1a, 0x6b0e275a, 0x6455070c,   // ht.eu.sw_521 is.mt.un_760  gd.is.ceb_553 it.rw.lg_543
  0x55216405, 0x10002829, 0x190d23a0, 0x070b2d07,   // lg.jw.rw_333 sw.lt.un_960  ca.cs.gl_322 sk.es.it_432
  0x64000112, 0x020e3104, 0x19051104, 0x3f102509,   // en.lg.un_640 az.is.da_332  ro.fr.gl_332 eu.lt.af_444
  // [8b70]
  0x04531ea4, 0x0b181f08, 0x55170da0, 0x0b005507,   // ms.ht.fi_433 cy.ga.es_443  cs.sr.rw_322 rw.es.un_420
  0x0a185307, 0x27131ca0, 0x3f0802ee, 0x12311bad,   // ht.ga.pt_432 id.et.gd_322  da.no.af_422 tr.az.hu_643
  0x27041307, 0x642101ad, 0x0e3f08a0, 0x1300101a,   // et.fi.gd_432 en.jw.lg_643  no.af.is_322 lt.et.un_760
  0x0b55645a, 0x18090da7, 0x0e1355ad, 0x28051ea0,   // lg.rw.es_553 cs.pl.ga_532  rw.et.is_643 ms.fr.sw_322
  // [8b80]
  0x05092d07, 0x07250ba4, 0x3f311ba9, 0x3f170409,   // sk.pl.fr_432 es.eu.it_433  tr.az.af_544 fi.sr.af_444
  0x13092109, 0x180e0a02, 0x27090107, 0x190a1813,   // jw.pl.et_444 pt.is.ga_222  en.pl.gd_432 ga.pt.gl_665
  0x3f171655, 0x2d0d1f0c, 0x3f002308, 0x0c1306ee,   // hr.sr.af_442 cy.cs.sk_543  ca.af.un_430 de.et.sv_422
  0x05002121, 0x171613af, 0x190a12a4, 0x3f00280c,   // jw.fr.un_860 et.hr.sr_655  hu.pt.gl_433 sw.af.un_530
  // [8b90]
  0x1100050c, 0x03060555, 0x2700020e, 0x55000507,   // fr.ro.un_530 fr.de.nl_442  da.gd.un_550 fr.rw.un_420
  0x29060ca0, 0x0c100802, 0x05000b02, 0x1000170d,   // sv.de.sl_322 no.lt.sv_222  es.fr.un_220 sr.be.un_540
  0x090e1f02, 0x0e0c0404, 0x04066bee, 0x0c3f0507,   // cy.is.pl_222 fi.sv.is_332  ceb.de.fi_422 fr.af.sv_432
  0x070a040c, 0x050406a4, 0x1a001f02, 0x0a071007,   // ru.mk.bg_543 de.fi.fr_433  cy.tl.un_220 be.bg.mk_432
  // [8ba0]
  0x27186ba7, 0x110a0409, 0x20001802, 0x211055a4,   // ceb.ga.gd_532 ru.mk.ro_444  ga.sq.un_220 rw.lt.jw_433
  0x170813ee, 0x041718af, 0x31061b11, 0x12085308,   // et.no.sr_422 ar.sr.ru_655  tr.de.az_653 ht.no.hu_443
  0x06083fa0, 0x1b0a1107, 0x0b1131ee, 0x201703a0,   // af.no.de_322 ro.pt.tr_432  az.ro.es_422 nl.sr.sq_322
  0x0d0c02ee, 0x6428070e, 0x271f11ee, 0x28256405,   // da.sv.cs_422 it.sw.lg_555  ro.cy.gd_422 lg.eu.sw_333
  // [8bb0]
  0x230511a4, 0x1f2305af, 0x2d1220a6, 0x231005a9,   // ro.fr.ca_433 fr.ca.cy_655  sq.hu.sk_521 fr.lt.ca_544
  0x0f2d0913, 0x0b00641a, 0x28082055, 0x04551007,   // pl.sk.lv_665 lg.es.un_760  sq.no.sw_442 lt.rw.fi_432
  0x2a103fa4, 0x2300101a, 0x23100ca4, 0x640e13a7,   // af.lt.mt_433 lt.ca.un_760  sv.lt.ca_433 et.is.lg_532
  0x0e191ea0, 0x08230307, 0x0a001f1a, 0x05012308,   // ms.gl.is_322 nl.ca.no_432  cy.pt.un_760 ca.en.fr_443
  // [8bc0]
  0x640701a0, 0x16136407, 0x091b3107, 0x0f1b1a0c,   // en.it.lg_322 lg.et.hr_432  az.tr.pl_432 tl.tr.lv_543
  0x1f130204, 0x112325ad, 0x205311a0, 0x0e000309,   // da.et.cy_332 eu.ca.ro_643  ro.ht.sq_322 nl.is.un_440
  0x11286411, 0x04281ea0, 0x110523ad, 0x1123055a,   // lg.sw.ro_653 ms.sw.fi_322  ca.fr.ro_643 fr.ca.ro_553
  0x12640f0c, 0x28000f22, 0x6b132811, 0x03130460,   // lv.lg.hu_543 lv.sw.un_870  sw.et.ceb_653 fi.et.nl_664
  // [8bd0]
  0x281e5504, 0x2800202b, 0x1123050c, 0x64036bee,   // rw.ms.sw_332 sq.sw.un_980  fr.ca.ro_543 ceb.nl.lg_422
  0x20285508, 0x131204ec, 0x08090cee, 0x1705060c,   // rw.sw.sq_443 fi.hu.et_644  sv.pl.no_422 de.fr.sr_543
  0x200308a0, 0x011f3f04, 0x1e0621a0, 0x31015504,   // no.nl.sq_322 af.cy.en_332  jw.de.ms_322 rw.en.az_332
  0x170828a4, 0x27002522, 0x08041208, 0x06550111,   // sw.no.sr_433 eu.gd.un_870  hu.fi.no_443 en.rw.de_653
  // [8be0]
  0x3f532a07, 0x6b1a0ea4, 0x1b3106ad, 0x6400200e,   // mt.ht.af_432 is.tl.ceb_433  de.az.tr_643 sq.lg.un_550
  0x1b0e040e, 0x09000308, 0x64050307, 0x1800110e,   // fi.is.tr_555 nl.pl.un_430  nl.fr.lg_432 ro.ga.un_550
  0x1002080c, 0x130206a7, 0x28231804, 0x2a09640b,   // no.da.lt_543 de.da.et_532  ga.ca.sw_332 lg.pl.mt_542
  0x0c000408, 0x010813a4, 0x55640f04, 0x11311b0c,   // fi.sv.un_430 et.no.en_433  lv.lg.rw_332 tr.az.ro_543
  // [8bf0]
  0x28096ba7, 0x1b31065a, 0x13080e08, 0x310464ee,   // ceb.pl.sw_532 de.az.tr_553  is.no.et_443 lg.fi.az_422
  0x21080255, 0x3f6b13af, 0x05081ba4, 0x2000551a,   // da.no.jw_442 et.ceb.af_655  tr.no.fr_433 rw.sq.un_760
  0x23110508, 0x281f20ee, 0x20002a07, 0x130c0607,   // fr.ro.ca_443 sq.cy.sw_422  mt.sq.un_420 de.sv.et_432
  0x06311baf, 0x6b190b55, 0x081001ad, 0x210627a9,   // tr.az.de_655 es.gl.ceb_442  en.lt.no_643 gd.de.jw_544

  // [8c00]
  0x09003f13, 0x6b00280d, 0x1b080d07, 0x06256405,   // af.pl.un_650 sw.ceb.un_540  cs.no.tr_432 lg.eu.de_333
  0x1a092aa0, 0x311b060e, 0x25120412, 0x02120304,   // mt.pl.tl_322 de.tr.az_555  fi.hu.eu_654 nl.hu.da_332
  0x0d64130c, 0x041312a4, 0x082a0ea7, 0x121304a4,   // et.lg.cs_543 hu.et.fi_433  is.mt.no_532 fi.et.hu_433
  0x23641104, 0x04131205, 0x0e211c0c, 0x2304090c,   // ro.lg.ca_332 hu.et.fi_333  id.jw.is_543 pl.fi.ca_543
  // [8c10]
  0x070417a7, 0x1617290c, 0x0e000408, 0x53001708,   // sr.ru.bg_532 sl.sr.hr_543  fi.is.un_430 sr.ht.un_430
  0x08000221, 0x6b002a02, 0x2a00060c, 0x2100550e,   // da.no.un_860 mt.ceb.un_220  de.mt.un_530 rw.jw.un_550
  0x05000f07, 0x552821a0, 0x190501ee, 0x0f000d12,   // lv.fr.un_420 jw.sw.rw_322  en.fr.gl_422 cs.lv.un_640
  0x0c1c2aee, 0x01040e0b, 0x071711a6, 0x120c01ec,   // mt.id.sv_422 is.fi.en_542  ro.sr.bg_521 en.sv.hu_644
  // [8c20]
  0x07001f0c, 0x08031f04, 0x05030704, 0x0c2a1fa0,   // cy.it.un_530 cy.nl.no_332  it.nl.fr_332 cy.mt.sv_322
  0x18001119, 0x051e1c02, 0x020c0e04, 0x25001112,   // ro.ga.un_750 id.ms.fr_222  is.sv.da_332 ro.eu.un_640
  0x6b1e1c0c, 0x132801a4, 0x28002a0c, 0x11182711,   // id.ms.ceb_543 en.sw.et_433  mt.sw.un_530 gd.ga.ro_653
  0x3f1e64a7, 0x132a1ea4, 0x2a191ea0, 0x190d0b07,   // lg.ms.af_532 ms.mt.et_433  ms.gl.mt_322 es.cs.gl_432
  // [8c30]
  0x190b6ba9, 0x1255640d, 0x07006b02, 0x080e06ad,   // ceb.es.gl_544 lg.rw.hu_554  ceb.it.un_220 de.is.no_643
  0x13100407, 0x0e642504, 0x6b0301a0, 0x2a17100d,   // fi.lt.et_432 eu.lg.is_332  en.nl.ceb_322 lt.sr.mt_554
  0x550328a4, 0x07001308, 0x55286b08, 0x21000319,   // sw.nl.rw_433 et.it.un_430  ceb.sw.rw_443 nl.jw.un_750
  0x252a0aa0, 0x64531008, 0x17012b02, 0x23130e04,   // pt.mt.eu_322 lt.ht.lg_443  vi.en.sr_222 is.et.ca_332
  // [8c40]
  0x0500110e, 0x1b001107, 0x170d2d12, 0x2a2101ad,   // ro.fr.un_550 ro.tr.un_420  sk.cs.sr_654 en.jw.mt_643
  0x13110ca4, 0x5553050b, 0x13211007, 0x2a211ea4,   // sv.ro.et_433 fr.ht.rw_542  lt.jw.et_432 ms.jw.mt_433
  0x3f2808a0, 0x016b12a0, 0x64551308, 0x0e640c55,   // no.sw.af_322 hu.ceb.en_322  et.rw.lg_443 sv.lg.is_442
  0x09131a55, 0x081b1a55, 0x16100f0c, 0x6b1a1307,   // tl.et.pl_442 tl.tr.no_442  lv.lt.hr_543 et.tl.ceb_432
  // [8c50]
  0x020b0a5a, 0x1104080c, 0x6b5305ec, 0x0410280c,   // pt.es.da_553 uk.ru.ro_543  fr.ht.ceb_644 sw.lt.fi_543
  0x0425100c, 0x0212080c, 0x21130207, 0x0a00191a,   // lt.eu.fi_543 no.hu.da_543  da.et.jw_432 gl.pt.un_760
  0x1c2a0707, 0x0f0c1307, 0x13100fad, 0x0100050c,   // it.mt.id_432 et.sv.lv_432  lv.lt.et_643 fr.en.un_530
  0x040f130c, 0x04080e07, 0x04002b02, 0x08111014,   // et.lv.fi_543 is.no.fi_432  vi.fi.un_220 be.ro.uk_666
  // [8c60]
  0x06120404, 0x3f000412, 0x29000207, 0x04060cec,   // fi.hu.de_332 fi.af.un_640  da.sl.un_420 sv.de.fi_644
  0x040f0b02, 0x2d290d0e, 0x04051304, 0x060e0804,   // es.lv.fi_222 cs.sl.sk_555  et.fr.fi_332 no.is.de_332
  0x17071105, 0x02000412, 0x12311baf, 0x043f130c,   // ro.bg.sr_333 fi.da.un_640  tr.az.hu_655 et.af.fi_543
  0x10040860, 0x212064a0, 0x030621a4, 0x08006b08,   // uk.ru.be_664 lg.sq.jw_322  jw.de.nl_433 ceb.no.un_430
  // [8c70]
  0x0529020c, 0x046b25a0, 0x061a6b07, 0x1e27310c,   // da.sl.fr_543 eu.ceb.fi_322  ceb.tl.de_432 az.gd.ms_543
  0x24000133, 0x12060407, 0x0913020c, 0x1a6b64af,   // iw.yi.un_A70 fi.de.hu_432  da.et.pl_543 lg.ceb.tl_655
  0x13040c0d, 0x10531f04, 0x1a00040d, 0x2d001307,   // sv.fi.et_554 cy.ht.lt_332  fi.tl.un_540 et.sk.un_420
  0x0d001311, 0x10170807, 0x0e6b1aad, 0x07002a05,   // bh.ne.un_630 uk.sr.be_432  tl.ceb.is_643 mt.it.un_330
  // [8c80]
  0x01000e04, 0x040623a0, 0x1e1c0fa4, 0x131011a4,   // is.en.un_320 ca.de.fi_322  lv.id.ms_433 ro.lt.et_433
  0x08000608, 0x0f17165a, 0x28013fa7, 0x053f0304,   // de.no.un_430 hr.sr.lv_553  af.en.sw_532 nl.af.fr_332
  0x041328ad, 0x6b641a09, 0x230f0607, 0x55002502,   // sw.et.fi_643 tl.lg.ceb_444  de.lv.ca_432 eu.rw.un_220
  0x1b21550c, 0x1a1b640c, 0x3f001118, 0x211f1ca0,   // rw.jw.tr_543 lg.tr.tl_543  ro.af.un_740 id.cy.jw_322
  // [8c90]
  0x291613a0, 0x130227a4, 0x131c0dec, 0x091155a7,   // et.hr.sl_322 gd.da.et_433  ne.mr.bh_644 rw.ro.pl_532
  0x21646bec, 0x0855640c, 0x290f17a4, 0x0e060c07,   // ceb.lg.jw_644 lg.rw.no_543  sr.lv.sl_433 sv.de.is_432
  0x1200640e, 0x1c211ead, 0x556b1a13, 0x531b28ac,   // lg.hu.un_550 ms.jw.id_643  tl.ceb.rw_665 sw.tr.ht_632
  0x011c21a0, 0x1221640c, 0x031b12ad, 0x0b23010c,   // jw.id.en_322 lg.jw.hu_543  hu.tr.nl_643 en.ca.es_543
  // [8ca0]
  0x01002308, 0x641a1b08, 0x6b642809, 0x6b230108,   // ca.en.un_430 tr.tl.lg_443  sw.lg.ceb_444 en.ca.ceb_443
  0x312a1c02, 0x03002507, 0x040c060b, 0x19250a04,   // id.mt.az_222 eu.nl.un_420  de.sv.fi_542 pt.eu.gl_332
  0x25132307, 0x21001302, 0x28641207, 0x082301af,   // ca.et.eu_432 et.jw.un_220  hu.lg.sw_432 en.ca.no_655
  0x19071107, 0x19051e04, 0x6b0123a7, 0x02033f02,   // ro.it.gl_432 ms.fr.gl_332  ca.en.ceb_532 af.nl.da_222
  // [8cb0]
  0x230301a4, 0x0a17110d, 0x020e20a0, 0x0b080207,   // en.nl.ca_433 ro.sr.mk_554  sq.is.da_322 da.no.es_432
  0x6b1a0260, 0x03011307, 0x0b1827ad, 0x13190aa0,   // da.tl.ceb_664 et.en.nl_432  gd.ga.es_643 pt.gl.et_322
  0x07002505, 0x2300190b, 0x091c29ee, 0x03020ea9,   // eu.it.un_330 gl.ca.un_520  sl.id.pl_422 is.da.nl_544
  0x0e3f0807, 0x06271804, 0x080210a4, 0x29271f02,   // no.af.is_432 ga.gd.de_332  lt.da.no_433 cy.gd.sl_222
  // [8cc0]
  0x06080e02, 0x0c000e08, 0x0e00200d, 0x17110fa4,   // is.no.de_222 is.sv.un_430  sq.is.un_540 lv.ro.sr_433
  0x2a121807, 0x6b082aec, 0x531664ec, 0x072d1107,   // ga.hu.mt_432 mt.no.ceb_644  lg.hr.ht_644 ro.sk.it_432
  0x6b0453a4, 0x1955645a, 0x021b08a0, 0x530805ee,   // ht.fi.ceb_433 lg.rw.gl_553  no.tr.da_322 fr.no.ht_422
  0x2821550c, 0x080302a4, 0x063f0855, 0x0b000705,   // rw.jw.sw_543 da.nl.no_433  no.af.de_442 it.es.un_330
  // [8cd0]
  0x1f006413, 0x176b1bee, 0x190a06ac, 0x530a05a0,   // lg.cy.un_650 tr.ceb.sr_422  de.pt.gl_632 fr.pt.ht_322
  0x2d000504, 0x050e21a0, 0x01002429, 0x2d1e1c08,   // fr.sk.un_320 jw.is.fr_322  yi.iw.un_960 id.ms.sk_443
  0x18011f0c, 0x130e1807, 0x040810ee, 0x2000040c,   // cy.en.ga_543 ga.is.et_432  be.uk.ru_422 fi.sq.un_530
  0x202a2ba0, 0x08002811, 0x53001305, 0x0800121b,   // vi.mt.sq_322 sw.no.un_630  et.ht.un_330 hu.no.un_770
  // [8ce0]
  0x06010408, 0x0a205302, 0x062a080c, 0x21231ca0,   // fi.en.de_443 ht.sq.pt_222  no.mt.de_543 id.ca.jw_322
  0x1207040c, 0x0d641308, 0x052a08a7, 0x11202a0c,   // fi.it.hu_543 et.lg.cs_443  no.mt.fr_532 mt.sq.ro_543
  0x135525af, 0x06080caf, 0x64552560, 0x06071ba4,   // eu.rw.et_655 sv.no.de_655  eu.rw.lg_664 tr.it.de_433
  0x0500071b, 0x130604a0, 0x311323a0, 0x1a062102,   // it.fr.un_770 fi.de.et_322  ca.et.az_322 jw.de.tl_222
  // [8cf0]
  0x08021c07, 0x1b002019, 0x01001b07, 0x311a6b12,   // id.da.no_432 sq.tr.un_750  tr.en.un_420 ceb.tl.az_654
  0x0c001904, 0x13001214, 0x19000a0b, 0x6b1a080d,   // gl.sv.un_320 hu.et.un_660  pt.gl.un_520 no.tl.ceb_554
  0x10130410, 0x071204ec, 0x53081260, 0x022a0c08,   // fi.et.lt_642 fi.hu.it_644  hu.no.ht_664 sv.mt.da_443
  0x31012004, 0x072a08a0, 0x3f07080c, 0x08251e08,   // sq.en.az_332 no.mt.it_322  no.it.af_543 ms.eu.no_443
  // [8d00]
  0x042a07a9, 0x0b131005, 0x111e20a7, 0x02072a14,   // it.mt.fi_544 lt.et.es_333  sq.ms.ro_532 mt.it.da_666
  0x1b171605, 0x201a1002, 0x0c1b0f0b, 0x2a0705ad,   // hr.sr.tr_333 lt.tl.sq_222  lv.tr.sv_542 fr.it.mt_643
  0x23002907, 0x07230207, 0x03080c04, 0x291609ee,   // sl.ca.un_420 da.ca.it_432  sv.no.nl_332 pl.hr.sl_422
  0x0d0c08a0, 0x06002107, 0x6b066e09, 0x071f2707,   // no.sv.cs_322 jw.de.un_420  blu.de.ceb_444 gd.cy.it_432
  // [8d10]
  0x04080512, 0x2a0412ec, 0x1e1c3fa7, 0x12171660,   // fr.no.fi_654 hu.fi.mt_644  af.id.ms_532 hr.sr.hu_664
  0x0708100d, 0x31002505, 0x21131f04, 0x2d00040c,   // be.uk.bg_554 eu.az.un_330  cy.et.jw_332 fi.sk.un_530
  0x0c1206a7, 0x06053f04, 0x16003f04, 0x3f0e0c0c,   // de.hu.sv_532 af.fr.de_332  af.hr.un_320 sv.is.af_543
  0x1a000213, 0x08020e0c, 0x020e0855, 0x1b1612a0,   // da.tl.un_650 is.da.no_543  no.is.da_442 hu.hr.tr_322
  // [8d20]
  0x131b0f05, 0x081017a9, 0x0c081a04, 0x2d280ca6,   // lv.tr.et_333 sr.be.uk_544  tl.no.sv_332 sv.sw.sk_521
  0x53080fee, 0x270602ee, 0x18000102, 0x0b0906a7,   // lv.no.ht_422 da.de.gd_422  en.ga.un_220 de.pl.es_532
  0x1a126b0c, 0x20110107, 0x2d0a23a4, 0x010325ec,   // ceb.hu.tl_543 en.ro.sq_432  ca.pt.sk_433 eu.nl.en_644
  0x0600290d, 0x64552105, 0x28640da4, 0x07080a5a,   // sl.de.un_540 jw.rw.lg_333  cs.lg.sw_433 mk.uk.bg_553
  // [8d30]
  0x08041707, 0x6421550c, 0x0f001a0e, 0x55000c04,   // sr.ru.uk_432 rw.jw.lg_543  tl.lv.un_550 sv.rw.un_320
  0x060228a0, 0x030c6ba0, 0x3f002908, 0x5500230d,   // sw.da.de_322 ceb.sv.nl_322  sl.af.un_430 ca.rw.un_540
  0x10002821, 0x64532902, 0x211655ac, 0x2a551a02,   // sw.lt.un_860 sl.ht.lg_222  rw.hr.jw_632 tl.rw.mt_222
  0x6e001c0d, 0x0d000f02, 0x25001004, 0x23001913,   // id.blu.un_540 lv.cs.un_220  lt.eu.un_320 gl.ca.un_650
  // [8d40]
  0x2925550c, 0x171011a4, 0x08110a05, 0x6e002118,   // rw.eu.sl_543 ro.be.sr_433  mk.ro.uk_333 jw.blu.un_740
  0x551c1e11, 0x64175505, 0x160910a4, 0x1a1716ee,   // ms.id.rw_653 rw.sr.lg_333  lt.pl.hr_433 hr.sr.tl_422
  0x55001c0d, 0x29200d0c, 0x161c21ee, 0x1f006e0c,   // id.rw.un_540 cs.sq.sl_543  jw.id.hr_422 blu.cy.un_530
  0x2d092a55, 0x090d2007, 0x21002329, 0x2a002322,   // mt.pl.sk_442 sq.cs.pl_432  ca.jw.un_960 ca.mt.un_870
  // [8d50]
  0x1f6e6ba0, 0x0b17010c, 0x050b01a4, 0x23002514,   // ceb.blu.cy_322 en.sr.es_543  en.es.fr_433 eu.ca.un_660
  0x2d1c0e02, 0x0b0118ee, 0x0b033fa0, 0x13280308,   // is.id.sk_222 ga.en.es_422  af.nl.es_322 nl.sw.et_443
  0x0b002821, 0x10080702, 0x21001a2c, 0x032864a0,   // sw.es.un_860 bg.uk.be_222  tl.jw.un_990 lg.sw.nl_322
  0x1a010b04, 0x0a006e07, 0x03061b07, 0x03006e09,   // es.en.tl_332 blu.pt.un_420  tr.de.nl_432 blu.nl.un_440
  // [8d60]
  0x0e130ca0, 0x1b282105, 0x23052155, 0x285553a0,   // sv.et.is_322 jw.sw.tr_333  jw.fr.ca_442 ht.rw.sw_322
  0x2a233f08, 0x641301ad, 0x033f53ac, 0x1704080d,   // af.ca.mt_443 en.et.lg_643  ht.af.nl_632 uk.ru.sr_554
  0x0a001304, 0x0b000f05, 0x1c251eee, 0x1f0c27ad,   // et.pt.un_320 lv.es.un_330  ms.eu.id_422 gd.sv.cy_643
  0x25000b11, 0x13190a13, 0x1f002013, 0x121c08a0,   // es.eu.un_630 pt.gl.et_665  sq.cy.un_650 no.id.hu_322
  // [8d70]
  0x031210ee, 0x6e1f53ec, 0x64002902, 0x09640ba0,   // lt.hu.nl_422 ht.cy.blu_644  sl.lg.un_220 es.lg.pl_322
  0x120b280b, 0x10002804, 0x10190b07, 0x553f1c07,   // sw.es.hu_542 sw.lt.un_320  es.gl.lt_432 id.af.rw_432
  0x0a0717ad, 0x080f10ad, 0x030413a4, 0x03046407,   // sr.bg.mk_643 lt.lv.no_643  et.fi.nl_433 lg.fi.nl_432
  0x1c130d0e, 0x64033f0d, 0x021f25a0, 0x123f64a0,   // ne.bh.mr_555 af.nl.lg_554  eu.cy.da_322 lg.af.hu_322
  // [8d80]
  0x0b002812, 0x55280b08, 0x0b001002, 0x6400031b,   // sw.es.un_640 es.sw.rw_443  lt.es.un_220 nl.lg.un_770
  0x04006422, 0x53210704, 0x13060ea4, 0x13046404,   // lg.fi.un_870 it.jw.ht_332  is.de.et_433 lg.fi.et_332
  0x64130412, 0x0a051211, 0x12311b0c, 0x11310304,   // fi.et.lg_654 hu.fr.pt_653  tr.az.hu_543 nl.az.ro_332
  0x051853a7, 0x53000517, 0x2500531a, 0x03213f08,   // ht.ga.fr_532 fr.ht.un_730  ht.eu.un_760 af.jw.nl_443
  // [8d90]
  0x023f03ee, 0x09003f05, 0x64131ca0, 0x02290da0,   // nl.af.da_422 af.pl.un_330  id.et.lg_322 cs.sl.da_322
  0x070b230c, 0x1a002004, 0x0a2003a0, 0x1b1621a0,   // ca.es.it_543 sq.tl.un_320  nl.sq.pt_322 jw.hr.tr_322
  0x20000312, 0x210e0607, 0x551125a7, 0x17160c02,   // nl.sq.un_640 de.is.jw_432  eu.ro.rw_532 sv.hr.sr_222
  0x0920120c, 0x11002513, 0x170708a7, 0x06031f02,   // hu.sq.pl_543 eu.ro.un_650  uk.bg.sr_532 cy.nl.de_222
  // [8da0]
  0x03202a13, 0x0e1f640d, 0x29001212, 0x042813ee,   // mt.sq.nl_665 lg.cy.is_554  hu.sl.un_640 et.sw.fi_422
  0x05041307, 0x310413ec, 0x55002d05, 0x01530c09,   // et.fi.fr_432 et.fi.az_644  sk.rw.un_330 sv.ht.en_444
  0x130f2a11, 0x23002721, 0x1300070e, 0x0c2a06ee,   // mt.lv.et_653 gd.ca.un_860  it.et.un_550 de.mt.sv_422
  0x530601a0, 0x0210080c, 0x1f001a05, 0x073f0313,   // en.de.ht_322 no.lt.da_543  tl.cy.un_330 nl.af.it_665
  // [8db0]
  0x03292da9, 0x29002a02, 0x063f230c, 0x13040804,   // sk.sl.nl_544 mt.sl.un_220  ca.af.de_543 no.fi.et_332
  0x1200100c, 0x060104a0, 0x1e0f3fa7, 0x0a132a02,   // lt.hu.un_530 fi.en.de_322  af.lv.ms_532 mt.et.pt_222
  0x25100707, 0x0b01050c, 0x551310ee, 0x1e031f07,   // it.lt.eu_432 fr.en.es_543  lt.et.rw_422 cy.nl.ms_432
  0x3f060309, 0x0c1f05ac, 0x1f5510ac, 0x04081f12,   // nl.de.af_444 fr.cy.sv_632  lt.rw.cy_632 cy.no.fi_654
  // [8dc0]
  0x05000a21, 0x0500550c, 0x05002712, 0x0a0b050b,   // pt.fr.un_860 rw.fr.un_530  gd.fr.un_640 fr.es.pt_542
  0x190a0414, 0x64130407, 0x3f00040c, 0x07000a34,   // fi.pt.gl_666 fi.et.lg_432  fi.af.un_530 mk.bg.un_A80
  0x100b5507, 0x04000514, 0x07255507, 0x10550704,   // rw.es.lt_432 fr.fi.un_660  rw.eu.it_432 it.rw.lt_332
  0x0b0a21a4, 0x13002a0d, 0x09283f02, 0x0c020607,   // jw.pt.es_433 mt.et.un_540  af.sw.pl_222 de.da.sv_432
  // [8dd0]
  0x081110af, 0x17002918, 0x0b0501ee, 0x6b0f100d,   // be.ro.uk_655 sl.sr.un_740  en.fr.es_422 lt.lv.ceb_554
  0x28640107, 0x0c000211, 0x07033fa4, 0x0c020811,   // en.lg.sw_432 da.sv.un_630  af.nl.it_433 no.da.sv_653
  0x23020504, 0x172a6e55, 0x09001f22, 0x2a006e19,   // fr.da.ca_332 blu.mt.sr_442  cy.pl.un_870 blu.mt.un_750
  0x19000508, 0x11040a0c, 0x1812010c, 0x21131ca0,   // fr.gl.un_430 mk.ru.ro_543  en.hu.ga_543 id.et.jw_322
  // [8de0]
  0x121e1c0e, 0x04000a12, 0x0f251ba0, 0x252a070c,   // id.ms.hu_555 mk.ru.un_640  tr.eu.lv_322 it.mt.eu_543
  0x2b182855, 0x0f1b5307, 0x28002b07, 0x20006e0c,   // sw.ga.vi_442 ht.tr.lv_432  vi.sw.un_420 blu.sq.un_530
  0x12645512, 0x041019a0, 0x6e002019, 0x532d280c,   // rw.lg.hu_654 gl.lt.fi_322  sq.blu.un_750 sw.sk.ht_543
  0x0f2d10ec, 0x29161208, 0x12080604, 0x132a2d07,   // lt.sk.lv_644 hu.hr.sl_443  de.no.hu_332 sk.mt.et_432
  // [8df0]
  0x1908010c, 0x05002302, 0x0e000223, 0x016b0aa0,   // en.no.gl_543 ca.fr.un_220  da.is.un_880 pt.ceb.en_322
  0x2917030e, 0x0d13090b, 0x231907a0, 0x0c030805,   // nl.sr.sl_555 hi.bh.ne_542  it.gl.ca_322 no.nl.sv_333
  0x1f64010c, 0x230a6ea4, 0x3f0e0604, 0x0c123f07,   // en.lg.cy_543 blu.pt.ca_433  de.is.af_332 af.hu.sv_432
  0x252004a7, 0x13311ba0, 0x6b55640c, 0x04000502,   // fi.sq.eu_532 tr.az.et_322  lg.rw.ceb_543 fr.fi.un_220
  // [8e00]
  0x256429a4, 0x1e1c27ec, 0x0f2319a4, 0x23190504,   // sl.lg.eu_433 gd.id.ms_644  gl.ca.lv_433 fr.gl.ca_332
  0x0c120807, 0x082a0712, 0x13006e04, 0x0b2120a0,   // no.hu.sv_432 it.mt.no_654  blu.et.un_320 sq.jw.es_322
  0x20006409, 0x2000160d, 0x171623a6, 0x1f211e07,   // lg.sq.un_440 hr.sq.un_540  ca.hr.sr_521 ms.jw.cy_432
  0x07280a13, 0x21190a60, 0x1a211e0c, 0x25201ea0,   // pt.sw.it_665 pt.gl.jw_664  ms.jw.tl_543 ms.sq.eu_322
  // [8e10]
  0x10006e07, 0x2a2804ee, 0x06231108, 0x11170f04,   // blu.lt.un_420 fi.sw.mt_422  ro.ca.de_443 lv.sr.ro_332
  0x09310f09, 0x3f1006ac, 0x17291004, 0x0412250b,   // lv.az.pl_444 de.lt.af_632  lt.sl.sr_332 eu.hu.fi_542
  0x1a6b5307, 0x04002005, 0x27000204, 0x23291907,   // ht.ceb.tl_432 sq.fi.un_330  da.gd.un_320 gl.sl.ca_432
  0x18250ca0, 0x27001904, 0x0e0c31ad, 0x202307a4,   // sv.eu.ga_322 gl.gd.un_320  az.sv.is_643 it.ca.sq_433
  // [8e20]
  0x0f002521, 0x31000e16, 0x21001107, 0x045510a0,   // eu.lv.un_860 is.az.un_720  ro.jw.un_420 lt.rw.fi_322
  0x55252105, 0x1a3f01a6, 0x212d17a0, 0x011a06ee,   // jw.eu.rw_333 en.af.tl_521  sr.sk.jw_322 de.tl.en_422
  0x25005305, 0x11126ea0, 0x190b25ec, 0x20251b07,   // ht.eu.un_330 blu.hu.ro_322  eu.es.gl_644 tr.eu.sq_432
  0x0c000419, 0x12171bee, 0x31531b04, 0x0a08230c,   // fi.sv.un_750 tr.sr.hu_422  tr.ht.az_332 ca.no.pt_543
  // [8e30]
  0x1e250707, 0x091f0505, 0x12000a19, 0x090405a9,   // it.eu.ms_432 fr.cy.pl_333  pt.hu.un_750 fr.fi.pl_544
  0x190b2313, 0x05001602, 0x0f000e04, 0x021b1aa4,   // ca.es.gl_665 hr.fr.un_220  is.lv.un_320 tl.tr.da_433
  0x1b310cec, 0x191f09ee, 0x1f006407, 0x1e182760,   // sv.az.tr_644 pl.cy.gl_422  lg.cy.un_420 gd.ga.ms_664
  0x041708ad, 0x19001219, 0x286b5504, 0x2a005321,   // uk.sr.ru_643 hu.gl.un_750  rw.ceb.sw_332 ht.mt.un_860
  // [8e40]
  0x172d160d, 0x28000209, 0x55000508, 0x286455a0,   // hr.sk.sr_554 da.sw.un_440  fr.rw.un_430 rw.lg.sw_322
  0x19050904, 0x290e1904, 0x132305a4, 0x28095512,   // pl.fr.gl_332 gl.is.sl_332  fr.ca.et_433 rw.pl.sw_654
  0x09551f04, 0x551c2807, 0x28005308, 0x100411ec,   // cy.rw.pl_332 sw.id.rw_432  ht.sw.un_430 ro.ru.be_644
  0x09120655, 0x210c1aa0, 0x25001e13, 0x0b081107,   // de.hu.pl_442 tl.sv.jw_322  ms.eu.un_650 ro.no.es_432
  // [8e50]
  0x25081ea9, 0x1a645504, 0x1c552007, 0x205564ee,   // ms.no.eu_544 rw.lg.tl_332  sq.rw.id_432 lg.rw.sq_422
  0x6b1b2aa0, 0x0b311b1e, 0x0e0304a7, 0x21132007,   // mt.tr.ceb_322 tr.az.es_863  fi.nl.is_532 sq.et.jw_432
  0x120d1c04, 0x10131fac, 0x18116405, 0x0f06180c,   // id.cs.hu_332 cy.et.lt_632  lg.ro.ga_333 ga.de.lv_543
  0x12001f14, 0x070b0a09, 0x0f2a17a4, 0x312125ad,   // cy.hu.un_660 pt.es.it_444  sr.mt.lv_433 eu.jw.az_643
  // [8e60]
  0x06002522, 0x31060ead, 0x2b006404, 0x04202804,   // eu.de.un_870 is.de.az_643  lg.vi.un_320 sw.sq.fi_332
  0x12006b0d, 0x101b0e08, 0x0e1206ec, 0x04001e07,   // ceb.hu.un_540 is.tr.lt_443  de.hu.is_644 ms.fi.un_420
  0x0f0208ee, 0x06100f07, 0x1e1c11ec, 0x20101107,   // no.da.lv_422 lv.lt.de_432  ro.id.ms_644 ro.lt.sq_432
  0x112a2013, 0x1c202507, 0x273f0907, 0x0a171604,   // sq.mt.ro_665 eu.sq.id_432  pl.af.gd_432 hr.sr.pt_332
  // [8e70]
  0x13100fec, 0x05002007, 0x0400181a, 0x192a21ee,   // lv.lt.et_644 sq.fr.un_420  ga.fi.un_760 jw.mt.gl_422
  0x201a1807, 0x6b2d0d11, 0x16000402, 0x292a2704,   // ga.tl.sq_432 cs.sk.ceb_653  fi.hr.un_220 gd.mt.sl_332
  0x3f281802, 0x1a010804, 0x020507a0, 0x6b000604,   // ga.sw.af_222 no.en.tl_332  it.fr.da_322 de.ceb.un_320
  0x1a2b01ee, 0x07000904, 0x06010b07, 0x06002802,   // en.vi.tl_422 pl.it.un_320  es.en.de_432 sw.de.un_220
  // [8e80]
  0x10001723, 0x040a1105, 0x0b232aad, 0x05001c07,   // sr.be.un_880 ro.mk.ru_333  mt.ca.es_643 id.fr.un_420
  0x176b10a0, 0x030501ee, 0x132d0d02, 0x2d0d29ac,   // lt.ceb.sr_322 en.fr.nl_422  cs.sk.et_222 sl.cs.sk_632
  0x050b0a02, 0x1b000502, 0x06291109, 0x0b051912,   // pt.es.fr_222 fr.tr.un_220  ro.sl.de_444 gl.fr.es_654
  0x19002d08, 0x0a64090c, 0x64535512, 0x061b3fec,   // sk.gl.un_430 pl.lg.pt_543  rw.ht.lg_654 af.tr.de_644
  // [8e90]
  0x6453280b, 0x28536405, 0x13031b0c, 0x643f550c,   // sw.ht.lg_542 lg.ht.sw_333  tr.nl.et_543 rw.af.lg_543
  0x3f1f030d, 0x1f063f12, 0x020301a7, 0x3f036b05,   // nl.cy.af_554 af.de.cy_654  en.nl.da_532 ceb.nl.af_333
  0x0955285a, 0x645509a4, 0x0c1308ee, 0x2855530d,   // sw.rw.pl_553 pl.rw.lg_433  no.et.sv_422 ht.rw.sw_554
  0x03060804, 0x051912ad, 0x16092802, 0x531a2813,   // no.de.nl_332 hu.gl.fr_643  sw.pl.hr_222 sw.tl.ht_665
  // [8ea0]
  0x09000f08, 0x1f643f05, 0x2a3f03a9, 0x033f060c,   // lv.pl.un_430 af.lg.cy_333  nl.af.mt_544 de.af.nl_543
  0x0600030c, 0x0a050611, 0x093f035a, 0x6e201a05,   // nl.de.un_530 de.fr.pt_653  nl.af.pl_553 tl.sq.blu_333
  0x0655010c, 0x18000412, 0x236b0e04, 0x23200b13,   // en.rw.de_543 fi.ga.un_640  is.ceb.ca_332 es.sq.ca_665
  0x6b211aa4, 0x64550f05, 0x011f2aee, 0x0c081fec,   // tl.jw.ceb_433 lv.rw.lg_333  mt.cy.en_422 cy.no.sv_644
  // [8eb0]
  0x1b6455a4, 0x09211c07, 0x216b1aa7, 0x1e000904,   // rw.lg.tr_433 id.jw.pl_432  tl.ceb.jw_532 pl.ms.un_320
  0x216b1a0e, 0x0c021102, 0x216b1aaf, 0x28171660,   // tl.ceb.jw_555 ro.da.sv_222  tl.ceb.jw_655 hr.sr.sw_664
  0x213f1c0c, 0x6b13010b, 0x211f1a07, 0x180701a6,   // id.af.jw_543 en.et.ceb_542  tl.cy.jw_432 en.it.ga_521
  0x190b230c, 0x032107ee, 0x102113a6, 0x1a0401a0,   // ca.es.gl_543 it.jw.nl_422  et.jw.lt_521 en.fi.tl_322
  // [8ec0]
  0x28001613, 0x0d110e11, 0x6b002108, 0x091304a0,   // hr.sw.un_650 is.ro.cs_653  jw.ceb.un_430 fi.et.pl_322
  0x216b55a0, 0x5520280b, 0x21530907, 0x171655a9,   // rw.ceb.jw_322 sw.sq.rw_542  pl.ht.jw_432 rw.hr.sr_544
  0x53001f09, 0x64002108, 0x0410530c, 0x64010907,   // cy.ht.un_440 jw.lg.un_430  ht.lt.fi_543 pl.en.lg_432
  0x1f182aa0, 0x07001b0c, 0x01070560, 0x27010804,   // mt.ga.cy_322 tr.it.un_530  fr.it.en_664 no.en.gd_332
  // [8ed0]
  0x0900280c, 0x27001321, 0x1f002814, 0x271813a9,   // sw.pl.un_530 et.gd.un_860  sw.cy.un_660 et.ga.gd_544
  0x2a1b25ad, 0x312510a0, 0x28003f04, 0x063f2113,   // eu.tr.mt_643 lt.eu.az_322  af.sw.un_320 jw.af.de_665
  0x12001314, 0x1b230a12, 0x53020807, 0x192a08ee,   // et.hu.un_660 pt.ca.tr_654  no.da.ht_432 no.mt.gl_422
  0x02072007, 0x10002504, 0x050403ad, 0x1f190704,   // sq.it.da_432 eu.lt.un_320  nl.fi.fr_643 it.gl.cy_332
  // [8ee0]
  0x3f2a1804, 0x201b1008, 0x112010a4, 0x55201e04,   // ga.mt.af_332 lt.tr.sq_443  lt.sq.ro_433 ms.sq.rw_332
  0x10002014, 0x131020ee, 0x311b0eac, 0x1b1020ee,   // sq.lt.un_660 sq.lt.et_422  is.tr.az_632 sq.lt.tr_422
  0x06091f07, 0x281255a9, 0x100a1108, 0x0f1308ee,   // cy.pl.de_432 rw.hu.sw_544  ro.mk.be_443 no.et.lv_422
  0x64285502, 0x050b23a0, 0x6b6428a4, 0x310f10ad,   // rw.sw.lg_222 ca.es.fr_322  sw.lg.ceb_433 lt.lv.az_643
  // [8ef0]
  0x280b2502, 0x05111907, 0x052520a0, 0x20131004,   // eu.es.sw_222 gl.ro.fr_432  sq.eu.fr_322 lt.et.sq_332
  0x28116b13, 0x23070802, 0x201013a9, 0x2864550d,   // ceb.ro.sw_665 no.it.ca_222  et.lt.sq_544 rw.lg.sw_554
  0x12642811, 0x280e6407, 0x551321ec, 0x100e0907,   // sw.lg.hu_653 lg.is.sw_432  jw.et.rw_644 pl.is.lt_432
  0x0e1a6b07, 0x3f645560, 0x17160e05, 0x09001f14,   // ceb.tl.is_432 rw.lg.af_664  is.hr.sr_333 cy.pl.un_660
  // [8f00]
  0x2a0723a7, 0x09100ead, 0x1b0409a0, 0x12550aad,   // ca.it.mt_532 is.lt.pl_643  pl.fi.tr_322 pt.rw.hu_643
  0x2a081e07, 0x05002112, 0x0e00130e, 0x17160ea9,   // ms.no.mt_432 jw.fr.un_640  et.is.un_550 is.hr.sr_544
  0x230b2507, 0x070106a0, 0x17160eaf, 0x180c16a0,   // eu.es.ca_432 de.en.it_322  is.hr.sr_655 hr.sv.ga_322
  0x17160ea4, 0x04171007, 0x070f0107, 0x28001a0c,   // is.hr.sr_433 be.sr.ru_432  en.lv.it_432 tl.sw.un_530
  // [8f10]
  0x0906120d, 0x03002012, 0x033f020d, 0x20001212,   // hu.de.pl_554 sq.nl.un_640  da.af.nl_554 hu.sq.un_640
  0x28000c07, 0x64001021, 0x0c2a6ba0, 0x2a071ca0,   // sv.sw.un_420 lt.lg.un_860  ceb.mt.sv_322 id.it.mt_322
  0x06020ca0, 0x1110640c, 0x530801a4, 0x2d292008,   // sv.da.de_322 lg.lt.ro_543  en.no.ht_433 sq.sl.sk_443
  0x0b051ea0, 0x07112a05, 0x31200ea4, 0x200f10a7,   // ms.fr.es_322 mt.ro.it_333  is.sq.az_433 lt.lv.sq_532
  // [8f20]
  0x1a6b1ea4, 0x1311070c, 0x0e000704, 0x110d23a4,   // ms.ceb.tl_433 it.ro.et_543  it.is.un_320 ca.cs.ro_433
  0x0300230b, 0x2a070408, 0x2a1264ec, 0x101225ec,   // ca.nl.un_520 fi.it.mt_443  lg.hu.mt_644 eu.hu.lt_644
  0x0e001022, 0x036b0107, 0x0e003107, 0x1b3107ad,   // lt.is.un_870 en.ceb.nl_432  az.is.un_420 it.az.tr_643
  0x11000a1a, 0x0a170809, 0x042a0712, 0x0f0710a4,   // mk.ro.un_760 uk.sr.mk_444  it.mt.fi_654 lt.it.lv_433
  // [8f30]
  0x1e1c0da0, 0x230b0aad, 0x10160ea9, 0x3f030ca0,   // cs.id.ms_322 pt.es.ca_643  is.hr.lt_544 sv.nl.af_322
  0x1e001012, 0x08066b02, 0x0417080d, 0x13080204,   // lt.ms.un_640 ceb.de.no_222  uk.sr.ru_554 da.no.et_332
  0x2a040305, 0x6e001a21, 0x04061208, 0x04072a5a,   // nl.fi.mt_333 tl.blu.un_860  hu.de.fi_443 mt.it.fi_553
  0x0408110d, 0x6e001f22, 0x0b006e0c, 0x12040705,   // ro.uk.ru_554 cy.blu.un_870  blu.es.un_530 it.fi.hu_333
  // [8f40]
  0x0811040c, 0x190c1fa7, 0x310e1a0c, 0x17000c04,   // ru.ro.uk_543 cy.sv.gl_532  tl.is.az_543 sv.sr.un_320
  0x131c1eee, 0x0e00270c, 0x55126402, 0x110a1012,   // ms.id.et_422 gd.is.un_530  lg.hu.rw_222 lt.pt.ro_654
  0x123f6ba0, 0x1f0405a7, 0x640510ee, 0x16051104,   // ceb.af.hu_322 fr.fi.cy_532  lt.fr.lg_422 ro.fr.hr_332
  0x11170a08, 0x052a3fa0, 0x6e00051a, 0x55001122,   // mk.sr.ro_443 af.mt.fr_322  fr.blu.un_760 ro.rw.un_870
  // [8f50]
  0x21556460, 0x0d000a12, 0x0a000b18, 0x311e1c04,   // lg.rw.jw_664 pt.cs.un_640  es.pt.un_740 id.ms.az_332
  0x11162055, 0x040a10a4, 0x0810130c, 0x2b252aa0,   // sq.hr.ro_442 be.mk.ru_433  et.lt.no_543 mt.eu.vi_322
  0x19530404, 0x2a072008, 0x6b311b0e, 0x1c0921a6,   // fi.ht.gl_332 sq.it.mt_443  tr.az.ceb_555 jw.pl.id_521
  0x55642111, 0x53002519, 0x2d002911, 0x53552811,   // jw.lg.rw_653 eu.ht.un_750  sl.sk.un_630 sw.rw.ht_653
  // [8f60]
  0x0f001313, 0x041011ac, 0x640f2807, 0x176428ad,   // et.lv.un_650 ro.be.ru_632  sw.lv.lg_432 sw.lg.sr_643
  0x081a28a0, 0x0f280ead, 0x18000d08, 0x132a10ee,   // sw.tl.no_322 is.sw.lv_643  cs.ga.un_430 lt.mt.et_422
  0x2b1b13a6, 0x211812a4, 0x6417160e, 0x256b1e0c,   // et.tr.vi_521 ur.ar.fa_433  hr.sr.lg_555 ms.ceb.eu_543
  0x555331a4, 0x21171a0c, 0x16001e08, 0x2b0c0e04,   // az.ht.rw_433 tl.sr.jw_543  ms.hr.un_430 is.sv.vi_332
  // [8f70]
  0x1a001b19, 0x2d0d1212, 0x0c5564ec, 0x210916a0,   // tr.tl.un_750 hu.cs.sk_654  lg.rw.sv_644 hr.pl.jw_322
  0x04002013, 0x55001b1a, 0x0f5305a0, 0x64041008,   // sq.fi.un_650 tr.rw.un_760  fr.ht.lv_322 lt.fi.lg_443
  0x5500170d, 0x6b1a5313, 0x0413180d, 0x1a536b08,   // sr.rw.un_540 ht.tl.ceb_665  ga.et.fi_554 ceb.ht.tl_443
  0x2a122008, 0x12081814, 0x3f001204, 0x281a55a4,   // sq.hu.mt_443 ga.no.hu_666  hu.af.un_320 rw.tl.sw_433
  // [8f80]
  0x06080107, 0x1e011c13, 0x1a282113, 0x181125ad,   // en.no.de_432 id.en.ms_665  jw.sw.tl_665 eu.ro.ga_643
  0x21000f0d, 0x0418270d, 0x11090708, 0x201b2907,   // lv.jw.un_540 gd.ga.fi_554  it.pl.ro_443 sl.tr.sq_432
  0x130a08a4, 0x29001c13, 0x020c1b08, 0x12290ea7,   // no.pt.et_433 id.sl.un_650  tr.sv.da_443 is.sl.hu_532
  0x1e001c21, 0x12023f0c, 0x18231f05, 0x100f2555,   // id.ms.un_860 af.da.hu_543  cy.ca.ga_333 eu.lv.lt_442
  // [8f90]
  0x102512ad, 0x29080202, 0x101f0e09, 0x1e0e2707,   // hu.eu.lt_643 da.no.sl_222  is.cy.lt_444 gd.is.ms_432
  0x23002513, 0x253f27ee, 0x133f2904, 0x090d1ea0,   // eu.ca.un_650 gd.af.eu_422  sl.af.et_332 ms.cs.pl_322
  0x080a23ad, 0x0f0704a4, 0x64285505, 0x01120507,   // ca.pt.no_643 fi.it.lv_433  rw.sw.lg_333 fr.hu.en_432
  0x0a072aaf, 0x05000405, 0x6b0301a7, 0x1200251a,   // mt.it.pt_655 fi.fr.un_330  en.nl.ceb_532 eu.hu.un_760
  // [8fa0]
  0x011c2107, 0x120c0904, 0x133f6e05, 0x11170808,   // jw.id.en_432 pl.sv.hu_332  blu.af.et_333 uk.sr.ro_443
  0x05272508, 0x253f100c, 0x030c08a9, 0x230f0a0c,   // eu.gd.fr_443 lt.af.eu_543  no.sv.nl_544 pt.lv.ca_543
  0x12290e11, 0x13033f11, 0x12132a0c, 0x11005504,   // is.sl.hu_653 af.nl.et_653  mt.et.hu_543 rw.ro.un_320
  0x2b172907, 0x06212502, 0x17001b05, 0x04102a04,   // sl.sr.vi_432 eu.jw.de_222  tr.sr.un_330 mt.lt.fi_332
  // [8fb0]
  0x1f001309, 0x1e1c3fa6, 0x1b1e1204, 0x100428a7,   // et.cy.un_440 af.id.ms_521  hu.ms.tr_332 sw.fi.lt_532
  0x2a2d0d08, 0x13046ba9, 0x101708a7, 0x530c1ba4,   // cs.sk.mt_443 ceb.fi.et_544  uk.sr.be_532 tr.sv.ht_433
  0x20001819, 0x0600011a, 0x07000b02, 0x6b1a5512,   // ga.sq.un_750 en.de.un_760  es.it.un_220 rw.tl.ceb_654
  0x061827a4, 0x05190baf, 0x0c132112, 0x6b1a01a0,   // gd.ga.de_433 es.gl.fr_655  jw.et.sv_654 en.tl.ceb_322
  // [8fc0]
  0x160e08a0, 0x1f2718ee, 0x091f5304, 0x02001a09,   // no.is.hr_322 ga.gd.cy_422  ht.cy.pl_332 tl.da.un_440
  0x551a530d, 0x02050304, 0x071110a4, 0x192708a4,   // ht.tl.rw_554 nl.fr.da_332  lt.ro.it_433 no.gd.gl_433
  0x1e1c1aa4, 0x1e000104, 0x102853a4, 0x1000230d,   // tl.id.ms_433 en.ms.un_320  ht.sw.lt_433 ca.lt.un_540
  0x28000308, 0x6b0913ad, 0x09000f0e, 0x03180608,   // nl.sw.un_430 et.pl.ceb_643  lv.pl.un_550 de.ga.nl_443
  // [8fd0]
  0x2900081b, 0x1b5304a0, 0x2112070c, 0x0710110c,   // no.sl.un_770 fi.ht.tr_322  it.hu.jw_543 ro.lt.it_543
  0x6b1f0107, 0x070f10a9, 0x532a0a12, 0x0f1a130d,   // en.cy.ceb_432 lt.lv.it_544  pt.mt.ht_654 et.tl.lv_554
  0x3f1013ee, 0x2b001013, 0x230411a4, 0x11100408,   // et.lt.af_422 lt.vi.un_650  ro.fi.ca_433 fi.lt.ro_443
  0x080413ee, 0x1e1c13a9, 0x10001109, 0x09002508,   // et.fi.no_422 et.id.ms_544  ro.lt.un_440 eu.pl.un_430
  // [8fe0]
  0x1c0410a0, 0x0b0a2355, 0x3f00640b, 0x53640907,   // lt.fi.id_322 ca.pt.es_442  lg.af.un_520 pl.lg.ht_432
  0x210a130c, 0x280413a4, 0x1a64280b, 0x0f000609,   // et.pt.jw_543 et.fi.sw_433  sw.lg.tl_542 de.lv.un_440
  0x23002708, 0x31171614, 0x07171614, 0x212918ee,   // gd.ca.un_430 hr.sr.az_666  hr.sr.it_666 ga.sl.jw_422
  0x050704a4, 0x550a20a4, 0x0400010c, 0x31642a07,   // fi.it.fr_433 sq.pt.rw_433  en.fi.un_530 mt.lg.az_432
  // [8ff0]
  0x6e016b07, 0x10020c07, 0x270d04ad, 0x0d2928ee,   // ceb.en.blu_432 sv.da.lt_432  fi.cs.gd_643 sw.sl.cs_422
  0x1c532a0c, 0x2b000e0c, 0x0e002a07, 0x07551004,   // mt.ht.id_543 is.vi.un_530  mt.is.un_420 lt.rw.it_332
  0x013f09a0, 0x53002a02, 0x0e040607, 0x1c001704,   // pl.af.en_322 mt.ht.un_220  de.fi.is_432 sr.id.un_320
  0x080109ee, 0x082002af, 0x070b1ea0, 0x0a182005,   // pl.en.no_422 da.sq.no_655  ms.es.it_322 sq.ga.pt_333

  // [9000]
  0x2d001913, 0x06001905, 0x1f000c09, 0x2d0d28a0,   // gl.sk.un_650 gl.de.un_330  sv.cy.un_440 sw.cs.sk_322
  0x1f040955, 0x012d0d55, 0x201827ee, 0x27002018,   // pl.fi.cy_442 cs.sk.en_442  gd.ga.sq_422 sq.gd.un_740
  0x0a1708ad, 0x0400011a, 0x21001702, 0x0900010d,   // uk.sr.mk_643 en.fi.un_760  sr.jw.un_220 en.pl.un_540
  0x07100802, 0x19122d0b, 0x2d000a13, 0x0c006e0c,   // uk.be.bg_222 sk.hu.gl_542  pt.sk.un_650 blu.sv.un_530
  // [9010]
  0x0e2a2008, 0x1b0c2aee, 0x0511070b, 0x0d2d12a7,   // sq.mt.is_443 mt.sv.tr_422  it.ro.fr_542 hu.sk.cs_532
  0x13280e0c, 0x0a3f200b, 0x1b001e0d, 0x23002b2b,   // is.sw.et_543 sq.af.pt_542  ms.tr.un_540 vi.ca.un_980
  0x072a13a9, 0x2b1e1c13, 0x01050b04, 0x55000e0c,   // et.mt.it_544 id.ms.vi_665  es.fr.en_332 is.rw.un_530
  0x230b0a5a, 0x200716a9, 0x13121f12, 0x6b3101ee,   // pt.es.ca_553 hr.it.sq_544  cy.hu.et_654 en.az.ceb_422
  // [9020]
  0x113f01ad, 0x0e312da4, 0x19122d05, 0x1b005320,   // en.af.ro_643 sk.az.is_433  sk.hu.gl_333 ht.tr.un_850
  0x192d1207, 0x211c20af, 0x1e6b07a0, 0x230e1264,   // hu.sk.gl_432 sq.id.jw_655  it.ceb.ms_322 hu.is.ca_762
  0x0e071c0c, 0x2d1223a7, 0x11132813, 0x0e002513,   // id.it.is_543 ca.hu.sk_532  sw.et.ro_665 eu.is.un_650
  0x531e28a4, 0x07292da0, 0x13111a05, 0x0f002104,   // sw.ms.ht_433 sk.sl.it_322  tl.ro.et_333 jw.lv.un_320
  // [9030]
  0x29162da9, 0x11001602, 0x53000719, 0x1b0b2504,   // sk.hr.sl_544 hr.ro.un_220  it.ht.un_750 eu.es.tr_332
  0x6e250413, 0x160d1704, 0x05002807, 0x042528ec,   // fi.eu.blu_665 sr.cs.hr_332  sw.fr.un_420 sw.eu.fi_644
  0x25002823, 0x251e1c12, 0x0b282308, 0x070c0807,   // sw.eu.un_880 id.ms.eu_654  ca.sw.es_443 no.sv.it_432
  0x250c0204, 0x0a2128a0, 0x28000f05, 0x282025af,   // da.sv.eu_332 sw.jw.pt_322  lv.sw.un_330 eu.sq.sw_655
  // [9040]
  0x1e0c02a0, 0x6e280407, 0x0b0a10a0, 0x251b12a0,   // da.sv.ms_322 fi.sw.blu_432  lt.pt.es_322 hu.tr.eu_322
  0x2028250c, 0x2a210955, 0x1b1113a4, 0x25041c07,   // eu.sw.sq_543 pl.jw.mt_442  et.ro.tr_433 id.fi.eu_432
  0x21171604, 0x02250ca4, 0x0a08020e, 0x1f531c09,   // hr.sr.jw_332 sv.eu.da_433  da.no.pt_555 id.ht.cy_444
  0x2a001f08, 0x01041f0c, 0x1f006e09, 0x13311607,   // cy.mt.un_430 cy.fi.en_543  blu.cy.un_440 hr.az.et_432
  // [9050]
  0x08000904, 0x06093f07, 0x1b00130b, 0x6b203f07,   // pl.no.un_320 af.pl.de_432  et.tr.un_520 af.sq.ceb_432
  0x20216b0c, 0x2800201a, 0x10093faf, 0x0b06030e,   // ceb.jw.sq_543 sq.sw.un_760  af.pl.lt_655 nl.de.es_555
  0x64052704, 0x2809040c, 0x1009040c, 0x09190b55,   // gd.fr.lg_332 fi.pl.sw_543  fi.pl.lt_543 es.gl.pl_442
  0x1a28010c, 0x1b0f20ee, 0x281c1eec, 0x553f20ec,   // en.sw.tl_543 sq.lv.tr_422  ms.id.sw_644 sq.af.rw_644
  // [9060]
  0x09022d0b, 0x641a28a9, 0x6b002109, 0x06092d0c,   // sk.da.pl_542 sw.tl.lg_544  jw.ceb.un_440 sk.pl.de_543
  0x2d070ba4, 0x21202dad, 0x070a105a, 0x31042a07,   // es.it.sk_433 sk.sq.jw_643  be.mk.bg_553 mt.fi.az_432
  0x08002902, 0x1c1a1ea9, 0x1c211eec, 0x0e001108,   // sl.no.un_220 ms.tl.id_544  ms.jw.id_644 ro.is.un_430
  0x09216b05, 0x03060912, 0x211a6b60, 0x1e6b1a07,   // ceb.jw.pl_333 pl.de.nl_654  ceb.tl.jw_664 tl.ceb.ms_432
  // [9070]
  0x2800091a, 0x2d0a0507, 0x103f0412, 0x11090faf,   // pl.sw.un_760 fr.pt.sk_432  fi.af.lt_654 lv.pl.ro_655
  0x11201708, 0x04000623, 0x180e1208, 0x2d042a11,   // sr.sq.ro_443 de.fi.un_880  hu.is.ga_443 mt.fi.sk_653
  0x531a2107, 0x25071807, 0x2112050d, 0x181b310d,   // jw.tl.ht_432 ga.it.eu_432  fr.hu.jw_554 az.tr.ga_554
  0x04131107, 0x1e2025a9, 0x64190a0d, 0x281a1e07,   // ro.et.fi_432 eu.sq.ms_544  pt.gl.lg_554 ms.tl.sw_432
  // [9080]
  0x100e120c, 0x122a2012, 0x07042d04, 0x0603250c,   // hu.is.lt_543 sq.mt.hu_654  sk.fi.it_332 eu.nl.de_543
  0x1711200c, 0x2d00180c, 0x06006412, 0x030c1207,   // sq.ro.sr_543 ga.sk.un_530  lg.de.un_640 hu.sv.nl_432
  0x1a080205, 0x53001205, 0x236b0ba4, 0x073f0a08,   // da.no.tl_333 hu.ht.un_330  es.ceb.ca_433 pt.af.it_443
  0x1205235a, 0x31001704, 0x12001e0d, 0x12071108,   // ca.fr.hu_553 sr.az.un_320  ms.hu.un_540 ro.it.hu_443
  // [9090]
  0x281a180c, 0x0a122d04, 0x18110107, 0x02050c05,   // ga.tl.sw_543 sk.hu.pt_332  en.ro.ga_432 sv.fr.da_333
  0x0e1b0c0c, 0x2521640c, 0x31001211, 0x080211a4,   // sv.tr.is_543 lg.jw.eu_543  hu.az.un_630 ro.da.no_433
  0x316421a0, 0x0b232512, 0x2d0820ee, 0x216b1a13,   // jw.lg.az_322 eu.ca.es_654  sq.no.sk_422 tl.ceb.jw_665
  0x2300180b, 0x17162d07, 0x21042507, 0x12232d5a,   // ga.ca.un_520 sk.hr.sr_432  eu.fi.jw_432 sk.ca.hu_553
  // [90a0]
  0x0f0455a0, 0x1c641ba4, 0x55640408, 0x10041c04,   // rw.fi.lv_322 tr.lg.id_433  fi.lg.rw_443 id.fi.lt_332
  0x03552807, 0x2d062512, 0x23190a04, 0x0a2d19a0,   // sw.rw.nl_432 eu.de.sk_654  pt.gl.ca_332 gl.sk.pt_322
  0x6b002b0d, 0x55002504, 0x04001902, 0x532b1aa0,   // vi.ceb.un_540 eu.rw.un_320  gl.fi.un_220 tl.vi.ht_322
  0x1a5528ec, 0x6b281a04, 0x55080c07, 0x112d01a4,   // sw.rw.tl_644 tl.sw.ceb_332  sv.no.rw_432 en.sk.ro_433
  // [90b0]
  0x1b0c1004, 0x6b001b05, 0x111004ad, 0x190b25a6,   // lt.sv.tr_332 tr.ceb.un_330  ru.be.ro_643 eu.es.gl_521
  0x040102a0, 0x100817ec, 0x1e000f07, 0x03000411,   // da.en.fi_322 sr.uk.be_644  lv.ms.un_420 fi.nl.un_630
  0x6b001c08, 0x6b1a0107, 0x2d2503a4, 0x100604a0,   // id.ceb.un_430 en.tl.ceb_432  nl.eu.sk_433 fi.de.lt_322
  0x29042dee, 0x2b283fa4, 0x1a100608, 0x08025509,   // sk.fi.sl_422 af.sw.vi_433  de.lt.tl_443 rw.da.no_444
  // [90c0]
  0x6b1a1e0c, 0x281e2b02, 0x213f0312, 0x6b002114,   // ms.tl.ceb_543 vi.ms.sw_222  nl.af.jw_654 jw.ceb.un_660
  0x212a1a0c, 0x101a040c, 0x1a536bee, 0x07252aee,   // tl.mt.jw_543 fi.tl.lt_543  ceb.ht.tl_422 mt.eu.it_422
  0x216b1a11, 0x25215555, 0x0e000312, 0x06001007,   // tl.ceb.jw_653 rw.jw.eu_442  nl.is.un_640 lt.de.un_420
  0x1c551ea4, 0x1e1c2bee, 0x2a2b2107, 0x312d1ba7,   // ms.rw.id_433 vi.id.ms_422  jw.vi.mt_432 tr.sk.az_532
  // [90d0]
  0x04001c22, 0x3f001707, 0x0d082505, 0x1f042008,   // id.fi.un_870 sr.af.un_420  eu.no.cs_333 sq.fi.cy_443
  0x0410170c, 0x10071c07, 0x31006e13, 0x211e6ba6,   // sr.be.ru_543 id.it.lt_432  blu.az.un_650 ceb.ms.jw_521
  0x10002a21, 0x06010808, 0x211a0807, 0x28270ba4,   // mt.lt.un_860 no.en.de_443  no.tl.jw_432 es.gd.sw_433
  0x086b1aa4, 0x04100612, 0x2d0d1210, 0x040e0d07,   // tl.ceb.no_433 de.lt.fi_654  hu.cs.sk_642 cs.is.fi_432
  // [90e0]
  0x311b1707, 0x6e001604, 0x070a010c, 0x2864100c,   // sr.tr.az_432 hr.blu.un_320  en.pt.it_543 lt.lg.sw_543
  0x2a071c0c, 0x050664a6, 0x090501a4, 0x09002909,   // id.it.mt_543 lg.de.fr_521  en.fr.pl_433 sl.pl.un_440
  0x20312aad, 0x2d0d100c, 0x0e6b1aa7, 0x111304a4,   // mt.az.sq_643 lt.cs.sk_543  tl.ceb.is_532 fi.et.ro_433
  0x311b10a0, 0x3f001104, 0x27282504, 0x110413a0,   // lt.tr.az_322 ro.af.un_320  eu.sw.gd_332 et.fi.ro_322
  // [90f0]
  0x171609a9, 0x270618a7, 0x110f1304, 0x1113040c,   // pl.hr.sr_544 ga.de.gd_532  et.lv.ro_332 fi.et.ro_543
  0x04131108, 0x04081702, 0x1800010e, 0x28090107,   // ro.et.fi_443 sr.uk.ru_222  en.ga.un_550 en.pl.sw_432
  0x011805a0, 0x21001b04, 0x016e09a0, 0x53132a07,   // fr.ga.en_322 tr.jw.un_320  pl.blu.en_322 mt.et.ht_432
  0x283f0108, 0x2a2718a0, 0x0d533fee, 0x53000f07,   // en.af.sw_443 ga.gd.mt_322  af.ht.cs_422 lv.ht.un_420
  // [9100]
  0x07005313, 0x0f6b01ad, 0x0a0509a0, 0x2b04010c,   // ht.it.un_650 en.ceb.lv_643  pl.fr.pt_322 en.fi.vi_543
  0x0f311bee, 0x1e186b04, 0x230b19ee, 0x0f001207,   // tr.az.lv_422 ceb.ga.ms_332  gl.es.ca_422 hu.lv.un_420
  0x530812ee, 0x2b2a01a4, 0x18272104, 0x13010812,   // hu.no.ht_422 en.mt.vi_433  jw.gd.ga_332 no.en.et_654
  0x28002902, 0x0f0d0704, 0x550b010b, 0x281c21a7,   // sl.sw.un_220 it.cs.lv_332  en.es.rw_542 jw.id.sw_532
  // [9110]
  0x2a003114, 0x19002d02, 0x0c00120d, 0x3f1304a9,   // az.mt.un_660 sk.gl.un_220  hu.sv.un_540 fi.et.af_544
  0x122d0aa0, 0x04646ba7, 0x1e1c0daf, 0x081707ec,   // pt.sk.hu_322 ceb.lg.fi_532  cs.id.ms_655 bg.sr.uk_644
  0x25000f08, 0x0c000b05, 0x3f031309, 0x160f2905,   // lv.eu.un_430 es.sv.un_330  et.nl.af_444 sl.lv.hr_333
  0x270e1fa4, 0x2a00310e, 0x2b002808, 0x11002508,   // cy.is.gd_433 az.mt.un_550  sw.vi.un_430 eu.ro.un_430
  // [9120]
  0x272a2308, 0x043f0309, 0x6b5308a0, 0x1a640a0b,   // ca.mt.gd_443 nl.af.fi_444  no.ht.ceb_322 pt.lg.tl_542
  0x6b272104, 0x3f041307, 0x27132dec, 0x030c0208,   // jw.gd.ceb_332 et.fi.af_432  sk.et.gd_644 da.sv.nl_443
  0x2b000c05, 0x0a0710ee, 0x28052907, 0x040208a7,   // sv.vi.un_330 be.bg.mk_422  sl.fr.sw_432 no.da.fi_532
  0x12002721, 0x0f1716ee, 0x081202a7, 0x06026ba0,   // gd.hu.un_860 hr.sr.lv_422  da.hu.no_532 ceb.da.de_322
  // [9130]
  0x311b12af, 0x0e1a6b0c, 0x1107010b, 0x032108ee,   // hu.tr.az_655 ceb.tl.is_543  en.it.ro_542 no.jw.nl_422
  0x282a0907, 0x6b641008, 0x23002720, 0x1b2d0d0d,   // pl.mt.sw_432 lt.lg.ceb_443  gd.ca.un_850 cs.sk.tr_554
  0x0e0c04ec, 0x11000c1a, 0x1b003f14, 0x0f0c08a0,   // fi.sv.is_644 sv.ro.un_760  af.tr.un_660 no.sv.lv_322
  0x04271813, 0x101827ad, 0x160d07a0, 0x10000507,   // ga.gd.fi_665 gd.ga.lt_643  it.cs.hr_322 fr.lt.un_420
  // [9140]
  0x04001822, 0x0f2d10af, 0x28001109, 0x312a0e04,   // ga.fi.un_870 lt.sk.lv_655  ro.sw.un_440 is.mt.az_332
  0x1f091807, 0x0f0510ad, 0x0c1a6ba0, 0x21552813,   // ga.pl.cy_432 lt.fr.lv_643  ceb.tl.sv_322 sw.rw.jw_665
  0x0f2710a0, 0x03000912, 0x6b1c1902, 0x0d276e0b,   // lt.gd.lv_322 pl.nl.un_640  gl.id.ceb_222 blu.gd.cs_542
  0x190527ad, 0x05001909, 0x18000d0c, 0x112707a4,   // gd.fr.gl_643 gl.fr.un_440  cs.ga.un_530 it.gd.ro_433
  // [9150]
  0x0f00250c, 0x111320a0, 0x18000522, 0x081e1c0e,   // eu.lv.un_530 sq.et.ro_322  fr.ga.un_870 id.ms.no_555
  0x06005507, 0x04180107, 0x281f200c, 0x0d080212,   // rw.de.un_420 en.ga.fi_432  sq.cy.sw_543 da.no.cs_654
  0x55001b12, 0x1a001e08, 0x02002302, 0x641c6eee,   // tr.rw.un_640 ms.tl.un_430  ca.da.un_220 blu.id.lg_422
  0x2d0d0f02, 0x6b001904, 0x051f18a4, 0x065301a4,   // lv.cs.sk_222 gl.ceb.un_320  ga.cy.fr_433 en.ht.de_433
  // [9160]
  0x0306530c, 0x12130c02, 0x08250504, 0x091c13ac,   // ht.de.nl_543 sv.et.hu_222  fr.eu.no_332 bh.mr.hi_632
  0x021f3f08, 0x2100271a, 0x0600280e, 0x04133fa4,   // af.cy.da_443 gd.jw.un_760  sw.de.un_550 af.et.fi_433
  0x0306270c, 0x195306a4, 0x250e12a0, 0x2864060c,   // gd.de.nl_543 de.ht.gl_433  hu.is.eu_322 de.lg.sw_543
  0x08006b05, 0x022553a7, 0x07042aa4, 0x0805060c,   // ceb.no.un_330 ht.eu.da_532  mt.fi.it_433 de.fr.no_543
  // [9170]
  0x12311ba6, 0x530305a0, 0x06280360, 0x181f270c,   // tr.az.hu_521 fr.nl.ht_322  nl.sw.de_664 gd.cy.ga_543
  0x186b0eee, 0x1318270c, 0x0518270c, 0x11080a09,   // is.ceb.ga_422 gd.ga.et_543  gd.ga.fr_543 mk.uk.ro_444
  0x190a05ee, 0x312864a4, 0x550964a0, 0x171011a7,   // fr.pt.gl_422 lg.sw.az_433  lg.pl.rw_322 ro.be.sr_532
  0x13002312, 0x0d040912, 0x090411a0, 0x11042507,   // ca.et.un_640 pl.fi.cs_654  ro.fi.pl_322 eu.fi.ro_432
  // [9180]
  0x011004ee, 0x55251604, 0x0e002504, 0x08101712,   // fi.lt.en_422 hr.eu.rw_332  eu.is.un_320 sr.be.uk_654
  0x1c1004ad, 0x31201b02, 0x12002a0e, 0x0d013fee,   // fi.lt.id_643 tr.sq.az_222  mt.hu.un_550 af.en.cs_422
  0x31002704, 0x121805ad, 0x0d1205a7, 0x041206a9,   // gd.az.un_320 fr.ga.hu_643  fr.hu.cs_532 de.hu.fi_544
  0x110f04a0, 0x0f041155, 0x092504a4, 0x64555305,   // fi.lv.ro_322 ro.fi.lv_442  fi.eu.pl_433 ht.rw.lg_333
  // [9190]
  0x20250455, 0x11286404, 0x0406110c, 0x2718080c,   // fi.eu.sq_442 lg.sw.ro_332  ro.de.fi_543 no.ga.gd_543
  0x06040802, 0x0f002a1a, 0x251a2804, 0x12292aa6,   // no.fi.de_222 mt.lv.un_760  sw.tl.eu_332 mt.sl.hu_521
  0x640417a0, 0x25136bad, 0x040e100d, 0x0f002a20,   // sr.fi.lg_322 ceb.et.eu_643  lt.is.fi_554 mt.lv.un_850
  0x13020408, 0x04080302, 0x1e1c6bee, 0x2a002002,   // fi.da.et_443 nl.no.fi_222  ceb.id.ms_422 sq.mt.un_220
  // [91a0]
  0x2305010b, 0x03086404, 0x08031b0c, 0x041a1c04,   // en.fr.ca_542 lg.no.nl_332  tr.nl.no_543 id.tl.fi_332
  0x1a1729a0, 0x0d001102, 0x1a21040c, 0x6b042504,   // sl.sr.tl_322 ro.cs.un_220  fi.jw.tl_543 eu.fi.ceb_332
  0x251604a0, 0x0e1a1004, 0x2a041308, 0x040a100c,   // fi.hr.eu_322 lt.tl.is_332  et.fi.mt_443 be.mk.ru_543
  0x0a006402, 0x201225ee, 0x020c11a4, 0x640413a7,   // lg.pt.un_220 eu.hu.sq_422  ro.sv.da_433 et.fi.lg_532
  // [91b0]
  0x040f2aad, 0x04072a09, 0x1310115a, 0x120604ac,   // mt.lv.fi_643 mt.it.fi_444  ro.lt.et_553 fi.de.hu_632
  0x0b0c020b, 0x0b006e07, 0x040a050c, 0x25130a55,   // da.sv.es_542 blu.es.un_420  fr.pt.fi_543 pt.et.eu_442
  0x01003f07, 0x232a01a0, 0x18190a04, 0x3f2913a4,   // af.en.un_420 en.mt.ca_322  pt.gl.ga_332 et.sl.af_433
  0x18052702, 0x28251307, 0x0a2d12a9, 0x2a1364ee,   // gd.fr.ga_222 et.eu.sw_432  hu.sk.pt_544 lg.et.mt_422
  // [91c0]
  0x023f08a4, 0x1b060c12, 0x232d0d13, 0x13102a02,   // no.af.da_433 sv.de.tr_654  cs.sk.ca_665 mt.lt.et_222
  0x311a1bac, 0x17161b14, 0x13552507, 0x080c0211,   // tr.tl.az_632 tr.hr.sr_666  eu.rw.et_432 da.sv.no_653
  0x1004070e, 0x13030108, 0x64001322, 0x641355ee,   // bg.ru.be_555 en.nl.et_443  et.lg.un_870 rw.et.lg_422
  0x050a1912, 0x0e092507, 0x64006b05, 0x1200250c,   // gl.pt.fr_654 eu.pl.is_432  ceb.lg.un_330 eu.hu.un_530
  // [91d0]
  0x53002007, 0x25132a02, 0x3f0e0c55, 0x532128a7,   // sq.ht.un_420 mt.et.eu_222  sv.is.af_442 sw.jw.ht_532
  0x552025a7, 0x551253a9, 0x0a05110d, 0x08130ca4,   // eu.sq.rw_532 ht.hu.rw_544  ro.fr.pt_554 sv.et.no_433
  0x641f28ad, 0x1a00011a, 0x0e001e02, 0x170711a6,   // sw.cy.lg_643 en.tl.un_760  ms.is.un_220 ro.bg.sr_521
  0x1a0121af, 0x1a01210d, 0x3f03010e, 0x2d1364ec,   // jw.en.tl_655 jw.en.tl_554  en.nl.af_555 lg.et.sk_644
  // [91e0]
  0x031a0107, 0x1300640e, 0x2d00040e, 0x021e01ee,   // en.tl.nl_432 lg.et.un_550  fi.sk.un_550 en.ms.da_422
  0x5300200b, 0x082519a0, 0x0d530555, 0x1a002821,   // sq.ht.un_520 gl.eu.no_322  fr.ht.cs_442 sw.tl.un_860
  0x03000118, 0x070b05a0, 0x2a000a04, 0x2a092d11,   // en.nl.un_740 fr.es.it_322  pt.mt.un_320 sk.pl.mt_653
  0x08030112, 0x1c0b530c, 0x1a3f0112, 0x180c0618,   // en.nl.no_654 ht.es.id_543  en.af.tl_654 de.sv.ga_764
  // [91f0]
  0x031a010c, 0x25216bad, 0x641155ee, 0x040c06ad,   // en.tl.nl_543 ceb.jw.eu_643  rw.ro.lg_422 de.sv.fi_643
  0x550a23a4, 0x20552807, 0x0c01210c, 0x2800210e,   // ca.pt.rw_433 sw.rw.sq_432  jw.en.sv_543 jw.sw.un_550
  0x081e11ec, 0x532a20ee, 0x1a001e02, 0x1e285508,   // ro.ms.no_644 sq.mt.ht_422  ms.tl.un_220 rw.sw.ms_443
  0x551a2505, 0x5500202b, 0x2d0d02a6, 0x28642507,   // eu.tl.rw_333 sq.rw.un_980  da.cs.sk_521 eu.lg.sw_432
  // [9200]
  0x2d00091b, 0x09201207, 0x0b002104, 0x64003f02,   // pl.sk.un_770 hu.sq.pl_432  jw.es.un_320 af.lg.un_220
  0x3f2055ad, 0x0b182755, 0x53050c07, 0x0c00080b,   // rw.sq.af_643 gd.ga.es_442  sv.fr.ht_432 no.sv.un_520
  0x12006405, 0x026406a0, 0x012310a4, 0x172d1612,   // lg.hu.un_330 de.lg.da_322  lt.ca.en_433 hr.sk.sr_654
  0x11001305, 0x6b0f20a7, 0x13060455, 0x12203f07,   // et.ro.un_330 sq.lv.ceb_532  fi.de.et_442 af.sq.hu_432
  // [9210]
  0x17000602, 0x64002019, 0x0a0811a6, 0x28000a07,   // de.sr.un_220 sq.lg.un_750  ro.uk.mk_521 pt.sw.un_420
  0x031b0107, 0x0a000805, 0x27181f0c, 0x0106200b,   // en.tr.nl_432 uk.mk.un_330  cy.ga.gd_543 sq.de.en_542
  0x6b182708, 0x53042508, 0x13292aa4, 0x28271104,   // gd.ga.ceb_443 eu.fi.ht_443  mt.sl.et_433 ro.gd.sw_332
  0x120c0608, 0x18080508, 0x252a29ad, 0x29002a1b,   // de.sv.hu_443 fr.no.ga_443  sl.mt.eu_643 mt.sl.un_770
  // [9220]
  0x091304a4, 0x12003f08, 0x07081012, 0x2a132904,   // fi.et.pl_433 af.hu.un_430  be.uk.bg_654 sl.et.mt_332
  0x041708a9, 0x2a2029af, 0x0c090ead, 0x0e000b07,   // uk.sr.ru_544 sl.sq.mt_655  is.pl.sv_643 es.is.un_420
  0x1c002904, 0x160c01ee, 0x0118050c, 0x1b2503a0,   // sl.id.un_320 en.sv.hr_422  fr.ga.en_543 nl.eu.tr_322
  0x251827a9, 0x31182709, 0x030601a4, 0x121b25ee,   // gd.ga.eu_544 gd.ga.az_444  en.de.nl_433 eu.tr.hu_422
  // [9230]
  0x0c000f08, 0x121329ad, 0x180b1911, 0x0c2a0107,   // lv.sv.un_430 sl.et.hu_643  gl.es.ga_653 en.mt.sv_432
  0x20292a0c, 0x25132104, 0x0c292a0c, 0x132904a4,   // mt.sl.sq_543 jw.et.eu_332  mt.sl.sv_543 fi.sl.et_433
  0x0e1e1c05, 0x01000c07, 0x1e1c53ee, 0x2d0406a0,   // id.ms.is_333 sv.en.un_420  ht.id.ms_422 de.fi.sk_322
  0x1a006413, 0x20000205, 0x19182004, 0x080710ee,   // lg.tl.un_650 da.sq.un_330  sq.ga.gl_332 be.bg.uk_422
  // [9240]
  0x551a64a6, 0x032b010c, 0x0e09125a, 0x6e001b05,   // lg.tl.rw_521 en.vi.nl_543  hu.pl.is_553 tr.blu.un_330
  0x0c020107, 0x011929a0, 0x1600530b, 0x17006e08,   // en.da.sv_432 sl.gl.en_322  ht.hr.un_520 blu.sr.un_430
  0x1a6b01a0, 0x190729a0, 0x28001e19, 0x0802210e,   // en.ceb.tl_322 sl.it.gl_322  ms.sw.un_750 jw.da.no_555
  0x19230b0c, 0x290d110c, 0x2a312004, 0x2a001107,   // es.ca.gl_543 ro.cs.sl_543  sq.az.mt_332 ro.mt.un_420
  // [9250]
  0x110413af, 0x0d000107, 0x641a01ee, 0x101f0107,   // et.fi.ro_655 en.cs.un_420  en.tl.lg_422 en.cy.lt_432
  0x2b002902, 0x1f2718a4, 0x551b1aec, 0x1b1a1ea9,   // sl.vi.un_220 ga.gd.cy_433  tl.tr.rw_644 ms.tl.tr_544
  0x16211807, 0x190b0904, 0x1a1c1e0c, 0x25642807,   // ga.jw.hr_432 pl.es.gl_332  ms.id.tl_543 sw.lg.eu_432
  0x16000709, 0x28551e07, 0x290a1104, 0x236b0a02,   // it.hr.un_440 ms.rw.sw_432  ro.pt.sl_332 pt.ceb.ca_222
  // [9260]
  0x281a1ea0, 0x2713100c, 0x19022904, 0x06006e0b,   // ms.tl.sw_322 lt.et.gd_543  sl.da.gl_332 blu.de.un_520
  0x10001105, 0x1a211ca9, 0x25002019, 0x0e03130c,   // ro.lt.un_330 id.jw.tl_544  sq.eu.un_750 et.nl.is_543
  0x06056e07, 0x64002d04, 0x64212814, 0x282013a0,   // blu.fr.de_432 sk.lg.un_320  sw.jw.lg_666 et.sq.sw_322
  0x1c00280d, 0x3f1f6ead, 0x29312b0d, 0x2a1607a6,   // sw.id.un_540 blu.cy.af_643  vi.az.sl_554 it.hr.mt_521
  // [9270]
  0x281b550c, 0x111304a0, 0x101104ad, 0x20003113,   // rw.tr.sw_543 fi.et.ro_322  ru.ro.be_643 az.sq.un_650
  0x55001f04, 0x120413ad, 0x121e25a0, 0x55271e0c,   // cy.rw.un_320 et.fi.hu_643  eu.ms.hu_322 ms.gd.rw_543
  0x131a1c07, 0x3f002904, 0x20001e02, 0x0f0c1304,   // id.tl.et_432 sl.af.un_320  ms.sq.un_220 et.sv.lv_332
  0x0f0b0ca4, 0x530827af, 0x18063fa0, 0x290413ee,   // sv.es.lv_433 gd.no.ht_655  af.de.ga_322 et.fi.sl_422
  // [9280]
  0x1e000604, 0x23052a02, 0x2b000e09, 0x03133f02,   // de.ms.un_320 mt.fr.ca_222  is.vi.un_440 af.et.nl_222
  0x27001835, 0x0d006e08, 0x13001f0e, 0x6e2718ad,   // ga.gd.un_A90 blu.cs.un_430  cy.et.un_550 ga.gd.blu_643
  0x6b0955ee, 0x27000618, 0x0d270607, 0x06000d04,   // rw.pl.ceb_422 de.gd.un_740  de.gd.cs_432 cs.de.un_320
  0x05190b09, 0x12131ba4, 0x04031b12, 0x13033fa4,   // es.gl.fr_444 tr.et.hu_433  tr.nl.fi_654 af.nl.et_433
  // [9290]
  0x016b13a0, 0x2a3f1bee, 0x18270ea7, 0x040a0ba0,   // et.ceb.en_322 tr.af.mt_422  is.gd.ga_532 es.pt.fi_322
  0x010f13a0, 0x315509ee, 0x08132704, 0x0417100d,   // et.lv.en_322 pl.rw.az_422  gd.et.no_332 be.sr.ru_554
  0x03083f04, 0x1c1f210b, 0x2b3f010b, 0x1a1901a0,   // af.no.nl_332 jw.cy.id_542  en.af.vi_542 en.gl.tl_322
  0x3f640207, 0x10080fa6, 0x53001704, 0x03001b08,   // da.lg.af_432 lv.no.lt_521  sr.ht.un_320 tr.nl.un_430
  // [92a0]
  0x1c1b1ea4, 0x252010a4, 0x03040807, 0x13002913,   // ms.tr.id_433 lt.sq.eu_433  no.fi.nl_432 sl.et.un_650
  0x29002a09, 0x3f1311ad, 0x120d2da7, 0x2b022107,   // mt.sl.un_440 ro.et.af_643  sk.cs.hu_532 jw.da.vi_432
  0x0e131ba7, 0x070c0411, 0x13160fa0, 0x13290f08,   // tr.et.is_532 fi.sv.it_653  lv.hr.et_322 lv.sl.et_443
  0x0c091602, 0x29132a12, 0x1a6b6414, 0x2a001f0d,   // hr.pl.sv_222 mt.et.sl_654  lg.ceb.tl_666 cy.mt.un_540
  // [92b0]
  0x05073f08, 0x130f28ee, 0x130412a4, 0x2a00531a,   // af.it.fr_443 sw.lv.et_422  hu.fi.et_433 ht.mt.un_760
  0x041827a0, 0x19000705, 0x13123fa4, 0x09000f21,   // gd.ga.fi_322 it.gl.un_330  af.hu.et_433 lv.pl.un_860
  0x04000f19, 0x170407a9, 0x07000a0b, 0x2800110e,   // lv.fi.un_750 bg.ru.sr_544  mk.bg.un_520 ro.sw.un_550
  0x53640912, 0x13001705, 0x17211e04, 0x1218270d,   // pl.lg.ht_654 sr.et.un_330  ms.jw.sr_332 gd.ga.hu_554
  // [92c0]
  0x0e0906a0, 0x272a06a4, 0x281b25ee, 0x29310ea9,   // de.pl.is_322 de.mt.gd_433  eu.tr.sw_422 is.az.sl_544
  0x6428100c, 0x211604ee, 0x04250f04, 0x13001021,   // lt.sw.lg_543 fi.hr.jw_422  lv.eu.fi_332 lt.et.un_860
  0x04100811, 0x0500270c, 0x21172912, 0x5304050c,   // uk.be.ru_653 gd.fr.un_530  sl.sr.jw_654 fr.fi.ht_543
  0x6b131c07, 0x25006408, 0x11000f19, 0x28112005,   // id.et.ceb_432 lg.eu.un_430  lv.ro.un_750 sq.ro.sw_333
  // [92d0]
  0x11202508, 0x31001012, 0x0f002304, 0x285311a9,   // eu.sq.ro_443 lt.az.un_640  ca.lv.un_320 ro.ht.sw_544
  0x13552508, 0x2a000f05, 0x0b2d1005, 0x19645555,   // eu.rw.et_443 lv.mt.un_330  lt.sk.es_333 rw.lg.gl_442
  0x110b23a4, 0x200c08ee, 0x04170a0d, 0x0608530c,   // ca.es.ro_433 no.sv.sq_422  mk.sr.ru_554 ht.no.de_543
  0x2120640b, 0x08171607, 0x072955a0, 0x2a071ea4,   // lg.sq.jw_542 hr.sr.no_432  rw.sl.it_322 ms.it.mt_433
  // [92e0]
  0x25112005, 0x0400531a, 0x0c0206af, 0x280e20af,   // sq.ro.eu_333 ht.fi.un_760  de.da.sv_655 sq.is.sw_655
  0x1104130c, 0x21001a14, 0x1a641ba0, 0x29641b0c,   // et.fi.ro_543 tl.jw.un_660  tr.lg.tl_322 tr.lg.sl_543
  0x190553a0, 0x04130107, 0x641b21a0, 0x031308a4,   // ht.fr.gl_322 en.et.fi_432  jw.tr.lg_322 no.et.nl_433
  0x27551308, 0x042864a4, 0x082a01ee, 0x281a55ee,   // et.rw.gd_443 lg.sw.fi_433  en.mt.no_422 rw.tl.sw_422
  // [92f0]
  0x0820280c, 0x16080302, 0x0600021b, 0x2a0e08a0,   // sw.sq.no_543 nl.no.hr_222  da.de.un_770 no.is.mt_322
  0x192d0d13, 0x080413af, 0x2a230c0c, 0x050418ad,   // cs.sk.gl_665 et.fi.no_655  sv.ca.mt_543 ga.fi.fr_643
  0x17091607, 0x020f0c04, 0x3f1b1304, 0x3f0c0802,   // hr.pl.sr_432 sv.lv.da_332  et.tr.af_332 no.sv.af_222
  0x0455640d, 0x55640604, 0x13001008, 0x31081ba4,   // lg.rw.fi_554 de.lg.rw_332  lt.et.un_430 tr.no.az_433
  // [9300]
  0x230704ad, 0x11170aec, 0x13010b04, 0x3f021c07,   // fi.it.ca_643 mk.sr.ro_644  es.en.et_332 id.da.af_432
  0x020113ee, 0x283f55a7, 0x13000814, 0x08101308,   // et.en.da_422 rw.af.sw_532  no.et.un_660 et.lt.no_443
  0x31533fad, 0x03533f04, 0x1a6b3f13, 0x0f00250b,   // af.ht.az_643 af.ht.nl_332  af.ceb.tl_665 eu.lv.un_520
  0x1e1c02a0, 0x072501a4, 0x10070804, 0x0b0519af,   // da.id.ms_322 en.eu.it_433  uk.bg.be_332 gl.fr.es_655
  // [9310]
  0x02042bad, 0x16272107, 0x53000322, 0x2b27180d,   // vi.fi.da_643 jw.gd.hr_432  nl.ht.un_870 ga.gd.vi_554
  0x1b041005, 0x3f645504, 0x293f130c, 0x136b10a0,   // lt.fi.tr_333 rw.lg.af_332  et.af.sl_543 lt.ceb.et_322
  0x232b110c, 0x25123fa0, 0x1a2b05ee, 0x311b3f13,   // ro.vi.ca_543 af.hu.eu_322  fr.vi.tl_422 af.tr.az_665
  0x3f01130c, 0x2a1716af, 0x052b1107, 0x08532a0c,   // et.en.af_543 hr.sr.mt_655  ro.vi.fr_432 mt.ht.no_543
  // [9320]
  0x1c10210d, 0x190a2105, 0x531f10a4, 0x0f162904,   // jw.lt.id_554 jw.pt.gl_333  lt.cy.ht_433 sl.hr.lv_332
  0x191f07a0, 0x232b1104, 0x11000612, 0x010b05a9,   // it.cy.gl_322 ro.vi.ca_332  de.ro.un_640 fr.es.en_544
  0x2b2d02a0, 0x20006e13, 0x6e00202b, 0x171605ee,   // da.sk.vi_322 blu.sq.un_650  sq.blu.un_980 fr.hr.sr_422
  0x0e002323, 0x1a211c04, 0x160d29a4, 0x2b001808,   // ca.is.un_880 id.jw.tl_332  sl.cs.hr_433 ga.vi.un_430
  // [9330]
  0x0f00160d, 0x210c6ba9, 0x041028a0, 0x101f110e,   // hr.lv.un_540 ceb.sv.jw_544  sw.lt.fi_322 ro.cy.lt_555
  0x64125512, 0x27001f19, 0x08250411, 0x1b6b3107,   // rw.hu.lg_654 cy.gd.un_750  fi.eu.no_653 az.ceb.tr_432
  0x1a000805, 0x1f000408, 0x18000a04, 0x071f0807,   // no.tl.un_330 fi.cy.un_430  pt.ga.un_320 no.cy.it_432
  0x0b230a12, 0x1f232512, 0x171601ee, 0x170407af,   // pt.ca.es_654 eu.ca.cy_654  en.hr.sr_422 bg.ru.sr_655
  // [9340]
  0x18121904, 0x231101ee, 0x06181104, 0x070106ee,   // gl.hu.ga_332 en.ro.ca_422  ro.ga.de_332 de.en.it_422
  0x162925a0, 0x1e1c2b02, 0x27000108, 0x0a0723a9,   // eu.sl.hr_322 vi.id.ms_222  en.gd.un_430 ca.it.pt_544
  0x641304ad, 0x013123a0, 0x04106eee, 0x2a006e04,   // fi.et.lg_643 ca.az.en_322  blu.lt.fi_422 blu.mt.un_320
  0x6e00531a, 0x07290f04, 0x16006e04, 0x11070a02,   // ht.blu.un_760 lv.sl.it_332  blu.hr.un_320 pt.it.ro_222
  // [9350]
  0x18006e04, 0x10000a13, 0x1e6e1804, 0x12316ead,   // blu.ga.un_320 mk.be.un_650  ga.blu.ms_332 blu.az.hu_643
  0x202a04a4, 0x27121aa0, 0x041331a4, 0x29166b07,   // fi.mt.sq_433 tl.hu.gd_322  az.et.fi_433 ceb.hr.sl_432
  0x28051104, 0x170a1004, 0x2a006e33, 0x04002505,   // ro.fr.sw_332 be.mk.sr_332  blu.mt.un_A70 eu.fi.un_330
  0x641f285a, 0x070e2004, 0x531b0805, 0x6e016b04,   // sw.cy.lg_553 sq.is.it_332  no.tr.ht_333 ceb.en.blu_332
  // [9360]
  0x1b00121a, 0x0c0608a4, 0x121b04a0, 0x08003f12,   // hu.tr.un_760 no.de.sv_433  fi.tr.hu_322 af.no.un_640
  0x06001104, 0x64285504, 0x080425ee, 0x20020508,   // ro.de.un_320 rw.sw.lg_332  eu.fi.no_422 fr.da.sq_443
  0x130420a0, 0x1c3f21a0, 0x20231ca0, 0x53311bec,   // sq.fi.et_322 jw.af.id_322  id.ca.sq_322 tr.az.ht_644
  0x2a1b13a7, 0x1300180c, 0x171620a7, 0x201b53ec,   // et.tr.mt_532 ga.et.un_530  sq.hr.sr_532 ht.tr.sq_644
  // [9370]
  0x3f002120, 0x280425a0, 0x1100200c, 0x29136ea0,   // jw.af.un_850 eu.fi.sw_322  sq.ro.un_530 blu.et.sl_322
  0x25000f1b, 0x6b000502, 0x1a020807, 0x0b00180c,   // lv.eu.un_770 fr.ceb.un_220  no.da.tl_432 ga.es.un_530
  0x6b0607a0, 0x131e1c08, 0x21202802, 0x0e001b2a,   // it.de.ceb_322 id.ms.et_443  sw.sq.jw_222 tr.is.un_970
  0x2820210c, 0x1020230b, 0x17002108, 0x5305230c,   // jw.sq.sw_543 ca.sq.lt_542  jw.sr.un_430 ca.fr.ht_543
  // [9380]
  0x07202107, 0x1a000713, 0x0f231111, 0x162128ad,   // jw.sq.it_432 it.tl.un_650  ro.ca.lv_653 sw.jw.hr_643
  0x215564a0, 0x111e1c5a, 0x0c1b31a7, 0x070420a0,   // lg.rw.jw_322 id.ms.ro_553  az.tr.sv_532 sq.fi.it_322
  0x07170a11, 0x0e001a05, 0x07282008, 0x0e311b11,   // mk.sr.bg_653 tl.is.un_330  sq.sw.it_443 tr.az.is_653
  0x2d0d13ac, 0x64205508, 0x2105100c, 0x0213290c,   // et.cs.sk_632 rw.sq.lg_443  lt.fr.jw_543 sl.et.da_543
  // [9390]
  0x11003105, 0x1b2a53ee, 0x20120e0e, 0x092917af,   // az.ro.un_330 ht.mt.tr_422  is.hu.sq_555 sr.sl.pl_655
  0x6e00062a, 0x10060108, 0x6e002712, 0x1b53120c,   // de.blu.un_970 en.de.lt_443  gd.blu.un_640 hu.ht.tr_543
  0x113f0312, 0x2500080e, 0x6e202aa0, 0x0b002b04,   // nl.af.ro_654 no.eu.un_550  mt.sq.blu_322 vi.es.un_320
  0x192a0aec, 0x063f030c, 0x03096ead, 0x311921a0,   // pt.mt.gl_644 nl.af.de_543  blu.pl.nl_643 jw.gl.az_322
  // [93a0]
  0x10215304, 0x11000b2b, 0x295305a7, 0x0f6e11ad,   // ht.jw.lt_332 es.ro.un_980  fr.ht.sl_532 ro.blu.lv_643
  0x6e00050d, 0x080e0107, 0x27000420, 0x13042da4,   // fr.blu.un_540 en.is.no_432  fi.gd.un_850 sk.fi.et_433
  0x122b21a4, 0x231355ee, 0x101707a4, 0x1300070c,   // jw.vi.hu_433 rw.et.ca_422  bg.sr.be_433 it.et.un_530
  0x122a6e04, 0x2a006b05, 0x04080213, 0x2a006e08,   // blu.mt.hu_332 ceb.mt.un_330  da.no.fi_665 blu.mt.un_430
  // [93b0]
  0x10000e02, 0x55252a07, 0x20002d0c, 0x55002905,   // is.lt.un_220 mt.eu.rw_432  sk.sq.un_530 sl.rw.un_330
  0x04182711, 0x1200080c, 0x040f27a9, 0x08022aa4,   // gd.ga.fi_653 no.hu.un_530  gd.lv.fi_544 mt.da.no_433
  0x1a002705, 0x04252102, 0x53645502, 0x271f1813,   // gd.tl.un_330 jw.eu.fi_222  rw.lg.ht_222 ga.cy.gd_665
  0x18002b1a, 0x31130612, 0x130429ee, 0x0c130807,   // vi.ga.un_760 de.et.az_654  sl.fi.et_422 no.et.sv_432
  // [93c0]
  0x0a001005, 0x2b1c08a6, 0x110f0a08, 0x160b05a0,   // be.mk.un_330 no.id.vi_521  pt.lv.ro_443 fr.es.hr_322
  0x0f001213, 0x13000119, 0x5300200e, 0x0f1716ad,   // hu.lv.un_650 en.et.un_750  sq.ht.un_550 hr.sr.lv_643
  0x0a0f11a0, 0x192d0d0c, 0x17122905, 0x6b060107,   // ro.lv.pt_322 cs.sk.gl_543  sl.hu.sr_333 en.de.ceb_432
  0x27003104, 0x27201fad, 0x1c080205, 0x2d0218a0,   // az.gd.un_320 cy.sq.gd_643  da.no.id_333 ga.da.sk_322
  // [93d0]
  0x2a2006ec, 0x272a21a0, 0x29002804, 0x16172a04,   // de.sq.mt_644 jw.mt.gd_322  sw.sl.un_320 mt.sr.hr_332
  0x210f04ee, 0x29176e07, 0x0a0f1255, 0x1b230608,   // fi.lv.jw_422 blu.sr.sl_432  hu.lv.pt_442 de.ca.tr_443
  0x270f1ea0, 0x6e172da9, 0x110a0560, 0x271f0e04,   // ms.lv.gd_322 sk.sr.blu_544  fr.pt.ro_664 is.cy.gd_332
  0x11001214, 0x180206ee, 0x2d0d10a4, 0x0213010c,   // hu.ro.un_660 de.da.ga_422  lt.cs.sk_433 en.et.da_543
  // [93e0]
  0x092d0daf, 0x06053f07, 0x12041c02, 0x1f6e01a4,   // cs.sk.pl_655 af.fr.de_432  id.fi.hu_222 en.blu.cy_433
  0x1f00062a, 0x016b5307, 0x17080207, 0x281764ee,   // de.cy.un_970 ht.ceb.en_432  da.no.sr_432 lg.sr.sw_422
  0x2a002808, 0x1f55530c, 0x110518a4, 0x05012bee,   // sw.mt.un_430 ht.rw.cy_543  ga.fr.ro_433 vi.en.fr_422
  0x07000a2b, 0x532705a6, 0x0d000e0c, 0x3f1827ec,   // mk.bg.un_980 fr.gd.ht_521  is.cs.un_530 gd.ga.af_644
  // [93f0]
  0x55000b02, 0x11003f04, 0x21002b0c, 0x17100405,   // es.rw.un_220 af.ro.un_320  vi.jw.un_530 ru.be.sr_333
  0x3f0105a6, 0x13001109, 0x27000513, 0x27003f0e,   // fr.en.af_521 ro.et.un_440  fr.gd.un_650 af.gd.un_550
  0x09041313, 0x29130fa9, 0x101108ac, 0x1e5564af,   // et.fi.pl_665 lv.et.sl_544  uk.ro.be_632 lg.rw.ms_655
  0x64000409, 0x1e211004, 0x162d0905, 0x20002d05,   // fi.lg.un_440 lt.jw.ms_332  pl.sk.hr_333 sk.sq.un_330

  // [9400]
  0x1800050b, 0x290201a0, 0x13162907, 0x211c280c,   // fr.ga.un_520 en.da.sl_322  sl.hr.et_432 sw.id.jw_543
  0x0d1c06ee, 0x136b1a04, 0x1a000408, 0x0a002d02,   // de.id.cs_422 tl.ceb.et_332  fi.tl.un_430 sk.pt.un_220
  0x07001709, 0x0b00050e, 0x2a551aa0, 0x0105070c,   // sr.bg.un_440 fr.es.un_550  tl.rw.mt_322 it.fr.en_543
  0x31000504, 0x2a0806a0, 0x29090dee, 0x0d122a04,   // fr.az.un_320 de.no.mt_322  cs.pl.sl_422 mt.hu.cs_332
  // [9410]
  0x07110904, 0x051a5302, 0x04642a0c, 0x130464a9,   // pl.ro.it_332 ht.tl.fr_222  mt.lg.fi_543 lg.fi.et_544
  0x2a180907, 0x10070a05, 0x0d00531e, 0x12046413,   // pl.ga.mt_432 mk.bg.be_333  ht.cs.un_830 lg.fi.hu_665
  0x023105ee, 0x28006e07, 0x182a09a7, 0x112913a4,   // fr.az.da_422 blu.sw.un_420  pl.mt.ga_532 et.sl.ro_433
  0x6b042aa0, 0x29200f07, 0x1c1a6bad, 0x291621a7,   // mt.fi.ceb_322 lv.sq.sl_432  ceb.tl.id_643 jw.hr.sl_532
  // [9420]
  0x09002a0c, 0x0b530507, 0x25000912, 0x040c02a4,   // mt.pl.un_530 fr.ht.es_432  pl.eu.un_640 da.sv.fi_433
  0x09033f08, 0x291820ee, 0x04161204, 0x11002012,   // af.nl.pl_443 sq.ga.sl_422  hu.hr.fi_332 sq.ro.un_640
  0x0c291208, 0x201b53a7, 0x2a1a01ec, 0x17000419,   // hu.sl.sv_443 ht.tr.sq_532  en.tl.mt_644 ru.sr.un_750
  0x0c02100c, 0x02002d04, 0x29002104, 0x20006b07,   // lt.da.sv_543 sk.da.un_320  jw.sl.un_320 ceb.sq.un_420
  // [9430]
  0x55020807, 0x11200a0c, 0x131827ad, 0x162a0711,   // no.da.rw_432 pt.sq.ro_543  gd.ga.et_643 it.mt.hr_653
  0x2d160f04, 0x6e00250d, 0x640d16a0, 0x2d0d050b,   // lv.hr.sk_332 eu.blu.un_540  hr.cs.lg_322 fr.cs.sk_542
  0x18012707, 0x2d000512, 0x10000f0b, 0x53002708,   // gd.en.ga_432 fr.sk.un_640  lv.lt.un_520 gd.ht.un_430
  0x18271108, 0x31002819, 0x1c002b04, 0x111609a4,   // ro.gd.ga_443 sw.az.un_750  vi.id.un_320 pl.hr.ro_433
  // [9440]
  0x6b1827a7, 0x28011355, 0x0464250c, 0x160e25a0,   // gd.ga.ceb_532 et.en.sw_442  eu.lg.fi_543 eu.is.hr_322
  0x1f090ba4, 0x2a006b09, 0x17002807, 0x250e1aa0,   // es.pl.cy_433 ceb.mt.un_440  sw.sr.un_420 tl.is.eu_322
  0x550910a0, 0x0d531fad, 0x1e0f1c0c, 0x55001904,   // lt.pl.rw_322 cy.ht.cs_643  id.lv.ms_543 gl.rw.un_320
  0x23000b13, 0x1b31040c, 0x04006413, 0x13046413,   // es.ca.un_650 fi.az.tr_543  lg.fi.un_650 lg.fi.et_665
  // [9450]
  0x12076409, 0x31080204, 0x0306050d, 0x1c000702,   // lg.it.hu_444 da.no.az_332  fr.de.nl_554 it.id.un_220
  0x12640b08, 0x11530607, 0x0b19530c, 0x190b2105,   // es.lg.hu_443 de.ht.ro_432  ht.gl.es_543 jw.es.gl_333
  0x03001119, 0x532028ec, 0x550c0811, 0x0d2129ad,   // ro.nl.un_750 sw.sq.ht_644  no.sv.rw_653 sl.jw.cs_643
  0x270206a0, 0x250e6bee, 0x136404ad, 0x2d190d05,   // de.da.gd_322 ceb.is.eu_422  fi.lg.et_643 cs.gl.sk_333
  // [9460]
  0x055511a6, 0x1a046ba7, 0x10070413, 0x171008af,   // ro.rw.fr_521 ceb.fi.tl_532  ru.bg.be_665 uk.be.sr_655
  0x2d0d2109, 0x06270204, 0x2d0d0a0e, 0x55000307,   // jw.cs.sk_444 da.gd.de_332  pt.cs.sk_555 nl.rw.un_420
  0x0411170d, 0x0c001802, 0x080a1702, 0x08071007,   // sr.ro.ru_554 ga.sv.un_220  sr.mk.uk_222 be.bg.uk_432
  0x190128a6, 0x291720a6, 0x31285512, 0x090a0f02,   // sw.en.gl_521 sq.sr.sl_521  rw.sw.az_654 lv.pt.pl_222
  // [9470]
  0x0817070c, 0x191c20ec, 0x230b0a14, 0x0a001121,   // bg.sr.uk_543 sq.id.gl_644  pt.es.ca_666 ro.mk.un_860
  0x1729280c, 0x2831530c, 0x1b11070c, 0x18001113,   // sw.sl.sr_543 ht.az.sw_543  it.ro.tr_543 ro.ga.un_650
  0x08061302, 0x090521a4, 0x0c0d1ea0, 0x0f28530c,   // et.de.no_222 jw.fr.pl_433  ms.cs.sv_322 ht.sw.lv_543
  0x5364310d, 0x210a27ee, 0x13060c55, 0x1f1a2705,   // az.lg.ht_554 gd.pt.jw_422  sv.de.et_442 gd.tl.cy_333
  // [9480]
  0x2a281c05, 0x281b3108, 0x28311b0d, 0x1000042a,   // id.sw.mt_333 az.tr.sw_443  tr.az.sw_554 ru.be.un_970
  0x09005311, 0x311b17a9, 0x29100fa0, 0x2000310d,   // ht.pl.un_630 sr.tr.az_544  lv.lt.sl_322 az.sq.un_540
  0x0d0b19a7, 0x2d000f13, 0x1f0a13a7, 0x10033f07,   // gl.es.cs_532 lv.sk.un_650  et.pt.cy_532 af.nl.lt_432
  0x21121c07, 0x08120c08, 0x0d2d0e11, 0x13091012,   // id.hu.jw_432 sv.hu.no_443  is.sk.cs_653 lt.pl.et_654
  // [9490]
  0x04186b02, 0x55286408, 0x0b2d1904, 0x0c1203a0,   // ceb.ga.fi_222 lg.sw.rw_443  gl.sk.es_332 nl.hu.sv_322
  0x170d1aa0, 0x0e2d1207, 0x641a5514, 0x10003f13,   // tl.cs.sr_322 hu.sk.is_432  rw.tl.lg_666 af.lt.un_650
  0x1c0f31a0, 0x0f1c1ead, 0x02130d02, 0x6b001b14,   // az.lv.id_322 ms.id.lv_643  cs.et.da_222 tr.ceb.un_660
  0x1b066ba4, 0x315525af, 0x0b0a55ec, 0x040a1155,   // ceb.de.tr_433 eu.rw.az_655  rw.pt.es_644 ro.mk.ru_442
  // [94a0]
  0x55162908, 0x1a0811a4, 0x530b0a02, 0x0600131b,   // sl.hr.rw_443 ro.no.tl_433  pt.es.ht_222 et.de.un_770
  0x0e001e05, 0x0f0206a4, 0x1c5521ad, 0x0f006e14,   // ms.is.un_330 de.da.lv_433  jw.rw.id_643 blu.lv.un_660
  0x13062a11, 0x64002519, 0x100f2da0, 0x6e000113,   // mt.de.et_653 eu.lg.un_750  sk.lv.lt_322 en.blu.un_650
  0x18005321, 0x6e271c07, 0x071716ec, 0x101b0f05,   // ht.ga.un_860 id.gd.blu_432  hr.sr.it_644 lv.tr.lt_333
  // [94b0]
  0x03201755, 0x0d00230e, 0x2a0f6e12, 0x6b001105,   // sr.sq.nl_442 ca.cs.un_550  blu.lv.mt_654 ro.ceb.un_330
  0x08101108, 0x136e0111, 0x04252da9, 0x060c1308,   // ro.be.uk_443 en.blu.et_653  sk.eu.fi_544 et.sv.de_443
  0x03182755, 0x04252004, 0x0c001311, 0x31000802,   // gd.ga.nl_442 sq.eu.fi_332  et.sv.un_630 no.az.un_220
  0x311b09a9, 0x101e1c08, 0x101325ee, 0x12000509,   // pl.tr.az_544 id.ms.lt_443  eu.et.lt_422 fr.hu.un_440
  // [94c0]
  0x282a2307, 0x11011f0c, 0x08071004, 0x291b2004,   // ca.mt.sw_432 cy.en.ro_543  be.bg.uk_332 sq.tr.sl_332
  0x161f17a4, 0x18000302, 0x2d0425a0, 0x311b5307,   // sr.cy.hr_433 nl.ga.un_220  eu.fi.sk_322 ht.tr.az_432
  0x082513a0, 0x120d04a0, 0x21250404, 0x13200409,   // et.eu.no_322 fi.cs.hu_322  fi.eu.jw_332 fi.sq.et_444
  0x17000308, 0x53001204, 0x6b0b5512, 0x182d0d0d,   // nl.sr.un_430 hu.ht.un_320  rw.es.ceb_654 cs.sk.ga_554
  // [94d0]
  0x1b120c0c, 0x050d1905, 0x0b251eee, 0x0e061207,   // sv.hu.tr_543 gl.cs.fr_333  ms.eu.es_422 hu.de.is_432
  0x2d00050b, 0x6b551a05, 0x062313ad, 0x310f1bee,   // fr.sk.un_520 tl.rw.ceb_333  et.ca.de_643 tr.lv.az_422
  0x25003f04, 0x25201155, 0x2d00090e, 0x1a2b01a4,   // af.eu.un_320 ro.sq.eu_442  pl.sk.un_550 en.vi.tl_433
  0x1b0e0cad, 0x081e16a4, 0x0a2311a9, 0x2d283f04,   // sv.is.tr_643 hr.ms.no_433  ro.ca.pt_544 af.sw.sk_332
  // [94e0]
  0x10002b08, 0x0c00020b, 0x1c000923, 0x27005314,   // vi.lt.un_430 da.sv.un_520  hi.mr.un_880 ht.gd.un_660
  0x2000281a, 0x0c0d28a6, 0x6b6428ad, 0x11642104,   // sw.sq.un_760 sw.cs.sv_521  sw.lg.ceb_643 jw.lg.ro_332
  0x1a216ba9, 0x0d0a19eb, 0x05001022, 0x642853ad,   // ceb.jw.tl_544 gl.pt.cs_662  lt.fr.un_870 ht.sw.lg_643
  0x04642360, 0x0c001b1a, 0x200d16a0, 0x1a6b1212,   // ca.lg.fi_664 tr.sv.un_760  hr.cs.sq_322 hu.ceb.tl_654
  // [94f0]
  0x120b0505, 0x1300641b, 0x532055a0, 0x6b6401ac,   // fr.es.hu_333 lg.et.un_770  rw.sq.ht_322 en.lg.ceb_632
  0x643125a9, 0x0600200d, 0x25071b0c, 0x1a023f04,   // eu.az.lg_544 sq.de.un_540  tr.it.eu_543 af.da.tl_332
  0x191f0aa4, 0x28551fee, 0x6b030255, 0x1a6b64a9,   // pt.cy.gl_433 cy.rw.sw_422  da.nl.ceb_442 lg.ceb.tl_544
  0x04080714, 0x0f190b04, 0x55003f07, 0x1710310c,   // bg.uk.ru_666 es.gl.lv_332  af.rw.un_420 az.lt.sr_543
  // [9500]
  0x10001c08, 0x553f03ad, 0x10001e08, 0x011804a0,   // id.lt.un_430 nl.af.rw_643  ms.lt.un_430 fi.ga.en_322
  0x5320110d, 0x05031002, 0x6b022008, 0x100208a4,   // ro.sq.ht_554 lt.nl.fr_222  sq.da.ceb_443 no.da.lt_433
  0x31071b02, 0x1e001f07, 0x0b006412, 0x080702a0,   // tr.it.az_222 cy.ms.un_420  lg.es.un_640 da.it.no_322
  0x3f031fee, 0x282d10a0, 0x102d20a7, 0x080c0ea7,   // cy.nl.af_422 lt.sk.sw_322  sq.sk.lt_532 is.sv.no_532
  // [9510]
  0x2d1355ad, 0x07002108, 0x135501a0, 0x07082da0,   // rw.et.sk_643 jw.it.un_430  en.rw.et_322 sk.no.it_322
  0x0a0c0608, 0x130c0f04, 0x2d000107, 0x31002102,   // de.sv.pt_443 lv.sv.et_332  en.sk.un_420 jw.az.un_220
  0x171325a0, 0x13081104, 0x06086b04, 0x55643f07,   // eu.et.sr_322 ro.no.et_332  ceb.no.de_332 af.lg.rw_432
  0x282d03a0, 0x0b00120d, 0x0f0c1308, 0x6b552807,   // nl.sk.sw_322 hu.es.un_540  et.sv.lv_443 sw.rw.ceb_432
  // [9520]
  0x2d10130c, 0x09291704, 0x6b1055a0, 0x083f1004,   // et.lt.sk_543 sr.sl.pl_332  rw.lt.ceb_322 lt.af.no_332
  0x13001a05, 0x06030aee, 0x00001c37, 0x28002114,   // tl.et.un_330 pt.nl.de_422  mr.un.un_B00 jw.sw.un_660
  0x082855a0, 0x060f1b07, 0x0b1a1ba0, 0x122a0a07,   // rw.sw.no_322 tr.lv.de_432  tr.tl.es_322 pt.mt.hu_432
  0x12102807, 0x0b0901a0, 0x21000505, 0x01646ba4,   // sw.lt.hu_432 en.pl.es_322  fr.jw.un_330 ceb.lg.en_433
  // [9530]
  0x2064550d, 0x011121a4, 0x17110a08, 0x12040807,   // rw.lg.sq_554 jw.ro.en_433  mk.ro.sr_443 no.fi.hu_432
  0x0f1f5507, 0x04212008, 0x20552813, 0x130d2da4,   // rw.cy.lv_432 sq.jw.fi_443  sw.rw.sq_665 sk.cs.et_433
  0x042128a4, 0x13092aee, 0x1c002302, 0x070817af,   // sw.jw.fi_433 mt.pl.et_422  ca.id.un_220 sr.uk.bg_655
  0x16091eee, 0x642521a4, 0x071708a7, 0x211e5304,   // ms.pl.hr_422 jw.eu.lg_433  uk.sr.bg_532 ht.ms.jw_332
  // [9540]
  0x1f1611a4, 0x310e0c04, 0x3f1a03ee, 0x02000e21,   // ro.hr.cy_433 sv.is.az_332  nl.tl.af_422 is.da.un_860
  0x6b552a07, 0x100a115a, 0x27001014, 0x31531b08,   // mt.rw.ceb_432 ro.mk.be_553  lt.gd.un_660 tr.ht.az_443
  0x55641b07, 0x081f270c, 0x120b19ee, 0x1716550c,   // tr.lg.rw_432 gd.cy.no_543  gl.es.hu_422 rw.hr.sr_543
  0x64311bad, 0x1b12100c, 0x12130112, 0x25645513,   // tr.az.lg_643 lt.hu.tr_543  en.et.hu_654 rw.lg.eu_665
  // [9550]
  0x171613ec, 0x19252304, 0x1a18010c, 0x552a2804,   // et.hr.sr_644 ca.eu.gl_332  en.ga.tl_543 sw.mt.rw_332
  0x06000908, 0x0b0807a4, 0x2100282a, 0x12051802,   // pl.de.un_430 it.no.es_433  sw.jw.un_970 ga.fr.hu_222
  0x0d002a08, 0x2a002814, 0x1300211a, 0x1e1c2005,   // mt.cs.un_430 sw.mt.un_660  jw.et.un_760 sq.id.ms_333
  0x646b1aee, 0x1917640c, 0x0c0221a0, 0x64292d55,   // tl.ceb.lg_422 lg.sr.gl_543  jw.da.sv_322 sk.sl.lg_442
  // [9560]
  0x1e1a6b13, 0x1c131104, 0x13045355, 0x21551f07,   // ceb.tl.ms_665 ro.et.id_332  ht.fi.et_442 cy.rw.jw_432
  0x111304ee, 0x10182713, 0x2d170912, 0x13120760,   // fi.et.ro_422 gd.ga.lt_665  pl.sr.sk_654 it.hu.et_664
  0x11002914, 0x111e1c60, 0x0e0b1907, 0x0d190bec,   // sl.ro.un_660 id.ms.ro_664  gl.es.is_432 es.gl.cs_644
  0x135504a9, 0x1311040c, 0x060e0407, 0x17100402,   // fi.rw.et_544 fi.ro.et_543  fi.is.de_432 ru.be.sr_222
  // [9570]
  0x0e1f0ba0, 0x086b5309, 0x1a002507, 0x12000a08,   // es.cy.is_322 ht.ceb.no_444  eu.tl.un_420 pt.hu.un_430
  0x23532904, 0x10000307, 0x04201312, 0x20001e0c,   // sl.ht.ca_332 nl.lt.un_420  et.sq.fi_654 ms.sq.un_530
  0x211353a0, 0x182127a4, 0x0e062707, 0x29000f11,   // ht.et.jw_322 gd.jw.ga_433  gd.de.is_432 lv.sl.un_630
  0x17162b02, 0x16120f60, 0x1b1827af, 0x11070a0c,   // vi.hr.sr_222 lv.hu.hr_664  gd.ga.tr_655 mk.bg.ro_543
  // [9580]
  0x12050aa4, 0x112a070c, 0x27011107, 0x13552805,   // pt.fr.hu_433 it.mt.ro_543  ro.en.gd_432 sw.rw.et_333
  0x122103af, 0x271f2a12, 0x0e001122, 0x1b1107ee,   // nl.jw.hu_655 mt.cy.gd_654  ro.is.un_870 it.ro.tr_422
  0x3f1f0107, 0x061b53ee, 0x18052712, 0x21311b11,   // en.cy.af_432 ht.tr.de_422  gd.fr.ga_654 tr.az.jw_653
  0x03126408, 0x3f001a05, 0x29090da7, 0x2a00030c,   // lg.hu.nl_443 tl.af.un_330  cs.pl.sl_532 nl.mt.un_530
  // [9590]
  0x0717110d, 0x25033f08, 0x1f000d13, 0x5500210e,   // ro.sr.bg_554 af.nl.eu_443  cs.cy.un_650 jw.rw.un_550
  0x0e1b2ba0, 0x100a08a9, 0x3f050604, 0x230d0e04,   // vi.tr.is_322 uk.mk.be_544  de.fr.af_332 is.cs.ca_332
  0x2d1617a7, 0x1200030e, 0x27001f04, 0x64001212,   // sr.hr.sk_532 nl.hu.un_550  cy.gd.un_320 hu.lg.un_640
  0x25050804, 0x18211c05, 0x01005505, 0x03642811,   // no.fr.eu_332 id.jw.ga_333  rw.en.un_330 sw.lg.nl_653
  // [95a0]
  0x0917160d, 0x033f55a9, 0x1a215304, 0x531a210b,   // hr.sr.pl_554 rw.af.nl_544  ht.jw.tl_332 jw.tl.ht_542
  0x3f6412a4, 0x13281207, 0x122d0a0c, 0x6b1a21a7,   // hu.lg.af_433 hu.sw.et_432  pt.sk.hu_543 jw.tl.ceb_532
  0x3f211aee, 0x01001302, 0x1100271b, 0x13211a0b,   // tl.jw.af_422 et.en.un_220  gd.ro.un_770 tl.jw.et_542
  0x2800030e, 0x2b1c2aa0, 0x0d0953a0, 0x1f00181b,   // nl.sw.un_550 mt.id.vi_322  ht.pl.cs_322 ga.cy.un_770
  // [95b0]
  0x55000404, 0x1a6b21ec, 0x060220a7, 0x092d110c,   // fi.rw.un_320 jw.ceb.tl_644  sq.da.de_532 ro.sk.pl_543
  0x030108ee, 0x641a2814, 0x033f1aa0, 0x6b002112,   // no.en.nl_422 sw.tl.lg_666  tl.af.nl_322 jw.ceb.un_640
  0x2855110c, 0x53112504, 0x21021aa0, 0x533f0d07,   // ro.rw.sw_543 eu.ro.ht_332  tl.da.jw_322 cs.af.ht_432
  0x23033f13, 0x121e5504, 0x08041113, 0x12002b22,   // af.nl.ca_665 rw.ms.hu_332  ro.ru.uk_665 vi.hu.un_870
  // [95c0]
  0x201101a4, 0x07110455, 0x0c13060d, 0x0e122b0d,   // en.ro.sq_433 ru.ro.bg_442  de.et.sv_554 vi.hu.is_554
  0x08043fa7, 0x172921a9, 0x5521530d, 0x04006b04,   // af.fi.no_532 jw.sl.sr_544  ht.jw.rw_554 ceb.fi.un_320
  0x0e0d2bec, 0x21002807, 0x283164ee, 0x1c011ea0,   // vi.cs.is_644 sw.jw.un_420  lg.az.sw_422 ms.en.id_322
  0x532b06ee, 0x1c005305, 0x2d0d1ca0, 0x53211b12,   // de.vi.ht_422 ht.id.un_330  id.cs.sk_322 tr.jw.ht_654
  // [95d0]
  0x0a230eee, 0x211b29a9, 0x1b0625a4, 0x072a11a0,   // is.ca.pt_422 sl.tr.jw_544  eu.de.tr_433 ro.mt.it_322
  0x1c211b12, 0x04005323, 0x015305ad, 0x0a055304,   // tr.jw.id_654 ht.fi.un_880  fr.ht.en_643 ht.fr.pt_332
  0x0c0d09ad, 0x2b002504, 0x0f3f110c, 0x02112508,   // pl.cs.sv_643 eu.vi.un_320  ro.af.lv_543 eu.ro.da_443
  0x23071f05, 0x6b05530c, 0x05000121, 0x17293f0c,   // cy.it.ca_333 ht.fr.ceb_543  en.fr.un_860 af.sl.sr_543
  // [95e0]
  0x53000514, 0x05001b08, 0x01530507, 0x530c0a04,   // fr.ht.un_660 tr.fr.un_430  fr.ht.en_432 pt.sv.ht_332
  0x2a212002, 0x041b5555, 0x12023f0b, 0x02530507,   // sq.jw.mt_222 rw.tr.fi_442  af.da.hu_542 fr.ht.da_432
  0x64551b13, 0x05530d12, 0x530205a4, 0x28000402,   // tr.rw.lg_665 cs.ht.fr_654  fr.da.ht_433 fi.sw.un_220
  0x17000411, 0x06531104, 0x0d53050c, 0x0f000e12,   // ru.sr.un_630 ro.ht.de_332  fr.ht.cs_543 is.lv.un_640
  // [95f0]
  0x17000204, 0x13041112, 0x20311b55, 0x201c2102,   // da.sr.un_320 ro.fi.et_654  tr.az.sq_442 jw.id.sq_222
  0x16005508, 0x0d091c0b, 0x07272aee, 0x1c0221ee,   // rw.hr.un_430 mr.hi.ne_542  mt.gd.it_422 jw.da.id_422
  0x2a00200d, 0x09112da0, 0x041b0f0c, 0x11005502,   // sq.mt.un_540 sk.ro.pl_322  lv.tr.fi_543 rw.ro.un_220
  0x10130b08, 0x3f27040c, 0x1f0801ee, 0x530a1112,   // es.et.lt_443 fi.gd.af_543  en.no.cy_422 ro.pt.ht_654
  // [9600]
  0x3f0801a4, 0x280107a0, 0x190a1bac, 0x0e130204,   // en.no.af_433 it.en.sw_322  tr.pt.gl_632 da.et.is_332
  0x0e060ca4, 0x190b1b09, 0x013f040c, 0x20290da4,   // sv.de.is_433 tr.es.gl_444  fi.af.en_543 cs.sl.sq_433
  0x0e0c0655, 0x05080104, 0x02006e0c, 0x20002a12,   // de.sv.is_442 en.no.fr_332  blu.da.un_530 mt.sq.un_640
  0x18112bee, 0x102d2912, 0x060c080b, 0x1a001b02,   // vi.ro.ga_422 sl.sk.lt_654  no.sv.de_542 tr.tl.un_220
  // [9610]
  0x02160ca0, 0x1b1a6b55, 0x026b55ad, 0x100e1f0c,   // sv.hr.da_322 ceb.tl.tr_442  rw.ceb.da_643 cy.is.lt_543
  0x11311b5a, 0x0b162105, 0x1b160705, 0x28000713,   // tr.az.ro_553 jw.hr.es_333  it.hr.tr_333 it.sw.un_650
  0x19070aa9, 0x2d0d55af, 0x080213a4, 0x2b0e120c,   // pt.it.gl_544 rw.cs.sk_655  et.da.no_433 hu.is.vi_543
  0x0b102912, 0x03002b0c, 0x12080eec, 0x18280a02,   // sl.lt.es_654 vi.nl.un_530  is.no.hu_644 pt.sw.ga_222
  // [9620]
  0x64552d0d, 0x12002b08, 0x2b002002, 0x0e0464a0,   // sk.rw.lg_554 vi.hu.un_430  sq.vi.un_220 lg.fi.is_322
  0x2164040c, 0x286b6460, 0x1a162505, 0x3f5306a7,   // fi.lg.jw_543 lg.ceb.sw_664  eu.hr.tl_333 de.ht.af_532
  0x1b0612a6, 0x21096412, 0x1228555a, 0x0b001313,   // hu.de.tr_521 lg.pl.jw_654  rw.sw.hu_553 et.es.un_650
  0x1a6b01a4, 0x12002b0c, 0x200c2aa0, 0x286412ad,   // en.ceb.tl_433 vi.hu.un_530  mt.sv.sq_322 hu.lg.sw_643
  // [9630]
  0x08005304, 0x1a003f08, 0x2d200805, 0x05000d1a,   // ht.no.un_320 af.tl.un_430  no.sq.sk_333 cs.fr.un_760
  0x1200230c, 0x1c1e250b, 0x0d170455, 0x04093fa4,   // ca.hu.un_530 eu.ms.id_542  fi.sr.cs_442 af.pl.fi_433
  0x273f010c, 0x1125170d, 0x2127280c, 0x2d1827a0,   // en.af.gd_543 sr.eu.ro_554  sw.gd.jw_543 gd.ga.sk_322
  0x061c2702, 0x0b00090c, 0x0c000313, 0x022d0608,   // gd.id.de_222 pl.es.un_530  nl.sv.un_650 de.sk.da_443
  // [9640]
  0x0c063f04, 0x1a130b08, 0x1200060c, 0x1f0e13a7,   // af.de.sv_332 es.et.tl_443  de.hu.un_530 et.is.cy_532
  0x02002905, 0x10071708, 0x01033fa9, 0x1f2701a0,   // sl.da.un_330 sr.bg.be_443  af.nl.en_544 en.gd.cy_322
  0x100c6bad, 0x12012aa0, 0x2a00080c, 0x09000a0c,   // ceb.sv.lt_643 mt.en.hu_322  no.mt.un_530 pt.pl.un_530
  0x2d285507, 0x1c001321, 0x13200f04, 0x18000a19,   // rw.sw.sk_432 bh.mr.un_860  lv.sq.et_332 pt.ga.un_750
  // [9650]
  0x102a12a0, 0x0f006412, 0x29020602, 0x00006e01,   // hu.mt.lt_322 lg.lv.un_640  de.da.sl_222 blu.un.un_200
  0x1a2d29ad, 0x095305a7, 0x16091b07, 0x02001004,   // sl.sk.tl_643 fr.ht.pl_532  tr.pl.hr_432 lt.da.un_320
  0x080c1eee, 0x2a000422, 0x53002a05, 0x231204a4,   // ms.sv.no_422 fi.mt.un_870  mt.ht.un_330 fi.hu.ca_433
  0x046b010c, 0x296420a6, 0x01001204, 0x120304a0,   // en.ceb.fi_543 sq.lg.sl_521  hu.en.un_320 fi.nl.hu_322
  // [9660]
  0x1c215509, 0x3f00641a, 0x09200daf, 0x0e033f05,   // rw.jw.id_444 lg.af.un_760  cs.sq.pl_655 af.nl.is_333
  0x290f0707, 0x1c170707, 0x1b006412, 0x111b3113,   // it.lv.sl_432 it.sr.id_432  lg.tr.un_640 az.tr.ro_665
  0x6400100e, 0x0c061208, 0x0e3f120c, 0x083f1fa4,   // lt.lg.un_550 hu.de.sv_443  hu.af.is_543 cy.af.no_433
  0x04110a07, 0x120227a4, 0x3f2a6405, 0x1b1e270c,   // mk.ro.ru_432 gd.da.hu_433  lg.mt.af_333 gd.ms.tr_543
  // [9670]
  0x0a0b2308, 0x081107af, 0x2a002009, 0x0700270c,   // ca.es.pt_443 bg.ro.uk_655  sq.mt.un_440 gd.it.un_530
  0x0e000614, 0x27001f0e, 0x18001908, 0x530827a0,   // de.is.un_660 cy.gd.un_550  gl.ga.un_430 gd.no.ht_322
  0x111806ee, 0x31001604, 0x2b270ba0, 0x17100f04,   // de.ga.ro_422 hr.az.un_320  es.gd.vi_322 lv.lt.sr_332
  0x1308020c, 0x07000e11, 0x0400130b, 0x271b3114,   // da.no.et_543 is.it.un_630  et.fi.un_520 az.tr.gd_666
  // [9680]
  0x251827a7, 0x1e1c2805, 0x012511a0, 0x02060c05,   // gd.ga.eu_532 sw.id.ms_333  ro.eu.en_322 sv.de.da_333
  0x0c000e14, 0x13060c0b, 0x21001022, 0x2028130c,   // is.sv.un_660 sv.de.et_542  lt.jw.un_870 et.sw.sq_543
  0x28000b07, 0x172829af, 0x1e1c13a4, 0x16002912,   // es.sw.un_420 sl.sw.sr_655  et.id.ms_433 sl.hr.un_640
  0x11041308, 0x290d160e, 0x11001320, 0x17000f19,   // et.fi.ro_443 hr.cs.sl_555  et.ro.un_850 lv.sr.un_750
  // [9690]
  0x101c1e07, 0x161020a0, 0x2511130b, 0x060c2da0,   // ms.id.lt_432 sq.lt.hr_322  et.ro.eu_542 sk.sv.de_322
  0x282111a7, 0x08020e13, 0x0e0d21ee, 0x28171605,   // ro.jw.sw_532 is.da.no_665  jw.cs.is_422 hr.sr.sw_333
  0x0a042008, 0x18282aa0, 0x0b00050d, 0x1f2801a0,   // sq.fi.pt_443 mt.sw.ga_322  fr.es.un_540 en.sw.cy_322
  0x252829a9, 0x200f28af, 0x23002a0d, 0x53072a0b,   // sl.sw.eu_544 sw.lv.sq_655  mt.ca.un_540 mt.it.ht_542
  // [96a0]
  0x3f0d0704, 0x6428130c, 0x01112a07, 0x130f0404,   // it.cs.af_332 et.sw.lg_543  mt.ro.en_432 fi.lv.et_332
  0x2900170c, 0x1b071112, 0x0f002107, 0x1f002a22,   // sr.sl.un_530 ro.it.tr_654  jw.lv.un_420 mt.cy.un_870
  0x29002814, 0x23001f1b, 0x280113ee, 0x061e1c07,   // sw.sl.un_660 cy.ca.un_770  et.en.sw_422 id.ms.de_432
  0x081213ec, 0x20160804, 0x18016bee, 0x2a191aa0,   // et.hu.no_644 no.hr.sq_332  ceb.en.ga_422 tl.gl.mt_322
  // [96b0]
  0x070501af, 0x6b1e1c0d, 0x6b211307, 0x03080ca7,   // en.fr.it_655 id.ms.ceb_554  et.jw.ceb_432 sv.no.nl_532
  0x55061f08, 0x040a08a9, 0x2b000a09, 0x19201105,   // cy.de.rw_443 uk.mk.ru_544  pt.vi.un_440 ro.sq.gl_333
  0x17133f04, 0x230553b2, 0x5300201a, 0x12002d18,   // af.et.sr_332 ht.fr.ca_732  sq.ht.un_760 sk.hu.un_740
  0x1e1c06a9, 0x120964ad, 0x31281207, 0x08001208,   // de.id.ms_544 lg.pl.hu_643  hu.sw.az_432 hu.no.un_430
  // [96c0]
  0x64000618, 0x1f00090d, 0x080212a6, 0x01052bec,   // de.lg.un_740 pl.cy.un_540  hu.da.no_521 vi.fr.en_644
  0x25551308, 0x16171011, 0x13211207, 0x1f3f0208,   // et.rw.eu_443 lt.sr.hr_653  hu.jw.et_432 da.af.cy_443
  0x0b132307, 0x21281f0d, 0x291216ad, 0x060c0107,   // ca.et.es_432 cy.sw.jw_554  hr.hu.sl_643 en.sv.de_432
  0x53001307, 0x0c090607, 0x0b052312, 0x16060c04,   // et.ht.un_420 de.pl.sv_432  ca.fr.es_654 sv.de.hr_332
  // [96d0]
  0x050201a0, 0x0200551a, 0x02001f1a, 0x020c0107,   // en.da.fr_322 rw.da.un_760  cy.da.un_760 en.sv.da_432
  0x01060ca4, 0x0d006e07, 0x1710080b, 0x08020902,   // sv.de.en_433 blu.cs.un_420  uk.be.sr_542 pl.da.no_222
  0x0b2305ac, 0x13000323, 0x13033f55, 0x28553f04,   // fr.ca.es_632 nl.et.un_880  af.nl.et_442 af.rw.sw_332
  0x190e2da0, 0x0a070811, 0x1f1301ee, 0x18002302,   // sk.is.gl_322 uk.bg.mk_653  en.et.cy_422 ca.ga.un_220
  // [96e0]
  0x010c0611, 0x1f0501af, 0x531827af, 0x051b1a11,   // de.sv.en_653 en.fr.cy_655  gd.ga.ht_655 tl.tr.fr_653
  0x270401a9, 0x6b1b010c, 0x1a1b6b13, 0x032a2da0,   // en.fi.gd_544 en.tr.ceb_543  ceb.tr.tl_665 sk.mt.nl_322
  0x21171107, 0x13102807, 0x0e001f1a, 0x012d1fa6,   // ro.sr.jw_432 sw.lt.et_432  cy.is.un_760 cy.sk.en_521
  0x06133fa9, 0x070811a9, 0x042527af, 0x1716130c,   // af.et.de_544 ro.uk.bg_544  gd.eu.fi_655 et.hr.sr_543
  // [96f0]
  0x1e111ba0, 0x020f06a0, 0x01001313, 0x31001a08,   // tr.ro.ms_322 de.lv.da_322  et.en.un_650 tl.az.un_430
  0x216b1b04, 0x31043fa4, 0x230b0504, 0x1c052104,   // tr.ceb.jw_332 af.fi.az_433  fr.es.ca_332 jw.fr.id_332
  0x12002b07, 0x1f000122, 0x121c21a0, 0x1a002702,   // vi.hu.un_420 en.cy.un_870  jw.id.hu_322 gd.tl.un_220
  0x53041ea0, 0x0100060d, 0x17006e07, 0x6b531aa4,   // ms.fi.ht_322 de.en.un_540  blu.sr.un_420 tl.ht.ceb_433
  // [9700]
  0x2a0e010b, 0x0e2a0802, 0x3f06030d, 0x1a6b0405,   // en.is.mt_542 no.mt.is_222  nl.de.af_554 fi.ceb.tl_333
  0x1c122807, 0x173101a0, 0x0d17290c, 0x03230502,   // sw.hu.id_432 en.az.sr_322  sl.sr.cs_543 fr.ca.nl_222
  0x04002307, 0x08040cee, 0x11001909, 0x2d0b12a0,   // ca.fi.un_420 sv.fi.no_422  gl.ro.un_440 hu.es.sk_322
  0x23000708, 0x070c03a0, 0x53256b0b, 0x64001209,   // it.ca.un_430 nl.sv.it_322  ceb.eu.ht_542 hu.lg.un_440
  // [9710]
  0x06001e08, 0x190b1107, 0x171607ee, 0x180d1ea0,   // ms.de.un_430 ro.es.gl_432  it.hr.sr_422 ms.cs.ga_322
  0x2d001707, 0x3f2a18a0, 0x29082807, 0x0c201a02,   // sr.sk.un_420 ga.mt.af_322  sw.no.sl_432 tl.sq.sv_222
  0x19001221, 0x23120507, 0x31000607, 0x131a0402,   // hu.gl.un_860 fr.hu.ca_432  de.az.un_420 fi.tl.et_222
  0x190b2daf, 0x17160d0e, 0x2d0d100b, 0x160e1755,   // sk.es.gl_655 cs.hr.sr_555  lt.cs.sk_542 sr.is.hr_442
  // [9720]
  0x04071713, 0x0c002508, 0x28180104, 0x2d0d27a4,   // sr.bg.ru_665 eu.sv.un_430  en.ga.sw_332 gd.cs.sk_433
  0x272011ee, 0x23190dad, 0x0b1219a7, 0x23000b19,   // ro.sq.gd_422 cs.gl.ca_643  gl.hu.es_532 es.ca.un_750
  0x0b0a07af, 0x190b2311, 0x13000702, 0x290725a7,   // it.pt.es_655 ca.es.gl_653  it.et.un_220 eu.it.sl_532
  0x232d0d04, 0x2d001a05, 0x312855a9, 0x1100070c,   // cs.sk.ca_332 tl.sk.un_330  rw.sw.az_544 it.ro.un_530
  // [9730]
  0x1a64550c, 0x200d1aa4, 0x0b230a0c, 0x09001335,   // rw.lg.tl_543 tl.cs.sq_433  pt.ca.es_543 bh.hi.un_A90
  0x0b290da9, 0x55000b05, 0x1f10290c, 0x0a000c08,   // cs.sl.es_544 es.rw.un_330  sl.lt.cy_543 sv.pt.un_430
  0x0d2d53a0, 0x551a64a4, 0x0b0a07ee, 0x09272da0,   // ht.sk.cs_322 lg.tl.rw_433  it.pt.es_422 sk.gd.pl_322
  0x102d0d14, 0x0a000514, 0x022908a7, 0x13211cad,   // cs.sk.lt_666 fr.pt.un_660  no.sl.da_532 id.jw.et_643
  // [9740]
  0x0b1a6b11, 0x1f20230c, 0x20002509, 0x17160604,   // ceb.tl.es_653 ca.sq.cy_543  eu.sq.un_440 de.hr.sr_332
  0x0911200c, 0x060d2da7, 0x3f0602a7, 0x191a55ee,   // sq.ro.pl_543 sk.cs.de_532  da.de.af_532 rw.tl.gl_422
  0x160617ee, 0x11192305, 0x286b2109, 0x1c001e13,   // sr.de.hr_422 ca.gl.ro_333  jw.ceb.sw_444 ms.id.un_650
  0x55001104, 0x3f112513, 0x2b1a04a7, 0x2b3f10ad,   // ro.rw.un_320 eu.ro.af_665  fi.tl.vi_532 lt.af.vi_643
  // [9750]
  0x1907120b, 0x6b001a18, 0x2a136412, 0x0a1011ad,   // hu.it.gl_542 tl.ceb.un_740  lg.et.mt_654 ro.be.mk_643
  0x0c002912, 0x12000d09, 0x080e16a4, 0x0e271f0c,   // sl.sv.un_640 cs.hu.un_440  hr.is.no_433 cy.gd.is_543
  0x1c00210b, 0x13312d07, 0x081e1c0d, 0x080f1f0c,   // jw.id.un_520 sk.az.et_432  id.ms.no_554 cy.lv.no_543
  0x033f10a6, 0x21281aad, 0x556431a9, 0x180a1207,   // lt.af.nl_521 tl.sw.jw_643  az.lg.rw_544 hu.pt.ga_432
  // [9760]
  0x07290da4, 0x640c0207, 0x0a1c10a7, 0x53552855,   // cs.sl.it_433 da.sv.lg_432  lt.id.pt_532 sw.rw.ht_442
  0x1c041b0e, 0x04071712, 0x3100201b, 0x28102505,   // tr.fi.id_555 sr.bg.ru_654  sq.az.un_770 eu.lt.sw_333
  0x0f55315a, 0x181f0807, 0x0400021a, 0x10202807,   // az.rw.lv_553 no.cy.ga_432  da.fi.un_760 sw.sq.lt_432
  0x2900200e, 0x1a551ba7, 0x090620ee, 0x21311aa0,   // sq.sl.un_550 tr.rw.tl_532  sq.de.pl_422 tl.az.jw_322
  // [9770]
  0x1a216bac, 0x0e180a07, 0x1c531ea0, 0x1e021ca4,   // ceb.jw.tl_632 pt.ga.is_432  ms.ht.id_322 id.da.ms_433
  0x120e0d0b, 0x6e2804a0, 0x041028a4, 0x0d1617a4,   // cs.is.hu_542 fi.sw.blu_322  sw.lt.fi_433 sr.hr.cs_433
  0x0f0413af, 0x046b2804, 0x060a0304, 0x53272b07,   // et.fi.lv_655 sw.ceb.fi_332  nl.pt.de_332 vi.gd.ht_432
  0x050706a0, 0x2900111b, 0x02001f05, 0x190805a0,   // de.it.fr_322 ro.sl.un_770  cy.da.un_330 fr.no.gl_322
  // [9780]
  0x01061211, 0x1300060b, 0x030b23ee, 0x103f0aad,   // hu.de.en_653 de.et.un_520  ca.es.nl_422 pt.af.lt_643
  0x07011f04, 0x042523af, 0x04111704, 0x6b060704,   // cy.en.it_332 ca.eu.fi_655  sr.ro.ru_332 it.de.ceb_332
  0x190b2355, 0x100f1755, 0x25101102, 0x0410170e,   // ca.es.gl_442 sr.lv.lt_442  ro.lt.eu_222 sr.be.ru_555
  0x052507a0, 0x200916ee, 0x1716090b, 0x0d190aa0,   // it.eu.fr_322 hr.pl.sq_422  pl.hr.sr_542 pt.gl.cs_322
  // [9790]
  0x04133f08, 0x2d091902, 0x13006e0d, 0x16192da0,   // af.et.fi_443 gl.pl.sk_222  blu.et.un_540 sk.gl.hr_322
  0x29000d22, 0x186e64ee, 0x530b050c, 0x05011a07,   // cs.sl.un_870 lg.blu.ga_422  fr.es.ht_543 tl.en.fr_432
  0x160917a4, 0x2d001216, 0x12182daf, 0x291017a7,   // sr.pl.hr_433 hu.sk.un_720  sk.ga.hu_655 sr.lt.sl_532
  0x2d000707, 0x2a19250e, 0x0d2d2313, 0x13033faf,   // it.sk.un_420 eu.gl.mt_555  ca.sk.cs_665 af.nl.et_655
  // [97a0]
  0x13296e0c, 0x01002108, 0x136e3f09, 0x2d6e2912,   // blu.sl.et_543 jw.en.un_430  af.blu.et_444 sl.blu.sk_654
  0x6e2101ec, 0x0700081a, 0x6b2318a4, 0x20006e0b,   // en.jw.blu_644 uk.bg.un_760  ga.ca.ceb_433 blu.sq.un_520
  0x0d176eee, 0x17166eaf, 0x1200640c, 0x311b1814,   // blu.sr.cs_422 blu.hr.sr_655  lg.hu.un_530 ga.tr.az_666
  0x041b3155, 0x03061812, 0x10070a0e, 0x171016a7,   // az.tr.fi_442 ga.de.nl_654  mk.bg.be_555 hr.lt.sr_532
  // [97b0]
  0x09001b0d, 0x281c1e0b, 0x64551ea0, 0x120520a4,   // tr.pl.un_540 ms.id.sw_542  ms.rw.lg_322 sq.fr.hu_433
  0x0d0520a7, 0x090628a0, 0x53002111, 0x02530555,   // sq.fr.cs_532 sw.de.pl_322  jw.ht.un_630 fr.ht.da_442
  0x281e6ba0, 0x1b002313, 0x04101104, 0x2a1e1c07,   // ceb.ms.sw_322 ca.tr.un_650  ro.be.ru_332 id.ms.mt_432
  0x17160f02, 0x21020c02, 0x19180e05, 0x040817ee,   // lv.hr.sr_222 sv.da.jw_222  is.ga.gl_333 sr.uk.ru_422
  // [97c0]
  0x02006b02, 0x02061708, 0x2d120513, 0x6b010608,   // ceb.da.un_220 sr.de.da_443  fr.hu.sk_665 de.en.ceb_443
  0x09130d13, 0x1c0601a4, 0x190455a4, 0x1f2a0607,   // ne.bh.hi_665 en.de.id_433  rw.fi.gl_433 de.mt.cy_432
  0x050d12ec, 0x0b6b1a5a, 0x53001212, 0x1c000920,   // hu.cs.fr_644 tl.ceb.es_553  hu.ht.un_640 hi.mr.un_850
  0x0b105507, 0x021b05ad, 0x08001604, 0x20001905,   // rw.lt.es_432 fr.tr.da_643  hr.no.un_320 gl.sq.un_330
  // [97d0]
  0x021b1004, 0x2d162902, 0x250602af, 0x532d19a0,   // lt.tr.da_332 sl.hr.sk_222  da.de.eu_655 gl.sk.ht_322
  0x06031307, 0x13080107, 0x0807170e, 0x1b5528ac,   // et.nl.de_432 en.no.et_432  sr.bg.uk_555 sw.rw.tr_632
  0x1300010b, 0x110c06a4, 0x0e18120e, 0x0e172002,   // en.et.un_520 de.sv.ro_433  hu.ga.is_555 sq.sr.is_222
  0x070810a9, 0x0a1e1c0d, 0x0c0628a0, 0x1a10110c,   // be.uk.bg_544 id.ms.pt_554  sw.de.sv_322 ro.lt.tl_543
  // [97e0]
  0x190b1aa0, 0x3f0621ad, 0x071c1e0b, 0x13001b2b,   // tl.es.gl_322 jw.de.af_643  ms.id.it_542 tr.et.un_980
  0x2b090ba0, 0x101321ee, 0x1a166bad, 0x0a1117ec,   // es.pl.vi_322 jw.et.lt_422  ceb.hr.tl_643 sr.ro.mk_644
  0x27066ea0, 0x642a0308, 0x092016a4, 0x6e005314,   // blu.de.gd_322 nl.mt.lg_443  hr.sq.pl_433 ht.blu.un_660
  0x1a100a05, 0x292d0da7, 0x05016ea0, 0x06006e0e,   // pt.lt.tl_333 cs.sk.sl_532  blu.en.fr_322 blu.de.un_550
  // [97f0]
  0x1a1064a7, 0x193f6ea6, 0x1a296eee, 0x2a04550d,   // lg.lt.tl_532 blu.af.gl_521  blu.sl.tl_422 rw.fi.mt_554
  0x3f6408a4, 0x0e181202, 0x3f0321ee, 0x12091811,   // no.lg.af_433 hu.ga.is_222  jw.nl.af_422 ga.pl.hu_653
  0x17285507, 0x023f2aa0, 0x126e0da0, 0x6b0806a7,   // rw.sw.sr_432 mt.af.da_322  cs.blu.hu_322 de.no.ceb_532
  0x12182312, 0x53092007, 0x286403a9, 0x53001c0d,   // ca.ga.hu_654 sq.pl.ht_432  nl.lg.sw_544 id.ht.un_540

  // [9800]
  0x292a1707, 0x111b1307, 0x21006411, 0x1c216408,   // sr.mt.sl_432 et.tr.ro_432  lg.jw.un_630 lg.jw.id_443
  0x110929a0, 0x251123ad, 0x10251113, 0x116b1a05,   // sl.pl.ro_322 ca.ro.eu_643  ro.eu.lt_665 tl.ceb.ro_333
  0x213f080c, 0x09290a08, 0x1f006e23, 0x033f0805,   // no.af.jw_543 pt.sl.pl_443  blu.cy.un_880 no.af.nl_333
  0x0200030e, 0x64033f12, 0x0a281ca0, 0x2d190a08,   // nl.da.un_550 af.nl.lg_654  id.sw.pt_322 pt.gl.sk_443
  // [9810]
  0x1b190a08, 0x55211c04, 0x532855a7, 0x0d190aa9,   // pt.gl.tr_443 id.jw.rw_332  rw.sw.ht_532 pt.gl.cs_544
  0x04071004, 0x0e2a02a0, 0x53016ba0, 0x2500211b,   // be.bg.ru_332 da.mt.is_322  ceb.en.ht_322 jw.eu.un_770
  0x1b0112a0, 0x0403210c, 0x16006b12, 0x2700230c,   // hu.en.tr_322 jw.nl.fi_543  ceb.hr.un_640 ca.gd.un_530
  0x1e003120, 0x040d2dee, 0x0b1a2104, 0x090629ee,   // az.ms.un_850 sk.cs.fi_422  jw.tl.es_332 sl.de.pl_422
  // [9820]
  0x211c0604, 0x1c07640c, 0x23001216, 0x1a1321a0,   // de.id.jw_332 lg.it.id_543  hu.ca.un_720 jw.et.tl_322
  0x18002735, 0x216e2a05, 0x04080a02, 0x250c3f12,   // gd.ga.un_A90 mt.blu.jw_333  mk.uk.ru_222 af.sv.eu_654
  0x040a170e, 0x5503250c, 0x1b132555, 0x21251e0c,   // sr.mk.ru_555 eu.nl.rw_543  eu.et.tr_442 ms.eu.jw_543
  0x0d06120e, 0x0e0413a9, 0x060328a0, 0x0e000404,   // hu.de.cs_555 et.fi.is_544  sw.nl.de_322 fi.is.un_320
  // [9830]
  0x250e210c, 0x1a001c1a, 0x04252108, 0x31006411,   // jw.is.eu_543 id.tl.un_760  jw.eu.fi_443 lg.az.un_630
  0x211a1ea9, 0x211a1eaf, 0x271f01a9, 0x28085502,   // ms.tl.jw_544 ms.tl.jw_655  en.cy.gd_544 rw.no.sw_222
  0x0c530e13, 0x29001712, 0x272001a9, 0x251c1e07,   // is.ht.sv_665 sr.sl.un_640  en.sq.gd_544 ms.id.eu_432
  0x16000c05, 0x080613ee, 0x08003f19, 0x211110ad,   // sv.hr.un_330 et.de.no_422  af.no.un_750 lt.ro.jw_643
  // [9840]
  0x1100181b, 0x1e1c060c, 0x20110f07, 0x110b0a08,   // ga.ro.un_770 de.id.ms_543  lv.ro.sq_432 pt.es.ro_443
  0x6b1b280c, 0x25231fa9, 0x1e002808, 0x23000613,   // sw.tr.ceb_543 cy.ca.eu_544  sw.ms.un_430 de.ca.un_650
  0x6b001307, 0x1a002135, 0x642718ec, 0x55132507,   // et.ceb.un_420 jw.tl.un_A90  ga.gd.lg_644 eu.et.rw_432
  0x31001922, 0x01000514, 0x6b211a11, 0x6b000808,   // gl.az.un_870 fr.en.un_660  tl.jw.ceb_653 no.ceb.un_430
  // [9850]
  0x6b002508, 0x1e001318, 0x211a6ba9, 0x20000712,   // eu.ceb.un_430 et.ms.un_740  ceb.tl.jw_544 it.sq.un_640
  0x211a1c0c, 0x31001e07, 0x09135508, 0x230608ad,   // id.tl.jw_543 ms.az.un_420  rw.et.pl_443 no.de.ca_643
  0x0d13290d, 0x28000202, 0x0e080ca7, 0x11050708,   // sl.et.cs_554 da.sw.un_220  sv.no.is_532 it.fr.ro_443
  0x1a12130b, 0x0b190707, 0x230d2da9, 0x1b001a08,   // et.hu.tl_542 it.gl.es_432  sk.cs.ca_544 tl.tr.un_430
  // [9860]
  0x211b31a0, 0x1900110c, 0x04126b12, 0x25005507,   // az.tr.jw_322 ro.gl.un_530  ceb.hu.fi_654 rw.eu.un_420
  0x180206a4, 0x1f0e03a0, 0x0f0b10ac, 0x07000105,   // de.da.ga_433 nl.is.cy_322  lt.es.lv_632 en.it.un_330
  0x04001205, 0x642155a0, 0x25190aad, 0x1a0f25a4,   // hu.fi.un_330 rw.jw.lg_322  pt.gl.eu_643 eu.lv.tl_433
  0x1a000f13, 0x0d5311a0, 0x061b3104, 0x19230b12,   // lv.tl.un_650 ro.ht.cs_322  az.tr.de_332 es.ca.gl_654
  // [9870]
  0x03005305, 0x130218ad, 0x12311b07, 0x2a0c0602,   // ht.nl.un_330 ga.da.et_643  tr.az.hu_432 de.sv.mt_222
  0x1b061207, 0x12046b08, 0x101904ee, 0x062d0cee,   // hu.de.tr_432 ceb.fi.hu_443  fi.gl.lt_422 sv.sk.de_422
  0x08001122, 0x04080e0c, 0x53641aa0, 0x03641307,   // ro.uk.un_870 is.no.fi_543  tl.lg.ht_322 et.lg.nl_432
  0x120410a9, 0x3f031a0d, 0x010608a0, 0x060201a0,   // lt.fi.hu_544 tl.nl.af_554  no.de.en_322 en.da.de_322
  // [9880]
  0x0c0601a6, 0x0d033f0c, 0x010806a0, 0x101e1c02,   // en.de.sv_521 af.nl.cs_543  de.no.en_322 id.ms.lt_222
  0x041110af, 0x0c00010d, 0x07641fa0, 0x05212307,   // be.ro.ru_655 en.sv.un_540  cy.lg.it_322 ca.jw.fr_432
  0x0e0f100c, 0x6421200b, 0x08100f11, 0x08000e14,   // lt.lv.is_543 sq.jw.lg_542  lv.lt.no_653 is.no.un_660
  0x3f046ba0, 0x0e03100c, 0x06093fa9, 0x55000a0d,   // ceb.fi.af_322 lt.nl.is_543  af.pl.de_544 pt.rw.un_540
  // [9890]
  0x0b1a6407, 0x27010607, 0x6b1801ec, 0x230b185e,   // lg.tl.es_432 de.en.gd_432  en.ga.ceb_644 ga.es.ca_652
  0x2a2164a0, 0x19006407, 0x033f6ea0, 0x136b1a07,   // lg.jw.mt_322 lg.gl.un_420  blu.af.nl_322 tl.ceb.et_432
  0x135528ee, 0x1c190b55, 0x05190ba4, 0x1f131aa0,   // sw.rw.et_422 es.gl.id_442  es.gl.fr_433 tl.et.cy_322
  0x2a026455, 0x530b0d04, 0x21160da0, 0x550664a0,   // lg.da.mt_442 cs.es.ht_332  cs.hr.jw_322 lg.de.rw_322
  // [98a0]
  0x09063fa0, 0x3f0701ee, 0x0f29110c, 0x07051105,   // af.de.pl_322 en.it.af_422  ro.sl.lv_543 ro.fr.it_333
  0x01076b07, 0x25050d07, 0x29000b04, 0x55530ba0,   // ceb.it.en_432 cs.fr.eu_432  es.sl.un_320 es.ht.rw_322
  0x13211155, 0x04282012, 0x531a6b0c, 0x1b212804,   // ro.jw.et_442 sq.sw.fi_654  ceb.tl.ht_543 sw.jw.tr_332
  0x211b1608, 0x131a100c, 0x215528af, 0x6b102904,   // hr.tr.jw_443 lt.tl.et_543  sw.rw.jw_655 sl.lt.ceb_332
  // [98b0]
  0x170d250c, 0x18091004, 0x0e00110d, 0x160d2dee,   // eu.cs.sr_543 lt.pl.ga_332  ro.is.un_540 sk.cs.hr_422
  0x0d291105, 0x27021f09, 0x252111ad, 0x29100dee,   // ro.sl.cs_333 cy.da.gd_444  ro.jw.eu_643 cs.lt.sl_422
  0x07080cee, 0x0128210c, 0x253f01a4, 0x120510a0,   // sv.no.it_422 jw.sw.en_543  en.af.eu_433 lt.fr.hu_322
  0x11190a05, 0x011f0ca4, 0x042864a0, 0x28002119,   // pt.gl.ro_333 sv.cy.en_433  lg.sw.fi_322 jw.sw.un_750
  // [98c0]
  0x2500011a, 0x2821120c, 0x272b6ba0, 0x1f001018,   // en.eu.un_760 hu.jw.sw_543  ceb.vi.gd_322 lt.cy.un_740
  0x1f002914, 0x19000d11, 0x20251ba7, 0x066b3f02,   // sl.cy.un_660 cs.gl.un_630  tr.eu.sq_532 af.ceb.de_222
  0x02001f09, 0x1f533f07, 0x1f0c0855, 0x1b2512af,   // cy.da.un_440 af.ht.cy_432  no.sv.cy_442 hu.eu.tr_655
  0x27002a11, 0x11000623, 0x210c29a4, 0x102921a0,   // mt.gd.un_630 de.ro.un_880  sl.sv.jw_433 jw.sl.lt_322
  // [98d0]
  0x062d16ee, 0x290709a9, 0x20072905, 0x16172d0b,   // hr.sk.de_422 pl.it.sl_544  sl.it.sq_333 sk.sr.hr_542
  0x0a5504a0, 0x6b1b1a13, 0x6e190b05, 0x0a0804a0,   // fi.rw.pt_322 tl.tr.ceb_665  es.gl.blu_333 ru.uk.mk_322
  0x0a000918, 0x23190bee, 0x090a1807, 0x55002a0e,   // pl.pt.un_740 es.gl.ca_422  ga.pt.pl_432 mt.rw.un_550
  0x0a00121b, 0x550b0a02, 0x100913a0, 0x09000a04,   // hu.pt.un_770 pt.es.rw_222  et.pl.lt_322 pt.pl.un_320
  // [98e0]
  0x53230a07, 0x121301af, 0x071704ad, 0x0c0e20ee,   // pt.ca.ht_432 en.et.hu_655  ru.sr.bg_643 sq.is.sv_422
  0x31002a12, 0x231004ad, 0x02000121, 0x122d0aa4,   // mt.az.un_640 fi.lt.ca_643  en.da.un_860 pt.sk.hu_433
  0x17162b0c, 0x10110807, 0x090a23b2, 0x0c021b07,   // vi.hr.sr_543 uk.ro.be_432  ca.pt.pl_732 tr.da.sv_432
  0x25000504, 0x1c005307, 0x130611a0, 0x1300062a,   // fr.eu.un_320 ht.id.un_420  ro.de.et_322 de.et.un_970
  // [98f0]
  0x13000209, 0x080c1f0d, 0x04000a33, 0x08002518,   // da.et.un_440 cy.sv.no_554  mk.ru.un_A70 eu.no.un_740
  0x0e001107, 0x532723a0, 0x03171655, 0x03170604,   // ro.is.un_420 ca.gd.ht_322  hr.sr.nl_442 de.sr.nl_332
  0x011f0604, 0x131b25a0, 0x13000204, 0x230a190b,   // de.cy.en_332 eu.tr.et_322  da.et.un_320 gl.pt.ca_542
  0x23001702, 0x0a2d0e0c, 0x130e1b08, 0x010c08ee,   // sr.ca.un_220 is.sk.pt_543  tr.is.et_443 no.sv.en_422
  // [9900]
  0x0a001905, 0x1a640107, 0x162128a4, 0x04092d04,   // gl.pt.un_330 en.lg.tl_432  sw.jw.hr_433 sk.pl.fi_332
  0x1c0208a4, 0x04000d08, 0x28001902, 0x0f1b01a4,   // no.da.id_433 cs.fi.un_430  gl.sw.un_220 en.tr.lv_433
  0x16112004, 0x2b111707, 0x0c001b14, 0x2a282b07,   // sq.ro.hr_332 sr.ro.vi_432  tr.sv.un_660 vi.sw.mt_432
  0x3f00280b, 0x21000b13, 0x2a200704, 0x1200200c,   // sw.af.un_520 es.jw.un_650  it.sq.mt_332 sq.hu.un_530
  // [9910]
  0x0a001f02, 0x311b08ee, 0x64002823, 0x0413080c,   // cy.pt.un_220 no.tr.az_422  sw.lg.un_880 no.et.fi_543
  0x53003112, 0x10250fad, 0x2a6b130c, 0x10531ca9,   // az.ht.un_640 lv.eu.lt_643  et.ceb.mt_543 id.ht.lt_544
  0x08002a19, 0x11132508, 0x13070f5a, 0x1b1e1c05,   // mt.no.un_750 eu.et.ro_443  lv.it.et_553 id.ms.tr_333
  0x1a075307, 0x556b1308, 0x2a1a255a, 0x53255514,   // ht.it.tl_432 et.ceb.rw_443  eu.tl.mt_553 rw.eu.ht_666
  // [9920]
  0x1f001107, 0x0c25130c, 0x1a000709, 0x0f3f03ee,   // ro.cy.un_420 et.eu.sv_543  it.tl.un_440 nl.af.lv_422
  0x53310b05, 0x255511a4, 0x0c082a0d, 0x09005309,   // es.az.ht_333 ro.rw.eu_433  mt.no.sv_554 ht.pl.un_440
  0x1100031b, 0x06006404, 0x0a6b2304, 0x121c1e07,   // nl.ro.un_770 lg.de.un_320  ca.ceb.pt_332 ms.id.hu_432
  0x19072a13, 0x23000f13, 0x0f212a55, 0x1255250c,   // mt.it.gl_665 lv.ca.un_650  mt.jw.lv_442 eu.rw.hu_543
  // [9930]
  0x101a53a9, 0x04001114, 0x2a25130c, 0x21161104,   // ht.tl.lt_544 ro.ru.un_660  et.eu.mt_543 ro.hr.jw_332
  0x2500130c, 0x17292d60, 0x250f130c, 0x1728130c,   // et.eu.un_530 sk.sl.sr_664  et.lv.eu_543 et.sw.sr_543
  0x011b13a4, 0x64042804, 0x551913a9, 0x03000702,   // et.tr.en_433 sw.fi.lg_332  et.gl.rw_544 it.nl.un_220
  0x0b000f0e, 0x29170fad, 0x55091904, 0x64281ba7,   // lv.es.un_550 lv.sr.sl_643  gl.pl.rw_332 tr.sw.lg_532
  // [9940]
  0x102311ee, 0x286421a9, 0x53041304, 0x0d0411a0,   // ro.ca.lt_422 jw.lg.sw_544  et.fi.ht_332 ro.fi.cs_322
  0x12006e19, 0x2b0b27a0, 0x0900180c, 0x6e00292b,   // blu.hu.un_750 gd.es.vi_322  ga.pl.un_530 sl.blu.un_980
  0x033f01a7, 0x2d0912a0, 0x2d2916a4, 0x53006e22,   // en.af.nl_532 hu.pl.sk_322  hr.sl.sk_433 blu.ht.un_870
  0x1b0a53ec, 0x1f171614, 0x2a552855, 0x133f1f02,   // ht.pt.tr_644 hr.sr.cy_666  sw.rw.mt_442 cy.af.et_222
  // [9950]
  0x28641f0c, 0x11000b08, 0x16006e09, 0x12206e12,   // cy.lg.sw_543 es.ro.un_430  blu.hr.un_440 blu.sq.hu_654
  0x162717a7, 0x19085507, 0x0a182707, 0x1c005308,   // sr.gd.hr_532 rw.no.gl_432  gd.ga.pt_432 ht.id.un_430
  0x106e0f08, 0x070a1011, 0x29002023, 0x6e00532c,   // lv.blu.lt_443 be.mk.bg_653  sq.sl.un_880 ht.blu.un_990
  0x201617a9, 0x6e171660, 0x02292da9, 0x3f2707ee,   // sr.hr.sq_544 hr.sr.blu_664  sk.sl.da_544 it.gd.af_422
  // [9960]
  0x28311b60, 0x1217290c, 0x13040612, 0x205329a9,   // tr.az.sw_664 sl.sr.hu_543  de.fi.et_654 sl.ht.sq_544
  0x112805a7, 0x052112a0, 0x05110302, 0x09006e2c,   // fr.sw.ro_532 hu.jw.fr_322  nl.ro.fr_222 blu.pl.un_990
  0x060464ad, 0x02063f04, 0x03551107, 0x040208ad,   // lg.fi.de_643 af.de.da_332  ro.rw.nl_432 no.da.fi_643
  0x0c001005, 0x17002a12, 0x3f1223a0, 0x2a640412,   // lt.sv.un_330 mt.sr.un_640  ca.hu.af_322 fi.lg.mt_654
  // [9970]
  0x1312040d, 0x042a0713, 0x6b200107, 0x64120604,   // fi.hu.et_554 it.mt.fi_665  en.sq.ceb_432 de.hu.lg_332
  0x5300090c, 0x2a0708a4, 0x3f021f07, 0x01211b0b,   // pl.ht.un_530 no.it.mt_433  cy.da.af_432 tr.jw.en_542
  0x1b0c04a0, 0x25006409, 0x06081008, 0x2000131a,   // fi.sv.tr_322 lg.eu.un_440  lt.no.de_443 et.sq.un_760
  0x530a12ad, 0x043f08a0, 0x1b0220a0, 0x3f021207,   // hu.pt.ht_643 no.af.fi_322  sq.da.tr_322 hu.da.af_432
  // [9980]
  0x02040705, 0x311b2908, 0x13042aec, 0x010b2304,   // it.fi.da_333 sl.tr.az_443  mt.fi.et_644 ca.es.en_332
  0x0c2a0404, 0x6b6404a0, 0x030604ad, 0x0e0c13a0,   // fi.mt.sv_332 fi.lg.ceb_322  fi.de.nl_643 et.sv.is_322
  0x1b02080b, 0x312a0755, 0x64050702, 0x030c0207,   // no.da.tr_542 it.mt.az_442  it.fr.lg_222 da.sv.nl_432
  0x1e1c3fa4, 0x16000713, 0x08033f11, 0x1b130107,   // af.id.ms_433 it.hr.un_650  af.nl.no_653 en.et.tr_432
  // [9990]
  0x25033fa9, 0x1a0131a0, 0x121120a0, 0x20001208,   // af.nl.eu_544 az.en.tl_322  sq.ro.hu_322 hu.sq.un_430
  0x0b006b07, 0x01123fa0, 0x07110412, 0x12000412,   // ceb.es.un_420 af.hu.en_322  ru.ro.bg_654 fi.hu.un_640
  0x1e000302, 0x130f010c, 0x10170707, 0x196e060c,   // nl.ms.un_220 en.lv.et_543  bg.sr.be_432 de.blu.gl_543
  0x6b0c0455, 0x050a0202, 0x1f006e21, 0x0c002004,   // fi.sv.ceb_442 da.pt.fr_222  blu.cy.un_860 sq.sv.un_320
  // [99a0]
  0x29000d14, 0x251302ad, 0x1f0e180d, 0x011f6ea7,   // cs.sl.un_660 da.et.eu_643  ga.is.cy_554 blu.cy.en_532
  0x08250bad, 0x0f000613, 0x032320a0, 0x0e130caf,   // es.eu.no_643 de.lv.un_650  sq.ca.nl_322 sv.et.is_655
  0x1b0729a7, 0x6e001e05, 0x1b3f10a0, 0x53133112,   // sl.it.tr_532 ms.blu.un_330  lt.af.tr_322 az.et.ht_654
  0x550a53a0, 0x0817040d, 0x05001219, 0x23130912,   // ht.pt.rw_322 ru.sr.uk_554  hu.fr.un_750 pl.et.ca_654
  // [99b0]
  0x53291604, 0x23001021, 0x29172d0b, 0x53050e12,   // hr.sl.ht_332 lt.ca.un_860  sk.sr.sl_542 is.fr.ht_654
  0x1a000204, 0x1b0a2aa4, 0x18290111, 0x0d002807,   // da.tl.un_320 mt.pt.tr_433  en.sl.ga_653 sw.cs.un_420
  0x1200640d, 0x16091704, 0x06080f04, 0x12216404,   // lg.hu.un_540 sr.pl.hr_332  lv.no.de_332 lg.jw.hu_332
  0x6b00080e, 0x29002121, 0x17162d11, 0x020b6bee,   // no.ceb.un_550 jw.sl.un_860  sk.hr.sr_653 ceb.es.da_422
  // [99c0]
  0x211a6e07, 0x172129a0, 0x2a0955a0, 0x04081005,   // blu.tl.jw_432 sl.jw.sr_322  rw.pl.mt_322 be.uk.ru_333
  0x12060a12, 0x64552108, 0x02055502, 0x1a1e21a7,   // pt.de.hu_654 jw.rw.lg_443  rw.fr.da_222 jw.ms.tl_532
  0x64171614, 0x0a070b08, 0x03013f05, 0x64552d5a,   // hr.sr.lg_666 es.it.pt_443  af.en.nl_333 sk.rw.lg_553
  0x551b6407, 0x060e0f07, 0x0e061ca4, 0x211c2804,   // lg.tr.rw_432 lv.is.de_432  id.de.is_433 sw.id.jw_332
  // [99d0]
  0x2a0f1007, 0x641a6b5a, 0x1e0e21ee, 0x061a21ee,   // lt.lv.mt_432 ceb.tl.lg_553  jw.is.ms_422 jw.tl.de_422
  0x29211ea0, 0x0a000b0c, 0x21291712, 0x0100180e,   // ms.jw.sl_322 es.pt.un_530  sr.sl.jw_654 ga.en.un_550
  0x550628af, 0x030612ee, 0x3f271a05, 0x2d0d21ec,   // sw.de.rw_655 hu.de.nl_422  tl.gd.af_333 jw.cs.sk_644
  0x55096408, 0x1e281f07, 0x212d0d13, 0x1a200ea7,   // lg.pl.rw_443 cy.sw.ms_432  cs.sk.jw_665 is.sq.tl_532
  // [99e0]
  0x06080c0c, 0x10081113, 0x0a000421, 0x21002812,   // sv.no.de_543 ro.uk.be_665  ru.mk.un_860 sw.jw.un_640
  0x19120b0c, 0x2a1e2812, 0x1b0e07a7, 0x1c1e2111,   // es.hu.gl_543 sw.ms.mt_654  it.is.tr_532 jw.ms.id_653
  0x0100110d, 0x1a00070b, 0x1e6b0107, 0x3f1006ee,   // ro.en.un_540 it.tl.un_520  en.ceb.ms_432 de.lt.af_422
  0x2d00211a, 0x1200070d, 0x2d002119, 0x071a0ca4,   // jw.sk.un_760 it.hu.un_540  jw.sk.un_750 sv.tl.it_433
  // [99f0]
  0x171b5302, 0x076b1aac, 0x211b0b13, 0x2d190a04,   // ht.tr.sr_222 tl.ceb.it_632  es.tr.jw_665 pt.gl.sk_332
  0x531b2aee, 0x17000420, 0x122518af, 0x21090fa7,   // mt.tr.ht_422 ru.sr.un_850  ga.eu.hu_655 lv.pl.jw_532
  0x201b0e07, 0x25070fec, 0x311b2504, 0x0d212a07,   // is.tr.sq_432 lv.it.eu_644  eu.tr.az_332 mt.jw.cs_432
  0x09006409, 0x1b00530b, 0x31001118, 0x53000a1a,   // lg.pl.un_440 ht.tr.un_520  ro.az.un_740 pt.ht.un_760
  // [9a00]
  0x04133fa0, 0x1a281011, 0x010a0804, 0x110c0307,   // af.et.fi_322 lt.sw.tl_653  no.pt.en_332 nl.sv.ro_432
  0x28175513, 0x0a062512, 0x1b312a09, 0x16001a04,   // rw.sr.sw_665 eu.de.pt_654  mt.az.tr_444 tl.hr.un_320
  0x3f1306af, 0x28003104, 0x1b04135a, 0x28062a07,   // de.et.af_655 az.sw.un_320  et.fi.tr_553 mt.de.sw_432
  0x3f130308, 0x2d002305, 0x071108a7, 0x1918120b,   // nl.et.af_443 ca.sk.un_330  uk.ro.bg_532 hu.ga.gl_542
  // [9a10]
  0x6b1a5505, 0x121b130c, 0x2d0e0dee, 0x12080ca0,   // rw.tl.ceb_333 et.tr.hu_543  cs.is.sk_422 sv.no.hu_322
  0x1b5325ee, 0x0c121c04, 0x1a2d0907, 0x5300641a,   // eu.ht.tr_422 id.hu.sv_332  pl.sk.tl_432 lg.ht.un_760
  0x01122aec, 0x64002a13, 0x6400210d, 0x6b2855ac,   // mt.hu.en_644 mt.lg.un_650  jw.lg.un_540 rw.sw.ceb_632
  0x2d001804, 0x532b2104, 0x3f6b25ad, 0x20000b0e,   // ga.sk.un_320 jw.vi.ht_332  eu.ceb.af_643 es.sq.un_550
  // [9a20]
  0x100a04a4, 0x0400200e, 0x0c311b55, 0x64282155,   // ru.mk.be_433 sq.fi.un_550  tr.az.sv_442 jw.sw.lg_442
  0x0318270b, 0x0c1a530c, 0x3f1e64a4, 0x191304a6,   // gd.ga.nl_542 ht.tl.sv_543  lg.ms.af_433 fi.et.gl_521
  0x0b0219a4, 0x13042807, 0x18271fa0, 0x2d0d0b05,   // gl.da.es_433 sw.fi.et_432  cy.gd.ga_322 es.cs.sk_333
  0x552a530c, 0x0f2113ee, 0x03230505, 0x160b1104,   // ht.mt.rw_543 et.jw.lv_422  fr.ca.nl_333 ro.es.hr_332
  // [9a30]
  0x2b1a0707, 0x036413a7, 0x162d0aa9, 0x230711ee,   // it.tl.vi_432 et.lg.nl_532  pt.sk.hr_544 ro.it.ca_422
  0x1923010b, 0x311b1307, 0x070817a4, 0x07100102,   // en.ca.gl_542 et.tr.az_432  sr.uk.bg_433 en.lt.it_222
  0x19230aa9, 0x0b2d0a12, 0x18271112, 0x170a25ad,   // pt.ca.gl_544 pt.sk.es_654  ro.gd.ga_654 eu.pt.sr_643
  0x2d000a19, 0x55032a04, 0x316428a6, 0x07050baf,   // pt.sk.un_750 mt.nl.rw_332  sw.lg.az_521 es.fr.it_655
  // [9a40]
  0x0b072314, 0x1a005505, 0x290f1011, 0x31272a08,   // ca.it.es_666 rw.tl.un_330  lt.lv.sl_653 mt.gd.az_443
  0x041225a0, 0x0f3f0d07, 0x0c0612a9, 0x2810110d,   // eu.hu.fi_322 cs.af.lv_432  hu.de.sv_544 ro.lt.sw_554
  0x3f08110c, 0x203129a0, 0x0d0e18ad, 0x096b2aa4,   // ro.no.af_543 sl.az.sq_322  ga.is.cs_643 mt.ceb.pl_433
  0x3f2d0da4, 0x182706a4, 0x27002507, 0x0900250b,   // cs.sk.af_433 de.gd.ga_433  eu.gd.un_420 eu.pl.un_520
  // [9a50]
  0x276b01a4, 0x28311b07, 0x1b6b6ead, 0x042511af,   // en.ceb.gd_433 tr.az.sw_432  blu.ceb.tr_643 ro.eu.fi_655
  0x556453a4, 0x10005308, 0x052a02a0, 0x11171605,   // ht.lg.rw_433 ht.lt.un_430  da.mt.fr_322 hr.sr.ro_333
  0x13121b07, 0x27252aa7, 0x0b111a08, 0x05000f36,   // tr.hu.et_432 mt.eu.gd_532  tl.ro.es_443 lv.fr.un_AA0
  0x04002d0c, 0x09531b12, 0x0c0e08a9, 0x0d0a1911,   // sk.fi.un_530 tr.ht.pl_654  no.is.sv_544 gl.pt.cs_653
  // [9a60]
  0x0e3f035a, 0x0c182aa9, 0x3f000708, 0x29100f0d,   // nl.af.is_553 mt.ga.sv_544  it.af.un_430 lv.lt.sl_554
  0x2a6b1107, 0x120d0eec, 0x10081a07, 0x211c5307,   // ro.ceb.mt_432 is.cs.hu_644  tl.no.lt_432 ht.id.jw_432
  0x3f1e09ac, 0x532a6405, 0x19121807, 0x0e002b04,   // pl.ms.af_632 lg.mt.ht_333  ga.hu.gl_432 vi.is.un_320
  0x01051112, 0x190e1307, 0x2a000b08, 0x2d0c0da7,   // ro.fr.en_654 et.is.gl_432  es.mt.un_430 cs.sv.sk_532
  // [9a70]
  0x0e0313a4, 0x03053fee, 0x0e1113ee, 0x132a04a0,   // et.nl.is_433 af.fr.nl_422  et.ro.is_422 fi.mt.et_322
  0x2a020812, 0x0c020509, 0x31080c05, 0x11180104,   // no.da.mt_654 fr.da.sv_444  sv.no.az_333 en.ga.ro_332
  0x05000712, 0x2b002319, 0x6b0a2d55, 0x08021b14,   // it.fr.un_640 ca.vi.un_750  sk.pt.ceb_442 tr.da.no_666
  0x0c030908, 0x210511ee, 0x0c252aec, 0x53290c04,   // pl.nl.sv_443 ro.fr.jw_422  mt.eu.sv_644 sv.sl.ht_332
  // [9a80]
  0x0220080d, 0x230208a7, 0x05001102, 0x53010bad,   // no.sq.da_554 no.da.ca_532  ro.fr.un_220 es.en.ht_643
  0x53000619, 0x0d000e07, 0x1a00030d, 0x051a1202,   // de.ht.un_750 is.cs.un_420  nl.tl.un_540 hu.tl.fr_222
  0x08071b11, 0x08210ca9, 0x04062302, 0x2a080205,   // tr.it.no_653 sv.jw.no_544  ca.de.fi_222 da.no.mt_333
  0x29000c02, 0x03230507, 0x07001f14, 0x01080208,   // sv.sl.un_220 fr.ca.nl_432  cy.it.un_660 da.no.en_443
  // [9a90]
  0x64171602, 0x0e010807, 0x290802ee, 0x032953ee,   // hr.sr.lg_222 no.en.is_432  da.no.sl_422 ht.sl.nl_422
  0x111a6b60, 0x030d3f09, 0x01210904, 0x211b1ea4,   // ceb.tl.ro_664 af.cs.nl_444  pl.jw.en_332 ms.tr.jw_433
  0x0a0810a7, 0x6b1f0507, 0x231f0aa0, 0x081f0ca9,   // be.uk.mk_532 fr.cy.ceb_432  pt.cy.ca_322 sv.cy.no_544
  0x13110402, 0x0a1821ad, 0x55641704, 0x0b23180d,   // fi.ro.et_222 jw.ga.pt_643  sr.lg.rw_332 ga.ca.es_554
  // [9aa0]
  0x110b190c, 0x310c0604, 0x2d0d04ee, 0x256b19ee,   // gl.es.ro_543 de.sv.az_332  fi.cs.sk_422 gl.ceb.eu_422
  0x121a6ba4, 0x290c090c, 0x10162aa0, 0x29000c0d,   // ceb.tl.hu_433 pl.sv.sl_543  mt.hr.lt_322 sv.sl.un_540
  0x130c0902, 0x3f030807, 0x645531a4, 0x0a110b07,   // pl.sv.et_222 no.nl.af_432  az.rw.lg_433 es.ro.pt_432
  0x02000707, 0x1c1907a7, 0x070806ee, 0x2d103f0b,   // it.da.un_420 it.gl.id_532  de.no.it_422 af.lt.sk_542
  // [9ab0]
  0x27531e07, 0x25060fa0, 0x1b64310e, 0x21126ba0,   // ms.ht.gd_432 lv.de.eu_322  az.lg.tr_555 ceb.hu.jw_322
  0x1a536ba7, 0x0c08030c, 0x3f271f12, 0x033155af,   // ceb.ht.tl_532 nl.no.sv_543  cy.gd.af_654 rw.az.nl_655
  0x0e000904, 0x2a002121, 0x28041308, 0x3f000612,   // pl.is.un_320 jw.mt.un_860  et.fi.sw_443 de.af.un_640
  0x051c3fa0, 0x13042811, 0x03016ba0, 0x2d2917a4,   // af.id.fr_322 sw.fi.et_653  ceb.en.nl_322 sr.sl.sk_433
  // [9ac0]
  0x06640707, 0x64072aad, 0x286413ee, 0x271f010b,   // it.lg.de_432 mt.it.lg_643  et.lg.sw_422 en.cy.gd_542
  0x1600280c, 0x063f27ac, 0x2b122707, 0x201207a7,   // sw.hr.un_530 gd.af.de_632  gd.hu.vi_432 it.hu.sq_532
  0x11001007, 0x1f1c0bee, 0x641107a0, 0x1a215307,   // lt.ro.un_420 es.id.cy_422  it.ro.lg_322 ht.jw.tl_432
  0x03000511, 0x016b2102, 0x28001f19, 0x13110504,   // fr.nl.un_630 jw.ceb.en_222  cy.sw.un_750 fr.ro.et_332
  // [9ad0]
  0x13072807, 0x0b230707, 0x1200191b, 0x291b090c,   // sw.it.et_432 it.ca.es_432  gl.hu.un_770 pl.tr.sl_543
  0x64001b14, 0x1c292104, 0x640f16ee, 0x532b2109,   // tr.lg.un_660 jw.sl.id_332  hr.lv.lg_422 jw.vi.ht_444
  0x6b111207, 0x12001c05, 0x1c062004, 0x17041005,   // hu.ro.ceb_432 id.hu.un_330  sq.de.id_332 be.ru.sr_333
  0x231b1108, 0x13030204, 0x166417a9, 0x190b64a0,   // ro.tr.ca_443 da.nl.et_332  sr.lg.hr_544 lg.es.gl_322
  // [9ae0]
  0x13000911, 0x3f0206a4, 0x1a001013, 0x64085305,   // hi.bh.un_630 de.da.af_433  lt.tl.un_650 ht.no.lg_333
  0x64170405, 0x1c005302, 0x2d000d0b, 0x3f046407,   // fi.sr.lg_333 ht.id.un_220  cs.sk.un_520 lg.fi.af_432
  0x0a00280d, 0x2d006413, 0x3f21230c, 0x13640412,   // sw.pt.un_540 lg.sk.un_650  ca.jw.af_543 fi.lg.et_654
  0x1e1c25a6, 0x1b120ca0, 0x191c25ee, 0x06080209,   // eu.id.ms_521 sv.hu.tr_322  eu.id.gl_422 da.no.de_444
  // [9af0]
  0x041e6b07, 0x0e000c07, 0x2d2112a0, 0x210a08a0,   // ceb.ms.fi_432 sv.is.un_420  hu.jw.sk_322 no.pt.jw_322
  0x0c061307, 0x1e1c1005, 0x1f003f0c, 0x29201b07,   // et.de.sv_432 lt.id.ms_333  af.cy.un_530 tr.sq.sl_432
  0x1e1c28ee, 0x07041011, 0x290b1004, 0x53280307,   // sw.id.ms_422 be.ru.bg_653  lt.es.sl_332 nl.sw.ht_432
  0x120d2dee, 0x6b002d04, 0x13100460, 0x1b0213a0,   // sk.cs.hu_422 sk.ceb.un_320  fi.lt.et_664 et.da.tr_322
  // [9b00]
  0x08000222, 0x1c251e13, 0x53002016, 0x136b0412,   // da.no.un_870 ms.eu.id_665  sq.ht.un_720 fi.ceb.et_654
  0x0820040c, 0x120c0402, 0x01033faf, 0x040a17ac,   // fi.sq.no_543 fi.sv.hu_222  af.nl.en_655 sr.mk.ru_632
  0x3f030c12, 0x0d000507, 0x13081aa9, 0x2d0a070c,   // sv.nl.af_654 fr.cs.un_420  tl.no.et_544 it.pt.sk_543
  0x0f00092b, 0x0600131a, 0x6b1a0b07, 0x1a000120,   // pl.lv.un_980 et.de.un_760  es.tl.ceb_432 en.tl.un_850
  // [9b10]
  0x6b0a01a4, 0x23080c07, 0x550c21a0, 0x03001709,   // en.pt.ceb_433 sv.no.ca_432  jw.sv.rw_322 sr.nl.un_440
  0x6b001b09, 0x2a050107, 0x0413110e, 0x130c16ee,   // tr.ceb.un_440 en.fr.mt_432  ro.et.fi_555 hr.sv.et_422
  0x18001118, 0x11182708, 0x55212808, 0x1a216b12,   // ro.ga.un_740 gd.ga.ro_443  sw.jw.rw_443 ceb.jw.tl_654
  0x2a21280c, 0x21042a5a, 0x230b0a13, 0x2a0413af,   // sw.jw.mt_543 mt.fi.jw_553  pt.es.ca_665 et.fi.mt_655
  // [9b20]
  0x235564a9, 0x550728a9, 0x0d120ead, 0x162955a4,   // lg.rw.ca_544 sw.it.rw_544  is.hu.cs_643 rw.sl.hr_433
  0x2100111a, 0x273f030e, 0x202864ad, 0x31110704,   // ro.jw.un_760 nl.af.gd_555  lg.sw.sq_643 it.ro.az_332
  0x27000f04, 0x1e1c0fee, 0x642a0712, 0x2a00250d,   // lv.gd.un_320 lv.id.ms_422  it.mt.lg_654 eu.mt.un_540
  0x20072a0c, 0x1e011ca4, 0x2a2507af, 0x096b28a4,   // mt.it.sq_543 id.en.ms_433  it.eu.mt_655 sw.ceb.pl_433
  // [9b30]
  0x285512a4, 0x10001712, 0x1f080ea7, 0x282129a9,   // hu.rw.sw_433 sr.be.un_640  is.no.cy_532 sl.jw.sw_544
  0x11211e11, 0x20082aa0, 0x27000b08, 0x3f002722,   // ms.jw.ro_653 mt.no.sq_322  es.gd.un_430 gd.af.un_870
  0x0a1c1ead, 0x04131911, 0x06041304, 0x051e1c04,   // ms.id.pt_643 gl.et.fi_653  et.fi.de_332 id.ms.fr_332
  0x1e0e1007, 0x1a041c07, 0x171e0d04, 0x1b190b14,   // lt.is.ms_432 id.fi.tl_432  cs.ms.sr_332 es.gl.tr_666
  // [9b40]
  0x0f2928ee, 0x04003f05, 0x0200030d, 0x130f08a0,   // sw.sl.lv_422 af.fi.un_330  nl.da.un_540 no.lv.et_322
  0x07041fec, 0x171b29a4, 0x1c122aa4, 0x09033faf,   // cy.fi.it_644 sl.tr.sr_433  mt.hu.id_433 af.nl.pl_655
  0x6b281a12, 0x1a106bad, 0x160d13ee, 0x083f0ea4,   // tl.sw.ceb_654 ceb.lt.tl_643  et.cs.hr_422 is.af.no_433
  0x13001a08, 0x0e0308a4, 0x011008a0, 0x1c5328ee,   // tl.et.un_430 no.nl.is_433  no.lt.en_322 sw.ht.id_422
  // [9b50]
  0x043f03a0, 0x10001902, 0x0f0b0407, 0x25206b08,   // nl.af.fi_322 gl.lt.un_220  fi.es.lv_432 ceb.sq.eu_443
  0x041b16a4, 0x31160908, 0x641b12a0, 0x250813ee,   // hr.tr.fi_433 pl.hr.az_443  hu.tr.lg_322 et.no.eu_422
  0x19002518, 0x080c13ee, 0x130408ad, 0x29083109,   // eu.gl.un_740 et.sv.no_422  no.fi.et_643 az.no.sl_444
  0x131b04ee, 0x2a1a0f0e, 0x08000e12, 0x070817a0,   // fi.tr.et_422 lv.tl.mt_555  is.no.un_640 sr.uk.bg_322
  // [9b60]
  0x0f002b08, 0x1f6403ee, 0x1b281ea4, 0x1b002713,   // vi.lv.un_430 nl.lg.cy_422  ms.sw.tr_433 gd.tr.un_650
  0x1c551f0c, 0x13090d0c, 0x03253fa9, 0x1a552d07,   // cy.rw.id_543 ne.hi.bh_543  af.eu.nl_544 sk.rw.tl_432
  0x10000305, 0x1a3f1604, 0x53060107, 0x6b0e3f04,   // nl.lt.un_330 hr.af.tl_332  en.de.ht_432 af.is.ceb_332
  0x27033f08, 0x0500121a, 0x1306210d, 0x2108040e,   // af.nl.gd_443 hu.fr.un_760  jw.de.et_554 fi.no.jw_555
  // [9b70]
  0x250a19ad, 0x063f030e, 0x210f1a04, 0x102507a4,   // gl.pt.eu_643 nl.af.de_555  tl.lv.jw_332 it.eu.lt_433
  0x21000602, 0x110a0809, 0x172909a9, 0x13040d07,   // de.jw.un_220 uk.mk.ro_444  pl.sl.sr_544 cs.fi.et_432
  0x3f0364ec, 0x032a04ad, 0x643f03a0, 0x211a64ee,   // lg.nl.af_644 fi.mt.nl_643  nl.af.lg_322 lg.tl.jw_422
  0x12000513, 0x01271fa7, 0x211b13ee, 0x080220a9,   // fr.hu.un_650 cy.gd.en_532  et.tr.jw_422 sq.da.no_544
  // [9b80]
  0x13166402, 0x02210104, 0x0c020907, 0x08060204,   // lg.hr.et_222 en.jw.da_332  pl.da.sv_432 da.de.no_332
  0x20002705, 0x28041304, 0x043f13af, 0x1213040e,   // gd.sq.un_330 et.fi.sw_332  et.af.fi_655 fi.et.hu_555
  0x020108a7, 0x25282012, 0x0a232504, 0x1b1e28ee,   // no.en.da_532 sq.sw.eu_654  eu.ca.pt_332 sw.ms.tr_422
  0x31281b0c, 0x2a1c2d04, 0x102a210c, 0x17001904,   // tr.sw.az_543 sk.id.mt_332  jw.mt.lt_543 gl.sr.un_320
  // [9b90]
  0x13041114, 0x0c120207, 0x022d0d0b, 0x072531a9,   // ro.fi.et_666 da.hu.sv_432  cs.sk.da_542 az.eu.it_544
  0x28202111, 0x19050b08, 0x2564550c, 0x05070b08,   // jw.sq.sw_653 es.fr.gl_443  rw.lg.eu_543 es.it.fr_443
  0x31111b0d, 0x29532104, 0x291007a0, 0x280a53a7,   // tr.ro.az_554 jw.ht.sl_332  it.lt.sl_322 ht.pt.sw_532
  0x20001b08, 0x130e1004, 0x64001b08, 0x08002305,   // tr.sq.un_430 lt.is.et_332  tr.lg.un_430 ca.no.un_330
  // [9ba0]
  0x53202a05, 0x070a01a0, 0x09162913, 0x17310f08,   // mt.sq.ht_333 en.pt.it_322  sl.hr.pl_665 lv.az.sr_443
  0x07100f0c, 0x1b0a10af, 0x07003113, 0x020721a0,   // lv.lt.it_543 lt.pt.tr_655  az.it.un_650 jw.it.da_322
  0x0c180607, 0x0d120607, 0x53002905, 0x1b02080c,   // de.ga.sv_432 de.hu.cs_432  sl.ht.un_330 no.da.tr_543
  0x25070a05, 0x0c160655, 0x0d033fa9, 0x02083f07,   // pt.it.eu_333 de.hr.sv_442  af.nl.cs_544 af.no.da_432
  // [9bb0]
  0x112a53a0, 0x2d0208ac, 0x06002a11, 0x27000613,   // ht.mt.ro_322 no.da.sk_632  mt.de.un_630 de.gd.un_650
  0x01531207, 0x211a2b07, 0x250a20a0, 0x0f162908,   // hu.ht.en_432 vi.tl.jw_432  sq.pt.eu_322 sl.hr.lv_443
  0x2b6b31a0, 0x03550502, 0x100802ee, 0x101716a4,   // az.ceb.vi_322 fr.rw.nl_222  da.no.lt_422 hr.sr.lt_433
  0x02000820, 0x2a0153a6, 0x020d0ca0, 0x25190a04,   // no.da.un_850 ht.en.mt_521  sv.cs.da_322 pt.gl.eu_332
  // [9bc0]
  0x066b01ee, 0x01060804, 0x130c06a0, 0x0a0717a7,   // en.ceb.de_422 no.de.en_332  de.sv.et_322 sr.bg.mk_532
  0x060c0f13, 0x311b06ee, 0x11006b04, 0x29160da7,   // lv.sv.de_665 de.tr.az_422  ceb.ro.un_320 cs.hr.sl_532
  0x0206210c, 0x04190b02, 0x060c0209, 0x1000130c,   // jw.de.da_543 es.gl.fi_222  da.sv.de_444 et.lt.un_530
  0x0e001312, 0x02201307, 0x1b002808, 0x090413a4,   // et.is.un_640 et.sq.da_432  sw.tr.un_430 et.fi.pl_433
  // [9bd0]
  0x09161307, 0x1b551ea4, 0x6b00550d, 0x1b282d0c,   // et.hr.pl_432 ms.rw.tr_433  rw.ceb.un_540 sk.sw.tr_543
  0x090d1c07, 0x211a100c, 0x0f3108a0, 0x0f000312,   // mr.ne.hi_432 lt.tl.jw_543  no.az.lv_322 nl.lv.un_640
  0x5500110e, 0x0e000a12, 0x53001c02, 0x2b6428a0,   // ro.rw.un_550 pt.is.un_640  id.ht.un_220 sw.lg.vi_322
  0x531b6402, 0x10170a07, 0x0a530e0c, 0x08000a13,   // lg.tr.ht_222 mk.sr.be_432  is.ht.pt_543 mk.uk.un_650
  // [9be0]
  0x2d271812, 0x18001019, 0x550f2d0c, 0x1a1b55a7,   // ga.gd.sk_654 lt.ga.un_750  sk.lv.rw_543 rw.tr.tl_532
  0x0a2a04a0, 0x090712ad, 0x21251a12, 0x082512a0,   // fi.mt.pt_322 hu.it.pl_643  tl.eu.jw_654 hu.eu.no_322
  0x1a1f6bee, 0x052101a0, 0x120b0a08, 0x31002a05,   // ceb.cy.tl_422 en.jw.fr_322  pt.es.hu_443 mt.az.un_330
  0x3f0302ad, 0x311b1eaf, 0x28270aee, 0x641a2107,   // da.nl.af_643 ms.tr.az_655  pt.gd.sw_422 jw.tl.lg_432
  // [9bf0]
  0x033f010b, 0x07270912, 0x0e183fa4, 0x07112d12,   // en.af.nl_542 pl.gd.it_654  af.ga.is_433 sk.ro.it_654
  0x1b531007, 0x01061fa9, 0x09002108, 0x1a1e2102,   // lt.ht.tr_432 cy.de.en_544  jw.pl.un_430 jw.ms.tl_222
  0x17000d07, 0x53216b07, 0x08213f08, 0x2a002513,   // cs.sr.un_420 ceb.jw.ht_432  af.jw.no_443 eu.mt.un_650
  0x28006b18, 0x0700080d, 0x05192355, 0x252a07a4,   // ceb.sw.un_740 no.it.un_540  ca.gl.fr_442 it.mt.eu_433

  // [9c00]
  0x05000619, 0x0e063fa9, 0x25000713, 0x1b002d05,   // de.fr.un_750 af.de.is_544  it.eu.un_650 sk.tr.un_330
  0x110a100c, 0x10070aad, 0x29161905, 0x23120513,   // be.mk.ro_543 mk.bg.be_643  gl.hr.sl_333 fr.hu.ca_665
  0x07171111, 0x16230707, 0x0a170408, 0x080a23a4,   // ro.sr.bg_653 it.ca.hr_432  ru.sr.mk_443 ca.pt.no_433
  0x030f2a05, 0x0c3f2aa7, 0x100811a6, 0x200f3f08,   // mt.lv.nl_333 mt.af.sv_532  ro.uk.be_521 af.lv.sq_443
  // [9c10]
  0x115329a0, 0x042b0307, 0x3f0f09a4, 0x2a0f0807,   // sl.ht.ro_322 nl.vi.fi_432  pl.lv.af_433 no.lv.mt_432
  0x09062aaf, 0x0c081f0c, 0x20030f07, 0x0c082b07,   // mt.de.pl_655 cy.no.sv_543  lv.nl.sq_432 vi.no.sv_432
  0x21130b05, 0x160d2d11, 0x09130da4, 0x08020f14,   // es.et.jw_333 sk.cs.hr_653  ne.bh.hi_433 lv.da.no_666
  0x11011907, 0x020c0fa7, 0x100f2d04, 0x0a1617ad,   // gl.en.ro_432 lv.sv.da_532  sk.lv.lt_332 sr.hr.pt_643
  // [9c20]
  0x64006b0e, 0x28211aa0, 0x2a0131a0, 0x062a07ec,   // ceb.lg.un_550 tl.jw.sw_322  az.en.mt_322 it.mt.de_644
  0x09002109, 0x1a552808, 0x1300042c, 0x21556411,   // jw.pl.un_440 sw.rw.tl_443  fi.et.un_990 lg.rw.jw_653
  0x181219ee, 0x2a530d0c, 0x1e6e1cad, 0x6e1a6ba0,   // gl.hu.ga_422 cs.ht.mt_543  id.blu.ms_643 ceb.tl.blu_322
  0x6e1a21a4, 0x0f252da4, 0x081704a9, 0x023f08a9,   // jw.tl.blu_433 sk.eu.lv_433  ru.sr.uk_544 no.af.da_544
  // [9c30]
  0x040a10ec, 0x162d0d11, 0x55642113, 0x1b1c1e0c,   // be.mk.ru_644 cs.sk.hr_653  jw.lg.rw_665 ms.id.tr_543
  0x28556409, 0x04002514, 0x6429550c, 0x0727535a,   // lg.rw.sw_444 eu.fi.un_660  rw.sl.lg_543 ht.gd.it_553
  0x1c1b1e07, 0x2a1b29ac, 0x25172904, 0x182a2704,   // ms.tr.id_432 sl.tr.mt_632  sl.sr.eu_332 gd.mt.ga_332
  0x0e1729ec, 0x02060c0e, 0x1b1716ee, 0x21001e19,   // sl.sr.is_644 sv.de.da_555  hr.sr.tr_422 ms.jw.un_750
  // [9c40]
  0x1827085a, 0x1e000102, 0x0c120202, 0x285520a4,   // no.gd.ga_553 en.ms.un_220  da.hu.sv_222 sq.rw.sw_433
  0x131811a0, 0x16006413, 0x2b2018a4, 0x642021af,   // ro.ga.et_322 lg.hr.un_650  ga.sq.vi_433 jw.sq.lg_655
  0x2816550c, 0x23006407, 0x210f07af, 0x29281b07,   // rw.hr.sw_543 lg.ca.un_420  it.lv.jw_655 tr.sw.sl_432
  0x291217a0, 0x04201112, 0x531121a0, 0x25110704,   // sr.hu.sl_322 ro.sq.fi_654  jw.ro.ht_322 it.ro.eu_332
  // [9c50]
  0x0b230a60, 0x31041302, 0x09130d11, 0x25182714,   // pt.ca.es_664 et.fi.az_222  ne.bh.hi_653 gd.ga.eu_666
  0x2711180e, 0x28291602, 0x08182704, 0x13090d08,   // ga.ro.gd_555 hr.sl.sw_222  gd.ga.no_332 ne.hi.bh_443
  0x2d1716a9, 0x16005502, 0x080704ee, 0x190b1fa4,   // hr.sr.sk_544 rw.hr.un_220  ru.bg.uk_422 cy.es.gl_433
  0x132d2807, 0x065311a6, 0x2913090c, 0x07101fa7,   // sw.sk.et_432 ro.ht.de_521  pl.et.sl_543 cy.lt.it_532
  // [9c60]
  0x040c13ad, 0x136b1aa4, 0x2d120e12, 0x04002109,   // et.sv.fi_643 tl.ceb.et_433  is.hu.sk_654 jw.fi.un_440
  0x10001f07, 0x0d08550c, 0x10081709, 0x04282109,   // cy.lt.un_420 rw.no.cs_543  sr.uk.be_444 jw.sw.fi_444
  0x0b002102, 0x12070f07, 0x2d0c020c, 0x17161005,   // jw.es.un_220 lv.it.hu_432  da.sv.sk_543 lt.hr.sr_333
  0x2a0c6ea4, 0x160d2d07, 0x312028a0, 0x6e002d1a,   // blu.sv.mt_433 sk.cs.hr_432  sw.sq.az_322 sk.blu.un_760
  // [9c70]
  0x0b001a07, 0x131e20ec, 0x2129250c, 0x09172a04,   // tl.es.un_420 sq.ms.et_644  eu.sl.jw_543 mt.sr.pl_332
  0x016b0255, 0x13001c20, 0x270208a0, 0x3f6b6eec,   // da.ceb.en_442 mr.bh.un_850  no.da.gd_322 blu.ceb.af_644
  0x030e02ad, 0x1f2718a9, 0x04212804, 0x020105a4,   // da.is.nl_643 ga.gd.cy_544  sw.jw.fi_332 fr.en.da_433
  0x3f6e1fa9, 0x1f0203a7, 0x041e1c13, 0x020c2912,   // cy.blu.af_544 nl.da.cy_532  id.ms.fi_665 sl.sv.da_654
  // [9c80]
  0x04186bad, 0x036e270e, 0x04081e0c, 0x231055a0,   // ceb.ga.fi_643 gd.blu.nl_555  ms.no.fi_543 rw.lt.ca_322
  0x6e002d13, 0x04130fa6, 0x216b1355, 0x1c0d13a7,   // sk.blu.un_650 lv.et.fi_521  et.ceb.jw_442 bh.ne.mr_532
  0x112807a0, 0x6b100aa4, 0x192a0707, 0x6b1c1ea4,   // it.sw.ro_322 pt.lt.ceb_433  it.mt.gl_432 ms.id.ceb_433
  0x021a6bad, 0x0300190c, 0x136410ee, 0x190b0f09,   // ceb.tl.da_643 gl.nl.un_530  lt.lg.et_422 lv.es.gl_444
  // [9c90]
  0x190511af, 0x0a081004, 0x201009a0, 0x25551104,   // ro.fr.gl_655 be.uk.mk_332  pl.lt.sq_322 ro.rw.eu_332
  0x21641aa0, 0x06030c08, 0x0f0410ee, 0x03643fa9,   // tl.lg.jw_322 sv.nl.de_443  lt.fi.lv_422 af.lg.nl_544
  0x1e1c0409, 0x13101ea4, 0x0402080c, 0x1e122112,   // fi.id.ms_444 ms.lt.et_433  no.da.fi_543 jw.hu.ms_654
  0x12232807, 0x1b1f530d, 0x01033f55, 0x04070811,   // sw.ca.hu_432 ht.cy.tr_554  af.nl.en_442 uk.bg.ru_653
  // [9ca0]
  0x20001e0d, 0x551a6b07, 0x0802270e, 0x281e1c0e,   // ms.sq.un_540 ceb.tl.rw_432  gd.da.no_555 id.ms.sw_555
  0x2b071107, 0x2a640712, 0x1f1827ac, 0x13002502,   // ro.it.vi_432 it.lg.mt_654  gd.ga.cy_632 eu.et.un_220
  0x2500550c, 0x080f13a0, 0x170708af, 0x2a182708,   // rw.eu.un_530 et.lv.no_322  uk.bg.sr_655 gd.ga.mt_443
  0x1b251207, 0x2001270c, 0x0c130eac, 0x190423a7,   // hu.eu.tr_432 gd.en.sq_543  is.et.sv_632 ca.fi.gl_532
  // [9cb0]
  0x53000e04, 0x291a6ba4, 0x161129a9, 0x0b0123a6,   // is.ht.un_320 ceb.tl.sl_433  sl.ro.hr_544 ca.en.es_521
  0x080a1755, 0x0317160e, 0x55002902, 0x11256b0c,   // sr.mk.uk_442 hr.sr.nl_555  sl.rw.un_220 ceb.eu.ro_543
  0x10001e04, 0x0b070104, 0x16072a04, 0x0f282d55,   // ms.lt.un_320 en.it.es_332  mt.it.hr_332 sk.sw.lv_442
  0x1f00032b, 0x05550208, 0x6e001b0e, 0x1f006e22,   // nl.cy.un_980 da.rw.fr_443  tr.blu.un_550 blu.cy.un_870
  // [9cc0]
  0x171e5305, 0x6e00100d, 0x19001b07, 0x09071155,   // ht.ms.sr_333 lt.blu.un_540  tr.gl.un_420 ro.it.pl_442
  0x020c06a4, 0x29006b07, 0x130f0405, 0x02002007,   // de.sv.da_433 ceb.sl.un_420  fi.lv.et_333 sq.da.un_420
  0x0c0812af, 0x08180605, 0x232d02a0, 0x0f136ead,   // hu.no.sv_655 de.ga.no_333  da.sk.ca_322 blu.et.lv_643
  0x061f0ea4, 0x08000c1a, 0x2a002822, 0x1200530e,   // is.cy.de_433 sv.no.un_760  sw.mt.un_870 ht.hu.un_550
  // [9cd0]
  0x17003114, 0x07010604, 0x11552aec, 0x13000520,   // az.sr.un_660 de.en.it_332  mt.rw.ro_644 fr.et.un_850
  0x08000c23, 0x646b1804, 0x11311bec, 0x20060c04,   // sv.no.un_880 ga.ceb.lg_332  tr.az.ro_644 sv.de.sq_332
  0x080e0613, 0x05001109, 0x170c080c, 0x1a026bee,   // de.is.no_665 ro.fr.un_440  no.sv.sr_543 ceb.da.tl_422
  0x13010604, 0x036406a9, 0x12002013, 0x3f001019,   // de.en.et_332 de.lg.nl_544  sq.hu.un_650 lt.af.un_750
  // [9ce0]
  0x12212005, 0x55646b08, 0x2a551807, 0x0c181aa4,   // sq.jw.hu_333 ceb.lg.rw_443  ga.rw.mt_432 tl.ga.sv_433
  0x12080c60, 0x0c002008, 0x12000102, 0x1e1c55ec,   // sv.no.hu_664 sq.sv.un_430  en.hu.un_220 rw.id.ms_644
  0x1a216408, 0x05010ba7, 0x062855ee, 0x06005519,   // lg.jw.tl_443 es.en.fr_532  rw.sw.de_422 rw.de.un_750
  0x06002821, 0x2853130e, 0x10170409, 0x0c001102,   // sw.de.un_860 et.ht.sw_555  ru.sr.be_444 ro.sv.un_220
  // [9cf0]
  0x06001107, 0x55312805, 0x166b64a0, 0x0d16290b,   // ro.de.un_420 sw.az.rw_333  lg.ceb.hr_322 sl.hr.cs_542
  0x1f2d0d13, 0x2500642b, 0x04002a07, 0x020e0cee,   // cs.sk.cy_665 lg.eu.un_980  mt.fi.un_420 sv.is.da_422
  0x160d29ac, 0x082a0ca4, 0x04001b02, 0x0c1b04a0,   // sl.cs.hr_632 sv.mt.no_433  tr.fi.un_220 fi.tr.sv_322
  0x1f060104, 0x09290d02, 0x170525a0, 0x07042004,   // en.de.cy_332 cs.sl.pl_222  eu.fr.sr_322 sq.fi.it_332
  // [9d00]
  0x191e6402, 0x25002814, 0x0f0d2da9, 0x06190a13,   // lg.ms.gl_222 sw.eu.un_660  sk.cs.lv_544 pt.gl.de_665
  0x2b201307, 0x0925205a, 0x55001a19, 0x2b206eee,   // et.sq.vi_432 sq.eu.pl_553  tl.rw.un_750 blu.sq.vi_422
  0x23110107, 0x10070a11, 0x2109060c, 0x0f09315a,   // en.ro.ca_432 mk.bg.be_653  de.pl.jw_543 az.pl.lv_553
  0x25040711, 0x0c0908a0, 0x21001b0c, 0x20002522,   // it.fi.eu_653 no.pl.sv_322  tr.jw.un_530 eu.sq.un_870
  // [9d10]
  0x0b311ba9, 0x11006b08, 0x1b082aad, 0x030e3f02,   // tr.az.es_544 ceb.ro.un_430  mt.no.tr_643 af.is.nl_222
  0x1f211ca0, 0x1e000b07, 0x23001807, 0x03002304,   // id.jw.cy_322 es.ms.un_420  ga.ca.un_420 ca.nl.un_320
  0x272b1808, 0x18112704, 0x250219a0, 0x250818a4,   // ga.vi.gd_443 gd.ro.ga_332  gl.da.eu_322 ga.no.eu_433
  0x0211530c, 0x28000702, 0x06002a12, 0x27110107,   // ht.ro.da_543 it.sw.un_220  mt.de.un_640 en.ro.gd_432
  // [9d20]
  0x251c06a0, 0x311b065a, 0x101a1202, 0x16292d08,   // de.id.eu_322 de.tr.az_553  hu.tl.lt_222 sk.sl.hr_443
  0x2a123fec, 0x121c1ea4, 0x1e021cee, 0x12001a2a,   // af.hu.mt_644 ms.id.hu_433  id.da.ms_422 tl.hu.un_970
  0x230205ad, 0x100411a9, 0x0c00011a, 0x2d0e0a0c,   // fr.da.ca_643 ro.ru.be_544  en.sv.un_760 pt.is.sk_543
  0x1a0e1204, 0x0a006b04, 0x1a1c1eaf, 0x536b1a0c,   // hu.is.tl_332 ceb.pt.un_320  ms.id.tl_655 tl.ceb.ht_543
  // [9d30]
  0x13002013, 0x20531208, 0x080a17a7, 0x16172dad,   // sq.et.un_650 hu.ht.sq_443  sr.mk.uk_532 sk.sr.hr_643
  0x170d2911, 0x2d001005, 0x1c2b2aa0, 0x1e00061a,   // sl.cs.sr_653 lt.sk.un_330  mt.vi.id_322 de.ms.un_760
  0x2a181ea0, 0x1b1e1c14, 0x1e1c1aec, 0x6b001313,   // ms.ga.mt_322 id.ms.tr_666  tl.id.ms_644 et.ceb.un_650
  0x6b001b12, 0x28001004, 0x096b1a0d, 0x05070e04,   // tr.ceb.un_640 lt.sw.un_320  tl.ceb.pl_554 is.it.fr_332
  // [9d40]
  0x1a0364a4, 0x190a1b05, 0x033f1f10, 0x161f1007,   // lg.nl.tl_433 tr.pt.gl_333  cy.af.nl_642 lt.cy.hr_432
  0x12190a05, 0x190a6bad, 0x1f181114, 0x080253a4,   // pt.gl.hu_333 ceb.pt.gl_643  ro.ga.cy_666 ht.da.no_433
  0x132110a4, 0x55033f11, 0x0e00232b, 0x1f000c22,   // lt.jw.et_433 af.nl.rw_653  ca.is.un_980 sv.cy.un_870
  0x64000c04, 0x313f1aec, 0x27001e05, 0x09062712,   // sv.lg.un_320 tl.af.az_644  ms.gd.un_330 gd.de.pl_654
  // [9d50]
  0x11051b60, 0x5300311b, 0x02000505, 0x1811070d,   // tr.fr.ro_664 az.ht.un_770  fr.da.un_330 it.ro.ga_554
  0x2d090107, 0x20072313, 0x190a29a9, 0x1b186b07,   // en.pl.sk_432 ca.it.sq_665  sl.pt.gl_544 ceb.ga.tr_432
  0x060c27a4, 0x046b1a09, 0x045310a9, 0x0c0e0fa9,   // gd.sv.de_433 tl.ceb.fi_444  lt.ht.fi_544 lv.is.sv_544
  0x030c0205, 0x162a6b07, 0x1b00111b, 0x1f0601ad,   // da.sv.nl_333 ceb.mt.hr_432  ro.tr.un_770 en.de.cy_643
  // [9d60]
  0x2a091255, 0x3f030611, 0x2106090c, 0x1a5553a6,   // hu.pl.mt_442 de.nl.af_653  pl.de.jw_543 ht.rw.tl_521
  0x09211f07, 0x040d1e02, 0x03080105, 0x1f000113,   // cy.jw.pl_432 ms.cs.fi_222  en.no.nl_333 en.cy.un_650
  0x1c6421ee, 0x190a0cee, 0x1a000c02, 0x033f530c,   // jw.lg.id_422 sv.pt.gl_422  sv.tl.un_220 ht.af.nl_543
  0x3f031a08, 0x1f00092a, 0x2a091f55, 0x181f2704,   // tl.nl.af_443 pl.cy.un_970  cy.pl.mt_442 gd.cy.ga_332
  // [9d70]
  0x0f00060d, 0x053f0360, 0x09280107, 0x0e0803ec,   // de.lv.un_540 nl.af.fr_664  en.sw.pl_432 nl.no.is_644
  0x53033f55, 0x070d1b07, 0x0c130f04, 0x2d0d17ec,   // af.nl.ht_442 tr.cs.it_432  lv.et.sv_332 sr.cs.sk_644
  0x1b286412, 0x2b180107, 0x052755ee, 0x1264280b,   // lg.sw.tr_654 en.ga.vi_432  rw.gd.fr_422 sw.lg.hu_542
  0x281a6b13, 0x07033f07, 0x64001b02, 0x1f000712,   // ceb.tl.sw_665 af.nl.it_432  tr.lg.un_220 it.cy.un_640
  // [9d80]
  0x0b00110b, 0x311b120b, 0x11016ba0, 0x0a001108,   // ro.es.un_520 hu.tr.az_542  ceb.en.ro_322 ro.pt.un_430
  0x2a001002, 0x2b002d07, 0x641228a4, 0x1a2855a7,   // lt.mt.un_220 sk.vi.un_420  sw.hu.lg_433 rw.sw.tl_532
  0x282004ee, 0x1e003112, 0x11070112, 0x162564af,   // fi.sq.sw_422 az.ms.un_640  en.it.ro_654 lg.eu.hr_655
  0x531a28a7, 0x556b0d0d, 0x281764af, 0x1a001c04,   // sw.tl.ht_532 cs.ceb.rw_554  lg.sr.sw_655 id.tl.un_320
  // [9d90]
  0x2d00180d, 0x0e642812, 0x1600040c, 0x1955640d,   // ga.sk.un_540 sw.lg.is_654  fi.hr.un_530 lg.rw.gl_554
  0x2a070512, 0x311e1c0d, 0x051f0713, 0x06012702,   // fr.it.mt_654 id.ms.az_554  it.cy.fr_665 gd.en.de_222
  0x08182712, 0x21551a13, 0x0928210d, 0x6e2811a4,   // gd.ga.no_654 tl.rw.jw_665  jw.sw.pl_554 ro.sw.blu_433
  0x216b5507, 0x1e0a64af, 0x6b31550c, 0x215328a0,   // rw.ceb.jw_432 lg.pt.ms_655  rw.az.ceb_543 sw.ht.jw_322
  // [9da0]
  0x13002707, 0x27000807, 0x311a5555, 0x04271807,   // gd.et.un_420 no.gd.un_420  rw.tl.az_442 ga.gd.fi_432
  0x1a001c05, 0x050413a0, 0x1a212807, 0x55281a0c,   // id.tl.un_330 et.fi.fr_322  sw.jw.tl_432 tl.sw.rw_543
  0x080c1809, 0x251a3114, 0x041a6b12, 0x27251312,   // ga.sv.no_444 az.tl.eu_666  ceb.tl.fi_654 et.eu.gd_654
  0x1a1e1c14, 0x6b230aa7, 0x1101180c, 0x2a000402,   // id.ms.tl_666 pt.ca.ceb_532  ga.en.ro_543 fi.mt.un_220
  // [9db0]
  0x176b1a08, 0x05020cee, 0x18080cad, 0x3f060e04,   // tl.ceb.sr_443 sv.da.fr_422  sv.no.ga_643 is.de.af_332
  0x6b281a08, 0x23002509, 0x170807af, 0x08001818,   // tl.sw.ceb_443 eu.ca.un_440  bg.uk.sr_655 ga.no.un_740
  0x131b0ca9, 0x0708110c, 0x060853ee, 0x0700200c,   // sv.tr.et_544 ro.uk.bg_543  ht.no.de_422 sq.it.un_530
  0x0d106455, 0x101704a0, 0x645521ad, 0x08171008,   // lg.lt.cs_442 ru.sr.be_322  jw.rw.lg_643 be.sr.uk_443
  // [9dc0]
  0x0b006411, 0x21000a08, 0x2000251b, 0x536e0b04,   // lg.es.un_630 pt.jw.un_430  eu.sq.un_770 es.blu.ht_332
  0x061b12ad, 0x29000914, 0x20000809, 0x1b311212,   // hu.tr.de_643 pl.sl.un_660  no.sq.un_440 hu.az.tr_654
  0x162920ee, 0x21006b07, 0x53311eaf, 0x1b001218,   // sq.sl.hr_422 ceb.jw.un_420  ms.az.ht_655 hu.tr.un_740
  0x0b162904, 0x2a122011, 0x64006b13, 0x201216ee,   // sl.hr.es_332 sq.hu.mt_653  ceb.lg.un_650 hr.hu.sq_422
  // [9dd0]
  0x29120ba7, 0x6b006418, 0x2b2920a6, 0x1b042012,   // es.hu.sl_532 lg.ceb.un_740  sq.sl.vi_521 sq.fi.tr_654
  0x08162012, 0x1e2004a0, 0x16002005, 0x3f2803a4,   // sq.hr.no_654 fi.sq.ms_322  sq.hr.un_330 nl.sw.af_433
  0x0c00530d, 0x25001008, 0x28002a02, 0x206421a4,   // ht.sv.un_540 lt.eu.un_430  mt.sw.un_220 jw.lg.sq_433
  0x06250ca4, 0x0e202a07, 0x170a110e, 0x07000a35,   // sv.eu.de_433 mt.sq.is_432  ro.mk.sr_555 mk.bg.un_A90
  // [9de0]
  0x011c1ea0, 0x0d042d0c, 0x13002507, 0x08033f12,   // ms.id.en_322 sk.fi.cs_543  eu.et.un_420 af.nl.no_654
  0x0c0718a0, 0x1100291b, 0x015327ee, 0x133f030c,   // ga.it.sv_322 sl.ro.un_770  gd.ht.en_422 nl.af.et_543
  0x21645507, 0x12001805, 0x12200107, 0x04292d0c,   // rw.lg.jw_432 ar.ur.un_330  en.sq.hu_432 sk.sl.fi_543
  0x29531607, 0x3f2753a0, 0x0a111755, 0x25171605,   // hr.ht.sl_432 ht.gd.af_322  sr.ro.mk_442 hr.sr.eu_333
  // [9df0]
  0x10640f0c, 0x21272955, 0x0804170d, 0x062a6e60,   // lv.lg.lt_543 sl.gd.jw_442  sr.ru.uk_554 blu.mt.de_664
  0x21003f07, 0x110107a0, 0x061e1b07, 0x070b190c,   // af.jw.un_420 it.en.ro_322  tr.ms.de_432 gl.es.it_543
  0x311b64a0, 0x17276bee, 0x28121f07, 0x1f192508,   // lg.tr.az_322 ceb.gd.sr_422  cy.hu.sw_432 eu.gl.cy_443
  0x3f0103a4, 0x1c251fec, 0x04080a0c, 0x0305010c,   // nl.en.af_433 cy.eu.id_644  mk.uk.ru_543 en.fr.nl_543
  // [9e00]
  0x1c161ea7, 0x1f006e19, 0x170605ee, 0x1a1b31a4,   // ms.hr.id_532 blu.cy.un_750  fr.de.sr_422 az.tr.tl_433
  0x101f25ad, 0x0200061a, 0x2d090dee, 0x01001105,   // eu.cy.lt_643 de.da.un_760  cs.pl.sk_422 ro.en.un_330
  0x201609ad, 0x16132902, 0x11530107, 0x2a001305,   // pl.hr.sq_643 sl.et.hr_222  en.ht.ro_432 et.mt.un_330
  0x0c130804, 0x2b210aa7, 0x182509ad, 0x1f001b13,   // no.et.sv_332 pt.jw.vi_532  pl.eu.ga_643 tr.cy.un_650
  // [9e10]
  0x01000312, 0x25291fa0, 0x05000902, 0x03211f05,   // nl.en.un_640 cy.sl.eu_322  pl.fr.un_220 cy.jw.nl_333
  0x031f0dee, 0x12043fee, 0x3f060155, 0x2d170da4,   // cs.cy.nl_422 af.fi.hu_422  en.de.af_442 cs.sr.sk_433
  0x0c081e02, 0x2100030d, 0x21175307, 0x1e002507,   // ms.no.sv_222 nl.jw.un_540  ht.sr.jw_432 eu.ms.un_420
  0x210f53ad, 0x0c022da9, 0x17000414, 0x201004ee,   // ht.lv.jw_643 sk.da.sv_544  ru.sr.un_660 fi.lt.sq_422
  // [9e20]
  0x100f04a4, 0x530c0804, 0x1b1f280b, 0x200f1055,   // fi.lv.lt_433 no.sv.ht_332  sw.cy.tr_542 lt.lv.sq_442
  0x53000c05, 0x201e1c04, 0x100804a7, 0x5318550c,   // sv.ht.un_330 id.ms.sq_332  ru.uk.be_532 rw.ga.ht_543
  0x171016a0, 0x092d0da7, 0x0a10040c, 0x125305a4,   // hr.lt.sr_322 cs.sk.pl_532  ru.be.mk_543 fr.ht.hu_433
  0x20042d07, 0x0f10040c, 0x0f133104, 0x040f2da0,   // sk.fi.sq_432 fi.lt.lv_543  az.et.lv_332 sk.lv.fi_322
  // [9e30]
  0x290420af, 0x170810ec, 0x193106a0, 0x136e2511,   // sq.fi.sl_655 be.uk.sr_644  de.az.gl_322 eu.blu.et_653
  0x10001f11, 0x230b6ea6, 0x19111eac, 0x21002905,   // cy.lt.un_630 blu.es.ca_521  ms.ro.gl_632 sl.jw.un_330
  0x310a07a4, 0x53000d19, 0x03110707, 0x291b1a02,   // it.pt.az_433 cs.ht.un_750  it.ro.nl_432 tl.tr.sl_222
  0x11530d07, 0x011327a0, 0x0c003104, 0x201b030c,   // cs.ht.ro_432 gd.et.en_322  az.sv.un_320 nl.tr.sq_543
  // [9e40]
  0x55000422, 0x21250408, 0x64000a02, 0x29105507,   // fi.rw.un_870 fi.eu.jw_443  pt.lg.un_220 rw.lt.sl_432
  0x641b3104, 0x2011530c, 0x535507ad, 0x531c2dad,   // az.tr.lg_332 ht.ro.sq_543  it.rw.ht_643 sk.id.ht_643
  0x311b04a9, 0x162a64a6, 0x292d07a0, 0x13033fad,   // fi.tr.az_544 lg.mt.hr_521  it.sk.sl_322 af.nl.et_643
  0x1b316b07, 0x0700110e, 0x12291305, 0x1b211aa7,   // ceb.az.tr_432 ro.bg.un_550  et.sl.hu_333 tl.jw.tr_532
  // [9e50]
  0x130e2002, 0x1610290d, 0x13211811, 0x55212860,   // sq.is.et_222 sl.lt.hr_554  ga.jw.et_653 sw.jw.rw_664
  0x062d0ca0, 0x190b250e, 0x1c132160, 0x0b121912,   // sv.sk.de_322 eu.es.gl_555  jw.et.id_664 gl.hu.es_654
  0x2b00250d, 0x132718ad, 0x131c1e07, 0x1a216b04,   // eu.vi.un_540 ga.gd.et_643  ms.id.et_432 ceb.jw.tl_332
  0x2d002b12, 0x091720a4, 0x17002d11, 0x17100804,   // vi.sk.un_640 sq.sr.pl_433  sk.sr.un_630 uk.be.sr_332
  // [9e60]
  0x17161008, 0x1825270c, 0x040201ee, 0x051c01ee,   // lt.hr.sr_443 gd.eu.ga_543  en.da.fi_422 en.id.fr_422
  0x291710ad, 0x2a0403a6, 0x64160ea0, 0x04281a55,   // lt.sr.sl_643 nl.fi.mt_521  is.hr.lg_322 tl.sw.fi_442
  0x28171608, 0x2d006b04, 0x29021702, 0x17041155,   // hr.sr.sw_443 ceb.sk.un_320  sr.da.sl_222 ro.ru.sr_442
  0x281321a4, 0x13171655, 0x6b131a09, 0x3f2813a0,   // jw.et.sw_433 hr.sr.et_442  tl.et.ceb_444 et.sw.af_322
  // [9e70]
  0x6b2b1aa4, 0x041318a9, 0x556412a7, 0x2d172907,   // tl.vi.ceb_433 ga.et.fi_544  hu.lg.rw_532 sl.sr.sk_432
  0x06000122, 0x160413ad, 0x1e1c13a0, 0x1a0428a0,   // en.de.un_870 et.fi.hr_643  et.id.ms_322 sw.fi.tl_322
  0x13101c02, 0x12060cac, 0x20131a07, 0x0f001209,   // id.lt.et_222 sv.de.hu_632  tl.et.sq_432 hu.lv.un_440
  0x112b2708, 0x28041aa0, 0x12051f0c, 0x0118270c,   // gd.vi.ro_443 tl.fi.sw_322  cy.fr.hu_543 gd.ga.en_543
  // [9e80]
  0x0e002709, 0x3f311b0e, 0x1a1e1ca4, 0x2d16100c,   // gd.is.un_440 tr.az.af_555  id.ms.tl_433 lt.hr.sk_543
  0x1a216b08, 0x1803010c, 0x180111ee, 0x1f2b090c,   // ceb.jw.tl_443 en.nl.ga_543  ro.en.ga_422 pl.vi.cy_543
  0x1c031e11, 0x232a2b05, 0x180c1ea0, 0x070c21a4,   // ms.nl.id_653 vi.mt.ca_333  ms.sv.ga_322 jw.sv.it_433
  0x060e10a9, 0x041316a0, 0x28002712, 0x18551fa4,   // lt.is.de_544 hr.et.fi_322  gd.sw.un_640 cy.rw.ga_433
  // [9e90]
  0x64311b60, 0x1e00531a, 0x191664ee, 0x645501a0,   // tr.az.lg_664 ht.ms.un_760  lg.hr.gl_422 en.rw.lg_322
  0x1f0627a4, 0x02642aa0, 0x09006e07, 0x2b001802,   // gd.de.cy_433 mt.lg.da_322  blu.pl.un_420 ga.vi.un_220
  0x04072aa0, 0x18002822, 0x1200061a, 0x05110f07,   // mt.it.fi_322 sw.ga.un_870  de.hu.un_760 lv.ro.fr_432
  0x02012aee, 0x1f271808, 0x310e01a0, 0x11180807,   // mt.en.da_422 ga.gd.cy_443  en.is.az_322 no.ga.ro_432
  // [9ea0]
  0x02000408, 0x28551aa6, 0x21112aa9, 0x0a2a07a0,   // fi.da.un_430 tl.rw.sw_521  mt.ro.jw_544 it.mt.pt_322
  0x1a2821a4, 0x041b1308, 0x270153a0, 0x12072aa7,   // jw.sw.tl_433 et.tr.fi_443  ht.en.gd_322 mt.it.hu_532
  0x1f0701a4, 0x12096e0c, 0x060e080c, 0x532b180c,   // en.it.cy_433 blu.pl.hu_543  no.is.de_543 ga.vi.ht_543
  0x6b0106ee, 0x1700030c, 0x0e2d2a0c, 0x3f0627a4,   // de.en.ceb_422 nl.sr.un_530  mt.sk.is_543 gd.de.af_433
  // [9eb0]
  0x0a070b07, 0x010b0504, 0x0c025502, 0x0100061a,   // es.it.pt_432 fr.es.en_332  rw.da.sv_222 de.en.un_760
  0x020e3f02, 0x06000119, 0x020c0604, 0x0a002108,   // af.is.da_222 en.de.un_750  de.sv.da_332 jw.pt.un_430
  0x07000b1b, 0x0c041602, 0x0b085555, 0x12041307,   // es.it.un_770 hr.fi.sv_222  rw.no.es_442 et.fi.hu_432
  0x110106a0, 0x28645555, 0x03002708, 0x1100021b,   // de.en.ro_322 rw.lg.sw_442  gd.nl.un_430 da.ro.un_770
  // [9ec0]
  0x030106a7, 0x550b2808, 0x11030707, 0x2d1806a7,   // de.en.nl_532 sw.es.rw_443  it.nl.ro_432 de.ga.sk_532
  0x0c00090d, 0x280955a4, 0x112855ad, 0x291321a0,   // pl.sv.un_540 rw.pl.sw_433  rw.sw.ro_643 jw.et.sl_322
  0x10130fa4, 0x1029160b, 0x170316a0, 0x060208ec,   // lv.et.lt_433 hr.sl.lt_542  hr.nl.sr_322 no.da.de_644
  0x04130105, 0x24000109, 0x21001c14, 0x050601a9,   // en.et.fi_333 iw.yi.un_440  id.jw.un_660 en.de.fr_544
  // [9ed0]
  0x2d000807, 0x282131ee, 0x2a102504, 0x1b000413,   // no.sk.un_420 az.jw.sw_422  eu.lt.mt_332 fi.tr.un_650
  0x201b08a0, 0x3f122aee, 0x020c08ad, 0x092a08a0,   // no.tr.sq_322 mt.hu.af_422  no.sv.da_643 no.mt.pl_322
  0x07000c04, 0x04281a07, 0x16291760, 0x13013fa9,   // sv.it.un_320 tl.sw.fi_432  sr.sl.hr_664 af.en.et_544
  0x16002819, 0x06001a0b, 0x162821a4, 0x6b0613a9,   // sw.hr.un_750 tl.de.un_520  jw.sw.hr_433 et.de.ceb_544
  // [9ee0]
  0x1708100c, 0x1a64280c, 0x19250b0b, 0x1f0608a7,   // be.uk.sr_543 sw.lg.tl_543  es.eu.gl_542 no.de.cy_532
  0x04170a11, 0x10000c0d, 0x1a25280d, 0x03002008,   // mk.sr.ru_653 sv.lt.un_540  sw.eu.tl_554 sq.nl.un_430
  0x041a6ba0, 0x17291611, 0x1117100c, 0x6b2a04a0,   // ceb.tl.fi_322 hr.sl.sr_653  be.sr.ro_543 fi.mt.ceb_322
  0x6b1a28af, 0x2a2307a7, 0x10170a0c, 0x642355ad,   // sw.tl.ceb_655 it.ca.mt_532  mk.sr.be_543 rw.ca.lg_643
  // [9ef0]
  0x1b0812ec, 0x11170ba4, 0x31001014, 0x18130411,   // hu.no.tr_644 es.sr.ro_433  lt.az.un_660 fi.et.ga_653
  0x171655ac, 0x29135308, 0x040e0cee, 0x1c006e0c,   // rw.hr.sr_632 ht.et.sl_443  sv.is.fi_422 blu.id.un_530
  0x201325a7, 0x21192804, 0x1331040c, 0x181e1c08,   // eu.et.sq_532 sw.gl.jw_332  fi.az.et_543 id.ms.ga_443
  0x040d530c, 0x0f1b31a6, 0x645511a4, 0x0f1b310d,   // ht.cs.fi_543 az.tr.lv_521  ro.rw.lg_433 az.tr.lv_554
  // [9f00]
  0x196e0aad, 0x0900252a, 0x251155a4, 0x3f020313,   // pt.blu.gl_643 eu.pl.un_970  rw.ro.eu_433 nl.da.af_665
  0x0f103105, 0x55291705, 0x012b08a6, 0x12000313,   // az.lt.lv_333 sr.sl.rw_333  no.vi.en_521 nl.hu.un_650
  0x1153200c, 0x53080407, 0x2810640c, 0x2a1706a7,   // sq.ht.ro_543 fi.no.ht_432  lg.lt.sw_543 de.sr.mt_532
  0x5528100c, 0x092a5305, 0x1c6e0a08, 0x270a1814,   // lt.sw.rw_543 ht.mt.pl_333  pt.blu.id_443 ga.pt.gd_666
  // [9f10]
  0x03171604, 0x116b040c, 0x0c0855a4, 0x181c6ea0,   // hr.sr.nl_332 fi.ceb.ro_543  rw.no.sv_433 blu.id.ga_322
  0x100155a0, 0x0f2513a0, 0x53162a08, 0x6e5521ec,   // rw.en.lt_322 et.eu.lv_322  mt.hr.ht_443 jw.rw.blu_644
  0x033f1f12, 0x123f0312, 0x25001705, 0x251c1eee,   // cy.af.nl_654 nl.af.hu_654  sr.eu.un_330 ms.id.eu_422
  0x17311ba4, 0x06550855, 0x171603af, 0x28311b13,   // tr.az.sr_433 no.rw.de_442  nl.hr.sr_655 tr.az.sw_665
  // [9f20]
  0x1f6b0e08, 0x026b1aa9, 0x23050112, 0x281a6bec,   // is.ceb.cy_443 tl.ceb.da_544  en.fr.ca_654 ceb.tl.sw_644
  0x0317160c, 0x256455a9, 0x28000d19, 0x1b312a5a,   // hr.sr.nl_543 rw.lg.eu_544  cs.sw.un_750 mt.az.tr_553
  0x1a6b190d, 0x1a0a210c, 0x03171609, 0x07171009,   // gl.ceb.tl_554 jw.pt.tl_543  hr.sr.nl_444 be.sr.bg_444
  0x106b280c, 0x012d0d04, 0x131a280c, 0x0e191060,   // sw.ceb.lt_543 cs.sk.en_332  sw.tl.et_543 lt.gl.is_664
  // [9f30]
  0x0f000421, 0x1a2801a0, 0x311b1705, 0x181b310c,   // fi.lv.un_860 en.sw.tl_322  sr.tr.az_333 az.tr.ga_543
  0x53000620, 0x0d05535a, 0x08551304, 0x06020c60,   // de.ht.un_850 ht.fr.cs_553  et.rw.no_332 sv.da.de_664
  0x550413ad, 0x0f1028ad, 0x552764ad, 0x16001b02,   // et.fi.rw_643 sw.lt.lv_643  lg.gd.rw_643 tr.hr.un_220
  0x27115509, 0x0e002d0c, 0x20210704, 0x1a1001a4,   // rw.ro.gd_444 sk.is.un_530  it.jw.sq_332 en.lt.tl_433
  // [9f40]
  0x25211a0c, 0x310f1ba4, 0x6b0f1a04, 0x19090a0c,   // tl.jw.eu_543 tr.lv.az_433  tl.lv.ceb_332 pt.pl.gl_543
  0x21005319, 0x27000a07, 0x0e2b2808, 0x18001c08,   // ht.jw.un_750 pt.gd.un_420  sw.vi.is_443 id.ga.un_430
  0x091a21ee, 0x2809550b, 0x0c030209, 0x16002109,   // jw.tl.pl_422 rw.pl.sw_542  da.nl.sv_444 jw.hr.un_440
  0x310e0c07, 0x2d1918a6, 0x0d161bee, 0x04071009,   // sv.is.az_432 ga.gl.sk_521  tr.hr.cs_422 be.bg.ru_444
  // [9f50]
  0x13090d13, 0x1b000e05, 0x121b64a7, 0x0c290f0c,   // ne.hi.bh_665 is.tr.un_330  lg.tr.hu_532 lv.sl.sv_543
  0x6412230c, 0x53001b0c, 0x0d0908a4, 0x0d291709,   // ca.hu.lg_543 tr.ht.un_530  no.pl.cs_433 sr.sl.cs_444
  0x2a00290e, 0x1f002312, 0x1a00250d, 0x2a170f07,   // sl.mt.un_550 ca.cy.un_640  eu.tl.un_540 lv.sr.mt_432
  0x0e0802a4, 0x1113125a, 0x171b3104, 0x19110b04,   // da.no.is_433 hu.et.ro_553  az.tr.sr_332 es.ro.gl_332
  // [9f60]
  0x19112104, 0x1b312907, 0x1029170c, 0x041353a7,   // jw.ro.gl_332 sl.az.tr_432  sr.sl.lt_543 ht.et.fi_532
  0x010e08a4, 0x2d000604, 0x23002013, 0x536b1ba0,   // no.is.en_433 de.sk.un_320  sq.ca.un_650 tr.ceb.ht_322
  0x082113ad, 0x12081fad, 0x041017ee, 0x080304a4,   // et.jw.no_643 cy.no.hu_643  sr.be.ru_422 fi.nl.no_433
  0x2b0711a0, 0x0a000505, 0x3f060f12, 0x2a041aa0,   // ro.it.vi_322 fr.pt.un_330  lv.de.af_654 tl.fi.mt_322
  // [9f70]
  0x08200c08, 0x0e2d12ee, 0x13642502, 0x28003f2b,   // sv.sq.no_443 hu.sk.is_422  eu.lg.et_222 af.sw.un_980
  0x180601ac, 0x64312813, 0x1a1801a4, 0x0e08020e,   // en.de.ga_632 sw.az.lg_665  en.ga.tl_433 da.no.is_555
  0x0c0e0205, 0x28640eec, 0x130e0b05, 0x315528ee,   // da.is.sv_333 is.lg.sw_644  es.is.et_333 sw.rw.az_422
  0x6b0401a7, 0x076455a7, 0x09001f29, 0x1f001e07,   // en.fi.ceb_532 rw.lg.it_532  cy.pl.un_960 ms.cy.un_420
  // [9f80]
  0x0f2129ee, 0x13040302, 0x0f2d100d, 0x010b07a7,   // sl.jw.lv_422 nl.fi.et_222  lt.sk.lv_554 it.es.en_532
  0x190b280c, 0x290b1ba0, 0x1f270904, 0x03643fee,   // sw.es.gl_543 tr.es.sl_322  pl.gd.cy_332 af.lg.nl_422
  0x0d1729a0, 0x17001e02, 0x6b211a14, 0x09000f22,   // sl.sr.cs_322 ms.sr.un_220  tl.jw.ceb_666 lv.pl.un_870
  0x25040505, 0x120f21a0, 0x281b64ad, 0x0c022d04,   // fr.fi.eu_333 jw.lv.hu_322  lg.tr.sw_643 sk.da.sv_332
  // [9f90]
  0x0b0e2d0c, 0x116b28a0, 0x09001120, 0x283f64ad,   // sk.is.es_543 sw.ceb.ro_322  ro.pl.un_850 lg.af.sw_643
  0x2a291aa0, 0x2a645505, 0x190f0bee, 0x1b000c13,   // tl.sl.mt_322 rw.lg.mt_333  es.lv.gl_422 sv.tr.un_650
  0x250a285a, 0x2d100d07, 0x081e1c5a, 0x64000b08,   // sw.pt.eu_553 cs.lt.sk_432  id.ms.no_553 es.lg.un_430
  0x0a130707, 0x0a041155, 0x23070505, 0x190c0207,   // it.et.pt_432 ro.ru.mk_442  fr.it.ca_333 da.sv.gl_432
  // [9fa0]
  0x29020d07, 0x130e04a4, 0x04190a14, 0x080710ac,   // cs.da.sl_432 fi.is.et_433  pt.gl.fi_666 be.bg.uk_632
  0x2100110c, 0x01033fa6, 0x10250f08, 0x3f1e1c04,   // ro.jw.un_530 af.nl.en_521  lv.eu.lt_443 id.ms.af_332
  0x0a060507, 0x182704ad, 0x271805ee, 0x2d091012,   // fr.de.pt_432 fi.gd.ga_643  fr.ga.gd_422 lt.pl.sk_654
  0x0c280808, 0x05000422, 0x130c1b0c, 0x0400210c,   // no.sw.sv_443 fi.fr.un_870  tr.sv.et_543 jw.fi.un_530
  // [9fb0]
  0x28001a21, 0x1a2128ad, 0x64216b0c, 0x1020530c,   // tl.sw.un_860 sw.jw.tl_643  ceb.jw.lg_543 ht.sq.lt_543
  0x070411a6, 0x640855a0, 0x6b641a0c, 0x1a2164a0,   // ro.ru.bg_521 rw.no.lg_322  tl.lg.ceb_543 lg.jw.tl_322
  0x17002814, 0x040602a0, 0x1a556bec, 0x641a2104,   // sw.sr.un_660 da.de.fi_322  ceb.rw.tl_644 jw.tl.lg_332
  0x5300040c, 0x12002011, 0x1a536baf, 0x21002814,   // fi.ht.un_530 sq.hu.un_630  ceb.ht.tl_655 sw.jw.un_660
  // [9fc0]
  0x0a0121ee, 0x25046b07, 0x1a282105, 0x183f1fec,   // jw.en.pt_422 ceb.fi.eu_432  jw.sw.tl_333 cy.af.ga_644
  0x2500130d, 0x271f2304, 0x1700292b, 0x3f00010d,   // et.eu.un_540 ca.cy.gd_332  sl.sr.un_980 en.af.un_540
  0x10081104, 0x10001321, 0x5564285a, 0x1900280d,   // ro.uk.be_332 et.lt.un_860  sw.lg.rw_553 sw.gl.un_540
  0x19005505, 0x28085507, 0x05000309, 0x0a071fa0,   // rw.gl.un_330 rw.no.sw_432  nl.fr.un_440 cy.it.pt_322
  // [9fd0]
  0x050d20ee, 0x17160702, 0x2a64550c, 0x201112a0,   // sq.cs.fr_422 it.hr.sr_222  rw.lg.mt_543 hu.ro.sq_322
  0x1b000e02, 0x55006434, 0x042823a0, 0x115564ad,   // is.tr.un_220 lg.rw.un_A80  ca.sw.fi_322 lg.rw.ro_643
  0x2a5528ee, 0x230e0c11, 0x0e120ca0, 0x0c1827a9,   // sw.rw.mt_422 sv.is.ca_653  sv.hu.is_322 gd.ga.sv_544
  0x182027a7, 0x2303010c, 0x100a040c, 0x03005302,   // gd.sq.ga_532 en.nl.ca_543  ru.mk.be_543 ht.nl.un_220
  // [9fe0]
  0x0c0464a0, 0x08020cad, 0x1c2925ee, 0x0a020807,   // lg.fi.sv_322 sv.da.no_643  eu.sl.id_422 no.da.pt_432
  0x02200ca7, 0x0c2b0807, 0x11170b07, 0x3f0802a4,   // sv.sq.da_532 no.vi.sv_432  es.sr.ro_432 da.no.af_433
  0x0b0c2505, 0x0d642d0c, 0x2100201b, 0x0c0e0207,   // eu.sv.es_333 sk.lg.cs_543  sq.jw.un_770 da.is.sv_432
  0x17100f12, 0x132a12a6, 0x551204ee, 0x11002b07,   // lv.lt.sr_654 hu.mt.et_521  fi.hu.rw_422 vi.ro.un_420
  // [9ff0]
  0x0e081fec, 0x12033fa0, 0x171631a4, 0x19010d07,   // cy.no.is_644 af.nl.hu_322  az.hr.sr_433 cs.en.gl_432
  0x11041005, 0x1f080208, 0x0f1304ec, 0x55002907,   // be.ru.ro_333 da.no.cy_443  fi.et.lv_644 sl.rw.un_420
  0x02062304, 0x211c2304, 0x011204a0, 0x04001905,   // ca.de.da_332 ca.id.jw_332  fi.hu.en_322 gl.fi.un_330
  0x070301ee, 0x645512a0, 0x0f10010c, 0x102d29ad,   // en.nl.it_422 hu.rw.lg_322  en.lt.lv_543 sl.sk.lt_643

  // [a000]
  0x082d1f07, 0x122916a0, 0x21001008, 0x04121bec,   // cy.sk.no_432 hr.sl.hu_322  lt.jw.un_430 tr.hu.fi_644
  0x07055308, 0x041220a0, 0x6b2a0a12, 0x0b0a0ca0,   // ht.fr.it_443 sq.hu.fi_322  pt.mt.ceb_654 sv.pt.es_322
  0x11002d04, 0x060320a4, 0x27001107, 0x211a550c,   // sk.ro.un_320 sq.nl.de_433  ro.gd.un_420 rw.tl.jw_543
  0x256428a4, 0x64002508, 0x183f275a, 0x20005307,   // sw.lg.eu_433 eu.lg.un_430  gd.af.ga_553 ht.sq.un_420
  // [a010]
  0x0a000312, 0x25645511, 0x09000c19, 0x20006b04,   // nl.pt.un_640 rw.lg.eu_653  sv.pl.un_750 ceb.sq.un_320
  0x10080aaf, 0x29556412, 0x083f0fa4, 0x063f1008,   // mk.uk.be_655 lg.rw.sl_654  lv.af.no_433 lt.af.de_443
  0x11001902, 0x190b1102, 0x030f3fa9, 0x1e061f07,   // gl.ro.un_220 ro.es.gl_222  af.lv.nl_544 cy.de.ms_432
  0x282155ad, 0x2d001605, 0x18002a09, 0x23190b0c,   // rw.jw.sw_643 hr.sk.un_330  mt.ga.un_440 es.gl.ca_543
  // [a020]
  0x1700101a, 0x2a171614, 0x0e080c05, 0x04135505,   // be.sr.un_760 hr.sr.mt_666  sv.no.is_333 rw.et.fi_333
  0x17162aec, 0x55001307, 0x06000419, 0x1700040c,   // mt.hr.sr_644 et.rw.un_420  fi.de.un_750 ru.sr.un_530
  0x08121a08, 0x125328a7, 0x55001312, 0x13551204,   // tl.hu.no_443 sw.ht.hu_532  et.rw.un_640 hu.rw.et_332
  0x01063f07, 0x040653a9, 0x29000312, 0x21171602,   // af.de.en_432 ht.de.fi_544  nl.sl.un_640 hr.sr.jw_222
  // [a030]
  0x1b033f04, 0x070405a4, 0x0b0604ee, 0x55641a08,   // af.nl.tr_332 fr.fi.it_433  fi.de.es_422 tl.lg.rw_443
  0x0813040e, 0x23040bee, 0x200455a7, 0x090711a0,   // fi.et.no_555 es.fi.ca_422  rw.fi.sq_532 ro.it.pl_322
  0x1a6b1302, 0x551225a9, 0x645512ad, 0x16001207,   // et.ceb.tl_222 eu.hu.rw_544  hu.rw.lg_643 hu.hr.un_420
  0x0f0903ad, 0x0c310255, 0x03061b05, 0x2d0d1aee,   // nl.pl.lv_643 da.az.sv_442  tr.de.nl_333 tl.cs.sk_422
  // [a040]
  0x06001b07, 0x080604a4, 0x170411a9, 0x18071104,   // tr.de.un_420 fi.de.no_433  ro.ru.sr_544 ro.it.ga_332
  0x2d0d3fa0, 0x160f2507, 0x011807a0, 0x28642307,   // af.cs.sk_322 eu.lv.hr_432  it.ga.en_322 ca.lg.sw_432
  0x2d253f05, 0x29001a02, 0x1e211cee, 0x122a08a4,   // af.eu.sk_333 tl.sl.un_220  id.jw.ms_422 no.mt.hu_433
  0x080e2aad, 0x05002005, 0x0a000812, 0x2a00010c,   // mt.is.no_643 sq.fr.un_330  uk.mk.un_640 en.mt.un_530
  // [a050]
  0x190b230e, 0x55002705, 0x3f1801a0, 0x13080ead,   // ca.es.gl_555 gd.rw.un_330  en.ga.af_322 is.no.et_643
  0x0c2b01a0, 0x1e010a08, 0x13080260, 0x080221ec,   // en.vi.sv_322 pt.en.ms_443  da.no.et_664 jw.da.no_644
  0x19052155, 0x11080408, 0x103f0fa0, 0x20311155,   // jw.fr.gl_442 ru.uk.ro_443  lv.af.lt_322 ro.az.sq_442
  0x131c095a, 0x06270ea0, 0x2d0d28a9, 0x031827ad,   // hi.mr.bh_553 is.gd.de_322  sw.cs.sk_544 gd.ga.nl_643
  // [a060]
  0x0f07060c, 0x05275307, 0x27000304, 0x1100060c,   // de.it.lv_543 ht.gd.fr_432  nl.gd.un_320 de.ro.un_530
  0x0903060c, 0x1e001002, 0x64000f08, 0x130e2904,   // de.nl.pl_543 lt.ms.un_220  lv.lg.un_430 sl.is.et_332
  0x1e000908, 0x0f2d0d55, 0x10170705, 0x030928a0,   // pl.ms.un_430 cs.sk.lv_442  bg.sr.be_333 sw.pl.nl_322
  0x0d2d1213, 0x290d5508, 0x531a6ba0, 0x532907a7,   // hu.sk.cs_665 rw.cs.sl_443  ceb.tl.ht_322 it.sl.ht_532
  // [a070]
  0x0e1f0705, 0x6b001c04, 0x1e1b1ca0, 0x0f006409,   // it.cy.is_333 id.ceb.un_320  id.tr.ms_322 lg.lv.un_440
  0x251e1c08, 0x281f01a4, 0x1c641e0c, 0x3f0f210c,   // id.ms.eu_443 en.cy.sw_433  ms.lg.id_543 jw.lv.af_543
  0x21551f0c, 0x070b0a02, 0x0f001807, 0x07002a22,   // cy.rw.jw_543 pt.es.it_222  ga.lv.un_420 mt.it.un_870
  0x1a1c5307, 0x093f2807, 0x64070cee, 0x08131b07,   // ht.id.tl_432 sw.af.pl_432  sv.it.lg_422 tr.et.no_432
  // [a080]
  0x081310a0, 0x07001f0d, 0x0a2028ad, 0x10023f04,   // lt.et.no_322 cy.it.un_540  sw.sq.pt_643 af.da.lt_332
  0x12250b07, 0x2700280e, 0x53211b04, 0x12312302,   // es.eu.hu_432 sw.gd.un_550  tr.jw.ht_332 ca.az.hu_222
  0x0300080c, 0x042d0d07, 0x0f1017a0, 0x2a290faf,   // no.nl.un_530 cs.sk.fi_432  sr.lt.lv_322 lv.sl.mt_655
  0x0807250c, 0x281b2007, 0x1908280c, 0x2a182ba7,   // eu.it.no_543 sq.tr.sw_432  sw.no.gl_543 vi.ga.mt_532
  // [a090]
  0x1c00130b, 0x02211c04, 0x1b072a0c, 0x10081105,   // bh.mr.un_520 id.jw.da_332  mt.it.tr_543 ro.uk.be_333
  0x030231a0, 0x6e000f05, 0x06070455, 0x040c0608,   // az.da.nl_322 lv.blu.un_330  fi.it.de_442 de.sv.fi_443
  0x1600281a, 0x2d121904, 0x3f001004, 0x2100122c,   // sw.hr.un_760 gl.hu.sk_332  lt.af.un_320 ur.fa.un_990
  0x0d1c09a7, 0x64000f19, 0x1e001102, 0x171611af,   // hi.mr.ne_532 lv.lg.un_750  ro.ms.un_220 ro.hr.sr_655
  // [a0a0]
  0x28270807, 0x6b530907, 0x03060d02, 0x645321ad,   // no.gd.sw_432 pl.ht.ceb_432  cs.de.nl_222 jw.ht.lg_643
  0x033f0655, 0x111827a7, 0x556453ad, 0x02130cee,   // de.af.nl_442 gd.ga.ro_532  ht.lg.rw_643 sv.et.da_422
  0x1a6b090c, 0x6b095355, 0x2a002707, 0x53006b05,   // pl.ceb.tl_543 ht.pl.ceb_442  gd.mt.un_420 ceb.ht.un_330
  0x1300120d, 0x11180107, 0x17160e04, 0x6e1827af,   // hu.et.un_540 en.ga.ro_432  is.hr.sr_332 gd.ga.blu_655
  // [a0b0]
  0x0c531c0c, 0x170c0804, 0x3f0501a0, 0x1c1a2104,   // id.ht.sv_543 no.sv.sr_332  en.fr.af_322 jw.tl.id_332
  0x131f3f07, 0x1c002808, 0x290f1f12, 0x17036408,   // af.cy.et_432 sw.id.un_430  cy.lv.sl_654 lg.nl.sr_443
  0x101f29a4, 0x100428ee, 0x21100f05, 0x311264a0,   // sl.cy.lt_433 sw.fi.lt_422  lv.lt.jw_333 lg.hu.az_322
  0x1b3f060c, 0x1c1921a4, 0x0a040811, 0x17161fec,   // de.af.tr_543 jw.gl.id_433  uk.ru.mk_653 cy.hr.sr_644
  // [a0c0]
  0x1b3113ec, 0x03000622, 0x051109ec, 0x2100130c,   // et.az.tr_644 de.nl.un_870  pl.ro.fr_644 et.jw.un_530
  0x13280405, 0x64211c08, 0x1c131e55, 0x10122802,   // fi.sw.et_333 id.jw.lg_443  ms.et.id_442 sw.hu.lt_222
  0x536b28a0, 0x1710080e, 0x17160f05, 0x11100da0,   // sw.ceb.ht_322 uk.be.sr_555  lv.hr.sr_333 cs.lt.ro_322
  0x0c006e04, 0x12160f08, 0x13000b02, 0x042813a7,   // blu.sv.un_320 lv.hr.hu_443  es.et.un_220 et.sw.fi_532
  // [a0d0]
  0x121c21a9, 0x281004a0, 0x03013fa0, 0x1c641b04,   // jw.id.hu_544 fi.lt.sw_322  af.en.nl_322 tr.lg.id_332
  0x0a100705, 0x040a170b, 0x06171608, 0x1f001e2a,   // bg.be.mk_333 sr.mk.ru_542  hr.sr.de_443 ms.cy.un_970
  0x280453af, 0x100f130c, 0x132518ad, 0x10002005,   // ht.fi.sw_655 et.lv.lt_543  ga.eu.et_643 sq.lt.un_330
  0x21001908, 0x6b181aee, 0x1a000118, 0x10002b05,   // gl.jw.un_430 tl.ga.ceb_422  en.tl.un_740 vi.lt.un_330
  // [a0e0]
  0x1f002521, 0x190f25ec, 0x04002a0c, 0x28020ca4,   // eu.cy.un_860 eu.lv.gl_644  mt.fi.un_530 sv.da.sw_433
  0x2000282b, 0x101f0f0c, 0x131804a7, 0x21282007,   // sw.sq.un_980 lv.cy.lt_543  fi.ga.et_532 sq.sw.jw_432
  0x1f04180d, 0x132055a7, 0x312055ec, 0x09002b14,   // ga.fi.cy_554 rw.sq.et_532  rw.sq.az_644 vi.pl.un_660
  0x20005529, 0x060e3f04, 0x2a000413, 0x6b1a28ee,   // rw.sq.un_960 af.is.de_332  fi.mt.un_650 sw.tl.ceb_422
  // [a0f0]
  0x19202807, 0x23002b1a, 0x20132311, 0x550f05a6,   // sw.sq.gl_432 vi.ca.un_760  ca.et.sq_653 fr.lv.rw_521
  0x08001213, 0x190710a0, 0x2a000e12, 0x641a0607,   // hu.no.un_650 lt.it.gl_322  is.mt.un_640 de.tl.lg_432
  0x05230305, 0x1f20270c, 0x3f180407, 0x060418ec,   // nl.ca.fr_333 gd.sq.cy_543  fi.ga.af_432 ga.fi.de_644
  0x0b1b0a07, 0x061b200d, 0x31291ba0, 0x0e002a0e,   // pt.tr.es_432 sq.tr.de_554  tr.sl.az_322 mt.is.un_550
  // [a100]
  0x642701a0, 0x0806020c, 0x55531bee, 0x2b0a1b07,   // en.gd.lg_322 da.de.no_543  tr.ht.rw_422 tr.pt.vi_432
  0x1c2a1212, 0x553f0607, 0x0c00160b, 0x161e1708,   // hu.mt.id_654 de.af.rw_432  hr.sv.un_520 sr.ms.hr_443
  0x1800310e, 0x2b120107, 0x55640ca4, 0x1000061b,   // az.ga.un_550 en.hu.vi_432  sv.lg.rw_433 de.lt.un_770
  0x136b0655, 0x53283fa6, 0x21281e0c, 0x1a6421a7,   // de.ceb.et_442 af.sw.ht_521  ms.sw.jw_543 jw.lg.tl_532
  // [a110]
  0x233f01ad, 0x2d050a55, 0x1c202707, 0x16290da4,   // en.af.ca_643 pt.fr.sk_442  gd.sq.id_432 cs.sl.hr_433
  0x271f1804, 0x0c080da4, 0x1a0c21ee, 0x55280609,   // ga.cy.gd_332 cs.no.sv_433  jw.sv.tl_422 de.sw.rw_444
  0x04253fee, 0x64210407, 0x2b231904, 0x04033f09,   // af.eu.fi_422 fi.jw.lg_432  gl.ca.vi_332 af.nl.fi_444
  0x04000322, 0x042110a4, 0x25062104, 0x1a1364ee,   // nl.fi.un_870 lt.jw.fi_433  jw.de.eu_332 lg.et.tl_422
  // [a120]
  0x0e1806ad, 0x1f00130c, 0x21005514, 0x216b1a5a,   // de.ga.is_643 et.cy.un_530  rw.jw.un_660 tl.ceb.jw_553
  0x1b1713a0, 0x1c1617a7, 0x1a64115a, 0x643f0309,   // et.sr.tr_322 sr.hr.id_532  ro.lg.tl_553 nl.af.lg_444
  0x1e1a1112, 0x01000412, 0x1a6b11a7, 0x29160d05,   // ro.tl.ms_654 fi.en.un_640  ro.ceb.tl_532 cs.hr.sl_333
  0x12050a05, 0x2d00101a, 0x1364250c, 0x1c2111af,   // pt.fr.hu_333 lt.sk.un_760  eu.lg.et_543 ro.jw.id_655
  // [a130]
  0x063f0802, 0x6b11210c, 0x022d0c07, 0x13041ca0,   // no.af.de_222 jw.ro.ceb_543  sv.sk.da_432 id.fi.et_322
  0x11006419, 0x1a11640c, 0x0e642109, 0x0f0c2dee,   // lg.ro.un_750 lg.ro.tl_543  jw.lg.is_444 sk.sv.lv_422
  0x1b31110e, 0x1b1e0f04, 0x641b31ad, 0x2100110d,   // ro.az.tr_555 lv.ms.tr_332  az.tr.lg_643 ro.jw.un_540
  0x212a130c, 0x311b1112, 0x6b001109, 0x09112304,   // et.mt.jw_543 ro.tr.az_654  ro.ceb.un_440 ca.ro.pl_332
  // [a140]
  0x040a1714, 0x1200310d, 0x120220a0, 0x21251c05,   // sr.mk.ru_666 az.hu.un_540  sq.da.hu_322 id.eu.jw_333
  0x3f0f0107, 0x10012307, 0x130c040d, 0x010f23ee,   // en.lv.af_432 ca.en.lt_432  fi.sv.et_554 ca.lv.en_422
  0x041e0cee, 0x0a041004, 0x04080a11, 0x2a2301a0,   // sv.ms.fi_422 be.ru.mk_332  mk.uk.ru_653 en.ca.mt_322
  0x09001112, 0x1f0b18a9, 0x2012050e, 0x17002919,   // ro.pl.un_640 ga.es.cy_544  fr.hu.sq_555 sl.sr.un_750
  // [a150]
  0x641e2502, 0x6b012307, 0x130520ad, 0x55000705,   // eu.ms.lg_222 ca.en.ceb_432  sq.fr.et_643 it.rw.un_330
  0x3f030ea0, 0x230f010c, 0x0d001714, 0x17160dba,   // is.nl.af_322 en.lv.ca_543  sr.cs.un_660 cs.hr.sr_843
  0x0e2708af, 0x01230fa4, 0x0a1108a4, 0x1355640d,   // no.gd.is_655 lv.ca.en_433  uk.ro.mk_433 lg.rw.et_554
  0x1a532508, 0x3f2305a0, 0x10132504, 0x0e046407,   // eu.ht.tl_443 fr.ca.af_322  eu.et.lt_332 lg.fi.is_432
  // [a160]
  0x0e182704, 0x083f1ba0, 0x0e2555a0, 0x201b2107,   // gd.ga.is_332 tr.af.no_322  rw.eu.is_322 jw.tr.sq_432
  0x180b0a04, 0x080e27ec, 0x1a250e04, 0x292a03ee,   // pt.es.ga_332 gd.is.no_644  is.eu.tl_332 nl.mt.sl_422
  0x040c2904, 0x10552513, 0x080221a9, 0x1a316b09,   // sl.sv.fi_332 eu.rw.lt_665  jw.da.no_544 ceb.az.tl_444
  0x2507130b, 0x040f17ee, 0x29006b08, 0x28006b14,   // et.it.eu_542 sr.lv.fi_422  ceb.sl.un_430 ceb.sw.un_660
  // [a170]
  0x0a2d0d5a, 0x06211eaf, 0x25106ba4, 0x251308a6,   // cs.sk.pt_553 ms.jw.de_655  ceb.lt.eu_433 no.et.eu_521
  0x131004a0, 0x2b210612, 0x0a041712, 0x1c001e18,   // fi.lt.et_322 de.jw.vi_654  sr.ru.mk_654 ms.id.un_740
  0x06211c09, 0x09532d05, 0x25002813, 0x04002812,   // id.jw.de_444 sk.ht.pl_333  sw.eu.un_650 sw.fi.un_640
  0x2100060d, 0x0f000405, 0x2a0410a4, 0x2a536bee,   // de.jw.un_540 fi.lv.un_330  lt.fi.mt_433 ceb.ht.mt_422
  // [a180]
  0x53040fa4, 0x0f251ca0, 0x3f200e55, 0x04002a14,   // lv.fi.ht_433 id.eu.lv_322  is.sq.af_442 mt.fi.un_660
  0x041e25a7, 0x0f2853a4, 0x31020c08, 0x175528ac,   // eu.ms.fi_532 ht.sw.lv_433  sv.da.az_443 sw.rw.sr_632
  0x061c21ad, 0x1c281e0c, 0x283f2507, 0x2100060e,   // jw.id.de_643 ms.sw.id_543  eu.af.sw_432 de.jw.un_550
  0x530304ad, 0x03102aaf, 0x1b1a04a4, 0x6b1a1c12,   // fi.nl.ht_643 mt.lt.nl_655  fi.tl.tr_433 id.tl.ceb_654
  // [a190]
  0x1e171655, 0x1b250fa7, 0x1e1c2111, 0x1a000807,   // hr.sr.ms_442 lv.eu.tr_532  jw.id.ms_653 no.tl.un_420
  0x0c31550c, 0x21311ba9, 0x19002902, 0x170d1611,   // rw.az.sv_543 tr.az.jw_544  sl.gl.un_220 hr.cs.sr_653
  0x2b182d0c, 0x531b120c, 0x311119ee, 0x211c0904,   // sk.ga.vi_543 hu.tr.ht_543  gl.ro.az_422 pl.id.jw_332
  0x1104530c, 0x13001c2a, 0x102d17a0, 0x25001b09,   // ht.fi.ro_543 mr.bh.un_970  sr.sk.lt_322 tr.eu.un_440
  // [a1a0]
  0x0d2916a0, 0x11050107, 0x13083f02, 0x17070aa6,   // hr.sl.cs_322 en.fr.ro_432  af.no.et_222 mk.bg.sr_521
  0x0201070c, 0x0f000314, 0x036b25ee, 0x0e000409,   // it.en.da_543 nl.lv.un_660  eu.ceb.nl_422 fi.is.un_440
  0x022511a0, 0x026b08a9, 0x2302110c, 0x0700170e,   // ro.eu.da_322 no.ceb.da_544  ro.da.ca_543 sr.bg.un_550
  0x17131607, 0x076b01ee, 0x021811ad, 0x230e0aa0,   // hr.et.sr_432 en.ceb.it_422  ro.ga.da_643 pt.is.ca_322
  // [a1b0]
  0x2d171007, 0x1600010d, 0x3f000208, 0x11000b09,   // lt.sr.sk_432 en.hr.un_540  da.af.un_430 es.ro.un_440
  0x23132513, 0x061813ee, 0x0523010b, 0x03000213,   // eu.et.ca_665 et.ga.de_422  en.ca.fr_542 da.nl.un_650
  0x12180560, 0x0211010c, 0x2d2821a0, 0x02060804,   // fr.ga.hu_664 en.ro.da_543  jw.sw.sk_322 no.de.da_332
  0x17551604, 0x0400250b, 0x00006b01, 0x23001607,   // hr.rw.sr_332 eu.fi.un_520  ceb.un.un_200 hr.ca.un_420
  // [a1c0]
  0x21110a02, 0x160520a0, 0x08030ca9, 0x131e2808,   // pt.ro.jw_222 sq.fr.hr_322  sv.nl.no_544 sw.ms.et_443
  0x0b00280d, 0x3f1304a0, 0x2510285a, 0x042813a4,   // sw.es.un_540 fi.et.af_322  sw.lt.eu_553 et.sw.fi_433
  0x2a0413a0, 0x0b001602, 0x2b006b12, 0x071117a4,   // et.fi.mt_322 hr.es.un_220  ceb.vi.un_640 sr.ro.bg_433
  0x213155ad, 0x085553a0, 0x170710a9, 0x19001308,   // rw.az.jw_643 ht.rw.no_322  be.bg.sr_544 et.gl.un_430
  // [a1d0]
  0x1a6e0a07, 0x16000f0d, 0x1118010c, 0x2d0d19af,   // pt.blu.tl_432 lv.hr.un_540  en.ga.ro_543 gl.cs.sk_655
  0x2111200c, 0x0b182dee, 0x20102a0c, 0x11070460,   // sq.ro.jw_543 sk.ga.es_422  mt.lt.sq_543 ru.bg.ro_664
  0x10003111, 0x0c13040c, 0x08040c07, 0x6b136412,   // az.lt.un_630 fi.et.sv_543  sv.fi.no_432 lg.et.ceb_654
  0x080a17a6, 0x0e0813a6, 0x04080eec, 0x64080708,   // sr.mk.uk_521 et.no.is_521  is.no.fi_644 it.no.lg_443
  // [a1e0]
  0x18130402, 0x0c1208a0, 0x13000e04, 0x040e0a04,   // fi.et.ga_222 no.hu.sv_322  is.et.un_320 pt.is.fi_332
  0x080d290c, 0x210e1aa4, 0x2a1220a4, 0x1b211c07,   // sl.cs.no_543 tl.is.jw_433  sq.hu.mt_433 id.jw.tr_432
  0x081b2007, 0x0d001622, 0x1c2a1355, 0x55311a05,   // sq.tr.no_432 hr.cs.un_870  et.mt.id_442 tl.az.rw_333
  0x13040e05, 0x17290cee, 0x0e0802ec, 0x0c3f0307,   // is.fi.et_333 sv.sl.sr_422  da.no.is_644 nl.af.sv_432
  // [a1f0]
  0x2a0407af, 0x130c1012, 0x25042da4, 0x042813ec,   // it.fi.mt_655 lt.sv.et_654  sk.fi.eu_433 et.sw.fi_644
  0x05001009, 0x1b1a21a4, 0x06020508, 0x1c130455,   // lt.fr.un_440 jw.tl.tr_433  fr.da.de_443 fi.et.id_442
  0x2d0f10a7, 0x13122aee, 0x2a005513, 0x55000902,   // lt.lv.sk_532 mt.hu.et_422  rw.mt.un_650 pl.rw.un_220
  0x6b2a55a0, 0x192718ad, 0x132305a7, 0x282164a4,   // rw.mt.ceb_322 ga.gd.gl_643  fr.ca.et_532 lg.jw.sw_433
  // [a200]
  0x2d0d6b02, 0x64211c0e, 0x18285504, 0x1b002512,   // ceb.cs.sk_222 id.jw.lg_555  rw.sw.ga_332 eu.tr.un_640
  0x0f102d14, 0x10000e21, 0x130231a9, 0x080c040d,   // sk.lt.lv_666 is.lt.un_860  az.da.et_544 fi.sv.no_554
  0x050b0713, 0x0400530e, 0x0f2009ad, 0x11000807,   // it.es.fr_665 ht.fi.un_550  pl.sq.lv_643 no.ro.un_420
  0x190a07ee, 0x080264a0, 0x1a002d1a, 0x6e1a01ee,   // it.pt.gl_422 lg.da.no_322  sk.tl.un_760 en.tl.blu_422
  // [a210]
  0x530c02ac, 0x0c2008ee, 0x07000509, 0x55281e04,   // da.sv.ht_632 no.sq.sv_422  fr.it.un_440 ms.sw.rw_332
  0x042718ec, 0x55641b12, 0x0e1227a9, 0x31001902,   // ga.gd.fi_644 tr.lg.rw_654  gd.hu.is_544 gl.az.un_220
  0x01041107, 0x0853040c, 0x040717a7, 0x1a530d07,   // ro.fi.en_432 fi.ht.no_543  sr.bg.ru_532 cs.ht.tl_432
  0x10060e07, 0x04181f09, 0x5304210c, 0x25000707,   // is.de.lt_432 cy.ga.fi_444  jw.fi.ht_543 it.eu.un_420
  // [a220]
  0x18001602, 0x27551a04, 0x290e2d0c, 0x2d0229a4,   // hr.ga.un_220 tl.rw.gd_332  sk.is.sl_543 sl.da.sk_433
  0x022d2909, 0x64552aaf, 0x012b06ad, 0x1c0913ba,   // sl.sk.da_444 mt.rw.lg_655  de.vi.en_643 bh.hi.mr_843
  0x641b3112, 0x25202aa0, 0x071e04a0, 0x182a060c,   // az.tr.lg_654 mt.sq.eu_322  fi.ms.it_322 de.mt.ga_543
  0x060f2514, 0x070518a0, 0x29001205, 0x09000f23,   // eu.lv.de_666 ga.fr.it_322  hu.sl.un_330 lv.pl.un_880
  // [a230]
  0x13110ea0, 0x2b002807, 0x5528130b, 0x05000f04,   // is.ro.et_322 sw.vi.un_420  et.sw.rw_542 lv.fr.un_320
  0x12130c04, 0x1c282004, 0x02000e0c, 0x55251305,   // sv.et.hu_332 sq.sw.id_332  is.da.un_530 et.eu.rw_333
  0x1a041b04, 0x1a311b13, 0x292d3fa4, 0x0a062309,   // tr.fi.tl_332 tr.az.tl_665  af.sk.sl_433 ca.de.pt_444
  0x0e292d0c, 0x120e0a07, 0x533102a0, 0x2a0609ad,   // sk.sl.is_543 pt.is.hu_432  da.az.ht_322 pl.de.mt_643
  // [a240]
  0x06001b22, 0x12000923, 0x0b210208, 0x060c1fee,   // tr.de.un_870 pl.hu.un_880  da.jw.es_443 cy.sv.de_422
  0x160f1004, 0x21023fee, 0x3f2503af, 0x23000608,   // lt.lv.hr_332 af.da.jw_422  nl.eu.af_655 de.ca.un_430
  0x061b08ec, 0x18270611, 0x03021f04, 0x1b315313,   // no.tr.de_644 de.gd.ga_653  cy.da.nl_332 ht.az.tr_665
  0x03001004, 0x190a25a4, 0x0811130c, 0x022131a6,   // lt.nl.un_320 eu.pt.gl_433  et.ro.no_543 az.jw.da_521
  // [a250]
  0x160901a4, 0x531b0cee, 0x06200908, 0x01271804,   // en.pl.hr_433 sv.tr.ht_422  pl.sq.de_443 ga.gd.en_332
  0x08131ca4, 0x1c00270b, 0x1e001207, 0x16012905,   // id.et.no_433 gd.id.un_520  hu.ms.un_420 sl.en.hr_333
  0x0d251304, 0x04081755, 0x11000920, 0x01000518,   // et.eu.cs_332 sr.uk.ru_442  pl.ro.un_850 fr.en.un_740
  0x12530807, 0x0c001218, 0x061a09a7, 0x290f1713,   // no.ht.hu_432 hu.sv.un_740  pl.tl.de_532 sr.lv.sl_665
  // [a260]
  0x131104ec, 0x550113ee, 0x6425130c, 0x21531ca0,   // fi.ro.et_644 et.en.rw_422  et.eu.lg_543 id.ht.jw_322
  0x13110f04, 0x281e0eee, 0x16205307, 0x0e3153ee,   // lv.ro.et_332 is.ms.sw_422  ht.sq.hr_432 ht.az.is_422
  0x19002802, 0x170407a7, 0x1a001604, 0x251729a0,   // sw.gl.un_220 bg.ru.sr_532  hr.tl.un_320 sl.sr.eu_322
  0x04211060, 0x020c0811, 0x010b05ee, 0x3f005508,   // lt.jw.fi_664 no.sv.da_653  fr.es.en_422 rw.af.un_430
  // [a270]
  0x0c0302a0, 0x031706a0, 0x0b2319a4, 0x6b18010c,   // da.nl.sv_322 de.sr.nl_322  gl.ca.es_433 en.ga.ceb_543
  0x53645505, 0x53312a04, 0x043f0308, 0x01000702,   // rw.lg.ht_333 mt.az.ht_332  nl.af.fi_443 it.en.un_220
  0x19001819, 0x023f0c08, 0x55033f13, 0x0810110c,   // ga.gl.un_750 sv.af.da_443  af.nl.rw_665 ro.be.uk_543
  0x1e1c19a0, 0x3f000802, 0x0d0e2da7, 0x071110a9,   // gl.id.ms_322 no.af.un_220  sk.is.cs_532 be.ro.bg_544
  // [a280]
  0x0c061255, 0x0c02080b, 0x120831a0, 0x023f0908,   // hu.de.sv_442 no.da.sv_542  az.no.hu_322 pl.af.da_443
  0x11231855, 0x07030fee, 0x10042104, 0x110f03ee,   // ga.ca.ro_442 lv.nl.it_422  jw.fi.lt_332 nl.lv.ro_422
  0x6b55280c, 0x182827a4, 0x531b280c, 0x20552308,   // sw.rw.ceb_543 gd.sw.ga_433  sw.tr.ht_543 ca.rw.sq_443
  0x08020daf, 0x2d040f07, 0x251a0107, 0x08100a0e,   // cs.da.no_655 lv.fi.sk_432  en.tl.eu_432 mk.be.uk_555
  // [a290]
  0x21002705, 0x1c2116a0, 0x0b11230d, 0x2a041307,   // gd.jw.un_330 hr.jw.id_322  ca.ro.es_554 et.fi.mt_432
  0x060c20a4, 0x2011250c, 0x23111907, 0x132301a0,   // sq.sv.de_433 eu.ro.sq_543  gl.ro.ca_432 en.ca.et_322
  0x550921ec, 0x09170f05, 0x042523ec, 0x2d1b5304,   // jw.pl.rw_644 lv.sr.pl_333  ca.eu.fi_644 ht.tr.sk_332
  0x28042da0, 0x0500131a, 0x0b0a1ca4, 0x0f0c0207,   // sk.fi.sw_322 et.fr.un_760  id.pt.es_433 da.sv.lv_432
  // [a2a0]
  0x28040a07, 0x6e17160d, 0x06000919, 0x0c033f0e,   // pt.fi.sw_432 hr.sr.blu_554  pl.de.un_750 af.nl.sv_555
  0x0e0d1202, 0x3f092aaf, 0x122a0704, 0x64010707,   // hu.cs.is_222 mt.pl.af_655  it.mt.hu_332 it.en.lg_432
  0x030802a0, 0x09002a14, 0x212a0704, 0x3f31100c,   // da.no.nl_322 mt.pl.un_660  it.mt.jw_332 lt.az.af_543
  0x07190b13, 0x3f2a0eee, 0x232a0704, 0x532b1c0d,   // es.gl.it_665 is.mt.af_422  it.mt.ca_332 id.vi.ht_554
  // [a2b0]
  0x082d0d12, 0x18010ca7, 0x0d000705, 0x07001613,   // cs.sk.no_654 sv.en.ga_532  it.cs.un_330 hr.it.un_650
  0x0f2d0d05, 0x0f2a10af, 0x10080208, 0x010b05a0,   // cs.sk.lv_333 lt.mt.lv_655  da.no.lt_443 fr.es.en_322
  0x040501a0, 0x0912180c, 0x01082a07, 0x05000608,   // en.fr.fi_322 ga.hu.pl_543  mt.no.en_432 de.fr.un_430
  0x092911a4, 0x0f0619ee, 0x13020ca4, 0x190a1105,   // ro.sl.pl_433 gl.de.lv_422  sv.da.et_433 ro.pt.gl_333
  // [a2c0]
  0x0e000705, 0x121023a0, 0x0a002b02, 0x202a1c07,   // it.is.un_330 ca.lt.hu_322  vi.pt.un_220 id.mt.sq_432
  0x21005308, 0x070419a7, 0x64281aa7, 0x646b1a13,   // ht.jw.un_430 gl.fi.it_532  tl.sw.lg_532 tl.ceb.lg_665
  0x64001704, 0x1a286407, 0x53645508, 0x6e1e6b0d,   // sr.lg.un_320 lg.sw.tl_432  rw.lg.ht_443 ceb.ms.blu_554
  0x281a64ac, 0x10070460, 0x201807af, 0x3f556404,   // lg.tl.sw_632 ru.bg.be_664  it.ga.sq_655 lg.rw.af_332
  // [a2d0]
  0x1708070c, 0x083f0307, 0x0b001818, 0x642855ee,   // bg.uk.sr_543 nl.af.no_432  ga.es.un_740 rw.sw.lg_422
  0x11006e0c, 0x11212aa4, 0x21642507, 0x531a01a4,   // blu.ro.un_530 mt.jw.ro_433  eu.lg.jw_432 en.tl.ht_433
  0x2d0d2904, 0x270e0c02, 0x09001809, 0x0c060eac,   // sl.cs.sk_332 sv.is.gd_222  ga.pl.un_440 is.de.sv_632
  0x55000d02, 0x015321a0, 0x12002913, 0x313f10ad,   // cs.rw.un_220 jw.ht.en_322  sl.hu.un_650 lt.af.az_643
  // [a2e0]
  0x0e060207, 0x09000107, 0x030725a7, 0x2a0719a9,   // da.de.is_432 en.pl.un_420  eu.it.nl_532 gl.it.mt_544
  0x2b1a6b04, 0x0c271fa6, 0x556423af, 0x020608ec,   // ceb.tl.vi_332 cy.gd.sv_521  ca.lg.rw_655 no.de.da_644
  0x09000b0b, 0x080c0fee, 0x0f04050c, 0x04000507,   // es.pl.un_520 lv.sv.no_422  fr.fi.lv_543 fr.fi.un_420
  0x2809070b, 0x291620ec, 0x072a09a4, 0x2500050c,   // it.pl.sw_542 sq.hr.sl_644  pl.mt.it_433 fr.eu.un_530
  // [a2f0]
  0x0b00051b, 0x060c0eec, 0x100f1ca0, 0x290c1aa0,   // fr.es.un_770 is.sv.de_644  id.lv.lt_322 tl.sv.sl_322
  0x08003f1b, 0x09006e04, 0x31100307, 0x02001b19,   // af.no.un_770 blu.pl.un_320  nl.lt.az_432 tr.da.un_750
  0x55190a08, 0x2d100f55, 0x0c0e0811, 0x063f0ca4,   // pt.gl.rw_443 lv.lt.sk_442  no.is.sv_653 sv.af.de_433
  0x0b071f55, 0x3f100b08, 0x273f035a, 0x04060f14,   // cy.it.es_442 es.lt.af_443  nl.af.gd_553 lv.de.fi_666
  // [a300]
  0x07100f12, 0x080e0f0c, 0x090306a0, 0x3f2a0bad,   // lv.lt.it_654 lv.is.no_543  de.nl.pl_322 es.mt.af_643
  0x0f2d1007, 0x023f0f07, 0x033f2512, 0x1a1953ec,   // lt.sk.lv_432 lv.af.da_432  eu.af.nl_654 ht.gl.tl_644
  0x1623190e, 0x06002002, 0x070811ac, 0x2b200404,   // gl.ca.hr_555 sq.de.un_220  ro.uk.bg_632 fi.sq.vi_332
  0x0b002804, 0x0e2d12a4, 0x0e04090d, 0x13100e04,   // sw.es.un_320 hu.sk.is_433  pl.fi.is_554 is.lt.et_332
  // [a310]
  0x0c0f030c, 0x0d1064a0, 0x1900552a, 0x040801a0,   // nl.lv.sv_543 lg.lt.cs_322  rw.gl.un_970 en.no.fi_322
  0x040605ad, 0x0c3f0802, 0x17041013, 0x133f08a0,   // fr.de.fi_643 no.af.sv_222  be.ru.sr_665 no.af.et_322
  0x64190b08, 0x11002d02, 0x020964a4, 0x070b2807,   // es.gl.lg_443 sk.ro.un_220  lg.pl.da_433 sw.es.it_432
  0x081601a4, 0x17081112, 0x0964070b, 0x211125a7,   // en.hr.no_433 ro.uk.sr_654  it.lg.pl_542 eu.ro.jw_532
  // [a320]
  0x0f000b09, 0x11285512, 0x07006419, 0x08060504,   // es.lv.un_440 rw.sw.ro_654  lg.it.un_750 fr.de.no_332
  0x2104200c, 0x053f5505, 0x1c0821ee, 0x0d001609,   // sq.fi.jw_543 rw.af.fr_333  jw.no.id_422 hr.cs.un_440
  0x171619ee, 0x1a000707, 0x0900160c, 0x13072d04,   // gl.hr.sr_422 it.tl.un_420  hr.pl.un_530 sk.it.et_332
  0x170a0814, 0x64005318, 0x0a070f09, 0x050e08ee,   // uk.mk.sr_666 ht.lg.un_740  lv.it.pt_444 no.is.fr_422
  // [a330]
  0x1f27180d, 0x0d1e1c02, 0x0700102b, 0x03533f0d,   // ga.gd.cy_554 id.ms.cs_222  be.bg.un_980 af.ht.nl_554
  0x120d21a0, 0x180601a0, 0x100501a0, 0x101907a6,   // jw.cs.hu_322 en.de.ga_322  en.fr.lt_322 it.gl.lt_521
  0x10000b09, 0x27230107, 0x182d0d60, 0x122723ee,   // es.lt.un_440 en.ca.gd_432  cs.sk.ga_664 ca.gd.hu_422
  0x20190b08, 0x200c18ee, 0x1c642107, 0x27006b08,   // es.gl.sq_443 ga.sv.sq_422  jw.lg.id_432 ceb.gd.un_430
  // [a340]
  0x052307ad, 0x21161707, 0x12000b1a, 0x07001721,   // it.ca.fr_643 sr.hr.jw_432  es.hu.un_760 sr.bg.un_860
  0x200c1a08, 0x0e00121b, 0x25200b07, 0x64001a0e,   // tl.sv.sq_443 hu.is.un_770  es.sq.eu_432 tl.lg.un_550
  0x10030fa0, 0x13530b02, 0x0b006408, 0x2000130e,   // lv.nl.lt_322 es.ht.et_222  lg.es.un_430 et.sq.un_550
  0x201c1e0b, 0x230c0802, 0x20002821, 0x31291714,   // ms.id.sq_542 no.sv.ca_222  sw.sq.un_860 sr.sl.az_666
  // [a350]
  0x17092a04, 0x046413ad, 0x011c0cee, 0x290e04a0,   // mt.pl.sr_332 et.lg.fi_643  sv.id.en_422 fi.is.sl_322
  0x2a106b04, 0x160f17a0, 0x2d000605, 0x03000e08,   // ceb.lt.mt_332 sr.lv.hr_322  de.sk.un_330 is.nl.un_430
  0x190a11a0, 0x0f312504, 0x1b042a60, 0x05040707,   // ro.pt.gl_322 eu.az.lv_332  mt.fi.tr_664 it.fi.fr_432
  0x1a6b550c, 0x0b232509, 0x12081e07, 0x01031fec,   // rw.ceb.tl_543 eu.ca.es_444  ms.no.hu_432 cy.nl.en_644
  // [a360]
  0x25000b14, 0x0c1202a0, 0x5564250d, 0x1c1131a9,   // es.eu.un_660 da.hu.sv_322  eu.lg.rw_554 az.ro.id_544
  0x5500642b, 0x53640fa0, 0x190b0c05, 0x131c3f07,   // lg.rw.un_980 lv.lg.ht_322  sv.es.gl_333 af.id.et_432
  0x29000307, 0x09211007, 0x173f0855, 0x06001005,   // nl.sl.un_420 lt.jw.pl_432  no.af.sr_442 lt.de.un_330
  0x16002a08, 0x25550da9, 0x28006e0d, 0x53280aa4,   // mt.hr.un_430 cs.rw.eu_544  blu.sw.un_540 pt.sw.ht_433
  // [a370]
  0x2a556412, 0x0c64550d, 0x0b190a0d, 0x02090b07,   // lg.rw.mt_654 rw.lg.sv_554  pt.gl.es_554 es.pl.da_432
  0x0501130c, 0x0a180e0d, 0x1c0501ee, 0x0e000f11,   // et.en.fr_543 is.ga.pt_554  en.fr.id_422 lv.is.un_630
  0x250855ee, 0x550413a4, 0x19000e07, 0x08120ca9,   // rw.no.eu_422 et.fi.rw_433  is.gl.un_420 sv.hu.no_544
  0x1f000e07, 0x551b25a0, 0x171611ec, 0x0e2a29a7,   // is.cy.un_420 eu.tr.rw_322  ro.hr.sr_644 sl.mt.is_532
  // [a380]
  0x2a0712ec, 0x1b00280b, 0x0b001b04, 0x2500230e,   // hu.it.mt_644 sw.tr.un_520  tr.es.un_320 ca.eu.un_550
  0x03201204, 0x31001207, 0x180e0207, 0x070a10a0,   // hu.sq.nl_332 hu.az.un_420  da.is.ga_432 be.mk.bg_322
  0x6b551b08, 0x173f55ee, 0x130c25ec, 0x5517160d,   // tr.rw.ceb_443 rw.af.sr_422  eu.sv.et_644 hr.sr.rw_554
  0x100e07a0, 0x1a2b010c, 0x28290ba0, 0x0700170d,   // it.is.lt_322 en.vi.tl_543  es.sl.sw_322 sr.bg.un_540
  // [a390]
  0x160d2911, 0x0d001309, 0x0c081bad, 0x1e030ca0,   // sl.cs.hr_653 bh.ne.un_440  tr.no.sv_643 sv.nl.ms_322
  0x04100a5a, 0x101b20ec, 0x08022da0, 0x05132a0c,   // mk.be.ru_553 sq.tr.lt_644  sk.da.no_322 mt.et.fr_543
  0x2a183104, 0x0c005308, 0x2a002d08, 0x55052311,   // az.ga.mt_332 ht.sv.un_430  sk.mt.un_430 ca.fr.rw_653
  0x1b0c02a0, 0x090e10a7, 0x08120ead, 0x12080408,   // da.sv.tr_322 lt.is.pl_532  is.hu.no_643 fi.no.hu_443
  // [a3a0]
  0x11281360, 0x080e0c04, 0x0f2d0d18, 0x20251a07,   // et.sw.ro_664 sv.is.no_332  cs.sk.lv_764 tl.eu.sq_432
  0x061b2a0c, 0x040e08a0, 0x25232aaf, 0x18012aad,   // mt.tr.de_543 no.is.fi_322  mt.ca.eu_655 mt.en.ga_643
  0x041f0e60, 0x1f532808, 0x1f0f180c, 0x1c28210c,   // is.cy.fi_664 sw.ht.cy_443  ga.lv.cy_543 jw.sw.id_543
  0x07006b21, 0x040e010b, 0x111b310d, 0x1f00251a,   // ceb.it.un_860 en.is.fi_542  az.tr.ro_554 eu.cy.un_760
  // [a3b0]
  0x18190a0d, 0x13200ea7, 0x2018060c, 0x17161011,   // pt.gl.ga_554 is.sq.et_532  de.ga.sq_543 lt.hr.sr_653
  0x03211fa6, 0x0b001304, 0x2a002021, 0x01271904,   // cy.jw.nl_521 et.es.un_320  sq.mt.un_860 gl.gd.en_332
  0x132501a0, 0x201b3107, 0x551e2804, 0x1a6b1b5a,   // en.eu.et_322 az.tr.sq_432  sw.ms.rw_332 tr.ceb.tl_553
  0x041306ad, 0x131a2007, 0x1e3164a0, 0x11001309,   // de.et.fi_643 sq.tl.et_432  lg.az.ms_322 et.ro.un_440
  // [a3c0]
  0x0b00010d, 0x1f00062b, 0x6b006408, 0x12001708,   // en.es.un_540 de.cy.un_980  lg.ceb.un_430 sr.hu.un_430
  0x1225270d, 0x2a000805, 0x04000d13, 0x2d1f3fad,   // gd.eu.hu_554 no.mt.un_330  cs.fi.un_650 af.cy.sk_643
  0x291617a9, 0x163f02ec, 0x2a000a08, 0x231e11ad,   // sr.hr.sl_544 da.af.hr_644  pt.mt.un_430 ro.ms.ca_643
  0x0e211102, 0x0b050605, 0x25002712, 0x0d1029a4,   // ro.jw.is_222 de.fr.es_333  gd.eu.un_640 sl.lt.cs_433
  // [a3d0]
  0x07200ba4, 0x09181fa0, 0x3f100302, 0x04081760,   // es.sq.it_433 cy.ga.pl_322  nl.lt.af_222 sr.uk.ru_664
  0x6b001f13, 0x10170d07, 0x16001005, 0x64081f0c,   // cy.ceb.un_650 cs.sr.lt_432  lt.hr.un_330 cy.no.lg_543
  0x17161014, 0x08001f02, 0x3100120d, 0x2b001f08,   // lt.hr.sr_666 cy.no.un_220  hu.az.un_540 cy.vi.un_430
  0x033f12ee, 0x09162955, 0x55000805, 0x04136412,   // hu.af.nl_422 sl.hr.pl_442  no.rw.un_330 lg.et.fi_654
  // [a3e0]
  0x6b0f03a9, 0x552864a0, 0x072a0c07, 0x080e1308,   // nl.lv.ceb_544 lg.sw.rw_322  sv.mt.it_432 et.is.no_443
  0x01180304, 0x0e000c11, 0x05110308, 0x2305530c,   // nl.ga.en_332 sv.is.un_630  nl.ro.fr_443 ht.fr.ca_543
  0x28072a08, 0x07042804, 0x280725a0, 0x0e080107,   // mt.it.sw_443 sw.fi.it_332  eu.it.sw_322 en.no.is_432
  0x11312807, 0x310611a4, 0x0e6455ec, 0x31002105,   // sw.az.ro_432 ro.de.az_433  rw.lg.is_644 jw.az.un_330
  // [a3f0]
  0x1e1c20af, 0x08020cac, 0x06012007, 0x20162a07,   // sq.id.ms_655 sv.da.no_632  sq.en.de_432 mt.hr.sq_432
  0x6b0105a4, 0x2a0728ad, 0x1f00280d, 0x2a131aa4,   // fr.en.ceb_433 sw.it.mt_643  sw.cy.un_540 tl.et.mt_433
  0x3f000913, 0x23050b07, 0x645328ec, 0x2a1301a4,   // pl.af.un_650 es.fr.ca_432  sw.ht.lg_644 en.et.mt_433
  0x0c0812a4, 0x530428a7, 0x20121304, 0x211c6405,   // hu.no.sv_433 sw.fi.ht_532  et.hu.sq_332 lg.id.jw_333

  // [a400]
  0x201364a0, 0x0700641a, 0x2a001e07, 0x6b3f28ad,   // lg.et.sq_322 lg.it.un_760  ms.mt.un_420 sw.af.ceb_643
  0x3f6b5507, 0x07006411, 0x0400090d, 0x20295504,   // rw.ceb.af_432 lg.it.un_630  pl.fi.un_540 rw.sl.sq_332
  0x1b2a07a4, 0x273f0107, 0x29041211, 0x2a000907,   // it.mt.tr_433 en.af.gd_432  hu.fi.sl_653 pl.mt.un_420
  0x0a0718a7, 0x271301ee, 0x1827130c, 0x1b3103a0,   // ga.it.pt_532 en.et.gd_422  et.gd.ga_543 nl.az.tr_322
  // [a410]
  0x2d0c3fee, 0x29002d21, 0x132012ad, 0x1a2701a6,   // af.sv.sk_422 sk.sl.un_860  hu.sq.et_643 en.gd.tl_521
  0x3123130c, 0x10052855, 0x21536b04, 0x3f105312,   // et.ca.az_543 sw.fr.lt_442  ceb.ht.jw_332 ht.lt.af_654
  0x271a6ba4, 0x08031b02, 0x250b100c, 0x03073faf,   // ceb.tl.gd_433 tr.nl.no_222  lt.es.eu_543 af.it.nl_655
  0x13000c18, 0x042d08a0, 0x211606a7, 0x092d0d0e,   // sv.et.un_740 no.sk.fi_322  de.hr.jw_532 cs.sk.pl_555
  // [a420]
  0x0b0a05ee, 0x08532508, 0x2a0825ad, 0x0e001f22,   // fr.pt.es_422 eu.ht.no_443  eu.no.mt_643 cy.is.un_870
  0x18080202, 0x0c001214, 0x3f27100c, 0x11000619,   // da.no.ga_222 hu.sv.un_660  lt.gd.af_543 de.ro.un_750
  0x532829a4, 0x28006423, 0x122118a0, 0x642a10af,   // sl.sw.ht_433 lg.sw.un_880  ar.fa.ur_322 lt.mt.lg_655
  0x1300060e, 0x10642813, 0x171b3108, 0x06041002,   // de.et.un_550 sw.lg.lt_665  az.tr.sr_443 lt.fi.de_222
  // [a430]
  0x216410ee, 0x642110a9, 0x1c002502, 0x1f5306a4,   // lt.lg.jw_422 lt.jw.lg_544  eu.id.un_220 de.ht.cy_433
  0x64001009, 0x09002d1b, 0x2a1f05ec, 0x5311130c,   // lt.lg.un_440 sk.pl.un_770  fr.cy.mt_644 et.ro.ht_543
  0x071311a9, 0x55286414, 0x132153af, 0x11206402,   // ro.et.it_544 lg.sw.rw_666  ht.jw.et_655 lg.sq.ro_222
  0x2818010c, 0x133f6413, 0x11251308, 0x281364a6,   // en.ga.sw_543 lg.af.et_665  et.eu.ro_443 lg.et.sw_521
  // [a440]
  0x5528640b, 0x1a006421, 0x2b07010c, 0x11070513,   // lg.sw.rw_542 lg.tl.un_860  en.it.vi_543 fr.it.ro_665
  0x1f010611, 0x2b001312, 0x1e0413a0, 0x282a09a7,   // de.en.cy_653 et.vi.un_640  et.fi.ms_322 pl.mt.sw_532
  0x130711a4, 0x130711ec, 0x11080708, 0x53551c0c,   // ro.it.et_433 ro.it.et_644  bg.uk.ro_443 id.rw.ht_543
  0x64033f11, 0x131a0313, 0x3f1a13ec, 0x646b13a4,   // af.nl.lg_653 nl.tl.et_665  et.tl.af_644 et.ceb.lg_433
  // [a450]
  0x530428ac, 0x181c21a0, 0x17000714, 0x19206408,   // sw.fi.ht_632 jw.id.ga_322  bg.sr.un_660 lg.sq.gl_443
  0x0f0610ee, 0x20001b07, 0x0b2d2505, 0x03201ca0,   // lt.de.lv_422 tr.sq.un_420  eu.sk.es_333 id.sq.nl_322
  0x13090f07, 0x0400550c, 0x09082a04, 0x092a07af,   // lv.pl.et_432 rw.fi.un_530  mt.no.pl_332 it.mt.pl_655
  0x641355ec, 0x0a11100d, 0x0b002b07, 0x27002b23,   // rw.et.lg_644 lt.ro.pt_554  vi.es.un_420 vi.gd.un_880
  // [a460]
  0x2700201a, 0x2a111b13, 0x0f031702, 0x1a310e11,   // sq.gd.un_760 tr.ro.mt_665  sr.nl.lv_222 is.az.tl_653
  0x31000e12, 0x13086eec, 0x03290907, 0x211705a0,   // is.az.un_640 blu.no.et_644  pl.sl.nl_432 fr.sr.jw_322
  0x17201ca0, 0x27182ba9, 0x0d1c16a0, 0x2518010b,   // id.sq.sr_322 vi.ga.gd_544  hr.id.cs_322 en.ga.eu_542
  0x085502af, 0x04311b0c, 0x1f00182c, 0x19250b08,   // da.rw.no_655 tr.az.fi_543  ga.cy.un_990 es.eu.gl_443
  // [a470]
  0x642513a7, 0x0e1721a4, 0x270d18ec, 0x19311b60,   // et.eu.lg_532 jw.sr.is_433  ga.cs.gd_644 tr.az.gl_664
  0x0c1202a7, 0x0a073105, 0x0f120eee, 0x161f0c08,   // da.hu.sv_532 az.it.pt_333  is.hu.lv_422 sv.cy.hr_443
  0x12251fa4, 0x10251b07, 0x180b0107, 0x231f08ec,   // cy.eu.hu_433 tr.eu.lt_432  en.es.ga_432 no.cy.ca_644
  0x27281fee, 0x0e0501af, 0x11051307, 0x0713045a,   // cy.sw.gd_422 en.fr.is_655  et.fr.ro_432 fi.et.it_553
  // [a480]
  0x04130d0c, 0x64285511, 0x13252aa4, 0x251b130c,   // cs.et.fi_543 rw.sw.lg_653  mt.eu.et_433 et.tr.eu_543
  0x27060104, 0x08170ca9, 0x1c1b11ee, 0x130d1cad,   // en.de.gd_332 sv.sr.no_544  ro.tr.id_422 mr.ne.bh_643
  0x1b25130b, 0x210413a4, 0x011b1307, 0x0f040a0c,   // et.eu.tr_542 et.fi.jw_433  et.tr.en_432 pt.fi.lv_543
  0x01311b07, 0x11001302, 0x55641013, 0x080513a0,   // tr.az.en_432 et.ro.un_220  lt.lg.rw_665 et.fr.no_322
  // [a490]
  0x31131008, 0x18310813, 0x2b030508, 0x0b1b3104,   // lt.et.az_443 no.az.ga_665  fr.nl.vi_443 az.tr.es_332
  0x31200f07, 0x2a00551a, 0x53052b04, 0x06531b07,   // lv.sq.az_432 rw.mt.un_760  vi.fr.ht_332 tr.ht.de_432
  0x036b01ee, 0x080201a6, 0x2a005509, 0x12130411,   // en.ceb.nl_422 en.da.no_521  rw.mt.un_440 fi.et.hu_653
  0x53001318, 0x2d131ba4, 0x025501a4, 0x042505a4,   // et.ht.un_740 tr.et.sk_433  en.rw.da_433 fr.eu.fi_433
  // [a4a0]
  0x640f5512, 0x04210107, 0x046b0cee, 0x08171660,   // rw.lv.lg_654 en.jw.fi_432  sv.ceb.fi_422 hr.sr.no_664
  0x29050707, 0x642a5512, 0x0f2d2902, 0x21252008,   // it.fr.sl_432 rw.mt.lg_654  sl.sk.lv_222 sq.eu.jw_443
  0x09002112, 0x231121a0, 0x29001a20, 0x081c28a4,   // jw.pl.un_640 jw.ro.ca_322  tl.sl.un_850 sw.id.no_433
  0x1a080209, 0x642501a0, 0x64040855, 0x2a002b07,   // da.no.tl_444 en.eu.lg_322  no.fi.lg_442 vi.mt.un_420
  // [a4b0]
  0x64182704, 0x20531808, 0x641a0b0c, 0x12251ba0,   // gd.ga.lg_332 ga.ht.sq_443  es.tl.lg_543 tr.eu.hu_322
  0x17000108, 0x162017a4, 0x5531280c, 0x126b1a12,   // en.sr.un_430 sr.sq.hr_433  sw.az.rw_543 tl.ceb.hu_654
  0x0e0306a9, 0x21202911, 0x251b03ee, 0x02120c04,   // de.nl.is_544 sl.sq.jw_653  nl.tr.eu_422 sv.hu.da_332
  0x64002302, 0x13110707, 0x21111ba9, 0x101a6b0d,   // ca.lg.un_220 it.ro.et_432  tr.ro.jw_544 ceb.tl.lt_554
  // [a4c0]
  0x0c0408ad, 0x0800042a, 0x0255645a, 0x040608a4,   // no.fi.sv_643 ru.uk.un_970  lg.rw.da_553 no.de.fi_433
  0x1c6b1e0c, 0x0b0a64a0, 0x132555a4, 0x062b08a4,   // ms.ceb.id_543 lg.pt.es_322  rw.eu.et_433 no.vi.de_433
  0x042a1308, 0x55216402, 0x08071009, 0x06072507,   // et.mt.fi_443 lg.jw.rw_222  be.bg.uk_444 eu.it.de_432
  0x1b000902, 0x10020f14, 0x2d005304, 0x6455215a,   // pl.tr.un_220 lv.da.lt_666  ht.sk.un_320 jw.rw.lg_553
  // [a4d0]
  0x030c1f04, 0x02060307, 0x0e290f0c, 0x29001e21,   // cy.sv.nl_332 nl.de.da_432  lv.sl.is_543 ms.sl.un_860
  0x0c2908a4, 0x09281304, 0x182027ad, 0x2d13290c,   // no.sl.sv_433 et.sw.pl_332  gd.sq.ga_643 sl.et.sk_543
  0x290208ee, 0x1b0f1aa0, 0x071017a4, 0x12026407,   // no.da.sl_422 tl.lv.tr_322  sr.be.bg_433 lg.da.hu_432
  0x170f2909, 0x03311b02, 0x0e0c1f12, 0x0a00640c,   // sl.lv.sr_444 tr.az.nl_222  cy.sv.is_654 lg.pt.un_530
  // [a4e0]
  0x0c000209, 0x28041312, 0x161b0202, 0x2a091807,   // da.sv.un_440 et.fi.sw_654  da.tr.hr_222 ga.pl.mt_432
  0x31002808, 0x271811a9, 0x21312d02, 0x07000b0c,   // sw.az.un_430 ro.ga.gd_544  sk.az.jw_222 es.it.un_530
  0x3f0c1205, 0x02082107, 0x060210a4, 0x090208ad,   // hu.sv.af_333 jw.no.da_432  lt.da.de_433 no.da.pl_643
  0x02043f07, 0x02061ba0, 0x1a1227ee, 0x12000309,   // af.fi.da_432 tr.de.da_322  gd.hu.tl_422 nl.hu.un_440
  // [a4f0]
  0x2b00180c, 0x172901a4, 0x07000114, 0x1227180c,   // ga.vi.un_530 en.sl.sr_433  en.it.un_660 ga.gd.hu_543
  0x07211c0c, 0x28251ea9, 0x190218a6, 0x18112713,   // id.jw.it_543 ms.eu.sw_544  ga.da.gl_521 gd.ro.ga_665
  0x20005514, 0x0d131c12, 0x28291202, 0x550b1f07,   // rw.sq.un_660 mr.bh.ne_654  hu.sl.sw_222 cy.es.rw_432
  0x2d0955ee, 0x101b0612, 0x316420a4, 0x090b0a05,   // rw.pl.sk_422 de.tr.lt_654  sq.lg.az_433 pt.es.pl_333
  // [a500]
  0x1c135511, 0x07190107, 0x53001f0e, 0x11001807,   // rw.et.id_653 en.gl.it_432  cy.ht.un_550 ga.ro.un_420
  0x551c280c, 0x231f28a7, 0x25000407, 0x08290208,   // sw.id.rw_543 sw.cy.ca_532  fi.eu.un_420 da.sl.no_443
  0x08640107, 0x062916a4, 0x273f02ad, 0x08025507,   // en.lg.no_432 hr.sl.de_433  da.af.gd_643 rw.da.no_432
  0x281a1307, 0x17080c0c, 0x16005302, 0x53070507,   // et.tl.sw_432 sv.no.sr_543  ht.hr.un_220 fr.it.ht_432
  // [a510]
  0x0855280c, 0x55000b07, 0x0f0828a0, 0x023f05a4,   // sw.rw.no_543 es.rw.un_420  sw.no.lv_322 fr.af.da_433
  0x0c3f1304, 0x0723010c, 0x215564a7, 0x130c21a4,   // et.af.sv_332 en.ca.it_543  lg.rw.jw_532 jw.sv.et_433
  0x100c08ec, 0x11001314, 0x10040712, 0x190b1aa4,   // no.sv.lt_644 et.ro.un_660  bg.ru.be_654 tl.es.gl_433
  0x211c1eee, 0x196b64ad, 0x06091fa7, 0x09081aee,   // ms.id.jw_422 lg.ceb.gl_643  cy.pl.de_532 tl.no.pl_422
  // [a520]
  0x1c042812, 0x190b6405, 0x0c08290c, 0x64001907,   // sw.fi.id_654 lg.es.gl_333  sl.no.sv_543 gl.lg.un_420
  0x28110404, 0x280164a4, 0x0b002119, 0x64190b55,   // fi.ro.sw_332 lg.en.sw_433  jw.es.un_750 es.gl.lg_442
  0x013f0b04, 0x0c120804, 0x1a1617ee, 0x10041a09,   // es.af.en_332 no.hu.sv_332  sr.hr.tl_422 tl.fi.lt_444
  0x551328ac, 0x55196409, 0x11010b07, 0x0b0a1a0c,   // sw.et.rw_632 lg.gl.rw_444  es.en.ro_432 tl.pt.es_543
  // [a530]
  0x2d0d0bee, 0x3f08210c, 0x0e08040b, 0x0900250c,   // es.cs.sk_422 jw.no.af_543  fi.no.is_542 eu.pl.un_530
  0x190b55ec, 0x6e000505, 0x55002a20, 0x0e1f0c0d,   // rw.es.gl_644 fr.blu.un_330  mt.rw.un_850 sv.cy.is_554
  0x2a00070c, 0x6e3f02a4, 0x190b13af, 0x531e1c08,   // it.mt.un_530 da.af.blu_433  et.es.gl_655 id.ms.ht_443
  0x53002009, 0x08216e0c, 0x2800160e, 0x251101a0,   // sq.ht.un_440 blu.jw.no_543  hr.sw.un_550 en.ro.eu_322
  // [a540]
  0x552964a4, 0x1b006423, 0x23310aad, 0x120b3fa0,   // lg.sl.rw_433 lg.tr.un_880  pt.az.ca_643 af.es.hu_322
  0x28532105, 0x1c645505, 0x64211a07, 0x015328ee,   // jw.ht.sw_333 rw.lg.id_333  tl.jw.lg_432 sw.ht.en_422
  0x0400102b, 0x53003f0d, 0x081716a7, 0x086b1fa0,   // be.ru.un_980 af.ht.un_540  hr.sr.no_532 cy.ceb.no_322
  0x2a201612, 0x1a001f08, 0x25280bee, 0x25002a0d,   // hr.sq.mt_654 cy.tl.un_430  es.sw.eu_422 mt.eu.un_540
  // [a550]
  0x05533f09, 0x01000912, 0x130c010b, 0x311301a0,   // af.ht.fr_444 pl.en.un_640  en.sv.et_542 en.et.az_322
  0x130c02a9, 0x21030907, 0x180b19ee, 0x0500271b,   // da.sv.et_544 pl.nl.jw_432  gl.es.ga_422 gd.fr.un_770
  0x2a02010c, 0x3f182712, 0x1f312308, 0x252a010b,   // en.da.mt_543 gd.ga.af_654  ca.az.cy_443 en.mt.eu_542
  0x19200107, 0x05270c0c, 0x161053a9, 0x29160107,   // en.sq.gl_432 sv.gd.fr_543  ht.lt.hr_544 en.hr.sl_432
  // [a560]
  0x135310ac, 0x2900161a, 0x0c1a6ba4, 0x13250aad,   // lt.ht.et_632 hr.sl.un_760  ceb.tl.sv_433 pt.eu.et_643
  0x6b1827ad, 0x0d0a0ea9, 0x0d1716ee, 0x111729a4,   // gd.ga.ceb_643 is.pt.cs_544  hr.sr.cs_422 sl.sr.ro_433
  0x2d05160c, 0x0c0620ee, 0x531116a9, 0x080717a7,   // hr.fr.sk_543 sq.de.sv_422  hr.ro.ht_544 sr.bg.uk_532
  0x55645307, 0x165301a0, 0x0955210e, 0x11051609,   // ht.lg.rw_432 en.ht.hr_322  jw.rw.pl_555 hr.fr.ro_444
  // [a570]
  0x1104070e, 0x0b0a1209, 0x555316a9, 0x17211c0b,   // bg.ru.ro_555 hu.pt.es_444  hr.ht.rw_544 id.jw.sr_542
  0x160b1fa7, 0x2b000d07, 0x132a2007, 0x2a211cee,   // cy.es.hr_532 cs.vi.un_420  sq.mt.et_432 id.jw.mt_422
  0x53640bee, 0x180164a0, 0x08531008, 0x1b1255ee,   // es.lg.ht_422 lg.en.ga_322  lt.ht.no_443 rw.hu.tr_422
  0x1a1e1cec, 0x6b535505, 0x061c1305, 0x190b11ee,   // id.ms.tl_644 rw.ht.ceb_333  et.id.de_333 ro.es.gl_422
  // [a580]
  0x0900640c, 0x6b281804, 0x275328a7, 0x0b292d12,   // lg.pl.un_530 ga.sw.ceb_332  sw.ht.gd_532 sk.sl.es_654
  0x100a07ee, 0x1f1c210d, 0x290c0855, 0x050d0a02,   // bg.mk.be_422 jw.id.cy_554  no.sv.sl_442 pt.cs.fr_222
  0x10280da4, 0x0b0907a9, 0x28011a04, 0x18072712,   // cs.sw.lt_433 it.pl.es_544  tl.en.sw_332 gd.it.ga_654
  0x2500280c, 0x04282560, 0x28555312, 0x032819a9,   // sw.eu.un_530 eu.sw.fi_664  ht.rw.sw_654 gl.sw.nl_544
  // [a590]
  0x0c100fa4, 0x200b23ee, 0x25640c55, 0x251c2104,   // lv.lt.sv_433 ca.es.sq_422  sv.lg.eu_442 jw.id.eu_332
  0x0a641a14, 0x00000737, 0x0c0402a9, 0x251f18a4,   // tl.lg.pt_666 it.un.un_B00  da.fi.sv_544 ga.cy.eu_433
  0x07201ca9, 0x2b00181b, 0x190509ee, 0x1200040e,   // id.sq.it_544 ga.vi.un_770  pl.fr.gl_422 fi.hu.un_550
  0x3f0329ee, 0x1f02080b, 0x31041ba9, 0x6b171605,   // sl.nl.af_422 no.da.cy_542  tr.fi.az_544 hr.sr.ceb_333
  // [a5a0]
  0x201b13a4, 0x0c061205, 0x0713530c, 0x0b1a29a0,   // et.tr.sq_433 hu.de.sv_333  ht.et.it_543 sl.tl.es_322
  0x2064210c, 0x1f000202, 0x17645507, 0x0a07310c,   // jw.lg.sq_543 da.cy.un_220  rw.lg.sr_432 az.it.pt_543
  0x1b23310c, 0x0d0f17ee, 0x192128a0, 0x6b112004,   // az.ca.tr_543 sr.lv.cs_422  sw.jw.gl_322 sq.ro.ceb_332
  0x64102805, 0x1200290d, 0x1a6b6407, 0x0a001e02,   // sw.lt.lg_333 sl.hu.un_540  lg.ceb.tl_432 ms.pt.un_220
  // [a5b0]
  0x2d0c6bac, 0x1b2a3112, 0x20042804, 0x060701ee,   // ceb.sv.sk_632 az.mt.tr_654  sw.fi.sq_332 en.it.de_422
  0x0f201013, 0x64000a07, 0x031125a6, 0x1204130d,   // lt.sq.lv_665 pt.lg.un_420  eu.ro.nl_521 et.fi.hu_554
  0x16006b08, 0x230b190b, 0x1a12550c, 0x3f00230c,   // ceb.hr.un_430 gl.es.ca_542  rw.hu.tl_543 ca.af.un_530
  0x0e1208ee, 0x030c3f02, 0x190b2ba6, 0x20001c07,   // no.hu.is_422 af.sv.nl_222  vi.es.gl_521 id.sq.un_420
  // [a5c0]
  0x136b2a08, 0x06002d07, 0x08060cec, 0x170c08ee,   // mt.ceb.et_443 sk.de.un_420  sv.de.no_644 no.sv.sr_422
  0x250353ad, 0x55211b08, 0x1f050ca0, 0x64001b07,   // ht.nl.eu_643 tr.jw.rw_443  sv.fr.cy_322 tr.lg.un_420
  0x0600640c, 0x110e2807, 0x551c1eec, 0x0c552808,   // lg.de.un_530 sw.is.ro_432  ms.id.rw_644 sw.rw.sv_443
  0x1e041aa0, 0x0c081fa7, 0x03081209, 0x0a1b5507,   // tl.fi.ms_322 cy.no.sv_532  hu.no.nl_444 rw.tr.pt_432
  // [a5d0]
  0x25020707, 0x1b312012, 0x02061fa0, 0x04311a02,   // it.da.eu_432 sq.az.tr_654  cy.de.da_322 tl.az.fi_222
  0x072d2904, 0x2d1218af, 0x231e2105, 0x202804a4,   // sl.sk.it_332 ga.hu.sk_655  jw.ms.ca_333 fi.sw.sq_433
  0x29002d20, 0x0e080402, 0x281b0412, 0x12001909,   // sk.sl.un_850 fi.no.is_222  fi.tr.sw_654 gl.hu.un_440
  0x0c023fa0, 0x0d001909, 0x2d002b04, 0x120c1308,   // af.da.sv_322 gl.cs.un_440  vi.sk.un_320 et.sv.hu_443
  // [a5e0]
  0x190d0b04, 0x082904a0, 0x640b04a4, 0x55001b08,   // es.cs.gl_332 fi.sl.no_322  fi.es.lg_433 tr.rw.un_430
  0x250413af, 0x160417a0, 0x16170407, 0x25551204,   // et.fi.eu_655 sr.fi.hr_322  fi.sr.hr_432 hu.rw.eu_332
  0x21312aee, 0x29040d08, 0x17161305, 0x130428ad,   // mt.az.jw_422 cs.fi.sl_443  et.hr.sr_333 sw.fi.et_643
  0x0f171605, 0x10000d05, 0x12005505, 0x0a070812,   // hr.sr.lv_333 cs.lt.un_330  rw.hu.un_330 uk.bg.mk_654
  // [a5f0]
  0x31005507, 0x1327180b, 0x131716ad, 0x0f081304,   // rw.az.un_420 ga.gd.et_542  hr.sr.et_643 et.no.lv_332
  0x5513255a, 0x0600050c, 0x250c13a4, 0x05002714,   // eu.et.rw_553 fr.de.un_530  et.sv.eu_433 gd.fr.un_660
  0x171604a6, 0x1716130e, 0x070804a7, 0x1a000205,   // fi.hr.sr_521 et.hr.sr_555  ru.uk.bg_532 da.tl.un_330
  0x033f0802, 0x0e070504, 0x10052107, 0x6b000907,   // no.af.nl_222 fr.it.is_332  jw.fr.lt_432 pl.ceb.un_420
  // [a600]
  0x0f00061a, 0x11000819, 0x292705ad, 0x29160507,   // de.lv.un_760 uk.ro.un_750  fr.gd.sl_643 fr.hr.sl_432
  0x531f0fee, 0x2a2864ad, 0x0f53200c, 0x0d001c2b,   // lv.cy.ht_422 lg.sw.mt_643  sq.ht.lv_543 mr.ne.un_980
  0x042529a4, 0x0c001e05, 0x64212907, 0x11002323,   // sl.eu.fi_433 ms.sv.un_330  sl.jw.lg_432 ca.ro.un_880
  0x12110107, 0x100825a0, 0x250a2a07, 0x131729ad,   // en.ro.hu_432 eu.no.lt_322  mt.pt.eu_432 sl.sr.et_643
  // [a610]
  0x0f0e10a7, 0x13000622, 0x182d0b08, 0x032a2013,   // lt.is.lv_532 de.et.un_870  es.sk.ga_443 sq.mt.nl_665
  0x53001e08, 0x06030209, 0x170408ec, 0x1f071707,   // ms.ht.un_430 da.nl.de_444  uk.ru.sr_644 sr.it.cy_432
  0x13201fa0, 0x3f0301a9, 0x1103010d, 0x28552dad,   // cy.sq.et_322 en.nl.af_544  en.nl.ro_554 sk.rw.sw_643
  0x010a2107, 0x27181fad, 0x531f0b05, 0x0f0612a9,   // jw.pt.en_432 cy.ga.gd_643  es.cy.ht_333 hu.de.lv_544
  // [a620]
  0x2813040e, 0x31210107, 0x2d020407, 0x2a08120e,   // fi.et.sw_555 en.jw.az_432  fi.da.sk_432 hu.no.mt_555
  0x042520ee, 0x3f010308, 0x050d01ec, 0x3f0302a4,   // sq.eu.fi_422 nl.en.af_443  en.cs.fr_644 da.nl.af_433
  0x08110309, 0x53000119, 0x102b0a07, 0x3f000119,   // nl.ro.no_444 en.ht.un_750  pt.vi.lt_432 en.af.un_750
  0x6b1a1207, 0x081f01ad, 0x07010514, 0x6b211a07,   // hu.tl.ceb_432 en.cy.no_643  fr.en.it_666 tl.jw.ceb_432
  // [a630]
  0x050806a0, 0x041364a4, 0x120d2dec, 0x27201f0c,   // de.no.fr_322 lg.et.fi_433  sk.cs.hu_644 cy.sq.gd_543
  0x0e2a0407, 0x0e0c040c, 0x6e0621a7, 0x0d2d1260,   // fi.mt.is_432 fi.sv.is_543  jw.de.blu_532 hu.sk.cs_664
  0x310453ec, 0x0e000d0e, 0x182720ad, 0x272a04a0,   // ht.fi.az_644 cs.is.un_550  sq.gd.ga_643 fi.mt.gd_322
  0x1a00532a, 0x0e000a19, 0x210b11a0, 0x53001c08,   // ht.tl.un_970 pt.is.un_750  ro.es.jw_322 id.ht.un_430
  // [a640]
  0x0305010b, 0x01536ba7, 0x03270613, 0x06233fad,   // en.fr.nl_542 ceb.ht.en_532  de.gd.nl_665 af.ca.de_643
  0x162917a7, 0x0f013fa4, 0x531b6b05, 0x2504270c,   // sr.sl.hr_532 af.en.lv_433  ceb.tr.ht_333 gd.fi.eu_543
  0x0d2d6407, 0x12000812, 0x1a060ca0, 0x252d0908,   // lg.sk.cs_432 no.hu.un_640  sv.de.tl_322 pl.sk.eu_443
  0x0e181911, 0x125506ad, 0x211b02a4, 0x2000270e,   // gl.ga.is_653 de.rw.hu_643  da.tr.jw_433 gd.sq.un_550
  // [a650]
  0x3f1b53a4, 0x171613a9, 0x1e1c25ac, 0x3f17530c,   // ht.tr.af_433 et.hr.sr_544  eu.id.ms_632 ht.sr.af_543
  0x031b53a7, 0x20251312, 0x2a205305, 0x04251308,   // ht.tr.nl_532 et.eu.sq_654  ht.sq.mt_333 et.eu.fi_443
  0x2d53550e, 0x010b03a0, 0x252008a0, 0x21110107,   // rw.ht.sk_555 nl.es.en_322  no.sq.eu_322 en.ro.jw_432
  0x01032ba0, 0x3f00130c, 0x081253a0, 0x25080c09,   // vi.nl.en_322 et.af.un_530  ht.hu.no_322 sv.no.eu_444
  // [a660]
  0x03000714, 0x2d0f0d07, 0x111707af, 0x642d0dee,   // it.nl.un_660 cs.lv.sk_432  bg.sr.ro_655 cs.sk.lg_422
  0x0b111ba0, 0x211b020c, 0x09202513, 0x286420af,   // tr.ro.es_322 da.tr.jw_543  eu.sq.pl_665 sq.lg.sw_655
  0x2a642111, 0x13080ca4, 0x2920130c, 0x3f032bee,   // jw.lg.mt_653 sv.no.et_433  et.sq.sl_543 vi.nl.af_422
  0x202721a7, 0x0f080ca4, 0x06031109, 0x3f000f07,   // jw.gd.sq_532 sv.no.lv_433  ro.nl.de_444 lv.af.un_420
  // [a670]
  0x1c130da7, 0x0f1617a0, 0x21110807, 0x0e276b11,   // ne.bh.mr_532 sr.hr.lv_322  no.ro.jw_432 ceb.gd.is_653
  0x2112010c, 0x0c082705, 0x211f0407, 0x5528180c,   // en.hu.jw_543 gd.no.sv_333  fi.cy.jw_432 ga.sw.rw_543
  0x012b050c, 0x0f3f0c02, 0x210e1b0c, 0x531164ad,   // fr.vi.en_543 sv.af.lv_222  tr.is.jw_543 lg.ro.ht_643
  0x180d0aad, 0x072a12ec, 0x0c2a06a0, 0x17231b07,   // pt.cs.ga_643 hu.mt.it_644  de.mt.sv_322 tr.ca.sr_432
  // [a680]
  0x046b1a13, 0x290c53a0, 0x2d5528ee, 0x170c0eec,   // tl.ceb.fi_665 ht.sv.sl_322  sw.rw.sk_422 is.sv.sr_644
  0x230a0d04, 0x2a110109, 0x0e6418a0, 0x100a0805,   // cs.pt.ca_332 en.ro.mt_444  ga.lg.is_322 uk.mk.be_333
  0x182a2ba7, 0x0d642da0, 0x1200190d, 0x1e002504,   // vi.mt.ga_532 sk.lg.cs_322  gl.hu.un_540 eu.ms.un_320
  0x2d0d550c, 0x55641a14, 0x20006412, 0x0d092d0b,   // rw.cs.sk_543 tl.lg.rw_666  lg.sq.un_640 sk.pl.cs_542
  // [a690]
  0x090e0402, 0x0e04200c, 0x18000404, 0x041364af,   // fi.is.pl_222 sq.fi.is_543  fi.ga.un_320 lg.et.fi_655
  0x0d16290e, 0x0402080b, 0x0b000305, 0x02063fa0,   // sl.hr.cs_555 no.da.fi_542  nl.es.un_330 af.de.da_322
  0x03110208, 0x2d060dac, 0x64120204, 0x130c0608,   // da.ro.nl_443 cs.de.sk_632  da.hu.lg_332 de.sv.et_443
  0x2a1809a4, 0x0b013fee, 0x20126ba0, 0x641216a0,   // pl.ga.mt_433 af.en.es_422  ceb.hu.sq_322 hr.hu.lg_322
  // [a6a0]
  0x5300190d, 0x0f001605, 0x13640414, 0x6b531a55,   // gl.ht.un_540 hr.lv.un_330  fi.lg.et_666 tl.ht.ceb_442
  0x182127a7, 0x0f286412, 0x1f046413, 0x23131105,   // gd.jw.ga_532 lg.sw.lv_654  lg.fi.cy_665 ro.et.ca_333
  0x2d0d2009, 0x160f21a9, 0x052b2308, 0x5564280d,   // sq.cs.sk_444 jw.lv.hr_544  ca.vi.fr_443 sw.lg.rw_554
  0x11101fec, 0x1755160d, 0x04000f08, 0x041a2807,   // cy.lt.ro_644 hr.rw.sr_554  lv.fi.un_430 sw.tl.fi_432
  // [a6b0]
  0x09120305, 0x0b130411, 0x55250d07, 0x641b2160,   // nl.hu.pl_333 fi.et.es_653  cs.eu.rw_432 jw.tr.lg_664
  0x252a0da0, 0x13551a07, 0x130f11a0, 0x641f0914,   // cs.mt.eu_322 tl.rw.et_432  ro.lv.et_322 pl.cy.lg_666
  0x2a0e5502, 0x131621a0, 0x21551aec, 0x1a556ba0,   // rw.is.mt_222 jw.hr.et_322  tl.rw.jw_644 ceb.rw.tl_322
  0x2d0e18ad, 0x20312a04, 0x0c081307, 0x0e00530d,   // ga.is.sk_643 mt.az.sq_332  et.no.sv_432 ht.is.un_540
  // [a6c0]
  0x033f080b, 0x13042a0c, 0x201629a4, 0x28131a07,   // no.af.nl_542 mt.fi.et_543  sl.hr.sq_433 tl.et.sw_432
  0x25552805, 0x1a6b080b, 0x160421a0, 0x08111707,   // sw.rw.eu_333 no.ceb.tl_542  jw.fi.hr_322 sr.ro.uk_432
  0x2d0d21a4, 0x0b1f23af, 0x210208a0, 0x642123a4,   // jw.cs.sk_433 ca.cy.es_655  no.da.jw_322 ca.jw.lg_433
  0x201f0107, 0x250b01a0, 0x552d0314, 0x552112ad,   // en.cy.sq_432 en.es.eu_322  nl.sk.rw_666 hu.jw.rw_643
  // [a6d0]
  0x19532907, 0x1812050c, 0x11000208, 0x1e1c29a0,   // sl.ht.gl_432 fr.hu.ga_543  da.ro.un_430 sl.id.ms_322
  0x172d1655, 0x552d1b05, 0x21001105, 0x1f530107,   // hr.sk.sr_442 tr.sk.rw_333  ro.jw.un_330 en.ht.cy_432
  0x28211608, 0x20280404, 0x640b5560, 0x06040b05,   // hr.jw.sw_443 fi.sw.sq_332  rw.es.lg_664 es.fi.de_333
  0x201e1c0e, 0x202d0da0, 0x20001214, 0x53000f02,   // id.ms.sq_555 cs.sk.sq_322  hu.sq.un_660 lv.ht.un_220
  // [a6e0]
  0x080c09ec, 0x08291655, 0x55211ea0, 0x2d2b0d02,   // pl.sv.no_644 hr.sl.no_442  ms.jw.rw_322 cs.vi.sk_222
  0x072d2907, 0x12281ba7, 0x021b05ee, 0x07042007,   // sl.sk.it_432 tr.sw.hu_532  fr.tr.da_422 sq.fi.it_432
  0x08020da0, 0x07001320, 0x1716090d, 0x0f09290b,   // cs.da.no_322 et.it.un_850  pl.hr.sr_554 sl.pl.lv_542
  0x1b5321ee, 0x2a00020e, 0x1b0d0155, 0x07291f04,   // jw.ht.tr_422 da.mt.un_550  en.cs.tr_442 cy.sl.it_332
  // [a6f0]
  0x036e3f08, 0x050e1f07, 0x06003f0b, 0x0a056eee,   // af.blu.nl_443 cy.is.fr_432  af.de.un_520 blu.fr.pt_422
  0x6b291f07, 0x21531b09, 0x0c0e27ec, 0x131f3108,   // cy.sl.ceb_432 tr.ht.jw_444  gd.is.sv_644 az.cy.et_443
  0x2a6b1a04, 0x1a252104, 0x04002704, 0x25000408,   // tl.ceb.mt_332 jw.eu.tl_332  gd.fi.un_320 fi.eu.un_430
  0x1a1f6b09, 0x280e3f04, 0x31005321, 0x080f1012,   // ceb.cy.tl_444 af.is.sw_332  ht.az.un_860 lt.lv.no_654
  // [a700]
  0x3f010804, 0x2100531b, 0x1f6b0e0c, 0x0f2a130c,   // no.en.af_332 ht.jw.un_770  is.ceb.cy_543 et.mt.lv_543
  0x271e1c08, 0x31090d07, 0x31251bec, 0x531a0b07,   // id.ms.gd_443 cs.pl.az_432  tr.eu.az_644 es.tl.ht_432
  0x27180807, 0x12001e08, 0x27050411, 0x11132909,   // no.ga.gd_432 ms.hu.un_430  fi.fr.gd_653 sl.et.ro_444
  0x6b000607, 0x6b000412, 0x0c6406ee, 0x1b1e250b,   // de.ceb.un_420 fi.ceb.un_640  de.lg.sv_422 eu.ms.tr_542
  // [a710]
  0x1f1a1bee, 0x0c060ea9, 0x3f0104a0, 0x011606ee,   // tr.tl.cy_422 is.de.sv_544  fi.en.af_322 de.hr.en_422
  0x231b03ee, 0x09160c04, 0x311b0ea4, 0x16002a02,   // nl.tr.ca_422 sv.hr.pl_332  is.tr.az_433 mt.hr.un_220
  0x022b010c, 0x2d002b02, 0x272504ec, 0x120913a4,   // en.vi.da_543 vi.sk.un_220  fi.eu.gd_644 et.pl.hu_433
  0x12040bee, 0x07040aa7, 0x0f28130d, 0x1200130d,   // es.fi.hu_422 mk.ru.bg_532  et.sw.lv_554 et.hu.un_540
  // [a720]
  0x6b251304, 0x04286455, 0x080253ec, 0x20132508,   // et.eu.ceb_332 lg.sw.fi_442  ht.da.no_644 eu.et.sq_443
  0x1210200c, 0x5564120e, 0x136455af, 0x08130704,   // sq.lt.hu_543 hu.lg.rw_555  rw.lg.et_655 it.et.no_332
  0x201716af, 0x0c030204, 0x10181f07, 0x18000608,   // hr.sr.sq_655 da.nl.sv_332  cy.ga.lt_432 de.ga.un_430
  0x02292daf, 0x293f0308, 0x280e13ad, 0x20005507,   // sk.sl.da_655 nl.af.sl_443  et.is.sw_643 rw.sq.un_420
  // [a730]
  0x020c3fa4, 0x04311b07, 0x100413a4, 0x0c010ea6,   // af.sv.da_433 tr.az.fi_432  et.fi.lt_433 is.en.sv_521
  0x1a0c0855, 0x1b315504, 0x29090f55, 0x0c021fee,   // no.sv.tl_442 rw.az.tr_332  lv.pl.sl_442 cy.da.sv_422
  0x1f1a040c, 0x080603a4, 0x13121e04, 0x09170ea6,   // fi.tl.cy_543 nl.de.no_433  ms.hu.et_332 is.sr.pl_521
  0x272d0d04, 0x173f0fee, 0x2a002812, 0x1c531b07,   // cs.sk.gd_332 lv.af.sr_422  sw.mt.un_640 tr.ht.id_432
  // [a740]
  0x11000d0d, 0x0c1e6ba0, 0x311b1907, 0x286419a0,   // cs.ro.un_540 ceb.ms.sv_322  gl.tr.az_432 gl.lg.sw_322
  0x2a00121a, 0x07001e04, 0x0e0864a0, 0x212a0711,   // hu.mt.un_760 ms.it.un_320  lg.no.is_322 it.mt.jw_653
  0x1e286404, 0x6b1b1f04, 0x04001f1b, 0x110c23af,   // lg.sw.ms_332 cy.tr.ceb_332  cy.fi.un_770 ca.sv.ro_655
  0x09292da0, 0x0f000205, 0x13020f04, 0x3f130312,   // sk.sl.pl_322 da.lv.un_330  lv.da.et_332 nl.et.af_654
  // [a750]
  0x160f27a0, 0x13000a02, 0x115528a4, 0x1b311ead,   // gd.lv.hr_322 pt.et.un_220  sw.rw.ro_433 ms.az.tr_643
  0x011b05a0, 0x1b281308, 0x0c001908, 0x05312107,   // fr.tr.en_322 et.sw.tr_443  gl.sv.un_430 jw.az.fr_432
  0x19001811, 0x1900531a, 0x07092da0, 0x3f041f0d,   // ga.gl.un_630 ht.gl.un_760  sk.pl.it_322 cy.fi.af_554
  0x040710ee, 0x1f003f1a, 0x1e1c1105, 0x1e001f09,   // be.bg.ru_422 af.cy.un_760  ro.id.ms_333 cy.ms.un_440
  // [a760]
  0x1a2125ad, 0x25006b1a, 0x216b25ad, 0x211f3f04,   // eu.jw.tl_643 ceb.eu.un_760  eu.ceb.jw_643 af.cy.jw_332
  0x013f1f07, 0x1a6b2510, 0x23070805, 0x1f081a02,   // cy.af.en_432 eu.ceb.tl_642  no.it.ca_333 tl.no.cy_222
  0x040717ad, 0x08280711, 0x21006b20, 0x2b6b2512,   // sr.bg.ru_643 it.sw.no_653  ceb.jw.un_850 eu.ceb.vi_654
  0x120811a0, 0x0c106b0c, 0x19110ba7, 0x212b250c,   // ro.no.hu_322 ceb.lt.sv_543  es.ro.gl_532 eu.vi.jw_543
  // [a770]
  0x2d0d18ee, 0x0a001109, 0x0b110512, 0x03100f0c,   // ga.cs.sk_422 ro.mk.un_440  fr.ro.es_654 lv.lt.nl_543
  0x122555a0, 0x0c0603a9, 0x1b0953ad, 0x09005507,   // rw.eu.hu_322 nl.de.sv_544  ht.pl.tr_643 rw.pl.un_420
  0x18001319, 0x080201af, 0x0f100112, 0x031b06a6,   // et.ga.un_750 en.da.no_655  en.lt.lv_654 de.tr.nl_521
  0x311b1a09, 0x021006a6, 0x17130f02, 0x0f0c13af,   // tl.tr.az_444 de.lt.da_521  lv.et.sr_222 et.sv.lv_655
  // [a780]
  0x1b3120ee, 0x21052aa6, 0x0b231812, 0x0c0f3f07,   // sq.az.tr_422 mt.fr.jw_521  ga.ca.es_654 af.lv.sv_432
  0x100f1a07, 0x010f1312, 0x11000718, 0x0f000322,   // tl.lv.lt_432 et.lv.en_654  it.ro.un_740 nl.lv.un_870
  0x010a110c, 0x233f01a9, 0x2916250c, 0x063f01a4,   // ro.pt.en_543 en.af.ca_544  eu.hr.sl_543 en.af.de_433
  0x060f0107, 0x09213fad, 0x180123a9, 0x0a19230c,   // en.lv.de_432 af.jw.pl_643  ca.en.ga_544 ca.gl.pt_543
  // [a790]
  0x1a002512, 0x2d1353a0, 0x182b27af, 0x17003f07,   // eu.tl.un_640 ht.et.sk_322  gd.vi.ga_655 af.sr.un_420
  0x27001319, 0x1a311b04, 0x23001f21, 0x1a04010c,   // et.gd.un_750 tr.az.tl_332  cy.ca.un_860 en.fi.tl_543
  0x1b643111, 0x181027ec, 0x25100655, 0x10281aec,   // az.lg.tr_653 gd.lt.ga_644  de.lt.eu_442 tl.sw.lt_644
  0x020c0f55, 0x6e00012b, 0x12162007, 0x04110a0c,   // lv.sv.da_442 en.blu.un_980  sq.hr.hu_432 pt.ro.fi_543
  // [a7a0]
  0x046e100d, 0x0000252d, 0x271a1e0b, 0x6b193fa0,   // lt.blu.fi_554 eu.un.un_A00  ms.tl.gd_542 af.gl.ceb_322
  0x192a07af, 0x3f190a0b, 0x17162109, 0x131a1ca4,   // it.mt.gl_655 pt.gl.af_542  jw.hr.sr_444 id.tl.et_433
  0x12002707, 0x1b641f05, 0x03060fee, 0x1b6b64af,   // gd.hu.un_420 cy.lg.tr_333  lv.de.nl_422 lg.ceb.tr_655
  0x1f012007, 0x3f080911, 0x01190b55, 0x1b106b60,   // sq.en.cy_432 pl.no.af_653  es.gl.en_442 ceb.lt.tr_664
  // [a7b0]
  0x0f556408, 0x1c3f1304, 0x17081f14, 0x01001007,   // lg.rw.lv_443 et.af.id_332  cy.no.sr_666 lt.en.un_420
  0x1b253113, 0x280904a7, 0x206b01ad, 0x641b31ec,   // az.eu.tr_665 fi.pl.sw_532  en.ceb.sq_643 az.tr.lg_644
  0x292d1605, 0x1a001014, 0x192531ac, 0x311b530c,   // hr.sk.sl_333 lt.tl.un_660  az.eu.gl_632 ht.tr.az_543
  0x1c161eee, 0x28033f55, 0x1f23270c, 0x641a1e12,   // ms.hr.id_422 af.nl.sw_442  gd.ca.cy_543 ms.tl.lg_654
  // [a7c0]
  0x181223a9, 0x28002008, 0x0b001b07, 0x6b101a0c,   // ca.hu.ga_544 sq.sw.un_430  tr.es.un_420 tl.lt.ceb_543
  0x201e3107, 0x08071b05, 0x1b0c2004, 0x2120010b,   // az.ms.sq_432 tr.it.no_333  sq.sv.tr_332 en.sq.jw_542
  0x173110ad, 0x23005504, 0x211628ee, 0x01550707,   // lt.az.sr_643 rw.ca.un_320  sw.hr.jw_422 it.rw.en_432
  0x64551255, 0x182d12ad, 0x27290ba0, 0x200f170c,   // hu.rw.lg_442 hu.sk.ga_643  es.sl.gd_322 sr.lv.sq_543
  // [a7d0]
  0x183f2ba7, 0x11000f07, 0x0e190b13, 0x0a000e1a,   // vi.af.ga_532 lv.ro.un_420  es.gl.is_665 is.pt.un_760
  0x291101a4, 0x11290105, 0x17000f04, 0x02001305,   // en.ro.sl_433 en.sl.ro_333  lv.sr.un_320 et.da.un_330
  0x070d13af, 0x29012504, 0x20001b14, 0x12645507,   // et.cs.it_655 eu.en.sl_332  tr.sq.un_660 rw.lg.hu_432
  0x011b1104, 0x0e530412, 0x0e00040e, 0x1e016b08,   // ro.tr.en_332 fi.ht.is_654  fi.is.un_550 ceb.en.ms_443
  // [a7e0]
  0x64033f02, 0x1b0420a7, 0x2d0d2aec, 0x0900160d,   // af.nl.lg_222 sq.fi.tr_532  mt.cs.sk_644 hr.pl.un_540
  0x13080fad, 0x13042004, 0x1a00130e, 0x16000d07,   // lv.no.et_643 sq.fi.et_332  et.tl.un_550 cs.hr.un_420
  0x16011ea0, 0x17006e13, 0x1b0e20a0, 0x2a0b1f04,   // ms.en.hr_322 blu.sr.un_650  sq.is.tr_322 cy.es.mt_332
  0x1c040ea0, 0x20040eec, 0x16281307, 0x640827a0,   // is.fi.id_322 is.fi.sq_644  et.sw.hr_432 gd.no.lg_322
  // [a7f0]
  0x03013fa4, 0x10162905, 0x040208a4, 0x1b290f0c,   // af.en.nl_433 sl.hr.lt_333  no.da.fi_433 lv.sl.tr_543
  0x1f25290c, 0x1b1f0a04, 0x213f060c, 0x21001a0d,   // sl.eu.cy_543 pt.cy.tr_332  de.af.jw_543 tl.jw.un_540
  0x1b166ea0, 0x211625a0, 0x271e1c02, 0x0e021b07,   // blu.hr.tr_322 eu.hr.jw_322  id.ms.gd_222 tr.da.is_432
  0x1b006407, 0x08002a07, 0x033f29ee, 0x271e1c09,   // lg.tr.un_420 mt.no.un_420  sl.af.nl_422 id.ms.gd_444

  // [a800]
  0x6b001b0e, 0x120802a9, 0x29206e04, 0x0b0a28a0,   // tr.ceb.un_550 da.no.hu_544  blu.sq.sl_332 sw.pt.es_322
  0x1a0b0a08, 0x1e1c0ca9, 0x1a6b640c, 0x16230b02,   // pt.es.tl_443 sv.id.ms_544  lg.ceb.tl_543 es.ca.hr_222
  0x10170805, 0x1c212705, 0x040f1012, 0x110a175a,   // uk.sr.be_333 gd.jw.id_333  lt.lv.fi_654 sr.mk.ro_553
  0x6b003118, 0x31190a0d, 0x28211f04, 0x08020f0c,   // az.ceb.un_740 pt.gl.az_554  cy.jw.sw_332 lv.da.no_543
  // [a810]
  0x201028a4, 0x64001313, 0x011a23a4, 0x27001008,   // sw.lt.sq_433 et.lg.un_650  ca.tl.en_433 lt.gd.un_430
  0x6b000d08, 0x080664a0, 0x200802ad, 0x31531ba4,   // cs.ceb.un_430 lg.de.no_322  da.no.sq_643 tr.ht.az_433
  0x2520530c, 0x200b1102, 0x08003112, 0x6e2b01a7,   // ht.sq.eu_543 ro.es.sq_222  az.no.un_640 en.vi.blu_532
  0x0b0601ee, 0x170a0e04, 0x1311640c, 0x5500110b,   // en.de.es_422 is.pt.sr_332  lg.ro.et_543 ro.rw.un_520
  // [a820]
  0x135527ee, 0x25556413, 0x21281107, 0x110819ee,   // gd.rw.et_422 lg.rw.eu_665  ro.sw.jw_432 gl.no.ro_422
  0x296409ad, 0x25186405, 0x092921a4, 0x04110f04,   // pl.lg.sl_643 lg.ga.eu_333  jw.sl.pl_433 lv.ro.fi_332
  0x046b1313, 0x19001107, 0x2d296460, 0x09291608,   // et.ceb.fi_665 ro.gl.un_420  lg.sl.sk_664 hr.sl.pl_443
  0x092864a0, 0x251e1c02, 0x04642804, 0x016b180b,   // lg.sw.pl_322 id.ms.eu_222  sw.lg.fi_332 ga.ceb.en_542
  // [a830]
  0x132511a0, 0x5300270c, 0x0b0a2da0, 0x1f0d2d07,   // ro.eu.et_322 gd.ht.un_530  sk.pt.es_322 sk.cs.cy_432
  0x642916ee, 0x011f55a0, 0x162d090d, 0x11000f08,   // hr.sl.lg_422 rw.cy.en_322  pl.sk.hr_554 lv.ro.un_430
  0x6b1c1aec, 0x642511a4, 0x28001122, 0x53006b02,   // tl.id.ceb_644 ro.eu.lg_433  ro.sw.un_870 ceb.ht.un_220
  0x033f11a9, 0x3f03130c, 0x1100161b, 0x29020caf,   // ro.af.nl_544 et.nl.af_543  hr.ro.un_770 sv.da.sl_655
  // [a840]
  0x1b1113ad, 0x19042307, 0x09006e33, 0x030f11a4,   // et.ro.tr_643 ca.fi.gl_432  blu.pl.un_A70 ro.lv.nl_433
  0x11640413, 0x231b11ee, 0x03006e0e, 0x0d006e19,   // fi.lg.ro_665 ro.tr.ca_422  blu.nl.un_550 blu.cs.un_750
  0x1f641208, 0x042721a0, 0x04190b05, 0x0e04270d,   // hu.lg.cy_443 jw.gd.fi_322  es.gl.fi_333 gd.fi.is_554
  0x0d131113, 0x0c062005, 0x19071f05, 0x645508a7,   // ro.et.cs_665 sq.de.sv_333  cy.it.gl_333 no.rw.lg_532
  // [a850]
  0x1b01530c, 0x1000312a, 0x3f13110c, 0x1100132a,   // ht.en.tr_543 az.lt.un_970  ro.et.af_543 et.ro.un_970
  0x180d12a4, 0x2d1611a4, 0x100711ec, 0x3f0e06a7,   // hu.cs.ga_433 ro.hr.sk_433  ro.bg.be_644 de.is.af_532
  0x05212314, 0x0f016e04, 0x05001a08, 0x1e1c110c,   // ca.jw.fr_666 blu.en.lv_332  tl.fr.un_430 ro.id.ms_543
  0x11000611, 0x110106ee, 0x250e0c08, 0x1a276b12,   // de.ro.un_630 de.en.ro_422  sv.is.eu_443 ceb.gd.tl_654
  // [a860]
  0x0c00180c, 0x01006e08, 0x04001a1b, 0x0c3f02a0,   // ga.sv.un_530 blu.en.un_430  tl.fi.un_770 da.af.sv_322
  0x05001813, 0x640a0807, 0x25190b5a, 0x060e3fa0,   // ga.fr.un_650 no.pt.lg_432  es.gl.eu_553 af.is.de_322
  0x6b1a0409, 0x02001f0d, 0x310e1b0b, 0x0e00061a,   // fi.tl.ceb_444 cy.da.un_540  tr.is.az_542 de.is.un_760
  0x102d1707, 0x0a006e1b, 0x030c3faf, 0x1200021a,   // sr.sk.lt_432 blu.pt.un_770  af.sv.nl_655 da.hu.un_760
  // [a870]
  0x531a1c04, 0x190e06ee, 0x1a042102, 0x6b1a2107,   // id.tl.ht_332 de.is.gl_422  jw.fi.tl_222 jw.tl.ceb_432
  0x1a0e6b07, 0x056e1f0c, 0x27053f0c, 0x6e530a09,   // ceb.is.tl_432 cy.blu.fr_543  af.fr.gd_543 pt.ht.blu_444
  0x3f006e12, 0x05530308, 0x0c003f0c, 0x1b006b0c,   // blu.af.un_640 nl.ht.fr_443  af.sv.un_530 ceb.tr.un_530
  0x25312aad, 0x040f13ec, 0x102916ee, 0x040f13a9,   // mt.az.eu_643 et.lv.fi_644  hr.sl.lt_422 et.lv.fi_544
  // [a880]
  0x131a0412, 0x0a2b6e12, 0x0f0204ee, 0x08033f55,   // fi.tl.et_654 blu.vi.pt_654  fi.da.lv_422 af.nl.no_442
  0x031c3fa7, 0x190b6414, 0x6e000e1a, 0x2000230b,   // af.id.nl_532 lg.es.gl_666  is.blu.un_760 ca.sq.un_520
  0x3f0355a0, 0x230603a4, 0x041a1b04, 0x6b311b0d,   // rw.nl.af_322 nl.de.ca_433  tr.tl.fi_332 tr.az.ceb_554
  0x0d040107, 0x030e0807, 0x64055304, 0x100a06ec,   // en.fi.cs_432 no.is.nl_432  ht.fr.lg_332 de.pt.lt_644
  // [a890]
  0x3f311b12, 0x28210402, 0x10070aa0, 0x1b042807,   // tr.az.af_654 fi.jw.sw_222  mk.bg.be_322 sw.fi.tr_432
  0x1a001b05, 0x010f1007, 0x0f106e5a, 0x532b01ac,   // tr.tl.un_330 lt.lv.en_432  blu.lt.lv_553 en.vi.ht_632
  0x02131b05, 0x1b023f0c, 0x081b0208, 0x1a0601a7,   // tr.et.da_333 af.da.tr_543  da.tr.no_443 en.de.tl_532
  0x04003104, 0x041b3111, 0x0d0216af, 0x081b0207,   // az.fi.un_320 az.tr.fi_653  hr.da.cs_655 da.tr.no_432
  // [a8a0]
  0x04311b55, 0x3f311b11, 0x130601a0, 0x2d0d1ba0,   // tr.az.fi_442 tr.az.af_653  en.de.et_322 tr.cs.sk_322
  0x023f1707, 0x1b190b08, 0x20311b0b, 0x041007ad,   // sr.af.da_432 es.gl.tr_443  tr.az.sq_542 bg.be.ru_643
  0x6b311b08, 0x64000609, 0x641355a4, 0x1b020811,   // tr.az.ceb_443 de.lg.un_440  rw.et.lg_433 no.da.tr_653
  0x3f23100c, 0x02532908, 0x020a11a7, 0x0c020305,   // lt.ca.af_543 sl.ht.da_443  ro.pt.da_532 nl.da.sv_333
  // [a8b0]
  0x183f0107, 0x29001b0e, 0x09201b0c, 0x086b6e12,   // en.af.ga_432 tr.sl.un_550  tr.sq.pl_543 blu.ceb.no_654
  0x03000212, 0x6e016b05, 0x21005321, 0x086b0fee,   // da.nl.un_640 ceb.en.blu_333  ht.jw.un_860 lv.ceb.no_422
  0x010555a0, 0x20001f1a, 0x3f001c02, 0x123f0404,   // rw.fr.en_322 cy.sq.un_760  id.af.un_220 fi.af.hu_332
  0x18002a05, 0x11170604, 0x03002a04, 0x055301a9,   // mt.ga.un_330 de.sr.ro_332  mt.nl.un_320 en.ht.fr_544
  // [a8c0]
  0x0f103fee, 0x0e082009, 0x27010a04, 0x230c0e0c,   // af.lt.lv_422 sq.no.is_444  pt.en.gd_332 is.sv.ca_543
  0x2a0c08a4, 0x080211a6, 0x0c041f08, 0x0c6b0808,   // no.sv.mt_433 ro.da.no_521  cy.fi.sv_443 no.ceb.sv_443
  0x230f05ee, 0x18190e55, 0x080c0f07, 0x0200012a,   // fr.lv.ca_422 is.gl.ga_442  lv.sv.no_432 en.da.un_970
  0x531e1c0c, 0x28001813, 0x06020812, 0x641310a0,   // id.ms.ht_543 ga.sw.un_650  no.da.de_654 lt.et.lg_322
  // [a8d0]
  0x0553020c, 0x0e6b0104, 0x25000907, 0x29100fa7,   // da.ht.fr_543 en.ceb.is_332  pl.eu.un_420 lv.lt.sl_532
  0x11071907, 0x5311050c, 0x06080ea4, 0x3f00270e,   // gl.it.ro_432 fr.ro.ht_543  is.no.de_433 gd.af.un_550
  0x251e1c09, 0x3f5521a4, 0x072718ee, 0x112307ee,   // id.ms.eu_444 jw.rw.af_433  ga.gd.it_422 it.ca.ro_422
  0x28071108, 0x08100107, 0x042711a0, 0x093f2d12,   // ro.it.sw_443 en.lt.no_432  ro.gd.fi_322 sk.af.pl_654
  // [a8e0]
  0x080f2304, 0x2800111b, 0x3f002012, 0x25050907,   // ca.lv.no_332 ro.sw.un_770  sq.af.un_640 pl.fr.eu_432
  0x051c2a07, 0x1e1c1f0c, 0x17160609, 0x192307a9,   // mt.id.fr_432 cy.id.ms_543  de.hr.sr_444 it.ca.gl_544
  0x18001105, 0x096b1aa0, 0x216b1807, 0x060802ee,   // ro.ga.un_330 tl.ceb.pl_322  ga.ceb.jw_432 da.no.de_422
  0x09000635, 0x28111aa9, 0x6b012ba4, 0x1e1c6ba9,   // de.pl.un_A90 tl.ro.sw_544  vi.en.ceb_433 ceb.id.ms_544
  // [a8f0]
  0x0b2d050c, 0x17160809, 0x080901ee, 0x0f0206a0,   // fr.sk.es_543 no.hr.sr_444  en.pl.no_422 de.da.lv_322
  0x02060404, 0x20551208, 0x0802060e, 0x23001b12,   // fi.de.da_332 hu.rw.sq_443  de.da.no_555 tr.ca.un_640
  0x13111208, 0x0e311b13, 0x21281ea9, 0x1c131a13,   // hu.ro.et_443 tr.az.is_665  ms.sw.jw_544 tl.et.id_665
  0x09001804, 0x100f20af, 0x280c0807, 0x55211ca4,   // ga.pl.un_320 sq.lv.lt_655  no.sv.sw_432 id.jw.rw_433
  // [a900]
  0x2d2111ee, 0x20000709, 0x05272a0c, 0x1c131ea0,   // ro.jw.sk_422 it.sq.un_440  mt.gd.fr_543 ms.et.id_322
  0x092908a0, 0x04033f14, 0x3f0c25a6, 0x0d1f01a0,   // no.sl.pl_322 af.nl.fi_666  eu.sv.af_521 en.cy.cs_322
  0x0c2808ee, 0x0d120912, 0x11001f14, 0x02641f07,   // no.sw.sv_422 pl.hu.cs_654  cy.ro.un_660 cy.lg.da_432
  0x2a001707, 0x0300070c, 0x021f08a7, 0x27000d04,   // sr.mt.un_420 it.nl.un_530  no.cy.da_532 cs.gd.un_320
  // [a910]
  0x0b190a5a, 0x08000612, 0x1355200c, 0x0d1e0904,   // pt.gl.es_553 de.no.un_640  sq.rw.et_543 pl.ms.cs_332
  0x21271860, 0x01022707, 0x051b530d, 0x20550d07,   // ga.gd.jw_664 gd.da.en_432  ht.tr.fr_554 cs.rw.sq_432
  0x1b000608, 0x1709310b, 0x19000534, 0x16080eec,   // de.tr.un_430 az.pl.sr_542  fr.gl.un_A80 is.no.hr_644
  0x18040107, 0x23110505, 0x02210f0c, 0x0c055307,   // en.fi.ga_432 fr.ro.ca_333  lv.jw.da_543 ht.fr.sv_432
  // [a920]
  0x133f04a4, 0x293f0307, 0x0a211005, 0x046b6402,   // fi.af.et_433 nl.af.sl_432  lt.jw.pt_333 lg.ceb.fi_222
  0x1b2a1007, 0x051f270c, 0x292004a7, 0x19126ea7,   // lt.mt.tr_432 gd.cy.fr_543  fi.sq.sl_532 blu.hu.gl_532
  0x0b1a5507, 0x18061f08, 0x28642a08, 0x07002d1a,   // rw.tl.es_432 cy.de.ga_443  mt.lg.sw_443 sk.it.un_760
  0x31001805, 0x551f08a0, 0x29006404, 0x07010308,   // ga.az.un_330 no.cy.rw_322  lg.sl.un_320 nl.en.it_443
  // [a930]
  0x271f1812, 0x19011fa7, 0x13006e0b, 0x3f006e0e,   // ga.cy.gd_654 cy.en.gl_532  blu.et.un_520 blu.af.un_550
  0x6e133f09, 0x105528ee, 0x211e3104, 0x23000e0e,   // af.et.blu_444 sw.rw.lt_422  az.ms.jw_332 is.ca.un_550
  0x061b1307, 0x1a001812, 0x04001a13, 0x18002b0b,   // et.tr.de_432 ga.tl.un_640  tl.fi.un_650 vi.ga.un_520
  0x55201b07, 0x230b0ea0, 0x082116a0, 0x0e0a2dac,   // tr.sq.rw_432 is.es.ca_322  hr.jw.no_322 sk.pt.is_632
  // [a940]
  0x21002018, 0x2711180c, 0x1108530b, 0x1a28010b,   // sq.jw.un_740 ga.ro.gd_543  ht.no.ro_542 en.sw.tl_542
  0x230a0eaf, 0x1820010c, 0x27200111, 0x31000614,   // is.pt.ca_655 en.sq.ga_543  en.sq.gd_653 de.az.un_660
  0x2d002802, 0x641f55af, 0x64000614, 0x110704a4,   // sw.sk.un_220 rw.cy.lg_655  de.lg.un_660 ru.bg.ro_433
  0x06095511, 0x050a31a7, 0x311b1217, 0x1b0605a4,   // rw.pl.de_653 az.pt.fr_532  hu.tr.az_753 fr.de.tr_433
  // [a950]
  0x3f061f02, 0x13000929, 0x0664550d, 0x17030ca0,   // cy.de.af_222 hi.bh.un_960  rw.lg.de_554 sv.nl.sr_322
  0x23190a0e, 0x55000919, 0x052a0107, 0x0e0416a0,   // pt.gl.ca_555 pl.rw.un_750  en.mt.fr_432 hr.fi.is_322
  0x192311a4, 0x0b005502, 0x1b1302a4, 0x28061fa0,   // ro.ca.gl_433 rw.es.un_220  da.et.tr_433 cy.de.sw_322
  0x13282104, 0x206e1a05, 0x05001f19, 0x1f3f64a0,   // jw.sw.et_332 tl.blu.sq_333  cy.fr.un_750 lg.af.cy_322
  // [a960]
  0x0906550c, 0x1f002822, 0x063f09ad, 0x2800290e,   // rw.de.pl_543 sw.cy.un_870  pl.af.de_643 sl.sw.un_550
  0x100417af, 0x2a00310d, 0x0b071f04, 0x04001104,   // sr.ru.be_655 az.mt.un_540  cy.it.es_332 ro.fi.un_320
  0x062a1307, 0x1c2829ac, 0x0c000a05, 0x283f55a0,   // et.mt.de_432 sl.sw.id_632  pt.sv.un_330 rw.af.sw_322
  0x25002112, 0x041a1f0c, 0x055313ee, 0x3f002813,   // jw.eu.un_640 cy.tl.fi_543  et.ht.fr_422 sw.af.un_650
  // [a970]
  0x1a001f05, 0x08000307, 0x0613285a, 0x20113f07,   // cy.tl.un_330 nl.no.un_420  sw.et.de_553 af.ro.sq_432
  0x3f1e1c08, 0x532106a7, 0x0b0c25a9, 0x131206af,   // id.ms.af_443 de.jw.ht_532  eu.sv.es_544 de.hu.et_655
  0x0b1219af, 0x190b05af, 0x1b5355af, 0x04091fa7,   // gl.hu.es_655 fr.es.gl_655  rw.ht.tr_655 cy.pl.fi_532
  0x28553f55, 0x180701a0, 0x3f082a04, 0x3f080907,   // af.rw.sw_442 en.it.ga_322  mt.no.af_332 pl.no.af_432
  // [a980]
  0x21060c04, 0x1c21060c, 0x06030804, 0x3f0208a7,   // sv.de.jw_332 de.jw.id_543  no.nl.de_332 no.da.af_532
  0x171631ee, 0x041007a7, 0x06120cee, 0x012805ee,   // az.hr.sr_422 bg.be.ru_532  sv.hu.de_422 fr.sw.en_422
  0x28182302, 0x28271808, 0x2b6b040c, 0x086455ad,   // ca.ga.sw_222 ga.gd.sw_443  fi.ceb.vi_543 rw.lg.no_643
  0x532b28ee, 0x1e002b0c, 0x2821270c, 0x211c28a4,   // sw.vi.ht_422 vi.ms.un_530  gd.jw.sw_543 sw.id.jw_433
  // [a990]
  0x1a276bac, 0x2b2310a0, 0x271828a4, 0x25000f19,   // ceb.gd.tl_632 lt.ca.vi_322  sw.ga.gd_433 lv.eu.un_750
  0x1e1c040c, 0x18071a04, 0x0000072d, 0x1f53270c,   // fi.id.ms_543 tl.it.ga_332  it.un.un_A00 gd.ht.cy_543
  0x281610a6, 0x02001812, 0x130417a7, 0x132506a0,   // lt.hr.sw_521 ga.da.un_640  sr.fi.et_532 de.eu.et_322
  0x21271111, 0x0e0425ad, 0x282b010c, 0x181a0e05,   // ro.gd.jw_653 eu.fi.is_643  en.vi.sw_543 is.tl.ga_333
  // [a9a0]
  0x181f01a4, 0x6b0d2a02, 0x212d0d55, 0x271f0102,   // en.cy.ga_433 mt.cs.ceb_222  cs.sk.jw_442 en.cy.gd_222
  0x0418270c, 0x1f27180c, 0x11040da4, 0x552528af,   // gd.ga.fi_543 ga.gd.cy_543  cs.fi.ro_433 sw.eu.rw_655
  0x20272312, 0x1a041b07, 0x1900050c, 0x532a1805,   // ca.gd.sq_654 tr.fi.tl_432  fr.gl.un_530 ga.mt.ht_333
  0x180127a0, 0x6b0104a0, 0x121617a4, 0x0b071155,   // gd.en.ga_322 fi.en.ceb_322  sr.hr.hu_433 ro.it.es_442
  // [a9b0]
  0x2800291a, 0x00000142, 0x6b1a10a7, 0x18000e05,   // sl.sw.un_760 en.un.un_C00  lt.tl.ceb_532 is.ga.un_330
  0x552509a0, 0x0500210c, 0x170104a4, 0x2d005302,   // pl.eu.rw_322 jw.fr.un_530  fi.en.sr_433 ht.sk.un_220
  0x131007ee, 0x04000b08, 0x07281902, 0x07001812,   // it.lt.et_422 es.fi.un_430  gl.sw.it_222 ga.it.un_640
  0x6b3f01a0, 0x0c0601ee, 0x19001113, 0x2d060c07,   // en.af.ceb_322 en.de.sv_422  ro.gl.un_650 sv.de.sk_432
  // [a9c0]
  0x08070a0e, 0x0a051960, 0x106407ee, 0x120b0304,   // mk.bg.uk_555 gl.fr.pt_664  it.lg.lt_422 nl.es.hu_332
  0x1f000a05, 0x2d0d6baf, 0x07196407, 0x0a0407ee,   // pt.cy.un_330 ceb.cs.sk_655  lg.gl.it_432 bg.ru.mk_422
  0x2d0d0ba0, 0x0d1f6b0b, 0x2d000902, 0x1a162d07,   // es.cs.sk_322 ceb.cy.cs_542  pl.sk.un_220 sk.hr.tl_432
  0x13033f08, 0x04133fee, 0x030113ee, 0x10645511,   // af.nl.et_443 af.et.fi_422  et.en.nl_422 rw.lg.lt_653
  // [a9d0]
  0x6400091b, 0x2d0f53a0, 0x19010bee, 0x19171608,   // pl.lg.un_770 ht.lv.sk_322  es.en.gl_422 hr.sr.gl_443
  0x0b1905a0, 0x080702a4, 0x1a556413, 0x64161a07,   // fr.gl.es_322 da.it.no_433  lg.rw.tl_665 tl.hr.lg_432
  0x641a1202, 0x556b1a09, 0x10002502, 0x29000c13,   // hu.tl.lg_222 tl.ceb.rw_444  eu.lt.un_220 sv.sl.un_650
  0x201b31a4, 0x06000e0c, 0x1b20640c, 0x20291309,   // az.tr.sq_433 is.de.un_530  lg.sq.tr_543 et.sl.sq_444
  // [a9e0]
  0x07120e0c, 0x29080209, 0x09292008, 0x20292da0,   // is.hu.it_543 da.no.sl_444  sq.sl.pl_443 sk.sl.sq_322
  0x641a6ba6, 0x120d18ad, 0x315520a4, 0x16080712,   // ceb.tl.lg_521 ga.cs.hu_643  sq.rw.az_433 it.no.hr_654
  0x1b202955, 0x041e1c09, 0x0e1c1eec, 0x291020ac,   // sl.sq.tr_442 id.ms.fi_444  ms.id.is_644 sq.lt.sl_632
  0x20292dee, 0x211c1ea7, 0x1e1c1a05, 0x201029a4,   // sk.sl.sq_422 ms.id.jw_532  tl.id.ms_333 sl.lt.sq_433
  // [a9f0]
  0x16132aee, 0x071b2009, 0x13290c07, 0x25040308,   // mt.et.hr_422 sq.tr.it_444  sv.sl.et_432 nl.fi.eu_443
  0x551b200c, 0x1b31200c, 0x1c0f0411, 0x033f06ac,   // sq.tr.rw_543 sq.az.tr_543  fi.lv.id_653 de.af.nl_632
  0x23001a04, 0x110207a4, 0x1000072b, 0x201f1104,   // tl.ca.un_320 it.da.ro_433  bg.be.un_980 ro.cy.sq_332
  0x190a0555, 0x0b000504, 0x28250da0, 0x0600080e,   // fr.pt.gl_442 fr.es.un_320  cs.eu.sw_322 no.de.un_550
  // [aa00]
  0x6b04100c, 0x080113a0, 0x2d0d0912, 0x25100fec,   // lt.fi.ceb_543 et.en.no_322  pl.cs.sk_654 lv.lt.eu_644
  0x0b0a05a4, 0x6b1a2155, 0x0e000113, 0x060c1b04,   // fr.pt.es_433 jw.tl.ceb_442  en.is.un_650 tr.sv.de_332
  0x190b0409, 0x02060ea0, 0x121823a0, 0x010628a9,   // fi.es.gl_444 is.de.da_322  ca.ga.hu_322 sw.de.en_544
  0x04280ea7, 0x281a6b55, 0x051f07ee, 0x16111b05,   // is.sw.fi_532 ceb.tl.sw_442  it.cy.fr_422 tr.ro.hr_333
  // [aa10]
  0x211f280c, 0x1a132105, 0x1a130ca0, 0x0c2a2307,   // sw.cy.jw_543 jw.et.tl_333  sv.et.tl_322 ca.mt.sv_432
  0x130c2aad, 0x09640a04, 0x31072305, 0x551007a0,   // mt.sv.et_643 pt.lg.pl_332  ca.it.az_333 it.lt.rw_322
  0x31200809, 0x1100251a, 0x202d0d05, 0x641625a4,   // no.sq.az_444 eu.ro.un_760  cs.sk.sq_333 eu.hr.lg_433
  0x08310107, 0x552064ad, 0x2700010c, 0x07002114,   // en.az.no_432 lg.sq.rw_643  en.gd.un_530 jw.it.un_660
  // [aa20]
  0x6b1a040c, 0x0400050d, 0x120706ee, 0x16280407,   // fi.tl.ceb_543 fr.fi.un_540  de.it.hu_422 fi.sw.hr_432
  0x310355a7, 0x256b10ee, 0x21001f18, 0x0720060c,   // rw.nl.az_532 lt.ceb.eu_422  cy.jw.un_740 de.sq.it_543
  0x190b28a0, 0x0b2a0107, 0x0e0613a4, 0x02551a0b,   // sw.es.gl_322 en.mt.es_432  et.de.is_433 tl.rw.da_542
  0x6b6e1107, 0x182d0d5a, 0x066429a9, 0x19006e0e,   // ro.blu.ceb_432 cs.sk.ga_553  sl.lg.de_544 blu.gl.un_550
  // [aa30]
  0x0c6455ee, 0x29212a07, 0x2b1904a0, 0x550625a9,   // rw.lg.sv_422 mt.jw.sl_432  fi.gl.vi_322 eu.de.rw_544
  0x120a0d11, 0x04133f55, 0x6e0413a0, 0x0a000e0d,   // cs.pt.hu_653 af.et.fi_442  et.fi.blu_322 is.pt.un_540
  0x1a255513, 0x23002808, 0x2a1a55a7, 0x0a2713a0,   // rw.eu.tl_665 sw.ca.un_430  rw.tl.mt_532 et.gd.pt_322
  0x12005523, 0x16035305, 0x532d210d, 0x55182ba7,   // rw.hu.un_880 ht.nl.hr_333  jw.sk.ht_554 vi.ga.rw_532
  // [aa40]
  0x09002002, 0x19002108, 0x25125308, 0x5528210c,   // sq.pl.un_220 jw.gl.un_430  ht.hu.eu_443 jw.sw.rw_543
  0x170c02a4, 0x096e2b07, 0x2b271e07, 0x061b310d,   // da.sv.sr_433 vi.blu.pl_432  ms.gd.vi_432 az.tr.de_554
  0x311b12a7, 0x23043f02, 0x033f13a9, 0x13076ba0,   // hu.tr.az_532 af.fi.ca_222  et.af.nl_544 ceb.it.et_322
  0x030813a0, 0x033f1b0c, 0x08040aaf, 0x0f5510ec,   // et.no.nl_322 tr.af.nl_543  mk.ru.uk_655 lt.rw.lv_644
  // [aa50]
  0x641255af, 0x110f01a0, 0x11215508, 0x53190a04,   // rw.hu.lg_655 en.lv.ro_322  rw.jw.ro_443 pt.gl.ht_332
  0x111004a4, 0x55200107, 0x1b3f02a0, 0x0c060808,   // fi.lt.ro_433 en.sq.rw_432  da.af.tr_322 no.de.sv_443
  0x31061b04, 0x1a6b13ac, 0x17161fa4, 0x03002021,   // tr.de.az_332 et.ceb.tl_632  cy.hr.sr_433 sq.nl.un_860
  0x1f1118ac, 0x1355280e, 0x1e1625a6, 0x31551c04,   // ga.ro.cy_632 sw.rw.et_555  eu.hr.ms_521 id.rw.az_332
  // [aa60]
  0x2855060c, 0x08020eac, 0x2028550c, 0x13083fa0,   // de.rw.sw_543 is.da.no_632  rw.sw.sq_543 af.no.et_322
  0x21101e07, 0x03553f07, 0x121e1c0d, 0x1c0d13ee,   // ms.lt.jw_432 af.rw.nl_432  id.ms.hu_554 bh.ne.mr_422
  0x1e6b1bee, 0x1a552807, 0x6b17160d, 0x161a1fa6,   // tr.ceb.ms_422 sw.rw.tl_432  hr.sr.ceb_554 cy.tl.hr_521
  0x1b1704ad, 0x026b1a09, 0x3f06020c, 0x2800642a,   // fi.sr.tr_643 tl.ceb.da_444  da.de.af_543 lg.sw.un_970
  // [aa70]
  0x6e1a6ba4, 0x16286455, 0x3f17165a, 0x0f28640c,   // ceb.tl.blu_433 lg.sw.hr_442  hr.sr.af_553 lg.sw.lv_543
  0x64100fa9, 0x1f1a6bec, 0x1a171604, 0x1800191a,   // lv.lt.lg_544 ceb.tl.cy_644  hr.sr.tl_332 gl.ga.un_760
  0x1b2813ee, 0x1b2113a4, 0x0700130d, 0x28641e07,   // et.sw.tr_422 et.jw.tr_433  et.it.un_540 ms.lg.sw_432
  0x200802a4, 0x0c0807ac, 0x21286412, 0x2800071b,   // da.no.sq_433 it.no.sv_632  lg.sw.jw_654 it.sw.un_770
  // [aa80]
  0x05110713, 0x18210504, 0x120829a7, 0x060e0ca4,   // it.ro.fr_665 fr.jw.ga_332  sl.no.hu_532 sv.is.de_433
  0x17162a14, 0x04532a14, 0x28096412, 0x0e0510ad,   // mt.hr.sr_666 mt.ht.fi_666  lg.pl.sw_654 lt.fr.is_643
  0x05110709, 0x210c2a0e, 0x202a2155, 0x0220080c,   // it.ro.fr_444 mt.sv.jw_555  jw.mt.sq_442 no.sq.da_543
  0x0600200e, 0x07001802, 0x0e1827af, 0x05060fad,   // sq.de.un_550 ga.it.un_220  gd.ga.is_655 lv.de.fr_643
  // [aa90]
  0x180e2707, 0x18000919, 0x040e2304, 0x25005313,   // gd.is.ga_432 pl.ga.un_750  ca.is.fi_332 ht.eu.un_650
  0x06001f1a, 0x290c045a, 0x27181ea0, 0x0c20095a,   // cy.de.un_760 fi.sv.sl_553  ms.ga.gd_322 pl.sq.sv_553
  0x07100407, 0x182701ad, 0x2006080c, 0x0e250504,   // ru.be.bg_432 en.gd.ga_643  no.de.sq_543 fr.eu.is_332
  0x200608a4, 0x13052707, 0x0a0e1904, 0x09292d12,   // no.de.sq_433 gd.fr.et_432  gl.is.pt_332 sk.sl.pl_654
  // [aaa0]
  0x0e122d55, 0x1b190a05, 0x090d13a7, 0x1700080e,   // sk.hu.is_442 pt.gl.tr_333  bh.ne.hi_532 uk.sr.un_550
  0x3f5520a7, 0x210620ad, 0x111a20ee, 0x2055070c,   // sq.rw.af_532 sq.de.jw_643  sq.tl.ro_422 it.rw.sq_543
  0x172d2912, 0x100907a4, 0x641f07ec, 0x191220ee,   // sl.sk.sr_654 it.pl.lt_433  it.cy.lg_644 sq.hu.gl_422
  0x3f1b0107, 0x01191307, 0x020c2d07, 0x20001219,   // en.tr.af_432 et.gl.en_432  sk.sv.da_432 hu.sq.un_750
  // [aab0]
  0x1b311160, 0x133f0c08, 0x0f10290b, 0x1c000c08,   // ro.az.tr_664 sv.af.et_443  sl.lt.lv_542 sv.id.un_430
  0x2d1b3111, 0x28640709, 0x02311ba7, 0x11070b04,   // az.tr.sk_653 it.lg.sw_444  tr.az.da_532 es.it.ro_332
  0x2118280c, 0x063f0c0c, 0x09101fad, 0x030109ee,   // sw.ga.jw_543 sv.af.de_543  cy.lt.pl_643 pl.en.nl_422
  0x16001907, 0x1c0213ad, 0x1b190a55, 0x065553a0,   // gl.hr.un_420 et.da.id_643  pt.gl.tr_442 ht.rw.de_322
  // [aac0]
  0x201355ee, 0x081905a4, 0x0a190c0c, 0x09000422,   // rw.et.sq_422 fr.gl.no_433  sv.gl.pt_543 fi.pl.un_870
  0x550c2da0, 0x130c2da0, 0x101f090c, 0x0e00081b,   // sk.sv.rw_322 sk.sv.et_322  pl.cy.lt_543 no.is.un_770
  0x0c292804, 0x2d0d02ee, 0x03060f04, 0x09002014,   // sw.sl.sv_332 da.cs.sk_422  lv.de.nl_332 sq.pl.un_660
  0x131c0d13, 0x082820a0, 0x02130804, 0x210b5504,   // ne.mr.bh_665 sq.sw.no_322  no.et.da_332 rw.es.jw_332
  // [aad0]
  0x08020ead, 0x20552555, 0x0e1c2a04, 0x21025511,   // is.da.no_643 eu.rw.sq_442  mt.id.is_332 rw.da.jw_653
  0x1b00641b, 0x28002034, 0x29161c02, 0x05020b5a,   // lg.tr.un_770 sq.sw.un_A80  id.hr.sl_222 es.da.fr_553
  0x122909a7, 0x01006b05, 0x060a11a0, 0x122011a0,   // pl.sl.hu_532 ceb.en.un_330  ro.pt.de_322 ro.sq.hu_322
  0x1a106ba7, 0x28290913, 0x0e180d12, 0x09000f13,   // ceb.lt.tl_532 pl.sl.sw_665  cs.ga.is_654 lv.pl.un_650
  // [aae0]
  0x01031f0c, 0x0f2902ee, 0x18000113, 0x31552007,   // cy.nl.en_543 da.sl.lv_422  en.ga.un_650 sq.rw.az_432
  0x010c0855, 0x060109a0, 0x102d0d0e, 0x061b0c02,   // no.sv.en_442 pl.en.de_322  cs.sk.lt_555 sv.tr.de_222
  0x1c091e04, 0x160d290c, 0x19250b04, 0x1a6b2804,   // ms.pl.id_332 sl.cs.hr_543  es.eu.gl_332 sw.ceb.tl_332
  0x27000904, 0x55646b05, 0x091801a0, 0x18000905,   // pl.gd.un_320 ceb.lg.rw_333  en.ga.pl_322 pl.ga.un_330
  // [aaf0]
  0x2d0d0309, 0x012b2704, 0x02062b07, 0x21001a1a,   // nl.cs.sk_444 gd.vi.en_332  vi.de.da_432 tl.jw.un_760
  0x06311b07, 0x53000907, 0x080c0e0c, 0x31252aee,   // tr.az.de_432 pl.ht.un_420  is.sv.no_543 mt.eu.az_422
  0x056b1e07, 0x066b1a0c, 0x061123a0, 0x172510ad,   // ms.ceb.fr_432 tl.ceb.de_543  ca.ro.de_322 lt.eu.sr_643
  0x0a110404, 0x2a2d01ee, 0x0d1c13a0, 0x01110c08,   // ru.ro.mk_332 en.sk.mt_422  bh.mr.ne_322 sv.ro.en_443
  // [ab00]
  0x1a002b1b, 0x10001313, 0x211a5307, 0x016b275a,   // vi.tl.un_770 et.lt.un_650  ht.tl.jw_432 gd.ceb.en_553
  0x101b0f60, 0x6e3f03a9, 0x1b062108, 0x080201ad,   // lv.tr.lt_664 nl.af.blu_544  jw.de.tr_443 en.da.no_643
  0x1a060807, 0x082718ee, 0x070523ee, 0x0800641a,   // no.de.tl_432 ga.gd.no_422  ca.fr.it_422 lg.no.un_760
  0x0b101f0d, 0x020c1607, 0x2a5525a7, 0x020c28a0,   // cy.lt.es_554 hr.sv.da_432  eu.rw.mt_532 sw.sv.da_322
  // [ab10]
  0x05210107, 0x07001f23, 0x06202aaf, 0x060e0305,   // en.jw.fr_432 cy.it.un_880  mt.sq.de_655 nl.is.de_333
  0x641304a9, 0x10002823, 0x6b1f1a04, 0x041108af,   // fi.et.lg_544 sw.lt.un_880  tl.cy.ceb_332 uk.ro.ru_655
  0x130d1ca9, 0x11190155, 0x0a001f21, 0x020c1307,   // mr.ne.bh_544 en.gl.ro_442  cy.pt.un_860 et.sv.da_432
  0x1a2a010c, 0x032564a0, 0x19110ba9, 0x08060255,   // en.mt.tl_543 lg.eu.nl_322  es.ro.gl_544 da.de.no_442
  // [ab20]
  0x6b1a1f05, 0x0364250c, 0x291e1302, 0x0700252c,   // cy.tl.ceb_333 eu.lg.nl_543  et.ms.sl_222 eu.it.un_990
  0x06002908, 0x6b2519ad, 0x05555304, 0x0717160d,   // sl.de.un_430 gl.eu.ceb_643  ht.rw.fr_332 hr.sr.it_554
  0x18005522, 0x160e2a0c, 0x101f1ca0, 0x07111c55,   // rw.ga.un_870 mt.is.hr_543  id.cy.lt_322 id.ro.it_442
  0x281b1207, 0x0c0813ee, 0x2a006429, 0x07012855,   // hu.tr.sw_432 et.no.sv_422  lg.mt.un_960 sw.en.it_442
  // [ab30]
  0x25000b05, 0x04000e11, 0x311f0ea9, 0x23003105,   // es.eu.un_330 is.fi.un_630  is.cy.az_544 az.ca.un_330
  0x1200550d, 0x0400120e, 0x28042007, 0x1b0e2508,   // rw.hu.un_540 hu.fi.un_550  sq.fi.sw_432 eu.is.tr_443
  0x16202107, 0x2a25280c, 0x1a0e20a9, 0x0f1053a7,   // jw.sq.hr_432 sw.eu.mt_543  sq.is.tl_544 ht.lt.lv_532
  0x040a1fad, 0x04001804, 0x09292808, 0x1b000e0d,   // cy.pt.fi_643 ga.fi.un_320  sw.sl.pl_443 is.tr.un_540
  // [ab40]
  0x06000402, 0x083f0e08, 0x1629090c, 0x053f0aa0,   // fi.de.un_220 is.af.no_443  pl.sl.hr_543 pt.af.fr_322
  0x2b2523a0, 0x031827af, 0x04132304, 0x2100071a,   // ca.eu.vi_322 gd.ga.nl_655  ca.et.fi_332 it.jw.un_760
  0x0e2d0d60, 0x05000c13, 0x25051ea0, 0x0c1f0404,   // cs.sk.is_664 sv.fr.un_650  ms.fr.eu_322 fi.cy.sv_332
  0x17161faf, 0x202a020c, 0x232a08a0, 0x21551fec,   // cy.hr.sr_655 da.mt.sq_543  no.mt.ca_322 cy.rw.jw_644
  // [ab50]
  0x280955af, 0x0c270b02, 0x64120d04, 0x1b080214,   // rw.pl.sw_655 es.gd.sv_222  cs.hu.lg_332 da.no.tr_666
  0x0f002513, 0x28001212, 0x060401a0, 0x292120a0,   // eu.lv.un_650 hu.sw.un_640  en.fi.de_322 sq.jw.sl_322
  0x0c130809, 0x21171813, 0x042a2807, 0x20230409,   // no.et.sv_444 ar.sr.fa_665  sw.mt.fi_432 fi.ca.sq_444
  0x64062911, 0x200c0404, 0x211f040c, 0x6b0b010c,   // sl.de.lg_653 fi.sv.sq_332  fi.cy.jw_543 en.es.ceb_543
  // [ab60]
  0x2007010c, 0x200912ee, 0x036428ec, 0x312025a4,   // en.it.sq_543 hu.pl.sq_422  sw.lg.nl_644 eu.sq.az_433
  0x111225a4, 0x192a31a4, 0x0925640c, 0x131601a4,   // eu.hu.ro_433 az.mt.gl_433  lg.eu.pl_543 en.hr.et_433
  0x0d0655ad, 0x161101a4, 0x21012b04, 0x1112250b,   // rw.de.cs_643 en.ro.hr_433  vi.en.jw_332 eu.hu.ro_542
  0x0a00090d, 0x25551213, 0x061101a4, 0x04051e07,   // pl.pt.un_540 hu.rw.eu_665  en.ro.de_433 ms.fr.fi_432
  // [ab70]
  0x1629130c, 0x231301a4, 0x07230804, 0x062b0107,   // et.sl.hr_543 en.et.ca_433  no.ca.it_332 en.vi.de_432
  0x230413ec, 0x231f1aa4, 0x070111a4, 0x02270812,   // et.fi.ca_644 tl.cy.ca_433  ro.en.it_433 no.gd.da_654
  0x1b55110b, 0x172d1607, 0x1c211f07, 0x16000108,   // ro.rw.tr_542 hr.sk.sr_432  cy.jw.id_432 en.hr.un_430
  0x070111a9, 0x1a000608, 0x0c126b55, 0x11132511,   // ro.en.it_544 de.tl.un_430  ceb.hu.sv_442 eu.et.ro_653
  // [ab80]
  0x0a110755, 0x20005513, 0x0c00290c, 0x123f1fa9,   // it.ro.pt_442 rw.sq.un_650  sl.sv.un_530 cy.af.hu_544
  0x0600181a, 0x02061208, 0x252d110c, 0x2b2164a9,   // ga.de.un_760 hu.de.da_443  ro.sk.eu_543 lg.jw.vi_544
  0x08131b08, 0x0613010c, 0x25110111, 0x0b1101a4,   // tr.et.no_443 en.et.de_543  en.ro.eu_653 en.ro.es_433
  0x10071105, 0x31002a07, 0x2d011fa7, 0x125521a4,   // ro.it.lt_333 mt.az.un_420  cy.en.sk_532 jw.rw.hu_433
  // [ab90]
  0x12006e0c, 0x0c006e0e, 0x0c020307, 0x6e000c12,   // blu.hu.un_530 blu.sv.un_550  nl.da.sv_432 sv.blu.un_640
  0x031a3f07, 0x0802530c, 0x033f0807, 0x28002a0d,   // af.tl.nl_432 ht.da.no_543  no.af.nl_432 mt.sw.un_540
  0x6e003f23, 0x07201208, 0x12086b0c, 0x20172913,   // af.blu.un_880 hu.sq.it_443  ceb.no.hu_543 sl.sr.sq_665
  0x0a55215a, 0x28550555, 0x0e0c0207, 0x052853ee,   // jw.rw.pt_553 fr.rw.sw_442  da.sv.is_432 ht.sw.fr_422
  // [aba0]
  0x23002109, 0x186e2aa9, 0x2d0d0102, 0x122005ee,   // jw.ca.un_440 mt.blu.ga_544  en.cs.sk_222 fr.sq.hu_422
  0x05085307, 0x531b1604, 0x256b18ee, 0x16000305,   // ht.no.fr_432 hr.tr.ht_332  ga.ceb.eu_422 nl.hr.un_330
  0x171628ee, 0x091a1b07, 0x1000280b, 0x23000a0d,   // sw.hr.sr_422 tr.tl.pl_432  sw.lt.un_520 pt.ca.un_540
  0x02060c09, 0x230a05a7, 0x6b311b13, 0x6b281aa0,   // sv.de.da_444 fr.pt.ca_532  tr.az.ceb_665 tl.sw.ceb_322
  // [abb0]
  0x182301ee, 0x0e311f07, 0x531a280c, 0x041716a7,   // en.ca.ga_422 cy.az.is_432  sw.tl.ht_543 hr.sr.fi_532
  0x28001a09, 0x110a0709, 0x080611ee, 0x2817160b,   // tl.sw.un_440 bg.mk.ro_444  ro.de.no_422 hr.sr.sw_542
  0x0600550c, 0x645304ee, 0x12085512, 0x16080b09,   // rw.de.un_530 fi.ht.lg_422  rw.no.hu_654 es.no.hr_444
  0x311b1f13, 0x281b6405, 0x086b1a04, 0x1917010c,   // cy.tr.az_665 lg.tr.sw_333  tl.ceb.no_332 en.sr.gl_543
  // [abc0]
  0x1b311704, 0x036455a9, 0x042564ec, 0x31021a04,   // sr.az.tr_332 rw.lg.nl_544  lg.eu.fi_644 tl.da.az_332
  0x55640da4, 0x1b3108a9, 0x03021108, 0x311a2712,   // cs.lg.rw_433 no.az.tr_544  ro.da.nl_443 gd.tl.az_654
  0x31006b19, 0x53282702, 0x18000d1a, 0x10311a02,   // ceb.az.un_750 gd.sw.ht_222  cs.ga.un_760 tl.az.lt_222
  0x0806110d, 0x21200ca0, 0x5500120d, 0x1b005509,   // ro.de.no_554 sv.sq.jw_322  hu.rw.un_540 rw.tr.un_440
  // [abd0]
  0x020a01a4, 0x190a05a9, 0x2d0d0ea9, 0x3f00060c,   // en.pt.da_433 fr.pt.gl_544  is.cs.sk_544 de.af.un_530
  0x03025509, 0x062010a9, 0x0f1011ec, 0x11232508,   // rw.da.nl_444 lt.sq.de_544  ro.lt.lv_644 eu.ca.ro_443
  0x051320a0, 0x072101a0, 0x2d2110a7, 0x21101aa4,   // sq.et.fr_322 en.jw.it_322  lt.jw.sk_532 tl.lt.jw_433
  0x023f01a0, 0x12293fa4, 0x6428200c, 0x250908a4,   // en.af.da_322 af.sl.hu_433  sq.sw.lg_543 no.pl.eu_433
  // [abe0]
  0x0f101b08, 0x1e041307, 0x190a2802, 0x17000c07,   // tr.lt.lv_443 et.fi.ms_432  sw.pt.gl_222 sv.sr.un_420
  0x0e0f13ad, 0x0e030607, 0x0406270c, 0x10170704,   // et.lv.is_643 de.nl.is_432  gd.de.fi_543 bg.sr.be_332
  0x270406a9, 0x0c0908af, 0x052b210b, 0x271203a0,   // de.fi.gd_544 no.pl.sv_655  jw.vi.fr_542 nl.hu.gd_322
  0x0e060802, 0x2d091104, 0x2d280b5a, 0x03133f0e,   // no.de.is_222 ro.pl.sk_332  es.sw.sk_553 af.et.nl_555
  // [abf0]
  0x31061ba4, 0x2d0d0e0b, 0x08021307, 0x120e1804,   // tr.de.az_433 is.cs.sk_542  et.da.no_432 ga.is.hu_332
  0x23190a0d, 0x3f060107, 0x11062707, 0x2a0b2302,   // pt.gl.ca_554 en.de.af_432  gd.de.ro_432 ca.es.mt_222
  0x21001f13, 0x17002104, 0x04006e13, 0x040a05ee,   // cy.jw.un_650 jw.sr.un_320  blu.fi.un_650 fr.pt.fi_422
  0x1f000e08, 0x0e231f12, 0x1e051c0c, 0x210e1c12,   // is.cy.un_430 cy.ca.is_654  id.fr.ms_543 id.is.jw_654

  // [ac00]
  0x271f205a, 0x06292aa4, 0x17000207, 0x111710af,   // sq.cy.gd_553 mt.sl.de_433  da.sr.un_420 be.sr.ro_655
  0x1a1c02ee, 0x08052355, 0x21082060, 0x02060ca0,   // da.id.tl_422 ca.fr.no_442  sq.no.jw_664 sv.de.da_322
  0x2d0e200c, 0x02041355, 0x12001b14, 0x200a190c,   // sq.is.sk_543 et.fi.da_442  tr.hu.un_660 gl.pt.sq_543
  0x1a0c0e07, 0x17000305, 0x10000a05, 0x03041b12,   // is.sv.tl_432 nl.sr.un_330  mk.be.un_330 tr.fi.nl_654
  // [ac10]
  0x251c2102, 0x04031b0c, 0x050e0c07, 0x1b0203a7,   // jw.id.eu_222 tr.nl.fi_543  sv.is.fr_432 nl.da.tr_532
  0x07056ba4, 0x12060202, 0x2500640d, 0x08002020,   // ceb.fr.it_433 da.de.hu_222  lg.eu.un_540 sq.no.un_850
  0x12001a05, 0x070e0c07, 0x12001b1a, 0x190b12ec,   // tl.hu.un_330 sv.is.it_432  tr.hu.un_760 hu.es.gl_644
  0x1b311a12, 0x0c0508a0, 0x061b030c, 0x18001f02,   // tl.az.tr_654 no.fr.sv_322  nl.tr.de_543 cy.ga.un_220
  // [ac20]
  0x07020eee, 0x130425ad, 0x211b3113, 0x09013fec,   // is.da.it_422 eu.fi.et_643  az.tr.jw_665 af.en.pl_644
  0x091f1a12, 0x53033fa0, 0x1a0b2504, 0x23643f02,   // tl.cy.pl_654 af.nl.ht_322  eu.es.tl_332 af.lg.ca_222
  0x0f031311, 0x1064250c, 0x5321050b, 0x3f000d0d,   // et.nl.lv_653 eu.lg.lt_543  fr.jw.ht_542 cs.af.un_540
  0x01172955, 0x2d1b2512, 0x212b1aee, 0x3f640604,   // sl.sr.en_442 eu.tr.sk_654  tl.vi.jw_422 de.lg.af_332
  // [ac30]
  0x100704ee, 0x1a536b0c, 0x271f2104, 0x03006402,   // ru.bg.be_422 ceb.ht.tl_543  jw.cy.gd_332 lg.nl.un_220
  0x0b0a1fa0, 0x1f182a02, 0x066b13ee, 0x07190b12,   // cy.pt.es_322 mt.ga.cy_222  et.ceb.de_422 es.gl.it_654
  0x29170d0b, 0x170c23a0, 0x3f130112, 0x12040813,   // cs.sr.sl_542 ca.sv.sr_322  en.et.af_654 no.fi.hu_665
  0x03201207, 0x033f1aa9, 0x5300060b, 0x0c171602,   // hu.sq.nl_432 tl.af.nl_544  de.ht.un_520 hr.sr.sv_222
  // [ac40]
  0x21252704, 0x2500272b, 0x2700252b, 0x0800071a,   // gd.eu.jw_332 gd.eu.un_980  eu.gd.un_980 bg.uk.un_760
  0x212504af, 0x04202b07, 0x051153a0, 0x2500271b,   // fi.eu.jw_655 vi.sq.fi_432  ht.ro.fr_322 gd.eu.un_770
  0x1c2728a7, 0x12092907, 0x25001807, 0x25211808,   // sw.gd.id_532 sl.pl.hu_432  ga.eu.un_420 ga.jw.eu_443
  0x552a210e, 0x08020660, 0x6b002704, 0x271a6b07,   // jw.mt.rw_555 de.da.no_664  gd.ceb.un_320 ceb.tl.gd_432
  // [ac50]
  0x070e060c, 0x13001b0d, 0x2d2928a4, 0x0c060304,   // de.is.it_543 tr.et.un_540  sw.sl.sk_433 nl.de.sv_332
  0x0429090c, 0x281f6404, 0x28002513, 0x10280a02,   // pl.sl.fi_543 lg.cy.sw_332  eu.sw.un_650 pt.sw.lt_222
  0x271904a6, 0x07051fad, 0x2a000204, 0x1901530c,   // fi.gl.gd_521 cy.fr.it_643  da.mt.un_320 ht.en.gl_543
  0x0f6404ad, 0x1a0725ec, 0x2d092913, 0x010804a0,   // fi.lg.lv_643 eu.it.tl_644  sl.pl.sk_665 fi.no.en_322
  // [ac60]
  0x251827ec, 0x2d256408, 0x07042b0c, 0x0b190504,   // gd.ga.eu_644 lg.eu.sk_443  vi.fi.it_543 fr.gl.es_332
  0x04642512, 0x1b011902, 0x0f2d2504, 0x162d0d0b,   // eu.lg.fi_654 gl.en.tr_222  eu.sk.lv_332 cs.sk.hr_542
  0x09281bec, 0x20061109, 0x080c1ba9, 0x291353a7,   // tr.sw.pl_644 ro.de.sq_444  tr.sv.no_544 ht.et.sl_532
  0x080c3105, 0x160206a0, 0x04191f12, 0x0e311ba7,   // az.sv.no_333 de.da.hr_322  cy.gl.fi_654 tr.az.is_532
  // [ac70]
  0x170a0460, 0x2d090da9, 0x64000209, 0x04162d0c,   // ru.mk.sr_664 cs.pl.sk_544  da.lg.un_440 sk.hr.fi_543
  0x0c0b310c, 0x53052704, 0x041064a4, 0x292025a9,   // az.es.sv_543 gd.fr.ht_332  lg.lt.fi_433 eu.sq.sl_544
  0x182a02ee, 0x1b110aad, 0x2a2705ad, 0x05532007,   // da.mt.ga_422 pt.ro.tr_643  fr.gd.mt_643 sq.ht.fr_432
  0x252d0d07, 0x1b00041b, 0x310c1baf, 0x31000c0d,   // cs.sk.eu_432 fi.tr.un_770  tr.sv.az_655 sv.az.un_540
  // [ac80]
  0x12532812, 0x080c1b08, 0x0f0728ee, 0x0f000d13,   // sw.ht.hu_654 tr.sv.no_443  sw.it.lv_422 cs.lv.un_650
  0x0d090c07, 0x23311b12, 0x3f2a0712, 0x53006419,   // sv.pl.cs_432 tr.az.ca_654  it.mt.af_654 lg.ht.un_750
  0x1e05530e, 0x3f2a64a0, 0x120925ee, 0x0b1a0404,   // ht.fr.ms_555 lg.mt.af_322  eu.pl.hu_422 fi.tl.es_332
  0x130e0611, 0x0c201c0c, 0x0d131c0b, 0x13120c07,   // de.is.et_653 id.sq.sv_543  mr.bh.ne_542 sv.hu.et_432
  // [ac90]
  0x1f000402, 0x1e0413a7, 0x1f180911, 0x0a092da4,   // fi.cy.un_220 et.fi.ms_532  pl.ga.cy_653 sk.pl.pt_433
  0x08001b0c, 0x0f001b08, 0x080c1eec, 0x0d001905,   // tr.no.un_530 tr.lv.un_430  ms.sv.no_644 gl.cs.un_330
  0x021801a0, 0x09001c2b, 0x1a040c02, 0x0d0b19ee,   // en.ga.da_322 mr.hi.un_980  sv.fi.tl_222 gl.es.cs_422
  0x0f250208, 0x2d0d0fee, 0x27001604, 0x06231007,   // da.eu.lv_443 lv.cs.sk_422  hr.gd.un_320 lt.ca.de_432
  // [aca0]
  0x1917160d, 0x1a0f1ba4, 0x2a003109, 0x1b001a1b,   // hr.sr.gl_554 tr.lv.tl_433  az.mt.un_440 tl.tr.un_770
  0x0a190e0b, 0x032908a0, 0x103f01a0, 0x103f0302,   // is.gl.pt_542 no.sl.nl_322  en.af.lt_322 nl.af.lt_222
  0x1e1c1fa0, 0x2b2a1ca0, 0x0c000222, 0x09002b04,   // cy.id.ms_322 id.mt.vi_322  da.sv.un_870 vi.pl.un_320
  0x2a000918, 0x29232b07, 0x641b6ba0, 0x1b1a6b0b,   // pl.mt.un_740 vi.ca.sl_432  ceb.tr.lg_322 ceb.tl.tr_542
  // [acb0]
  0x07000902, 0x281a6b04, 0x2100270d, 0x10001a12,   // pl.it.un_220 ceb.tl.sw_332  gd.jw.un_540 tl.lt.un_640
  0x1a000809, 0x0c060205, 0x012321a4, 0x3f031f08,   // no.tl.un_440 da.de.sv_333  jw.ca.en_433 cy.nl.af_443
  0x07551a0b, 0x256b55ad, 0x53000704, 0x6b255311,   // tl.rw.it_542 rw.ceb.eu_643  it.ht.un_320 ht.eu.ceb_653
  0x55080cad, 0x190a0511, 0x0c002708, 0x16532504,   // sv.no.rw_643 fr.pt.gl_653  gd.sv.un_430 eu.ht.hr_332
  // [acc0]
  0x6e003f2b, 0x010d11a7, 0x3f6e0812, 0x10201ea0,   // af.blu.un_980 ro.cs.en_532  no.blu.af_654 ms.sq.lt_322
  0x19271860, 0x18211c04, 0x2564555a, 0x53002512,   // ga.gd.gl_664 id.jw.ga_332  rw.lg.eu_553 eu.ht.un_640
  0x052718ec, 0x6e052314, 0x091a550c, 0x07001a08,   // ga.gd.fr_644 ca.fr.blu_666  rw.tl.pl_543 tl.it.un_430
  0x2b290a5a, 0x55106405, 0x25130408, 0x311b3f0d,   // pt.sl.vi_553 lg.lt.rw_333  fi.et.eu_443 af.tr.az_554
  // [acd0]
  0x1e1c2807, 0x1300280d, 0x27051807, 0x04641b0d,   // sw.id.ms_432 sw.et.un_540  ga.fr.gd_432 tr.lg.fi_554
  0x2b081ea4, 0x27002814, 0x11000622, 0x06213f0c,   // ms.no.vi_433 sw.gd.un_660  de.ro.un_870 af.jw.de_543
  0x6e000107, 0x12080c0c, 0x1b063107, 0x211e05a9,   // en.blu.un_420 sv.no.hu_543  az.de.tr_432 fr.ms.jw_544
  0x551c21a0, 0x2d00200b, 0x07111f02, 0x033f25a9,   // jw.id.rw_322 sq.sk.un_520  cy.ro.it_222 eu.af.nl_544
  // [ace0]
  0x190a0dec, 0x040c1f12, 0x07041711, 0x17081014,   // cs.pt.gl_644 cy.sv.fi_654  sr.ru.bg_653 be.uk.sr_666
  0x0c0e080d, 0x2a061b55, 0x06000e1a, 0x3f251fad,   // no.is.sv_554 tr.de.mt_442  is.de.un_760 cy.eu.af_643
  0x0127180c, 0x0e000c0e, 0x1b001f0c, 0x21080ca0,   // ga.gd.en_543 sv.is.un_550  cy.tr.un_530 sv.no.jw_322
  0x272b3fac, 0x556420ad, 0x21182704, 0x2a0227a0,   // af.vi.gd_632 sq.lg.rw_643  gd.ga.jw_332 gd.da.mt_322
  // [acf0]
  0x0c001f12, 0x0b200c04, 0x0f160c04, 0x08005314,   // cy.sv.un_640 sv.sq.es_332  sv.hr.lv_332 ht.no.un_660
  0x0c121bad, 0x1f216404, 0x190b1109, 0x130c0414,   // tr.hu.sv_643 lg.jw.cy_332  ro.es.gl_444 fi.sv.et_666
  0x09002d05, 0x181b0e07, 0x201f1b12, 0x64001f21,   // sk.pl.un_330 is.tr.ga_432  tr.cy.sq_654 cy.lg.un_860
  0x0e1f0107, 0x28642908, 0x19640aee, 0x0c6b0e04,   // en.cy.is_432 sl.lg.sw_443  pt.lg.gl_422 is.ceb.sv_332
  // [ad00]
  0x1c292aa7, 0x0800281a, 0x11050102, 0x2a1c25a0,   // mt.sl.id_532 sw.no.un_760  en.fr.ro_222 eu.id.mt_322
  0x271321a4, 0x280518a4, 0x09132a11, 0x17002b0d,   // jw.et.gd_433 ga.fr.sw_433  mt.et.pl_653 vi.sr.un_540
  0x2d083fa0, 0x13030807, 0x0f001f0d, 0x3f002305,   // af.no.sk_322 no.nl.et_432  cy.lv.un_540 ca.af.un_330
  0x291655a0, 0x256b23a0, 0x2900230e, 0x55642808,   // rw.hr.sl_322 ca.ceb.eu_322  ca.sl.un_550 sw.lg.rw_443
  // [ad10]
  0x2b0a1007, 0x291c21a4, 0x18041311, 0x29000805,   // lt.pt.vi_432 jw.id.sl_433  et.fi.ga_653 no.sl.un_330
  0x041a6b0d, 0x25556b60, 0x6b645507, 0x286410ec,   // ceb.tl.fi_554 ceb.rw.eu_664  rw.lg.ceb_432 lt.lg.sw_644
  0x0d112da0, 0x01270802, 0x190802a7, 0x282a1aad,   // sk.ro.cs_322 no.gd.en_222  da.no.gl_532 tl.mt.sw_643
  0x192113ee, 0x0d040ca0, 0x046e13a0, 0x0d292104,   // et.jw.gl_422 sv.fi.cs_322  et.blu.fi_322 jw.sl.cs_332
  // [ad20]
  0x531f05a0, 0x04172107, 0x17556455, 0x0a0810a4,   // fr.cy.ht_322 jw.sr.fi_432  lg.rw.sr_442 be.uk.mk_433
  0x280b1ca4, 0x0c003111, 0x6b005513, 0x6b04280c,   // id.es.sw_433 az.sv.un_630  rw.ceb.un_650 sw.fi.ceb_543
  0x25285504, 0x13556baf, 0x55211112, 0x1a286b07,   // rw.sw.eu_332 ceb.rw.et_655  ro.jw.rw_654 ceb.sw.tl_432
  0x550b12ee, 0x192a070b, 0x120a2304, 0x21045308,   // hu.es.rw_422 it.mt.gl_542  ca.pt.hu_332 ht.fi.jw_443
  // [ad30]
  0x533f2811, 0x041a16a4, 0x0a081155, 0x0a2519a4,   // sw.af.ht_653 hr.tl.fi_433  ro.uk.mk_442 gl.eu.pt_433
  0x530912ee, 0x1c095504, 0x0c2029a0, 0x6400280b,   // hu.pl.ht_422 rw.pl.id_332  sl.sq.sv_322 sw.lg.un_520
  0x18003f04, 0x211c3f07, 0x216e1a09, 0x121f1308,   // af.ga.un_320 af.id.jw_432  tl.blu.jw_444 et.cy.hu_443
  0x29001018, 0x13251213, 0x273f12a6, 0x281f09ee,   // lt.sl.un_740 hu.eu.et_665  hu.af.gd_521 pl.cy.sw_422
  // [ad40]
  0x252001a0, 0x1f002a18, 0x122a1f0c, 0x1c003f09,   // en.sq.eu_322 mt.cy.un_740  cy.mt.hu_543 af.id.un_440
  0x3f021fad, 0x3f060314, 0x1c001a09, 0x202a25ad,   // cy.da.af_643 nl.de.af_666  tl.id.un_440 eu.mt.sq_643
  0x13042804, 0x2a062812, 0x201112ac, 0x10070a13,   // sw.fi.et_332 sw.de.mt_654  hu.ro.sq_632 mk.bg.be_665
  0x2d1312ad, 0x213f6ba4, 0x09001022, 0x131123ec,   // hu.et.sk_643 ceb.af.jw_433  lt.pl.un_870 ca.ro.et_644
  // [ad50]
  0x10000923, 0x1f0208a0, 0x1a062108, 0x29091602,   // pl.lt.un_880 no.da.cy_322  jw.de.tl_443 hr.pl.sl_222
  0x050e1b12, 0x1b202aa0, 0x16292807, 0x206e0112,   // tr.is.fr_654 mt.sq.tr_322  sw.sl.hr_432 en.blu.sq_654
  0x2a1e1c08, 0x0c0e0255, 0x0e040ba0, 0x1a00090b,   // id.ms.mt_443 da.is.sv_442  es.fi.is_322 pl.tl.un_520
  0x0e290908, 0x0a101705, 0x2000130c, 0x0e00081a,   // pl.sl.is_443 sr.be.mk_333  et.sq.un_530 no.is.un_760
  // [ad60]
  0x0e0c1e05, 0x211b1a05, 0x12200713, 0x050725a0,   // ms.sv.is_333 tl.tr.jw_333  it.sq.hu_665 eu.it.fr_322
  0x201b0605, 0x211e020c, 0x20280ead, 0x08000f12,   // de.tr.sq_333 da.ms.jw_543  is.sw.sq_643 lv.no.un_640
  0x6b6423a7, 0x03020ca0, 0x64250608, 0x04020c0e,   // ca.lg.ceb_532 sv.da.nl_322  de.eu.lg_443 sv.da.fi_555
  0x641955a4, 0x271f010c, 0x6b002713, 0x31531b02,   // rw.gl.lg_433 en.cy.gd_543  gd.ceb.un_650 tr.ht.az_222
  // [ad70]
  0x080e0c12, 0x230b08a4, 0x0a080ead, 0x6b1b5504,   // sv.is.no_654 no.es.ca_433  is.no.pt_643 rw.tr.ceb_332
  0x31002507, 0x092d0da9, 0x55002109, 0x130a550c,   // eu.az.un_420 cs.sk.pl_544  jw.rw.un_440 rw.pt.et_543
  0x29080ca0, 0x1f002322, 0x1f0419a0, 0x23080c04,   // sv.no.sl_322 ca.cy.un_870  gl.fi.cy_322 sv.no.ca_332
  0x080c0ea4, 0x0e1f060c, 0x531a10a0, 0x0f212ba0,   // is.sv.no_433 de.cy.is_543  lt.tl.ht_322 vi.jw.lv_322
  // [ad80]
  0x12250aad, 0x010d0902, 0x271f06ec, 0x272d0da7,   // pt.eu.hu_643 pl.cs.en_222  de.cy.gd_644 cs.sk.gd_532
  0x08230e11, 0x27080ea0, 0x031f0508, 0x28001b0d,   // is.ca.no_653 is.no.gd_322  fr.cy.nl_443 tr.sw.un_540
  0x1e1b28ad, 0x31000805, 0x0c083fa4, 0x23000904,   // sw.tr.ms_643 no.az.un_330  af.no.sv_433 pl.ca.un_320
  0x0900230b, 0x041b1311, 0x0c025509, 0x2a000f04,   // ca.pl.un_520 et.tr.fi_653  rw.da.sv_444 lv.mt.un_320
  // [ad90]
  0x19000e12, 0x55002122, 0x13006402, 0x531f12ee,   // is.gl.un_640 jw.rw.un_870  lg.et.un_220 hu.cy.ht_422
  0x13080ca0, 0x0b1f07ec, 0x010c10a0, 0x0d2d0904,   // sv.no.et_322 it.cy.es_644  lt.sv.en_322 pl.sk.cs_332
  0x02122507, 0x28550260, 0x04031b02, 0x016b0904,   // eu.hu.da_432 da.rw.sw_664  tr.nl.fi_222 pl.ceb.en_332
  0x0e080c12, 0x120b10a0, 0x04070813, 0x01001305,   // sv.no.is_654 lt.es.hu_322  uk.bg.ru_665 et.en.un_330
  // [ada0]
  0x31282aa0, 0x64550aa4, 0x16001008, 0x20251b04,   // mt.sw.az_322 pt.rw.lg_433  lt.hr.un_430 tr.eu.sq_332
  0x08023f0c, 0x0f0a29ee, 0x05002311, 0x2100030c,   // af.da.no_543 sl.pt.lv_422  ca.fr.un_630 nl.jw.un_530
  0x55532808, 0x553f64a4, 0x11081009, 0x162910a4,   // sw.ht.rw_443 lg.af.rw_433  be.uk.ro_444 lt.sl.hr_433
  0x11052da0, 0x2b002704, 0x29090d05, 0x64000d12,   // sk.fr.ro_322 gd.vi.un_320  cs.pl.sl_333 cs.lg.un_640
  // [adb0]
  0x06080cee, 0x033f0608, 0x1b002520, 0x272d55af,   // sv.no.de_422 de.af.nl_443  eu.tr.un_850 rw.sk.gd_655
  0x030b010c, 0x03533f11, 0x230d53a4, 0x010553ee,   // en.es.nl_543 af.ht.nl_653  ht.cs.ca_433 ht.fr.en_422
  0x233f53ad, 0x126b2da0, 0x552053ad, 0x052753a0,   // ht.af.ca_643 sk.ceb.hu_322  ht.sq.rw_643 ht.gd.fr_322
  0x53233fad, 0x182305ee, 0x0b1225a4, 0x05532313,   // af.ca.ht_643 fr.ca.ga_422  eu.hu.es_433 ca.ht.fr_665
  // [adc0]
  0x2d180d11, 0x130e04ee, 0x53003f1a, 0x182d0d0c,   // cs.ga.sk_653 fi.is.et_422  af.ht.un_760 cs.sk.ga_543
  0x102904a4, 0x27070b13, 0x2d000d2b, 0x13311ca0,   // fi.sl.lt_433 es.it.gd_665  cs.sk.un_980 id.az.et_322
  0x0511010c, 0x030c06a4, 0x2d0d18af, 0x070f01a0,   // en.ro.fr_543 de.sv.nl_433  ga.cs.sk_655 en.lv.it_322
  0x1900060d, 0x551f28a0, 0x6b1a08a0, 0x2b533fee,   // de.gl.un_540 sw.cy.rw_322  no.tl.ceb_322 af.ht.vi_422
  // [add0]
  0x3f005334, 0x230119a0, 0x1f001e09, 0x04121bad,   // ht.af.un_A80 gl.en.ca_322  ms.cy.un_440 tr.hu.fi_643
  0x3f190aec, 0x03533f12, 0x230a1cee, 0x18000d21,   // pt.gl.af_644 af.ht.nl_654  id.pt.ca_422 cs.ga.un_860
  0x20000534, 0x17161f0e, 0x100f250c, 0x0a2308a0,   // fr.sq.un_A80 cy.hr.sr_555  eu.lv.lt_543 no.ca.pt_322
  0x230a0807, 0x230f0608, 0x18002d22, 0x1e1c0902,   // no.pt.ca_432 de.lv.ca_443  sk.ga.un_870 pl.id.ms_222
  // [ade0]
  0x101304ad, 0x18000d13, 0x11171607, 0x64091a55,   // fi.et.lt_643 cs.ga.un_650  hr.sr.ro_432 tl.pl.lg_442
  0x080c105a, 0x10011f12, 0x09001220, 0x1900060e,   // lt.sv.no_553 cy.en.lt_654  hu.pl.un_850 de.gl.un_550
  0x6b005309, 0x07000212, 0x23251907, 0x0b00250d,   // ht.ceb.un_440 da.it.un_640  gl.eu.ca_432 eu.es.un_540
  0x0b0a0da0, 0x031125ad, 0x3f136eee, 0x0d001812,   // cs.pt.es_322 eu.ro.nl_643  blu.et.af_422 ga.cs.un_640
  // [adf0]
  0x0c0811ee, 0x1f190b08, 0x11050204, 0x1f020c07,   // ro.no.sv_422 es.gl.cy_443  da.fr.ro_332 sv.da.cy_432
  0x0c1f190c, 0x0a1b110c, 0x100417ee, 0x27556404,   // gl.cy.sv_543 ro.tr.pt_543  sr.ru.be_422 lg.rw.gd_332
  0x6b1a1309, 0x0f11250d, 0x55001b20, 0x2a1220ad,   // et.tl.ceb_444 eu.ro.lv_554  tr.rw.un_850 sq.hu.mt_643
  0x1a6b5505, 0x13002907, 0x0811255a, 0x13070402,   // rw.ceb.tl_333 sl.et.un_420  eu.ro.no_553 fi.it.et_222
  // [ae00]
  0x1704070b, 0x1600550c, 0x020c3fee, 0x0e290307,   // bg.ru.sr_542 rw.hr.un_530  af.sv.da_422 nl.sl.is_432
  0x120c2a0c, 0x202a1212, 0x29132aee, 0x080417ec,   // mt.sv.hu_543 hu.mt.sq_654  mt.et.sl_422 sr.ru.uk_644
  0x033f29a0, 0x0e0d1605, 0x02000e13, 0x0d1e2d04,   // sl.af.nl_322 hr.cs.is_333  is.da.un_650 sk.ms.cs_332
  0x1b00060b, 0x17255304, 0x08131007, 0x1f5325ad,   // de.tr.un_520 ht.eu.sr_332  lt.et.no_432 eu.ht.cy_643
  // [ae10]
  0x1e271caf, 0x13272107, 0x6b1f275a, 0x27552807,   // id.gd.ms_655 jw.gd.et_432  gd.cy.ceb_553 sw.rw.gd_432
  0x2b6b53a0, 0x6e08020c, 0x1a18270c, 0x106e200c,   // ht.ceb.vi_322 da.no.blu_543  gd.ga.tl_543 sq.blu.lt_543
  0x025325a4, 0x0c251aa7, 0x102120a9, 0x27181c12,   // eu.ht.da_433 tl.eu.sv_532  sq.jw.lt_544 id.ga.gd_654
  0x0400050e, 0x09006e0e, 0x01311b0b, 0x0f190b07,   // fr.fi.un_550 blu.pl.un_550  tr.az.en_542 es.gl.lv_432
  // [ae20]
  0x1f002721, 0x2b006e22, 0x2b2004ee, 0x10290dad,   // gd.cy.un_860 blu.vi.un_870  fi.sq.vi_422 cs.sl.lt_643
  0x29272b12, 0x18271f04, 0x07641f11, 0x101711af,   // vi.gd.sl_654 cy.gd.ga_332  cy.lg.it_653 ro.sr.be_655
  0x0b1007ee, 0x18270507, 0x2d000b02, 0x1f00530e,   // it.lt.es_422 fr.gd.ga_432  es.sk.un_220 ht.cy.un_550
  0x211005a9, 0x2b1f2708, 0x033f2b0c, 0x10000f2a,   // fr.lt.jw_544 gd.cy.vi_443  vi.af.nl_543 lv.lt.un_970
  // [ae30]
  0x1f001a1b, 0x180401af, 0x251f2708, 0x211c2714,   // tl.cy.un_770 en.fi.ga_655  gd.cy.eu_443 gd.id.jw_666
  0x2a000905, 0x0b051a55, 0x536e1f08, 0x0f210304,   // pl.mt.un_330 tl.fr.es_442  cy.blu.ht_443 nl.jw.lv_332
  0x07640555, 0x23296e0d, 0x232511a0, 0x1000200d,   // fr.lg.it_442 blu.sl.ca_554  ro.eu.ca_322 sq.lt.un_540
  0x1c3f0312, 0x0500211a, 0x233f0304, 0x183f0504,   // nl.af.id_654 jw.fr.un_760  nl.af.ca_332 fr.af.ga_332
  // [ae40]
  0x193f0a07, 0x11051f07, 0x0f000d04, 0x13120b04,   // pt.af.gl_432 cy.fr.ro_432  cs.lv.un_320 es.hu.et_332
  0x06002313, 0x1f1e2712, 0x55211a11, 0x64202804,   // ca.de.un_650 gd.ms.cy_654  tl.jw.rw_653 sw.sq.lg_332
  0x1b0e3108, 0x06030da7, 0x1b3113a0, 0x31000e04,   // az.is.tr_443 cs.nl.de_532  et.az.tr_322 is.az.un_320
  0x0e131bee, 0x211b310c, 0x19311ba9, 0x2a001602,   // tr.et.is_422 az.tr.jw_543  tr.az.gl_544 hr.mt.un_220
  // [ae50]
  0x2d000a02, 0x040231ee, 0x310e1baf, 0x0e1b3108,   // pt.sk.un_220 az.da.fi_422  tr.is.az_655 az.tr.is_443
  0x216b13ad, 0x28080fad, 0x060c07a7, 0x20001309,   // et.ceb.jw_643 lv.no.sw_643  it.sv.de_532 et.sq.un_440
  0x11060d0c, 0x033f2aa0, 0x030c0da0, 0x2a2004a4,   // cs.de.ro_543 mt.af.nl_322  cs.sv.nl_322 fi.sq.mt_433
  0x1700080b, 0x200825a7, 0x0400190b, 0x1b311ca4,   // uk.sr.un_520 eu.no.sq_532  gl.fi.un_520 id.az.tr_433
  // [ae60]
  0x6b000505, 0x12200607, 0x6b1b0107, 0x04201055,   // fr.ceb.un_330 de.sq.hu_432  en.tr.ceb_432 lt.sq.fi_442
  0x04130111, 0x3f2a0307, 0x19001307, 0x2a05130c,   // en.et.fi_653 nl.mt.af_432  et.gl.un_420 et.fr.mt_543
  0x1c641eee, 0x07101702, 0x27002a0c, 0x0d002b07,   // ms.lg.id_422 sr.be.bg_222  mt.gd.un_530 vi.cs.un_420
  0x16000d19, 0x0e001f09, 0x285503a4, 0x04000307,   // cs.hr.un_750 cy.is.un_440  nl.rw.sw_433 nl.fi.un_420
  // [ae70]
  0x13036b09, 0x1e1c04ec, 0x6b041aa9, 0x1300030e,   // ceb.nl.et_444 fi.id.ms_644  tl.fi.ceb_544 nl.et.un_550
  0x05001002, 0x6b211c13, 0x1c041e12, 0x133f1811,   // lt.fr.un_220 id.jw.ceb_665  ms.fi.id_654 ga.af.et_653
  0x551b310c, 0x11002812, 0x2a2103ad, 0x21131a0c,   // az.tr.rw_543 sw.ro.un_640  nl.jw.mt_643 tl.et.jw_543
  0x09002502, 0x230b0512, 0x1f00211a, 0x1a1c1e07,   // eu.pl.un_220 fr.es.ca_654  jw.cy.un_760 ms.id.tl_432
  // [ae80]
  0x03002a14, 0x3f060304, 0x06080c05, 0x04081f11,   // mt.nl.un_660 nl.de.af_332  sv.no.de_333 cy.no.fi_653
  0x1a1f2104, 0x190b03a4, 0x06041312, 0x10000c05,   // jw.cy.tl_332 nl.es.gl_433  et.fi.de_654 sv.lt.un_330
  0x3f001e12, 0x1a031309, 0x033f0408, 0x0c0807a7,   // ms.af.un_640 et.nl.tl_444  fi.af.nl_443 it.no.sv_532
  0x02033fee, 0x3f00040d, 0x04100aa4, 0x103f0f07,   // af.nl.da_422 fi.af.un_540  mk.be.ru_433 lv.af.lt_432
  // [ae90]
  0x1a1e1c09, 0x19002121, 0x09081605, 0x062053a0,   // id.ms.tl_444 jw.gl.un_860  hr.no.pl_333 ht.sq.de_322
  0x1a000414, 0x3f0309ee, 0x06005504, 0x310b23ee,   // fi.tl.un_660 pl.nl.af_422  rw.de.un_320 ca.es.az_422
  0x2b1a1805, 0x20002914, 0x2a1b1107, 0x2a000a1a,   // ga.tl.vi_333 sl.sq.un_660  ro.tr.mt_432 pt.mt.un_760
  0x1f161204, 0x12030605, 0x1011080c, 0x0400281a,   // hu.hr.cy_332 de.nl.hu_333  uk.ro.be_543 sw.fi.un_760
  // [aea0]
  0x03060807, 0x290c06ee, 0x013f030b, 0x033f1e12,   // no.de.nl_432 de.sv.sl_422  nl.af.en_542 ms.af.nl_654
  0x18272112, 0x2d1625a0, 0x0b2955ac, 0x07081113,   // jw.gd.ga_654 eu.hr.sk_322  rw.sl.es_632 ro.uk.bg_665
  0x04080e0b, 0x0e1b31ec, 0x2564120d, 0x06002013,   // is.no.fi_542 az.tr.is_644  hu.lg.eu_554 sq.de.un_650
  0x1e001b04, 0x55211aad, 0x28000412, 0x08100908,   // tr.ms.un_320 tl.jw.rw_643  fi.sw.un_640 pl.lt.no_443
  // [aeb0]
  0x10001e05, 0x0d292dec, 0x06001221, 0x2d002307,   // ms.lt.un_330 sk.sl.cs_644  hu.de.un_860 ca.sk.un_420
  0x12550da0, 0x212b1f12, 0x6b3f01a6, 0x0c0e0802,   // cs.rw.hu_322 cy.vi.jw_654  en.af.ceb_521 no.is.sv_222
  0x210e1c0c, 0x080212a9, 0x0e0120ee, 0x2d171614,   // id.is.jw_543 hu.da.no_544  sq.en.is_422 hr.sr.sk_666
  0x311b2009, 0x023f08ee, 0x1700280c, 0x2d130da0,   // sq.tr.az_444 no.af.da_422  sw.sr.un_530 cs.et.sk_322
  // [aec0]
  0x1707280c, 0x063f1205, 0x27182ba0, 0x17162811,   // sw.it.sr_543 hu.af.de_333  vi.ga.gd_322 sw.hr.sr_653
  0x050d19a0, 0x16180705, 0x27002113, 0x04251a0b,   // gl.cs.fr_322 it.ga.hr_333  jw.gd.un_650 tl.eu.fi_542
  0x13001205, 0x25171655, 0x29000707, 0x1317165a,   // hu.et.un_330 hr.sr.eu_442  it.sl.un_420 hr.sr.et_553
  0x05212807, 0x171107af, 0x190b18a9, 0x27181f55,   // sw.jw.fr_432 it.ro.sr_655  ga.es.gl_544 cy.ga.gd_442
  // [aed0]
  0x10170f04, 0x0a071013, 0x10000c07, 0x0c1217a7,   // lv.sr.lt_332 be.bg.mk_665  sv.lt.un_420 sr.hu.sv_532
  0x020608a6, 0x0c0e1fad, 0x121716ee, 0x1c642807,   // no.de.da_521 cy.is.sv_643  hr.sr.hu_422 sw.lg.id_432
  0x021629a4, 0x281809ec, 0x0e002008, 0x64296b0c,   // sl.hr.da_433 pl.ga.sw_644  sq.is.un_430 ceb.sl.lg_543
  0x0d091307, 0x551e1c05, 0x0b1e55a0, 0x11081008,   // bh.hi.ne_432 id.ms.rw_333  rw.ms.es_322 be.uk.ro_443
  // [aee0]
  0x042d0cee, 0x190b180c, 0x0b190a12, 0x31002302,   // sv.sk.fi_422 ga.es.gl_543  pt.gl.es_654 ca.az.un_220
  0x1328550c, 0x0e0c05a4, 0x6b2d0dee, 0x23122004,   // rw.sw.et_543 fr.sv.is_433  cs.sk.ceb_422 sq.hu.ca_332
  0x1064040c, 0x296e6b04, 0x1f061907, 0x0302050c,   // fi.lg.lt_543 ceb.blu.sl_332  gl.de.cy_432 fr.da.nl_543
  0x1f2d0d05, 0x2d0d090b, 0x0f0b10a4, 0x2d1025a4,   // cs.sk.cy_333 pl.cs.sk_542  lt.es.lv_433 eu.lt.sk_433
  // [aef0]
  0x53002907, 0x09556405, 0x1f000e0c, 0x082a1804,   // sl.ht.un_420 lg.rw.pl_333  is.cy.un_530 ga.mt.no_332
  0x080c1ca0, 0x091a1fa9, 0x061123a9, 0x0711170e,   // id.sv.no_322 cy.tl.pl_544  ca.ro.de_544 sr.ro.bg_555
  0x64000b09, 0x55282112, 0x130c0e02, 0x53001a05,   // es.lg.un_440 jw.sw.rw_654  is.sv.et_222 tl.ht.un_330
  0x29006408, 0x2000020c, 0x06250304, 0x080e0c0c,   // lg.sl.un_430 da.sq.un_530  nl.eu.de_332 sv.is.no_543
  // [af00]
  0x23132008, 0x080a10ee, 0x6b1f1255, 0x08295307,   // sq.et.ca_443 be.mk.uk_422  hu.cy.ceb_442 ht.sl.no_432
  0x212a1fa7, 0x3f1f2160, 0x19280eee, 0x030c06a9,   // cy.mt.jw_532 jw.cy.af_664  is.sw.gl_422 de.sv.nl_544
  0x12211f0c, 0x05000d07, 0x16102d02, 0x02031fac,   // cy.jw.hu_543 cs.fr.un_420  sk.lt.hr_222 cy.nl.da_632
  0x121f2107, 0x18000e04, 0x53030607, 0x036b0aa0,   // jw.cy.hu_432 is.ga.un_320  de.nl.ht_432 pt.ceb.nl_322
  // [af10]
  0x06120807, 0x010b19ad, 0x21126bad, 0x05006b0d,   // no.hu.de_432 gl.es.en_643  ceb.hu.jw_643 ceb.fr.un_540
  0x0c00530c, 0x3f120ead, 0x0f230704, 0x16172d0c,   // ht.sv.un_530 is.hu.af_643  it.ca.lv_332 sk.sr.hr_543
  0x0c1f12a4, 0x0e180ba0, 0x64551b04, 0x1f296ea4,   // hu.cy.sv_433 es.ga.is_322  tr.rw.lg_332 blu.sl.cy_433
  0x0c1b2d08, 0x311b55ec, 0x0b06110c, 0x55642814,   // sk.tr.sv_443 rw.tr.az_644  ro.de.es_543 sw.lg.rw_666
  // [af20]
  0x16030612, 0x081007a9, 0x116455ad, 0x6e0f05a7,   // de.nl.hr_654 bg.be.uk_544  rw.lg.ro_643 fr.lv.blu_532
  0x1e645511, 0x07081013, 0x020e0604, 0x0a1110a4,   // rw.lg.ms_653 be.uk.bg_665  de.is.da_332 lt.ro.pt_433
  0x232d0d14, 0x160812ee, 0x030c0e07, 0x642555a7,   // cs.sk.ca_666 hu.no.hr_422  is.sv.nl_432 rw.eu.lg_532
  0x0f046402, 0x08111f12, 0x6e00252b, 0x6b011107,   // lg.fi.lv_222 cy.ro.no_654  eu.blu.un_980 ro.en.ceb_432
  // [af30]
  0x2b6e2508, 0x1f0823ee, 0x0f2325a4, 0x2500532b,   // eu.blu.vi_443 ca.no.cy_422  eu.ca.lv_433 ht.eu.un_980
  0x1c0c02a7, 0x051753a0, 0x232b1faf, 0x12530104,   // da.sv.id_532 ht.sr.fr_322  cy.vi.ca_655 en.ht.hu_332
  0x163f1f07, 0x25001f13, 0x17311004, 0x11006e08,   // cy.af.hr_432 cy.eu.un_650  lt.az.sr_332 blu.ro.un_430
  0x2b6e1107, 0x6b532105, 0x311a2d11, 0x2b6e1114,   // ro.blu.vi_432 jw.ht.ceb_333  sk.tl.az_653 ro.blu.vi_666
  // [af40]
  0x190a230c, 0x55206412, 0x161a060c, 0x04236e04,   // ca.pt.gl_543 lg.sq.rw_654  de.tl.hr_543 blu.ca.fi_332
  0x16000b04, 0x101a6b13, 0x25005308, 0x1700100e,   // es.hr.un_320 ceb.tl.lt_665  ht.eu.un_430 be.sr.un_550
  0x16090d07, 0x640b5502, 0x1806035a, 0x05180702,   // cs.pl.hr_432 rw.es.lg_222  nl.de.ga_553 it.ga.fr_222
  0x07005507, 0x2a1b0907, 0x16310813, 0x10091a09,   // rw.it.un_420 pl.tr.mt_432  no.az.hr_665 tl.pl.lt_444
  // [af50]
  0x190a0702, 0x20000d02, 0x042725a0, 0x2a100f08,   // it.pt.gl_222 cs.sq.un_220  eu.gd.fi_322 lv.lt.mt_443
  0x2a0f04a4, 0x17041607, 0x08002805, 0x161303ad,   // fi.lv.mt_433 hr.fi.sr_432  sw.no.un_330 nl.et.hr_643
  0x1a0b19a4, 0x04162905, 0x55253114, 0x04161007,   // gl.es.tl_433 sl.hr.fi_333  az.eu.rw_666 lt.hr.fi_432
  0x552820a4, 0x17000604, 0x256455ad, 0x111707a4,   // sq.sw.rw_433 de.sr.un_320  rw.lg.eu_643 bg.sr.ro_433
  // [af60]
  0x03042aad, 0x27000702, 0x17002a08, 0x06645507,   // mt.fi.nl_643 it.gd.un_220  mt.sr.un_430 rw.lg.de_432
  0x160d2007, 0x03002a0c, 0x1a0f550c, 0x1b1f08af,   // sq.cs.hr_432 mt.nl.un_530  rw.lv.tl_543 no.cy.tr_655
  0x0e1b6402, 0x200c230b, 0x64205511, 0x252055a9,   // lg.tr.is_222 ca.sv.sq_542  rw.sq.lg_653 rw.sq.eu_544
  0x1f00070e, 0x311155a4, 0x1119550c, 0x1e6b6ea6,   // it.cy.un_550 rw.ro.az_433  rw.gl.ro_543 blu.ceb.ms_521
  // [af70]
  0x0e0d2104, 0x28215507, 0x07190a08, 0x17110807,   // jw.cs.is_332 rw.jw.sw_432  pt.gl.it_443 uk.ro.sr_432
  0x271c18a0, 0x1a005507, 0x09165507, 0x041107ec,   // ga.id.gd_322 rw.tl.un_420  rw.hr.pl_432 bg.ro.ru_644
  0x0b191b12, 0x0a002102, 0x0c3f0308, 0x1828270c,   // tr.gl.es_654 jw.pt.un_220  nl.af.sv_443 gd.sw.ga_543
  0x0a081009, 0x021f01a4, 0x04001b0c, 0x080c1307,   // be.uk.mk_444 en.cy.da_433  tr.fi.un_530 et.sv.no_432
  // [af80]
  0x1a285508, 0x2a001311, 0x1c13250b, 0x3f130304,   // rw.sw.tl_443 et.mt.un_630  eu.et.id_542 nl.et.af_332
  0x190b1bee, 0x2b08010c, 0x1b190a02, 0x11551ba4,   // tr.es.gl_422 en.no.vi_543  pt.gl.tr_222 tr.rw.ro_433
  0x065513ad, 0x10250555, 0x04006b08, 0x6e005512,   // et.rw.de_643 fr.eu.lt_442  ceb.fi.un_430 rw.blu.un_640
  0x13285511, 0x0a0755a0, 0x0e0612a7, 0x080c55af,   // rw.sw.et_653 rw.it.pt_322  hu.de.is_532 rw.sv.no_655
  // [af90]
  0x0c5508ee, 0x19251b07, 0x1e000f02, 0x1e1c5514,   // no.rw.sv_422 tr.eu.gl_432  lv.ms.un_220 rw.id.ms_666
  0x1104170e, 0x0f291008, 0x1a09100c, 0x1b311f04,   // sr.ru.ro_555 lt.sl.lv_443  lt.pl.tl_543 cy.az.tr_332
  0x25000709, 0x051b11a0, 0x100a0755, 0x02001109,   // it.eu.un_440 ro.tr.fr_322  bg.mk.be_442 ro.da.un_440
  0x53092a55, 0x016b2a04, 0x2d0929a4, 0x06120ca4,   // mt.pl.ht_442 mt.ceb.en_332  sl.pl.sk_433 sv.hu.de_433
  // [afa0]
  0x170d160d, 0x01005307, 0x075321a6, 0x09002a07,   // hr.cs.sr_554 ht.en.un_420  jw.ht.it_521 mt.pl.un_420
  0x531f2a0c, 0x0f0931a4, 0x1b1a53ad, 0x110b2d02,   // mt.cy.ht_543 az.pl.lv_433  ht.tl.tr_643 sk.es.ro_222
  0x29091a0c, 0x21070907, 0x1b000b0d, 0x0f210904,   // tl.pl.sl_543 pl.it.jw_432  es.tr.un_540 pl.jw.lv_332
  0x0b2519a4, 0x17120ca7, 0x532a09a9, 0x271825ee,   // gl.eu.es_433 sv.hu.sr_532  pl.mt.ht_544 eu.ga.gd_422
  // [afb0]
  0x190b0605, 0x092a530c, 0x2a2008a7, 0x100f285a,   // de.es.gl_333 ht.mt.pl_543  no.sq.mt_532 sw.lv.lt_553
  0x0f042a07, 0x1e1c23a4, 0x110b0408, 0x04192a55,   // mt.fi.lv_432 ca.id.ms_433  fi.es.ro_443 mt.gl.fi_442
  0x09002307, 0x17040714, 0x29090fad, 0x1c2a0c02,   // ca.pl.un_420 bg.ru.sr_666  lv.pl.sl_643 sv.mt.id_222
  0x236b0907, 0x251a0bee, 0x2d0a1205, 0x0528040d,   // pl.ceb.ca_432 es.tl.eu_422  hu.pt.sk_333 fi.sw.fr_554
  // [afc0]
  0x23001e02, 0x09002802, 0x04000a2a, 0x012309ee,   // ms.ca.un_220 sw.pl.un_220  pt.fi.un_970 pl.ca.en_422
  0x640405a7, 0x10033f13, 0x23270509, 0x082a2312,   // fr.fi.lg_532 af.nl.lt_665  fr.gd.ca_444 ca.mt.no_654
  0x182305a7, 0x080c2002, 0x0e1602a0, 0x09002304,   // fr.ca.ga_532 sq.sv.no_222  da.hr.is_322 ca.pl.un_320
  0x3f0327ec, 0x180501a4, 0x05130408, 0x280127ee,   // gd.nl.af_644 en.fr.ga_433  fi.et.fr_443 gd.en.sw_422
  // [afd0]
  0x1f2a2311, 0x17162aac, 0x64055504, 0x25002908,   // ca.mt.cy_653 mt.hr.sr_632  rw.fr.lg_332 sl.eu.un_430
  0x2d0d3f0b, 0x2825550e, 0x3f0f060d, 0x0c001207,   // af.cs.sk_542 rw.eu.sw_555  de.lv.af_554 hu.sv.un_420
  0x096455a4, 0x19312aee, 0x060418ad, 0x03076407,   // rw.lg.pl_433 mt.az.gl_422  ga.fi.de_643 lg.it.nl_432
  0x2a051807, 0x09002a21, 0x0f005505, 0x64550907,   // ga.fr.mt_432 mt.pl.un_860  rw.lv.un_330 pl.rw.lg_432
  // [afe0]
  0x05250704, 0x2a002d05, 0x0800160d, 0x17160ba0,   // it.eu.fr_332 sk.mt.un_330  hr.no.un_540 es.hr.sr_322
  0x0c0812ee, 0x0e000b05, 0x02110804, 0x160810ad,   // hu.no.sv_422 es.is.un_330  no.ro.da_332 lt.no.hr_643
  0x0b001f14, 0x10130cac, 0x08003104, 0x070a08ee,   // cy.es.un_660 sv.et.lt_632  az.no.un_320 uk.mk.bg_422
  0x06311b12, 0x27002502, 0x04171012, 0x1200182a,   // tr.az.de_654 eu.gd.un_220  be.sr.ru_654 ar.ur.un_970
  // [aff0]
  0x18000613, 0x6e056ba0, 0x291f16a4, 0x310d29a0,   // de.ga.un_650 ceb.fr.blu_322  hr.cy.sl_433 sl.cs.az_322
  0x13001b12, 0x12000f0d, 0x6b0308a6, 0x0f033f02,   // tr.et.un_640 lv.hu.un_540  no.nl.ceb_521 af.nl.lv_222
  0x103f030b, 0x3f016b02, 0x08030607, 0x2a1801a0,   // nl.af.lt_542 ceb.en.af_222  de.nl.no_432 en.ga.mt_322
  0x0a07170d, 0x0c000421, 0x0e0310a0, 0x042d0d02,   // sr.bg.mk_554 fi.sv.un_860  lt.nl.is_322 cs.sk.fi_222

  // [b000]
  0x0c0812a7, 0x0f291704, 0x11182713, 0x191105a0,   // hu.no.sv_532 sr.sl.lv_332  gd.ga.ro_665 fr.ro.gl_322
  0x53001008, 0x181e1c60, 0x030c3f04, 0x0c000420,   // lt.ht.un_430 id.ms.ga_664  af.sv.nl_332 fi.sv.un_850
  0x2827180e, 0x060c04ad, 0x3f09100c, 0x03080e08,   // ga.gd.sw_555 fi.sv.de_643  lt.pl.af_543 is.no.nl_443
  0x0c002905, 0x3f032da4, 0x170f2902, 0x16000321,   // sl.sv.un_330 sk.nl.af_433  sl.lv.sr_222 nl.hr.un_860
  // [b010]
  0x16110313, 0x2a292d07, 0x191f12a0, 0x2a556411,   // nl.ro.hr_665 sk.sl.mt_432  hu.cy.gl_322 lg.rw.mt_653
  0x130c12af, 0x64552013, 0x10110855, 0x100a1709,   // hu.sv.et_655 sq.rw.lg_665  no.ro.lt_442 sr.mk.be_444
  0x12002a22, 0x07231002, 0x17162da7, 0x0e08130c,   // mt.hu.un_870 lt.ca.it_222  sk.hr.sr_532 et.no.is_543
  0x120e1004, 0x110b25a4, 0x060103ee, 0x0c0e12a6,   // lt.is.hu_332 eu.es.ro_433  nl.en.de_422 hu.is.sv_521
  // [b020]
  0x170f16a7, 0x6b0106a4, 0x07551f07, 0x012a1207,   // hr.lv.sr_532 de.en.ceb_433  cy.rw.it_432 hu.mt.en_432
  0x02120508, 0x03001613, 0x29092dee, 0x093f2da0,   // fr.hu.da_443 hr.nl.un_650  sk.pl.sl_422 sk.af.pl_322
  0x1603170c, 0x08001b18, 0x10230e13, 0x21112313,   // sr.nl.hr_543 tr.no.un_740  is.ca.lt_665 ca.ro.jw_665
  0x25032a07, 0x0a001b08, 0x133f1b0c, 0x2500210e,   // mt.nl.eu_432 tr.pt.un_430  tr.af.et_543 jw.eu.un_550
  // [b030]
  0x112910a7, 0x17163fa4, 0x2d2a090c, 0x11055308,   // lt.sl.ro_532 af.hr.sr_433  pl.mt.sk_543 ht.fr.ro_443
  0x64000512, 0x08120ca6, 0x0c3f12a7, 0x25000905,   // fr.lg.un_640 sv.hu.no_521  hu.af.sv_532 pl.eu.un_330
  0x29000302, 0x0a08045a, 0x040506a6, 0x1800100c,   // nl.sl.un_220 ru.uk.mk_553  de.fr.fi_521 lt.ga.un_530
  0x0c021707, 0x230b250c, 0x020c060c, 0x0c002107,   // sr.da.sv_432 eu.es.ca_543  de.sv.da_543 jw.sv.un_420
  // [b040]
  0x016b03ad, 0x05080260, 0x1c0e1e08, 0x29230e0c,   // nl.ceb.en_643 da.no.fr_664  ms.is.id_443 is.ca.sl_543
  0x133f1b07, 0x041328a4, 0x2d00200c, 0x021318a0,   // tr.af.et_432 sw.et.fi_433  sq.sk.un_530 ga.et.da_322
  0x02080c12, 0x0d0e2dec, 0x0c123fa0, 0x061208ee,   // sv.no.da_654 sk.is.cs_644  af.hu.sv_322 no.hu.de_422
  0x3f070205, 0x180e13ad, 0x13180409, 0x1200130c,   // da.it.af_333 et.is.ga_643  fi.ga.et_444 et.hu.un_530
  // [b050]
  0x25110b02, 0x13002804, 0x13180811, 0x64271807,   // es.ro.eu_222 sw.et.un_320  no.ga.et_653 ga.gd.lg_432
  0x27011b04, 0x1c552155, 0x09040d02, 0x0953010c,   // tr.en.gd_332 jw.rw.id_442  cs.fi.pl_222 en.ht.pl_543
  0x231306a6, 0x55001019, 0x08171002, 0x531a5505,   // de.et.ca_521 lt.rw.un_750  be.sr.uk_222 rw.tl.ht_333
  0x2d160911, 0x0d002521, 0x55000905, 0x286e21ad,   // pl.hr.sk_653 eu.cs.un_860  pl.rw.un_330 jw.blu.sw_643
  // [b060]
  0x1c0812a0, 0x096b1609, 0x0f000d0b, 0x53091004,   // hu.no.id_322 hr.ceb.pl_444  cs.lv.un_520 lt.pl.ht_332
  0x0f210408, 0x1b105307, 0x1f0955ee, 0x311b0e12,   // fi.jw.lv_443 ht.lt.tr_432  rw.pl.cy_422 is.tr.az_654
  0x09001018, 0x18000512, 0x0712290c, 0x050c010b,   // lt.pl.un_740 fr.ga.un_640  sl.hu.it_543 en.sv.fr_542
  0x311b0ea9, 0x05182708, 0x2a006b02, 0x0e311faf,   // is.tr.az_544 gd.ga.fr_443  ceb.mt.un_220 cy.az.is_655
  // [b070]
  0x0416170c, 0x0b082105, 0x2d0d1909, 0x0d1b29a4,   // sr.hr.fi_543 jw.no.es_333  gl.cs.sk_444 sl.tr.cs_433
  0x05075309, 0x532109a0, 0x1c2a21a0, 0x06286ba4,   // ht.it.fr_444 pl.jw.ht_322  jw.mt.id_322 ceb.sw.de_433
  0x1f311b13, 0x120929ee, 0x02061304, 0x19052807,   // tr.az.cy_665 sl.pl.hu_422  et.de.da_332 sw.fr.gl_432
  0x271f31a7, 0x1b312aa4, 0x2a0813ee, 0x0c083107,   // az.cy.gd_532 mt.az.tr_433  et.no.mt_422 az.no.sv_432
  // [b080]
  0x1b0313ad, 0x0806020e, 0x0e1008a0, 0x0c130607,   // et.nl.tr_643 da.de.no_555  no.lt.is_322 de.et.sv_432
  0x0a00100c, 0x2d1c21a0, 0x1b0831ec, 0x111006ac,   // be.mk.un_530 jw.id.sk_322  az.no.tr_644 de.lt.ro_632
  0x6e000707, 0x252010ee, 0x18311ba9, 0x31081308,   // it.blu.un_420 lt.sq.eu_422  tr.az.ga_544 et.no.az_443
  0x2d00101b, 0x0e1f13a6, 0x0a0704a6, 0x13001007,   // lt.sk.un_770 et.cy.is_521  ru.bg.mk_521 lt.et.un_420
  // [b090]
  0x2b002308, 0x080203a4, 0x13000202, 0x0320020c,   // ca.vi.un_430 nl.da.no_433  da.et.un_220 da.sq.nl_543
  0x2d0710ac, 0x3f6b020c, 0x23041304, 0x08102d07,   // lt.it.sk_632 da.ceb.af_543  et.fi.ca_332 sk.lt.no_432
  0x19182b07, 0x0d2d1019, 0x2d000e0d, 0x191e1c02,   // vi.ga.gl_432 lt.sk.cs_765  is.sk.un_540 id.ms.gl_222
  0x2d17165a, 0x53002523, 0x133f200c, 0x100f1708,   // hr.sr.sk_553 eu.ht.un_880  sq.af.et_543 sr.lv.lt_443
  // [b0a0]
  0x010c16a0, 0x280607a0, 0x076b02a0, 0x2a171605,   // hr.sv.en_322 it.de.sw_322  da.ceb.it_322 hr.sr.mt_333
  0x2800071a, 0x100c09ee, 0x0b005505, 0x1c2a25a0,   // it.sw.un_760 pl.sv.lt_422  rw.es.un_330 eu.mt.id_322
  0x251b09ee, 0x1f000f20, 0x2100291a, 0x06031b0b,   // pl.tr.eu_422 lv.cy.un_850  sl.jw.un_760 tr.nl.de_542
  0x2900202a, 0x1f002d08, 0x16171007, 0x3f1b10a0,   // sq.sl.un_970 sk.cy.un_430  lt.sr.hr_432 lt.tr.af_322
  // [b0b0]
  0x21282da0, 0x01280a07, 0x02001b14, 0x31060908,   // sk.sw.jw_322 pt.sw.en_432  tr.da.un_660 pl.de.az_443
  0x53256bad, 0x11121f07, 0x3f1f0914, 0x172b5302,   // ceb.eu.ht_643 cy.hu.ro_432  pl.cy.af_666 ht.vi.sr_222
  0x2b0b1a02, 0x12041b07, 0x03001f08, 0x17100f0c,   // tl.es.vi_222 tr.fi.hu_432  cy.nl.un_430 lv.lt.sr_543
  0x100a2da0, 0x04132a12, 0x643f2905, 0x25230307,   // sk.pt.lt_322 mt.et.fi_654  sl.af.lg_333 nl.ca.eu_432
  // [b0c0]
  0x2503090b, 0x01092a04, 0x2508180b, 0x290d16ee,   // pl.nl.eu_542 mt.pl.en_332  ga.no.eu_542 hr.cs.sl_422
  0x1a1f0d07, 0x033f0102, 0x2a0c06ee, 0x090d08ee,   // cs.cy.tl_432 en.af.nl_222  de.sv.mt_422 no.cs.pl_422
  0x0c080e0c, 0x03000c05, 0x291e1ca4, 0x55212012,   // is.no.sv_543 sv.nl.un_330  id.ms.sl_433 sq.jw.rw_654
  0x31000204, 0x1f1a250c, 0x0e0c1f0c, 0x171e2504,   // da.az.un_320 eu.tl.cy_543  cy.sv.is_543 eu.ms.sr_332
  // [b0d0]
  0x090d1704, 0x1a551b13, 0x0b003109, 0x2a0b0107,   // sr.cs.pl_332 tr.rw.tl_665  az.es.un_440 en.es.mt_432
  0x64001f12, 0x190631ee, 0x290f1004, 0x281b0804,   // cy.lg.un_640 az.de.gl_422  lt.lv.sl_332 no.tr.sw_332
  0x2a17165a, 0x1e1c1609, 0x230b08a0, 0x052713a0,   // hr.sr.mt_553 hr.id.ms_444  no.es.ca_322 et.gd.fr_322
  0x31131ba4, 0x166b1a05, 0x29000412, 0x182713a4,   // tr.et.az_433 tl.ceb.hr_333  fi.sl.un_640 et.gd.ga_433
  // [b0e0]
  0x02311b55, 0x18131f12, 0x1b001014, 0x09100402,   // tr.az.da_442 cy.et.ga_654  lt.tr.un_660 fi.lt.pl_222
  0x23002a1a, 0x17165505, 0x17166bec, 0x13040204,   // mt.ca.un_760 rw.hr.sr_333  ceb.hr.sr_644 da.fi.et_332
  0x0e211204, 0x0a3f1a02, 0x166b0e07, 0x0d0210ee,   // hu.jw.is_332 tl.af.pt_222  is.ceb.hr_432 lt.da.cs_422
  0x0e121302, 0x1a002814, 0x1a162904, 0x2b2816a0,   // et.hu.is_222 sw.tl.un_660  sl.hr.tl_332 hr.sw.vi_322
  // [b0f0]
  0x021312a9, 0x21311b0e, 0x0e002712, 0x02311bad,   // hu.et.da_544 tr.az.jw_555  gd.is.un_640 tr.az.da_643
  0x070b010c, 0x3f030213, 0x171628ad, 0x201a1fa0,   // en.es.it_543 da.nl.af_665  sw.hr.sr_643 cy.tl.sq_322
  0x6e000a08, 0x2b00070d, 0x0b0a0eec, 0x211e0e55,   // pt.blu.un_430 it.vi.un_540  is.pt.es_644 is.ms.jw_442
  0x12131ca0, 0x53002004, 0x190a2505, 0x060e1704,   // id.et.hu_322 sq.ht.un_320  eu.pt.gl_333 sr.is.de_332
  // [b100]
  0x28002002, 0x1a171608, 0x170c2ba0, 0x18000e29,   // sq.sw.un_220 hr.sr.tl_443  vi.sv.sr_322 is.ga.un_960
  0x08001a0d, 0x0c000305, 0x092b0f07, 0x0a232b07,   // tl.no.un_540 nl.sv.un_330  lv.vi.pl_432 vi.ca.pt_432
  0x1a27180e, 0x53002b05, 0x08292007, 0x1f001812,   // ga.gd.tl_555 vi.ht.un_330  sq.sl.no_432 ga.cy.un_640
  0x6e532b13, 0x0b060107, 0x53206ea4, 0x250802ee,   // vi.ht.blu_665 en.de.es_432  blu.sq.ht_433 da.no.eu_422
  // [b110]
  0x180a0811, 0x0a1b6e12, 0x0206080c, 0x02010604,   // no.pt.ga_653 blu.tr.pt_654  no.de.da_543 de.en.da_332
  0x1c271860, 0x311b6e04, 0x19181f0c, 0x160f04a0,   // ga.gd.id_664 blu.tr.az_332  cy.ga.gl_543 fi.lv.hr_322
  0x031a3f04, 0x012507ee, 0x290e0d11, 0x6b1a1b12,   // af.tl.nl_332 it.eu.en_422  cs.is.sl_653 tr.tl.ceb_654
  0x03276b04, 0x061a6b0c, 0x0a0c29af, 0x0c0204ee,   // ceb.gd.nl_332 ceb.tl.de_543  sl.sv.pt_655 fi.da.sv_422
  // [b120]
  0x251a64a9, 0x6453060b, 0x0a00292c, 0x1c081ea0,   // lg.tl.eu_544 de.ht.lg_542  sl.pt.un_990 ms.no.id_322
  0x03130602, 0x171008a7, 0x061629ee, 0x020c28a9,   // de.et.nl_222 uk.be.sr_532  sl.hr.de_422 sw.sv.da_544
  0x08020f05, 0x20170ca0, 0x210c64a0, 0x250631a4,   // lv.da.no_333 sv.sr.sq_322  lg.sv.jw_322 az.de.eu_433
  0x04280f05, 0x110c035a, 0x25001b0c, 0x1a216b14,   // lv.sw.fi_333 nl.sv.ro_553  tr.eu.un_530 ceb.jw.tl_666
  // [b130]
  0x2a033f02, 0x1b0f31a0, 0x0c010808, 0x6b012b04,   // af.nl.mt_222 az.lv.tr_322  no.en.sv_443 vi.en.ceb_332
  0x04080c08, 0x02000421, 0x0c0e040c, 0x100a1107,   // sv.no.fi_443 fi.da.un_860  fi.is.sv_543 ro.mk.be_432
  0x0708105a, 0x0c311bac, 0x0e256ba0, 0x2d0c64a7,   // be.uk.bg_553 tr.az.sv_632  ceb.eu.is_322 lg.sv.sk_532
  0x0b0a27a4, 0x170f0ca6, 0x0e0c1f07, 0x100d1b07,   // gd.pt.es_433 sv.lv.sr_521  cy.sv.is_432 tr.cs.lt_432
  // [b140]
  0x06082a07, 0x3f0e03a0, 0x0501100c, 0x201a21a0,   // mt.no.de_432 nl.is.af_322  lt.en.fr_543 jw.tl.sq_322
  0x130b0a05, 0x0c0806af, 0x0c00280e, 0x231320a0,   // pt.es.et_333 de.no.sv_655  sw.sv.un_550 sq.et.ca_322
  0x0c130aa0, 0x55006b0e, 0x190a0704, 0x04201fa9,   // pt.et.sv_322 ceb.rw.un_550  it.pt.gl_332 cy.sq.fi_544
  0x3f121a08, 0x082a0e11, 0x04081f04, 0x276b1a5a,   // tl.hu.af_443 is.mt.no_653  cy.no.fi_332 tl.ceb.gd_553
  // [b150]
  0x11310704, 0x0c5321a0, 0x291320af, 0x16311b04,   // it.az.ro_332 jw.ht.sv_322  sq.et.sl_655 tr.az.hr_332
  0x05080209, 0x531f0bee, 0x0c0e0455, 0x08211207,   // da.no.fr_444 es.cy.ht_422  fi.is.sv_442 hu.jw.no_432
  0x04132812, 0x08120c04, 0x31002705, 0x290205ee,   // sw.et.fi_654 sv.hu.no_332  gd.az.un_330 fr.da.sl_422
  0x111901a0, 0x0c0806a4, 0x1b311107, 0x066404ee,   // en.gl.ro_322 de.no.sv_433  ro.az.tr_432 fi.lg.de_422
  // [b160]
  0x121a6b60, 0x20000307, 0x1f1c1ead, 0x160b6407,   // ceb.tl.hu_664 nl.sq.un_420  ms.id.cy_643 lg.es.hr_432
  0x021203a0, 0x060304a4, 0x060c6bec, 0x6b1e1ca0,   // nl.hu.da_322 fi.nl.de_433  ceb.sv.de_644 id.ms.ceb_322
  0x1f1b0e0c, 0x1827110e, 0x08190a09, 0x0b232704,   // is.tr.cy_543 ro.gd.ga_555  pt.gl.no_444 gd.ca.es_332
  0x27000119, 0x3f1a02af, 0x210b1805, 0x0c1e210c,   // en.gd.un_750 da.tl.af_655  ga.es.jw_333 jw.ms.sv_543
  // [b170]
  0x29083f04, 0x0a0127a7, 0x1211010c, 0x182701af,   // af.no.sl_332 gd.en.pt_532  en.ro.hu_543 en.gd.ga_655
  0x0d003104, 0x053f03a4, 0x041308af, 0x1e6e2aa6,   // az.cs.un_320 nl.af.fr_433  no.et.fi_655 mt.blu.ms_521
  0x0c6423a0, 0x061801a4, 0x0a27180d, 0x040c08a7,   // ca.lg.sv_322 en.ga.de_433  ga.gd.pt_554 no.sv.fi_532
  0x0c1304a4, 0x21551fa0, 0x06005513, 0x0c04060e,   // fi.et.sv_433 cy.rw.jw_322  rw.de.un_650 de.fi.sv_555
  // [b180]
  0x0c0f0804, 0x0c0504a6, 0x196b01a0, 0x082701ec,   // no.lv.sv_332 fi.fr.sv_521  en.ceb.gl_322 en.gd.no_644
  0x0e190a09, 0x556e6404, 0x1b1a31a4, 0x211c0107,   // pt.gl.is_444 lg.blu.rw_332  az.tl.tr_433 en.id.jw_432
  0x1c000408, 0x180b2705, 0x0100271a, 0x3f0155a0,   // fi.id.un_430 gd.es.ga_333  gd.en.un_760 rw.en.af_322
  0x53232508, 0x201125a4, 0x043f1355, 0x08646b0c,   // eu.ca.ht_443 eu.ro.sq_433  et.af.fi_442 ceb.lg.no_543
  // [b190]
  0x21640107, 0x0f20530c, 0x0817115a, 0x53001b13,   // en.lg.jw_432 ht.sq.lv_543  ro.sr.uk_553 tr.ht.un_650
  0x212516ee, 0x1a000114, 0x6b1b53a9, 0x21111aad,   // hr.eu.jw_422 en.tl.un_660  ht.tr.ceb_544 tl.ro.jw_643
  0x121f01a4, 0x2a0253a0, 0x12080407, 0x25041207,   // en.cy.hu_433 ht.da.mt_322  fi.no.hu_432 hu.fi.eu_432
  0x081a6bee, 0x0a170807, 0x081f06ee, 0x0c0429ee,   // ceb.tl.no_422 uk.sr.mk_432  de.cy.no_422 sl.fi.sv_422
  // [b1a0]
  0x0e2d0daf, 0x3f000c18, 0x1b0c04a4, 0x2d0b0ead,   // cs.sk.is_655 sv.af.un_740  fi.sv.tr_433 is.es.sk_643
  0x29092d07, 0x1b642807, 0x1b0c2905, 0x311b0605,   // sk.pl.sl_432 sw.lg.tr_432  sl.sv.tr_333 de.tr.az_333
  0x07112312, 0x03001f21, 0x3f090ba0, 0x161f2da4,   // ca.ro.it_654 cy.nl.un_860  es.pl.af_322 sk.cy.hr_433
  0x0c2102ee, 0x08001808, 0x16121104, 0x11070aad,   // da.jw.sv_422 ga.no.un_430  ro.hu.hr_332 pt.it.ro_643
  // [b1b0]
  0x1f000e12, 0x21002313, 0x2d190aad, 0x04032a11,   // is.cy.un_640 ca.jw.un_650  pt.gl.sk_643 mt.nl.fi_653
  0x29041809, 0x0a212912, 0x55001109, 0x18190407,   // ga.fi.sl_444 sl.jw.pt_654  ro.rw.un_440 fi.gl.ga_432
  0x0e00640c, 0x01000b12, 0x6b6413ee, 0x21061bee,   // lg.is.un_530 es.en.un_640  et.lg.ceb_422 tr.de.jw_422
  0x1b0231a4, 0x0c1b020c, 0x0b0819ee, 0x0e1012a4,   // az.da.tr_433 da.tr.sv_543  gl.no.es_422 hu.lt.is_433
  // [b1c0]
  0x23003f05, 0x0e0413a7, 0x6e090708, 0x09103f55,   // af.ca.un_330 et.fi.is_532  it.pl.blu_443 af.lt.pl_442
  0x016b040c, 0x09030407, 0x1900170c, 0x31000e19,   // fi.ceb.en_543 fi.nl.pl_432  sr.gl.un_530 is.az.un_750
  0x21091055, 0x0c201602, 0x10170a02, 0x090d3fee,   // lt.pl.jw_442 hr.sq.sv_222  mk.sr.be_222 af.cs.pl_422
  0x2d120704, 0x07000913, 0x051b3102, 0x0f000b1a,   // it.hu.sk_332 pl.it.un_650  az.tr.fr_222 es.lv.un_760
  // [b1d0]
  0x53053faf, 0x25000212, 0x0c0f1207, 0x290f0da0,   // af.fr.ht_655 da.eu.un_640  hu.lv.sv_432 cs.lv.sl_322
  0x102d0ba7, 0x0b0310a4, 0x062d1007, 0x3f071060,   // es.sk.lt_532 lt.nl.es_433  lt.sk.de_432 lt.it.af_664
  0x02006b0d, 0x19250b07, 0x2d1912ec, 0x12192dad,   // ceb.da.un_540 es.eu.gl_432  hu.gl.sk_644 sk.gl.hu_643
  0x04070a0e, 0x0f001211, 0x06021207, 0x2d00190d,   // mk.bg.ru_555 hu.lv.un_630  hu.da.de_432 gl.sk.un_540
  // [b1e0]
  0x0d00050c, 0x2d190d12, 0x0d1905a6, 0x18001109,   // fr.cs.un_530 cs.gl.sk_654  fr.gl.cs_521 ro.ga.un_440
  0x2d1219ec, 0x6b1a2a12, 0x2a005307, 0x2a6b1a13,   // gl.hu.sk_644 mt.tl.ceb_654  ht.mt.un_420 tl.ceb.mt_665
  0x122d19ad, 0x1a2120a4, 0x192d12ad, 0x1a6e6b08,   // gl.sk.hu_643 sq.jw.tl_433  hu.sk.gl_643 ceb.blu.tl_443
  0x3f530405, 0x171213a0, 0x12000519, 0x3f0208ee,   // fi.ht.af_333 et.hu.sr_322  fr.hu.un_750 no.da.af_422
  // [b1f0]
  0x531f2aa0, 0x0c1b01a4, 0x05000a1a, 0x2a6b1a12,   // mt.cy.ht_322 en.tr.sv_433  pt.fr.un_760 tl.ceb.mt_654
  0x642516a9, 0x1b121704, 0x091a6b60, 0x0f1a1255,   // hr.eu.lg_544 sr.hu.tr_332  ceb.tl.pl_664 hu.tl.lv_442
  0x0d001a0c, 0x192d0a07, 0x060803ee, 0x041c1eee,   // tl.cs.un_530 pt.sk.gl_432  nl.no.de_422 ms.id.fi_422
  0x103f2aa0, 0x27001113, 0x076428a0, 0x6b1a2a09,   // mt.af.lt_322 ro.gd.un_650  sw.lg.it_322 mt.tl.ceb_444
  // [b200]
  0x17003f09, 0x120b04a4, 0x09000f09, 0x6e6b1a04,   // af.sr.un_440 fi.es.hu_433  lv.pl.un_440 tl.ceb.blu_332
  0x646e17a0, 0x1a6b2a0d, 0x120a25a4, 0x28000b08,   // sr.blu.lg_322 mt.ceb.tl_554  eu.pt.hu_433 es.sw.un_430
  0x0b235505, 0x020a0e13, 0x06531307, 0x10211104,   // rw.ca.es_333 is.pt.da_665  et.ht.de_432 ro.jw.lt_332
  0x0810070d, 0x081e0c05, 0x122d5304, 0x2a005323,   // bg.be.uk_554 sv.ms.no_333  ht.sk.hu_332 ht.mt.un_880
  // [b210]
  0x1f072102, 0x046b1aee, 0x0a21050b, 0x53230507,   // jw.it.cy_222 tl.ceb.fi_422  fr.jw.pt_542 fr.ca.ht_432
  0x01051fa7, 0x05000e09, 0x13001202, 0x1900051a,   // cy.fr.en_532 is.fr.un_440  hu.et.un_220 fr.gl.un_760
  0x0100051a, 0x23100eee, 0x6b230508, 0x531020a6,   // fr.en.un_760 is.lt.ca_422  fr.ca.ceb_443 sq.lt.ht_521
  0x066b0c08, 0x0c0e1805, 0x19120504, 0x6e3f01ee,   // sv.ceb.de_443 ga.is.sv_333  fr.hu.gl_332 en.af.blu_422
  // [b220]
  0x06230ca0, 0x2b1a01ee, 0x052312a4, 0x12000a11,   // sv.ca.de_322 en.tl.vi_422  hu.ca.fr_433 pt.hu.un_630
  0x0a002d1b, 0x0e000513, 0x190b05ac, 0x050e0f0c,   // sk.pt.un_770 fr.is.un_650  fr.es.gl_632 lv.is.fr_543
  0x060c0304, 0x21000514, 0x310f0c02, 0x0c3f0204,   // nl.sv.de_332 fr.jw.un_660  sv.lv.az_222 da.af.sv_332
  0x0e0a2d07, 0x2d003f08, 0x06000e12, 0x2b2d0dee,   // sk.pt.is_432 af.sk.un_430  is.de.un_640 cs.sk.vi_422
  // [b230]
  0x110b1805, 0x041828ee, 0x0b1f6404, 0x6b1a1209,   // ga.es.ro_333 sw.ga.fi_422  lg.cy.es_332 hu.tl.ceb_444
  0x271f19a0, 0x08130407, 0x17131608, 0x06311b02,   // gl.cy.gd_322 fi.et.no_432  hr.et.sr_443 tr.az.de_222
  0x12000a21, 0x1c04130c, 0x641e2809, 0x1e1c130c,   // pt.hu.un_860 et.fi.id_543  sw.ms.lg_444 et.id.ms_543
  0x050107ac, 0x2d051907, 0x060e13ee, 0x2b5520ee,   // it.en.fr_632 gl.fr.sk_432  et.is.de_422 sq.rw.vi_422
  // [b240]
  0x0c030807, 0x6b1a1308, 0x11230a13, 0x23115307,   // no.nl.sv_432 et.tl.ceb_443  pt.ca.ro_665 ht.ro.ca_432
  0x08190bad, 0x270102a0, 0x120519a6, 0x06001f2a,   // es.gl.no_643 da.en.gd_322  gl.fr.hu_521 cy.de.un_970
  0x6b5510a4, 0x0b0a19ad, 0x211a6b05, 0x64171660,   // lt.rw.ceb_433 gl.pt.es_643  ceb.tl.jw_333 hr.sr.lg_664
  0x230a0e07, 0x282125ac, 0x1100250d, 0x192d0508,   // is.pt.ca_432 eu.jw.sw_632  eu.ro.un_540 fr.sk.gl_443
  // [b250]
  0x6455110c, 0x0b1e1c5a, 0x12102aad, 0x646b07ac,   // ro.rw.lg_543 id.ms.es_553  mt.lt.hu_643 it.ceb.lg_632
  0x190a1ba4, 0x021923ad, 0x015525a0, 0x3f080ca7,   // tr.pt.gl_433 ca.gl.da_643  eu.rw.en_322 sv.no.af_532
  0x0a002122, 0x2864530c, 0x64230b08, 0x3f031ea0,   // jw.pt.un_870 ht.lg.sw_543  es.ca.lg_443 ms.nl.af_322
  0x0d1b2d55, 0x0d311b0c, 0x091729af, 0x31202aac,   // sk.tr.cs_442 tr.az.cs_543  sl.sr.pl_655 mt.sq.az_632
  // [b260]
  0x182a5502, 0x21001c22, 0x102301a4, 0x1f6b1104,   // rw.mt.ga_222 id.jw.un_870  en.ca.lt_433 ro.ceb.cy_332
  0x235525ad, 0x23002507, 0x53210fa9, 0x64115507,   // eu.rw.ca_643 eu.ca.un_420  lv.jw.ht_544 rw.ro.lg_432
  0x120d2dac, 0x080c0604, 0x0e550ba9, 0x110608ee,   // sk.cs.hu_632 de.sv.no_332  es.rw.is_544 no.de.ro_422
  0x3f080755, 0x0f100cec, 0x2d290f07, 0x116b28a7,   // it.no.af_442 sv.lt.lv_644  lv.sl.sk_432 sw.ceb.ro_532
  // [b270]
  0x0b1912a0, 0x16290f04, 0x2825110c, 0x03093fad,   // hu.gl.es_322 lv.sl.hr_332  ro.eu.sw_543 af.pl.nl_643
  0x2d001218, 0x0e002d05, 0x286453a9, 0x0b000502,   // hu.sk.un_740 sk.is.un_330  ht.lg.sw_544 fr.es.un_220
  0x0b0a19a6, 0x2d020d0c, 0x10170aec, 0x181225a7,   // gl.pt.es_521 cs.da.sk_543  mk.sr.be_644 eu.hu.ga_532
  0x1f080cec, 0x29213f5a, 0x0d5331a7, 0x2d050a02,   // sv.no.cy_644 af.jw.sl_553  az.ht.cs_532 pt.fr.sk_222
  // [b280]
  0x0a1205a0, 0x1700070c, 0x08271860, 0x08033faf,   // fr.hu.pt_322 bg.sr.un_530  ga.gd.no_664 af.nl.no_655
  0x041117a7, 0x2d0a05a9, 0x190b3105, 0x20070407,   // sr.ro.ru_532 fr.pt.sk_544  az.es.gl_333 fi.it.sq_432
  0x0b2305a4, 0x050a2da0, 0x18132707, 0x27131f02,   // fr.ca.es_433 sk.pt.fr_322  gd.et.ga_432 cy.et.gd_222
  0x04001604, 0x18082da0, 0x25001212, 0x10130413,   // hr.fi.un_320 sk.no.ga_322  hu.eu.un_640 fi.et.lt_665
  // [b290]
  0x0813645a, 0x0a281a08, 0x1f1828a0, 0x07001a2b,   // lg.et.no_553 tl.sw.pt_443  sw.ga.cy_322 tl.it.un_980
  0x1a0e64af, 0x13005511, 0x212a27a0, 0x13011aa4,   // lg.is.tl_655 rw.et.un_630  gd.mt.jw_322 tl.en.et_433
  0x20002119, 0x0a1007a4, 0x55001e29, 0x1a6b5507,   // jw.sq.un_750 bg.be.mk_433  ms.rw.un_960 rw.ceb.tl_432
  0x08001f05, 0x2a2728a6, 0x64001004, 0x64070ea7,   // cy.no.un_330 sw.gd.mt_521  lt.lg.un_320 is.it.lg_532
  // [b2a0]
  0x250b0a05, 0x1c0325a0, 0x0a230b08, 0x64551c11,   // pt.es.eu_333 eu.nl.id_322  es.ca.pt_443 id.rw.lg_653
  0x1200060d, 0x28552112, 0x2d0d1ea4, 0x160d0f07,   // de.hu.un_540 jw.rw.sw_654  ms.cs.sk_433 lv.cs.hr_432
  0x6455255a, 0x180501ee, 0x251164a7, 0x2a2720ad,   // eu.rw.lg_553 en.fr.ga_422  lg.ro.eu_532 sq.gd.mt_643
  0x12645508, 0x290d0955, 0x04132912, 0x17161ea0,   // rw.lg.hu_443 pl.cs.sl_442  sl.et.fi_654 ms.hr.sr_322
  // [b2b0]
  0x12002305, 0x210b0f55, 0x10001305, 0x201a03ad,   // ca.hu.un_330 lv.es.jw_442  et.lt.un_330 nl.tl.sq_643
  0x2d1f0c0c, 0x12101314, 0x20285504, 0x06081304,   // sv.cy.sk_543 et.lt.hu_666  rw.sw.sq_332 et.no.de_332
  0x0c1b5504, 0x311b0c0c, 0x2a2507ee, 0x310b1b0b,   // rw.tr.sv_332 sv.tr.az_543  it.eu.mt_422 tr.es.az_542
  0x21120aa4, 0x0e0b08a4, 0x171608a4, 0x31081fec,   // pt.hu.jw_433 no.es.is_433  no.hr.sr_433 cy.no.az_644
  // [b2c0]
  0x25080408, 0x05001212, 0x072009ec, 0x25001f19,   // fi.no.eu_443 hu.fr.un_640  pl.sq.it_644 cy.eu.un_750
  0x25002d0e, 0x190e2d0c, 0x2d081102, 0x0c250f08,   // sk.eu.un_550 sk.is.gl_543  ro.no.sk_222 lv.eu.sv_443
  0x0e002708, 0x080301a0, 0x08642807, 0x0f046404,   // gd.is.un_430 en.nl.no_322  sw.lg.no_432 lg.fi.lv_332
  0x2a001907, 0x27000c08, 0x070811a7, 0x21080204,   // gl.mt.un_420 sv.gd.un_430  ro.uk.bg_532 da.no.jw_332
  // [b2d0]
  0x641e28a0, 0x08072aac, 0x0c001202, 0x1f006b0d,   // sw.ms.lg_322 mt.it.no_632  hu.sv.un_220 ceb.cy.un_540
  0x0d160ca0, 0x1821200d, 0x13032aa0, 0x0f000402,   // sv.hr.cs_322 sq.jw.ga_554  mt.nl.et_322 fi.lv.un_220
  0x06530312, 0x080205a7, 0x0c2d0d08, 0x64001307,   // nl.ht.de_654 fr.da.no_532  cs.sk.sv_443 et.lg.un_420
  0x09100302, 0x1f003112, 0x2d0d1f14, 0x0e2a08a7,   // nl.lt.pl_222 az.cy.un_640  cy.cs.sk_666 no.mt.is_532
  // [b2e0]
  0x27000e02, 0x16552509, 0x1f00070c, 0x20552112,   // is.gd.un_220 eu.rw.hr_444  it.cy.un_530 jw.rw.sq_654
  0x06160308, 0x190b55a4, 0x200c0807, 0x160201a4,   // nl.hr.de_443 rw.es.gl_433  no.sv.sq_432 en.da.hr_433
  0x2d1128ad, 0x1907110c, 0x04082a0c, 0x2d103fa0,   // sw.ro.sk_643 ro.it.gl_543  mt.no.fi_543 af.lt.sk_322
  0x23532507, 0x556421a9, 0x080413ad, 0x1f1125a0,   // eu.ht.ca_432 jw.lg.rw_544  et.fi.no_643 eu.ro.cy_322
  // [b2f0]
  0x64001311, 0x09250fad, 0x03026404, 0x0412100c,   // et.lg.un_630 lv.eu.pl_643  lg.da.nl_332 lt.hu.fi_543
  0x03250f60, 0x071f27a9, 0x1a2164ad, 0x5510280c,   // lv.eu.nl_664 gd.cy.it_544  lg.jw.tl_643 sw.lt.rw_543
  0x0f005307, 0x5500250c, 0x09006b0d, 0x250b0f13,   // ht.lv.un_420 eu.rw.un_530  ceb.pl.un_540 lv.es.eu_665
  0x23001105, 0x2a130404, 0x010427a0, 0x04100ba7,   // ro.ca.un_330 fi.et.mt_332  gd.fi.en_322 es.lt.fi_532
  // [b300]
  0x31200a55, 0x132718ec, 0x090712a0, 0x111801a4,   // pt.sq.az_442 ga.gd.et_644  hu.it.pl_322 en.ga.ro_433
  0x181203a0, 0x3f1f09a9, 0x0b120502, 0x080f2da4,   // nl.hu.ga_322 pl.cy.af_544  fr.hu.es_222 sk.lv.no_433
  0x0e1204a7, 0x17003f08, 0x20032902, 0x18000d12,   // fi.hu.is_532 af.sr.un_430  sl.nl.sq_222 cs.ga.un_640
  0x09002114, 0x312964a0, 0x1c1a090c, 0x2a0764a7,   // jw.pl.un_660 lg.sl.az_322  pl.tl.id_543 lg.it.mt_532
  // [b310]
  0x1a09210b, 0x19001704, 0x0f000419, 0x1f002805,   // jw.pl.tl_542 sr.gl.un_320  fi.lv.un_750 sw.cy.un_330
  0x3f000702, 0x28001a19, 0x020107a0, 0x1c0904ad,   // it.af.un_220 tl.sw.un_750  it.en.da_322 fi.pl.id_643
  0x05000409, 0x04082013, 0x020408a4, 0x046e1312,   // fi.fr.un_440 sq.no.fi_665  no.fi.da_433 et.blu.fi_654
  0x0200040d, 0x105521a4, 0x6e1e1c0c, 0x20282111,   // fi.da.un_540 jw.rw.lt_433  id.ms.blu_543 jw.sw.sq_653
  // [b320]
  0x17086b07, 0x17200aee, 0x29002119, 0x1f6e1ea0,   // ceb.no.sr_432 pt.sq.sr_422  jw.sl.un_750 ms.blu.cy_322
  0x5523130c, 0x032008a4, 0x1b006e05, 0x11190a55,   // et.ca.rw_543 no.sq.nl_433  blu.tr.un_330 pt.gl.ro_442
  0x200e0208, 0x063f1b04, 0x6b1107a7, 0x041707ad,   // da.is.sq_443 tr.af.de_332  it.ro.ceb_532 bg.sr.ru_643
  0x12190e08, 0x25210b07, 0x64281ea0, 0x0a041104,   // is.gl.hu_443 es.jw.eu_432  ms.sw.lg_322 ro.ru.mk_332
  // [b330]
  0x1e1c2a02, 0x27001f23, 0x131a6b04, 0x1f006b23,   // mt.id.ms_222 cy.gd.un_880  ceb.tl.et_332 ceb.cy.un_880
  0x28645502, 0x02285504, 0x2528645a, 0x2113010c,   // rw.lg.sw_222 rw.sw.da_332  lg.sw.eu_553 en.et.jw_543
  0x19001f29, 0x0b0a1fec, 0x011918a0, 0x10001212,   // cy.gl.un_960 cy.pt.es_644  ga.gl.en_322 hu.lt.un_640
  0x0b081307, 0x641307ec, 0x21252d04, 0x531609a7,   // et.no.es_432 it.et.lg_644  sk.eu.jw_332 pl.hr.ht_532
  // [b340]
  0x55053fa4, 0x1800281a, 0x1f000921, 0x1e1c1fec,   // af.fr.rw_433 sw.ga.un_760  pl.cy.un_860 cy.id.ms_644
  0x1c5328a0, 0x0a1f2dad, 0x10115507, 0x17080705,   // sw.ht.id_322 sk.cy.pt_643  rw.ro.lt_432 bg.uk.sr_333
  0x0a23110d, 0x0d2d100b, 0x04252304, 0x051106a9,   // ro.ca.pt_554 lt.sk.cs_542  ca.eu.fi_332 de.ro.fr_544
  0x05131b04, 0x3f182704, 0x180327a4, 0x3f5305a6,   // tr.et.fr_332 gd.ga.af_332  gd.nl.ga_433 fr.ht.af_521
  // [b350]
  0x271f180c, 0x6b1b0904, 0x3f0d2da0, 0x181f2711,   // ga.cy.gd_543 pl.tr.ceb_332  sk.cs.af_322 gd.cy.ga_653
  0x641f10ee, 0x1f182711, 0x53021fa7, 0x07001c02,   // lt.cy.lg_422 gd.ga.cy_653  cy.da.ht_532 id.it.un_220
  0x063f07a0, 0x64271808, 0x271e18af, 0x1b005309,   // it.af.de_322 ga.gd.lg_443  ga.ms.gd_655 ht.tr.un_440
  0x03001311, 0x033f0604, 0x07000513, 0x0417070d,   // et.nl.un_630 de.af.nl_332  fr.it.un_650 bg.sr.ru_554
  // [b360]
  0x6b1f01ee, 0x03182712, 0x18000b02, 0x6b531a14,   // en.cy.ceb_422 gd.ga.nl_654  es.ga.un_220 tl.ht.ceb_666
  0x0a232707, 0x53001f1b, 0x061e0804, 0x1f6409a7,   // gd.ca.pt_432 cy.ht.un_770  no.ms.de_332 pl.lg.cy_532
  0x2a2d0712, 0x092d1109, 0x2a3f0714, 0x100407a7,   // it.sk.mt_654 ro.sk.pl_444  it.af.mt_666 bg.ru.be_532
  0x07002d20, 0x090d1ca7, 0x531a0ba0, 0x080410ac,   // sk.it.un_850 mr.ne.hi_532  es.tl.ht_322 be.ru.uk_632
  // [b370]
  0x13020ca0, 0x0c25100b, 0x19180b0e, 0x531008a0,   // sv.da.et_322 lt.eu.sv_542  es.ga.gl_555 no.lt.ht_322
  0x2d0b2805, 0x5321290c, 0x0e160208, 0x3f201ca0,   // sw.es.sk_333 sl.jw.ht_543  da.hr.is_443 id.sq.af_322
  0x1f001b09, 0x0c0604a0, 0x29000812, 0x53051fa0,   // tr.cy.un_440 fi.de.sv_322  no.sl.un_640 cy.fr.ht_322
  0x0f000202, 0x1f5323ad, 0x5300080d, 0x2a0523a9,   // da.lv.un_220 ca.ht.cy_643  no.ht.un_540 ca.fr.mt_544
  // [b380]
  0x06033f0b, 0x100a0404, 0x0f16550c, 0x21280a12,   // af.nl.de_542 ru.mk.be_332  rw.hr.lv_543 pt.sw.jw_654
  0x130408a4, 0x04002508, 0x6b3f130c, 0x28215312,   // no.fi.et_433 eu.fi.un_430  et.af.ceb_543 ht.jw.sw_654
  0x5300030d, 0x090b07ee, 0x2b1c64a0, 0x080913a4,   // nl.ht.un_540 it.es.pl_422  lg.id.vi_322 et.pl.no_433
  0x211827ad, 0x112701a4, 0x2d1013a7, 0x100e1308,   // gd.ga.jw_643 en.gd.ro_433  et.lt.sk_532 et.is.lt_443
  // [b390]
  0x53190b05, 0x02001007, 0x20120912, 0x28215304,   // es.gl.ht_333 lt.da.un_420  pl.hu.sq_654 ht.jw.sw_332
  0x290413a0, 0x11002311, 0x21642b55, 0x641b3102,   // et.fi.sl_322 ca.ro.un_630  vi.lg.jw_442 az.tr.lg_222
  0x642813af, 0x281955a4, 0x2a0413ec, 0x5513640c,   // et.sw.lg_655 rw.gl.sw_433  et.fi.mt_644 lg.et.rw_543
  0x1c21640c, 0x033f09af, 0x16001720, 0x11072a02,   // lg.jw.id_543 pl.af.nl_655  sr.hr.un_850 mt.it.ro_222
  // [b3a0]
  0x5300030c, 0x6427180c, 0x0a190bad, 0x25003113,   // nl.ht.un_530 ga.gd.lg_543  es.gl.pt_643 az.eu.un_650
  0x270c02ad, 0x270f5555, 0x1e1c0faf, 0x04132112,   // da.sv.gd_643 rw.lv.gd_442  lv.id.ms_655 jw.et.fi_654
  0x550a2105, 0x0a2319ad, 0x13002a13, 0x29176402,   // jw.pt.rw_333 gl.ca.pt_643  mt.et.un_650 lg.sr.sl_222
  0x64552860, 0x162004a9, 0x191304af, 0x03133faf,   // sw.rw.lg_664 fi.sq.hr_544  fi.et.gl_655 af.et.nl_655
  // [b3b0]
  0x0e0c0214, 0x05005508, 0x17001022, 0x1e0c13a7,   // da.sv.is_666 rw.fr.un_430  be.sr.un_870 et.sv.ms_532
  0x121b100c, 0x2d001207, 0x2a0e1004, 0x12200304,   // lt.tr.hu_543 hu.sk.un_420  lt.is.mt_332 nl.sq.hu_332
  0x181b0e04, 0x09020807, 0x55000c08, 0x1b640f12,   // is.tr.ga_332 no.da.pl_432  sv.rw.un_430 lv.lg.tr_654
  0x0b1210ee, 0x0f1b28a4, 0x0d0f0304, 0x010e0ba0,   // lt.hu.es_422 sw.tr.lv_433  nl.lv.cs_332 es.is.en_322
  // [b3c0]
  0x101b0fa7, 0x0f000b07, 0x311b28a9, 0x28000f23,   // lv.tr.lt_532 es.lv.un_420  sw.tr.az_544 lv.sw.un_880
  0x20230a12, 0x1e001202, 0x1a232108, 0x640f280c,   // pt.ca.sq_654 hu.ms.un_220  jw.ca.tl_443 sw.lv.lg_543
  0x64280faf, 0x55212512, 0x0b041005, 0x2d170f04,   // lv.sw.lg_655 eu.jw.rw_654  lt.fi.es_333 lv.sr.sk_332
  0x310f55af, 0x020c20a4, 0x05136404, 0x082a20ad,   // rw.lv.az_655 sq.sv.da_433  lg.et.fr_332 sq.mt.no_643
  // [b3d0]
  0x130208ac, 0x06040ca7, 0x080213ee, 0x13000619,   // no.da.et_632 sv.fi.de_532  et.da.no_422 de.et.un_750
  0x2164130c, 0x55640faf, 0x050e0804, 0x2d280fa4,   // et.lg.jw_543 lv.lg.rw_655  no.is.fr_332 lv.sw.sk_433
  0x2a001113, 0x05230a11, 0x03061308, 0x0f1b29a9,   // ro.mt.un_650 pt.ca.fr_653  et.de.nl_443 sl.tr.lv_544
  0x0f081007, 0x211b1e02, 0x64280fa0, 0x31001e13,   // lt.no.lv_432 ms.tr.jw_222  lv.sw.lg_322 ms.az.un_650
  // [b3e0]
  0x162917a6, 0x0111050c, 0x2d0d6ea7, 0x555325af,   // sr.sl.hr_521 fr.ro.en_543  blu.cs.sk_532 eu.ht.rw_655
  0x3f2053a0, 0x2827180b, 0x2d0f25ee, 0x13000812,   // ht.sq.af_322 ga.gd.sw_542  eu.lv.sk_422 no.et.un_640
  0x1f000a1a, 0x27000a22, 0x0313120b, 0x17136405,   // pt.cy.un_760 pt.gd.un_870  hu.et.nl_542 lg.et.sr_333
  0x23645555, 0x5531250c, 0x0f111307, 0x0c2d5555,   // rw.lg.ca_442 eu.az.rw_543  et.ro.lv_432 rw.sk.sv_442
  // [b3f0]
  0x182127ee, 0x110513a0, 0x2d00060c, 0x312a2004,   // gd.jw.ga_422 et.fr.ro_322  de.sk.un_530 sq.mt.az_332
  0x06132512, 0x081a2102, 0x052307a4, 0x21641311,   // eu.et.de_654 jw.tl.no_222  it.ca.fr_433 et.lg.jw_653
  0x21000723, 0x641b28a0, 0x1000290e, 0x1f1827ad,   // it.jw.un_880 sw.tr.lg_322  sl.lt.un_550 gd.ga.cy_643
  0x120a0707, 0x3f040309, 0x271b2104, 0x061204a4,   // it.pt.hu_432 nl.fi.af_444  jw.tr.gd_332 fi.hu.de_433

  // [b400]
  0x10292111, 0x1e002508, 0x311755ee, 0x190b0e09,   // jw.sl.lt_653 eu.ms.un_430  rw.sr.az_422 is.es.gl_444
  0x062312ee, 0x0b2319ee, 0x190a21a0, 0x0a122d0d,   // hu.ca.de_422 gl.ca.es_422  jw.pt.gl_322 sk.hu.pt_554
  0x04230aa0, 0x31251311, 0x091325a4, 0x1312040b,   // pt.ca.fi_322 et.eu.az_653  eu.et.pl_433 fi.hu.et_542
  0x13120408, 0x291b0f55, 0x1b1729a7, 0x11002b0c,   // fi.hu.et_443 lv.tr.sl_442  sl.sr.tr_532 vi.ro.un_530
  // [b410]
  0x060c2dee, 0x080711a9, 0x03291307, 0x131e1c09,   // sk.sv.de_422 ro.bg.uk_544  et.sl.nl_432 id.ms.et_444
  0x17071004, 0x1317160e, 0x641321ad, 0x1f000d02,   // be.bg.sr_332 hr.sr.et_555  jw.et.lg_643 cs.cy.un_220
  0x043f1a08, 0x060f0407, 0x01051908, 0x20086ea0,   // tl.af.fi_443 fi.lv.de_432  gl.fr.en_443 blu.no.sq_322
  0x1202080b, 0x6b130204, 0x2700100c, 0x11002702,   // no.da.hu_542 da.et.ceb_332  lt.gd.un_530 gd.ro.un_220
  // [b420]
  0x02002807, 0x04081308, 0x0f2904a0, 0x1b002013,   // sw.da.un_420 et.no.fi_443  fi.sl.lv_322 sq.tr.un_650
  0x0c270607, 0x0c130455, 0x27061ead, 0x531716a0,   // de.gd.sv_432 fi.et.sv_442  ms.de.gd_643 hr.sr.ht_322
  0x0c1b0407, 0x3f0103a9, 0x082a0c0c, 0x050c1305,   // fi.tr.sv_432 nl.en.af_544  sv.mt.no_543 et.sv.fr_333
  0x641e1c12, 0x0a230b60, 0x0c006b04, 0x2a180809,   // id.ms.lg_654 es.ca.pt_664  ceb.sv.un_320 no.ga.mt_444
  // [b430]
  0x11006409, 0x2a180107, 0x0c3f2904, 0x0600041a,   // lg.ro.un_440 en.ga.mt_432  sl.af.sv_332 fi.de.un_760
  0x0a001209, 0x09131ca0, 0x1a316ba4, 0x53081a08,   // hu.pt.un_440 id.et.pl_322  ceb.az.tl_433 tl.no.ht_443
  0x29080c07, 0x28182b07, 0x6b211aa7, 0x25190b55,   // sv.no.sl_432 vi.ga.sw_432  tl.jw.ceb_532 es.gl.eu_442
  0x1a532160, 0x53001a09, 0x281c1e07, 0x21000b0c,   // jw.ht.tl_664 tl.ht.un_440  ms.id.sw_432 es.jw.un_530
  // [b440]
  0x28081604, 0x6b121a13, 0x111305a4, 0x55006429,   // hr.no.sw_332 tl.hu.ceb_665  fr.et.ro_433 lg.rw.un_960
  0x07010502, 0x09251004, 0x031b0404, 0x1b000308,   // fr.en.it_222 lt.eu.pl_332  fi.tr.nl_332 nl.tr.un_430
  0x166b31a0, 0x08121ca4, 0x251a6b09, 0x160c25a4,   // az.ceb.hr_322 id.hu.no_433  ceb.tl.eu_444 eu.sv.hr_433
  0x53312107, 0x3f005512, 0x6b315313, 0x271f3f0c,   // jw.az.ht_432 rw.af.un_640  ht.az.ceb_665 af.cy.gd_543
  // [b450]
  0x1e1c1314, 0x1a55250c, 0x170f0805, 0x0a3f0313,   // et.id.ms_666 eu.rw.tl_543  no.lv.sr_333 nl.af.pt_665
  0x02070307, 0x1e212d07, 0x2a0523ee, 0x211a1ca9,   // nl.it.da_432 sk.jw.ms_432  ca.fr.mt_422 id.tl.jw_544
  0x21100205, 0x20001a0d, 0x29172011, 0x0c002807,   // da.lt.jw_333 tl.sq.un_540  sq.sr.sl_653 sw.sv.un_420
  0x285504ac, 0x08200b04, 0x641b55a4, 0x280c1012,   // fi.rw.sw_632 es.sq.no_332  rw.tr.lg_433 lt.sv.sw_654
  // [b460]
  0x06002309, 0x6400101a, 0x16001113, 0x0d190b02,   // ca.de.un_440 lt.lg.un_760  ro.hr.un_650 es.gl.cs_222
  0x010407a4, 0x051a2007, 0x311310a4, 0x2b041307,   // it.fi.en_433 sq.tl.fr_432  lt.et.az_433 et.fi.vi_432
  0x641b1307, 0x10002914, 0x04002d19, 0x27001204,   // et.tr.lg_432 sl.lt.un_660  sk.fi.un_750 hu.gd.un_320
  0x18282713, 0x060f100c, 0x2a1f07a4, 0x0d00130b,   // gd.sw.ga_665 lt.lv.de_543  it.cy.mt_433 bh.ne.un_520
  // [b470]
  0x252d29ee, 0x080e0212, 0x060f08a0, 0x130f0302,   // sl.sk.eu_422 da.is.no_654  no.lv.de_322 nl.lv.et_222
  0x10060fa4, 0x311b2012, 0x0e160a02, 0x116b01a7,   // lv.de.lt_433 sq.tr.az_654  pt.hr.is_222 en.ceb.ro_532
  0x17102107, 0x060f01a0, 0x53105507, 0x162a1802,   // jw.lt.sr_432 en.lv.de_322  rw.lt.ht_432 ga.mt.hr_222
  0x0c130f0c, 0x130f1208, 0x12001912, 0x10211aa7,   // lv.et.sv_543 hu.lv.et_443  gl.hu.un_640 tl.jw.lt_532
  // [b480]
  0x286b1a55, 0x3f215307, 0x646b1a05, 0x31556413,   // tl.ceb.sw_442 ht.jw.af_432  tl.ceb.lg_333 lg.rw.az_665
  0x6b643108, 0x6b211a0c, 0x6b1a2105, 0x553164ad,   // az.lg.ceb_443 tl.jw.ceb_543  jw.tl.ceb_333 lg.az.rw_643
  0x07111ea0, 0x6b1b1a08, 0x212718af, 0x0f0d17a0,   // ms.ro.it_322 tl.tr.ceb_443  ga.gd.jw_655 sr.cs.lv_322
  0x64003119, 0x18000707, 0x316b6404, 0x06020c0e,   // az.lg.un_750 it.ga.un_420  lg.ceb.az_332 sv.da.de_555
  // [b490]
  0x1a312108, 0x1a6e1f12, 0x1b1a31af, 0x55316413,   // jw.az.tl_443 cy.blu.tl_654  az.tl.tr_655 lg.az.rw_665
  0x1b00212a, 0x236b1f08, 0x21003113, 0x645531a0,   // jw.tr.un_970 cy.ceb.ca_443  az.jw.un_650 az.rw.lg_322
  0x2d0d1aaf, 0x1b1a21ad, 0x281f0c04, 0x316b550c,   // tl.cs.sk_655 jw.tl.tr_643  sv.cy.sw_332 rw.ceb.az_543
  0x0b1f6b11, 0x06000209, 0x12080207, 0x25000a0d,   // ceb.cy.es_653 da.de.un_440  da.no.hu_432 pt.eu.un_540
  // [b4a0]
  0x11175302, 0x1f060e02, 0x061f550b, 0x020c0ba0,   // ht.sr.ro_222 is.de.cy_222  rw.cy.de_542 es.sv.da_322
  0x1a6b1207, 0x0f020604, 0x1b2d12ee, 0x17001009,   // hu.ceb.tl_432 de.da.lv_332  hu.sk.tr_422 lt.sr.un_440
  0x131f6ba4, 0x172855ee, 0x0c003112, 0x020c1a08,   // ceb.cy.et_433 rw.sw.sr_422  az.sv.un_640 tl.sv.da_443
  0x1a1201a0, 0x25006b0d, 0x29041aa4, 0x1c002d04,   // en.hu.tl_322 ceb.eu.un_540  tl.fi.sl_433 sk.id.un_320
  // [b4b0]
  0x1e2125ee, 0x201255a0, 0x2a1b1102, 0x173f010b,   // eu.jw.ms_422 rw.hu.sq_322  ro.tr.mt_222 en.af.sr_542
  0x29112da4, 0x1117295a, 0x04011207, 0x1a050fa0,   // sk.ro.sl_433 sl.sr.ro_553  hu.en.fi_432 lv.fr.tl_322
  0x130f6b0c, 0x1a001805, 0x08061205, 0x111013a0,   // ceb.lv.et_543 ga.tl.un_330  hu.de.no_333 et.lt.ro_322
  0x200107a4, 0x23000b0c, 0x19010ba4, 0x0453050c,   // it.en.sq_433 es.ca.un_530  es.en.gl_433 fr.ht.fi_543
  // [b4c0]
  0x1e040a0c, 0x2b1013a6, 0x10072512, 0x03091f0c,   // pt.fi.ms_543 et.lt.vi_521  eu.it.lt_654 cy.pl.nl_543
  0x0c082aa7, 0x10552507, 0x2a0c0607, 0x030a29a0,   // mt.no.sv_532 eu.rw.lt_432  de.sv.mt_432 sl.pt.nl_322
  0x6400290c, 0x0e6b1a0c, 0x0c086b07, 0x07040a11,   // sl.lg.un_530 tl.ceb.is_543  ceb.no.sv_432 mk.ru.bg_653
  0x3f6b1aaf, 0x10251112, 0x080a1008, 0x1a00290d,   // tl.ceb.af_655 ro.eu.lt_654  be.mk.uk_443 sl.tl.un_540
  // [b4d0]
  0x0c130208, 0x08131204, 0x1028070c, 0x25130108,   // da.et.sv_443 hu.et.no_332  it.sw.lt_543 en.et.eu_443
  0x0f2d2907, 0x160c0208, 0x0c12080c, 0x552111a0,   // sl.sk.lv_432 da.sv.hr_443  no.hu.sv_543 ro.jw.rw_322
  0x06311bee, 0x080e04ac, 0x080c04ad, 0x0e041ba7,   // tr.az.de_422 fi.is.no_632  fi.sv.no_643 tr.fi.is_532
  0x04000213, 0x2a0504af, 0x055507ee, 0x210d2d0c,   // da.fi.un_650 fi.fr.mt_655  it.rw.fr_422 sk.cs.jw_543
  // [b4e0]
  0x3f0320ed, 0x6b2d550c, 0x31001913, 0x171611a4,   // sq.nl.af_622 rw.sk.ceb_543  gl.az.un_650 ro.hr.sr_433
  0x536b2807, 0x216e02ee, 0x0104130c, 0x0f271304,   // sw.ceb.ht_432 da.blu.jw_422  et.fi.en_543 et.gd.lv_332
  0x136428ac, 0x2a00041b, 0x13100f11, 0x122318a0,   // sw.lg.et_632 fi.mt.un_770  lv.lt.et_653 ga.ca.hu_322
  0x052b1a02, 0x1f000813, 0x2b000419, 0x080220a4,   // tl.vi.fr_222 no.cy.un_650  fi.vi.un_750 sq.da.no_433
  // [b4f0]
  0x29530504, 0x251028a4, 0x1c131a07, 0x2b00250e,   // fr.ht.sl_332 sw.lt.eu_433  tl.et.id_432 eu.vi.un_550
  0x6b1a55af, 0x2d0d5502, 0x23311baf, 0x1316170c,   // rw.tl.ceb_655 rw.cs.sk_222  tr.az.ca_655 sr.hr.et_543
  0x0c2d1ba0, 0x25531fa4, 0x2b021c02, 0x162a2d02,   // tr.sk.sv_322 cy.ht.eu_433  id.da.vi_222 sk.mt.hr_222
  0x0d000307, 0x131c10ee, 0x0f181ea9, 0x166e3f0c,   // nl.cs.un_420 lt.id.et_422  ms.ga.lv_544 af.blu.hr_543
  // [b500]
  0x6455200c, 0x040711ec, 0x28001014, 0x1a0155a0,   // sq.rw.lg_543 ro.bg.ru_644  lt.sw.un_660 rw.en.tl_322
  0x21282504, 0x2b07040c, 0x0a071008, 0x190b1f02,   // eu.sw.jw_332 fi.it.vi_543  be.bg.mk_443 cy.es.gl_222
  0x282510a0, 0x0f002804, 0x2d0d06ac, 0x0c026e0c,   // lt.eu.sw_322 sw.lv.un_320  de.cs.sk_632 blu.da.sv_543
  0x2a211a02, 0x130c1c0c, 0x2a00160d, 0x060704a4,   // tl.jw.mt_222 id.sv.et_543  hr.mt.un_540 fi.it.de_433
  // [b510]
  0x07040505, 0x04000e1b, 0x04003112, 0x282a23a4,   // fr.fi.it_333 is.fi.un_770  az.fi.un_640 ca.mt.sw_433
  0x080b06ec, 0x072a0a0c, 0x08001018, 0x0a100455,   // de.es.no_644 pt.mt.it_543  be.uk.un_740 ru.be.mk_442
  0x10082555, 0x29005505, 0x250410a0, 0x3f001f0b,   // eu.no.lt_442 rw.sl.un_330  lt.fi.eu_322 cy.af.un_520
  0x19002107, 0x64291004, 0x06000407, 0x23040807,   // jw.gl.un_420 lt.sl.lg_332  fi.de.un_420 no.fi.ca_432
  // [b520]
  0x2a0306af, 0x06002012, 0x0305040c, 0x0f0d2907,   // de.nl.mt_655 sq.de.un_640  fi.fr.nl_543 sl.cs.lv_432
  0x070a115a, 0x06002302, 0x04056404, 0x23071908,   // ro.mk.bg_553 ca.de.un_220  lg.fr.fi_332 gl.it.ca_443
  0x23033f07, 0x28640eaf, 0x110719a0, 0x0f101709,   // af.nl.ca_432 is.lg.sw_655  gl.it.ro_322 sr.lt.lv_444
  0x13040fa4, 0x201a6b02, 0x280403a4, 0x640302a0,   // lv.fi.et_433 ceb.tl.sq_222  nl.fi.sw_433 da.nl.lg_322
  // [b530]
  0x3f030655, 0x0a011302, 0x203f0308, 0x200f2a09,   // de.nl.af_442 et.en.pt_222  nl.af.sq_443 mt.lv.sq_444
  0x03000813, 0x1000030b, 0x181f0c04, 0x311b1208,   // no.nl.un_650 nl.lt.un_520  sv.cy.ga_332 hu.tr.az_443
  0x64041311, 0x181027ee, 0x0b001009, 0x21033f07,   // et.fi.lg_653 gd.lt.ga_422  lt.es.un_440 af.nl.jw_432
  0x0b136407, 0x0c0f10a4, 0x3f060308, 0x190a0faf,   // lg.et.es_432 lt.lv.sv_433  nl.de.af_443 lv.pt.gl_655
  // [b540]
  0x13000b08, 0x12033fa7, 0x210428a0, 0x1910270c,   // es.et.un_430 af.nl.hu_532  sw.fi.jw_322 gd.lt.gl_543
  0x21000b0e, 0x17002004, 0x28002505, 0x19010555,   // es.jw.un_550 sq.sr.un_320  eu.sw.un_330 fr.en.gl_442
  0x171631a0, 0x1000280c, 0x1600080d, 0x102811a0,   // az.hr.sr_322 sw.lt.un_530  no.hr.un_540 ro.sw.lt_322
  0x052d12ad, 0x196b0b07, 0x550f6ea4, 0x211f1012,   // hu.sk.fr_643 es.ceb.gl_432  blu.lv.rw_433 lt.cy.jw_654
  // [b550]
  0x553f64ec, 0x020c1f08, 0x0a076b07, 0x2d0d1002,   // lg.af.rw_644 cy.sv.da_443  ceb.it.pt_432 lt.cs.sk_222
  0x130f25a4, 0x29190ba0, 0x07002a02, 0x1600090b,   // eu.lv.et_433 es.gl.sl_322  mt.it.un_220 pl.hr.un_520
  0x0f131fee, 0x11273f02, 0x21121805, 0x1b1013a0,   // cy.et.lv_422 af.gd.ro_222  ar.ur.fa_333 et.lt.tr_322
  0x11000c02, 0x042d0d5a, 0x1100170e, 0x040c065a,   // sv.ro.un_220 cs.sk.fi_553  sr.ro.un_550 de.sv.fi_553
  // [b560]
  0x03001009, 0x041008a0, 0x2d00100d, 0x08100304,   // lt.nl.un_440 uk.be.ru_322  lt.sk.un_540 nl.lt.no_332
  0x0400090b, 0x04170aac, 0x18000907, 0x5521100d,   // pl.fi.un_520 mk.sr.ru_632  pl.ga.un_420 lt.jw.rw_554
  0x28551a0b, 0x55046bad, 0x0c200fa4, 0x122104a4,   // tl.rw.sw_542 ceb.fi.rw_643  lv.sq.sv_433 fi.jw.hu_433
  0x12211012, 0x290e10ee, 0x04290e13, 0x292a1304,   // lt.jw.hu_654 lt.is.sl_422  is.sl.fi_665 et.mt.sl_332
  // [b570]
  0x1e1c12ee, 0x25552107, 0x03083f55, 0x1c1221a9,   // hu.id.ms_422 jw.rw.eu_432  af.no.nl_442 jw.hu.id_544
  0x09121702, 0x033f180c, 0x133f08a4, 0x25122807,   // sr.hu.pl_222 ga.af.nl_543  no.af.et_433 sw.hu.eu_432
  0x03020d07, 0x6b122804, 0x3f0802ac, 0x11060708,   // cs.da.nl_432 sw.hu.ceb_332  da.no.af_632 it.de.ro_443
  0x0412280c, 0x09031104, 0x12001c0d, 0x2516280c,   // sw.hu.fi_543 ro.nl.pl_332  id.hu.un_540 sw.hr.eu_543
  // [b580]
  0x281221a4, 0x230805a0, 0x1720280c, 0x1f3f03af,   // jw.hu.sw_433 fr.no.ca_322  sw.sq.sr_543 nl.af.cy_655
  0x1e1c200e, 0x27040512, 0x05010408, 0x121f1ba0,   // sq.id.ms_555 fr.fi.gd_654  fi.en.fr_443 tr.cy.hu_322
  0x08090507, 0x18270aaf, 0x080c06af, 0x25080207,   // fr.pl.no_432 pt.gd.ga_655  de.sv.no_655 da.no.eu_432
  0x281a6ba0, 0x180b0504, 0x05180404, 0x10090ea7,   // ceb.tl.sw_322 fr.es.ga_332  fi.ga.fr_332 is.pl.lt_532
  // [b590]
  0x0500041a, 0x28171609, 0x18060309, 0x182704af,   // fi.fr.un_760 hr.sr.sw_444  nl.de.ga_444 fi.gd.ga_655
  0x3f021fee, 0x25285512, 0x28190a08, 0x07162a0c,   // cy.da.af_422 rw.sw.eu_654  pt.gl.sw_443 mt.hr.it_543
  0x311b120c, 0x06132504, 0x040a2a04, 0x022928ee,   // hu.tr.az_543 eu.et.de_332  mt.pt.fi_332 sw.sl.da_422
  0x0c25070c, 0x08230f08, 0x05641808, 0x311f2a07,   // it.eu.sv_543 lv.ca.no_443  ga.lg.fr_443 mt.cy.az_432
  // [b5a0]
  0x17290d0c, 0x1610020c, 0x0f3f03a0, 0x1e083fa7,   // cs.sl.sr_543 da.lt.hr_543  nl.af.lv_322 af.no.ms_532
  0x210364a0, 0x0b001911, 0x11552804, 0x286b5304,   // lg.nl.jw_322 gl.es.un_630  sw.rw.ro_332 ht.ceb.sw_332
  0x0a19230d, 0x06311204, 0x1f000409, 0x03043f07,   // ca.gl.pt_554 hu.az.de_332  fi.cy.un_440 af.fi.nl_432
  0x21000a19, 0x1a050404, 0x0d130907, 0x0a200412,   // pt.jw.un_750 fi.fr.tl_332  hi.bh.ne_432 fi.sq.pt_654
  // [b5b0]
  0x53000412, 0x02002105, 0x31033f0c, 0x08001b04,   // fi.ht.un_640 jw.da.un_330  af.nl.az_543 tr.no.un_320
  0x12080307, 0x290f1305, 0x12210307, 0x201716ec,   // nl.no.hu_432 et.lv.sl_333  nl.jw.hu_432 hr.sr.sq_644
  0x171008a6, 0x110a04a9, 0x062d2307, 0x28200e05,   // uk.be.sr_521 ru.mk.ro_544  ca.sk.de_432 is.sq.sw_333
  0x07080aa7, 0x2b162d11, 0x1b216ba0, 0x11131b5a,   // mk.uk.bg_532 sk.hr.vi_653  ceb.jw.tr_322 tr.et.ro_553
  // [b5c0]
  0x131b0607, 0x2b211c04, 0x080c2107, 0x1c0413a4,   // de.tr.et_432 id.jw.vi_332  jw.sv.no_432 et.fi.id_433
  0x23002d07, 0x2a000208, 0x551b21ee, 0x640905a0,   // sk.ca.un_420 da.mt.un_430  jw.tr.rw_422 fr.pl.lg_322
  0x120c08a0, 0x0a0410a0, 0x210b200c, 0x1a001b08,   // no.sv.hu_322 be.ru.mk_322  sq.es.jw_543 tr.tl.un_430
  0x25060aa4, 0x10291707, 0x5507280c, 0x070b2305,   // pt.de.eu_433 sr.sl.lt_432  sw.it.rw_543 ca.es.it_333
  // [b5d0]
  0x082855ad, 0x0f000902, 0x2d2012a7, 0x09001107,   // rw.sw.no_643 pl.lv.un_220  hu.sq.sk_532 ro.pl.un_420
  0x64001005, 0x0d002813, 0x1608020d, 0x06130855,   // lt.lg.un_330 sw.cs.un_650  da.no.hr_554 no.et.de_442
  0x276b0607, 0x2a002b02, 0x6b2801ee, 0x0e00130d,   // de.ceb.gd_432 vi.mt.un_220  en.sw.ceb_422 et.is.un_540
  0x12131104, 0x12040aa7, 0x06002905, 0x17161ba7,   // ro.et.hu_332 pt.fi.hu_532  sl.de.un_330 tr.hr.sr_532
  // [b5e0]
  0x281306a7, 0x03232507, 0x0600230e, 0x6b100f12,   // de.et.sw_532 eu.ca.nl_432  ca.de.un_550 lv.lt.ceb_654
  0x1c101307, 0x3f180107, 0x04070a14, 0x1c282107,   // et.lt.id_432 en.ga.af_432  mk.bg.ru_666 jw.sw.id_432
  0x1a006419, 0x08021305, 0x06000f08, 0x0e003f13,   // lg.tl.un_750 et.da.no_333  lv.de.un_430 af.is.un_650
  0x100e06a0, 0x08270ca7, 0x190a1309, 0x0f000412,   // de.is.lt_322 sv.gd.no_532  et.pt.gl_444 fi.lv.un_640
  // [b5f0]
  0x19001309, 0x162d5312, 0x1a006e04, 0x0c00021b,   // et.gl.un_440 ht.sk.hr_654  blu.tl.un_320 da.sv.un_770
  0x2a1f0c12, 0x3f130c02, 0x0f0e06a7, 0x136b1aa7,   // sv.cy.mt_654 sv.et.af_222  de.is.lv_532 tl.ceb.et_532
  0x27053fa4, 0x531f21a0, 0x21101caf, 0x0b31180c,   // af.fr.gd_433 jw.cy.ht_322  id.lt.jw_655 ga.az.es_543
  0x03183fa0, 0x2800131a, 0x071a6e07, 0x201307ee,   // af.ga.nl_322 et.sw.un_760  blu.tl.it_432 it.et.sq_422
  // [b600]
  0x55282007, 0x03273f0d, 0x1107040e, 0x0c1f08a0,   // sq.sw.rw_432 af.gd.nl_554  ru.bg.ro_555 no.cy.sv_322
  0x530c0607, 0x06311b0c, 0x0e060c02, 0x010227ee,   // de.sv.ht_432 tr.az.de_543  sv.de.is_222 gd.da.en_422
  0x31061ba7, 0x041f0aaf, 0x1f100309, 0x061f04a4,   // tr.de.az_532 pt.cy.fi_655  nl.lt.cy_444 fi.cy.de_433
  0x03296ea4, 0x312a1f04, 0x3f1f03a4, 0x08033f13,   // blu.sl.nl_433 cy.mt.az_332  nl.cy.af_433 af.nl.no_665
  // [b610]
  0x04003f14, 0x060105a4, 0x1f001012, 0x12000602,   // af.fi.un_660 fr.en.de_433  lt.cy.un_640 de.hu.un_220
  0x0500180e, 0x190a0b12, 0x0a100755, 0x05010807,   // ga.fr.un_550 es.pt.gl_654  bg.be.mk_442 no.en.fr_432
  0x0413640d, 0x0e085307, 0x110c0209, 0x1100201b,   // lg.et.fi_554 ht.no.is_432  da.sv.ro_444 sq.ro.un_770
  0x1a016b04, 0x103f0807, 0x04081ca0, 0x1b3f0107,   // ceb.en.tl_332 no.af.lt_432  id.no.fi_322 en.af.tr_432
  // [b620]
  0x3f1306ad, 0x03061fac, 0x1f0f0407, 0x19120508,   // de.et.af_643 cy.de.nl_632  fi.lv.cy_432 fr.hu.gl_443
  0x3f1a5305, 0x04641a14, 0x0e0c0112, 0x09002805,   // ht.tl.af_333 tl.lg.fi_666  en.sv.is_654 sw.pl.un_330
  0x1a286414, 0x5318010c, 0x0f002812, 0x27130a0c,   // lg.sw.tl_666 en.ga.ht_543  sw.lv.un_640 pt.et.gd_543
  0x131c0d04, 0x251264a0, 0x0f0464ad, 0x290d1212,   // ne.mr.bh_332 lg.hu.eu_322  lg.fi.lv_643 hu.cs.sl_654
  // [b630]
  0x190b100b, 0x0f0c130c, 0x0313050c, 0x08170414,   // lt.es.gl_542 et.sv.lv_543  fr.et.nl_543 ru.sr.uk_666
  0x6b2864ad, 0x0b1912ac, 0x212917ee, 0x3f071307,   // lg.sw.ceb_643 hu.gl.es_632  sr.sl.jw_422 et.it.af_432
  0x041e1c05, 0x64001302, 0x07282a13, 0x2a290dad,   // id.ms.fi_333 et.lg.un_220  mt.sw.it_665 cs.sl.mt_643
  0x1f6b10ad, 0x042d0d14, 0x120d20ec, 0x23000523,   // lt.ceb.cy_643 cs.sk.fi_666  sq.cs.hu_644 fr.ca.un_880
  // [b640]
  0x170916a4, 0x0c191e07, 0x126425af, 0x290353af,   // hr.pl.sr_433 ms.gl.sv_432  eu.lg.hu_655 ht.nl.sl_655
  0x0f100c0b, 0x1e1f1802, 0x1700280b, 0x041264a4,   // sv.lt.lv_542 ga.cy.ms_222  sw.sr.un_520 lg.hu.fi_433
  0x16270e07, 0x2d091907, 0x0f6b1a0c, 0x0b2307af,   // is.gd.hr_432 gl.pl.sk_432  tl.ceb.lv_543 it.ca.es_655
  0x211f6408, 0x28556411, 0x07041713, 0x2d0305a0,   // lg.cy.jw_443 lg.rw.sw_653  sr.ru.bg_665 fr.nl.sk_322
  // [b650]
  0x122128a4, 0x12180ea4, 0x28536412, 0x64092a08,   // sw.jw.hu_433 is.ga.hu_433  lg.ht.sw_654 mt.pl.lg_443
  0x0f1112a4, 0x0d0512ac, 0x121e1909, 0x2a6b0704,   // hu.ro.lv_433 hu.fr.cs_632  gl.ms.hu_444 it.ceb.mt_332
  0x12041312, 0x20072307, 0x23250107, 0x1b3120ad,   // et.fi.hu_654 ca.it.sq_432  en.eu.ca_432 sq.az.tr_643
  0x3f536ba0, 0x23000a2a, 0x31013fa0, 0x6b642aa0,   // ceb.ht.af_322 pt.ca.un_970  af.en.az_322 mt.lg.ceb_322
  // [b660]
  0x17006402, 0x21001319, 0x0d001608, 0x130e0f55,   // lg.sr.un_220 et.jw.un_750  hr.cs.un_430 lv.is.et_442
  0x080f19a0, 0x210f12a0, 0x1b0a2313, 0x20001b0c,   // gl.lv.no_322 hu.lv.jw_322  ca.pt.tr_665 tr.sq.un_530
  0x1a126b07, 0x0a1017af, 0x0f281312, 0x6e1827ad,   // ceb.hu.tl_432 sr.be.mk_655  et.sw.lv_654 gd.ga.blu_643
  0x0b0308ee, 0x271819a4, 0x1a1116a0, 0x071b11ad,   // no.nl.es_422 gl.ga.gd_433  hr.ro.tl_322 ro.tr.it_643
  // [b670]
  0x0a1827ad, 0x316407a9, 0x2d000c04, 0x2d0a210c,   // gd.ga.pt_643 it.lg.az_544  sv.sk.un_320 jw.pt.sk_543
  0x550c64ee, 0x09083f04, 0x0508230c, 0x2d1b6404,   // lg.sv.rw_422 af.no.pl_332  ca.no.fr_543 lg.tr.sk_332
  0x19050da0, 0x3f001f11, 0x2a120707, 0x1a556b05,   // cs.fr.gl_322 cy.af.un_630  it.hu.mt_432 ceb.rw.tl_333
  0x215564a4, 0x641a6ba9, 0x131e6b0c, 0x55641a09,   // lg.rw.jw_433 ceb.tl.lg_544  ceb.ms.et_543 tl.lg.rw_444
  // [b680]
  0x013f03a0, 0x071a28a7, 0x27191308, 0x6b531a08,   // nl.af.en_322 sw.tl.it_532  et.gl.gd_443 tl.ht.ceb_443
  0x01062bee, 0x06020c08, 0x1300251b, 0x6b1a6408,   // vi.de.en_422 sv.da.de_443  eu.et.un_770 lg.tl.ceb_443
  0x120f1e07, 0x25066b02, 0x55281b5a, 0x0c0406a0,   // ms.lv.hu_432 ceb.de.eu_222  tr.sw.rw_553 de.fi.sv_322
  0x083f0555, 0x3f1f080b, 0x64001f0c, 0x0200530c,   // fr.af.no_442 no.cy.af_542  cy.lg.un_530 ht.da.un_530
  // [b690]
  0x16182707, 0x250b0502, 0x06080c07, 0x0d1b3155,   // gd.ga.hr_432 fr.es.eu_222  sv.no.de_432 az.tr.cs_442
  0x086e1304, 0x3100110d, 0x17002d02, 0x55182102,   // et.blu.no_332 ro.az.un_540  sk.sr.un_220 jw.ga.rw_222
  0x0d000e18, 0x101104a4, 0x100a07a7, 0x0b0464ad,   // is.cs.un_740 ru.ro.be_433  bg.mk.be_532 lg.fi.es_643
  0x1e1c06a0, 0x200b0a55, 0x1a0e6bee, 0x2d00210c,   // de.id.ms_322 pt.es.sq_442  ceb.is.tl_422 jw.sk.un_530
  // [b6a0]
  0x0b000a2c, 0x19002007, 0x20042aa7, 0x112b0107,   // pt.es.un_990 sq.gl.un_420  mt.fi.sq_532 en.vi.ro_432
  0x190a6e11, 0x0d2d0eb6, 0x2d2916ee, 0x292a200b,   // blu.pt.gl_653 is.sk.cs_766  hr.sl.sk_422 sq.mt.sl_542
  0x2d001304, 0x0b0a04ee, 0x1f080704, 0x11003108,   // et.sk.un_320 fi.pt.es_422  it.no.cy_332 az.ro.un_430
  0x0b0a100c, 0x21282004, 0x3f210304, 0x27001b09,   // lt.pt.es_543 sq.sw.jw_332  nl.jw.af_332 tr.gd.un_440
  // [b6b0]
  0x1b200fa0, 0x201328a9, 0x211b11ec, 0x64005511,   // lv.sq.tr_322 sw.et.sq_544  ro.tr.jw_644 rw.lg.un_630
  0x2a0e1ba4, 0x01002808, 0x0b250708, 0x1e0e0409,   // tr.is.mt_433 sw.en.un_430  it.eu.es_443 fi.is.ms_444
  0x18252aa0, 0x1120040c, 0x04200e05, 0x12180607,   // mt.eu.ga_322 fi.sq.ro_543  is.sq.fi_333 de.ga.hu_432
  0x0d091c5a, 0x17162105, 0x0b2d0d05, 0x290c0ea0,   // mr.hi.ne_553 jw.hr.sr_333  cs.sk.es_333 is.sv.sl_322
  // [b6c0]
  0x0e1218a4, 0x02100fa0, 0x180b0e08, 0x25001207,   // ga.hu.is_433 lv.lt.da_322  is.es.ga_443 hu.eu.un_420
  0x641125ee, 0x3f1f110c, 0x2500120d, 0x1800190d,   // eu.ro.lg_422 ro.cy.af_543  hu.eu.un_540 gl.ga.un_540
  0x25106402, 0x0e0c2d0c, 0x0c041aa0, 0x21000908,   // lg.lt.eu_222 sk.sv.is_543  tl.fi.sv_322 pl.jw.un_430
  0x25171604, 0x25165502, 0x0e001a23, 0x1208060d,   // hr.sr.eu_332 rw.hr.eu_222  tl.is.un_880 de.no.hu_554
  // [b6d0]
  0x191601a4, 0x295328a0, 0x16552004, 0x2a280aee,   // en.hr.gl_433 sw.ht.sl_322  sq.rw.hr_332 pt.sw.mt_422
  0x6428530c, 0x53002119, 0x0c1f100d, 0x0b0a01ec,   // ht.sw.lg_543 jw.ht.un_750  lt.cy.sv_554 en.pt.es_644
  0x1e6b1804, 0x190b6ba4, 0x060c0812, 0x16110aee,   // ga.ceb.ms_332 ceb.es.gl_433  no.sv.de_654 pt.ro.hr_422
  0x2d210daf, 0x0b0a6409, 0x04311ba4, 0x29090e0c,   // cs.jw.sk_655 lg.pt.es_444  tr.az.fi_433 is.pl.sl_543
  // [b6e0]
  0x1005280d, 0x180510a9, 0x551611ee, 0x13042513,   // sw.fr.lt_554 lt.fr.ga_544  ro.hr.rw_422 eu.fi.et_665
  0x041813a9, 0x092155af, 0x03041f02, 0x28100508,   // et.ga.fi_544 rw.jw.pl_655  cy.fi.nl_222 fr.lt.sw_443
  0x0c002a13, 0x0e2d0d11, 0x060c0404, 0x0d0512a7,   // mt.sv.un_650 cs.sk.is_653  fi.sv.de_332 hu.fr.cs_532
  0x052718a9, 0x10270f0c, 0x64280404, 0x04286407,   // ga.gd.fr_544 lv.gd.lt_543  fi.sw.lg_332 lg.sw.fi_432
  // [b6f0]
  0x311923a0, 0x1c0720a4, 0x213f1fa0, 0x3f000405,   // ca.gl.az_322 sq.it.id_433  cy.af.jw_322 fi.af.un_330
  0x2d0d19a6, 0x120e0c0c, 0x0a005309, 0x021f3f05,   // gl.cs.sk_521 sv.is.hu_543  ht.pt.un_440 af.cy.da_333
  0x1e000108, 0x082a070d, 0x04050fa9, 0x1905100c,   // en.ms.un_430 it.mt.no_554  lv.fr.fi_544 lt.fr.gl_543
  0x2d0d230c, 0x271018a9, 0x07000f07, 0x16000707,   // ca.cs.sk_543 ga.lt.gd_544  lv.it.un_420 it.hr.un_420
  // [b700]
  0x07110a0c, 0x640405a4, 0x10002518, 0x0e080207,   // mk.ro.bg_543 fr.fi.lg_433  eu.lt.un_740 da.no.is_432
  0x0c000622, 0x55640b07, 0x31005502, 0x11200da0,   // de.sv.un_870 es.lg.rw_432  rw.az.un_220 cs.sq.ro_322
  0x060218ee, 0x531811ee, 0x03001604, 0x03000811,   // ga.da.de_422 ro.ga.ht_422  hr.nl.un_320 no.nl.un_630
  0x3f0904ec, 0x13000a09, 0x17160811, 0x531a1b5a,   // fi.pl.af_644 pt.et.un_440  no.hr.sr_653 tr.tl.ht_553
  // [b710]
  0x10060407, 0x101827ee, 0x0700180e, 0x186e27a7,   // fi.de.lt_432 gd.ga.lt_422  ga.it.un_550 gd.blu.ga_532
  0x04081b55, 0x25001208, 0x1311550b, 0x190b27a4,   // tr.no.fi_442 hu.eu.un_430  rw.ro.et_542 gd.es.gl_433
  0x030b0807, 0x172916ac, 0x09216407, 0x531205a0,   // no.es.nl_432 hr.sl.sr_632  lg.jw.pl_432 fr.hu.ht_322
  0x201f03a0, 0x05210b08, 0x0b0208a0, 0x0c1b310d,   // nl.cy.sq_322 es.jw.fr_443  no.da.es_322 az.tr.sv_554
  // [b720]
  0x062a070c, 0x0108235a, 0x0c001807, 0x0c27250c,   // it.mt.de_543 ca.no.en_553  ga.sv.un_420 eu.gd.sv_543
  0x55030205, 0x2a1b6ba4, 0x641b28a4, 0x1800030e,   // da.nl.rw_333 ceb.tr.mt_433  sw.tr.lg_433 nl.ga.un_550
  0x1a6b1209, 0x23001c0d, 0x13311108, 0x0653030c,   // hu.ceb.tl_444 id.ca.un_540  ro.az.et_443 nl.ht.de_543
  0x250801a4, 0x64135504, 0x030801a4, 0x08001e13,   // en.no.eu_433 rw.et.lg_332  en.no.nl_433 ms.no.un_650
  // [b730]
  0x55250204, 0x553164a0, 0x011e1c0d, 0x06020c02,   // da.eu.rw_332 lg.az.rw_322  id.ms.en_554 sv.da.de_222
  0x1c001b05, 0x2d1912a0, 0x27002b05, 0x20291204,   // tr.id.un_330 hu.gl.sk_322  vi.gd.un_330 hu.sl.sq_332
  0x23002118, 0x0410170b, 0x18001c07, 0x0f000b13,   // jw.ca.un_740 sr.be.ru_542  id.ga.un_420 es.lv.un_650
  0x0a2711ad, 0x532718ad, 0x1b3f1307, 0x03641305,   // ro.gd.pt_643 ga.gd.ht_643  et.af.tr_432 et.lg.nl_333
  // [b740]
  0x192105a7, 0x096b1ba0, 0x1a042507, 0x2a192355,   // fr.jw.gl_532 tr.ceb.pl_322  eu.fi.tl_432 ca.gl.mt_442
  0x21080aee, 0x29182004, 0x27000405, 0x27180509,   // pt.no.jw_422 sq.ga.sl_332  fi.gd.un_330 fr.ga.gd_444
  0x033f040c, 0x10290a0c, 0x23271804, 0x130464ec,   // fi.af.nl_543 pt.sl.lt_543  ga.gd.ca_332 lg.fi.et_644
  0x120e180d, 0x1c210aa0, 0x23072007, 0x0d000f12,   // ga.is.hu_554 pt.jw.id_322  sq.it.ca_432 lv.cs.un_640
  // [b750]
  0x102820ec, 0x086413a7, 0x3f1a0408, 0x20002818,   // sq.sw.lt_644 et.lg.no_532  fi.tl.af_443 sw.sq.un_740
  0x230a11a4, 0x273f1a04, 0x273f0304, 0x19230aa7,   // ro.pt.ca_433 tl.af.gd_332  nl.af.gd_332 pt.ca.gl_532
  0x07003109, 0x2d0d6b05, 0x28002705, 0x642310a7,   // az.it.un_440 ceb.cs.sk_333  gd.sw.un_330 lt.ca.lg_532
  0x06032704, 0x290d160c, 0x3f0c02ee, 0x04000718,   // gd.nl.de_332 hr.cs.sl_543  da.sv.af_422 bg.ru.un_740
  // [b760]
  0x3f0625a0, 0x031304ad, 0x036428ad, 0x1300281b,   // eu.de.af_322 fi.et.nl_643  sw.lg.nl_643 sw.et.un_770
  0x0c060207, 0x27002d09, 0x011927a0, 0x230720a4,   // da.de.sv_432 sk.gd.un_440  gd.gl.en_322 sq.it.ca_433
  0x23110aa0, 0x1e1c55a0, 0x2d18270d, 0x0b080205,   // pt.ro.ca_322 rw.id.ms_322  gd.ga.sk_554 da.no.es_333
  0x3f001f09, 0x11106ea6, 0x2d291709, 0x041223a7,   // cy.af.un_440 blu.lt.ro_521  sr.sl.sk_444 ca.hu.fi_532
  // [b770]
  0x2d0c0607, 0x0b2718af, 0x190a050e, 0x13001013,   // de.sv.sk_432 ga.gd.es_655  fr.pt.gl_555 lt.et.un_650
  0x1f182712, 0x120a050c, 0x1a081c09, 0x0a120504,   // gd.ga.cy_654 fr.pt.hu_543  id.no.tl_444 fr.hu.pt_332
  0x0c100f0d, 0x192d0d0b, 0x6b311b09, 0x64212807,   // lv.lt.sv_554 cs.sk.gl_542  tr.az.ceb_444 sw.jw.lg_432
  0x17161309, 0x191728ad, 0x1a556405, 0x6b280604,   // et.hr.sr_444 sw.sr.gl_643  lg.rw.tl_333 de.sw.ceb_332
  // [b780]
  0x272105a4, 0x1a5521a4, 0x1c1013a4, 0x1a131004,   // fr.jw.gd_433 jw.rw.tl_433  et.lt.id_433 lt.et.tl_332
  0x093f1f55, 0x06171602, 0x55286405, 0x060413ad,   // cy.af.pl_442 hr.sr.de_222  lg.sw.rw_333 et.fi.de_643
  0x1c0e2007, 0x535564af, 0x07001602, 0x040f080c,   // sq.is.id_432 lg.rw.ht_655  hr.it.un_220 no.lv.fi_543
  0x551c210b, 0x0500310c, 0x316b2a08, 0x0d122da7,   // jw.id.rw_542 az.fr.un_530  mt.ceb.az_443 sk.hu.cs_532
  // [b790]
  0x1304100c, 0x31201f07, 0x132004a0, 0x3f190b0b,   // lt.fi.et_543 cy.sq.az_432  fi.sq.et_322 es.gl.af_542
  0x0204200b, 0x09100f11, 0x05190a08, 0x0d012104,   // sq.fi.da_542 lv.lt.pl_653  pt.gl.fr_443 jw.en.cs_332
  0x0f001029, 0x1c6b12a4, 0x0d001004, 0x1c53080c,   // lt.lv.un_960 hu.ceb.id_433  lt.cs.un_320 no.ht.id_543
  0x2021040c, 0x29161b02, 0x1a6b2113, 0x13042008,   // fi.jw.sq_543 tr.hr.sl_222  jw.ceb.tl_665 sq.fi.et_443
  // [b7a0]
  0x061f0408, 0x2500200b, 0x0b2b6ba0, 0x1a6e2b04,   // fi.cy.de_443 sq.eu.un_520  ceb.vi.es_322 vi.blu.tl_332
  0x182d0d11, 0x251e1cad, 0x04251ea7, 0x06001213,   // cs.sk.ga_653 id.ms.eu_643  ms.eu.fi_532 hu.de.un_650
  0x1e1c6b14, 0x251a20a4, 0x1a00271b, 0x182b270b,   // ceb.id.ms_666 sq.tl.eu_433  gd.tl.un_770 gd.vi.ga_542
  0x1e251ca4, 0x182b2709, 0x021e2004, 0x0f210cee,   // id.eu.ms_433 gd.vi.ga_444  sq.ms.da_332 sv.jw.lv_422
  // [b7b0]
  0x311b64a9, 0x1a1b1102, 0x06120905, 0x1b1a6b12,   // lg.tr.az_544 ro.tr.tl_222  pl.hu.de_333 ceb.tl.tr_654
  0x556411ad, 0x06120455, 0x0a100410, 0x6421040d,   // ro.lg.rw_643 fi.hu.de_442  ru.be.mk_642 fi.jw.lg_554
  0x09001221, 0x090f0b0c, 0x08001b02, 0x29000d09,   // hu.pl.un_860 es.lv.pl_543  tr.no.un_220 cs.sl.un_440
  0x6b1e1aaf, 0x20252ba4, 0x251e1c0c, 0x0f0912af,   // tl.ms.ceb_655 vi.eu.sq_433  id.ms.eu_543 hu.pl.lv_655
  // [b7c0]
  0x0f02270c, 0x131c0daf, 0x201e2ba0, 0x12285512,   // gd.da.lv_543 ne.mr.bh_655  vi.ms.sq_322 rw.sw.hu_654
  0x3f280304, 0x6b033f07, 0x190a2102, 0x53282502,   // nl.sw.af_332 af.nl.ceb_432  jw.pt.gl_222 eu.sw.ht_222
  0x53000b02, 0x230525a0, 0x19005305, 0x041713ec,   // es.ht.un_220 eu.fr.ca_322  ht.gl.un_330 et.sr.fi_644
  0x0500530e, 0x1704075a, 0x09000511, 0x1a015307,   // ht.fr.un_550 bg.ru.sr_553  fr.pl.un_630 ht.en.tl_432
  // [b7d0]
  0x29161105, 0x0c100f55, 0x10091b04, 0x0c0f1011,   // ro.hr.sl_333 lv.lt.sv_442  tr.pl.lt_332 lt.lv.sv_653
  0x171e1c5a, 0x0f1a11a4, 0x103f08a0, 0x10000c1a,   // id.ms.sr_553 ro.tl.lv_433  no.af.lt_322 sv.lt.un_760
  0x21205505, 0x0611040c, 0x0b1129ad, 0x070a2304,   // rw.sq.jw_333 fi.ro.de_543  sl.ro.es_643 ca.pt.it_332
  0x09002a12, 0x1b000d08, 0x02000e02, 0x0f6e10af,   // mt.pl.un_640 cs.tr.un_430  is.da.un_220 lt.blu.lv_655
  // [b7e0]
  0x0c020ea4, 0x1c003104, 0x01005312, 0x0c271f0c,   // is.da.sv_433 az.id.un_320  ht.en.un_640 cy.gd.sv_543
  0x18312705, 0x551721a0, 0x1b2812ad, 0x013f290c,   // gd.az.ga_333 jw.sr.rw_322  hu.sw.tr_643 sl.af.en_543
  0x16231f08, 0x1764290e, 0x25000b0e, 0x285517a4,   // cy.ca.hr_443 sl.lg.sr_555  es.eu.un_550 sr.rw.sw_433
  0x316b1b05, 0x1a2a6bec, 0x1c0d13af, 0x1c532704,   // tr.ceb.az_333 ceb.mt.tl_644  bh.ne.mr_655 gd.ht.id_332
  // [b7f0]
  0x2327040c, 0x17005308, 0x17032a0c, 0x11070a09,   // fi.gd.ca_543 ht.sr.un_430  mt.nl.sr_543 mk.bg.ro_444
  0x051306a0, 0x01000408, 0x110b0504, 0x020c03ee,   // de.et.fr_322 fi.en.un_430  fr.es.ro_332 nl.sv.da_422
  0x060c01a4, 0x2d5305ac, 0x0f002a21, 0x10000713,   // en.sv.de_433 fr.ht.sk_632  mt.lv.un_860 bg.be.un_650
  0x08100aa0, 0x55642104, 0x531a2807, 0x172a1660,   // mk.be.uk_322 jw.lg.rw_332  sw.tl.ht_432 hr.mt.sr_664

  // [b800]
  0x0b0207a0, 0x2d000308, 0x1c002a0d, 0x0f132aa7,   // it.da.es_322 nl.sk.un_430  mt.id.un_540 mt.et.lv_532
  0x10001f22, 0x53130507, 0x6b020107, 0x1c0108a0,   // cy.lt.un_870 fr.et.ht_432  en.da.ceb_432 no.en.id_322
  0x09000f02, 0x0e286b0b, 0x6e6b27ee, 0x04100708,   // lv.pl.un_220 ceb.sw.is_542  gd.ceb.blu_422 bg.be.ru_443
  0x0c3f02a4, 0x53553107, 0x05232a0c, 0x1710040d,   // da.af.sv_433 az.rw.ht_432  mt.ca.fr_543 ru.be.sr_554
  // [b810]
  0x0d6e0604, 0x25000a05, 0x1b002a05, 0x250711ee,   // de.blu.cs_332 pt.eu.un_330  mt.tr.un_330 ro.it.eu_422
  0x131b3155, 0x0b00010c, 0x180c1a0c, 0x1a315304,   // az.tr.et_442 en.es.un_530  tl.sv.ga_543 ht.az.tl_332
  0x250b1255, 0x1b0413a4, 0x0a006e04, 0x060b07a6,   // hu.es.eu_442 et.fi.tr_433  blu.pt.un_320 it.es.de_521
  0x080503ac, 0x641e53a0, 0x04000f02, 0x25000a13,   // nl.fr.no_632 ht.ms.lg_322  lv.fi.un_220 pt.eu.un_650
  // [b820]
  0x21121855, 0x0c002513, 0x070311a7, 0x0a0b1911,   // ar.ur.fa_442 eu.sv.un_650  ro.nl.it_532 gl.es.pt_653
  0x1f3f0807, 0x07131009, 0x641a6b04, 0x12001829,   // no.af.cy_432 lt.et.it_444  ceb.tl.lg_332 ar.ur.un_960
  0x06312a0b, 0x0700110b, 0x2b005313, 0x1b041308,   // mt.az.de_542 ro.it.un_520  ht.vi.un_650 et.fi.tr_443
  0x1f6b2107, 0x21051105, 0x1a190b14, 0x0717110c,   // jw.ceb.cy_432 ro.fr.jw_333  es.gl.tl_666 ro.sr.bg_543
  // [b830]
  0x27041b08, 0x2500050b, 0x05231ea0, 0x290407ad,   // tr.fi.gd_443 fr.eu.un_520  ms.ca.fr_322 it.fi.sl_643
  0x1b2004a0, 0x05002504, 0x01001a05, 0x1105090d,   // fi.sq.tr_322 eu.fr.un_320  tl.en.un_330 pl.fr.ro_554
  0x010605ee, 0x6b005507, 0x160d09a4, 0x10190b02,   // fr.de.en_422 rw.ceb.un_420  pl.cs.hr_433 es.gl.lt_222
  0x2b5307a0, 0x645520af, 0x17641604, 0x112007ad,   // it.ht.vi_322 sq.rw.lg_655  hr.lg.sr_332 it.sq.ro_643
  // [b840]
  0x1125050d, 0x1b0a55ad, 0x100411ee, 0x07250604,   // fr.eu.ro_554 rw.pt.tr_643  ro.ru.be_422 de.eu.it_332
  0x0811070c, 0x07110a09, 0x23000208, 0x11172004,   // it.ro.no_543 pt.ro.it_444  da.ca.un_430 sq.sr.ro_332
  0x11190b09, 0x20311b11, 0x1a111fee, 0x6b530107,   // es.gl.ro_444 tr.az.sq_653  cy.ro.tl_422 en.ht.ceb_432
  0x020c5313, 0x110d0707, 0x05070da0, 0x1b0f25a0,   // ht.sv.da_665 it.cs.ro_432  cs.it.fr_322 eu.lv.tr_322
  // [b850]
  0x11552504, 0x08002012, 0x17002d34, 0x131604a7,   // eu.rw.ro_332 sq.no.un_640  sk.sr.un_A80 fi.hr.et_532
  0x0f1b130c, 0x023f2912, 0x23190ba0, 0x0d172d07,   // et.tr.lv_543 sl.af.da_654  es.gl.ca_322 sk.sr.cs_432
  0x0700171b, 0x2318050c, 0x080a075a, 0x0a282508,   // sr.bg.un_770 fr.ga.ca_543  bg.mk.uk_553 eu.sw.pt_443
  0x13271807, 0x641e2a07, 0x2000640c, 0x64132a07,   // ga.gd.et_432 mt.ms.lg_432  lg.sq.un_530 mt.et.lg_432
  // [b860]
  0x3f001312, 0x2a006421, 0x281e1c02, 0x1f002308,   // et.af.un_640 lg.mt.un_860  id.ms.sw_222 ca.cy.un_430
  0x211f2712, 0x0f271014, 0x170407ac, 0x2a006409,   // gd.cy.jw_654 lt.gd.lv_666  bg.ru.sr_632 lg.mt.un_440
  0x25002720, 0x27281812, 0x1f270f09, 0x12040708,   // gd.eu.un_850 ga.sw.gd_654  lv.gd.cy_444 it.fi.hu_443
  0x0f272512, 0x2b0711ee, 0x060412ec, 0x13041207,   // eu.gd.lv_654 ro.it.vi_422  hu.fi.de_644 hu.fi.et_432
  // [b870]
  0x1a1e13a0, 0x1a042707, 0x04531a0c, 0x05061208,   // et.ms.tl_322 gd.fi.tl_432  tl.ht.fi_543 hu.de.fr_443
  0x21041a0c, 0x0f1013a9, 0x041f27ad, 0x1b0612ee,   // tl.fi.jw_543 et.lt.lv_544  gd.cy.fi_643 hu.de.tr_422
  0x01000509, 0x230a01a4, 0x0f18270c, 0x27002822,   // fr.en.un_440 en.pt.ca_433  gd.ga.lv_543 sw.gd.un_870
  0x1f182705, 0x1e1c27af, 0x0d001c29, 0x20006414,   // gd.ga.cy_333 gd.id.ms_655  mr.ne.un_960 lg.sq.un_660
  // [b880]
  0x0a120612, 0x100408ee, 0x23130aa4, 0x2a643fa0,   // de.hu.pt_654 uk.ru.be_422  pt.et.ca_433 af.lg.mt_322
  0x04130505, 0x0e1b31a0, 0x0e17160d, 0x17160a05,   // fr.et.fi_333 az.tr.is_322  hr.sr.is_554 pt.hr.sr_333
  0x0a071207, 0x0e2b08a0, 0x25045304, 0x6b270e09,   // hu.it.pt_432 no.vi.is_322  ht.fi.eu_332 is.gd.ceb_444
  0x121b3105, 0x2a002902, 0x29122dee, 0x041b2aa0,   // az.tr.hu_333 sl.mt.un_220  sk.hu.sl_422 mt.tr.fi_322
  // [b890]
  0x070a0460, 0x0f0c1312, 0x09000109, 0x0b000f04,   // ru.mk.bg_664 et.sv.lv_654  en.pl.un_440 lv.es.un_320
  0x10001721, 0x162d1207, 0x2d1629a4, 0x18002a08,   // sr.be.un_860 hu.sk.hr_432  sl.hr.sk_433 mt.ga.un_430
  0x070a0302, 0x11040a09, 0x2916200b, 0x100a110c,   // nl.pt.it_222 pt.fi.ro_444  sq.hr.sl_542 ro.pt.lt_543
  0x0d162da7, 0x290e0c07, 0x172d1660, 0x25002321,   // sk.hr.cs_532 sv.is.sl_432  hr.sk.sr_664 ca.eu.un_860
  // [b8a0]
  0x0e001f21, 0x2016290c, 0x133f0c02, 0x0c530604,   // cy.is.un_860 sl.hr.sq_543  sv.af.et_222 de.ht.sv_332
  0x02282507, 0x13200413, 0x64002007, 0x110613af,   // eu.sw.da_432 fi.sq.et_665  sq.lg.un_420 et.de.ro_655
  0x0f122d07, 0x122855ee, 0x6b060c55, 0x130c0614,   // sk.hu.lv_432 rw.sw.hu_422  sv.de.ceb_442 de.sv.et_666
  0x062055a4, 0x08060c0c, 0x555364ad, 0x28001602,   // rw.sq.de_433 sv.de.no_543  lg.ht.rw_643 hr.sw.un_220
  // [b8b0]
  0x55211ca0, 0x3f001f22, 0x0d001e04, 0x0a1017ec,   // id.jw.rw_322 cy.af.un_870  ms.cs.un_320 sr.be.mk_644
  0x0a17040d, 0x07170a55, 0x21005518, 0x111004af,   // ru.sr.mk_554 mk.sr.bg_442  rw.jw.un_740 ru.be.ro_655
  0x070f64a4, 0x1c000202, 0x1b551a04, 0x18001e07,   // lg.lv.it_433 da.id.un_220  tl.rw.tr_332 ms.ga.un_420
  0x1e640f60, 0x281e1312, 0x126b13ee, 0x55050604,   // lv.lg.ms_664 et.ms.sw_654  et.ceb.hu_422 de.fr.rw_332
  // [b8c0]
  0x13286b12, 0x6b2128a7, 0x060b190b, 0x12100f07,   // ceb.sw.et_654 sw.jw.ceb_532  gl.es.de_542 lv.lt.hu_432
  0x13001b23, 0x0b27110c, 0x071704ee, 0x0f136b55,   // tr.et.un_880 ro.gd.es_543  ru.sr.bg_422 ceb.et.lv_442
  0x12001a07, 0x552110ee, 0x0d003f02, 0x13091c13,   // tl.hu.un_420 lt.jw.rw_422  af.cs.un_220 mr.hi.bh_665
  0x64551004, 0x13002802, 0x130f64a0, 0x18081aee,   // lt.rw.lg_332 sw.et.un_220  lg.lv.et_322 tl.no.ga_422
  // [b8d0]
  0x64283fa0, 0x55190b14, 0x08065305, 0x055331ad,   // af.sw.lg_322 es.gl.rw_666  ht.de.no_333 az.ht.fr_643
  0x10531909, 0x2d062702, 0x09181f04, 0x12230704,   // gl.ht.lt_444 gd.de.sk_222  cy.ga.pl_332 it.ca.hu_332
  0x21292d04, 0x2b012907, 0x1b002112, 0x0464100b,   // sk.sl.jw_332 sl.en.vi_432  jw.tr.un_640 lt.lg.fi_542
  0x280f1309, 0x191a6ba0, 0x0f3f13a4, 0x0a006e19,   // et.lv.sw_444 ceb.tl.gl_322  et.af.lv_433 blu.pt.un_750
  // [b8e0]
  0x08311b12, 0x02012ba6, 0x09532102, 0x3f001705,   // tr.az.no_654 vi.en.da_521  jw.ht.pl_222 sr.af.un_330
  0x1c216407, 0x280a1fee, 0x53133fa9, 0x030c0e04,   // lg.jw.id_432 cy.pt.sw_422  af.et.ht_544 is.sv.nl_332
  0x08120c0c, 0x28231e04, 0x23001f12, 0x6b281307,   // sv.hu.no_543 ms.ca.sw_332  cy.ca.un_640 et.sw.ceb_432
  0x23001235, 0x13002504, 0x0e0c19a4, 0x01050811,   // hu.ca.un_A90 eu.et.un_320  gl.sv.is_433 no.fr.en_653
  // [b8f0]
  0x0c1c08ee, 0x64131007, 0x2800200c, 0x6b005523,   // no.id.sv_422 lt.et.lg_432  sq.sw.un_530 rw.ceb.un_880
  0x10200aee, 0x23000807, 0x3f00640c, 0x3f2a2512,   // pt.sq.lt_422 no.ca.un_420  lg.af.un_530 eu.mt.af_654
  0x122025a7, 0x25180aaf, 0x29532007, 0x2b010811,   // eu.sq.hu_532 pt.ga.eu_655  sq.ht.sl_432 no.en.vi_653
  0x29282007, 0x1917200c, 0x2b5501a0, 0x0f092507,   // sq.sw.sl_432 sq.sr.gl_543  en.rw.vi_322 eu.pl.lv_432
  // [b900]
  0x12291c02, 0x03000812, 0x060c0e0c, 0x20000802,   // id.sl.hu_222 no.nl.un_640  is.sv.de_543 no.sq.un_220
  0x1b250fee, 0x231906a4, 0x05641f07, 0x5529200c,   // lv.eu.tr_422 de.gl.ca_433  cy.lg.fr_432 sq.sl.rw_543
  0x08202da0, 0x64201304, 0x6b2120a0, 0x082916a4,   // sk.sq.no_322 et.sq.lg_332  sq.jw.ceb_322 hr.sl.no_433
  0x552853a0, 0x310c25ee, 0x2a021e04, 0x0e0c08a9,   // ht.sw.rw_322 eu.sv.az_422  ms.da.mt_332 no.sv.is_544
  // [b910]
  0x21131e07, 0x2d000f0e, 0x031a3f0c, 0x25090f08,   // ms.et.jw_432 lv.sk.un_550  af.tl.nl_543 lv.pl.eu_443
  0x05000609, 0x1f001a0d, 0x03010604, 0x0b1912a6,   // de.fr.un_440 tl.cy.un_540  de.en.nl_332 hu.gl.es_521
  0x0d000b04, 0x3f1f6eee, 0x21050104, 0x28000c02,   // es.cs.un_320 blu.cy.af_422  en.fr.jw_332 sv.sw.un_220
  0x6b080213, 0x09001e0d, 0x211a6e04, 0x16000f02,   // da.no.ceb_665 ms.pl.un_540  blu.tl.jw_332 lv.hr.un_220
  // [b920]
  0x06311ba4, 0x0411080e, 0x07081105, 0x53006b09,   // tr.az.de_433 uk.ro.ru_555  ro.uk.bg_333 ceb.ht.un_440
  0x28001a1a, 0x6b003109, 0x03643fec, 0x202d0d55,   // tl.sw.un_760 az.ceb.un_440  af.lg.nl_644 cs.sk.sq_442
  0x64041e07, 0x25100f04, 0x2d0d130c, 0x1a1b3104,   // ms.fi.lg_432 lv.lt.eu_332  et.cs.sk_543 az.tr.tl_332
  0x0c045304, 0x21060307, 0x01000519, 0x2800040d,   // ht.fi.sv_332 nl.de.jw_432  fr.en.un_750 fi.sw.un_540
  // [b930]
  0x19000d12, 0x12005305, 0x5305640c, 0x161729a0,   // cs.gl.un_640 ht.hu.un_330  lg.fr.ht_543 sl.sr.hr_322
  0x29001e12, 0x100411a7, 0x3f1204a0, 0x0306530e,   // ms.sl.un_640 ro.ru.be_532  fi.hu.af_322 ht.de.nl_555
  0x53056407, 0x1809050c, 0x316b1ca0, 0x23190ba7,   // lg.fr.ht_432 fr.pl.ga_543  id.ceb.az_322 es.gl.ca_532
  0x076405ee, 0x01231e05, 0x1c21230c, 0x18110a08,   // fr.lg.it_422 ms.ca.en_333  ca.jw.id_543 pt.ro.ga_443
  // [b940]
  0x1c2021ec, 0x132a0ca9, 0x0b000422, 0x050853a0,   // jw.sq.id_644 sv.mt.et_544  fi.es.un_870 ht.no.fr_322
  0x201109a0, 0x01050412, 0x0e0f1313, 0x551b640c,   // pl.ro.sq_322 fi.fr.en_654  et.lv.is_665 lg.tr.rw_543
  0x0d27185a, 0x5521640d, 0x100a0405, 0x2500530e,   // ga.gd.cs_553 lg.jw.rw_554  ru.mk.be_333 ht.eu.un_550
  0x2a001e0d, 0x3f00131b, 0x29001108, 0x111617a7,   // ms.mt.un_540 et.af.un_770  ro.sl.un_430 sr.hr.ro_532
  // [b950]
  0x1a12250c, 0x31001c08, 0x03642155, 0x31251304,   // eu.hu.tl_543 id.az.un_430  jw.lg.nl_442 et.eu.az_332
  0x112855ee, 0x20291607, 0x040b0ea9, 0x27092513,   // rw.sw.ro_422 hr.sl.sq_432  is.es.fi_544 eu.pl.gd_665
  0x110a0505, 0x251f53a0, 0x07000d08, 0x10041112,   // fr.pt.ro_333 ht.cy.eu_322  cs.it.un_430 ro.fi.lt_654
  0x05110112, 0x551611a7, 0x11000821, 0x642a2855,   // en.ro.fr_654 ro.hr.rw_532  uk.ro.un_860 sw.mt.lg_442
  // [b960]
  0x0a282a08, 0x11120aa0, 0x53051707, 0x1a2505ee,   // mt.sw.pt_443 pt.hu.ro_322  sr.fr.ht_432 fr.eu.tl_422
  0x23131055, 0x18276455, 0x081b230c, 0x11005305,   // lt.et.ca_442 lg.gd.ga_442  ca.tr.no_543 ht.ro.un_330
  0x2a120cec, 0x0e08180c, 0x082518a4, 0x231827a9,   // sv.hu.mt_644 ga.no.is_543  ga.eu.no_433 gd.ga.ca_544
  0x3f2a06a4, 0x06080e08, 0x11000e21, 0x16110d12,   // de.mt.af_433 is.no.de_443  is.ro.un_860 cs.ro.hr_654
  // [b970]
  0x2500060e, 0x035325ac, 0x180608a4, 0x25271c07,   // de.eu.un_550 eu.ht.nl_632  no.de.ga_433 id.gd.eu_432
  0x0e2b0b07, 0x08100e0c, 0x21251ca9, 0x2900010d,   // es.vi.is_432 is.lt.no_543  id.eu.jw_544 en.sl.un_540
  0x080b0ea0, 0x2a04065a, 0x010d110c, 0x0e0b250c,   // is.es.no_322 de.fi.mt_553  ro.cs.en_543 eu.es.is_543
  0x11003f05, 0x11160d07, 0x1f0618a4, 0x1f1007a0,   // af.ro.un_330 cs.hr.ro_432  ga.de.cy_433 it.lt.cy_322
  // [b980]
  0x100d2aac, 0x0c062755, 0x04100ba9, 0x01533f55,   // mt.cs.lt_632 gd.de.sv_442  es.lt.fi_544 af.ht.en_442
  0x291f0612, 0x120e0c07, 0x1b002521, 0x19250760,   // de.cy.sl_654 sv.is.hu_432  eu.tr.un_860 it.eu.gl_664
  0x0f2d09ec, 0x09000408, 0x6b060908, 0x21073fec,   // pl.sk.lv_644 fi.pl.un_430  pl.de.ceb_443 af.it.jw_644
  0x10122514, 0x2d0f04a4, 0x2b190b08, 0x2a2b270b,   // eu.hu.lt_666 fi.lv.sk_433  es.gl.vi_443 gd.vi.mt_542
  // [b990]
  0x25002a0c, 0x272a1807, 0x112d0da0, 0x120a2dec,   // mt.eu.un_530 ga.mt.gd_432  cs.sk.ro_322 sk.pt.hu_644
  0x13080207, 0x23052aa0, 0x092a1311, 0x1f001c02,   // da.no.et_432 mt.fr.ca_322  et.mt.pl_653 id.cy.un_220
  0x04110813, 0x3f001812, 0x11081714, 0x193f0307,   // uk.ro.ru_665 ga.af.un_640  sr.uk.ro_666 nl.af.gl_432
  0x0f042107, 0x2a25110d, 0x286423a0, 0x110725af,   // jw.fi.lv_432 ro.eu.mt_554  ca.lg.sw_322 eu.it.ro_655
  // [b9a0]
  0x6b251a09, 0x230b05ee, 0x0f2d0d60, 0x161b2a11,   // tl.eu.ceb_444 fr.es.ca_422  cs.sk.lv_664 mt.tr.hr_653
  0x2000041a, 0x19041007, 0x230a1f02, 0x0a072da9,   // fi.sq.un_760 lt.fi.gl_432  cy.pt.ca_222 sk.it.pt_544
  0x2d090302, 0x190a110c, 0x25190aa0, 0x1a6b2da9,   // nl.pl.sk_222 ro.pt.gl_543  pt.gl.eu_322 sk.ceb.tl_544
  0x0a002707, 0x091a6bad, 0x0c0608a9, 0x0b0719a0,   // gd.pt.un_420 ceb.tl.pl_643  no.de.sv_544 gl.it.es_322
  // [b9b0]
  0x2029100c, 0x0f1a6b11, 0x31001007, 0x10002308,   // lt.sl.sq_543 ceb.tl.lv_653  lt.az.un_420 ca.lt.un_430
  0x1e1c13ee, 0x53052007, 0x03051f04, 0x05100904,   // et.id.ms_422 sq.fr.ht_432  cy.fr.nl_332 pl.lt.fr_332
  0x16000a08, 0x23282507, 0x0a003114, 0x01182a04,   // pt.hr.un_430 eu.sw.ca_432  az.pt.un_660 mt.ga.en_332
  0x060428a7, 0x2d2928a7, 0x100405a0, 0x191716a0,   // sw.fi.de_532 sw.sl.sk_532  fr.fi.lt_322 hr.sr.gl_322
  // [b9c0]
  0x23071fa0, 0x10251e04, 0x0c002908, 0x0b071107,   // cy.it.ca_322 ms.eu.lt_332  sl.sv.un_430 ro.it.es_432
  0x1a2116ee, 0x0a640505, 0x27101faf, 0x202155a7,   // hr.jw.tl_422 fr.lg.pt_333  cy.lt.gd_655 rw.jw.sq_532
  0x121b2905, 0x190b1007, 0x311b5512, 0x071629a6,   // sl.tr.hu_333 lt.es.gl_432  rw.tr.az_654 sl.hr.it_521
  0x0a0b19ad, 0x110804a0, 0x6b0c1f04, 0x10000b19,   // gl.es.pt_643 fi.no.ro_322  cy.sv.ceb_332 es.lt.un_750
  // [b9d0]
  0x05005305, 0x556e2804, 0x130802a0, 0x08100ead,   // ht.fr.un_330 sw.blu.rw_332  da.no.et_322 is.lt.no_643
  0x041913a9, 0x130f1ca4, 0x02001f13, 0x13000708,   // et.gl.fi_544 id.lv.et_433  cy.da.un_650 it.et.un_430
  0x1c041311, 0x033f0213, 0x0e281f07, 0x0c080e0d,   // et.fi.id_653 da.af.nl_665  cy.sw.is_432 is.no.sv_554
  0x200c6405, 0x55285304, 0x041307ad, 0x040c53a0,   // lg.sv.sq_333 ht.sw.rw_332  it.et.fi_643 ht.sv.fi_322
  // [b9e0]
  0x31040107, 0x3f032011, 0x3113040c, 0x10071707,   // en.fi.az_432 sq.nl.af_653  fi.et.az_543 sr.bg.be_432
  0x17551ea4, 0x28001f12, 0x121f05ee, 0x08001718,   // ms.rw.sr_433 cy.sw.un_640  fr.cy.hu_422 sr.no.un_740
  0x180406a4, 0x551a210c, 0x1a271808, 0x2a0d01a0,   // de.fi.ga_433 jw.tl.rw_543  ga.gd.tl_443 en.cs.mt_322
  0x1c231b08, 0x2d021ba6, 0x05130107, 0x185505a0,   // tr.ca.id_443 tr.da.sk_521  en.et.fr_432 fr.rw.ga_322
  // [b9f0]
  0x052018a4, 0x190b0aa7, 0x051155a4, 0x21051ead,   // ga.sq.fr_433 pt.es.gl_532  rw.ro.fr_433 ms.fr.jw_643
  0x556420ee, 0x29230ba4, 0x0a00080e, 0x1b1e1c5a,   // sq.lg.rw_422 es.ca.sl_433  uk.mk.un_550 id.ms.tr_553
  0x1306080c, 0x1b001308, 0x3f27130c, 0x081b1ca4,   // no.de.et_543 et.tr.un_430  et.gd.af_543 id.tr.no_433
  0x202705af, 0x2008110c, 0x55192004, 0x282029ad,   // fr.gd.sq_655 ro.no.sq_543  sq.gl.rw_332 sl.sq.sw_643
  // [ba00]
  0x040e1008, 0x2a1b1104, 0x270518a4, 0x1000132c,   // lt.is.fi_443 ro.tr.mt_332  ga.fr.gd_433 et.lt.un_990
  0x64112009, 0x641b5508, 0x010720a4, 0x183f0608,   // sq.ro.lg_444 rw.tr.lg_443  sq.it.en_433 de.af.ga_443
  0x6b000a04, 0x27060305, 0x271913a7, 0x110820a0,   // pt.ceb.un_320 nl.de.gd_333  et.gl.gd_532 sq.no.ro_322
  0x550f06a6, 0x11642004, 0x641155a0, 0x28041aa4,   // de.lv.rw_521 sq.lg.ro_332  rw.ro.lg_322 tl.fi.sw_433
  // [ba10]
  0x01002119, 0x200513ee, 0x0500200c, 0x1c2107a4,   // jw.en.un_750 et.fr.sq_422  sq.fr.un_530 it.jw.id_433
  0x1308200c, 0x09162705, 0x02000829, 0x18000b09,   // sq.no.et_543 gd.hr.pl_333  no.da.un_960 es.ga.un_440
  0x6b002522, 0x170704ec, 0x062a2107, 0x271f1811,   // eu.ceb.un_870 ru.bg.sr_644  jw.mt.de_432 ga.cy.gd_653
  0x171211a0, 0x07130405, 0x1e00040e, 0x1a11230c,   // ro.hu.sr_322 fi.et.it_333  fi.ms.un_550 ca.ro.tl_543
  // [ba20]
  0x0600100e, 0x100e1ba0, 0x1f0c02a0, 0x162917ac,   // lt.de.un_550 tr.is.lt_322  da.sv.cy_322 sr.sl.hr_632
  0x281853a7, 0x17060e04, 0x1f6b05ee, 0x010d1f04,   // ht.ga.sw_532 is.de.sr_332  fr.ceb.cy_422 cy.cs.en_332
  0x0e1a0805, 0x210a1c04, 0x0f1310a7, 0x21131ea0,   // no.tl.is_333 id.pt.jw_332  lt.et.lv_532 ms.et.jw_322
  0x112025a4, 0x3f0327a9, 0x070b280c, 0x3f1827a4,   // eu.sq.ro_433 gd.nl.af_544  sw.es.it_543 gd.ga.af_433
  // [ba30]
  0x55211304, 0x11272304, 0x13210808, 0x02551304,   // et.jw.rw_332 ca.gd.ro_332  no.jw.et_443 et.rw.da_332
  0x272d2a07, 0x0f1f3f02, 0x25092aee, 0x16211e05,   // mt.sk.gd_432 af.cy.lv_222  mt.pl.eu_422 ms.jw.hr_333
  0x190d2da0, 0x20001005, 0x05033fa9, 0x1008170c,   // sk.cs.gl_322 lt.sq.un_330  af.nl.fr_544 sr.uk.be_543
  0x033f2302, 0x07280b08, 0x286425ad, 0x0d252a12,   // ca.af.nl_222 es.sw.it_443  eu.lg.sw_643 mt.eu.cs_654
  // [ba40]
  0x216428ad, 0x1c251f0c, 0x07190a02, 0x2155285a,   // sw.lg.jw_643 cy.eu.id_543  pt.gl.it_222 sw.rw.jw_553
  0x162a17a7, 0x21281305, 0x64092507, 0x0b1e23a0,   // sr.mt.hr_532 et.sw.jw_333  eu.pl.lg_432 ca.ms.es_322
  0x1907160c, 0x053f1007, 0x166b17a0, 0x062d0f07,   // hr.it.gl_543 lt.af.fr_432  sr.ceb.hr_322 lv.sk.de_432
  0x1c006e08, 0x1f0728ec, 0x27291807, 0x0b181aa0,   // blu.id.un_430 sw.it.cy_644  ga.sl.gd_432 tl.ga.es_322
  // [ba50]
  0x160410a0, 0x20000805, 0x0b1a2508, 0x19011ea0,   // lt.fi.hr_322 no.sq.un_330  eu.tl.es_443 ms.en.gl_322
  0x5528250e, 0x21000309, 0x13120ca9, 0x190b27ee,   // eu.sw.rw_555 nl.jw.un_440  sv.hu.et_544 gd.es.gl_422
  0x0f181104, 0x131c0d05, 0x01271112, 0x27181908,   // ro.ga.lv_332 ne.mr.bh_333  ro.gd.en_654 gl.ga.gd_443
  0x18033f08, 0x281b1e07, 0x1a016b5a, 0x1a001b0d,   // af.nl.ga_443 ms.tr.sw_432  ceb.en.tl_553 tr.tl.un_540
  // [ba60]
  0x641b31ee, 0x64281a04, 0x1b6b1aa9, 0x1b6b28a4,   // az.tr.lg_422 tl.sw.lg_332  tl.ceb.tr_544 sw.ceb.tr_433
  0x02001609, 0x3f2718ad, 0x551b3104, 0x21551a0c,   // hr.da.un_440 ga.gd.af_643  az.tr.rw_332 tl.rw.jw_543
  0x130b180c, 0x1c212809, 0x1e1c64a4, 0x1a00310c,   // ga.es.et_543 sw.jw.id_444  lg.id.ms_433 az.tl.un_530
  0x04641309, 0x53000b0d, 0x04080ea7, 0x311a1baf,   // et.lg.fi_444 es.ht.un_540  is.no.fi_532 tr.tl.az_655
  // [ba70]
  0x311e1b08, 0x080e5508, 0x1b211a0c, 0x060301af,   // tr.ms.az_443 rw.is.no_443  tl.jw.tr_543 en.nl.de_655
  0x12101fa4, 0x2d2708a0, 0x2d051255, 0x640425a0,   // cy.lt.hu_433 no.gd.sk_322  hu.fr.sk_442 eu.fi.lg_322
  0x12640307, 0x0d022d0c, 0x07001f0e, 0x6b000909,   // nl.lg.hu_432 sk.da.cs_543  cy.it.un_550 pl.ceb.un_440
  0x3f060e0c, 0x29160faf, 0x0e3f08a4, 0x09001f08,   // is.de.af_543 lv.hr.sl_655  no.af.is_433 cy.pl.un_430
  // [ba80]
  0x531101ee, 0x052b07a0, 0x1f1a1007, 0x2a000814,   // en.ro.ht_422 it.vi.fr_322  lt.tl.cy_432 no.mt.un_660
  0x6b0a07a0, 0x1f531307, 0x216b10a0, 0x0d2b0f05,   // it.pt.ceb_322 et.ht.cy_432  lt.ceb.jw_322 lv.vi.cs_333
  0x19180b02, 0x11001f12, 0x0e033f07, 0x2a050111,   // es.ga.gl_222 cy.ro.un_640  af.nl.is_432 en.fr.mt_653
  0x0d190ea4, 0x0c0a1104, 0x23001119, 0x1a6b06ad,   // is.gl.cs_433 ro.pt.sv_332  ro.ca.un_750 de.ceb.tl_643
  // [ba90]
  0x23192d02, 0x04033fa4, 0x190523a4, 0x230b190c,   // sk.gl.ca_222 af.nl.fi_433  ca.fr.gl_433 gl.es.ca_543
  0x29000507, 0x07001a1a, 0x120a190c, 0x23110b07,   // fr.sl.un_420 tl.it.un_760  gl.pt.hu_543 es.ro.ca_432
  0x0f0c08ee, 0x19230b08, 0x3f001309, 0x061808a4,   // no.sv.lv_422 es.ca.gl_443  et.af.un_440 no.ga.de_433
  0x6e210e05, 0x0e1a0b09, 0x3f6e6b55, 0x096b6404,   // is.jw.blu_333 es.tl.is_444  ceb.blu.af_442 lg.ceb.pl_332
  // [baa0]
  0x2b130708, 0x12190b0d, 0x0311250c, 0x11006b02,   // it.et.vi_443 es.gl.hu_554  eu.ro.nl_543 ceb.ro.un_220
  0x192d0ba6, 0x6400090d, 0x053125a0, 0x080a17ad,   // es.sk.gl_521 pl.lg.un_540  eu.az.fr_322 sr.mk.uk_643
  0x050306a4, 0x23180d0c, 0x180e12a9, 0x182d0d14,   // de.nl.fr_433 cs.ga.ca_543  hu.is.ga_544 cs.sk.ga_666
  0x31125302, 0x533f095a, 0x28250f07, 0x12190a02,   // ht.hu.az_222 pl.af.ht_553  lv.eu.sw_432 pt.gl.hu_222
  // [bab0]
  0x1e1c31a0, 0x0a2d1204, 0x29080205, 0x02060302,   // az.id.ms_322 hu.sk.pt_332  da.no.sl_333 nl.de.da_222
  0x17040a13, 0x2508040c, 0x130f1013, 0x10091908,   // mk.ru.sr_665 fi.no.eu_543  lt.lv.et_665 gl.pl.lt_443
  0x280f0d09, 0x13091c05, 0x0b20190d, 0x0e1304a4,   // cs.lv.sw_444 mr.hi.bh_333  gl.sq.es_554 fi.et.is_433
  0x281204ee, 0x55000512, 0x07130407, 0x29080e0c,   // fi.hu.sw_422 fr.rw.un_640  fi.et.it_432 is.no.sl_543
  // [bac0]
  0x08641214, 0x2a1f190b, 0x23172007, 0x29190b02,   // hu.lg.no_666 gl.cy.mt_542  sq.sr.ca_432 es.gl.sl_222
  0x19211c0c, 0x0c271809, 0x100907ad, 0x13050408,   // id.jw.gl_543 ga.gd.sv_444  it.pl.lt_643 fi.fr.et_443
  0x0a00120c, 0x1305045a, 0x3f18270d, 0x2800111a,   // hu.pt.un_530 fi.fr.et_553  gd.ga.af_554 ro.sw.un_760
  0x03062855, 0x070604a4, 0x07000c19, 0x6b1a1bec,   // sw.de.nl_442 fi.de.it_433  sv.it.un_750 tr.tl.ceb_644
  // [bad0]
  0x071328a6, 0x1e1c1bec, 0x28641a05, 0x08000107,   // sw.et.it_521 tr.id.ms_644  tl.lg.sw_333 en.no.un_420
  0x100d0f04, 0x13080507, 0x1e1c08a0, 0x100f090c,   // lv.cs.lt_332 fr.no.et_432  no.id.ms_322 pl.lv.lt_543
  0x13006409, 0x09001a0c, 0x0e001b21, 0x170d16af,   // lg.et.un_440 tl.pl.un_530  tr.is.un_860 hr.cs.sr_655
  0x020e0c04, 0x1a646b04, 0x101b6b07, 0x052512ad,   // sv.is.da_332 ceb.lg.tl_332  ceb.tr.lt_432 hu.eu.fr_643
  // [bae0]
  0x2d020607, 0x090d0eac, 0x210602a0, 0x251c21a0,   // de.da.sk_432 is.cs.pl_632  da.de.jw_322 jw.id.eu_322
  0x2d000508, 0x21162504, 0x0a17115a, 0x5300291a,   // fr.sk.un_430 eu.hr.jw_332  ro.sr.mk_553 sl.ht.un_760
  0x2d002a08, 0x2a003f0e, 0x081b020c, 0x0a08170e,   // mt.sk.un_430 af.mt.un_550  da.tr.no_543 sr.uk.mk_555
  0x021b030c, 0x0300040d, 0x080e020e, 0x05001b04,   // nl.tr.da_543 fi.nl.un_540  da.is.no_555 tr.fr.un_320
  // [baf0]
  0x0e000823, 0x04071013, 0x2721180c, 0x080704a6,   // no.is.un_880 be.bg.ru_665  ga.jw.gd_543 ru.bg.uk_521
  0x03041202, 0x081f18a7, 0x083f0cee, 0x11000802,   // hu.fi.nl_222 ga.cy.no_532  sv.af.no_422 no.ro.un_220
  0x0d2917a4, 0x1c3f2107, 0x27211f07, 0x2500280e,   // sr.sl.cs_433 jw.af.id_432  cy.jw.gd_432 sw.eu.un_550
  0x0e063f02, 0x0a2d23af, 0x2d000f08, 0x216b10a4,   // af.de.is_222 ca.sk.pt_655  lv.sk.un_430 lt.ceb.jw_433
  // [bb00]
  0x2a3f09ad, 0x11121ba4, 0x08031bee, 0x120f29a7,   // pl.af.mt_643 tr.hu.ro_433  tr.nl.no_422 sl.lv.hu_532
  0x06001004, 0x122b1fa0, 0x131108a4, 0x0f002d05,   // lt.de.un_320 cy.vi.hu_322  no.ro.et_433 sk.lv.un_330
  0x6b04550c, 0x2700182a, 0x13212807, 0x190e1207,   // rw.fi.ceb_543 ga.gd.un_970  sw.jw.et_432 hu.is.gl_432
  0x64211e07, 0x190a2d0e, 0x02211cee, 0x090718af,   // ms.jw.lg_432 sk.pt.gl_555  id.jw.da_422 ga.it.pl_655
  // [bb10]
  0x3f210605, 0x3f001314, 0x07235355, 0x190b1114,   // de.jw.af_333 et.af.un_660  ht.ca.it_442 ro.es.gl_666
  0x21286408, 0x17001635, 0x181013a4, 0x171b200b,   // lg.sw.jw_443 hr.sr.un_A90  et.lt.ga_433 sq.tr.sr_542
  0x1c2a280b, 0x2564090e, 0x0b190d07, 0x2d0a23af,   // sw.mt.id_542 pl.lg.eu_555  cs.gl.es_432 ca.pt.sk_655
  0x131204ee, 0x180e2d07, 0x2a3155a9, 0x160c0e0d,   // fi.hu.et_422 sk.is.ga_432  rw.az.mt_544 is.sv.hr_554
  // [bb20]
  0x28552a5a, 0x06030202, 0x0a000e07, 0x55002009,   // mt.rw.sw_553 da.nl.de_222  is.pt.un_420 sq.rw.un_440
  0x1e1101a0, 0x55002a02, 0x190a5514, 0x2d0d23a0,   // en.ro.ms_322 mt.rw.un_220  rw.pt.gl_666 ca.cs.sk_322
  0x04101308, 0x230b12ec, 0x280855a0, 0x251205a4,   // et.lt.fi_443 hu.es.ca_644  rw.no.sw_322 fr.hu.eu_433
  0x6e005522, 0x292d200c, 0x29172d12, 0x2300090c,   // rw.blu.un_870 sq.sk.sl_543  sk.sr.sl_654 pl.ca.un_530
  // [bb30]
  0x6e006409, 0x0a00231a, 0x11000705, 0x64535507,   // lg.blu.un_440 ca.pt.un_760  it.ro.un_330 rw.ht.lg_432
  0x100e0c09, 0x02290dee, 0x05000802, 0x0d102d12,   // sv.is.lt_444 cs.sl.da_422  no.fr.un_220 sk.lt.cs_654
  0x2a00210d, 0x2d0d1fec, 0x1e121ca0, 0x251205ee,   // jw.mt.un_540 cy.cs.sk_644  id.hu.ms_322 fr.hu.eu_422
  0x55000704, 0x10090f0c, 0x0500100d, 0x6b0f0304,   // it.rw.un_320 lv.pl.lt_543  lt.fr.un_540 nl.lv.ceb_332
  // [bb40]
  0x19211204, 0x0f250607, 0x093f0ea4, 0x092a0faf,   // hu.jw.gl_332 de.eu.lv_432  is.af.pl_433 lv.mt.pl_655
  0x282506a0, 0x0900020d, 0x23093fa4, 0x0a28205a,   // de.eu.sw_322 da.pl.un_540  af.pl.ca_433 sq.sw.pt_553
  0x10090f12, 0x23181108, 0x273f03a9, 0x0d011802,   // lv.pl.lt_654 ro.ga.ca_443  nl.af.gd_544 ga.en.cs_222
  0x29186ba0, 0x09000f1a, 0x100409ee, 0x555305ee,   // ceb.ga.sl_322 lv.pl.un_760  pl.fi.lt_422 fr.ht.rw_422
  // [bb50]
  0x2300011a, 0x033f0dad, 0x090f050c, 0x1008070c,   // en.ca.un_760 cs.af.nl_643  fr.lv.pl_543 bg.uk.be_543
  0x2d2b0d05, 0x09000f12, 0x28005511, 0x645505a0,   // cs.vi.sk_333 lv.pl.un_640  rw.sw.un_630 fr.rw.lg_322
  0x05075507, 0x2b000719, 0x131e2aa6, 0x0f1813a4,   // rw.it.fr_432 it.vi.un_750  mt.ms.et_521 et.ga.lv_433
  0x10130f0c, 0x53036404, 0x273f0c05, 0x530208ad,   // lv.et.lt_543 lg.nl.ht_332  sv.af.gd_333 no.da.ht_643
  // [bb60]
  0x1f006e13, 0x100f0ba4, 0x276b1a04, 0x08001312,   // blu.cy.un_650 es.lv.lt_433  tl.ceb.gd_332 et.no.un_640
  0x1720290b, 0x12081102, 0x3f121007, 0x19122daf,   // sl.sq.sr_542 ro.no.hu_222  lt.hu.af_432 sk.hu.gl_655
  0x09101104, 0x10642807, 0x1b0931a0, 0x2d090d07,   // ro.lt.pl_332 sw.lg.lt_432  az.pl.tr_322 cs.pl.sk_432
  0x2d0d2304, 0x2d001914, 0x011105ee, 0x55311105,   // ca.cs.sk_332 gl.sk.un_660  fr.ro.en_422 ro.az.rw_333
  // [bb70]
  0x170a080b, 0x192d120d, 0x28182a02, 0x11072504,   // uk.mk.sr_542 hu.sk.gl_554  mt.ga.sw_222 eu.it.ro_332
  0x036e2b04, 0x130e1f08, 0x10001118, 0x13312d02,   // vi.blu.nl_332 cy.is.et_443  ro.be.un_740 sk.az.et_222
  0x28001205, 0x1a285307, 0x0e1a0804, 0x6b556412,   // hu.sw.un_330 ht.sw.tl_432  no.tl.is_332 lg.rw.ceb_654
  0x6b001e22, 0x2d160d05, 0x17001c04, 0x0b070505,   // ms.ceb.un_870 cs.hr.sk_333  id.sr.un_320 fr.it.es_333
  // [bb80]
  0x1e2d1ca7, 0x1c202807, 0x2a1f25af, 0x180b1907,   // id.sk.ms_532 sw.sq.id_432  eu.cy.mt_655 gl.es.ga_432
  0x64001e02, 0x0600250d, 0x210e17a0, 0x31281ca0,   // ms.lg.un_220 eu.de.un_540  sr.is.jw_322 id.sw.az_322
  0x10000e0d, 0x06001708, 0x01271105, 0x050753ec,   // is.lt.un_540 sr.de.un_430  ro.gd.en_333 ht.it.fr_644
  0x1f1a27a0, 0x64530f07, 0x282d0d04, 0x1e1c1a02,   // gd.tl.cy_322 lv.ht.lg_432  cs.sk.sw_332 tl.id.ms_222
  // [bb90]
  0x0e556407, 0x3f1207a4, 0x28005518, 0x060309a0,   // lg.rw.is_432 it.hu.af_433  rw.sw.un_740 pl.nl.de_322
  0x021121a0, 0x060809a0, 0x282021a7, 0x2000530b,   // jw.ro.da_322 pl.no.de_322  jw.sq.sw_532 ht.sq.un_520
  0x11121ea0, 0x070e53ad, 0x042a1012, 0x531221ee,   // ms.hu.ro_322 ht.is.it_643  lt.mt.fi_654 jw.hu.ht_422
  0x09030404, 0x213f2aa7, 0x2d100f09, 0x09102d12,   // fi.nl.pl_332 mt.af.jw_532  lv.lt.sk_444 sk.lt.pl_654
  // [bba0]
  0x01096407, 0x2a091f12, 0x25033fee, 0x08283f08,   // lg.pl.en_432 cy.pl.mt_654  af.nl.eu_422 af.sw.no_443
  0x17161b02, 0x1f00642a, 0x06181204, 0x291655a4,   // tr.hr.sr_222 lg.cy.un_970  hu.ga.de_332 rw.hr.sl_433
  0x0900551b, 0x3f00101a, 0x085355a6, 0x020603a0,   // rw.pl.un_770 lt.af.un_760  rw.ht.no_521 nl.de.da_322
  0x04530904, 0x102816a4, 0x06192aa0, 0x19120a02,   // pl.ht.fi_332 hr.sw.lt_433  mt.gl.de_322 pt.hu.gl_222
  // [bbb0]
  0x0b101704, 0x55062807, 0x1300280e, 0x0a280405,   // sr.lt.es_332 sw.de.rw_432  sw.et.un_550 fi.sw.pt_333
  0x642855a9, 0x0f1710a4, 0x1e1c04a9, 0x171310a9,   // rw.sw.lg_544 lt.sr.lv_433  fi.id.ms_544 lt.et.sr_544
  0x276b04ee, 0x12190b0c, 0x05070aa4, 0x12051902,   // fi.ceb.gd_422 es.gl.hu_543  pt.it.fr_433 gl.fr.hu_222
  0x55172807, 0x0819230c, 0x53212511, 0x12190b09,   // sw.sr.rw_432 ca.gl.no_543  eu.jw.ht_653 es.gl.hu_444
  // [bbc0]
  0x101701a0, 0x216b1a05, 0x28040305, 0x16005509,   // en.sr.lt_322 tl.ceb.jw_333  nl.fi.sw_333 rw.hr.un_440
  0x1f2827ee, 0x2d0916a0, 0x31002511, 0x2d0c120d,   // gd.sw.cy_422 hr.pl.sk_322  eu.az.un_630 hu.sv.sk_554
  0x1b0a25ac, 0x0b181904, 0x29160fa4, 0x2a00190d,   // eu.pt.tr_632 gl.ga.es_332  lv.hr.sl_433 gl.mt.un_540
  0x03062aa4, 0x07002d07, 0x16202905, 0x291127a0,   // mt.de.nl_433 sk.it.un_420  sl.sq.hr_333 gd.ro.sl_322
  // [bbd0]
  0x27000e07, 0x550a5307, 0x0e001b1a, 0x1b080e12,   // is.gd.un_420 ht.pt.rw_432  tr.is.un_760 is.no.tr_654
  0x2505110b, 0x0a0810ee, 0x1713290c, 0x05182507,   // ro.fr.eu_542 be.uk.mk_422  sl.et.sr_543 eu.ga.fr_432
  0x0d2d0c0c, 0x1b000e22, 0x06000505, 0x161b0e12,   // sv.sk.cs_543 is.tr.un_870  fr.de.un_330 is.tr.hr_654
  0x28126ea4, 0x3f1025ee, 0x0c6412ad, 0x070b0504,   // blu.hu.sw_433 eu.lt.af_422  hu.lg.sv_643 fr.es.it_332
  // [bbe0]
  0x2a00530d, 0x23001808, 0x0e000d02, 0x2d080255,   // ht.mt.un_540 ga.ca.un_430  cs.is.un_220 da.no.sk_442
  0x28236407, 0x11051304, 0x101105a4, 0x1f280802,   // lg.ca.sw_432 et.fr.ro_332  fr.ro.lt_433 no.sw.cy_222
  0x13001f11, 0x28030407, 0x1b556407, 0x13001f0c,   // cy.et.un_630 fi.nl.sw_432  lg.rw.tr_432 cy.et.un_530
  0x1312060c, 0x10000f20, 0x3f280355, 0x0e1b0904,   // de.hu.et_543 lv.lt.un_850  nl.sw.af_442 pl.tr.is_332
  // [bbf0]
  0x28256bee, 0x06100fa4, 0x10006408, 0x2a00090e,   // ceb.eu.sw_422 lv.lt.de_433  lg.lt.un_430 pl.mt.un_550
  0x21135304, 0x100a19a9, 0x1100190c, 0x0603050c,   // ht.et.jw_332 gl.pt.lt_544  gl.ro.un_530 fr.nl.de_543
  0x04170811, 0x18190a09, 0x04080ea9, 0x18276e12,   // uk.sr.ru_653 pt.gl.ga_444  is.no.fi_544 blu.gd.ga_654
  0x201304ee, 0x02001704, 0x1f2710a4, 0x011a0ea0,   // fi.et.sq_422 sr.da.un_320  lt.gd.cy_433 is.tl.en_322

  // [bc00]
  0x162921a9, 0x1309040d, 0x190a0fa4, 0x2900160b,   // jw.sl.hr_544 fi.pl.et_554  lv.pt.gl_433 hr.sl.un_520
  0x0f190a5a, 0x2a0e0807, 0x100f1960, 0x0a230b04,   // pt.gl.lv_553 no.is.mt_432  gl.lv.lt_664 es.ca.pt_332
  0x1a102aee, 0x080c6ba4, 0x100f05a4, 0x641f210c,   // mt.lt.tl_422 ceb.sv.no_433  fr.lv.lt_433 jw.cy.lg_543
  0x180f1009, 0x10000509, 0x131004ee, 0x100a230c,   // lt.lv.ga_444 fr.lt.un_440  fi.lt.et_422 ca.pt.lt_543
  // [bc10]
  0x0e3f290c, 0x10170aaf, 0x18000504, 0x06002807,   // sl.af.is_543 mk.sr.be_655  fr.ga.un_320 sw.de.un_420
  0x2a001a12, 0x0c002013, 0x04101755, 0x1b1a01ee,   // tl.mt.un_640 sq.sv.un_650  sr.be.ru_442 en.tl.tr_422
  0x55042760, 0x1b25550c, 0x18201ba4, 0x0e0c08a7,   // gd.fi.rw_664 rw.eu.tr_543  tr.sq.ga_433 no.sv.is_532
  0x2d0d25a4, 0x0a0708a7, 0x556e6412, 0x1a206412,   // eu.cs.sk_433 uk.bg.mk_532  lg.blu.rw_654 lg.sq.tl_654
  // [bc20]
  0x0d001e02, 0x2d172104, 0x2a1e1c0e, 0x1b3108a0,   // ms.cs.un_220 jw.sr.sk_332  id.ms.mt_555 no.az.tr_322
  0x0f1a1f5a, 0x0e0c0813, 0x283f0804, 0x180105a0,   // cy.tl.lv_553 no.sv.is_665  no.af.sw_332 fr.en.ga_322
  0x080e100d, 0x29002d23, 0x2164200c, 0x17201008,   // lt.is.no_554 sk.sl.un_880  sq.lg.jw_543 lt.sq.sr_443
  0x55080c0c, 0x286425ec, 0x2a2031a0, 0x1a6b1b07,   // sv.no.rw_543 eu.lg.sw_644  az.sq.mt_322 tr.ceb.tl_432
  // [bc30]
  0x641a1e0c, 0x13211c08, 0x21311ba4, 0x20001105,   // ms.tl.lg_543 id.jw.et_443  tr.az.jw_433 ro.sq.un_330
  0x10040711, 0x052b07ee, 0x31005512, 0x311b550c,   // bg.ru.be_653 it.vi.fr_422  rw.az.un_640 rw.tr.az_543
  0x03003f20, 0x55121e55, 0x0e111bad, 0x1c1f64a4,   // af.nl.un_850 ms.hu.rw_442  tr.ro.is_643 lg.cy.id_433
  0x211a64a9, 0x1b315305, 0x2a1f6404, 0x1e005504,   // lg.tl.jw_544 ht.az.tr_333  lg.cy.mt_332 rw.ms.un_320
  // [bc40]
  0x31551b0c, 0x1b551605, 0x311b55a7, 0x0a000809,   // tr.rw.az_543 hr.rw.tr_333  rw.tr.az_532 no.pt.un_440
  0x190127a0, 0x1f1308ee, 0x270b0a0b, 0x230b0aec,   // gd.en.gl_322 no.et.cy_422  pt.es.gd_542 pt.es.ca_644
  0x2a275302, 0x1b006e08, 0x27002319, 0x31202aa7,   // ht.gd.mt_222 blu.tr.un_430  ca.gd.un_750 mt.sq.az_532
  0x010b2ba0, 0x1f00040d, 0x0f640707, 0x0b0a230e,   // vi.es.en_322 fi.cy.un_540  it.lg.lv_432 ca.pt.es_555
  // [bc50]
  0x3f0f1aa7, 0x212520ad, 0x1f23110c, 0x2300250e,   // tl.lv.af_532 sq.eu.jw_643  ro.ca.cy_543 eu.ca.un_550
  0x1a000f0e, 0x6b251807, 0x1f1123ac, 0x20090fec,   // lv.tl.un_550 ga.eu.ceb_432  ca.ro.cy_632 lv.pl.sq_644
  0x25081f11, 0x10271811, 0x2b316e0c, 0x1b0a1fa0,   // cy.no.eu_653 ga.gd.lt_653  blu.az.vi_543 cy.pt.tr_322
  0x0f130805, 0x230b0a0e, 0x290f16ee, 0x05120a05,   // no.et.lv_333 pt.es.ca_555  hr.lv.sl_422 pt.hu.fr_333
  // [bc60]
  0x045528ee, 0x02010e04, 0x0f133f55, 0x212a310c,   // sw.rw.fi_422 is.en.da_332  af.et.lv_442 az.mt.jw_543
  0x55135311, 0x645521a9, 0x13041608, 0x1b0c2ba4,   // ht.et.rw_653 jw.rw.lg_544  hr.fi.et_443 vi.sv.tr_433
  0x21002b18, 0x031b02a0, 0x080f3fa0, 0x640f08a7,   // vi.jw.un_740 da.tr.nl_322  af.lv.no_322 no.lv.lg_532
  0x05191207, 0x3f2821ad, 0x2900250d, 0x3f64550c,   // hu.gl.fr_432 jw.sw.af_643  eu.sl.un_540 rw.lg.af_543
  // [bc70]
  0x5508640c, 0x080a04ac, 0x20006408, 0x080e120c,   // lg.no.rw_543 ru.mk.uk_632  lg.sq.un_430 hu.is.no_543
  0x12042a07, 0x1e2028ee, 0x1a3f6ba0, 0x645328a7,   // mt.fi.hu_432 sw.sq.ms_422  ceb.af.tl_322 sw.ht.lg_532
  0x1a0d6ba7, 0x12003f1b, 0x64161712, 0x04551307,   // ceb.cs.tl_532 af.hu.un_770  sr.hr.lg_654 et.rw.fi_432
  0x1c1308ee, 0x0c001a02, 0x1f090d04, 0x011a5307,   // no.et.id_422 tl.sv.un_220  cs.pl.cy_332 ht.tl.en_432
  // [bc80]
  0x1f080260, 0x1c213fad, 0x02211c55, 0x041716ad,   // da.no.cy_664 af.jw.id_643  id.jw.da_442 hr.sr.fi_643
  0x122921a4, 0x28006433, 0x55536ba0, 0x0d001f05,   // jw.sl.hu_433 lg.sw.un_A70  ceb.ht.rw_322 cy.cs.un_330
  0x1e091cee, 0x0e0a05ee, 0x2a001213, 0x211b31af,   // id.pl.ms_422 fr.pt.is_422  hu.mt.un_650 az.tr.jw_655
  0x190a1c02, 0x1e1c1baf, 0x0b1716a0, 0x0a1831ee,   // id.pt.gl_222 tr.id.ms_655  hr.sr.es_322 az.ga.pt_422
  // [bc90]
  0x2d0d120c, 0x1f530504, 0x1308110c, 0x080a1e04,   // hu.cs.sk_543 fr.ht.cy_332  ro.no.et_543 ms.pt.no_332
  0x05111902, 0x23181007, 0x1b000620, 0x0e050b05,   // gl.ro.fr_222 lt.ga.ca_432  de.tr.un_850 es.fr.is_333
  0x21530f07, 0x041009ee, 0x3f04090c, 0x55122105,   // lv.ht.jw_432 pl.lt.fi_422  pl.fi.af_543 jw.hu.rw_333
  0x09010202, 0x1e1b3155, 0x04003f1b, 0x6b311ba0,   // da.en.pl_222 az.tr.ms_442  af.fi.un_770 tr.az.ceb_322
  // [bca0]
  0x1b17160c, 0x1a003107, 0x1006090c, 0x2b1e1c0e,   // hr.sr.tr_543 az.tl.un_420  pl.de.lt_543 id.ms.vi_555
  0x1c111e04, 0x3f1105a4, 0x1e136407, 0x100925a7,   // ms.ro.id_332 fr.ro.af_433  lg.et.ms_432 eu.pl.lt_532
  0x03291004, 0x2b1a010c, 0x53052804, 0x28022ba0,   // lt.sl.nl_332 en.tl.vi_543  sw.fr.ht_332 vi.da.sw_322
  0x171f25ad, 0x08211c07, 0x190b18ec, 0x0b0a200c,   // eu.cy.sr_643 id.jw.no_432  ga.es.gl_644 sq.pt.es_543
  // [bcb0]
  0x100a175a, 0x0f040907, 0x271b1812, 0x1a6b01ad,   // sr.mk.be_553 pl.fi.lv_432  ga.tr.gd_654 en.ceb.tl_643
  0x10093f0c, 0x07020b02, 0x29180aa0, 0x02292a0d,   // af.pl.lt_543 es.da.it_222  pt.ga.sl_322 mt.sl.da_554
  0x20272102, 0x271b3108, 0x270818ec, 0x192164a4,   // jw.gd.sq_222 az.tr.gd_443  ga.no.gd_644 lg.jw.gl_433
  0x191b0aa0, 0x1b002022, 0x531b0d07, 0x230a20ec,   // pt.tr.gl_322 sq.tr.un_870  cs.tr.ht_432 sq.pt.ca_644
  // [bcc0]
  0x01071ea0, 0x290727a0, 0x0b0a050e, 0x0e29080c,   // ms.it.en_322 gd.it.sl_322  fr.pt.es_555 no.sl.is_543
  0x02003f11, 0x1c0405a0, 0x0c0104ee, 0x2a0c0e07,   // af.da.un_630 fr.fi.id_322  fi.en.sv_422 is.sv.mt_432
  0x08100a02, 0x170d16ad, 0x1000200e, 0x25001b08,   // mk.be.uk_222 hr.cs.sr_643  sq.lt.un_550 tr.eu.un_430
  0x03093fa4, 0x31000c02, 0x28001108, 0x17110a04,   // af.pl.nl_433 sv.az.un_220  ro.sw.un_430 mk.ro.sr_332
  // [bcd0]
  0x1a010455, 0x292d1f0c, 0x210e1208, 0x10040aad,   // fi.en.tl_442 cy.sk.sl_543  hu.is.jw_443 mk.ru.be_643
  0x1a105304, 0x060102a0, 0x1e0121a0, 0x071b04a0,   // ht.lt.tl_332 da.en.de_322  jw.en.ms_322 fi.tr.it_322
  0x31005307, 0x19080c12, 0x3f0a19ad, 0x0700101b,   // ht.az.un_420 sv.no.gl_654  gl.pt.af_643 be.bg.un_770
  0x29000904, 0x531107a0, 0x17100411, 0x01181f08,   // pl.sl.un_320 it.ro.ht_322  ru.be.sr_653 cy.ga.en_443
  // [bce0]
  0x2d0d16a9, 0x0b05010c, 0x1b0c0a07, 0x28012a12,   // hr.cs.sk_544 en.fr.es_543  pt.sv.tr_432 mt.en.sw_654
  0x2a3f0312, 0x2b000107, 0x0e000b08, 0x0200531a,   // nl.af.mt_654 en.vi.un_420  es.is.un_430 ht.da.un_760
  0x290a23ee, 0x276e01ee, 0x211a6b09, 0x1a6b280c,   // ca.pt.sl_422 en.blu.gd_422  ceb.tl.jw_444 sw.ceb.tl_543
  0x2d050d04, 0x0a04100d, 0x2a1a53a4, 0x1b645505,   // cs.fr.sk_332 be.ru.mk_554  ht.tl.mt_433 rw.lg.tr_333
  // [bcf0]
  0x1c645511, 0x25090407, 0x28000f0c, 0x53166407,   // rw.lg.id_653 fi.pl.eu_432  lv.sw.un_530 lg.hr.ht_432
  0x2a1e1c0d, 0x20006402, 0x170708a6, 0x2a6b06ee,   // id.ms.mt_554 lg.sq.un_220  uk.bg.sr_521 de.ceb.mt_422
  0x07041fee, 0x09280407, 0x6e2a5308, 0x1e002812,   // cy.fi.it_422 fi.sw.pl_432  ht.mt.blu_443 sw.ms.un_640
  0x1f0413a4, 0x2a290daf, 0x08022dec, 0x1e311ca9,   // et.fi.cy_433 cs.sl.mt_655  sk.da.no_644 id.az.ms_544
  // [bd00]
  0x530f2104, 0x18072704, 0x6e002713, 0x3f2d03ee,   // jw.lv.ht_332 gd.it.ga_332  gd.blu.un_650 nl.sk.af_422
  0x05000909, 0x18000e1a, 0x533f03a0, 0x0900061b,   // pl.fr.un_440 is.ga.un_760  nl.af.ht_322 de.pl.un_770
  0x1f00280c, 0x250f0107, 0x032a09ad, 0x02072a08,   // sw.cy.un_530 en.lv.eu_432  pl.mt.nl_643 mt.it.da_443
  0x3f0304ee, 0x5300090e, 0x2a1007af, 0x2d00081a,   // fi.nl.af_422 pl.ht.un_550  it.lt.mt_655 no.sk.un_760
  // [bd10]
  0x64531b11, 0x55090f0c, 0x090f0608, 0x070f53a0,   // tr.ht.lg_653 lv.pl.rw_543  de.lv.pl_443 ht.lv.it_322
  0x6b5364ad, 0x080217ec, 0x10070fa0, 0x1c1f18a0,   // lg.ht.ceb_643 sr.da.no_644  lv.it.lt_322 ga.cy.id_322
  0x070a10ec, 0x28271a0c, 0x6b211a0d, 0x13001b05,   // be.mk.bg_644 tl.gd.sw_543  tl.jw.ceb_554 tr.et.un_330
  0x0c0e1e04, 0x0c2d0dad, 0x170a08a7, 0x1e271cee,   // ms.is.sv_332 cs.sk.sv_643  uk.mk.sr_532 id.gd.ms_422
  // [bd20]
  0x230f1807, 0x29171a07, 0x040717a9, 0x2a050eaf,   // ga.lv.ca_432 tl.sr.sl_432  sr.bg.ru_544 is.fr.mt_655
  0x281255ee, 0x5320040c, 0x1e1c1ba4, 0x230f1055,   // rw.hu.sw_422 fi.sq.ht_543  tr.id.ms_433 lt.lv.ca_442
  0x211f19a0, 0x1e0d0304, 0x21082004, 0x13001b0e,   // gl.cy.jw_322 nl.cs.ms_332  sq.no.jw_332 tr.et.un_550
  0x1a0901a0, 0x0e00290e, 0x1e002b02, 0x27006b07,   // en.pl.tl_322 sl.is.un_550  vi.ms.un_220 ceb.gd.un_420
  // [bd30]
  0x022d0107, 0x6b033f0b, 0x2b001a2a, 0x2000100c,   // en.sk.da_432 af.nl.ceb_542  tl.vi.un_970 lt.sq.un_530
  0x052b010c, 0x040717ac, 0x211a2b55, 0x18002b18,   // en.vi.fr_543 sr.bg.ru_632  vi.tl.jw_442 vi.ga.un_740
  0x2a212ba7, 0x1f531e12, 0x12212304, 0x292d01a0,   // vi.jw.mt_532 ms.ht.cy_654  ca.jw.hu_332 en.sk.sl_322
  0x07001f05, 0x03005307, 0x0d2b130b, 0x060e0809,   // cy.it.un_330 ht.nl.un_420  et.vi.cs_542 no.is.de_444
  // [bd40]
  0x0e0b06a0, 0x210701a4, 0x132b21ad, 0x202113a7,   // de.es.is_322 en.it.jw_433  jw.vi.et_643 et.jw.sq_532
  0x0b16200c, 0x281716ee, 0x07000508, 0x070d53a9,   // sq.hr.es_543 hr.sr.sw_422  fr.it.un_430 ht.cs.it_544
  0x6e002b12, 0x3f64210c, 0x2b3f1aa4, 0x2d1119a7,   // vi.blu.un_640 jw.lg.af_543  tl.af.vi_433 gl.ro.sk_532
  0x04130ea4, 0x060d16a0, 0x0c1716ad, 0x040f2aa4,   // is.et.fi_433 hr.cs.de_322  hr.sr.sv_643 mt.lv.fi_433
  // [bd50]
  0x3f1716ee, 0x0f002a0d, 0x0f072a08, 0x130719a4,   // hr.sr.af_422 mt.lv.un_540  mt.it.lv_443 gl.it.et_433
  0x232564a0, 0x64553fa9, 0x641311a4, 0x0a2019a4,   // lg.eu.ca_322 af.rw.lg_544  ro.et.lg_433 gl.sq.pt_433
  0x0f17160e, 0x292307a0, 0x28002707, 0x190f0da4,   // hr.sr.lv_555 it.ca.sl_322  gd.sw.un_420 cs.lv.gl_433
  0x2a003f13, 0x53131104, 0x0d000e08, 0x203f0311,   // af.mt.un_650 ro.et.ht_332  is.cs.un_430 nl.af.sq_653
  // [bd60]
  0x2800040c, 0x1f000602, 0x1f2d0d0d, 0x1c00092b,   // fi.sw.un_530 de.cy.un_220  cs.sk.cy_554 hi.mr.un_980
  0x13002822, 0x190f2d04, 0x2a003f20, 0x28000505,   // sw.et.un_870 sk.lv.gl_332  af.mt.un_850 fr.sw.un_330
  0x31555302, 0x12000107, 0x0b3f1055, 0x21002b08,   // ht.rw.az_222 en.hu.un_420  lt.af.es_442 vi.jw.un_430
  0x210227a0, 0x28002304, 0x28002704, 0x251208ee,   // gd.da.jw_322 ca.sw.un_320  gd.sw.un_320 no.hu.eu_422
  // [bd70]
  0x18080207, 0x6b2a1a08, 0x0f100407, 0x0c0602ee,   // da.no.ga_432 tl.mt.ceb_443  fi.lt.lv_432 da.de.sv_422
  0x6e000207, 0x12002313, 0x080209a0, 0x1008110c,   // da.blu.un_420 ca.hu.un_650  pl.da.no_322 ro.no.lt_543
  0x04131004, 0x21041307, 0x211e1a0c, 0x1e086ba0,   // lt.et.fi_332 et.fi.jw_432  tl.ms.jw_543 ceb.no.ms_322
  0x12111907, 0x6b1a11ad, 0x1f1b0cee, 0x0400280e,   // gl.ro.hu_432 ro.tl.ceb_643  sv.tr.cy_422 sw.fi.un_550
  // [bd80]
  0x19002b02, 0x10000605, 0x0b0e1aa4, 0x2d162905,   // vi.gl.un_220 de.lt.un_330  tl.is.es_433 sl.hr.sk_333
  0x6b1a21ad, 0x0c060813, 0x29120da0, 0x281a2160,   // jw.tl.ceb_643 no.de.sv_665  cs.hu.sl_322 jw.tl.sw_664
  0x11000b1b, 0x13080cad, 0x0b0a08ee, 0x0e2308a0,   // es.ro.un_770 sv.no.et_643  no.pt.es_422 no.ca.is_322
  0x1b230c07, 0x1f291607, 0x0f1025ac, 0x1e000f12,   // sv.ca.tr_432 hr.sl.cy_432  eu.lt.lv_632 lv.ms.un_640
  // [bd90]
  0x25000d08, 0x0a1708ee, 0x55001f02, 0x201f0e0c,   // cs.eu.un_430 uk.sr.mk_422  cy.rw.un_220 is.cy.sq_543
  0x53291612, 0x175316ad, 0x0d0913a7, 0x01001307,   // hr.sl.ht_654 hr.ht.sr_643  et.pl.cs_532 et.en.un_420
  0x201b1704, 0x02033f04, 0x23001120, 0x0f172aa0,   // sr.tr.sq_332 af.nl.da_332  ro.ca.un_850 mt.sr.lv_322
  0x310f1207, 0x091312a0, 0x2a1a01ee, 0x29071104,   // hu.lv.az_432 hu.et.pl_322  en.tl.mt_422 ro.it.sl_332
  // [bda0]
  0x1c2a0da0, 0x021206ac, 0x2a0553a4, 0x2a6b550b,   // cs.mt.id_322 de.hu.da_632  ht.fr.mt_433 rw.ceb.mt_542
  0x17100a0b, 0x28211eac, 0x05271baf, 0x21001f0e,   // mk.be.sr_542 ms.jw.sw_632  tr.gd.fr_655 cy.jw.un_550
  0x02033f12, 0x0a0710ec, 0x0e001207, 0x28271a04,   // af.nl.da_654 be.bg.mk_644  hu.is.un_420 tl.gd.sw_332
  0x0e002d08, 0x202a07ec, 0x64011a08, 0x13121f0c,   // sk.is.un_430 it.mt.sq_644  tl.en.lg_443 cy.hu.et_543
  // [bdb0]
  0x276b1a55, 0x046b1a07, 0x0c001f18, 0x28101112,   // tl.ceb.gd_442 tl.ceb.fi_432  cy.sv.un_740 ro.lt.sw_654
  0x12040604, 0x55006e08, 0x206b1a0c, 0x12061fa6,   // de.fi.hu_332 blu.rw.un_430  tl.ceb.sq_543 cy.de.hu_521
  0x1b041f08, 0x10281107, 0x551e64a9, 0x1a206bac,   // cy.fi.tr_443 ro.sw.lt_432  lg.ms.rw_544 ceb.sq.tl_632
  0x090408ec, 0x282d64ee, 0x1a046404, 0x3f0e120c,   // no.fi.pl_644 lg.sk.sw_422  lg.fi.tl_332 hu.is.af_543
  // [bdc0]
  0x3f2a01a0, 0x53092104, 0x041e1c02, 0x29171f07,   // en.mt.af_322 jw.pl.ht_332  id.ms.fi_222 cy.sr.sl_432
  0x0c532008, 0x25000b1a, 0x270711a6, 0x05025312,   // sq.ht.sv_443 es.eu.un_760  ro.it.gd_521 ht.da.fr_654
  0x272028a4, 0x31281b13, 0x2500231a, 0x31091207,   // sw.sq.gd_433 tr.sw.az_665  ca.eu.un_760 hu.pl.az_432
  0x2b64050b, 0x171104af, 0x0b006b09, 0x3f641f07,   // fr.lg.vi_542 ru.ro.sr_655  ceb.es.un_440 cy.lg.af_432
  // [bdd0]
  0x18002814, 0x101704ee, 0x210112a4, 0x163f02ee,   // sw.ga.un_660 ru.sr.be_422  hu.en.jw_433 da.af.hr_422
  0x09041fad, 0x0d6b1aec, 0x130910ac, 0x08121b05,   // cy.fi.pl_643 tl.ceb.cs_644  lt.pl.et_632 tr.hu.no_333
  0x551b280c, 0x211a28ec, 0x0b006407, 0x1c130d07,   // sw.tr.rw_543 sw.tl.jw_644  lg.es.un_420 ne.bh.mr_432
  0x186b27ec, 0x20002122, 0x0f530107, 0x25190a02,   // gd.ceb.ga_644 jw.sq.un_870  en.ht.lv_432 pt.gl.eu_222
  // [bde0]
  0x12000a0b, 0x0a000607, 0x03052aee, 0x1e211aa9,   // pt.hu.un_520 de.pt.un_420  mt.fr.nl_422 tl.jw.ms_544
  0x10282da0, 0x532104ec, 0x2a003102, 0x552a2512,   // sk.sw.lt_322 fi.jw.ht_644  az.mt.un_220 eu.mt.rw_654
  0x2a230eee, 0x17160da6, 0x6b641ca4, 0x646b1a60,   // is.ca.mt_422 cs.hr.sr_521  id.lg.ceb_433 tl.ceb.lg_664
  0x0b033f55, 0x052904a0, 0x0b20050d, 0x20000528,   // af.nl.es_442 fi.sl.fr_322  fr.sq.es_554 fr.sq.un_950
  // [bdf0]
  0x25001005, 0x2d0d53ac, 0x21050a11, 0x17642907,   // lt.eu.un_330 ht.cs.sk_632  pt.fr.jw_653 sl.lg.sr_432
  0x033f1804, 0x106b0802, 0x20001007, 0x122013a7,   // ga.af.nl_332 no.ceb.lt_222  lt.sq.un_420 et.sq.hu_532
  0x2a001211, 0x286b1012, 0x0c1f3f0c, 0x0a0d05ee,   // hu.mt.un_630 lt.ceb.sw_654  af.cy.sv_543 fr.cs.pt_422
  0x100425a9, 0x04102804, 0x160f1007, 0x0e001f14,   // eu.fi.lt_544 sw.lt.fi_332  lt.lv.hr_432 cy.is.un_660
  // [be00]
  0x031106ee, 0x10530f07, 0x29210d0c, 0x1c011204,   // de.ro.nl_422 lv.ht.lt_432  cs.jw.sl_543 hu.en.id_332
  0x17182d07, 0x1a3f12ee, 0x31271e05, 0x552528ee,   // sk.ga.sr_432 hu.af.tl_422  ms.gd.az_333 sw.eu.rw_422
  0x01280604, 0x64216ba0, 0x16172d04, 0x64023fa4,   // de.sw.en_332 ceb.jw.lg_322  sk.sr.hr_332 af.da.lg_433
  0x07271908, 0x182a2807, 0x03183fa4, 0x6b001b1a,   // gl.gd.it_443 sw.mt.ga_432  af.ga.nl_433 tr.ceb.un_760
  // [be10]
  0x110325a0, 0x06010507, 0x0a001810, 0x281f18a0,   // eu.nl.ro_322 fr.en.de_432  ga.pt.un_620 ga.cy.sw_322
  0x01033f05, 0x04120807, 0x0300640b, 0x0b0723ec,   // af.nl.en_333 no.hu.fi_432  lg.nl.un_520 ca.it.es_644
  0x29001c08, 0x04080309, 0x530819ee, 0x04001102,   // id.sl.un_430 nl.no.fi_444  gl.no.ht_422 ro.fi.un_220
  0x296425ee, 0x040b13af, 0x0f00251a, 0x1f1b20a4,   // eu.lg.sl_422 et.es.fi_655  eu.lv.un_760 sq.tr.cy_433
  // [be20]
  0x3f1808a4, 0x25072d07, 0x111229af, 0x120e0fa7,   // no.ga.af_433 sk.it.eu_432  sl.hu.ro_655 lv.is.hu_532
  0x01060505, 0x09002822, 0x02000e08, 0x29281a0c,   // fr.de.en_333 sw.pl.un_870  is.da.un_430 tl.sw.sl_543
  0x20001c0d, 0x531a1605, 0x04081111, 0x1b110107,   // id.sq.un_540 hr.tl.ht_333  ro.uk.ru_653 en.ro.tr_432
  0x111b2104, 0x0b120507, 0x0a170802, 0x0d2a076c,   // jw.tr.ro_332 fr.hu.es_432  uk.sr.mk_222 it.mt.cs_873
  // [be30]
  0x0f00120d, 0x00001242, 0x060c01ee, 0x083f6404,   // hu.lv.un_540 ur.un.un_C00  en.sv.de_422 lg.af.no_332
  0x08060208, 0x20536ba9, 0x18000f19, 0x081f2555,   // da.de.no_443 ceb.ht.sq_544  lv.ga.un_750 eu.cy.no_442
  0x066b1ca4, 0x201208a9, 0x06001a09, 0x1c2153a4,   // id.ceb.de_433 no.hu.sq_544  tl.de.un_440 ht.jw.id_433
  0x122b0107, 0x2a18010c, 0x312853ee, 0x2053010b,   // en.vi.hu_432 en.ga.mt_543  ht.sw.az_422 en.ht.sq_542
  // [be40]
  0x273f2107, 0x1b0e1fa7, 0x12040608, 0x16003f14,   // jw.af.gd_432 cy.is.tr_532  de.fi.hu_443 af.hr.un_660
  0x1f5321a9, 0x2a002809, 0x126b1aaf, 0x641e21a0,   // jw.ht.cy_544 sw.mt.un_440  tl.ceb.hu_655 jw.ms.lg_322
  0x290c0211, 0x0c53010c, 0x231b3109, 0x02203107,   // da.sv.sl_653 en.ht.sv_543  az.tr.ca_444 az.sq.da_432
  0x08280cad, 0x20230704, 0x21176405, 0x64551a07,   // sv.sw.no_643 it.ca.sq_332  lg.sr.jw_333 tl.rw.lg_432
  // [be50]
  0x3f21280d, 0x25641bad, 0x250f01a9, 0x2053070c,   // sw.jw.af_554 tr.lg.eu_643  en.lv.eu_544 it.ht.sq_543
  0x6b002822, 0x64211a55, 0x2d280713, 0x2b000f04,   // sw.ceb.un_870 tl.jw.lg_442  it.sw.sk_665 lv.vi.un_320
  0x280306a7, 0x033f2707, 0x093f0fee, 0x12006414,   // de.nl.sw_532 gd.af.nl_432  lv.af.pl_422 lg.hu.un_660
  0x25210707, 0x160f2908, 0x3f1b0305, 0x2d1612ee,   // it.jw.eu_432 sl.lv.hr_443  nl.tr.af_333 hu.hr.sk_422
  // [be60]
  0x1304190c, 0x03060f07, 0x04072a12, 0x3f0f080c,   // gl.fi.et_543 lv.de.nl_432  mt.it.fi_654 no.lv.af_543
  0x12211907, 0x0c211ea0, 0x2d271855, 0x6b1a550c,   // gl.jw.hu_432 ms.jw.sv_322  ga.gd.sk_442 rw.tl.ceb_543
  0x0d102da0, 0x0d29080b, 0x0a101714, 0x20182711,   // sk.lt.cs_322 no.sl.cs_542  sr.be.mk_666 gd.ga.sq_653
  0x1c2110af, 0x191f08a0, 0x0c3f0302, 0x0c2112a7,   // lt.jw.id_655 no.cy.gl_322  nl.af.sv_222 hu.jw.sv_532
  // [be70]
  0x2d0d0ba4, 0x0c086e04, 0x071108a4, 0x042153a4,   // es.cs.sk_433 blu.no.sv_332  uk.ro.bg_433 ht.jw.fi_433
  0x1e1c2160, 0x6b005522, 0x28292107, 0x53002b12,   // jw.id.ms_664 rw.ceb.un_870  jw.sl.sw_432 vi.ht.un_640
  0x551b040c, 0x55002120, 0x02080d11, 0x0d2104ee,   // fi.tr.rw_543 jw.rw.un_850  cs.no.da_653 fi.jw.cs_422
  0x13002113, 0x2b000e07, 0x640e3fa0, 0x080c01a0,   // jw.et.un_650 is.vi.un_420  af.is.lg_322 en.sv.no_322
  // [be80]
  0x16136b07, 0x19550455, 0x555321a4, 0x16080c0c,   // ceb.et.hr_432 fi.rw.gl_442  jw.ht.rw_433 sv.no.hr_543
  0x01211ea4, 0x200c2102, 0x12010604, 0x03002513,   // ms.jw.en_433 jw.sv.sq_222  de.en.hu_332 eu.nl.un_650
  0x190b64ee, 0x0e002b09, 0x2500310d, 0x0811105a,   // lg.es.gl_422 vi.is.un_440  az.eu.un_540 be.ro.uk_553
  0x1a0121a7, 0x0320210c, 0x0f050708, 0x210c2a09,   // jw.en.tl_532 jw.sq.nl_543  it.fr.lv_443 mt.sv.jw_444
  // [be90]
  0x103f21a4, 0x2d180e55, 0x21101ea0, 0x2900211a,   // jw.af.lt_433 is.ga.sk_442  ms.lt.jw_322 jw.sl.un_760
  0x161a6ba0, 0x3f2b01a0, 0x0d0c0307, 0x23000402,   // ceb.tl.hr_322 en.vi.af_322  nl.sv.cs_432 fi.ca.un_220
  0x550128ee, 0x1a2b1c07, 0x2d2901a7, 0x033f0905,   // sw.en.rw_422 id.vi.tl_432  en.sl.sk_532 pl.af.nl_333
  0x2b211a11, 0x311e0307, 0x0700121a, 0x6b6e2ba7,   // tl.jw.vi_653 nl.ms.az_432  hu.it.un_760 vi.blu.ceb_532
  // [bea0]
  0x10290f0c, 0x06072911, 0x110a0760, 0x1c2b21af,   // lv.sl.lt_543 sl.it.de_653  bg.mk.ro_664 jw.vi.id_655
  0x112a07a4, 0x2000071a, 0x2d180d09, 0x27000713,   // it.mt.ro_433 it.sq.un_760  cs.ga.sk_444 it.gd.un_650
  0x6e3f2b13, 0x021a2b07, 0x2d002804, 0x280f6408,   // vi.af.blu_665 vi.tl.da_432  sw.sk.un_320 lg.lv.sw_443
  0x101664a4, 0x07002812, 0x2d032004, 0x55281904,   // lg.hr.lt_433 sw.it.un_640  sq.nl.sk_332 gl.sw.rw_332
  // [beb0]
  0x0f060c02, 0x28106408, 0x64283113, 0x0a042705,   // sv.de.lv_222 lg.lt.sw_443  az.sw.lg_665 gd.fi.pt_333
  0x2a0821ee, 0x02083f04, 0x0611070c, 0x55311b08,   // jw.no.mt_422 af.no.da_332  it.ro.de_543 tr.az.rw_443
  0x112901a4, 0x2310040c, 0x12001b21, 0x1b282007,   // en.sl.ro_433 fi.lt.ca_543  tr.hu.un_860 sq.sw.tr_432
  0x281309ee, 0x1b013f07, 0x0c100f0b, 0x55000612,   // pl.et.sw_422 af.en.tr_432  lv.lt.sv_542 de.rw.un_640
  // [bec0]
  0x12001609, 0x0c041608, 0x1b640407, 0x20080412,   // hr.hu.un_440 hr.fi.sv_443  fi.lg.tr_432 fi.no.sq_654
  0x0e1b0707, 0x19530ba9, 0x53002319, 0x280e20ac,   // it.tr.is_432 es.ht.gl_544  ca.ht.un_750 sq.is.sw_632
  0x200812ad, 0x16000808, 0x091716a6, 0x0f0c0204,   // hu.no.sq_643 no.hr.un_430  hr.sr.pl_521 da.sv.lv_332
  0x1a31280c, 0x2d0d0ead, 0x161217ec, 0x12230ba7,   // sw.az.tl_543 is.cs.sk_643  sr.hu.hr_644 es.ca.hu_532
  // [bed0]
  0x12201608, 0x16082007, 0x08000f07, 0x112005af,   // hr.sq.hu_443 sq.no.hr_432  lv.no.un_420 fr.sq.ro_655
  0x1a00210c, 0x2d160dec, 0x0d000108, 0x170710a4,   // jw.tl.un_530 cs.hr.sk_644  en.cs.un_430 be.bg.sr_433
  0x052b0a02, 0x53092a0c, 0x0a215504, 0x11070555,   // pt.vi.fr_222 mt.pl.ht_543  rw.jw.pt_332 fr.it.ro_442
  0x100a070d, 0x191f0ba0, 0x081106a0, 0x06083f08,   // bg.mk.be_554 es.cy.gl_322  de.ro.no_322 af.no.de_443
  // [bee0]
  0x120b19ad, 0x2d070d07, 0x190b0fa4, 0x02000511,   // gl.es.hu_643 cs.it.sk_432  lv.es.gl_433 fr.da.un_630
  0x0d0911a4, 0x2307050c, 0x531628ec, 0x06311bad,   // ro.pl.cs_433 fr.it.ca_543  sw.hr.ht_644 tr.az.de_643
  0x11170409, 0x0b2319a6, 0x20000c19, 0x0f0d1704,   // ru.sr.ro_444 gl.ca.es_521  sv.sq.un_750 sr.cs.lv_332
  0x1b001121, 0x1f063fee, 0x19000a10, 0x13121104,   // ro.tr.un_860 af.de.cy_422  pt.gl.un_620 ro.hu.et_332
  // [bef0]
  0x04100a12, 0x3f1106ee, 0x3f00080e, 0x12001321,   // mk.be.ru_654 de.ro.af_422  no.af.un_550 et.hu.un_860
  0x1a0501ad, 0x160d0fec, 0x092d12a0, 0x13171609,   // en.fr.tl_643 lv.cs.hr_644  hu.sk.pl_322 hr.sr.et_444
  0x101204a0, 0x2b121102, 0x31000c12, 0x2a161ea4,   // fi.hu.lt_322 ro.hu.vi_222  sv.az.un_640 ms.hr.mt_433
  0x050b230c, 0x292a1608, 0x290531a0, 0x20000604,   // ca.es.fr_543 hr.mt.sl_443  az.fr.sl_322 de.sq.un_320
  // [bf00]
  0x1e642812, 0x1c001607, 0x136455a0, 0x29281609,   // sw.lg.ms_654 hr.id.un_420  rw.lg.et_322 hr.sw.sl_444
  0x281201ad, 0x17111607, 0x0a1117ad, 0x120413a0,   // en.hu.sw_643 hr.ro.sr_432  sr.ro.mk_643 et.fi.hu_322
  0x2a13255a, 0x13060ca9, 0x31292d11, 0x25002308,   // eu.et.mt_553 sv.de.et_544  sk.sl.az_653 ca.eu.un_430
  0x31292da9, 0x071116a4, 0x07291609, 0x0e021204,   // sk.sl.az_544 hr.ro.it_433  hr.sl.it_444 hu.da.is_332
  // [bf10]
  0x312d290d, 0x0f002d0c, 0x0c252355, 0x07000a36,   // sl.sk.az_554 sk.lv.un_530  ca.eu.sv_442 mk.bg.un_AA0
  0x100f020c, 0x31292d0c, 0x2d311105, 0x0e2a2307,   // da.lv.lt_543 sk.sl.az_543  ro.az.sk_333 ca.mt.is_432
  0x2d29175a, 0x0b12250b, 0x29312d13, 0x316e2da6,   // sr.sl.sk_553 eu.hu.es_542  sk.az.sl_665 sk.blu.az_521
  0x1306250c, 0x1c000102, 0x23190b5a, 0x0c2007ee,   // eu.de.et_543 en.id.un_220  es.gl.ca_553 it.sq.sv_422
  // [bf20]
  0x010321a0, 0x0d292d5a, 0x2155280b, 0x31292d13,   // jw.nl.en_322 sk.sl.cs_553  sw.rw.jw_542 sk.sl.az_665
  0x181b1604, 0x11292d0c, 0x1f002b04, 0x1f012aa4,   // hr.tr.ga_332 sk.sl.ro_543  vi.cy.un_320 mt.en.cy_433
  0x171608a9, 0x0d102905, 0x0a2307a7, 0x04110a09,   // no.hr.sr_544 sl.lt.cs_333  it.ca.pt_532 mk.ro.ru_444
  0x2a2911a7, 0x0c1304a0, 0x190b2bb2, 0x20003f0e,   // ro.sl.mt_532 fi.et.sv_322  vi.es.gl_732 af.sq.un_550
  // [bf30]
  0x063f08a0, 0x29030804, 0x3100292b, 0x060e3f07,   // no.af.de_322 no.nl.sl_332  sl.az.un_980 af.is.de_432
  0x1b0813a4, 0x0a230708, 0x04002805, 0x010221a0,   // et.no.tr_433 it.ca.pt_443  sw.fi.un_330 jw.da.en_322
  0x02060eee, 0x0e201008, 0x110821ee, 0x551c1eee,   // is.de.da_422 lt.sq.is_443  jw.no.ro_422 ms.id.rw_422
  0x180b19a0, 0x1f2701a9, 0x31005312, 0x02001f19,   // gl.es.ga_322 en.gd.cy_544  ht.az.un_640 cy.da.un_750
  // [bf40]
  0x1e002304, 0x2d29100b, 0x311a20af, 0x1719160c,   // ca.ms.un_320 lt.sl.sk_542  sq.tl.az_655 hr.gl.sr_543
  0x201b31af, 0x25002005, 0x29202d07, 0x1e200da0,   // az.tr.sq_655 sq.eu.un_330  sk.sq.sl_432 cs.sq.ms_322
  0x042118a7, 0x0e051f09, 0x0e001002, 0x0e3f010c,   // ga.jw.fi_532 cy.fr.is_444  lt.is.un_220 en.af.is_543
  0x10531fa4, 0x182d0aa7, 0x55001211, 0x10092004,   // cy.ht.lt_433 pt.sk.ga_532  hu.rw.un_630 sq.pl.lt_332
  // [bf50]
  0x1a1b310d, 0x1119130c, 0x110a10ec, 0x312a23a4,   // az.tr.tl_554 et.gl.ro_543  be.mk.ro_644 ca.mt.az_433
  0x195313a4, 0x0d31045a, 0x1c1716ee, 0x1f1a1c07,   // et.ht.gl_433 fi.az.cs_553  hr.sr.id_422 id.tl.cy_432
  0x1a2001a0, 0x19130107, 0x286421ad, 0x04003121,   // en.sq.tl_322 en.et.gl_432  jw.lg.sw_643 az.fi.un_860
  0x201a0d07, 0x13011904, 0x103125a4, 0x20003114,   // cs.tl.sq_432 gl.en.et_332  eu.az.lt_433 az.sq.un_660
  // [bf60]
  0x216419a0, 0x070a10ac, 0x086e6ba4, 0x110119ee,   // gl.lg.jw_322 be.mk.bg_632  ceb.blu.no_433 gl.en.ro_422
  0x0e00641b, 0x6b000714, 0x06201109, 0x0d000804,   // lg.is.un_770 it.ceb.un_660  ro.sq.de_444 no.cs.un_320
  0x18012aa0, 0x1a1f200b, 0x0d1729ad, 0x1e1225ee,   // mt.en.ga_322 sq.cy.tl_542  sl.sr.cs_643 eu.hu.ms_422
  0x0b13190d, 0x1f1e1c07, 0x645521ec, 0x21131907,   // gl.et.es_554 id.ms.cy_432  jw.rw.lg_644 gl.et.jw_432
  // [bf70]
  0x1e0c0107, 0x5301190c, 0x211308a0, 0x19005307,   // en.sv.ms_432 gl.en.ht_543  no.et.jw_322 ht.gl.un_420
  0x29001612, 0x6b2513a6, 0x2d0d20ac, 0x1a1b0107,   // hr.sl.un_640 et.eu.ceb_521  sq.cs.sk_632 en.tr.tl_432
  0x2b2821a9, 0x1a1f1c07, 0x131b2aee, 0x033f2a07,   // jw.sw.vi_544 id.cy.tl_432  mt.tr.et_422 mt.af.nl_432
  0x100f1aa0, 0x0c115355, 0x0b0a08a0, 0x040c0202,   // tl.lv.lt_322 ht.ro.sv_442  no.pt.es_322 da.sv.fi_222
  // [bf80]
  0x03040607, 0x072301a0, 0x251c0eee, 0x086b2507,   // de.fi.nl_432 en.ca.it_322  is.id.eu_422 eu.ceb.no_432
  0x1b000807, 0x072d0d09, 0x13082007, 0x1a001c07,   // no.tr.un_420 cs.sk.it_444  sq.no.et_432 id.tl.un_420
  0x53250ba7, 0x12131008, 0x110e0907, 0x0f16170c,   // es.eu.ht_532 lt.et.hu_443  pl.is.ro_432 sr.hr.lv_543
  0x080231ee, 0x190a0955, 0x07110ba4, 0x531b5512,   // az.da.no_422 pl.pt.gl_442  es.ro.it_433 rw.tr.ht_654
  // [bf90]
  0x0e002d13, 0x16000d0c, 0x1f1b310c, 0x20551104,   // sk.is.un_650 cs.hr.un_530  az.tr.cy_543 ro.rw.sq_332
  0x1b311c05, 0x25130d07, 0x05002a07, 0x256455ee,   // id.az.tr_333 cs.et.eu_432  mt.fr.un_420 rw.lg.eu_422
  0x10080aad, 0x01001c07, 0x09642511, 0x1f000702,   // mk.uk.be_643 id.en.un_420  eu.lg.pl_653 it.cy.un_220
  0x061104ad, 0x04171060, 0x530d55a4, 0x091c16a0,   // fi.ro.de_643 be.sr.ru_664  rw.cs.ht_433 hr.id.pl_322
  // [bfa0]
  0x1b00180d, 0x0e002d11, 0x080a0409, 0x55282514,   // ga.tr.un_540 sk.is.un_630  ru.mk.uk_444 eu.sw.rw_666
  0x532029a0, 0x20290707, 0x072320ec, 0x1304080d,   // sl.sq.ht_322 it.sl.sq_432  sq.ca.it_644 no.fi.et_554
  0x0b000609, 0x112b1ca0, 0x01051fa0, 0x17552004,   // de.es.un_440 id.vi.ro_322  cy.fr.en_322 sq.rw.sr_332
  0x0b645511, 0x0d000e20, 0x060c5302, 0x031321a0,   // rw.lg.es_653 is.cs.un_850  ht.sv.de_222 jw.et.nl_322
  // [bfb0]
  0x03253f07, 0x13006422, 0x28033fad, 0x641e0407,   // af.eu.nl_432 lg.et.un_870  af.nl.sw_643 fi.ms.lg_432
  0x3f002519, 0x090618a0, 0x253f0308, 0x1a002012,   // eu.af.un_750 ga.de.pl_322  nl.af.eu_443 sq.tl.un_640
  0x232105a7, 0x1c003f1a, 0x2b0353a0, 0x1b130807,   // fr.jw.ca_532 af.id.un_760  ht.nl.vi_322 no.et.tr_432
  0x3f25030e, 0x2a120305, 0x25003f19, 0x1e1c0609,   // nl.eu.af_555 nl.hu.mt_333  af.eu.un_750 de.id.ms_444
  // [bfc0]
  0x080c3fa7, 0x03083fec, 0x04130e05, 0x180802af,   // af.sv.no_532 af.no.nl_644  is.et.fi_333 da.no.ga_655
  0x0d020307, 0x210853ec, 0x02030c09, 0x0e181fad,   // nl.da.cs_432 ht.no.jw_644  sv.nl.da_444 cy.ga.is_643
  0x111c1ea7, 0x04065512, 0x6427185a, 0x3f0802a0,   // ms.id.ro_532 rw.de.fi_654  ga.gd.lg_553 da.no.af_322
  0x02271807, 0x0f2006a4, 0x1b000b02, 0x11200608,   // ga.gd.da_432 de.sq.lv_433  es.tr.un_220 de.sq.ro_443
  // [bfd0]
  0x050364a6, 0x1c0655a4, 0x1b123105, 0x102d2905,   // lg.nl.fr_521 rw.de.id_433  az.hu.tr_333 sl.sk.lt_333
  0x16132d04, 0x1002040c, 0x010f28ee, 0x07640107,   // sk.et.hr_332 fi.da.lt_543  sw.lv.en_422 en.lg.it_432
  0x210c08ec, 0x21080c04, 0x132a070c, 0x55281102,   // no.sv.jw_644 sv.no.jw_332  it.mt.et_543 ro.sw.rw_222
  0x051e1c14, 0x11000202, 0x28006e0c, 0x130f0807,   // id.ms.fr_666 da.ro.un_220  blu.sw.un_530 no.lv.et_432
  // [bfe0]
  0x5564210c, 0x056b1a04, 0x093f10ee, 0x1a642155,   // jw.lg.rw_543 tl.ceb.fr_332  lt.af.pl_422 jw.lg.tl_442
  0x11025507, 0x17100aa6, 0x23000a2b, 0x10110a08,   // rw.da.ro_432 mk.be.sr_521  pt.ca.un_980 mk.ro.be_443
  0x532d0d09, 0x64001a14, 0x0b0511ad, 0x1008290c,   // cs.sk.ht_444 tl.lg.un_660  ro.fr.es_643 sl.no.lt_543
  0x06002d0c, 0x6b021a07, 0x3f000d02, 0x3f0806a0,   // sk.de.un_530 tl.da.ceb_432  cs.af.un_220 de.no.af_322
  // [bff0]
  0x1a1207a0, 0x205528a0, 0x161c2902, 0x090f1012,   // it.hu.tl_322 sw.rw.sq_322  sl.id.hr_222 lt.lv.pl_654
  0x04001a23, 0x270c1f02, 0x0d002105, 0x020e0c02,   // tl.fi.un_880 cy.sv.gd_222  jw.cs.un_330 sv.is.da_222
  0x2a000809, 0x076b1a08, 0x1a0e0cee, 0x0e0b19a9,   // no.mt.un_440 tl.ceb.it_443  sv.is.tl_422 gl.es.is_544
  0x0c0206a0, 0x1f021b05, 0x013f1a07, 0x3f2a0912,   // de.da.sv_322 tr.da.cy_333  tl.af.en_432 pl.mt.af_654

  // [c000]
  0x186b01ee, 0x0f0804ee, 0x072a3f07, 0x13081bad,   // en.ceb.ga_422 fi.no.lv_422  af.mt.it_432 tr.no.et_643
  0x0800290c, 0x171b0fa4, 0x0c081012, 0x6b1a070c,   // sl.no.un_530 lv.tr.sr_433  lt.no.sv_654 it.tl.ceb_543
  0x20130404, 0x06120207, 0x04000508, 0x252a1b0c,   // fi.et.sq_332 da.hu.de_432  fr.fi.un_430 tr.mt.eu_543
  0x21000305, 0x1b211e05, 0x1a556b0b, 0x311828a0,   // nl.jw.un_330 ms.jw.tr_333  ceb.rw.tl_542 sw.ga.az_322
  // [c010]
  0x20121bee, 0x255364a4, 0x13041f07, 0x020412a0,   // tr.hu.sq_422 lg.ht.eu_433  cy.fi.et_432 hu.fi.da_322
  0x210413ee, 0x1e081bac, 0x1f0e0408, 0x0f101308,   // et.fi.jw_422 tr.no.ms_632  fi.is.cy_443 et.lt.lv_443
  0x0a0723a0, 0x08000f04, 0x181f27a4, 0x17161ba4,   // ca.it.pt_322 lv.no.un_320  gd.cy.ga_433 tr.hr.sr_433
  0x161b3f0c, 0x10020d07, 0x27011207, 0x55252808,   // af.tr.hr_543 cs.da.lt_432  hu.en.gd_432 sw.eu.rw_443
  // [c020]
  0x13271f07, 0x0700012b, 0x0a1711a9, 0x0c020da4,   // cy.gd.et_432 en.it.un_980  ro.sr.mk_544 cs.da.sv_433
  0x0400200c, 0x0f002919, 0x20000e09, 0x6e53290c,   // sq.fi.un_530 sl.lv.un_750  is.sq.un_440 sl.ht.blu_543
  0x020c0dec, 0x0c120e04, 0x0e0c0410, 0x20000f05,   // cs.sv.da_644 is.hu.sv_332  fi.sv.is_642 lv.sq.un_330
  0x6b171604, 0x2d090d13, 0x04000e0c, 0x112d0d13,   // hr.sr.ceb_332 cs.pl.sk_665  is.fi.un_530 cs.sk.ro_665
  // [c030]
  0x270c23ee, 0x2d160d07, 0x040717af, 0x31006e2a,   // ca.sv.gd_422 cs.hr.sk_432  sr.bg.ru_655 blu.az.un_970
  0x080229ec, 0x1113530b, 0x090d1707, 0x2a2304ad,   // sl.da.no_644 ht.et.ro_542  sr.cs.pl_432 fi.ca.mt_643
  0x0620110c, 0x11001221, 0x08000411, 0x0c0818ee,   // ro.sq.de_543 hu.ro.un_860  ru.uk.un_630 ga.no.sv_422
  0x0b000d04, 0x2a281807, 0x08010755, 0x64000802,   // cs.es.un_320 ga.sw.mt_432  it.en.no_442 no.lg.un_220
  // [c040]
  0x6b002a05, 0x3f0813a9, 0x2804130c, 0x1f090ea4,   // mt.ceb.un_330 et.no.af_544  et.fi.sw_543 is.pl.cy_433
  0x3f000408, 0x250c0ba0, 0x042513af, 0x031a6b07,   // fi.af.un_430 es.sv.eu_322  et.eu.fi_655 ceb.tl.nl_432
  0x13033f0d, 0x1c2d10a0, 0x070e120c, 0x1e1c1802,   // af.nl.et_554 lt.sk.id_322  hu.is.it_543 ga.id.ms_222
  0x0a003f02, 0x28002a1b, 0x3f64280c, 0x3f130360,   // af.pt.un_220 mt.sw.un_770  sw.lg.af_543 nl.et.af_664
  // [c050]
  0x012b1b07, 0x64001b22, 0x031304a7, 0x0e080ca9,   // tr.vi.en_432 tr.lg.un_870  fi.et.nl_532 sv.no.is_544
  0x012313a7, 0x13043f12, 0x01070baf, 0x11061304,   // et.ca.en_532 af.fi.et_654  es.it.en_655 et.de.ro_332
  0x030e05ee, 0x04530d13, 0x0f001a09, 0x1a3110a9,   // fr.is.nl_422 cs.ht.fi_665  tl.lv.un_440 lt.az.tl_544
  0x0b1827a0, 0x311a105a, 0x280c2508, 0x21281b0d,   // gd.ga.es_322 lt.tl.az_553  eu.sv.sw_443 tr.sw.jw_554
  // [c060]
  0x1a551009, 0x1b1021ad, 0x13101ca0, 0x1a006e08,   // lt.rw.tl_444 jw.lt.tr_643  id.lt.et_322 blu.tl.un_430
  0x17000907, 0x111a100c, 0x1b3110a4, 0x0d002302,   // pl.sr.un_420 lt.tl.ro_543  lt.az.tr_433 ca.cs.un_220
  0x080c0e04, 0x6e6b0804, 0x04091ba7, 0x2100230c,   // is.sv.no_332 no.ceb.blu_332  tr.pl.fi_532 ca.jw.un_530
  0x20282107, 0x53000d1a, 0x1f18230c, 0x2d1b100c,   // jw.sw.sq_432 cs.ht.un_760  ca.ga.cy_543 lt.tr.sk_543
  // [c070]
  0x2d0d53ec, 0x1f2109ad, 0x08111602, 0x1b311012,   // ht.cs.sk_644 pl.jw.cy_643  hr.ro.no_222 lt.az.tr_654
  0x10311b0e, 0x101b3113, 0x04250804, 0x251b12ad,   // tr.az.lt_555 az.tr.lt_665  no.eu.fi_332 hu.tr.eu_643
  0x11211c07, 0x3100200e, 0x312821a0, 0x201028af,   // id.jw.ro_432 sq.az.un_550  jw.sw.az_322 sw.lt.sq_655
  0x130f1112, 0x1625280b, 0x1c281e07, 0x6b280404,   // ro.lv.et_654 sw.eu.hr_542  ms.sw.id_432 fi.sw.ceb_332
  // [c080]
  0x182701a0, 0x0e111708, 0x0708230c, 0x08530107,   // en.gd.ga_322 sr.ro.is_443  ca.no.it_543 en.ht.no_432
  0x0c080fa0, 0x03001e05, 0x0d092a55, 0x130e04af,   // lv.no.sv_322 ms.nl.un_330  mt.pl.cs_442 fi.is.et_655
  0x2d0d2ba9, 0x311112a7, 0x101e1ca4, 0x0e171002,   // vi.cs.sk_544 hu.ro.az_532  id.ms.lt_433 lt.sr.is_222
  0x29201604, 0x0b0a1aa0, 0x2d280f07, 0x11001b04,   // hr.sq.sl_332 tl.pt.es_322  lv.sw.sk_432 tr.ro.un_320
  // [c090]
  0x550928ad, 0x17100aad, 0x641a55a7, 0x171004a6,   // sw.pl.rw_643 mk.be.sr_643  rw.tl.lg_532 ru.be.sr_521
  0x0f6b5304, 0x1f0818a4, 0x112801a0, 0x1a005302,   // ht.ceb.lv_332 ga.no.cy_433  en.sw.ro_322 ht.tl.un_220
  0x08641207, 0x0e002805, 0x2d0d28ee, 0x3f5302ee,   // hu.lg.no_432 sw.is.un_330  sw.cs.sk_422 da.ht.af_422
  0x132a55ec, 0x0a110409, 0x21282011, 0x1c2718a6,   // rw.mt.et_644 ru.ro.mk_444  sq.sw.jw_653 ga.gd.id_521
  // [c0a0]
  0x0e0a0b07, 0x1b2506a4, 0x23180d04, 0x1c000922,   // es.pt.is_432 de.eu.tr_433  cs.ga.ca_332 hi.mr.un_870
  0x08122505, 0x1225280c, 0x0a182704, 0x2d2a1807,   // eu.hu.no_333 sw.eu.hu_543  gd.ga.pt_332 ga.mt.sk_432
  0x2700250c, 0x286b1aa0, 0x02200c04, 0x2d00090b,   // eu.gd.un_530 tl.ceb.sw_322  sv.sq.da_332 pl.sk.un_520
  0x18270d02, 0x063f12a7, 0x1b0d100c, 0x2d3f0304,   // cs.gd.ga_222 hu.af.de_532  lt.cs.tr_543 nl.af.sk_332
  // [c0b0]
  0x3f2d0fa7, 0x3f2d0308, 0x3f000907, 0x121c1f07,   // lv.sk.af_532 nl.sk.af_443  pl.af.un_420 cy.id.hu_432
  0x1012250c, 0x1b032dac, 0x2d250302, 0x550723ad,   // eu.hu.lt_543 sk.nl.tr_632  nl.eu.sk_222 ca.it.rw_643
  0x29002721, 0x182d20ee, 0x1b000e08, 0x1e1c2aa4,   // gd.sl.un_860 sq.sk.ga_422  is.tr.un_430 mt.id.ms_433
  0x043f1908, 0x25000319, 0x0e023fee, 0x232d290c,   // gl.af.fi_443 nl.eu.un_750  af.da.is_422 sl.sk.ca_543
  // [c0c0]
  0x0c0620b3, 0x1c3f5304, 0x27116b08, 0x25093fa7,   // sq.de.sv_743 ht.af.id_332  ceb.ro.gd_443 af.pl.eu_532
  0x551b3113, 0x120e0804, 0x3f13250b, 0x640c13a4,   // az.tr.rw_665 no.is.hu_332  eu.et.af_542 et.sv.lg_433
  0x1c0d1312, 0x531c16a0, 0x121c08ee, 0x0e2d0d55,   // bh.ne.mr_654 hr.id.ht_322  no.id.hu_422 cs.sk.is_442
  0x0c000821, 0x21100f09, 0x0d00132a, 0x07000218,   // no.sv.un_860 lv.lt.jw_444  bh.ne.un_970 da.it.un_740
  // [c0d0]
  0x281155ee, 0x6e002109, 0x0b171605, 0x0806120c,   // rw.ro.sw_422 jw.blu.un_440  hr.sr.es_333 hu.de.no_543
  0x0e120605, 0x060e1205, 0x1606120c, 0x100a0412,   // de.hu.is_333 hu.is.de_333  hu.de.hr_543 ru.mk.be_654
  0x07001605, 0x0d001810, 0x192311a9, 0x0825180d,   // hr.it.un_330 ga.cs.un_620  ro.ca.gl_544 ga.eu.no_554
  0x0b0e19a9, 0x16101aa0, 0x0e0b19ee, 0x061f0802,   // gl.is.es_544 tl.lt.hr_322  gl.es.is_422 no.cy.de_222
  // [c0e0]
  0x6b070f0c, 0x04006420, 0x1a1629a7, 0x13001820,   // lv.it.ceb_543 lg.fi.un_850  sl.hr.tl_532 ga.et.un_850
  0x05112302, 0x25000505, 0x0e0b190c, 0x112007ee,   // ca.ro.fr_222 fr.eu.un_330  gl.es.is_543 it.sq.ro_422
  0x11052507, 0x11022a0d, 0x53026eaf, 0x28001b19,   // eu.fr.ro_432 mt.da.ro_554  blu.da.ht_655 tr.sw.un_750
  0x1b000c21, 0x0f001f21, 0x110128ec, 0x53211304,   // sv.tr.un_860 cy.lv.un_860  sw.en.ro_644 et.jw.ht_332
  // [c0f0]
  0x2d0b190c, 0x2d1309af, 0x023f010c, 0x2d0716ad,   // gl.es.sk_543 pl.et.sk_655  en.af.da_543 hr.it.sk_643
  0x2d190b13, 0x531a6bee, 0x08130ca0, 0x6b1a6e0d,   // es.gl.sk_665 ceb.tl.ht_422  sv.et.no_322 blu.tl.ceb_554
  0x0500251a, 0x060504a7, 0x2500050d, 0x20002713,   // eu.fr.un_760 fi.fr.de_532  fr.eu.un_540 gd.sq.un_650
  0x05000f05, 0x2d055312, 0x0f0413a4, 0x09172da4,   // lv.fr.un_330 ht.fr.sk_654  et.fi.lv_433 sk.sr.pl_433
  // [c100]
  0x2818270b, 0x0b6e0607, 0x060c0805, 0x111007ad,   // gd.ga.sw_542 de.blu.es_432  no.sv.de_333 bg.be.ro_643
  0x06000c21, 0x13111ea7, 0x056b08ee, 0x12182dec,   // sv.de.un_860 ms.ro.et_532  no.ceb.fr_422 sk.ga.hu_644
  0x110f28a4, 0x0c001013, 0x550413af, 0x18001313,   // sw.lv.ro_433 lt.sv.un_650  et.fi.rw_655 et.ga.un_650
  0x1a0c1b0c, 0x53056402, 0x0c1b1f12, 0x12230b04,   // tr.sv.tl_543 lg.fr.ht_222  cy.tr.sv_654 es.ca.hu_332
  // [c110]
  0x0c0908a4, 0x041f01a0, 0x17001020, 0x12190b07,   // no.pl.sv_433 en.cy.fi_322  be.sr.un_850 es.gl.hu_432
  0x081f02a4, 0x2b1f0107, 0x0b001207, 0x190b1807,   // da.cy.no_433 en.cy.vi_432  hu.es.un_420 ga.es.gl_432
  0x2a070ca9, 0x190e0b5a, 0x0e063fee, 0x08290404,   // sv.it.mt_544 es.is.gl_553  af.de.is_422 fi.sl.no_332
  0x091f3f12, 0x012a20a0, 0x1b06310c, 0x3f032907,   // af.cy.pl_654 sq.mt.en_322  az.de.tr_543 sl.nl.af_432
  // [c120]
  0x11000e0d, 0x210b040c, 0x2910120c, 0x3f031c0c,   // is.ro.un_540 fi.es.jw_543  hu.lt.sl_543 id.nl.af_543
  0x55000e22, 0x201b210d, 0x55005304, 0x18211fa0,   // is.rw.un_870 jw.tr.sq_554  ht.rw.un_320 cy.jw.ga_322
  0x0c250b04, 0x29033f13, 0x1e3f1c0b, 0x27181baf,   // es.eu.sv_332 af.nl.sl_665  id.af.ms_542 tr.ga.gd_655
  0x201c2b04, 0x642103ad, 0x030b0507, 0x033f040d,   // vi.id.sq_332 nl.jw.lg_643  fr.es.nl_432 fi.af.nl_554
  // [c130]
  0x030e23a7, 0x1a001312, 0x0b0a270e, 0x091f06a0,   // ca.is.nl_532 et.tl.un_640  gd.pt.es_555 de.cy.pl_322
  0x041c2008, 0x0c3f030d, 0x133f1a07, 0x1c022107,   // sq.id.fi_443 nl.af.sv_554  tl.af.et_432 jw.da.id_432
  0x0a04250c, 0x3f2a230c, 0x1c211ea7, 0x285319a4,   // eu.fi.pt_543 ca.mt.af_543  ms.jw.id_532 gl.ht.sw_433
  0x17001a02, 0x230d2dec, 0x1a002107, 0x04291bee,   // tl.sr.un_220 sk.cs.ca_644  jw.tl.un_420 tr.sl.fi_422
  // [c140]
  0x1e1c080c, 0x1b172904, 0x0a071a09, 0x180b27ad,   // no.id.ms_543 sl.sr.tr_332  tl.it.pt_444 gd.es.ga_643
  0x1c6b1ea4, 0x13551f55, 0x2829160c, 0x1a556b12,   // ms.ceb.id_433 cy.rw.et_442  hr.sl.sw_543 ceb.rw.tl_654
  0x08120208, 0x556b2805, 0x6b1a1ca0, 0x311b28a0,   // da.hu.no_443 sw.ceb.rw_333  id.tl.ceb_322 sw.tr.az_322
  0x07551308, 0x550964a4, 0x1b103112, 0x1f31120e,   // et.rw.it_443 lg.pl.rw_433  az.lt.tr_654 hu.az.cy_555
  // [c150]
  0x010605a0, 0x1b162dee, 0x23000d1a, 0x1b001005,   // fr.de.en_322 sk.hr.tr_422  cs.ca.un_760 lt.tr.un_330
  0x09190b13, 0x0c3f1007, 0x070411af, 0x0b1b0e07,   // es.gl.pl_665 lt.af.sv_432  ro.ru.bg_655 is.tr.es_432
  0x642d5504, 0x031f1ea4, 0x08556455, 0x253f0608,   // rw.sk.lg_332 ms.cy.nl_433  lg.rw.no_442 de.af.eu_443
  0x291f1b07, 0x2855640d, 0x28170405, 0x1c55640b,   // tr.cy.sl_432 lg.rw.sw_554  fi.sr.sw_333 lg.rw.id_542
  // [c160]
  0x1a6b25ec, 0x1a646bad, 0x090812a4, 0x11002512,   // eu.ceb.tl_644 ceb.lg.tl_643  hu.no.pl_433 eu.ro.un_640
  0x31000e0c, 0x0c0902a0, 0x31005305, 0x072311ac,   // is.az.un_530 da.pl.sv_322  ht.az.un_330 ro.ca.it_632
  0x0d022da7, 0x06002113, 0x02090c07, 0x160921ee,   // sk.da.cs_532 jw.de.un_650  sv.pl.da_432 jw.pl.hr_422
  0x29280904, 0x0c083f0d, 0x100d3fad, 0x290916a0,   // pl.sw.sl_332 af.no.sv_554  af.cs.lt_643 hr.pl.sl_322
  // [c170]
  0x28050b08, 0x020b0c04, 0x100817a9, 0x092d0fa0,   // es.fr.sw_443 sv.es.da_332  sr.uk.be_544 lv.sk.pl_322
  0x13003f09, 0x0c120e11, 0x08001720, 0x0a1027a7,   // af.et.un_440 is.hu.sv_653  sr.uk.un_850 gd.lt.pt_532
  0x031b3107, 0x01122a08, 0x6e00640d, 0x2017290c,   // az.tr.nl_432 mt.hu.en_443  lg.blu.un_540 sl.sr.sq_543
  0x3f1a640b, 0x171b19a0, 0x292d1705, 0x170208a4,   // lg.tl.af_542 gl.tr.sr_322  sr.sk.sl_333 no.da.sr_433
  // [c180]
  0x010c2da0, 0x0e020608, 0x6e086ba4, 0x3f002a11,   // sk.sv.en_322 de.da.is_443  ceb.no.blu_433 mt.af.un_630
  0x0900132b, 0x2a050f08, 0x172521a0, 0x160802a7,   // bh.hi.un_980 lv.fr.mt_443  jw.eu.sr_322 da.no.hr_532
  0x270119af, 0x0a00010d, 0x201b0508, 0x100b25a0,   // gl.en.gd_655 en.pt.un_540  fr.tr.sq_443 eu.es.lt_322
  0x1b290da0, 0x16190b5a, 0x6b000d07, 0x17071b04,   // cs.sl.tr_322 es.gl.hr_553  cs.ceb.un_420 tr.it.sr_332
  // [c190]
  0x20000922, 0x11001722, 0x270b1804, 0x251820a0,   // pl.sq.un_870 sr.ro.un_870  ga.es.gd_332 sq.ga.eu_322
  0x17281607, 0x291f07ad, 0x2b1e1c09, 0x25556404,   // hr.sw.sr_432 it.cy.sl_643  id.ms.vi_444 lg.rw.eu_332
  0x120410ad, 0x1b0831a0, 0x31551ba7, 0x122864ad,   // lt.fi.hu_643 az.no.tr_322  tr.rw.az_532 lg.sw.hu_643
  0x07030f08, 0x532905a9, 0x28001b21, 0x16001a07,   // lv.nl.it_443 fr.sl.ht_544  tr.sw.un_860 tl.hr.un_420
  // [c1a0]
  0x172953a4, 0x291b5308, 0x311b6b07, 0x020e08af,   // ht.sl.sr_433 ht.tr.sl_443  ceb.tr.az_432 no.is.da_655
  0x190507a4, 0x050c0813, 0x29175508, 0x1704080b,   // it.fr.gl_433 no.sv.fr_665  rw.sr.sl_443 uk.ru.sr_542
  0x551a2855, 0x19006402, 0x6b315511, 0x31005505,   // sw.tl.rw_442 lg.gl.un_220  rw.az.ceb_653 rw.az.un_330
  0x031e2805, 0x07230a60, 0x092001a0, 0x0c095305,   // sw.ms.nl_333 pt.ca.it_664  en.sq.pl_322 ht.pl.sv_333
  // [c1b0]
  0x55271fa7, 0x28040e14, 0x101a0408, 0x2a12070b,   // cy.gd.rw_532 is.fi.sw_666  fi.tl.lt_443 it.hu.mt_542
  0x53002013, 0x0f6b0404, 0x04100f5a, 0x0410115a,   // sq.ht.un_650 fi.ceb.lv_332  lv.lt.fi_553 ro.be.ru_553
  0x1700091a, 0x01553104, 0x533105a4, 0x02080e07,   // pl.sr.un_760 az.rw.en_332  fr.az.ht_433 is.no.da_432
  0x21041311, 0x2a2311a4, 0x0e100812, 0x00000637,   // et.fi.jw_653 ro.ca.mt_433  no.lt.is_654 de.un.un_B00
  // [c1c0]
  0x17000c20, 0x64001a0c, 0x0d000923, 0x280601a9,   // sv.sr.un_850 tl.lg.un_530  hi.ne.un_880 en.de.sw_544
  0x6e041004, 0x04100f07, 0x170b29a0, 0x250d2da9,   // lt.fi.blu_332 lv.lt.fi_432  sl.es.sr_322 sk.cs.eu_544
  0x21000907, 0x0b0a1f0c, 0x10040f04, 0x311a6b04,   // pl.jw.un_420 cy.pt.es_543  lv.fi.lt_332 ceb.tl.az_332
  0x25041307, 0x641307a0, 0x1f6b0107, 0x102b05a4,   // et.fi.eu_432 it.et.lg_322  en.ceb.cy_432 fr.vi.lt_433
  // [c1d0]
  0x176b16a9, 0x2a311e05, 0x1c0b23ee, 0x07000a21,   // hr.ceb.sr_544 ms.az.mt_333  ca.es.id_422 pt.it.un_860
  0x070a040d, 0x080b020c, 0x17081ca0, 0x0f201604,   // ru.mk.bg_554 da.es.no_543  id.no.sr_322 hr.sq.lv_332
  0x1153280c, 0x13010505, 0x100f12a0, 0x12110fa0,   // sw.ht.ro_543 fr.en.et_333  hu.lv.lt_322 lv.ro.hu_322
  0x02002b0c, 0x02200ca4, 0x04171614, 0x29100d07,   // vi.da.un_530 sv.sq.da_433  hr.sr.fi_666 cs.lt.sl_432
  // [c1e0]
  0x311f1808, 0x535511a0, 0x230b11a4, 0x171653ee,   // ga.cy.az_443 ro.rw.ht_322  ro.es.ca_433 ht.hr.sr_422
  0x28213f07, 0x25000c08, 0x190b1fee, 0x53112d02,   // af.jw.sw_432 sv.eu.un_430  cy.es.gl_422 sk.ro.ht_222
  0x05001809, 0x171601a4, 0x5500070c, 0x5300290c,   // ga.fr.un_440 en.hr.sr_433  it.rw.un_530 sl.ht.un_530
  0x110753a0, 0x09001f20, 0x100911a0, 0x6b005505,   // ht.it.ro_322 cy.pl.un_850  ro.pl.lt_322 rw.ceb.un_330
  // [c1f0]
  0x070f2504, 0x55112804, 0x28080213, 0x13030ca0,   // eu.lv.it_332 sw.ro.rw_332  da.no.sw_665 sv.nl.et_322
  0x102d13ad, 0x10002508, 0x53001107, 0x25171609,   // et.sk.lt_643 eu.lt.un_430  ro.ht.un_420 hr.sr.eu_444
  0x550d05a7, 0x132011a4, 0x1300050c, 0x17000709,   // fr.cs.rw_532 ro.sq.et_433  fr.et.un_530 bg.sr.un_440
  0x0411550b, 0x11070aaf, 0x13033fac, 0x21000513,   // rw.ro.fi_542 mk.bg.ro_655  af.nl.et_632 fr.jw.un_650
  // [c200]
  0x2d2b0daf, 0x022b18ac, 0x1a2864a9, 0x2b1828a0,   // cs.vi.sk_655 ga.vi.da_632  lg.sw.tl_544 sw.ga.vi_322
  0x1a6b2808, 0x0f006419, 0x292d0d11, 0x100b53a7,   // sw.ceb.tl_443 lg.lv.un_750  cs.sk.sl_653 ht.es.lt_532
  0x1f3f030d, 0x062a31ee, 0x0e001b13, 0x020308a4,   // nl.af.cy_554 az.mt.de_422  tr.is.un_650 no.nl.da_433
  0x071f2a02, 0x020301a4, 0x08101707, 0x31000d04,   // mt.cy.it_222 en.nl.da_433  sr.be.uk_432 cs.az.un_320
  // [c210]
  0x07171607, 0x0e120ba9, 0x16001735, 0x3f1e0609,   // hr.sr.it_432 es.hu.is_544  sr.hr.un_A90 de.ms.af_444
  0x19180a0b, 0x27211a07, 0x311e1cad, 0x0f1053a4,   // pt.ga.gl_542 tl.jw.gd_432  id.ms.az_643 ht.lt.lv_433
  0x1b12530e, 0x19180b12, 0x64001b1b, 0x13010808,   // ht.hu.tr_555 es.ga.gl_654  tr.lg.un_770 no.en.et_443
  0x1b00070e, 0x03020505, 0x0a531202, 0x033f0660,   // it.tr.un_550 fr.da.nl_333  hu.ht.pt_222 de.af.nl_664
  // [c220]
  0x6b2a290c, 0x23001923, 0x291f0711, 0x1b122007,   // sl.mt.ceb_543 gl.ca.un_880  it.cy.sl_653 sq.hu.tr_432
  0x1b0e31a4, 0x110701af, 0x2a161707, 0x03000d08,   // az.is.tr_433 en.it.ro_655  sr.hr.mt_432 cs.nl.un_430
  0x5300010d, 0x64005307, 0x16290fa9, 0x090608a0,   // en.ht.un_540 ht.lg.un_420  lv.sl.hr_544 no.de.pl_322
  0x0c0602a9, 0x270806af, 0x071008a9, 0x041321ad,   // da.de.sv_544 de.no.gd_655  uk.be.bg_544 jw.et.fi_643
  // [c230]
  0x20001b0e, 0x31531ca0, 0x08206404, 0x25000809,   // tr.sq.un_550 id.ht.az_322  lg.sq.no_332 no.eu.un_440
  0x18002519, 0x20251014, 0x0f100e11, 0x2d0c08a0,   // eu.ga.un_750 lt.eu.sq_666  is.lt.lv_653 no.sv.sk_322
  0x20252a12, 0x10250612, 0x09021f12, 0x04001120,   // mt.eu.sq_654 de.eu.lt_654  cy.da.pl_654 ro.ru.un_850
  0x160464a4, 0x23010ca0, 0x08100fec, 0x201f3fec,   // lg.fi.hr_433 sv.en.ca_322  lv.lt.no_644 af.cy.sq_644
  // [c240]
  0x2502060c, 0x20080209, 0x25002a13, 0x10070a0d,   // de.da.eu_543 da.no.sq_444  mt.eu.un_650 mk.bg.be_554
  0x0e003f08, 0x08171004, 0x1e252107, 0x271f18a7,   // af.is.un_430 be.sr.uk_332  jw.eu.ms_432 ga.cy.gd_532
  0x1329120c, 0x1e1028a7, 0x29281b08, 0x2928160c,   // hu.sl.et_543 sw.lt.ms_532  tr.sw.sl_443 hr.sw.sl_543
  0x071b2007, 0x211211a4, 0x160d1111, 0x1c010802,   // sq.tr.it_432 ro.hu.jw_433  ro.cs.hr_653 no.en.id_222
  // [c250]
  0x6b002a0d, 0x311228af, 0x55001b18, 0x311120ad,   // mt.ceb.un_540 sw.hu.az_655  tr.rw.un_740 sq.ro.az_643
  0x20005302, 0x03000122, 0x12170d07, 0x0f101e07,   // ht.sq.un_220 en.nl.un_870  cs.sr.hu_432 ms.lt.lv_432
  0x53002522, 0x0c000521, 0x23000a05, 0x2b210702,   // eu.ht.un_870 fr.sv.un_860  pt.ca.un_330 it.jw.vi_222
  0x6b1364a4, 0x0700100d, 0x53101ca4, 0x10001302,   // lg.et.ceb_433 lt.it.un_540  id.lt.ht_433 et.lt.un_220
  // [c260]
  0x17081012, 0x1f270107, 0x01080255, 0x02275307,   // be.uk.sr_654 en.gd.cy_432  da.no.en_442 ht.gd.da_432
  0x100a0502, 0x1c080c05, 0x09310d04, 0x040e13a0,   // fr.pt.lt_222 sv.no.id_333  cs.az.pl_332 et.is.fi_322
  0x020c080b, 0x3f6b0204, 0x1a002819, 0x175306a0,   // no.sv.da_542 da.ceb.af_332  sw.tl.un_750 de.ht.sr_322
  0x08021104, 0x17003f1b, 0x11000c2a, 0x1f002712,   // ro.da.no_332 af.sr.un_770  sv.ro.un_970 gd.cy.un_640
  // [c270]
  0x090b1107, 0x2a1e09a0, 0x102a0f60, 0x010705ee,   // ro.es.pl_432 pl.ms.mt_322  lv.mt.lt_664 fr.it.en_422
  0x6b041307, 0x13110c0d, 0x1209170c, 0x1a136b08,   // et.fi.ceb_432 sv.ro.et_554  sr.pl.hu_543 ceb.et.tl_443
  0x1e000d07, 0x250c1305, 0x1e3f12a6, 0x10171107,   // cs.ms.un_420 et.sv.eu_333  hu.af.ms_521 ro.sr.be_432
  0x230c0a0c, 0x12041355, 0x042808ee, 0x0a040755,   // pt.sv.ca_543 et.fi.hu_442  no.sw.fi_422 bg.ru.mk_442
  // [c280]
  0x6b002813, 0x080c0605, 0x1a216409, 0x0104130b,   // sw.ceb.un_650 de.sv.no_333  lg.jw.tl_444 et.fi.en_542
  0x3f0813ee, 0x0c0408ee, 0x12001f02, 0x21551ca4,   // et.no.af_422 no.fi.sv_422  cy.hu.un_220 id.rw.jw_433
  0x0e5308a0, 0x28000c05, 0x3f6b0407, 0x09041a07,   // no.ht.is_322 sv.sw.un_330  fi.ceb.af_432 tl.fi.pl_432
  0x64000705, 0x04130aad, 0x1b060ea0, 0x3f081c0b,   // it.lg.un_330 pt.et.fi_643  is.de.tr_322 id.no.af_542
  // [c290]
  0x551a6405, 0x070a2a08, 0x070b2312, 0x09101fa0,   // lg.tl.rw_333 mt.pt.it_443  ca.es.it_654 cy.lt.pl_322
  0x03001012, 0x071323a0, 0x08021aa0, 0x0a080c0c,   // lt.nl.un_640 ca.et.it_322  tl.da.no_322 sv.no.pt_543
  0x07230a07, 0x191307ee, 0x250b07a7, 0x253f03af,   // pt.ca.it_432 it.et.gl_422  it.es.eu_532 nl.af.eu_655
  0x1c0408a4, 0x6b012a04, 0x03250614, 0x25200612,   // no.fi.id_433 mt.en.ceb_332  de.eu.nl_666 de.sq.eu_654
  // [c2a0]
  0x0800181a, 0x25210312, 0x0812075a, 0x03000419,   // ga.no.un_760 nl.jw.eu_654  it.hu.no_553 fi.nl.un_750
  0x0c1f060c, 0x0c03060e, 0x17000722, 0x21120613,   // de.cy.sv_543 de.nl.sv_555  bg.sr.un_870 de.hu.jw_665
  0x12190b5a, 0x1a001213, 0x046b5507, 0x0e00061b,   // es.gl.hu_553 hu.tl.un_650  rw.ceb.fi_432 de.is.un_770
  0x06003f12, 0x29032512, 0x121b53a9, 0x03055305,   // af.de.un_640 eu.nl.sl_654  ht.tr.hu_544 ht.fr.nl_333
  // [c2b0]
  0x0c19230c, 0x31006b29, 0x211a0eec, 0x080203ec,   // ca.gl.sv_543 ceb.az.un_960  is.tl.jw_644 nl.da.no_644
  0x21530308, 0x0b001007, 0x20005304, 0x200b0a04,   // nl.ht.jw_443 lt.es.un_420  ht.sq.un_320 pt.es.sq_332
  0x1a001902, 0x25230611, 0x080c230b, 0x060325af,   // gl.tl.un_220 de.ca.eu_653  ca.sv.no_542 eu.nl.de_655
  0x250803a9, 0x070e20a0, 0x10190ba0, 0x08021604,   // nl.no.eu_544 sq.is.it_322  es.gl.lt_322 hr.da.no_332
  // [c2c0]
  0x0e6b1aee, 0x10040a02, 0x31122507, 0x211a3f07,   // tl.ceb.is_422 mk.ru.be_222  eu.hu.az_432 af.tl.jw_432
  0x10000b08, 0x130604ee, 0x04100855, 0x20001008,   // es.lt.un_430 fi.de.et_422  uk.be.ru_442 lt.sq.un_430
  0x1a1b6ba4, 0x29201104, 0x132904ad, 0x1a215508,   // ceb.tr.tl_433 ro.sq.sl_332  fi.sl.et_643 rw.jw.tl_443
  0x032553a0, 0x0f0b01a4, 0x551353a4, 0x25202308,   // ht.eu.nl_322 en.es.lv_433  ht.et.rw_433 ca.sq.eu_443
  // [c2d0]
  0x2300200d, 0x08003108, 0x05112a04, 0x13110a04,   // sq.ca.un_540 az.no.un_430  mt.ro.fr_332 pt.ro.et_332
  0x160f1704, 0x20110460, 0x17160409, 0x0f2d0da7,   // sr.lv.hr_332 fi.ro.sq_664  fi.hr.sr_444 cs.sk.lv_532
  0x0e001e0d, 0x0d002104, 0x25211c04, 0x08002314,   // ms.is.un_540 jw.cs.un_320  id.jw.eu_332 ca.no.un_660
  0x1f0802a0, 0x041013a6, 0x081f2aa0, 0x640413ec,   // da.no.cy_322 et.lt.fi_521  mt.cy.no_322 et.fi.lg_644
  // [c2e0]
  0x13000218, 0x641f1baf, 0x2b002a12, 0x1f0c2005,   // da.et.un_740 tr.cy.lg_655  mt.vi.un_640 sq.sv.cy_333
  0x170802a0, 0x1e281caf, 0x0e081204, 0x3f0c020c,   // da.no.sr_322 id.sw.ms_655  hu.no.is_332 da.sv.af_543
  0x06000309, 0x0c0603a4, 0x17092d0c, 0x02180c07,   // nl.de.un_440 nl.de.sv_433  sk.pl.sr_543 sv.ga.da_432
  0x12001e04, 0x180b1307, 0x080213ec, 0x10030f02,   // ms.hu.un_320 et.es.ga_432  et.da.no_644 lv.nl.lt_222
  // [c2f0]
  0x171a08a0, 0x0e011fac, 0x1b0d3f0c, 0x3f0c0804,   // no.tl.sr_322 cy.en.is_632  af.cs.tr_543 no.sv.af_332
  0x130f04a7, 0x2a0706ec, 0x1b0210a0, 0x280f3fa0,   // fi.lv.et_532 de.it.mt_644  lt.da.tr_322 af.lv.sw_322
  0x16001304, 0x033f0804, 0x170d1655, 0x190b18ac,   // et.hr.un_320 no.af.nl_332  hr.cs.sr_442 ga.es.gl_632
  0x2d0d21a6, 0x28646ba0, 0x281a6b05, 0x12005319,   // jw.cs.sk_521 ceb.lg.sw_322  ceb.tl.sw_333 ht.hu.un_750
  // [c300]
  0x0f3f02af, 0x3f1b530c, 0x1000071b, 0x10071712,   // da.af.lv_655 ht.tr.af_543  bg.be.un_770 sr.bg.be_654
  0x3f0201a0, 0x291609a9, 0x6b1a64a0, 0x3f030daf,   // en.da.af_322 pl.hr.sl_544  lg.tl.ceb_322 cs.nl.af_655
  0x113f0e08, 0x2b553f07, 0x31111b04, 0x20532a02,   // is.af.ro_443 af.rw.vi_432  tr.ro.az_332 mt.ht.sq_222
  0x21070fec, 0x211c0308, 0x2120100c, 0x0f041307,   // lv.it.jw_644 nl.id.jw_443  lt.sq.jw_543 et.fi.lv_432
  // [c310]
  0x06280805, 0x12190a08, 0x010802a4, 0x0f531014,   // no.sw.de_333 pt.gl.hu_443  da.no.en_433 lt.ht.lv_666
  0x102b3f0c, 0x202d0d02, 0x03003f35, 0x05001007,   // af.vi.lt_543 cs.sk.sq_222  af.nl.un_A90 lt.fr.un_420
  0x110428a4, 0x2d0b0a04, 0x1c0806ee, 0x13081c05,   // sw.fi.ro_433 pt.es.sk_332  de.no.id_422 id.no.et_333
  0x07161f0b, 0x551b6405, 0x17110aad, 0x6b1f1aad,   // cy.hr.it_542 lg.tr.rw_333  mk.ro.sr_643 tl.cy.ceb_643
  // [c320]
  0x231e04ec, 0x0a1a6b09, 0x0e181212, 0x2a060ca7,   // fi.ms.ca_644 ceb.tl.pt_444  hu.ga.is_654 sv.de.mt_532
  0x1c1e0b07, 0x01052307, 0x161a5312, 0x0413250d,   // es.ms.id_432 ca.fr.en_432  ht.tl.hr_654 eu.et.fi_554
  0x21231c05, 0x6b1a21ec, 0x28001a13, 0x252d0407,   // id.ca.jw_333 jw.tl.ceb_644  tl.sw.un_650 fi.sk.eu_432
  0x1a64250d, 0x29101aee, 0x1e002d02, 0x0b0208a4,   // eu.lg.tl_554 tl.lt.sl_422  sk.ms.un_220 no.da.es_433
  // [c330]
  0x160d2902, 0x0f100bee, 0x090d2907, 0x6b551aad,   // sl.cs.hr_222 es.lt.lv_422  sl.cs.pl_432 tl.rw.ceb_643
  0x03000f02, 0x1c1e1b11, 0x033f1313, 0x6b211c0c,   // lv.nl.un_220 tr.ms.id_653  et.af.nl_665 id.jw.ceb_543
  0x642155af, 0x19001e1a, 0x04131ca4, 0x13100f07,   // rw.jw.lg_655 ms.gl.un_760  id.et.fi_433 lv.lt.et_432
  0x64002834, 0x133f64ee, 0x21250fa0, 0x0f1019a4,   // sw.lg.un_A80 lg.af.et_422  lv.eu.jw_322 gl.lt.lv_433
  // [c340]
  0x070d0e04, 0x641a13a7, 0x0d0c2d04, 0x17041011,   // is.cs.it_332 et.tl.lg_532  sk.sv.cs_332 be.ru.sr_653
  0x6413030c, 0x21000612, 0x0c080e0e, 0x13033f5a,   // nl.et.lg_543 de.jw.un_640  is.no.sv_555 af.nl.et_553
  0x1a006b29, 0x16112904, 0x04002702, 0x29160daf,   // ceb.tl.un_960 sl.ro.hr_332  gd.fi.un_220 cs.hr.sl_655
  0x081304a0, 0x2d0d1cee, 0x09000209, 0x2a071055,   // fi.et.no_322 id.cs.sk_422  da.pl.un_440 lt.it.mt_442
  // [c350]
  0x042b13a0, 0x0e001f0e, 0x25000402, 0x12000e29,   // et.vi.fi_322 cy.is.un_550  fi.eu.un_220 is.hu.un_960
  0x25002808, 0x0c0e06ad, 0x00000e42, 0x2d006e08,   // sw.eu.un_430 de.is.sv_643  is.un.un_C00 blu.sk.un_430
  0x21005311, 0x0a001212, 0x230a21a9, 0x04100aec,   // ht.jw.un_630 hu.pt.un_640  jw.pt.ca_544 mk.be.ru_644
  0x04100714, 0x1b120613, 0x11311baf, 0x0d082bee,   // bg.be.ru_666 de.hu.tr_665  tr.az.ro_655 vi.no.cs_422
  // [c360]
  0x2d2105a4, 0x04060e07, 0x120425a4, 0x1f040111,   // fr.jw.sk_433 is.de.fi_432  eu.fi.hu_433 en.fi.cy_653
  0x1e311ca4, 0x0200131b, 0x211b1ca0, 0x072501ad,   // id.az.ms_433 et.da.un_770  id.tr.jw_322 en.eu.it_643
  0x25020c05, 0x1a532808, 0x041f1311, 0x086e0d08,   // sv.da.eu_333 sw.ht.tl_443  et.cy.fi_653 cs.blu.no_443
  0x062b2508, 0x1a002302, 0x290d6e07, 0x061304ec,   // eu.vi.de_443 ca.tl.un_220  blu.cs.sl_432 fi.et.de_644
  // [c370]
  0x293113a4, 0x12080eee, 0x281a250c, 0x6b0b2304,   // et.az.sl_433 is.no.hu_422  eu.tl.sw_543 ca.es.ceb_332
  0x25002114, 0x0c000308, 0x19230107, 0x0a122560,   // jw.eu.un_660 nl.sv.un_430  en.ca.gl_432 eu.hu.pt_664
  0x0c1204a0, 0x1e1c0fa9, 0x13000f14, 0x642113ee,   // fi.hu.sv_322 lv.id.ms_544  lv.et.un_660 et.jw.lg_422
  0x0c021b04, 0x1a002d04, 0x1b00190d, 0x0b062504,   // tr.da.sv_332 sk.tl.un_320  gl.tr.un_540 eu.de.es_332
  // [c380]
  0x072a1e12, 0x312a180c, 0x1a00280c, 0x20551008,   // ms.mt.it_654 ga.mt.az_543  sw.tl.un_530 lt.rw.sq_443
  0x292a2d07, 0x6b252da4, 0x311b100c, 0x1b020c08,   // sk.mt.sl_432 sk.eu.ceb_433  lt.tr.az_543 sv.da.tr_443
  0x29136ea7, 0x091c2102, 0x64281b04, 0x102a55a9,   // blu.et.sl_532 jw.id.pl_222  tr.sw.lg_332 rw.mt.lt_544
  0x3f000613, 0x012708a0, 0x3f041309, 0x07001204,   // de.af.un_650 no.gd.en_322  et.fi.af_444 hu.it.un_320
  // [c390]
  0x2a16280c, 0x190603a0, 0x08046404, 0x120804ec,   // sw.hr.mt_543 nl.de.gl_322  lg.fi.no_332 fi.no.hu_644
  0x10062a02, 0x02160ea0, 0x011a2ba0, 0x02000f02,   // mt.de.lt_222 is.hr.da_322  vi.tl.en_322 lv.da.un_220
  0x2a0964a9, 0x04001b04, 0x23120ba0, 0x29072aa9,   // lg.pl.mt_544 tr.fi.un_320  es.hu.ca_322 mt.it.sl_544
  0x0a002d13, 0x200413a7, 0x091225a0, 0x1e1c2aec,   // sk.pt.un_650 et.fi.sq_532  eu.hu.pl_322 mt.id.ms_644
  // [c3a0]
  0x290d17af, 0x12211855, 0x6b005504, 0x0d162902,   // sr.cs.sl_655 ar.fa.ur_442  rw.ceb.un_320 sl.hr.cs_222
  0x3f0306a0, 0x093f010c, 0x25121ba0, 0x202864a9,   // de.nl.af_322 en.af.pl_543  tr.hu.eu_322 lg.sw.sq_544
  0x6b311b55, 0x010c0604, 0x110a170e, 0x1a00640b,   // tr.az.ceb_442 de.sv.en_332  sr.mk.ro_555 lg.tl.un_520
  0x25000e0c, 0x013f08a0, 0x3f051207, 0x64000904,   // is.eu.un_530 no.af.en_322  hu.fr.af_432 pl.lg.un_320
  // [c3b0]
  0x1f21640e, 0x192064ec, 0x2a092d0c, 0x1b002d19,   // lg.jw.cy_555 lg.sq.gl_644  sk.pl.mt_543 sk.tr.un_750
  0x0e1a6b55, 0x1f2025a4, 0x031b2dad, 0x041729af,   // ceb.tl.is_442 eu.sq.cy_433  sk.tr.nl_643 sl.sr.fi_655
  0x1f080c08, 0x2a00551b, 0x271928af, 0x2a005305,   // sv.no.cy_443 rw.mt.un_770  sw.gl.gd_655 ht.mt.un_330
  0x2d200d11, 0x1100102a, 0x29161fa4, 0x20531b0c,   // cs.sq.sk_653 be.ro.un_970  cy.hr.sl_433 tr.ht.sq_543
  // [c3c0]
  0x0a1729a7, 0x1a005512, 0x071f2155, 0x3100210c,   // sl.sr.pt_532 rw.tl.un_640  jw.cy.it_442 jw.az.un_530
  0x1629530b, 0x16001c09, 0x31281b07, 0x231a6412,   // ht.sl.hr_542 id.hr.un_440  tr.sw.az_432 lg.tl.ca_654
  0x09063f04, 0x6428210b, 0x231119a0, 0x0c022d0c,   // af.de.pl_332 jw.sw.lg_542  gl.ro.ca_322 sk.da.sv_543
  0x64000419, 0x28001019, 0x132011ac, 0x093f1a07,   // fi.lg.un_750 lt.sw.un_750  ro.sq.et_632 tl.af.pl_432
  // [c3d0]
  0x1e006411, 0x1e1a1c04, 0x03006412, 0x23005505,   // lg.ms.un_630 id.tl.ms_332  lg.nl.un_640 rw.ca.un_330
  0x28235305, 0x19001805, 0x2800290d, 0x28003122,   // ht.ca.sw_333 ga.gl.un_330  sl.sw.un_540 az.sw.un_870
  0x17092908, 0x23000309, 0x0e002802, 0x0302010c,   // sl.pl.sr_443 nl.ca.un_440  sw.is.un_220 en.da.nl_543
  0x31111b13, 0x120821a0, 0x2b000c0c, 0x3f020c02,   // tr.ro.az_665 jw.no.hu_322  sv.vi.un_530 sv.da.af_222
  // [c3e0]
  0x07002721, 0x2300070b, 0x08026eee, 0x250f100b,   // gd.it.un_860 it.ca.un_520  blu.da.no_422 lt.lv.eu_542
  0x07080a05, 0x200c0fa4, 0x232b0707, 0x080c2707,   // mk.uk.bg_333 lv.sv.sq_433  it.vi.ca_432 gd.sv.no_432
  0x2b001e07, 0x0b1104a7, 0x252a070e, 0x281308a0,   // ms.vi.un_420 fi.ro.es_532  it.mt.eu_555 no.et.sw_322
  0x1b002a1a, 0x026b28ee, 0x2a002d12, 0x020f0e04,   // mt.tr.un_760 sw.ceb.da_422  sk.mt.un_640 is.lv.da_332
  // [c3f0]
  0x532a01a4, 0x6b251aaf, 0x1b000f08, 0x011308a0,   // en.mt.ht_433 tl.eu.ceb_655  lv.tr.un_430 no.et.en_322
  0x1e001302, 0x64000e14, 0x1f00120c, 0x071b0304,   // et.ms.un_220 is.lg.un_660  hu.cy.un_530 nl.tr.it_332
  0x1f003f0e, 0x2d000712, 0x040717ec, 0x20080c60,   // af.cy.un_550 it.sk.un_640  sr.bg.ru_644 sv.no.sq_664
  0x030c08a7, 0x1b080ca4, 0x200c3f0c, 0x280408ad,   // no.sv.nl_532 sv.no.tr_433  af.sv.sq_543 no.fi.sw_643

  // [c400]
  0x095520a0, 0x102a0f13, 0x6b040711, 0x64066ba7,   // sq.rw.pl_322 lv.mt.lt_665  it.fi.ceb_653 ceb.de.lg_532
  0x1c1e0ea7, 0x6b2a1a07, 0x1f1264a9, 0x09532805,   // is.ms.id_532 tl.mt.ceb_432  lg.hu.cy_544 sw.ht.pl_333
  0x2864550e, 0x17033f07, 0x212864af, 0x040a10ee,   // rw.lg.sw_555 af.nl.sr_432  lg.sw.jw_655 be.mk.ru_422
  0x1c1b1eec, 0x25000304, 0x13020cad, 0x25000309,   // ms.tr.id_644 nl.eu.un_320  sv.da.et_643 nl.eu.un_440
  // [c410]
  0x6b1a1b04, 0x1a1b280c, 0x051a0da0, 0x642a5508,   // tr.tl.ceb_332 sw.tr.tl_543  cs.tl.fr_322 rw.mt.lg_443
  0x01112808, 0x051a0112, 0x12000b05, 0x05002505,   // sw.ro.en_443 en.tl.fr_654  es.hu.un_330 eu.fr.un_330
  0x532155a4, 0x13253f12, 0x3f2a07a9, 0x201b01a0,   // rw.jw.ht_433 af.eu.et_654  it.mt.af_544 en.tr.sq_322
  0x1f1827a7, 0x170a0414, 0x551b28ee, 0x2a28010c,   // gd.ga.cy_532 ru.mk.sr_666  sw.tr.rw_422 en.sw.mt_543
  // [c420]
  0x530f0107, 0x531001a9, 0x202a31a7, 0x28203f05,   // en.lv.ht_432 en.lt.ht_544  az.mt.sq_532 af.sq.sw_333
  0x07170413, 0x1e5528ee, 0x1b282d07, 0x2a030602,   // ru.sr.bg_665 sw.rw.ms_422  sk.sw.tr_432 de.nl.mt_222
  0x0b12230c, 0x19182dad, 0x18192d07, 0x0b191807,   // ca.hu.es_543 sk.ga.gl_643  sk.gl.ga_432 ga.gl.es_432
  0x072b530b, 0x2d2319ee, 0x53072b12, 0x2b005312,   // ht.vi.it_542 gl.ca.sk_422  vi.it.ht_654 ht.vi.un_640
  // [c430]
  0x31001312, 0x0d182da7, 0x0f2710a4, 0x1a00100c,   // et.az.un_640 sk.ga.cs_532  lt.gd.lv_433 lt.tl.un_530
  0x28555304, 0x08101ca0, 0x07005319, 0x2b005311,   // ht.rw.sw_332 id.lt.no_322  ht.it.un_750 ht.vi.un_630
  0x050125a0, 0x0d162913, 0x0d000e05, 0x0e001013,   // eu.en.fr_322 sl.hr.cs_665  is.cs.un_330 lt.is.un_650
  0x2318270b, 0x17100760, 0x010631a0, 0x0e0c130b,   // gd.ga.ca_542 bg.be.sr_664  az.de.en_322 et.sv.is_542
  // [c440]
  0x55171655, 0x105313af, 0x051f01ee, 0x1c21100e,   // hr.sr.rw_442 et.ht.lt_655  en.cy.fr_422 lt.jw.id_555
  0x060f2da6, 0x31040112, 0x1a00040b, 0x53060e0c,   // sk.lv.de_521 en.fi.az_654  fi.tl.un_520 is.de.ht_543
  0x232917a9, 0x0d131c07, 0x29001804, 0x116401a7,   // sr.sl.ca_544 mr.bh.ne_432  ga.sl.un_320 en.lg.ro_532
  0x046413ee, 0x11180112, 0x051101a4, 0x16292d11,   // et.lg.fi_422 en.ga.ro_654  en.ro.fr_433 sk.sl.hr_653
  // [c450]
  0x64211ca4, 0x1b1a6bac, 0x02002308, 0x16172913,   // id.jw.lg_433 ceb.tl.tr_632  ca.da.un_430 sl.sr.hr_665
  0x080a0713, 0x07011ea0, 0x121621a7, 0x6b281314,   // bg.mk.uk_665 ms.en.it_322  jw.hr.hu_532 et.sw.ceb_666
  0x6b2a0709, 0x1e211c60, 0x201a28a4, 0x2a642812,   // it.mt.ceb_444 id.jw.ms_664  sw.tl.sq_433 sw.lg.mt_654
  0x2a291609, 0x28232ba0, 0x0721550c, 0x161107af,   // hr.sl.mt_444 vi.ca.sw_322  rw.jw.it_543 it.ro.hr_655
  // [c460]
  0x121b0c55, 0x042b280b, 0x6b1004ee, 0x13060802,   // sv.tr.hu_442 sw.vi.fi_542  fi.lt.ceb_422 no.de.et_222
  0x121116a4, 0x23290209, 0x250f29ad, 0x1c3f1eee,   // hr.ro.hu_433 da.sl.ca_444  sl.lv.eu_643 ms.af.id_422
  0x64531fa0, 0x16112a09, 0x2a2b2704, 0x2a0716a9,   // cy.ht.lg_322 mt.ro.hr_444  gd.vi.mt_332 hr.it.mt_544
  0x0a271812, 0x10080a11, 0x2b041004, 0x04060cad,   // ga.gd.pt_654 mk.uk.be_653  lt.fi.vi_332 sv.de.fi_643
  // [c470]
  0x2b00270c, 0x070d1ba0, 0x16100707, 0x12060805,   // gd.vi.un_530 tr.cs.it_322  it.lt.hr_432 no.de.hu_333
  0x0f001c02, 0x0a100702, 0x101e0404, 0x21000613,   // id.lv.un_220 bg.be.mk_222  fi.ms.lt_332 de.jw.un_650
  0x1e001019, 0x1f1e1c04, 0x31000304, 0x20161b02,   // lt.ms.un_750 id.ms.cy_332  nl.az.un_320 tr.hr.sq_222
  0x18090ead, 0x13010f07, 0x53000f19, 0x01235302,   // is.pl.ga_643 lv.en.et_432  lv.ht.un_750 ht.ca.en_222
  // [c480]
  0x31130f04, 0x0b002d02, 0x1c100fad, 0x29111607,   // lv.et.az_332 sk.es.un_220  lv.lt.id_643 hr.ro.sl_432
  0x0c100f60, 0x0b101ca4, 0x10190a05, 0x1b2528a0,   // lv.lt.sv_664 id.lt.es_433  pt.gl.lt_333 sw.eu.tr_322
  0x200f18ee, 0x0c0f10ec, 0x09230ba0, 0x17162d12,   // ga.lv.sq_422 lt.lv.sv_644  es.ca.pl_322 sk.hr.sr_654
  0x0b190aa7, 0x12000a22, 0x0c100f07, 0x0f101aa7,   // pt.gl.es_532 pt.hu.un_870  lv.lt.sv_432 tl.lt.lv_532
  // [c490]
  0x20255307, 0x1013190c, 0x2900161b, 0x31001208,   // ht.eu.sq_432 gl.et.lt_543  hr.sl.un_770 hu.az.un_430
  0x08001c07, 0x1c535502, 0x04080ca6, 0x55281212,   // id.no.un_420 rw.ht.id_222  sv.no.fi_521 hu.sw.rw_654
  0x0f2010ee, 0x0f0705a4, 0x21295504, 0x06120c0b,   // lt.sq.lv_422 fr.it.lv_433  rw.sl.jw_332 sv.hu.de_542
  0x1b230855, 0x3f131e0c, 0x041307af, 0x12001a19,   // no.ca.tr_442 ms.et.af_543  it.et.fi_655 tl.hu.un_750
  // [c4a0]
  0x120519a0, 0x122d0804, 0x080f29af, 0x1f032aee,   // gl.fr.hu_322 no.sk.hu_332  sl.lv.no_655 mt.nl.cy_422
  0x29160f0c, 0x11061fa7, 0x11251c07, 0x06000e13,   // lv.hr.sl_543 cy.de.ro_532  id.eu.ro_432 is.de.un_650
  0x3f211ca7, 0x201317ee, 0x6b1e1c60, 0x0d131c04,   // id.jw.af_532 sr.et.sq_422  id.ms.ceb_664 mr.bh.ne_332
  0x01202804, 0x1e1c11af, 0x271f2507, 0x1f002d13,   // sw.sq.en_332 ro.id.ms_655  eu.cy.gd_432 sk.cy.un_650
  // [c4b0]
  0x03002705, 0x1f0812ad, 0x1e3f040c, 0x6b1201a0,   // gd.nl.un_330 hu.no.cy_643  fi.af.ms_543 en.hu.ceb_322
  0x2b00190c, 0x016b27ee, 0x6b2705a7, 0x02063f0c,   // gl.vi.un_530 gd.ceb.en_422  fr.gd.ceb_532 af.de.da_543
  0x1b2a2707, 0x53251ea0, 0x18000b08, 0x1a00210e,   // gd.mt.tr_432 ms.eu.ht_322  es.ga.un_430 jw.tl.un_550
  0x0b272307, 0x19312514, 0x08020505, 0x6b043f0c,   // ca.gd.es_432 eu.az.gl_666  fr.da.no_333 af.fi.ceb_543
  // [c4c0]
  0x251c1eaf, 0x04136b05, 0x0e0c1807, 0x216b1e12,   // ms.id.eu_655 ceb.et.fi_333  ga.sv.is_432 ms.ceb.jw_654
  0x2a000d1a, 0x18060f07, 0x1c111e0c, 0x1b2d0d05,   // cs.mt.un_760 lv.de.ga_432  ms.ro.id_543 cs.sk.tr_333
  0x1b1305a7, 0x29112aaf, 0x6b0e1308, 0x121353a4,   // fr.et.tr_532 mt.ro.sl_655  et.is.ceb_443 ht.et.hu_433
  0x0c0253a0, 0x102718ec, 0x171216a4, 0x292516a9,   // ht.da.sv_322 ga.gd.lt_644  hr.hu.sr_433 hr.eu.sl_544
  // [c4d0]
  0x18273faf, 0x20012905, 0x3f100f11, 0x3f00072a,   // af.gd.ga_655 sl.en.sq_333  lv.lt.af_653 it.af.un_970
  0x0f101704, 0x0e033faf, 0x11121fec, 0x13040709,   // sr.lt.lv_332 af.nl.is_655  cy.hu.ro_644 it.fi.et_444
  0x53103fee, 0x640f045a, 0x1e1c06ee, 0x2a283107,   // af.lt.ht_422 fi.lv.lg_553  de.id.ms_422 az.sw.mt_432
  0x012a03a0, 0x29002a2b, 0x2d041607, 0x19002321,   // nl.mt.en_322 mt.sl.un_980  hr.fi.sk_432 ca.gl.un_860
  // [c4e0]
  0x17100a04, 0x10002902, 0x2a1c31a7, 0x102d1605,   // mk.be.sr_332 sl.lt.un_220  az.id.mt_532 hr.sk.lt_333
  0x23111908, 0x551e1c0c, 0x1c006404, 0x1a002908,   // gl.ro.ca_443 id.ms.rw_543  lg.id.un_320 sl.tl.un_430
  0x0713040c, 0x6b1c1eee, 0x06181fa4, 0x0e291007,   // fi.et.it_543 ms.id.ceb_422  cy.ga.de_433 lt.sl.is_432
  0x31001f07, 0x0c105309, 0x31000f14, 0x061b1fad,   // cy.az.un_420 ht.lt.sv_444  lv.az.un_660 cy.tr.de_643
  // [c4f0]
  0x1e0501a0, 0x022a1fee, 0x0c130f07, 0x122864a9,   // en.fr.ms_322 cy.mt.da_422  lv.et.sv_432 lg.sw.hu_544
  0x55000405, 0x18002904, 0x09202a07, 0x2a110707,   // fi.rw.un_330 sl.ga.un_320  mt.sq.pl_432 it.ro.mt_432
  0x112a2305, 0x21000e13, 0x212918a4, 0x1c1353a4,   // ca.mt.ro_333 is.jw.un_650  ga.sl.jw_433 ht.et.id_433
  0x6b29160d, 0x55071107, 0x0f1020ac, 0x032806ad,   // hr.sl.ceb_554 ro.it.rw_432  sq.lt.lv_632 de.sw.nl_643
  // [c500]
  0x05020c05, 0x202a0b0b, 0x090c02a7, 0x0c030e0c,   // sv.da.fr_333 es.mt.sq_542  da.sv.pl_532 is.nl.sv_543
  0x1f060e0e, 0x06280ea4, 0x200b18a0, 0x16202804,   // is.de.cy_555 is.sw.de_433  ga.es.sq_322 sw.sq.hr_332
  0x2527180c, 0x1c2804ec, 0x6e1e1c5a, 0x1e181c04,   // ga.gd.eu_543 fi.sw.id_644  id.ms.blu_553 id.ga.ms_332
  0x030f3fa7, 0x16292da9, 0x2b000f02, 0x1118250c,   // af.lv.nl_532 sk.sl.hr_544  lv.vi.un_220 eu.ga.ro_543
  // [c510]
  0x230b07ee, 0x0b00011a, 0x531f0b02, 0x0e1b31a4,   // it.es.ca_422 en.es.un_760  es.cy.ht_222 az.tr.is_433
  0x03001105, 0x230a0708, 0x2a071b12, 0x53050aac,   // ro.nl.un_330 it.pt.ca_443  tr.it.mt_654 pt.fr.ht_632
  0x28005312, 0x31531b0c, 0x311b3f04, 0x3100060c,   // ht.sw.un_640 tr.ht.az_543  af.tr.az_332 de.az.un_530
  0x6e1a2812, 0x19311ba7, 0x13120608, 0x0d2916ee,   // sw.tl.blu_654 tr.az.gl_532  de.hu.et_443 hr.sl.cs_422
  // [c520]
  0x081e1c04, 0x1b1201a0, 0x55006b2a, 0x0a0408a7,   // id.ms.no_332 en.hu.tr_322  ceb.rw.un_970 uk.ru.mk_532
  0x121b20ee, 0x210712a4, 0x07642504, 0x55645313,   // sq.tr.hu_422 hu.it.jw_433  eu.lg.it_332 ht.lg.rw_665
  0x0b0a64ee, 0x5510130c, 0x551364a0, 0x3f020c07,   // lg.pt.es_422 et.lt.rw_543  lg.et.rw_322 sv.da.af_432
  0x23001a13, 0x1325060e, 0x081325ec, 0x0700080c,   // tl.ca.un_650 de.eu.et_555  eu.et.no_644 no.it.un_530
  // [c530]
  0x181b12af, 0x170a16a0, 0x0a2311ee, 0x271a6b04,   // hu.tr.ga_655 hr.pt.sr_322  ro.ca.pt_422 ceb.tl.gd_332
  0x1b250805, 0x53001012, 0x0b000f14, 0x231b31a0,   // no.eu.tr_333 lt.ht.un_640  lv.es.un_660 az.tr.ca_322
  0x27190aa4, 0x18210804, 0x21230607, 0x27181009,   // pt.gl.gd_433 no.jw.ga_332  de.ca.jw_432 lt.ga.gd_444
  0x2107230c, 0x060305ee, 0x12136402, 0x04002522,   // ca.it.jw_543 fr.nl.de_422  lg.et.hu_222 eu.fi.un_870
  // [c540]
  0x060c0811, 0x162d1e07, 0x6e080204, 0x170a16a9,   // no.sv.de_653 ms.sk.hr_432  da.no.blu_332 hr.pt.sr_544
  0x190a1005, 0x040c130d, 0x1f0902a0, 0x020e1204,   // lt.pt.gl_333 et.sv.fi_554  da.pl.cy_322 hu.is.da_332
  0x081e25a0, 0x180709ee, 0x07191107, 0x053f13af,   // eu.ms.no_322 pl.it.ga_422  ro.gl.it_432 et.af.fr_655
  0x0527040c, 0x04282508, 0x1900120e, 0x1200071b,   // fi.gd.fr_543 eu.sw.fi_443  hu.gl.un_550 it.hu.un_770
  // [c550]
  0x0b191212, 0x21001b02, 0x19122d13, 0x05202508,   // hu.gl.es_654 tr.jw.un_220  sk.hu.gl_665 eu.sq.fr_443
  0x0e002522, 0x170c0da0, 0x02000a04, 0x25040ea4,   // eu.is.un_870 cs.sv.sr_322  pt.da.un_320 is.fi.eu_433
  0x13000507, 0x211b1302, 0x201e1c08, 0x53131ba4,   // fr.et.un_420 et.tr.jw_222  id.ms.sq_443 tr.et.ht_433
  0x07190b07, 0x13005314, 0x13001011, 0x0b05250c,   // es.gl.it_432 ht.et.un_660  lt.et.un_630 eu.fr.es_543
  // [c560]
  0x531129a0, 0x1200031a, 0x191827a4, 0x1b250bad,   // sl.ro.ht_322 nl.hu.un_760  gd.ga.gl_433 es.eu.tr_643
  0x0223250c, 0x040a08ec, 0x180f2105, 0x551a16a0,   // eu.ca.da_543 uk.mk.ru_644  jw.lv.ga_333 hr.tl.rw_322
  0x6e002d08, 0x07180808, 0x2800251a, 0x6b042004,   // sk.blu.un_430 no.ga.it_443  eu.sw.un_760 sq.fi.ceb_332
  0x2a1b3113, 0x0c0d2dad, 0x203105a4, 0x1007040d,   // az.tr.mt_665 sk.cs.sv_643  fr.az.sq_433 ru.bg.be_554
  // [c570]
  0x111a16af, 0x1f002d04, 0x11315304, 0x122a010c,   // hr.tl.ro_655 sk.cy.un_320  ht.az.ro_332 en.mt.hu_543
  0x6400121b, 0x311a6b0c, 0x281e55a4, 0x12001913,   // hu.lg.un_770 ceb.tl.az_543  rw.ms.sw_433 gl.hu.un_650
  0x0b0a1ca0, 0x04001723, 0x05000d0d, 0x0e270607,   // id.pt.es_322 sr.ru.un_880  cs.fr.un_540 de.gd.is_432
  0x1a0a1911, 0x201617ad, 0x16290d0c, 0x212a01ee,   // gl.pt.tl_653 sr.hr.sq_643  cs.sl.hr_543 en.mt.jw_422
  // [c580]
  0x533f2a07, 0x1c00211a, 0x10042955, 0x12000e1b,   // mt.af.ht_432 jw.id.un_760  sl.fi.lt_442 is.hu.un_770
  0x20282aa7, 0x116b16a0, 0x08002114, 0x07030611,   // mt.sw.sq_532 hr.ceb.ro_322  jw.no.un_660 de.nl.it_653
  0x102d29a9, 0x0c023f0c, 0x0f2d3fa0, 0x180b010b,   // sl.sk.lt_544 af.da.sv_543  af.sk.lv_322 en.es.ga_542
  0x2b102008, 0x0f00092a, 0x290d010c, 0x06050105,   // sq.lt.vi_443 pl.lv.un_970  en.cs.sl_543 en.fr.de_333
  // [c590]
  0x18272a04, 0x100f01a9, 0x10170f55, 0x3f0409ec,   // mt.gd.ga_332 en.lv.lt_544  lv.sr.lt_442 pl.fi.af_644
  0x29033fa7, 0x53002322, 0x2a0e0111, 0x31110107,   // af.nl.sl_532 ca.ht.un_870  en.is.mt_653 en.ro.az_432
  0x120a2107, 0x25081904, 0x0f080208, 0x182b01ad,   // jw.pt.hu_432 gl.no.eu_332  da.no.lv_443 en.vi.ga_643
  0x21551fa4, 0x030625af, 0x080227ee, 0x20096409,   // cy.rw.jw_433 eu.de.nl_655  gd.da.no_422 lg.pl.sq_444
  // [c5a0]
  0x060f0308, 0x13092d0c, 0x53190212, 0x0200010d,   // nl.lv.de_443 sk.pl.et_543  da.gl.ht_654 en.da.un_540
  0x0e09280c, 0x06005309, 0x08200c13, 0x1a6b13ad,   // sw.pl.is_543 ht.de.un_440  sv.sq.no_665 et.ceb.tl_643
  0x230b20a4, 0x2a201b55, 0x552909a4, 0x25003112,   // sq.es.ca_433 tr.sq.mt_442  pl.sl.rw_433 az.eu.un_640
  0x55020c07, 0x08020fee, 0x2021090c, 0x10136b0c,   // sv.da.rw_432 lv.da.no_422  pl.jw.sq_543 ceb.et.lt_543
  // [c5b0]
  0x230b6b05, 0x55002d08, 0x136b1aad, 0x12642808,   // ceb.es.ca_333 sk.rw.un_430  tl.ceb.et_643 sw.lg.hu_443
  0x55000c05, 0x010208a4, 0x10000a12, 0x215513ec,   // sv.rw.un_330 no.da.en_433  pt.lt.un_640 et.rw.jw_644
  0x07001807, 0x1b00100d, 0x551a13a4, 0x09290dee,   // ga.it.un_420 lt.tr.un_540  et.tl.rw_433 cs.sl.pl_422
  0x190b0fa0, 0x161a210c, 0x10040fa4, 0x111017a4,   // lv.es.gl_322 jw.tl.hr_543  lv.fi.lt_433 sr.be.ro_433
  // [c5c0]
  0x29190a0d, 0x0f172908, 0x090d53a0, 0x1200060b,   // pt.gl.sl_554 sl.sr.lv_443  ht.cs.pl_322 de.hu.un_520
  0x1b641aa7, 0x23120aa0, 0x041e1c0c, 0x1125080c,   // tl.lg.tr_532 pt.hu.ca_322  id.ms.fi_543 no.eu.ro_543
  0x21311b04, 0x211e2805, 0x040c13ec, 0x190f10ee,   // tr.az.jw_332 sw.ms.jw_333  et.sv.fi_644 lt.lv.gl_422
  0x190a1009, 0x0c000a0c, 0x536b1a5a, 0x0f131004,   // lt.pt.gl_444 pt.sv.un_530  tl.ceb.ht_553 lt.et.lv_332
  // [c5d0]
  0x6b041c07, 0x53642813, 0x1b110507, 0x1f000704,   // id.fi.ceb_432 sw.lg.ht_665  fr.ro.tr_432 it.cy.un_320
  0x0c190a05, 0x64551a5a, 0x19001205, 0x1a6425a0,   // pt.gl.sv_333 tl.rw.lg_553  hu.gl.un_330 eu.lg.tl_322
  0x11530aa7, 0x161e2109, 0x21080bec, 0x013f0807,   // pt.ht.ro_532 jw.ms.hr_444  es.no.jw_644 no.af.en_432
  0x0b0a1aa4, 0x05002519, 0x0955280c, 0x6b1612a7,   // tl.pt.es_433 eu.fr.un_750  sw.rw.pl_543 hu.hr.ceb_532
  // [c5e0]
  0x11250512, 0x1008170d, 0x08041009, 0x090a2daf,   // fr.eu.ro_654 sr.uk.be_554  be.ru.uk_444 sk.pt.pl_655
  0x050a19a6, 0x05000e07, 0x53112911, 0x1300210c,   // gl.pt.fr_521 is.fr.un_420  sl.ro.ht_653 jw.et.un_530
  0x2d0512a9, 0x6b1318a0, 0x0818060c, 0x1a6b20a0,   // hu.fr.sk_544 ga.et.ceb_322  de.ga.no_543 sq.ceb.tl_322
  0x2d001619, 0x07251aa0, 0x13642855, 0x250113a0,   // hr.sk.un_750 tl.eu.it_322  sw.lg.et_442 et.en.eu_322
  // [c5f0]
  0x55003121, 0x0c2718a7, 0x3f002707, 0x55000e05,   // az.rw.un_860 ga.gd.sv_532  gd.af.un_420 is.rw.un_330
  0x1f002b0c, 0x1a6412a9, 0x052853af, 0x64121a55,   // vi.cy.un_530 hu.lg.tl_544  ht.sw.fr_655 tl.hu.lg_442
  0x11160dee, 0x1a00121a, 0x12000514, 0x12050aec,   // cs.hr.ro_422 hu.tl.un_760  fr.hu.un_660 pt.fr.hu_644
  0x06070fa0, 0x645312ec, 0x0a1b28a4, 0x05001911,   // lv.it.de_322 hu.ht.lg_644  sw.tr.pt_433 gl.fr.un_630
  // [c600]
  0x64552107, 0x0c2a130c, 0x273f0504, 0x010718a0,   // jw.rw.lg_432 et.mt.sv_543  fr.af.gd_332 ga.it.en_322
  0x2018270b, 0x0a1b55a0, 0x10001b0d, 0x00001837,   // gd.ga.sq_542 rw.tr.pt_322  tr.lt.un_540 ar.un.un_B00
  0x28000c04, 0x10313f0c, 0x11000b04, 0x2700090c,   // sv.sw.un_320 af.az.lt_543  es.ro.un_320 pl.gd.un_530
  0x1a00280d, 0x12190560, 0x0a120107, 0x07002d18,   // sw.tl.un_540 fr.gl.hu_664  en.hu.pt_432 sk.it.un_740
  // [c610]
  0x270711a7, 0x0900060b, 0x061c2104, 0x0700160c,   // ro.it.gd_532 de.pl.un_520  jw.id.de_332 hr.it.un_530
  0x050d10a0, 0x20001204, 0x1a20060c, 0x0220290c,   // lt.cs.fr_322 hu.sq.un_320  de.sq.tl_543 sl.sq.da_543
  0x100a075a, 0x100f0cec, 0x210620ec, 0x07050207,   // bg.mk.be_553 sv.lv.lt_644  sq.de.jw_644 da.fr.it_432
  0x161b20a0, 0x09290f07, 0x0704135a, 0x06281aa4,   // sq.tr.hr_322 lv.sl.pl_432  et.fi.it_553 tl.sw.de_433
  // [c620]
  0x012004a0, 0x012307a4, 0x203f010c, 0x2513100c,   // fi.sq.en_322 it.ca.en_433  en.af.sq_543 lt.et.eu_543
  0x1304640c, 0x160f12a4, 0x280f04a0, 0x1e13040b,   // lg.fi.et_543 hu.lv.hr_433  fi.lv.sw_322 fi.et.ms_542
  0x04070a60, 0x640f1304, 0x11000402, 0x0f00090e,   // mk.bg.ru_664 et.lv.lg_332  fi.ro.un_220 pl.lv.un_550
  0x28033fa7, 0x073f0302, 0x1a2864a7, 0x642155a4,   // af.nl.sw_532 nl.af.it_222  lg.sw.tl_532 rw.jw.lg_433
  // [c630]
  0x201c0eee, 0x64532107, 0x0a072a05, 0x64041104,   // is.id.sq_422 jw.ht.lg_432  mt.it.pt_333 ro.fi.lg_332
  0x6b005307, 0x1e1c19a4, 0x1a096b07, 0x082a2907,   // ht.ceb.un_420 gl.id.ms_433  ceb.pl.tl_432 sl.mt.no_432
  0x2153640d, 0x27000705, 0x2d1a55a0, 0x176b550c,   // lg.ht.jw_554 it.gd.un_330  rw.tl.sk_322 rw.ceb.sr_543
  0x1c216ba4, 0x08041711, 0x2d0d23a6, 0x040e10a4,   // ceb.jw.id_433 sr.ru.uk_653  ca.cs.sk_521 lt.is.fi_433
  // [c640]
  0x0220100c, 0x082d01a7, 0x0e0210a0, 0x0f291007,   // lt.sq.da_543 en.sk.no_532  lt.da.is_322 lt.sl.lv_432
  0x02121b04, 0x071710a4, 0x16171013, 0x050a12bb,   // tr.hu.da_332 be.sr.bg_433  lt.sr.hr_665 hu.pt.fr_854
  0x180a1211, 0x160f1005, 0x0c0408a0, 0x20161004,   // hu.pt.ga_653 lt.lv.hr_333  no.fi.sv_322 lt.hr.sq_332
  0x050b06a0, 0x191c2107, 0x060405a0, 0x04002012,   // de.es.fr_322 jw.id.gl_432  fr.fi.de_322 sq.fi.un_640
  // [c650]
  0x02100f07, 0x17160f08, 0x09131c0b, 0x060208a6,   // lv.lt.da_432 lv.hr.sr_443  mr.bh.hi_542 no.da.de_521
  0x04201012, 0x06002907, 0x252d0507, 0x3f2a1a04,   // lt.sq.fi_654 sl.de.un_420  fr.sk.eu_432 tl.mt.af_332
  0x1a1c2505, 0x2d000e07, 0x0f101f07, 0x1a533f07,   // eu.id.tl_333 is.sk.un_420  cy.lt.lv_432 af.ht.tl_432
  0x23072dee, 0x092d1f0c, 0x1b0405ee, 0x091329a0,   // sk.it.ca_422 cy.sk.pl_543  fr.fi.tr_422 sl.et.pl_322
  // [c660]
  0x1c251ea0, 0x556425a6, 0x0d000404, 0x05001807,   // ms.eu.id_322 eu.lg.rw_521  fi.cs.un_320 ga.fr.un_420
  0x130e64a0, 0x211f5308, 0x2500071b, 0x27002802,   // lg.is.et_322 ht.cy.jw_443  it.eu.un_770 sw.gd.un_220
  0x200c06a0, 0x1f12200c, 0x1001070c, 0x171610a7,   // de.sv.sq_322 sq.hu.cy_543  it.en.lt_543 lt.hr.sr_532
  0x3f002d08, 0x07251105, 0x190a05ec, 0x53022508,   // sk.af.un_430 ro.eu.it_333  fr.pt.gl_644 eu.da.ht_443
  // [c670]
  0x1b0611ee, 0x0e211b0c, 0x640f280b, 0x0d2953a4,   // ro.de.tr_422 tr.jw.is_543  sw.lv.lg_542 ht.sl.cs_433
  0x1f0208a4, 0x1f1e1c0d, 0x19530107, 0x0b230511,   // no.da.cy_433 id.ms.cy_554  en.ht.gl_432 fr.ca.es_653
  0x1c201ea0, 0x041320a0, 0x1b0f2105, 0x2a0413ee,   // ms.sq.id_322 sq.et.fi_322  jw.lv.tr_333 et.fi.mt_422
  0x040f16a0, 0x041325a0, 0x121b29a0, 0x1e5321a7,   // hr.lv.fi_322 eu.et.fi_322  sl.tr.hu_322 jw.ht.ms_532
  // [c680]
  0x0407100d, 0x18531e02, 0x2d0d29a6, 0x0f080ca0,   // be.bg.ru_554 ms.ht.ga_222  sl.cs.sk_521 sv.no.lv_322
  0x06083fee, 0x28131a08, 0x1c000c04, 0x030501a0,   // af.no.de_422 tl.et.sw_443  sv.id.un_320 en.fr.nl_322
  0x1c000b02, 0x133f035a, 0x6b2807a0, 0x2a001a07,   // es.id.un_220 nl.af.et_553  it.sw.ceb_322 tl.mt.un_420
  0x311b1cec, 0x2821200c, 0x1200110d, 0x18000619,   // id.tr.az_644 sq.jw.sw_543  ro.hu.un_540 de.ga.un_750
  // [c690]
  0x02213f0c, 0x100701a4, 0x1c0e1ea4, 0x0c120302,   // af.jw.da_543 en.it.lt_433  ms.is.id_433 nl.hu.sv_222
  0x03061807, 0x2a6b1a08, 0x642808a0, 0x02182112,   // ga.de.nl_432 tl.ceb.mt_443  no.sw.lg_322 jw.ga.da_654
  0x23191104, 0x070629a0, 0x110306a7, 0x06131cee,   // ro.gl.ca_332 sl.de.it_322  de.nl.ro_532 id.et.de_422
  0x3f060207, 0x25115309, 0x04000613, 0x09000f05,   // da.de.af_432 ht.ro.eu_444  de.fi.un_650 lv.pl.un_330
  // [c6a0]
  0x111328a0, 0x28202aac, 0x256b2307, 0x64082a07,   // sw.et.ro_322 mt.sq.sw_632  ca.ceb.eu_432 mt.no.lg_432
  0x021e1c04, 0x1e1f1c12, 0x2a6b09ac, 0x071203a0,   // id.ms.da_332 id.cy.ms_654  pl.ceb.mt_632 nl.hu.it_322
  0x0e000407, 0x10060908, 0x02006402, 0x09031207,   // fi.is.un_420 pl.de.lt_443  lg.da.un_220 hu.nl.pl_432
  0x041f0804, 0x13281ea0, 0x16291207, 0x11000512,   // no.cy.fi_332 ms.sw.et_322  hu.sl.hr_432 fr.ro.un_640
  // [c6b0]
  0x216455a0, 0x13252d08, 0x21135504, 0x105505a0,   // rw.lg.jw_322 sk.eu.et_443  rw.et.jw_332 fr.rw.lt_322
  0x03055307, 0x1e2864a0, 0x17165555, 0x135525a4,   // ht.fr.nl_432 lg.sw.ms_322  rw.hr.sr_442 eu.rw.et_433
  0x01032707, 0x12061b55, 0x102113ad, 0x20060c0c,   // gd.nl.en_432 tr.de.hu_442  et.jw.lt_643 sv.de.sq_543
  0x55171613, 0x092008a0, 0x10070aa9, 0x09066413,   // hr.sr.rw_665 no.sq.pl_322  mk.bg.be_544 lg.de.pl_665
  // [c6c0]
  0x1f060ea9, 0x28311b04, 0x55001202, 0x13000613,   // is.de.cy_544 tr.az.sw_332  hu.rw.un_220 de.et.un_650
  0x02181307, 0x0a1704ec, 0x1f000614, 0x311b120d,   // et.ga.da_432 ru.sr.mk_644  de.cy.un_660 hu.tr.az_554
  0x2500642a, 0x21252aa0, 0x0f003107, 0x55171614,   // lg.eu.un_970 mt.eu.jw_322  az.lv.un_420 hr.sr.rw_666
  0x12000610, 0x643f28ec, 0x27121a04, 0x063f1fa7,   // de.hu.un_620 sw.af.lg_644  tl.hu.gd_332 cy.af.de_532
  // [c6d0]
  0x280d0502, 0x13251704, 0x1e00120d, 0x2021120b,   // fr.cs.sw_222 sr.eu.et_332  hu.ms.un_540 hu.jw.sq_542
  0x642831a0, 0x1b166b02, 0x0a0511a0, 0x1a126bad,   // az.sw.lg_322 ceb.hr.tr_222  ro.fr.pt_322 ceb.hu.tl_643
  0x2a2712a0, 0x1e001009, 0x061b120e, 0x121004a4,   // hu.gd.mt_322 lt.ms.un_440  hu.tr.de_555 fi.lt.hu_433
  0x042810ad, 0x1e091204, 0x04002102, 0x18201212,   // lt.sw.fi_643 hu.pl.ms_332  jw.fi.un_220 hu.sq.ga_654
  // [c6e0]
  0x17111007, 0x121e1c14, 0x07000907, 0x2a2b12a6,   // be.ro.sr_432 id.ms.hu_666  pl.it.un_420 hu.vi.mt_521
  0x0a1107af, 0x04006b0d, 0x55281207, 0x28000805,   // it.ro.pt_655 ceb.fi.un_540  hu.sw.rw_432 no.sw.un_330
  0x01271807, 0x5517110c, 0x111b2902, 0x21132a07,   // ga.gd.en_432 ro.sr.rw_543  sl.tr.ro_222 mt.et.jw_432
  0x11100f13, 0x071008ee, 0x29551b07, 0x20063f0b,   // lv.lt.ro_665 uk.be.bg_422  tr.rw.sl_432 af.de.sq_542
  // [c6f0]
  0x11271812, 0x12255508, 0x0f6b03a4, 0x251c1e11,   // ga.gd.ro_654 rw.eu.hu_443  nl.ceb.lv_433 ms.id.eu_653
  0x171207a7, 0x1025045a, 0x041053ec, 0x1a556b11,   // it.hu.sr_532 fi.eu.lt_553  ht.lt.fi_644 ceb.rw.tl_653
  0x1b552a09, 0x13040ca6, 0x120453a7, 0x6e1c1eee,   // mt.rw.tr_444 sv.fi.et_521  ht.fi.hu_532 ms.id.blu_422
  0x041c1e0c, 0x17002d05, 0x13120414, 0x2300250b,   // ms.id.fi_543 sk.sr.un_330  fi.hu.et_666 eu.ca.un_520
  // [c700]
  0x20000507, 0x131216a0, 0x16172da7, 0x07050da0,   // fr.sq.un_420 hr.hu.et_322  sk.sr.hr_532 cs.fr.it_322
  0x291755ee, 0x31286bee, 0x23123f04, 0x180413ee,   // rw.sr.sl_422 ceb.sw.az_422  af.hu.ca_332 et.fi.ga_422
  0x0d003f07, 0x17162d08, 0x03000119, 0x3f1303a7,   // af.cs.un_420 sk.hr.sr_443  en.nl.un_750 nl.et.af_532
  0x0f550da7, 0x0c041311, 0x112101a6, 0x09050d12,   // cs.rw.lv_532 et.fi.sv_653  en.jw.ro_521 cs.fr.pl_654
  // [c710]
  0x110301a4, 0x21642807, 0x2d0d2807, 0x162d1711,   // en.nl.ro_433 sw.lg.jw_432  sw.cs.sk_432 sr.sk.hr_653
  0x311e1b02, 0x29170355, 0x162017ee, 0x1f0108a0,   // tr.ms.az_222 nl.sr.sl_442  sr.sq.hr_422 no.en.cy_322
  0x29031704, 0x312755ec, 0x64000604, 0x190307a0,   // sr.nl.sl_332 rw.gd.az_644  de.lg.un_320 it.nl.gl_322
  0x13040111, 0x130d0405, 0x19000807, 0x07646b02,   // en.fi.et_653 fi.cs.et_333  no.gl.un_420 ceb.lg.it_222
  // [c720]
  0x081013a6, 0x3f061ba9, 0x13060c12, 0x0e0802a7,   // et.lt.no_521 tr.de.af_544  sv.de.et_654 da.no.is_532
  0x0c6b0202, 0x5564070c, 0x08006e04, 0x6e215512,   // da.ceb.sv_222 it.lg.rw_543  blu.no.un_320 rw.jw.blu_654
  0x64041ba4, 0x29000807, 0x1a00530c, 0x53011b02,   // tr.fi.lg_433 no.sl.un_420  ht.tl.un_530 tr.en.ht_222
  0x121e1c60, 0x10040504, 0x10006402, 0x17000c08,   // id.ms.hu_664 fr.fi.lt_332  lg.lt.un_220 sv.sr.un_430
  // [c730]
  0x16000c12, 0x0f002b13, 0x0f060b04, 0x100b050c,   // sv.hr.un_640 vi.lv.un_650  es.de.lv_332 fr.es.lt_543
  0x552164a4, 0x21056b07, 0x16000802, 0x022d0304,   // lg.jw.rw_433 ceb.fr.jw_432  no.hr.un_220 nl.sk.da_332
  0x1a311bec, 0x04130813, 0x061b13a0, 0x21056e07,   // tr.az.tl_644 no.et.fi_665  et.tr.de_322 blu.fr.jw_432
  0x1c251e0c, 0x0e250fac, 0x02162aa0, 0x2900280e,   // ms.eu.id_543 lv.eu.is_632  mt.hr.da_322 sw.sl.un_550
  // [c740]
  0x0f1612a0, 0x1a003105, 0x010f2ba7, 0x2b000205,   // hu.hr.lv_322 az.tl.un_330  vi.lv.en_532 da.vi.un_330
  0x231c1aa0, 0x102b04ee, 0x2a1f010c, 0x552805a0,   // tl.id.ca_322 fi.vi.lt_422  en.cy.mt_543 fr.sw.rw_322
  0x1b00210e, 0x100f0408, 0x3f0f2b07, 0x092a1fa4,   // jw.tr.un_550 fi.lv.lt_443  vi.lv.af_432 cy.mt.pl_433
  0x07080304, 0x08001318, 0x133f0fa0, 0x1b0e28a0,   // nl.no.it_332 et.no.un_740  lv.af.et_322 sw.is.tr_322
  // [c750]
  0x120e21a0, 0x0b001604, 0x06211a04, 0x0c001322,   // jw.is.hu_322 hr.es.un_320  tl.jw.de_332 et.sv.un_870
  0x02290808, 0x011206a0, 0x1e002004, 0x2d2912a0,   // no.sl.da_443 de.hu.en_322  sq.ms.un_320 hu.sl.sk_322
  0x0b103102, 0x16001b19, 0x16080c04, 0x080c13a4,   // az.lt.es_222 tr.hr.un_750  sv.no.hr_332 et.sv.no_433
  0x53216455, 0x07000d05, 0x030802a7, 0x1e0b2307,   // lg.jw.ht_442 cs.it.un_330  da.no.nl_532 ca.es.ms_432
  // [c760]
  0x170a080c, 0x23002a0c, 0x07131007, 0x5300210e,   // uk.mk.sr_543 mt.ca.un_530  lt.et.it_432 jw.ht.un_550
  0x120e18af, 0x19002814, 0x0b23070d, 0x0f0107ee,   // ga.is.hu_655 sw.gl.un_660  it.ca.es_554 it.en.lv_422
  0x0c00030c, 0x1607100c, 0x6b00101a, 0x6e2d29ad,   // nl.sv.un_530 lt.it.hr_543  lt.ceb.un_760 sl.sk.blu_643
  0x17130d0c, 0x121a2004, 0x046b1012, 0x0c100b05,   // cs.et.sr_543 sq.tl.hu_332  lt.ceb.fi_654 es.lt.sv_333
  // [c770]
  0x6b291a07, 0x0e0d2d0c, 0x13550211, 0x551b18ec,   // tl.sl.ceb_432 sk.cs.is_543  da.rw.et_653 ga.tr.rw_644
  0x11001322, 0x23530514, 0x0e033f0d, 0x052519a0,   // et.ro.un_870 fr.ht.ca_666  af.nl.is_554 gl.eu.fr_322
  0x13000c14, 0x09172912, 0x0b0a1205, 0x551a0b04,   // sv.et.un_660 sl.sr.pl_654  hu.pt.es_333 es.tl.rw_332
  0x1b0f16a0, 0x100b0a04, 0x0b0a1602, 0x2a2053a4,   // hr.lv.tr_322 pt.es.lt_332  hr.pt.es_222 ht.sq.mt_433
  // [c780]
  0x100b0a09, 0x09106ba4, 0x0601130c, 0x19050a12,   // pt.es.lt_444 ceb.lt.pl_433  et.en.de_543 pt.fr.gl_654
  0x0b6e19a0, 0x0b040d02, 0x1300010c, 0x55211307,   // gl.blu.es_322 cs.fi.es_222  en.et.un_530 et.jw.rw_432
  0x130f11ad, 0x0f000d02, 0x020c18ec, 0x02003f0d,   // ro.lv.et_643 cs.lv.un_220  ga.sv.da_644 af.da.un_540
  0x05062304, 0x2d0e0dec, 0x050c31ee, 0x10110a55,   // ca.de.fr_332 cs.is.sk_644  az.sv.fr_422 mk.ro.be_442
  // [c790]
  0x1a132aad, 0x03061805, 0x1b1f310c, 0x18100e07,   // mt.et.tl_643 ga.de.nl_333  az.cy.tr_543 is.lt.ga_432
  0x2d0d08a9, 0x11000e07, 0x05000605, 0x0e031f02,   // no.cs.sk_544 is.ro.un_420  de.fr.un_330 cy.nl.is_222
  0x2d090f0c, 0x1b182714, 0x1b123111, 0x2b000c04,   // lv.pl.sk_543 gd.ga.tr_666  az.hu.tr_653 sv.vi.un_320
  0x0c00131a, 0x136b02a0, 0x100502ee, 0x032818a0,   // et.sv.un_760 da.ceb.et_322  da.fr.lt_422 ga.sw.nl_322
  // [c7a0]
  0x1b042aa4, 0x3f1e1c09, 0x2a000d07, 0x11002313,   // mt.fi.tr_433 id.ms.af_444  cs.mt.un_420 ca.ro.un_650
  0x251b010b, 0x0f00120e, 0x21161ba0, 0x051c28a6,   // en.tr.eu_542 hu.lv.un_550  tr.hr.jw_322 sw.id.fr_521
  0x0700180d, 0x25003105, 0x310f2507, 0x132528a0,   // ga.it.un_540 az.eu.un_330  eu.lv.az_432 sw.eu.et_322
  0x23001b08, 0x2a003f07, 0x08290c08, 0x3f060955,   // tr.ca.un_430 af.mt.un_420  sv.sl.no_443 pl.de.af_442
  // [c7b0]
  0x04531ba0, 0x29060c60, 0x1e1c28a6, 0x28001608,   // tr.ht.fi_322 sv.de.sl_664  sw.id.ms_521 hr.sw.un_430
  0x203f0404, 0x1a08160c, 0x0603040c, 0x201e2807,   // fi.af.sq_332 hr.no.tl_543  fi.nl.de_543 sw.ms.sq_432
  0x531a28ac, 0x200c0611, 0x030619ee, 0x2b1f3f05,   // sw.tl.ht_632 de.sv.sq_653  gl.de.nl_422 af.cy.vi_333
  0x1a0e2855, 0x53071107, 0x161c0fad, 0x250c0111,   // sw.is.tl_442 ro.it.ht_432  lv.id.hr_643 en.sv.eu_653
  // [c7c0]
  0x111f1907, 0x08211c04, 0x0200042b, 0x552528a0,   // gl.cy.ro_432 id.jw.no_332  fi.da.un_980 sw.eu.rw_322
  0x29132a09, 0x04020aee, 0x1200041b, 0x171601a9,   // mt.et.sl_444 pt.da.fi_422  fi.hu.un_770 en.hr.sr_544
  0x212007ee, 0x13001219, 0x030d11ec, 0x211b20ec,   // it.sq.jw_422 hu.et.un_750  ro.cs.nl_644 sq.tr.jw_644
  0x0e08640d, 0x13212aa4, 0x64040ea4, 0x202928ad,   // lg.no.is_554 mt.jw.et_433  is.fi.lg_433 sw.sl.sq_643
  // [c7d0]
  0x11016b04, 0x122a200c, 0x201110a4, 0x1e131ca9,   // ceb.en.ro_332 sq.mt.hu_543  lt.ro.sq_433 id.et.ms_544
  0x550e040c, 0x202864a0, 0x0d001104, 0x6b1716ee,   // fi.is.rw_543 lg.sw.sq_322  ro.cs.un_320 hr.sr.ceb_422
  0x09022005, 0x64000e13, 0x311b1004, 0x1c1264a7,   // sq.da.pl_333 is.lg.un_650  lt.tr.az_332 lg.hu.id_532
  0x19310e08, 0x01080eee, 0x160b100c, 0x2a231311,   // is.az.gl_443 is.no.en_422  lt.es.hr_543 et.ca.mt_653
  // [c7e0]
  0x19080ba4, 0x13042908, 0x070b06a4, 0x17190b04,   // es.no.gl_433 sl.fi.et_443  de.es.it_433 es.gl.sr_332
  0x1613080c, 0x07030612, 0x080c64af, 0x0e13040c,   // no.et.hr_543 de.nl.it_654  lg.sv.no_655 fi.et.is_543
  0x0e081c0b, 0x07060309, 0x0e042708, 0x0c060355,   // id.no.is_542 nl.de.it_444  gd.fi.is_443 nl.de.sv_442
  0x17121611, 0x1b310eee, 0x1b190e08, 0x010910ad,   // hr.hu.sr_653 is.az.tr_422  is.gl.tr_443 lt.pl.en_643
  // [c7f0]
  0x070821a0, 0x0c1a0a07, 0x18070609, 0x07030607,   // jw.no.it_322 pt.tl.sv_432  de.it.ga_444 de.nl.it_432
  0x03060708, 0x0d290908, 0x182d0ea4, 0x1e000805,   // it.de.nl_443 pl.sl.cs_443  is.sk.ga_433 no.ms.un_330
  0x0d001002, 0x17000e04, 0x091f100b, 0x252112af,   // lt.cs.un_220 is.sr.un_320  lt.cy.pl_542 hu.jw.eu_655
  0x2a6b01a0, 0x060f03a4, 0x0f2353ee, 0x03213fa4,   // en.ceb.mt_322 nl.lv.de_433  ht.ca.lv_422 af.jw.nl_433

  // [c800]
  0x0e03060b, 0x53002321, 0x1e1c0aa0, 0x020c0ea6,   // de.nl.is_542 ca.ht.un_860  pt.id.ms_322 is.sv.da_521
  0x040817ac, 0x2800101a, 0x28121e0b, 0x041320ee,   // sr.uk.ru_632 lt.sw.un_760  ms.hu.sw_542 sq.et.fi_422
  0x0c000319, 0x2b000e14, 0x201f2307, 0x12231ba4,   // nl.sv.un_750 is.vi.un_660  ca.cy.sq_432 tr.ca.hu_433
  0x08022102, 0x182b010c, 0x116428a4, 0x0b110604,   // jw.da.no_222 en.vi.ga_543  sw.lg.ro_433 de.ro.es_332
  // [c810]
  0x2705180c, 0x28182a0c, 0x090d2d0c, 0x2a2106a0,   // ga.fr.gd_543 mt.ga.sw_543  sk.cs.pl_543 de.jw.mt_322
  0x02113104, 0x180812a4, 0x20011802, 0x29642dee,   // az.ro.da_332 hu.no.ga_433  ga.en.sq_222 sk.lg.sl_422
  0x022308a9, 0x011803ee, 0x110501a9, 0x090c29a4,   // no.ca.da_544 nl.ga.en_422  en.fr.ro_544 sl.sv.pl_433
  0x0d5564a0, 0x050c0107, 0x212a28ac, 0x01121fa7,   // lg.rw.cs_322 en.sv.fr_432  sw.mt.jw_632 cy.hu.en_532
  // [c820]
  0x05000305, 0x27182812, 0x0c000713, 0x1208020d,   // nl.fr.un_330 sw.ga.gd_654  it.sv.un_650 da.no.hu_554
  0x212728ec, 0x110755ee, 0x1300050d, 0x0d2d5555,   // sw.gd.jw_644 rw.it.ro_422  fr.et.un_540 rw.sk.cs_442
  0x6b2821ec, 0x180210ee, 0x0f2504ec, 0x1b281c07,   // jw.sw.ceb_644 lt.da.ga_422  fi.eu.lv_644 id.sw.tr_432
  0x052707a7, 0x2a0e6ea0, 0x071306a4, 0x1b000402,   // it.gd.fr_532 blu.is.mt_322  de.et.it_433 fi.tr.un_220
  // [c830]
  0x1107230d, 0x0717040d, 0x1e082108, 0x081807ee,   // ca.it.ro_554 ru.sr.bg_554  jw.no.ms_443 it.ga.no_422
  0x0c290107, 0x07001307, 0x07131bee, 0x132007a0,   // en.sl.sv_432 et.it.un_420  tr.et.it_422 it.sq.et_322
  0x2a111809, 0x1f290a0d, 0x0c212855, 0x120b19a7,   // ga.ro.mt_444 pt.sl.cy_554  sw.jw.sv_442 gl.es.hu_532
  0x0c2820a4, 0x1716010c, 0x0c000d0b, 0x020c05a0,   // sq.sw.sv_433 en.hr.sr_543  cs.sv.un_520 fr.sv.da_322
  // [c840]
  0x232a0708, 0x1107235a, 0x04000f05, 0x17161012,   // it.mt.ca_443 ca.it.ro_553  lv.fi.un_330 lt.hr.sr_654
  0x23000a02, 0x092519ad, 0x04001720, 0x2a00111a,   // pt.ca.un_220 gl.eu.pl_643  sr.ru.un_850 ro.mt.un_760
  0x0900250e, 0x23005308, 0x071011a4, 0x641a6b0d,   // eu.pl.un_550 ht.ca.un_430  ro.be.bg_433 ceb.tl.lg_554
  0x033f27a0, 0x185509ad, 0x64550960, 0x0a095555,   // gd.af.nl_322 pl.rw.ga_643  pl.rw.lg_664 rw.pl.pt_442
  // [c850]
  0x170810ee, 0x1700110b, 0x0e000f1a, 0x0a080755,   // be.uk.sr_422 ro.sr.un_520  lv.is.un_760 bg.uk.mk_442
  0x0f2810ad, 0x0f000e07, 0x0f000413, 0x23005309,   // lt.sw.lv_643 is.lv.un_420  fi.lv.un_650 ht.ca.un_440
  0x04100f08, 0x290b28ad, 0x2a002019, 0x092928ec,   // lv.lt.fi_443 sw.es.sl_643  sq.mt.un_750 sw.sl.pl_644
  0x181205ad, 0x0e100f0d, 0x0817100c, 0x0e001009,   // fr.hu.ga_643 lv.lt.is_554  be.sr.uk_543 lt.is.un_440
  // [c860]
  0x10200fa4, 0x100f0e11, 0x18005309, 0x31290fad,   // lv.sq.lt_433 is.lv.lt_653  ht.ga.un_440 lv.sl.az_643
  0x0f00161b, 0x0f230b55, 0x032a20ee, 0x063f2aa7,   // hr.lv.un_770 es.ca.lv_442  sq.mt.nl_422 mt.af.de_532
  0x2a2928a0, 0x082a07a4, 0x3f2301a4, 0x03215304,   // sw.sl.mt_322 it.mt.no_433  en.ca.af_433 ht.jw.nl_332
  0x211617ee, 0x0607010b, 0x0b1325ad, 0x2b100f08,   // sr.hr.jw_422 en.it.de_542  eu.et.es_643 lv.lt.vi_443
  // [c870]
  0x0f043fa0, 0x6b210607, 0x050f1007, 0x1b000412,   // af.fi.lv_322 de.jw.ceb_432  lt.lv.fr_432 fi.tr.un_640
  0x3f0f2da4, 0x063f2a07, 0x3f0713a6, 0x04101108,   // sk.lv.af_433 mt.af.de_432  et.it.af_521 ro.be.ru_443
  0x10042b02, 0x13002a02, 0x130720a4, 0x05040fa0,   // vi.fi.lt_222 mt.et.un_220  sq.it.et_433 lv.fi.fr_322
  0x06030ba4, 0x0e030804, 0x3f2912ac, 0x050118a7,   // es.nl.de_433 no.nl.is_332  hu.sl.af_632 ga.en.fr_532
  // [c880]
  0x090821a0, 0x17290f07, 0x12292355, 0x10031b02,   // jw.no.pl_322 lv.sl.sr_432  ca.sl.hu_442 tr.nl.lt_222
  0x17000302, 0x21171655, 0x5518280c, 0x55086404,   // nl.sr.un_220 hr.sr.jw_442  sw.ga.rw_543 lg.no.rw_332
  0x551609ee, 0x2a001302, 0x1c021b07, 0x08121bad,   // pl.hr.rw_422 et.mt.un_220  tr.da.id_432 tr.hu.no_643
  0x09550309, 0x0c20080c, 0x020d2d20, 0x28642902,   // nl.rw.pl_444 no.sq.sv_543  sk.cs.da_875 sl.lg.sw_222
  // [c890]
  0x1108175a, 0x0d0719a0, 0x0f296402, 0x2155280c,   // sr.uk.ro_553 gl.it.cs_322  lg.sl.lv_222 sw.rw.jw_543
  0x09291207, 0x2d170d09, 0x021308a0, 0x29072307,   // hu.sl.pl_432 cs.sr.sk_444  no.et.da_322 ca.it.sl_432
  0x2000030c, 0x1b0e08a0, 0x0d6b2d0c, 0x21281c04,   // nl.sq.un_530 no.is.tr_322  sk.ceb.cs_543 id.sw.jw_332
  0x2a002d04, 0x0e000304, 0x2d0e12af, 0x16001020,   // sk.mt.un_320 nl.is.un_320  hu.is.sk_655 lt.hr.un_850
  // [c8a0]
  0x17002a02, 0x16006e05, 0x2d001204, 0x1b00040c,   // mt.sr.un_220 blu.hr.un_330  hu.sk.un_320 fi.tr.un_530
  0x190218a0, 0x18001f19, 0x20060caf, 0x0d291112,   // ga.da.gl_322 cy.ga.un_750  sv.de.sq_655 ro.sl.cs_654
  0x11290d02, 0x21280604, 0x0c000105, 0x180123ee,   // cs.sl.ro_222 de.sw.jw_332  en.sv.un_330 ca.en.ga_422
  0x21002718, 0x042523a6, 0x18000705, 0x202a21a0,   // gd.jw.un_740 ca.eu.fi_521  it.ga.un_330 jw.mt.sq_322
  // [c8b0]
  0x0c0f08a0, 0x0d112907, 0x02060c55, 0x1109290c,   // no.lv.sv_322 sl.ro.cs_432  sv.de.da_442 sl.pl.ro_543
  0x29001112, 0x0c1b5312, 0x290d1109, 0x0e182711,   // ro.sl.un_640 ht.tr.sv_654  ro.cs.sl_444 gd.ga.is_653
  0x53000c0d, 0x201608a0, 0x11070da0, 0x0c030602,   // sv.ht.un_540 no.hr.sq_322  cs.it.ro_322 de.nl.sv_222
  0x17060104, 0x0e000507, 0x5500120e, 0x64001207,   // en.de.sr_332 fr.is.un_420  hu.rw.un_550 hu.lg.un_420
  // [c8c0]
  0x1c000308, 0x202b1907, 0x210b1705, 0x2d0e1908,   // nl.id.un_430 gl.vi.sq_432  sr.es.jw_333 gl.is.sk_443
  0x122517a4, 0x0c020304, 0x190b6402, 0x201711a0,   // sr.eu.hu_433 nl.da.sv_332  lg.es.gl_222 ro.sr.sq_322
  0x0a0811a0, 0x1228640b, 0x0f1228a4, 0x551217a0,   // ro.uk.mk_322 lg.sw.hu_542  sw.hu.lv_433 sr.hu.rw_322
  0x03100607, 0x1617120c, 0x25110912, 0x2b1364a7,   // de.lt.nl_432 hu.sr.hr_543  pl.ro.eu_654 lg.et.vi_532
  // [c8d0]
  0x172911a7, 0x1b100f55, 0x200d170c, 0x28040f0e,   // ro.sl.sr_532 lv.lt.tr_442  sr.cs.sq_543 lv.fi.sw_555
  0x17166402, 0x250406a4, 0x070e040c, 0x0600110d,   // lg.hr.sr_222 de.fi.eu_433  fi.is.it_543 ro.de.un_540
  0x04100613, 0x06133f0c, 0x2a050712, 0x0311010c,   // de.lt.fi_665 af.et.de_543  it.fr.mt_654 en.ro.nl_543
  0x3f010302, 0x270611a0, 0x1f000a23, 0x251f0611,   // nl.en.af_222 ro.de.gd_322  pt.cy.un_880 de.cy.eu_653
  // [c8e0]
  0x0f190aad, 0x190b2da4, 0x101b2109, 0x2b0601ad,   // pt.gl.lv_643 sk.es.gl_433  jw.tr.lt_444 en.de.vi_643
  0x190a0eaf, 0x191f28ee, 0x043f0313, 0x643f0308,   // is.pt.gl_655 sw.cy.gl_422  nl.af.fi_665 nl.af.lg_443
  0x06113f12, 0x6b1a06ee, 0x21061f07, 0x040f25a4,   // af.ro.de_654 de.tl.ceb_422  cy.de.jw_432 eu.lv.fi_433
  0x01530602, 0x281a3fa4, 0x05230b0c, 0x2d090d0b,   // de.ht.en_222 af.tl.sw_433  es.ca.fr_543 cs.pl.sk_542
  // [c8f0]
  0x6b001f07, 0x23051fa0, 0x2a035307, 0x01191fac,   // cy.ceb.un_420 cy.fr.ca_322  ht.nl.mt_432 cy.gl.en_632
  0x170810af, 0x1f063f07, 0x2a0905a0, 0x09200b08,   // be.uk.sr_655 af.de.cy_432  fr.pl.mt_322 es.sq.pl_443
  0x0f013fa0, 0x172a20a0, 0x0b0a23a9, 0x231f550c,   // af.en.lv_322 sq.mt.sr_322  ca.pt.es_544 rw.cy.ca_543
  0x060910ad, 0x2a1b550c, 0x0f551204, 0x04005308,   // lt.pl.de_643 rw.tr.mt_543  hu.rw.lv_332 ht.fi.un_430
  // [c900]
  0x20110ba4, 0x08172908, 0x2d0417a0, 0x18021fee,   // es.ro.sq_433 sl.sr.no_443  sr.fi.sk_322 cy.da.ga_422
  0x1121250c, 0x0b002708, 0x2d041ea0, 0x02002a1a,   // eu.jw.ro_543 gd.es.un_430  ms.fi.sk_322 mt.da.un_760
  0x11202155, 0x17292512, 0x0f00010d, 0x0d092d13,   // jw.sq.ro_442 eu.sl.sr_654  en.lv.un_540 sk.pl.cs_665
  0x643f03a6, 0x0e00230c, 0x1c5508a0, 0x1100120c,   // nl.af.lg_521 ca.is.un_530  no.rw.id_322 hu.ro.un_530
  // [c910]
  0x2d0d17af, 0x062a0fa0, 0x0d29090c, 0x10060f55,   // sr.cs.sk_655 lv.mt.de_322  pl.sl.cs_543 lv.de.lt_442
  0x08002804, 0x0f3f23a4, 0x02010607, 0x062a0f0c,   // sw.no.un_320 ca.af.lv_433  de.en.da_432 lv.mt.de_543
  0x23062504, 0x05031104, 0x08101713, 0x08041308,   // eu.de.ca_332 ro.nl.fr_332  sr.be.uk_665 et.fi.no_443
  0x17000a34, 0x1a002133, 0x2d03050c, 0x272a1fad,   // mk.sr.un_A80 jw.tl.un_A70  fr.nl.sk_543 cy.mt.gd_643
  // [c920]
  0x3f06010b, 0x2a25010b, 0x06000f02, 0x07110fa9,   // en.de.af_542 en.eu.mt_542  lv.de.un_220 lv.ro.it_544
  0x53060855, 0x1800190c, 0x280827a9, 0x07271855,   // no.de.ht_442 gl.ga.un_530  gd.no.sw_544 ga.gd.it_442
  0x31003f0d, 0x20042508, 0x0708170d, 0x551a64af,   // af.az.un_540 eu.fi.sq_443  sr.uk.bg_554 lg.tl.rw_655
  0x180211a0, 0x20130f05, 0x311a1e12, 0x551e1c5a,   // ro.da.ga_322 lv.et.sq_333  ms.tl.az_654 id.ms.rw_553
  // [c930]
  0x6b006405, 0x02030c02, 0x120a1708, 0x532328ee,   // lg.ceb.un_330 sv.nl.da_222  sr.mk.ur_443 sw.ca.ht_422
  0x28090408, 0x53192807, 0x3f002b02, 0x0c1617ee,   // fi.pl.sw_443 sw.gl.ht_432  vi.af.un_220 sr.hr.sv_422
  0x04101fad, 0x12090dee, 0x0a00072b, 0x64551e0c,   // cy.lt.fi_643 cs.pl.hu_422  bg.mk.un_980 ms.rw.lg_543
  0x530c1fa7, 0x04001129, 0x64551aa4, 0x2d16090c,   // cy.sv.ht_532 ro.ru.un_960  tl.rw.lg_433 pl.hr.sk_543
  // [c940]
  0x0c0a0407, 0x0a1704af, 0x6e5305a0, 0x53052707,   // fi.pt.sv_432 ru.sr.mk_655  fr.ht.blu_322 gd.fr.ht_432
  0x0c00170e, 0x53000f08, 0x0500250d, 0x03010cee,   // sr.sv.un_550 lv.ht.un_430  eu.fr.un_540 sv.en.nl_422
  0x2a052108, 0x1e1c2108, 0x25051ba0, 0x2a0853ee,   // jw.fr.mt_443 jw.id.ms_443  tr.fr.eu_322 ht.no.mt_422
  0x08050107, 0x13160f08, 0x01002812, 0x1f2009ad,   // en.fr.no_432 lv.hr.et_443  sw.en.un_640 pl.sq.cy_643
  // [c950]
  0x170a1114, 0x0e00131b, 0x0f080204, 0x1b552aa7,   // ro.mk.sr_666 et.is.un_770  da.no.lv_332 mt.rw.tr_532
  0x0e130c14, 0x311f2704, 0x3f001f21, 0x1f090408,   // sv.et.is_666 gd.cy.az_332  cy.af.un_860 fi.pl.cy_443
  0x080501a4, 0x1b0b01a0, 0x130e08a4, 0x12040aa0,   // en.fr.no_433 en.es.tr_322  no.is.et_433 pt.fi.hu_322
  0x3f0c1f0c, 0x08130c0b, 0x0b0701a4, 0x1f271860,   // cy.sv.af_543 sv.et.no_542  en.it.es_433 ga.gd.cy_664
  // [c960]
  0x060c130d, 0x19230755, 0x0d00102a, 0x06312504,   // et.sv.de_554 it.ca.gl_442  lt.cs.un_970 eu.az.de_332
  0x6b180107, 0x05192302, 0x1f2a1804, 0x23050704,   // en.ga.ceb_432 ca.gl.fr_222  ga.mt.cy_332 it.fr.ca_332
  0x07111005, 0x08031312, 0x0e0813a9, 0x29202da4,   // be.ro.bg_333 et.nl.no_654  et.no.is_544 sk.sq.sl_433
  0x0e13080e, 0x20100f0d, 0x160e030c, 0x2a203107,   // no.et.is_555 lv.lt.sq_554  nl.is.hr_543 az.sq.mt_432
  // [c970]
  0x212d11a0, 0x536455a6, 0x281f0107, 0x1100290c,   // ro.sk.jw_322 rw.lg.ht_521  en.cy.sw_432 sl.ro.un_530
  0x29232aa9, 0x2a002123, 0x20000f07, 0x02000705,   // mt.ca.sl_544 jw.mt.un_880  lv.sq.un_420 it.da.un_330
  0x20002512, 0x2500280d, 0x212555a9, 0x0c0a1f04,   // eu.sq.un_640 sw.eu.un_540  rw.eu.jw_544 cy.pt.sv_332
  0x530a0507, 0x29200e07, 0x532a0e0c, 0x1a190b0c,   // fr.pt.ht_432 is.sq.sl_432  is.mt.ht_543 es.gl.tl_543
  // [c980]
  0x17110a07, 0x0c200811, 0x28181308, 0x2118200c,   // mk.ro.sr_432 no.sq.sv_653  et.ga.sw_443 sq.ga.jw_543
  0x071110a0, 0x0a1004a9, 0x17100aa0, 0x03170809,   // lt.ro.it_322 ru.be.mk_544  mk.be.sr_322 no.sr.nl_444
  0x040a1760, 0x1131200d, 0x0d1c1360, 0x2d251a05,   // sr.mk.ru_664 sq.az.ro_554  bh.mr.ne_664 tl.eu.sk_333
  0x31000b04, 0x070a170b, 0x55050ba4, 0x64252102,   // es.az.un_320 sr.mk.bg_542  es.fr.rw_433 jw.eu.lg_222
  // [c990]
  0x556425ee, 0x646b29a4, 0x28011c02, 0x252855a0,   // eu.lg.rw_422 sl.ceb.lg_433  id.en.sw_222 rw.sw.eu_322
  0x216455ec, 0x55002b0e, 0x01550ba7, 0x0d120508,   // rw.lg.jw_644 vi.rw.un_550  es.rw.en_532 fr.hu.cs_443
  0x120a28a7, 0x64553108, 0x211f55a0, 0x07081704,   // sw.pt.hu_532 az.rw.lg_443  rw.cy.jw_322 sr.uk.bg_332
  0x202906ee, 0x21231e07, 0x05000702, 0x2b550b0d,   // de.sl.sq_422 ms.ca.jw_432  it.fr.un_220 es.rw.vi_554
  // [c9a0]
  0x0a251ca0, 0x0a110511, 0x2b1b0ba4, 0x12200b04,   // id.eu.pt_322 fr.ro.pt_653  es.tr.vi_433 es.sq.hu_332
  0x0f002a12, 0x0f2a3f04, 0x053f0607, 0x04051ba0,   // mt.lv.un_640 af.mt.lv_332  de.af.fr_432 tr.fr.fi_322
  0x0c1b0505, 0x111f1804, 0x0f043f14, 0x18286ba0,   // fr.tr.sv_333 ga.cy.ro_332  af.fi.lv_666 ceb.sw.ga_322
  0x3f092d08, 0x1e001c11, 0x09000f0c, 0x1b200204,   // sk.pl.af_443 id.ms.un_630  lv.pl.un_530 da.sq.tr_332
  // [c9b0]
  0x232913ad, 0x1e28210d, 0x28290f02, 0x23100ea0,   // et.sl.ca_643 jw.sw.ms_554  lv.sl.sw_222 is.lt.ca_322
  0x2a3f210d, 0x281e1ba4, 0x130d1cac, 0x110b2707,   // jw.af.mt_554 tr.ms.sw_433  mr.ne.bh_632 gd.es.ro_432
  0x2d001f04, 0x253f13a4, 0x1c2164a0, 0x07102008,   // cy.sk.un_320 et.af.eu_433  lg.jw.id_322 sq.lt.it_443
  0x0153550b, 0x03083fa4, 0x083f0313, 0x12041313,   // rw.ht.en_542 af.no.nl_433  nl.af.no_665 et.fi.hu_665
  // [c9c0]
  0x180627ee, 0x11002d12, 0x2a0f12a7, 0x1b001e08,   // gd.de.ga_422 sk.ro.un_640  hu.lv.mt_532 ms.tr.un_430
  0x0b0a2a02, 0x2a001b0e, 0x29090f04, 0x31046b07,   // mt.pt.es_222 tr.mt.un_550  lv.pl.sl_332 ceb.fi.az_432
  0x0b0a2a05, 0x12031104, 0x06040704, 0x31111ba7,   // mt.pt.es_333 ro.nl.hu_332  it.fi.de_332 tr.ro.az_532
  0x081104ee, 0x1b13045a, 0x186b0107, 0x113f1307,   // fi.ro.no_422 fi.et.tr_553  en.ceb.ga_432 et.af.ro_432
  // [c9d0]
  0x28205504, 0x023f1208, 0x1c111eec, 0x0e5528a0,   // rw.sq.sw_332 hu.af.da_443  ms.ro.id_644 sw.rw.is_322
  0x6b55250d, 0x2a0719a4, 0x285525ac, 0x12002520,   // eu.rw.ceb_554 gl.it.mt_433  eu.rw.sw_632 eu.hu.un_850
  0x100409a4, 0x0c1305ee, 0x13120a05, 0x0604080c,   // pl.fi.lt_433 fr.et.sv_422  pt.hu.et_333 no.fi.de_543
  0x21162802, 0x04000d04, 0x17165314, 0x12113f08,   // sw.hr.jw_222 cs.fi.un_320  ht.hr.sr_666 af.ro.hu_443
  // [c9e0]
  0x1b55280d, 0x07111008, 0x55282504, 0x0e131004,   // sw.rw.tr_554 be.ro.bg_443  eu.sw.rw_332 lt.et.is_332
  0x070417ec, 0x021a12a7, 0x251255ee, 0x3f002004,   // sr.ru.bg_644 hu.tl.da_532  rw.hu.eu_422 sq.af.un_320
  0x28000a05, 0x55531a04, 0x09001014, 0x20000702,   // pt.sw.un_330 tl.ht.rw_332  lt.pl.un_660 it.sq.un_220
  0x316411a4, 0x09136402, 0x2b006e12, 0x250164ee,   // ro.lg.az_433 lg.et.pl_222  blu.vi.un_640 lg.en.eu_422
  // [c9f0]
  0x0b1f2b0d, 0x1a0501a0, 0x645528a7, 0x213f1c12,   // vi.cy.es_554 en.fr.tl_322  sw.rw.lg_532 id.af.jw_654
  0x311253a0, 0x551a6b05, 0x06000e0b, 0x2b006e0c,   // ht.hu.az_322 ceb.tl.rw_333  is.de.un_520 blu.vi.un_530
  0x1a2107a9, 0x2d2108a0, 0x0c036bee, 0x02002802,   // it.jw.tl_544 no.jw.sk_322  ceb.nl.sv_422 sw.da.un_220
  0x281e1c11, 0x0b001f08, 0x030e3f04, 0x08001f0d,   // id.ms.sw_653 cy.es.un_430  af.is.nl_332 cy.no.un_540
  // [ca00]
  0x0c002909, 0x29006402, 0x11001212, 0x06083f05,   // sl.sv.un_440 lg.sl.un_220  hu.ro.un_640 af.no.de_333
  0x25122a02, 0x0a000523, 0x0c021fa6, 0x021706ee,   // mt.hu.eu_222 fr.pt.un_880  cy.da.sv_521 de.sr.da_422
  0x0e0818a0, 0x030f100b, 0x0a1b31ad, 0x20291a07,   // ga.no.is_322 lt.lv.nl_542  az.tr.pt_643 tl.sl.sq_432
  0x05001105, 0x1a046b0d, 0x2104280c, 0x06040ca4,   // ro.fr.un_330 ceb.fi.tl_554  sw.fi.jw_543 sv.fi.de_433
  // [ca10]
  0x0a081007, 0x64030109, 0x0c162907, 0x162555a9,   // be.uk.mk_432 en.nl.lg_444  sl.hr.sv_432 rw.eu.hr_544
  0x29556408, 0x0900160e, 0x29161b09, 0x28551b07,   // lg.rw.sl_443 hr.pl.un_550  tr.hr.sl_444 tr.rw.sw_432
  0x2a1931a0, 0x23100f07, 0x252931a9, 0x1e553107,   // az.gl.mt_322 lv.lt.ca_432  az.sl.eu_544 az.rw.ms_432
  0x092a2804, 0x550911a4, 0x162d0daf, 0x0b0e1907,   // sw.mt.pl_332 ro.pl.rw_433  cs.sk.hr_655 gl.is.es_432
  // [ca20]
  0x190a0502, 0x27281813, 0x051827a4, 0x292d17a4,   // fr.pt.gl_222 ga.sw.gd_665  gd.ga.fr_433 sr.sk.sl_433
  0x641a13ee, 0x18050bee, 0x1c002802, 0x25001009,   // et.tl.lg_422 es.fr.ga_422  sw.id.un_220 lt.eu.un_440
  0x27251607, 0x25196405, 0x09001704, 0x1a6b2514,   // hr.eu.gd_432 lg.gl.eu_333  sr.pl.un_320 eu.ceb.tl_666
  0x2a072ba0, 0x180601a7, 0x126b5507, 0x17645355,   // vi.it.mt_322 en.de.ga_532  rw.ceb.hu_432 ht.lg.sr_442
  // [ca30]
  0x0a110405, 0x0a060ca4, 0x3f020c12, 0x18282bee,   // ru.ro.mk_333 sv.de.pt_433  sv.da.af_654 vi.sw.ga_422
  0x64531aad, 0x29001722, 0x27181c0b, 0x11052b04,   // tl.ht.lg_643 sr.sl.un_870  id.ga.gd_542 vi.fr.ro_332
  0x09002007, 0x286b55ad, 0x251a6baf, 0x28552507,   // sq.pl.un_420 rw.ceb.sw_643  ceb.tl.eu_655 eu.rw.sw_432
  0x55121307, 0x0a000b19, 0x0c2521a0, 0x190801ee,   // et.hu.rw_432 es.pt.un_750  jw.eu.sv_322 en.no.gl_422
  // [ca40]
  0x09000c02, 0x3f64070d, 0x070c28a9, 0x0f002905,   // sv.pl.un_220 it.lg.af_554  sw.sv.it_544 sl.lv.un_330
  0x6b010cee, 0x081017ec, 0x12073fa4, 0x070508a4,   // sv.en.ceb_422 sr.be.uk_644  af.it.hu_433 no.fr.it_433
  0x0402280d, 0x086b01ad, 0x3f086402, 0x1e6b5305,   // sw.da.fi_554 en.ceb.no_643  lg.no.af_222 ht.ceb.ms_333
  0x20230111, 0x1e002920, 0x53001e11, 0x17190bad,   // en.ca.sq_653 sl.ms.un_850  ms.ht.un_630 es.gl.sr_643
  // [ca50]
  0x1b28550b, 0x12000609, 0x230625a7, 0x1220250c,   // rw.sw.tr_542 de.hu.un_440  eu.de.ca_532 eu.sq.hu_543
  0x6b0a0c05, 0x17250b0c, 0x06050c13, 0x0e2a08ad,   // sv.pt.ceb_333 es.eu.sr_543  sv.fr.de_665 no.mt.is_643
  0x06000f05, 0x080e2aaf, 0x31002304, 0x1f1a0aa6,   // lv.de.un_330 mt.is.no_655  ca.az.un_320 pt.tl.cy_521
  0x05190a09, 0x170a0412, 0x2b060a07, 0x64002304,   // pt.gl.fr_444 ru.mk.sr_654  pt.de.vi_432 ca.lg.un_320
  // [ca60]
  0x2a092d60, 0x0a1a2ba0, 0x2b0a2aee, 0x1c211e08,   // sk.pl.mt_664 vi.tl.pt_322  mt.pt.vi_422 ms.jw.id_443
  0x2b040a12, 0x10000918, 0x2d000914, 0x09002d21,   // pt.fi.vi_654 pl.lt.un_740  pl.sk.un_660 sk.pl.un_860
  0x0e6b1a12, 0x10001202, 0x1a0f1baf, 0x1b2b0a04,   // tl.ceb.is_654 hu.lt.un_220  tr.lv.tl_655 pt.vi.tr_332
  0x11012ba6, 0x18011a05, 0x272a28ec, 0x01230507,   // vi.en.ro_521 tl.en.ga_333  sw.mt.gd_644 fr.ca.en_432
  // [ca70]
  0x6e092d12, 0x31212a07, 0x13080e55, 0x0c0e1c0c,   // sk.pl.blu_654 mt.jw.az_432  is.no.et_442 id.is.sv_543
  0x19211ca4, 0x2b000a0c, 0x270f18af, 0x042b0a0c,   // id.jw.gl_433 pt.vi.un_530  ga.lv.gd_655 pt.vi.fi_543
  0x11000e2b, 0x042b0aad, 0x2107250c, 0x091f10af,   // is.ro.un_980 pt.vi.fi_643  eu.it.jw_543 lt.cy.pl_655
  0x0500532b, 0x182b0a0c, 0x3f040a08, 0x0b1b25ad,   // ht.fr.un_980 pt.vi.ga_543  pt.fi.af_443 eu.tr.es_643
  // [ca80]
  0x29092dad, 0x31081ba0, 0x11136b04, 0x0c530705,   // sk.pl.sl_643 tr.no.az_322  ceb.et.ro_332 it.ht.sv_333
  0x0a001c0d, 0x1a111e07, 0x27255507, 0x292a20a0,   // id.pt.un_540 ms.ro.tl_432  rw.eu.gd_432 sq.mt.sl_322
  0x13110cad, 0x0d062a02, 0x061353a0, 0x1a112a12,   // sv.ro.et_643 mt.de.cs_222  ht.et.de_322 mt.ro.tl_654
  0x3f0b04a4, 0x17161111, 0x07040fa0, 0x1b5355ad,   // fi.es.af_433 ro.hr.sr_653  lv.fi.it_322 rw.ht.tr_643
  // [ca90]
  0x2a00210c, 0x1b020fad, 0x07001209, 0x20001013,   // jw.mt.un_530 lv.da.tr_643  hu.it.un_440 lt.sq.un_650
  0x20001019, 0x12050107, 0x64000e08, 0x0d0910a4,   // lt.sq.un_750 en.fr.hu_432  is.lg.un_430 lt.pl.cs_433
  0x0a000820, 0x13110f08, 0x03086b02, 0x19001112,   // uk.mk.un_850 lv.ro.et_443  ceb.no.nl_222 ro.gl.un_640
  0x0802290c, 0x20291008, 0x29080cad, 0x0e080607,   // sl.da.no_543 lt.sl.sq_443  sv.no.sl_643 de.no.is_432
  // [caa0]
  0x07230b0c, 0x08051a07, 0x550b25a4, 0x0b0109ee,   // es.ca.it_543 tl.fr.no_432  eu.es.rw_433 pl.en.es_422
  0x100b2002, 0x2d0f06a9, 0x07050aa9, 0x0b162305,   // sq.es.lt_222 de.lv.sk_544  pt.fr.it_544 ca.hr.es_333
  0x20100d0b, 0x0f000502, 0x2000101a, 0x102d0d0c,   // cs.lt.sq_542 fr.lv.un_220  lt.sq.un_760 cs.sk.lt_543
  0x55201008, 0x03000c09, 0x20002a0c, 0x100c0212,   // lt.sq.rw_443 sv.nl.un_440  mt.sq.un_530 da.sv.lt_654
  // [cab0]
  0x180711af, 0x2d111b07, 0x0e07050e, 0x2a1c2107,   // ro.it.ga_655 tr.ro.sk_432  fr.it.is_555 jw.id.mt_432
  0x050e1aac, 0x2d1121a0, 0x02230ca7, 0x083f13a0,   // tl.is.fr_632 jw.ro.sk_322  sv.ca.da_532 et.af.no_322
  0x0e1218ad, 0x171b20a4, 0x120d1ba4, 0x04110a55,   // ga.hu.is_643 sq.tr.sr_433  tr.cs.hu_433 mk.ro.ru_442
  0x31121ba4, 0x1e1a120c, 0x2d0e0da9, 0x31061b07,   // tr.hu.az_433 hu.tl.ms_543  cs.is.sk_544 tr.de.az_432
  // [cac0]
  0x190d2d11, 0x121b3107, 0x0c231904, 0x3f170604,   // sk.cs.gl_653 az.tr.hu_432  gl.ca.sv_332 de.sr.af_332
  0x101711a0, 0x6b04130c, 0x25642155, 0x0e00090e,   // ro.sr.be_322 et.fi.ceb_543  jw.lg.eu_442 pl.is.un_550
  0x04122512, 0x08002807, 0x1b005319, 0x120d04a4,   // eu.hu.fi_654 sw.no.un_420  ht.tr.un_750 fi.cs.hu_433
  0x3f6412a0, 0x0d0e2da6, 0x0c003f09, 0x2a0704a0,   // hu.lg.af_322 sk.is.cs_521  af.sv.un_440 fi.it.mt_322
  // [cad0]
  0x111b31ad, 0x21132802, 0x04062aee, 0x18172a05,   // az.tr.ro_643 sw.et.jw_222  mt.de.fi_422 mt.sr.ga_333
  0x252a0407, 0x100a04a0, 0x28215508, 0x1c201004,   // fi.mt.eu_432 ru.mk.be_322  rw.jw.sw_443 lt.sq.id_332
  0x040812a4, 0x0e070da9, 0x28536407, 0x051227a4,   // hu.no.fi_433 cs.it.is_544  lg.ht.sw_432 gd.hu.fr_433
  0x2a291307, 0x5500210b, 0x64006b1a, 0x080d06ee,   // et.sl.mt_432 jw.rw.un_520  ceb.lg.un_760 de.cs.no_422
  // [cae0]
  0x06271811, 0x10170414, 0x11553104, 0x0300180d,   // ga.gd.de_653 ru.sr.be_666  az.rw.ro_332 ga.nl.un_540
  0x0c2a1008, 0x062d2907, 0x0e076ba0, 0x18190ba0,   // lt.mt.sv_443 sl.sk.de_432  ceb.it.is_322 es.gl.ga_322
  0x0e0a190b, 0x06311ba9, 0x02130502, 0x172116a0,   // gl.pt.is_542 tr.az.de_544  fr.et.da_222 hr.jw.sr_322
  0x211c2bad, 0x0b000e08, 0x1f182760, 0x64251102,   // vi.id.jw_643 is.es.un_430  gd.ga.cy_664 ro.eu.lg_222
  // [caf0]
  0x045512a9, 0x2753180c, 0x110a2504, 0x1821270e,   // hu.rw.fi_544 ga.ht.gd_543  eu.pt.ro_332 gd.jw.ga_555
  0x10071704, 0x18552a02, 0x051301a9, 0x532a18a4,   // sr.bg.be_332 mt.rw.ga_222  en.et.fr_544 ga.mt.ht_433
  0x04530108, 0x1704050c, 0x0e102108, 0x27051f07,   // en.ht.fi_443 fr.fi.sr_543  jw.lt.is_443 cy.fr.gd_432
  0x0c021007, 0x2a2b010c, 0x052301a4, 0x131729ee,   // lt.da.sv_432 en.vi.mt_543  en.ca.fr_433 sl.sr.et_422
  // [cb00]
  0x020601a7, 0x285321a0, 0x2d0d3102, 0x096b010c,   // en.de.da_532 jw.ht.sw_322  az.cs.sk_222 en.ceb.pl_543
  0x12011b0c, 0x643f2308, 0x0302130c, 0x64130409,   // tr.en.hu_543 ca.af.lg_443  et.da.nl_543 fi.et.lg_444
  0x0f001f04, 0x10552aad, 0x29002105, 0x04181055,   // cy.lv.un_320 mt.rw.lt_643  jw.sl.un_330 lt.ga.fi_442
  0x1004185a, 0x07170aa6, 0x2a532bee, 0x25180512,   // ga.fi.lt_553 mk.sr.bg_521  vi.ht.mt_422 fr.ga.eu_654
  // [cb10]
  0x092902a4, 0x1b6b0807, 0x206b06a0, 0x101825ee,   // da.sl.pl_433 no.ceb.tr_432  de.ceb.sq_322 eu.ga.lt_422
  0x09190b60, 0x09162d04, 0x25001f08, 0x0128110b,   // es.gl.pl_664 sk.hr.pl_332  cy.eu.un_430 ro.sw.en_542
  0x200d03a4, 0x18000904, 0x06002520, 0x1c1e2ba7,   // nl.cs.sq_433 pl.ga.un_320  eu.de.un_850 vi.ms.id_532
  0x2a6b1aee, 0x022a0704, 0x1a3f09a4, 0x013f1314,   // tl.ceb.mt_422 it.mt.da_332  pl.af.tl_433 et.af.en_666
  // [cb20]
  0x0c133f08, 0x1004180c, 0x3100180d, 0x0431180c,   // af.et.sv_443 ga.fi.lt_543  ga.az.un_540 ga.az.fi_543
  0x133f04a7, 0x25000202, 0x0f1009ee, 0x181004ee,   // fi.af.et_532 da.eu.un_220  pl.lt.lv_422 fi.lt.ga_422
  0x131b040c, 0x092d0f12, 0x2003020c, 0x2a0911a4,   // fi.tr.et_543 lv.sk.pl_654  da.nl.sq_543 ro.pl.mt_433
  0x010506ec, 0x181107a0, 0x023f1305, 0x2a0711a6,   // de.fr.en_644 it.ro.ga_322  et.af.da_333 ro.it.mt_521
  // [cb30]
  0x081704ec, 0x17080aa7, 0x05060109, 0x0a230b55,   // ru.sr.uk_644 mk.uk.sr_532  en.de.fr_444 es.ca.pt_442
  0x02030c04, 0x17080fa4, 0x0c0629a4, 0x08030ea7,   // sv.nl.da_332 lv.no.sr_433  sl.de.sv_433 is.nl.no_532
  0x03131002, 0x063f0e0c, 0x20001f07, 0x6b060ca0,   // lt.et.nl_222 is.af.de_543  cy.sq.un_420 sv.de.ceb_322
  0x2b041a07, 0x13285507, 0x1c11550c, 0x033f2008,   // tl.fi.vi_432 rw.sw.et_432  rw.ro.id_543 sq.af.nl_443
  // [cb40]
  0x115520af, 0x64251ea9, 0x18122dad, 0x0c000f09,   // sq.rw.ro_655 ms.eu.lg_544  sk.hu.ga_643 lv.sv.un_440
  0x0313060d, 0x31081b08, 0x111b0c05, 0x1b645511,   // de.et.nl_554 tr.no.az_443  sv.tr.ro_333 rw.lg.tr_653
  0x31552805, 0x0e1208ad, 0x042b10ee, 0x6b04135a,   // sw.rw.az_333 no.hu.is_643  lt.vi.fi_422 et.fi.ceb_553
  0x1b2021a4, 0x0c645508, 0x1c2810a0, 0x12230b07,   // jw.sq.tr_433 rw.lg.sv_443  lt.sw.id_322 es.ca.hu_432
  // [cb50]
  0x060812a7, 0x2d2a0d02, 0x200d2aa0, 0x2a07640c,   // hu.no.de_532 cs.mt.sk_222  mt.cs.sq_322 lg.it.mt_543
  0x550307a4, 0x0800550e, 0x04102108, 0x03000913,   // it.nl.rw_433 rw.no.un_550  jw.lt.fi_443 pl.nl.un_650
  0x55000613, 0x0107200c, 0x280410ac, 0x07200107,   // de.rw.un_650 sq.it.en_543  lt.fi.sw_632 en.sq.it_432
  0x532055af, 0x1a2108a0, 0x212b1c0c, 0x2a12060c,   // rw.sq.ht_655 no.jw.tl_322  id.vi.jw_543 de.hu.mt_543
  // [cb60]
  0x0d00200d, 0x2a00070e, 0x31130408, 0x1304030c,   // sq.cs.un_540 it.mt.un_550  fi.et.az_443 nl.fi.et_543
  0x552a0709, 0x0b180555, 0x2a190708, 0x130464a4,   // it.mt.rw_444 fr.ga.es_442  it.gl.mt_443 lg.fi.et_433
  0x2b002114, 0x171620a6, 0x0d202812, 0x3f0403ee,   // jw.vi.un_660 sq.hr.sr_521  sw.sq.cs_654 nl.fi.af_422
  0x64130405, 0x3f002b0c, 0x252007ad, 0x116412ad,   // fi.et.lg_333 vi.af.un_530  it.sq.eu_643 hu.lg.ro_643
  // [cb70]
  0x0c202ba4, 0x07002021, 0x55002022, 0x042164a7,   // vi.sq.sv_433 sq.it.un_860  sq.rw.un_870 lg.jw.fi_532
  0x13046411, 0x07002b08, 0x2a001e09, 0x041364ee,   // lg.fi.et_653 vi.it.un_430  ms.mt.un_440 lg.et.fi_422
  0x20210b04, 0x13551a11, 0x0a5511a4, 0x2a072105,   // es.jw.sq_332 tl.rw.et_653  ro.rw.pt_433 jw.it.mt_333
  0x642111a4, 0x0f2b01ee, 0x062725ec, 0x1f0112a0,   // ro.jw.lg_433 en.vi.lv_422  eu.gd.de_644 hu.en.cy_322
  // [cb80]
  0x12062504, 0x0f31250c, 0x3f0304ad, 0x071364a6,   // eu.de.hu_332 eu.az.lv_543  fi.nl.af_643 lg.et.it_521
  0x0a1f0655, 0x06016ba0, 0x1e642155, 0x0a640407,   // de.cy.pt_442 ceb.en.de_322  jw.lg.ms_442 fi.lg.pt_432
  0x0d6b01ac, 0x0a060c0c, 0x11080a12, 0x0c006e08,   // en.ceb.cs_632 sv.de.pt_543  mk.uk.ro_654 blu.sv.un_430
  0x06020107, 0x022a0807, 0x29023f04, 0x3f062504,   // en.da.de_432 no.mt.da_432  af.da.sl_332 eu.de.af_332
  // [cb90]
  0x181227a0, 0x041213a0, 0x061a03ee, 0x1e1a10a9,   // gd.hu.ga_322 et.hu.fi_322  nl.tl.de_422 lt.tl.ms_544
  0x180c0609, 0x051f2307, 0x05003f12, 0x09000207,   // de.sv.ga_444 ca.cy.fr_432  af.fr.un_640 da.pl.un_420
  0x0d1c1304, 0x05122aec, 0x20132aa4, 0x13022305,   // bh.mr.ne_332 mt.hu.fr_644  mt.et.sq_433 ca.da.et_333
  0x10011c04, 0x041629a7, 0x25132aa4, 0x106b0fec,   // id.en.lt_332 sl.hr.fi_532  mt.et.eu_433 lv.ceb.lt_644
  // [cba0]
  0x310a1b55, 0x200d2a0c, 0x200825a0, 0x165528ee,   // tr.pt.az_442 mt.cs.sq_543  eu.no.sq_322 sw.rw.hr_422
  0x080f2d07, 0x17041008, 0x6b1a0ca9, 0x64051314,   // sk.lv.no_432 be.ru.sr_443  sv.tl.ceb_544 et.fr.lg_666
  0x5500170e, 0x1728125a, 0x0f0a16a7, 0x0f002a08,   // sr.rw.un_550 hu.sw.sr_553  hr.pt.lv_532 mt.lv.un_430
  0x21132aa4, 0x201355af, 0x2a28200c, 0x53171608,   // mt.et.jw_433 rw.et.sq_655  sq.sw.mt_543 hr.sr.ht_443
  // [cbb0]
  0x251021ee, 0x1a082502, 0x6b0512a4, 0x0b0a11a0,   // jw.lt.eu_422 eu.no.tl_222  hu.fr.ceb_433 ro.pt.es_322
  0x165517af, 0x28000e1a, 0x170316ec, 0x20161e11,   // sr.rw.hr_655 is.sw.un_760  hr.nl.sr_644 ms.hr.sq_653
  0x29161ba4, 0x0c080e02, 0x2d0d2a0c, 0x0f041312,   // tr.hr.sl_433 is.no.sv_222  mt.cs.sk_543 et.fi.lv_654
  0x0e250807, 0x050107a9, 0x552d0d55, 0x291112a0,   // no.eu.is_432 it.en.fr_544  cs.sk.rw_442 hu.ro.sl_322
  // [cbc0]
  0x17001629, 0x016b19a0, 0x53001620, 0x0500210e,   // hr.sr.un_960 gl.ceb.en_322  hr.ht.un_850 jw.fr.un_550
  0x29211607, 0x0d001b07, 0x1200310c, 0x01091b07,   // hr.jw.sl_432 tr.cs.un_420  az.hu.un_530 tr.pl.en_432
  0x18006e0b, 0x091b120c, 0x233f0ea7, 0x3f080c04,   // blu.ga.un_520 hu.tr.pl_543  is.af.ca_532 sv.no.af_332
  0x25001604, 0x212916a0, 0x070a17a6, 0x1b0929a4,   // hr.eu.un_320 hr.sl.jw_322  sr.mk.bg_521 sl.pl.tr_433
  // [cbd0]
  0x1a002105, 0x1a536ba4, 0x12090507, 0x040f21a0,   // jw.tl.un_330 ceb.ht.tl_433  fr.pl.hu_432 jw.lv.fi_322
  0x29002319, 0x0d2909af, 0x1004110e, 0x0a1105a4,   // ca.sl.un_750 pl.sl.cs_655  ro.ru.be_555 fr.ro.pt_433
  0x1103250b, 0x6b212307, 0x1a110e02, 0x2a280707,   // eu.nl.ro_542 ca.jw.ceb_432  is.ro.tl_222 it.sw.mt_432
  0x201825a4, 0x131b04a9, 0x112506a0, 0x17101608,   // eu.ga.sq_433 fi.tr.et_544  de.eu.ro_322 hr.lt.sr_443
  // [cbe0]
  0x642528ee, 0x6b001805, 0x1b00040d, 0x0f101ea0,   // sw.eu.lg_422 ga.ceb.un_330  fi.tr.un_540 ms.lt.lv_322
  0x010464a0, 0x13121155, 0x04130ca0, 0x11001713,   // lg.fi.en_322 ro.hu.et_442  sv.et.fi_322 sr.ro.un_650
  0x1e532155, 0x281823a0, 0x28645308, 0x1c1e2107,   // jw.ht.ms_442 ca.ga.sw_322  ht.lg.sw_443 jw.ms.id_432
  0x2a125507, 0x1b000419, 0x17161c0c, 0x100a0605,   // rw.hu.mt_432 fi.tr.un_750  id.hr.sr_543 de.pt.lt_333
  // [cbf0]
  0x21101c02, 0x532564a4, 0x0d033fad, 0x55001112,   // id.lt.jw_222 lg.eu.ht_433  af.nl.cs_643 ro.rw.un_640
  0x20130755, 0x01190b05, 0x530b10ad, 0x53000202,   // it.et.sq_442 es.gl.en_333  lt.es.ht_643 da.ht.un_220
  0x21000b07, 0x3f080eee, 0x31000e07, 0x013f0e07,   // es.jw.un_420 is.no.af_422  is.az.un_420 is.af.en_432
  0x115507a0, 0x111c16a0, 0x1e111c0c, 0x55003f08,   // it.rw.ro_322 hr.id.ro_322  id.ro.ms_543 af.rw.un_430

  // [cc00]
  0x18000e13, 0x1b002307, 0x316b0ead, 0x0f1716a6,   // is.ga.un_650 ca.tr.un_420  is.ceb.az_643 hr.sr.lv_521
  0x2d002512, 0x06030807, 0x120e18ad, 0x25213fee,   // eu.sk.un_640 no.nl.de_432  ga.is.hu_643 af.jw.eu_422
  0x13001802, 0x10132509, 0x083f25ad, 0x25020ca0,   // ga.et.un_220 eu.et.lt_444  eu.af.no_643 sv.da.eu_322
  0x170410a6, 0x02250512, 0x25032812, 0x2d3f0c07,   // be.ru.sr_521 fr.eu.da_654  sw.nl.eu_654 sv.af.sk_432
  // [cc10]
  0x25003f0e, 0x0a082804, 0x29160c07, 0x0e00180b,   // af.eu.un_550 sw.no.pt_332  sv.hr.sl_432 ga.is.un_520
  0x0f001202, 0x12006b0c, 0x033f1907, 0x012b0aa6,   // hu.lv.un_220 ceb.hu.un_530  gl.af.nl_432 pt.vi.en_521
  0x1a060907, 0x251c1e12, 0x21231f0c, 0x01641ba4,   // pl.de.tl_432 ms.id.eu_654  cy.ca.jw_543 tr.lg.en_433
  0x6b1a2114, 0x53272107, 0x1b3f08ac, 0x21201f0c,   // jw.tl.ceb_666 jw.gd.ht_432  no.af.tr_632 cy.sq.jw_543
  // [cc20]
  0x1a281ea0, 0x0d2b2805, 0x12312808, 0x046428ad,   // ms.sw.tl_322 sw.vi.cs_333  sw.az.hu_443 sw.lg.fi_643
  0x251a6b0c, 0x0c3f21a7, 0x3f062511, 0x1a1e1c0e,   // ceb.tl.eu_543 jw.af.sv_532  eu.de.af_653 id.ms.tl_555
  0x311e1c13, 0x292855ee, 0x032508a9, 0x1b1655a0,   // id.ms.az_665 rw.sw.sl_422  no.eu.nl_544 rw.hr.tr_322
  0x1e2a1aa4, 0x55000807, 0x1b000908, 0x1c281e11,   // tl.mt.ms_433 no.rw.un_420  pl.tr.un_430 ms.sw.id_653
  // [cc30]
  0x180507a7, 0x291b0aa7, 0x0a00121a, 0x1b2855a7,   // it.fr.ga_532 pt.tr.sl_532  hu.pt.un_760 rw.sw.tr_532
  0x29092808, 0x0325090c, 0x31001705, 0x1b205307,   // sw.pl.sl_443 pl.eu.nl_543  sr.az.un_330 ht.sq.tr_432
  0x1b041309, 0x211013a0, 0x1c001e11, 0x015553ee,   // et.fi.tr_444 et.lt.jw_322  ms.id.un_630 ht.rw.en_422
  0x1108550c, 0x53556409, 0x10172d55, 0x13212a07,   // rw.no.ro_543 lg.rw.ht_444  sk.sr.lt_442 mt.jw.et_432
  // [cc40]
  0x01645507, 0x21100fa4, 0x1c552102, 0x1e131c0c,   // rw.lg.en_432 lv.lt.jw_433  jw.rw.id_222 id.et.ms_543
  0x020e080c, 0x6b00551a, 0x1b1112a4, 0x280c0855,   // no.is.da_543 rw.ceb.un_760  hu.ro.tr_433 no.sv.sw_442
  0x53210511, 0x1c215507, 0x0e1b08a0, 0x08133fee,   // fr.jw.ht_653 rw.jw.id_432  no.tr.is_322 af.et.no_422
  0x532a1a05, 0x16292007, 0x1f23060c, 0x3f0c0808,   // tl.mt.ht_333 sq.sl.hr_432  de.ca.cy_543 no.sv.af_443
  // [cc50]
  0x030e080c, 0x061f0ea0, 0x1a0c0ea4, 0x0b2a060d,   // no.is.nl_543 is.cy.de_322  is.sv.tl_433 de.mt.es_554
  0x03211ca4, 0x282010a4, 0x28000419, 0x211a13a7,   // id.jw.nl_433 lt.sq.sw_433  fi.sw.un_750 et.tl.jw_532
  0x0e072a55, 0x05061005, 0x080601ee, 0x02122107,   // mt.it.is_442 lt.de.fr_333  en.de.no_422 jw.hu.da_432
  0x0c000e11, 0x286455ee, 0x13556b04, 0x013f1fa4,   // is.sv.un_630 rw.lg.sw_422  ceb.rw.et_332 cy.af.en_433
  // [cc60]
  0x28071a0c, 0x1c115511, 0x10202104, 0x0200180d,   // tl.it.sw_543 rw.ro.id_653  jw.sq.lt_332 ga.da.un_540
  0x0b11530c, 0x0718645a, 0x0f002012, 0x1f2018ee,   // ht.ro.es_543 lg.ga.it_553  sq.lv.un_640 ga.sq.cy_422
  0x110755a9, 0x1800061b, 0x03020cee, 0x01215508,   // rw.it.ro_544 de.ga.un_770  sv.da.nl_422 rw.jw.en_443
  0x0713280c, 0x2a200705, 0x2a021f07, 0x02060c07,   // sw.et.it_543 it.sq.mt_333  cy.da.mt_432 sv.de.da_432
  // [cc70]
  0x10006e04, 0x0f2521a4, 0x01192ba4, 0x11166404,   // blu.lt.un_320 jw.eu.lv_433  vi.gl.en_433 lg.hr.ro_332
  0x186455ad, 0x551a2512, 0x2d092007, 0x25270b08,   // rw.lg.ga_643 eu.tl.rw_654  sq.pl.sk_432 es.gd.eu_443
  0x180920a0, 0x130d1c60, 0x23111cee, 0x55071155,   // sq.pl.ga_322 mr.ne.bh_664  id.ro.ca_422 ro.it.rw_442
  0x230a05a6, 0x19182712, 0x21002904, 0x646b1b13,   // fr.pt.ca_521 gd.ga.gl_654  sl.jw.un_320 tr.ceb.lg_665
  // [cc80]
  0x0e286455, 0x55002521, 0x12645307, 0x28210708,   // lg.sw.is_442 eu.rw.un_860  ht.lg.hu_432 it.jw.sw_443
  0x1c2706ad, 0x191f180b, 0x01645508, 0x0a070f12,   // de.gd.id_643 ga.cy.gl_542  rw.lg.en_443 lv.it.pt_654
  0x20530107, 0x0c06080c, 0x0f182713, 0x07550509,   // en.ht.sq_432 no.de.sv_543  gd.ga.lv_665 fr.rw.it_444
  0x0b556407, 0x16112707, 0x11550107, 0x06011ca0,   // lg.rw.es_432 gd.ro.hr_432  en.rw.ro_432 id.en.de_322
  // [cc90]
  0x270b08a0, 0x18000e11, 0x2d0d170c, 0x21251313,   // no.es.gd_322 is.ga.un_630  sr.cs.sk_543 et.eu.jw_665
  0x11071c0b, 0x0e00040d, 0x1b6b01ee, 0x182d0d55,   // id.it.ro_542 fi.is.un_540  en.ceb.tr_422 cs.sk.ga_442
  0x06020ca4, 0x011e0aa0, 0x1b001212, 0x0a0e18ec,   // sv.da.de_433 pt.ms.en_322  hu.tr.un_640 ga.is.pt_644
  0x190b0d02, 0x20296e02, 0x02000904, 0x20130707,   // cs.es.gl_222 blu.sl.sq_222  pl.da.un_320 it.et.sq_432
  // [cca0]
  0x060225a0, 0x6400060b, 0x080f02ee, 0x21286402,   // eu.da.de_322 de.lg.un_520  da.lv.no_422 lg.sw.jw_222
  0x292d1704, 0x53033f12, 0x1e0307ee, 0x6e002309,   // sr.sk.sl_332 af.nl.ht_654  it.nl.ms_422 ca.blu.un_440
  0x230410a0, 0x210b2804, 0x28180705, 0x100f1308,   // lt.fi.ca_322 sw.es.jw_332  it.ga.sw_333 et.lv.lt_443
  0x1c1e1107, 0x07230b0e, 0x0f5310a4, 0x13041fa9,   // ro.ms.id_432 es.ca.it_555  lt.ht.lv_433 cy.fi.et_544
  // [ccb0]
  0x01531904, 0x2d2913ee, 0x06280dee, 0x29132dee,   // gl.ht.en_332 et.sl.sk_422  cs.sw.de_422 sk.et.sl_422
  0x1b311e07, 0x1004070c, 0x08200f5a, 0x21201c07,   // ms.az.tr_432 bg.ru.be_543  lv.sq.no_553 id.sq.jw_432
  0x160e2a05, 0x1f2931ee, 0x0500281a, 0x03002d12,   // mt.is.hr_333 az.sl.cy_422  sw.fr.un_760 sk.nl.un_640
  0x2b1f0e08, 0x12060405, 0x05020812, 0x130c25a0,   // is.cy.vi_443 fi.de.hu_333  no.da.fr_654 eu.sv.et_322
  // [ccc0]
  0x120604ad, 0x0700050c, 0x6b0301a9, 0x0f231105,   // fi.de.hu_643 fr.it.un_530  en.nl.ceb_544 ro.ca.lv_333
  0x050107a0, 0x126b21a0, 0x311b25ec, 0x21081ea0,   // it.en.fr_322 jw.ceb.hu_322  eu.tr.az_644 ms.no.jw_322
  0x311b1ca0, 0x122855ac, 0x0400311b, 0x1f002122,   // id.tr.az_322 rw.sw.hu_632  az.fi.un_770 jw.cy.un_870
  0x2d000813, 0x11271804, 0x53000d08, 0x311b25a9,   // no.sk.un_650 ga.gd.ro_332  cs.ht.un_430 eu.tr.az_544
  // [ccd0]
  0x131b2dee, 0x06270111, 0x291c1ead, 0x12000605,   // sk.tr.et_422 en.gd.de_653  ms.id.sl_643 de.hu.un_330
  0x11170aaf, 0x211c2dee, 0x2100021b, 0x16000f11,   // mk.sr.ro_655 sk.id.jw_422  da.jw.un_770 lv.hr.un_630
  0x10080a0b, 0x272b1802, 0x11190a14, 0x06271855,   // mk.uk.be_542 ga.vi.gd_222  pt.gl.ro_666 ga.gd.de_442
  0x211620ad, 0x28211c05, 0x052d1207, 0x0605010c,   // sq.hr.jw_643 id.jw.sw_333  hu.sk.fr_432 en.fr.de_543
  // [cce0]
  0x18002907, 0x08023107, 0x3f0f050c, 0x190b0dee,   // sl.ga.un_420 az.da.no_432  fr.lv.af_543 cs.es.gl_422
  0x182101a7, 0x1b00550c, 0x10071760, 0x3f271811,   // en.jw.ga_532 rw.tr.un_530  sr.bg.be_664 ga.gd.af_653
  0x25551e0d, 0x0c003f13, 0x19005308, 0x552a1b08,   // ms.rw.eu_554 af.sv.un_650  ht.gl.un_430 tr.mt.rw_443
  0x04002a1a, 0x072a0fa0, 0x18271f55, 0x16000309,   // mt.fi.un_760 lv.mt.it_322  cy.gd.ga_442 nl.hr.un_440
  // [ccf0]
  0x022916a7, 0x033f0fa4, 0x530213a0, 0x3f1006a0,   // hr.sl.da_532 lv.af.nl_433  et.da.ht_322 de.lt.af_322
  0x1a3f0804, 0x1b0b02a0, 0x20001911, 0x07002118,   // no.af.tl_332 da.es.tr_322  gl.sq.un_630 jw.it.un_740
  0x01001604, 0x08286e07, 0x6b00011a, 0x04060e05,   // hr.en.un_320 blu.sw.no_432  en.ceb.un_760 is.de.fi_333
  0x270c060c, 0x070502a0, 0x2a642507, 0x040e0655,   // de.sv.gd_543 da.fr.it_322  eu.lg.mt_432 de.is.fi_442
  // [cd00]
  0x0e0f10ad, 0x1318270b, 0x03083f05, 0x0e100fa0,   // lt.lv.is_643 gd.ga.et_542  af.no.nl_333 lv.lt.is_322
  0x3f051fee, 0x1e08550c, 0x10066b07, 0x11052aa7,   // cy.fr.af_422 rw.no.ms_543  ceb.de.lt_432 mt.fr.ro_532
  0x03130ca0, 0x030806ee, 0x0d1c070c, 0x02230f04,   // sv.et.nl_322 de.no.nl_422  it.id.cs_543 lv.ca.da_332
  0x2a1e1ca4, 0x06040ea0, 0x11002909, 0x0f086ea4,   // id.ms.mt_433 is.fi.de_322  sl.ro.un_440 blu.no.lv_433
  // [cd10]
  0x033f2104, 0x130e065a, 0x1300201b, 0x040c20a7,   // jw.af.nl_332 de.is.et_553  sq.et.un_770 sq.sv.fi_532
  0x130e03a0, 0x55002007, 0x532b05a7, 0x1900200d,   // nl.is.et_322 sq.rw.un_420  fr.vi.ht_532 sq.gl.un_540
  0x06100707, 0x070625ad, 0x0b00052b, 0x28102508,   // it.lt.de_432 eu.de.it_643  fr.es.un_980 eu.lt.sw_443
  0x0f0b2dad, 0x0c202807, 0x6b0501ec, 0x531a1ca9,   // sk.es.lv_643 sw.sq.sv_432  en.fr.ceb_644 id.tl.ht_544
  // [cd20]
  0x033f2b08, 0x100f01a4, 0x1a6b1ca0, 0x050b0805,   // vi.af.nl_443 en.lv.lt_433  id.ceb.tl_322 no.es.fr_333
  0x0b1e1c55, 0x1c0f1e0c, 0x29001a0d, 0x25000321,   // id.ms.es_442 ms.lv.id_543  tl.sl.un_540 nl.eu.un_860
  0x3f050308, 0x1b1631a9, 0x110b01a4, 0x1a6b0807,   // nl.fr.af_443 az.hr.tr_544  en.es.ro_433 no.ceb.tl_432
  0x2d00060d, 0x6b251aa9, 0x1f1827af, 0x250709a4,   // de.sk.un_540 tl.eu.ceb_544  gd.ga.cy_655 pl.it.eu_433
  // [cd30]
  0x230413ad, 0x0b050fec, 0x112521a4, 0x2b100f12,   // et.fi.ca_643 lv.fr.es_644  jw.eu.ro_433 lv.lt.vi_654
  0x2b033fa4, 0x020501a4, 0x10041308, 0x0809100c,   // af.nl.vi_433 en.fr.da_433  et.fi.lt_443 lt.pl.no_543
  0x0e100fa4, 0x1e1204a9, 0x1e1c0405, 0x27181f05,   // lv.lt.is_433 fi.hu.ms_544  fi.id.ms_333 cy.ga.gd_333
  0x080e18a4, 0x182a010c, 0x04100e04, 0x27002907,   // ga.is.no_433 en.mt.ga_543  is.lt.fi_332 sl.gd.un_420
  // [cd40]
  0x211c2004, 0x1e1c5309, 0x042a550c, 0x0b000e0c,   // sq.id.jw_332 ht.id.ms_444  rw.mt.fi_543 is.es.un_530
  0x16002505, 0x2a170ca4, 0x1b0b04ee, 0x550706a7,   // eu.hr.un_330 sv.sr.mt_433  fi.es.tr_422 de.it.rw_532
  0x0e2508a0, 0x16072755, 0x07190b05, 0x285519ad,   // no.eu.is_322 gd.it.hr_442  es.gl.it_333 gl.rw.sw_643
  0x180a0704, 0x5525280e, 0x1b190b05, 0x255528ad,   // it.pt.ga_332 sw.eu.rw_555  es.gl.tr_333 sw.rw.eu_643
  // [cd50]
  0x31211b04, 0x2500190b, 0x060907ee, 0x18281604,   // tr.jw.az_332 gl.eu.un_520  it.pl.de_422 hr.sw.ga_332
  0x091c2112, 0x08020fa4, 0x07190b08, 0x3f0a0555,   // jw.id.pl_654 lv.da.no_433  es.gl.it_443 fr.pt.af_442
  0x072805a9, 0x190b29ee, 0x28001821, 0x55002a13,   // fr.sw.it_544 sl.es.gl_422  ga.sw.un_860 mt.rw.un_650
  0x53212312, 0x130f20ee, 0x203f09ad, 0x3f126ba9,   // ca.jw.ht_654 sq.lv.et_422  pl.af.sq_643 ceb.hu.af_544
  // [cd60]
  0x2d002a02, 0x29020c55, 0x25556402, 0x0a000414,   // mt.sk.un_220 sv.da.sl_442  lg.rw.eu_222 ru.mk.un_660
  0x230b53af, 0x28000609, 0x1f0420ad, 0x23215304,   // ht.es.ca_655 de.sw.un_440  sq.fi.cy_643 ht.jw.ca_332
  0x165564a4, 0x07210804, 0x09530c02, 0x550b0a05,   // lg.rw.hr_433 no.jw.it_332  sv.ht.pl_222 pt.es.rw_333
  0x201b0c05, 0x282508ee, 0x0e000c20, 0x12182d07,   // sv.tr.sq_333 no.eu.sw_422  sv.is.un_850 sk.ga.hu_432
  // [cd70]
  0x041655a7, 0x082a5308, 0x252113ee, 0x05532108,   // rw.hr.fi_532 ht.mt.no_443  et.jw.eu_422 jw.ht.fr_443
  0x641b250c, 0x1021200c, 0x163f29a0, 0x171620a9,   // eu.tr.lg_543 sq.jw.lt_543  sl.af.hr_322 sq.hr.sr_544
  0x09130dad, 0x2d0d0402, 0x0d122d11, 0x04060e13,   // ne.bh.hi_643 fi.cs.sk_222  sk.hu.cs_653 is.de.fi_665
  0x12002d21, 0x0f2916a7, 0x18122db6, 0x646b0b0b,   // sk.hu.un_860 hr.sl.lv_532  sk.hu.ga_766 es.ceb.lg_542
  // [cd80]
  0x0d002111, 0x0b040602, 0x1b0e0655, 0x07285512,   // jw.cs.un_630 de.fi.es_222  de.is.tr_442 rw.sw.it_654
  0x07280608, 0x062a0714, 0x0e003f0d, 0x2a000b05,   // de.sw.it_443 it.mt.de_666  af.is.un_540 es.mt.un_330
  0x04132507, 0x06000707, 0x110825ee, 0x065525a4,   // eu.et.fi_432 it.de.un_420  eu.no.ro_422 eu.rw.de_433
  0x162817a0, 0x0e2707a4, 0x110853ec, 0x21282012,   // sr.sw.hr_322 it.gd.is_433  ht.no.ro_644 sq.sw.jw_654
  // [cd90]
  0x0d121604, 0x55072aec, 0x0a00111b, 0x190105a0,   // hr.hu.cs_332 mt.it.rw_644  ro.mk.un_770 fr.en.gl_322
  0x1f0501ee, 0x10041707, 0x0121180c, 0x11000a0b,   // en.fr.cy_422 sr.ru.be_432  ga.jw.en_543 pt.ro.un_520
  0x552a0708, 0x25552d0c, 0x272818ad, 0x07002514,   // it.mt.rw_443 sk.rw.eu_543  ga.sw.gd_643 eu.it.un_660
  0x0b5364a0, 0x0c251904, 0x2700050c, 0x3f2164a7,   // lg.ht.es_322 gl.eu.sv_332  fr.gd.un_530 lg.jw.af_532
  // [cda0]
  0x17080a13, 0x020c25ee, 0x64550c0d, 0x08250c08,   // mk.uk.sr_665 eu.sv.da_422  sv.rw.lg_554 sv.eu.no_443
  0x0b0553af, 0x0f080e07, 0x190a25a9, 0x28182009,   // ht.fr.es_655 is.no.lv_432  eu.pt.gl_544 sq.ga.sw_444
  0x010c0802, 0x53002014, 0x212a0da0, 0x200e0804,   // no.sv.en_222 sq.ht.un_660  cs.mt.jw_322 no.is.sq_332
  0x160c1707, 0x0c020e07, 0x181a27ad, 0x2d0d13a4,   // sr.sv.hr_432 is.da.sv_432  gd.tl.ga_643 et.cs.sk_433
  // [cdb0]
  0x181312a0, 0x0a5305a0, 0x0a000423, 0x2521120c,   // hu.et.ga_322 fr.ht.pt_322  ru.mk.un_880 hu.jw.eu_543
  0x21121c0c, 0x29000c12, 0x12092a0e, 0x1b00061a,   // id.hu.jw_543 sv.sl.un_640  mt.pl.hu_555 de.tr.un_760
  0x10281807, 0x052164a0, 0x6b090d0c, 0x27092a04,   // ga.sw.lt_432 lg.jw.fr_322  cs.pl.ceb_543 mt.pl.gd_332
  0x0a0811ad, 0x25120908, 0x20040102, 0x0d001b08,   // ro.uk.mk_643 pl.hu.eu_443  en.fi.sq_222 tr.cs.un_430
  // [cdc0]
  0x210911a0, 0x08041160, 0x100801a0, 0x0710040d,   // ro.pl.jw_322 ro.ru.uk_664  en.no.lt_322 ru.be.bg_554
  0x271310a4, 0x0d00200c, 0x100d1604, 0x201e0e08,   // lt.et.gd_433 sq.cs.un_530  hr.cs.lt_332 is.ms.sq_443
  0x05001919, 0x6e003f12, 0x0e201207, 0x03000e07,   // gl.fr.un_750 af.blu.un_640  hu.sq.is_432 is.nl.un_420
  0x060403a0, 0x06120302, 0x126e6b02, 0x1f0408a7,   // nl.fi.de_322 nl.hu.de_222  ceb.blu.hu_222 no.fi.cy_532
  // [cdd0] --- double_langprob_start=cdd1 ---
  0x0a2319a4,                                       // gl.ca.pt_433
  };

//  COMPILE_ASSERT(52689 < (1 << 16), k_indirectbits_too_small);

extern const CLD2TableSummary kQuad_obj = {
  kQuadChrome0715,
  kQuadChrome0715Ind,
  kQuadChrome0715SizeOne,
  kQuadChrome0715Size,
  kQuadChrome0715KeyMask,
  kQuadChrome0715BuildDate,
  kQuadChrome0715RecognizedLangScripts,
};

}       // End namespace CLD2

// End of generated tables
